#
# spec file for package kernel-syms
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define variant %{nil}

%include %_sourcedir/kernel-spec-macros

Name:           kernel-syms
Summary:        Kernel Symbol Versions (modversions)
License:        GPL-2.0-only
Group:          Development/Sources
Version:        5.3.18
%if %using_buildservice
%if 0%{?is_kotd}
Release:        150300.59.101.1.gb2a976e
%else
Release:        150300.59.101.1
%endif
%else
%define kernel_source_release %(LC_ALL=C rpm -q kernel-devel%variant-%version --qf "%{RELEASE}" | grep -v 'not installed' || echo 0)
Release:        150300.59.101.1
%endif
URL:            https://www.kernel.org/
AutoReqProv:    off
BuildRequires:  coreutils
%ifarch aarch64
Requires:       kernel-64kb-devel = %version-%source_rel
%endif
%ifarch aarch64 armv7hl ppc64le s390x x86_64
Requires:       kernel-default-devel = %version-%source_rel
%endif
%ifarch armv7hl
Requires:       kernel-lpae-devel = %version-%source_rel
%endif
%ifarch aarch64 x86_64
Requires:       kernel-preempt-devel = %version-%source_rel
%endif
Requires:       pesign-obs-integration
Provides:       %name = %version-%source_rel
Provides:       %name-srchash-b2a976e56b17f0ba573577940956e3fcc1085fbe
Provides:       multiversion(kernel)
Source:         README.KSYMS
Requires:       kernel-devel%variant = %version-%source_rel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  aarch64 armv7hl ppc64le s390x x86_64
Prefix:         /usr/src

# Force bzip2 instead of lzma compression to
# 1) allow install on older dist versions, and
# 2) decrease build times (bsc#962356 boo#1175882)
%define _binary_payload w9.bzdio

%description
Kernel symbols, such as functions and variables, have version
information attached to them. This package contains the symbol versions
for the standard kernels.

This package is needed for compiling kernel module packages with proper
package dependencies.


%source_timestamp
%prep

%install
install -m 644 -D %{SOURCE0} %buildroot/%_docdir/%name/README.SUSE

%files
%defattr(-, root, root)
%dir %_docdir/%name
%_docdir/%name/README.SUSE

%changelog
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/usnic: fix set-but-not-unused variable 'flags' warning (git-fixes)
- commit 293bf91
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- IB/rdmavt: Add __init/__exit annotations to module init/exit funcs (git-fixes)
- commit f7baf6a
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/siw: Always consume all skbuf data in sk_data_ready() upcall. (git-fixes)
- commit d355c79
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix the error caused by qp->sk (git-fixes)
- commit 6d0ef48
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix "kernel NULL pointer dereference" error (git-fixes)
- commit 9205fa0
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/siw: Pass a pointer to virt_to_page() (git-fixes)
- commit 7daf160
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/cma: Fix arguments order in net device validation (git-fixes)
- commit 7890ffd
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rtrs-srv: Pass the correct number of entries for dma mapped SGL (git-fixes)
- commit cc2cd02
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix error unwind in rxe_create_qp() (git-fixes)
- commit 4332868
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Add missing check for return value in get namespace flow (git-fixes)
- commit 19e84c3
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix rnr retry behavior (git-fixes)
- commit db88b1b
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/siw: Fix duplicated reported IW_CM_EVENT_CONNECT_REPLY event (git-fixes)
- commit c8db39b
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix potential memory leak in __qedr_alloc_mr() (git-fixes)
- commit e28b8f5
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA: remove useless condition in siw_create_cq() (git-fixes)
- commit 4c36066
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/cm: Fix memory leak in ib_cm_insert_listen (git-fixes)
- commit 3ec31d2
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix reporting QP timeout attribute (git-fixes)
- commit 26de3e3
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/hfi1: Fix potential integer multiplication overflow errors (git-fixes)
- commit 9d4253b
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Generate a completion for unsupported/invalid opcode (git-fixes)
- commit 92bff10
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/hns: Remove unnecessary check for the sgid_attr when modifying QP (git-fixes)
- commit e806a5b
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/siw: Fix a condition race issue in MPA request processing (git-fixes)
- commit 709fd3a
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- IB/cm: Cancel mad on the DREQ event when the state is MRA_REP_RCVD (git-fixes)
- commit 121ed63
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Fix memory leak in error flow for subscribe event routine (git-fixes)
- commit 1408298
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- IB/cma: Allow XRC INI QPs to set their local ACK timeout (git-fixes)
- commit 8a4119a
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix NULL deref for query_qp on the GSI QP (git-fixes)
- commit f1870dd
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/mlx4: Return missed an error if device doesn't support steering (git-fixes)
- commit 53e12a2
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/bnxt_re: Fix query SRQ failure (git-fixes)
- commit 3389a3f
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix wrong port_cap_flags (git-fixes)
- commit a3b0ded
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/sa_query: Use strscpy_pad instead of memcpy to copy a string (git-fixes)
- commit 12260f5
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- IB/hfi1: Fix abba locking issue with sc_disable() (git-fixes)
- commit 7c89c4a
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- IB/qib: Protect from buffer overflow in struct qib_user_sdma_pkt fields (git-fixes)
- commit 1259749
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Set user priority for DCT (git-fixes)
- commit b499161
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/cma: Ensure rdma_addr_cancel() happens before issuing more requests (git-fixes)
- commit 74e3ed2
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/efa: Remove double QP type assignment (git-fixes)
- commit 858283b
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/iwcm: Release resources if iw_cm module initialization fails (git-fixes)
- commit 47de10e
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- IB/hfi1: Adjust pkey entry in index 0 (git-fixes)
- commit 385ff05
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/efa: Free IRQ vectors on error flow (git-fixes)
- commit 2498525
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- IB/hfi1: Fix possible null-pointer dereference in _extend_sdma_tx_descs() (git-fixes)
- commit 96f828c
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/bnxt_re: Add missing spin lock initialization (git-fixes)
- commit 49315d8
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Don't overwrite errno from ib_umem_get() (git-fixes)
- commit dc6482e
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix redundant skb_put_zero (git-fixes)
- commit 4b744b6
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix extra copy in prepare_ack_packet (git-fixes)
- commit b0c4366
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Remove unused pkt->offset (git-fixes)
- commit 2e0cf31
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix over copying in get_srq_wqe (git-fixes)
- commit 8d71bad
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix extra copies in build_rdma_network_hdr (git-fixes)
- commit 2b87978
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix redundant call to ip_send_check (git-fixes)
- commit 6f47c39
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix failure during driver load (git-fixes)
- commit bb23773
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/core: Sanitize WQ state received from the userspace (git-fixes)
- commit 1ebcca8
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- IB/core: Only update PKEY and GID caches on respective events (git-fixes)
- commit 242d271
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- IB/srpt: Remove redundant assignment to ret (git-fixes)
- commit 1421a09
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA: Verify port when creating flow rule (git-fixes)
- commit 75b7985
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- IB/mlx4: Use port iterator and validation APIs (git-fixes)
- commit c3aa778
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Block FDB rules when not in switchdev mode (git-fixes)
- commit 097d131
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Return CQE error if invalid lkey was supplied (git-fixes)
- commit 8811d6a
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMa/mthca: Work around -Wenum-conversion warning (git-fixes)
- commit e6dae53
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/cxgb4: Remove MW support (git-fixes)
- commit d49ea58
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Make mkeys always owned by the kernel's PD when not enabled (git-fixes)
- commit fdca7b3
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Use set_mkc_access_pd_addr_fields() in reg_create() (git-fixes)
- commit 289115b
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/i40iw: Use ib_umem_num_dma_pages() (git-fixes)
- commit ad98a0c
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/efa: Use ib_umem_num_dma_pages() (git-fixes)
- commit cda973b
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- RDMA/qib: Remove superfluous fallthrough statements (git-fixes)
- commit 0c97417
* Mon Oct 31 2022 nmoreychaisemartin@suse.com
- IB/mlx4: Add support for REJ due to timeout (git-fixes)
- commit dd6c131
* Mon Oct 31 2022 osalvador@suse.de
- Rename colliding patches before the next cve/linux-5.3 -> SLE15-SP3 merge
- commit a77f876
* Mon Oct 31 2022 msuchanek@suse.de
- kbuild: remove the target in signal traps when interrupted
  (git-fixes).
- kbuild: sink stdout from cmd for silent build (git-fixes).
- commit d17022d
* Mon Oct 31 2022 ptesarik@suse.cz
- blacklist.conf: Unnecessary S390 ARCHITECTURE fixes.
- commit 8f1bd85
* Mon Oct 31 2022 msuchanek@suse.de
- kbuild: Add skip_encoding_btf_enum64 option to pahole
  (git-fixes).
- kbuild: skip per-CPU BTF generation for pahole v1.18-v1.21
  (jsc#SLE-24559).
- commit 7b939ad
* Mon Oct 31 2022 tiwai@suse.de
- fbdev: cyber2000fb: fix missing pci_disable_device()
  (git-fixes).
- fbdev: da8xx-fb: Fix error handling in .remove() (git-fixes).
- iio: adc: mcp3911: use correct id bits (git-fixes).
- iio: light: tsl2583: Fix module unloading (git-fixes).
- usb: dwc3: gadget: Don't set IMI for no_interrupt (git-fixes).
- usb: dwc3: gadget: Stop processing more requests on IMI
  (git-fixes).
- usb: bdc: change state when port disconnected (git-fixes).
- hwmon/coretemp: Handle large core ID value (git-fixes).
- ACPI: extlog: Handle multiple records (git-fixes).
- commit 77773fb
* Sat Oct 29 2022 tiwai@suse.de
- device property: Fix documentation for *_match_string() APIs
  (git-fixes).
- PM: domains: Fix handling of unavailable/disabled idle states
  (git-fixes).
- PM: hibernate: Allow hybrid sleep to work with s2idle
  (git-fixes).
- mmc: core: Fix kernel panic when remove non-standard SDIO card
  (git-fixes).
- mtd: rawnand: marvell: Use correct logic for nand-keep-config
  (git-fixes).
- ALSA: aoa: Fix I2S device accounting (git-fixes).
- ALSA: Use del_timer_sync() before freeing timer (git-fixes).
- ALSA: aoa: i2sbus: fix possible memory leak in i2sbus_add_dev()
  (git-fixes).
- ALSA: rme9652: use explicitly signed char (git-fixes).
- ALSA: au88x0: use explicitly signed char (git-fixes).
- ALSA: ac97: fix possible memory leak in snd_ac97_dev_register()
  (git-fixes).
- drm/msm/hdmi: fix memory corruption with too many bridges
  (git-fixes).
- drm/msm/dsi: fix memory corruption with too many bridges
  (git-fixes).
- drm/msm: Fix return type of mdp4_lvds_connector_mode_valid
  (git-fixes).
- can: kvaser_usb: Fix possible completions during init_completion
  (git-fixes).
- openvswitch: switch from WARN to pr_warn (git-fixes).
- can: mscan: mpc5xxx: mpc5xxx_can_probe(): add missing
  put_clock() in error path (git-fixes).
- mac802154: Fix LQI recording (git-fixes).
- media: videodev2.h: V4L2_DV_BT_BLANKING_HEIGHT should check
  'interlaced' (git-fixes).
- media: v4l2-dv-timings: add sanity checks for blanking values
  (git-fixes).
- commit c820733
* Fri Oct 28 2022 osalvador@suse.de
- Fix build warning
  Refreshed:
  patches.suse/mm-hugetlb-fix-races-when-looking-up-a-CONT-PTE-PMD-.patch
- commit ca5cb24
* Thu Oct 27 2022 jack@suse.cz
- Add CVE reference to
  patches.suse/net-usb-ax88179_178a-Fix-out-of-bounds-accesses-in-R.patch
  (bsc#1196018 CVE-2022-28748 CVE-2022-2964).
- commit 94992c9
* Thu Oct 27 2022 tiwai@suse.de
- thermal: intel_powerclamp: Use first online CPU as control_cpu
  (git-fixes).
- HID: magicmouse: Do not set BTN_MOUSE on double report
  (git-fixes).
- ALSA: oss: Fix potential deadlock at unregistration (git-fixes).
- ALSA: rawmidi: Drop register_mutex in snd_rawmidi_free()
  (git-fixes).
- ALSA: hda/realtek: Add Intel Reference SSID to support headset
  keys (git-fixes).
- ALSA: hda/realtek: Add quirk for ASUS GV601R laptop (git-fixes).
- clk: bcm2835: Make peripheral PLLC critical (git-fixes).
- clk: zynqmp: pll: rectify rate rounding in zynqmp_pll_round_rate
  (git-fixes).
- clk: zynqmp: Fix stack-out-of-bounds in strncpy` (git-fixes).
- staging: rtl8723bs: fix a potential memory leak in
  rtw_init_cmd_priv() (git-fixes).
- staging: vt6655: fix potential memory leak (git-fixes).
- iio: pressure: dps310: Reset chip after timeout (git-fixes).
- iio: pressure: dps310: Refactor startup procedure (git-fixes).
- usb: add quirks for Lenovo OneLink+ Dock (git-fixes).
- usb: idmouse: fix an uninit-value in idmouse_open (git-fixes).
- usb: musb: Fix musb_gadget.c rxstate overflow bug (git-fixes).
- usb: host: xhci: Fix potential memory leak in
  xhci_alloc_stream_info() (git-fixes).
- power: supply: adp5061: fix out-of-bounds read in
  adp5061_get_chg_type() (git-fixes).
- HSI: omap_ssi_port: Fix dma_map_sg error check (git-fixes).
- HSI: omap_ssi: Fix refcount leak in ssi_probe (git-fixes).
- HID: roccat: Fix use-after-free in roccat_read() (git-fixes).
- media: cx88: Fix a null-ptr-deref bug in buffer_prepare()
  (git-fixes).
- ata: libahci_platform: Sanity check the DT child nodes number
  (git-fixes).
- ALSA: usb-audio: Fix potential memory leaks (git-fixes).
- ALSA: usb-audio: Fix NULL dererence at error path (git-fixes).
- drm/amdgpu: fix initial connector audio value (git-fixes).
- drm: panel-orientation-quirks: Add quirk for Anbernic Win600
  (git-fixes).
- drm: Prevent drm_copy_field() to attempt copying a NULL pointer
  (git-fixes).
- drm: Use size_t type for len variable in drm_copy_field()
  (git-fixes).
- drm/nouveau/nouveau_bo: fix potential memory leak in
  nouveau_bo_alloc() (git-fixes).
- platform/x86: msi-laptop: Change DMI match / alias strings to
  fix module autoloading (git-fixes).
- mmc: sdhci-msm: add compatible string check for sdm670
  (git-fixes).
- Bluetooth: L2CAP: Fix user-after-free (git-fixes).
- Bluetooth: hci_sysfs: Fix attempting to call device_add multiple
  times (git-fixes).
- Bluetooth: L2CAP: initialize delayed works at
  l2cap_chan_create() (git-fixes).
- wifi: rt2x00: correctly set BBP register 86 for MT7620
  (git-fixes).
- wifi: rt2x00: set SoC wmac clock register (git-fixes).
- wifi: rt2x00: set VGC gain for both chains of MT7620
  (git-fixes).
- wifi: rt2x00: set correct TX_SW_CFG1 MAC register for MT7620
  (git-fixes).
- wifi: rt2x00: don't run Rt5592 IQ calibration on MT7620
  (git-fixes).
- wifi: brcmfmac: fix use-after-free bug in
  brcmf_netdev_start_xmit() (git-fixes).
- can: bcm: check the result of can_send() in bcm_can_tx()
  (git-fixes).
- wifi: ath9k: avoid uninit memory read in ath9k_htc_rx_msg()
  (git-fixes).
- wifi: brcmfmac: fix invalid address access when enabling SCAN
  log level (git-fixes).
- openvswitch: Fix overreporting of drops in dropwatch
  (git-fixes).
- openvswitch: Fix double reporting of drops in dropwatch
  (git-fixes).
- thermal: intel_powerclamp: Use get_cpu() instead of
  smp_processor_id() to avoid crash (git-fixes).
- ACPI: video: Add Toshiba Satellite/Portege Z830 quirk
  (git-fixes).
- HID: hidraw: fix memory leak in hidraw_release() (git-fixes).
- commit 89baab9
* Thu Oct 27 2022 mkoutny@suse.com
- kthread: Extract KTHREAD_IS_PER_CPU (bsc#1204753).
- commit 0463863
* Thu Oct 27 2022 osalvador@suse.de
- mm/hugetlb: fix races when looking up a CONT-PTE/PMD size
  hugetlb page (bsc#1204575).
- commit 06c4f04
* Wed Oct 26 2022 ailiop@suse.com
- xfs: reserve data and rt quota at the same time (bsc#1203496).
- commit fb82e46
* Wed Oct 26 2022 lduncan@suse.com
- scsi: libsas: Fix use-after-free bug in smp_execute_task_sg()
  (git-fixes).
- scsi: mpt3sas: Fix return value check of dma_get_required_mask()
  (git-fixes).
- scsi: qla2xxx: Fix disk failure to rediscover (git-fixes).
- commit 0ca6891
* Wed Oct 26 2022 mkoutny@suse.com
- mm: memcontrol: fix occasional OOMs due to proportional
  memory.low reclaim (bsc#1204754).
- mm, memcg: avoid stale protection values when cgroup is above
  protection (bsc#1204754).
- commit 0e7d107
* Wed Oct 26 2022 mkoutny@suse.com
- cgroup/cpuset: Enable update_tasks_cpumask() on top_cpuset
  (bsc#1204753).
- commit b8640ed
* Wed Oct 26 2022 mkoutny@suse.com
- blacklist.conf: Add cgroup: cgroup: Honor caller's cgroup NS when resolving cgroup id
- commit d9d65d4
* Wed Oct 26 2022 msuchanek@suse.de
- powerpc/fadump: align destination address to pagesize
  (bsc#1204728 ltc#200074).
- commit 618ab17
* Wed Oct 26 2022 ailiop@suse.com
- fs: move S_ISGID stripping into the vfs_*() helpers (bsc#1198702
  CVE-2021-4037).
- commit 2f39bf9
* Wed Oct 26 2022 ailiop@suse.com
- fs: Add missing umask strip in vfs_tmpfile (bsc#1198702
  CVE-2021-4037).
- commit ab394e7
* Wed Oct 26 2022 ailiop@suse.com
- fs: add mode_strip_sgid() helper (bsc#1198702 CVE-2021-4037).
- commit 536e02f
* Wed Oct 26 2022 oneukum@suse.com
- usb: mon: make mmapped memory read only (bsc#1204653
  CVE-2022-43750).
- commit 1f646df
* Tue Oct 25 2022 lduncan@suse.com
- blacklist.conf: add commit from git-fixes
- commit c46aa6a
* Tue Oct 25 2022 vkarasulli@suse.de
- devlink: Fix use-after-free after a failed reload (bsc#1204637
  CVE-2022-3625).
- commit 3567978
* Mon Oct 24 2022 iivanov@suse.de
- kABI: arm64/crypto/sha512 Preserve function signature (git-fixes).
- commit 9ea634f
* Mon Oct 24 2022 iivanov@suse.de
- arm64: assembler: add cond_yield macro (git-fixes)
- commit f628c0a
* Mon Oct 24 2022 tbogendoerfer@suse.de
- net: mvpp2: fix mvpp2 debugfs leak (bsc#1204417 CVE-2022-3535).
- bnx2x: fix potential memory leak in bnx2x_tpa_stop()
  (bsc#1204402 CVE-2022-3542).
- nfp: fix use-after-free in area_cache_get() (bsc#1204415
  CVE-2022-3545).
- commit 9a28d9e
* Mon Oct 24 2022 tiwai@suse.de
- nilfs2: fix leak of nilfs_root in case of writer thread creation
  failure (CVE-2022-3646 bsc#1204646).
- nilfs2: fix use-after-free bug of struct nilfs_root
  (CVE-2022-3649 bsc#1204647).
- vsock: Fix memory leak in vsock_connect() (CVE-2022-3629
  bsc#1204635).
- commit 772e9a5
* Mon Oct 24 2022 tiwai@suse.de
- Bluetooth: L2CAP: fix use-after-free in l2cap_conn_del()
  (CVE-2022-3640 bsc#1204619).
- commit b1ed4c2
* Mon Oct 24 2022 iivanov@suse.de
- crypto: arm64/sha512-ce - simplify NEON yield (git-fixes)
- commit d60e491
* Mon Oct 24 2022 iivanov@suse.de
- crypto: arm64/sha3-ce - simplify NEON yield (git-fixes)
- commit 477d56a
* Mon Oct 24 2022 ptesarik@suse.cz
- KVM: s390: pv: don't present the ecall interrupt twice
  (git-fixes).
- KVM: s390x: fix SCK locking (git-fixes).
- KVM: s390: Clarify SIGP orders versus STOP/RESTART (git-fixes).
- KVM: s390: preserve deliverable_mask in __airqs_kick_single_vcpu
  (git-fixes).
- KVM: s390: clear kicked_mask before sleeping again (git-fixes).
- KVM: s390: VSIE: fix MVPG handling for prefixing and MSO
  (git-fixes).
- KVM: s390: split kvm_s390_real_to_abs (git-fixes).
- commit 1c45296
* Mon Oct 24 2022 iivanov@suse.de
- crypto: arm64/sha2-ce - simplify NEON yield (git-fixes)
- commit ec837bd
* Mon Oct 24 2022 iivanov@suse.de
- crypto: arm64/sha1-ce - simplify NEON yield (git-fixes)
- commit bf7093a
* Mon Oct 24 2022 iivanov@suse.de
- crypto: arm64/sha - fix function types (git-fixes)
- commit 887f265
* Mon Oct 24 2022 denis.kirjanov@suse.com
- Update metadata references
- commit 980fadf
* Mon Oct 24 2022 iivanov@suse.de
- blacklist.conf: ("arm64: Introduce a way to disable the 32bit vdso")
- commit 0591754
* Fri Oct 21 2022 vkarasulli@suse.de
- KVM: x86: do not report a vCPU as preempted outside instruction
  boundaries (bsc#1203066 CVE-2022-39189).
- commit 89982eb
* Fri Oct 21 2022 tiwai@suse.de
- nilfs2: fix NULL pointer dereference at
  nilfs_bmap_lookup_at_level() (CVE-2022-3621 bsc#1204574).
- commit df5c951
* Wed Oct 19 2022 tiwai@suse.de
- r8152: Rate limit overflow messages (CVE-2022-3594 bsc#1204479).
- commit 488dede
* Wed Oct 19 2022 tiwai@suse.de
- HID: bigben: fix slab-out-of-bounds Write in bigben_probe
  (CVE-2022-3577 bsc#1204470).
- commit e57339b
* Tue Oct 18 2022 denis.kirjanov@suse.com
- kcm: avoid potential race in kcm_tx_work (bsc#1204355
  CVE-2022-3521).
- commit d2eeccc
* Tue Oct 18 2022 denis.kirjanov@suse.com
- tcp/udp: Fix memory leak in ipv6_renew_options() (bsc#1204354
  CVE-2022-3524).
- commit ec8a71d
* Tue Oct 18 2022 denis.kirjanov@suse.com
- Update metadata references
- commit 6d888aa
* Tue Oct 18 2022 tiwai@suse.de
- sch_sfb: Also store skb len before calling child enqueue
  (CVE-2022-3586 bsc#1204439).
- sch_sfb: Don't assume the skb is still around after enqueueing
  to child (CVE-2022-3586 bsc#1204439).
- commit bbd433f
* Tue Oct 18 2022 tiwai@suse.de
- mISDN: fix use-after-free bugs in l1oip timer handlers
  (CVE-2022-3565 bsc#1204431).
- commit 1917bcf
* Tue Oct 18 2022 tiwai@suse.de
- net: ieee802154: return -EINVAL for unknown addr type
  (git-fixes).
- commit 2d80805
* Tue Oct 18 2022 tiwai@suse.de
- ACPI: HMAT: Release platform device in case of
  platform_device_add_data() fails (git-fixes).
- rtc: stmp3xxx: Add failure handling for stmp3xxx_wdt_register()
  (git-fixes).
- ALSA: hda/realtek: Correct pin configs for ASUS G533Z
  (git-fixes).
- ALSA: hda/realtek: remove ALC289_FIXUP_DUAL_SPK for Dell 5530
  (git-fixes).
- Input: xpad - add supported devices as contributed on github
  (git-fixes).
- USB: serial: qcserial: add new usb-id for Dell branded EM7455
  (git-fixes).
- USB: serial: ftdi_sio: fix 300 bps rate for SIO (git-fixes).
- ALSA: hda: Fix position reporting on Poulsbo (git-fixes).
- mmc: core: Terminate infinite loop in SD-UHS voltage switch
  (git-fixes).
- firmware: arm_scmi: Add SCMI PM driver remove routine
  (git-fixes).
- net/ieee802154: fix uninit value bug in dgram_sendmsg
  (git-fixes).
- dmaengine: xilinx_dma: Report error in case of
  dma_set_mask_and_coherent API failure (git-fixes).
- dmaengine: xilinx_dma: cleanup for fetching xlnx,num-fstores
  property (git-fixes).
- rpmsg: qcom: glink: replace strncpy() with strscpy_pad()
  (git-fixes).
- mmc: core: Replace with already defined values for readability
  (git-fixes).
- commit ba86540
* Tue Oct 18 2022 tiwai@suse.de
- struct pci_config_window kABI workaround (bsc#1204382).
- commit b2287af
* Tue Oct 18 2022 tiwai@suse.de
- PCI: Dynamically map ECAM regions (bsc#1204382).
- commit dc89dd6
* Mon Oct 17 2022 msuchanek@suse.de
- powerpc/mm: remove pmd_huge/pud_huge stubs and include hugetlb.h
  (bsc#1065729).
- Refresh patches.suse/powerpc-mm-radix-Create-separate-mappings-for-hot-pl.patch
- Refresh patches.suse/powerpc-mm-radix-Remove-split_kernel_mapping.patch
- commit 852bb71
* Mon Oct 17 2022 oneukum@suse.com
- Revert "usb: storage: Add quirk for Samsung Fit flash"
  (git-fixes).
- commit c4ea05c
* Mon Oct 17 2022 oneukum@suse.com
- USB: serial: qcserial: add new usb-id for Dell branded EM7455
  (git-fixes).
- commit 72baa22
* Mon Oct 17 2022 msuchanek@suse.de
- powerpc/mm/64s: Drop pgd_huge() (bsc#1065729).
- powerpc/powernv: add missing of_node_put() in
  opal_export_attrs() (bsc#1065729).
- powerpc/pci_dn: Add missing of_node_put() (bsc#1065729).
- commit 11a4b1b
* Mon Oct 17 2022 msuchanek@suse.de
- powerpc/kprobes: Fix null pointer reference in
  arch_prepare_kprobe() (jsc#SLE-13847 git-fixes).
- powerpc/64: Remove unused SYS_CALL_TABLE symbol (jsc#SLE-9246
  git-fixes).
- commit 98b4617
* Fri Oct 14 2022 ailiop@suse.com
- xfs: remove obsolete AGF counter debugging (git-fixes).
- commit 6b3cbd8
* Fri Oct 14 2022 ailiop@suse.com
- xfs: hoist out xfs_resizefs_init_new_ags() (git-fixes).
- commit c80d128
* Fri Oct 14 2022 ailiop@suse.com
- xfs: rename `new' to `delta' in xfs_growfs_data_private()
  (git-fixes).
- commit 7994309
* Fri Oct 14 2022 ailiop@suse.com
- xfs: streamline xfs_attr3_leaf_inactive (git-fixes).
- commit d0ec732
* Fri Oct 14 2022 ailiop@suse.com
- xfs: fix memory corruption during remote attr value buffer
  invalidation (git-fixes).
- commit 63ac0a8
* Fri Oct 14 2022 ailiop@suse.com
- xfs: refactor remote attr value buffer invalidation (git-fixes).
- commit cdcab38
* Fri Oct 14 2022 ailiop@suse.com
- xfs: fix s_maxbytes computation on 32-bit kernels (git-fixes).
- commit 260cd8e
* Fri Oct 14 2022 ailiop@suse.com
- xfs: move incore structures out of xfs_da_format.h (git-fixes).
- commit f916b39
* Fri Oct 14 2022 ailiop@suse.com
- xfs: add missing assert in xfs_fsmap_owner_from_rmap
  (git-fixes).
- commit 7d88bfe
* Fri Oct 14 2022 ailiop@suse.com
- xfs: slightly tweak an assert in xfs_fs_map_blocks (git-fixes).
- commit dc70b98
* Fri Oct 14 2022 tiwai@suse.de
- mmc: sdhci-sprd: Fix minimum clock limit (git-fixes).
- wifi: iwlwifi: mvm: fix double list_add at
  iwl_mvm_mac_wake_tx_queue (other cases) (git-fixes).
- wifi: mac80211: do not drop packets smaller than the LLC-SNAP
  header on fast-rx (git-fixes).
- can: kvaser_usb_leaf: Fix CAN state after restart (git-fixes).
- can: kvaser_usb_leaf: Fix TX queue out of sync after restart
  (git-fixes).
- can: kvaser_usb: Fix use of uninitialized completion
  (git-fixes).
- mISDN: hfcpci: Fix use-after-free bug in hfcpci_softirq
  (git-fixes).
- watchdog: armada_37xx_wdt: Fix .set_timeout callback
  (git-fixes).
- watchdog: ftwdt010_wdt: fix test for platform_get_irq() failure
  (git-fixes).
- drm/i915/gvt: fix a memory leak in intel_gvt_init_vgpu_types
  (git-fixes).
- irqchip/ls-extirq: Fix invalid wait context by avoiding to
  use regmap (git-fixes).
- commit 90b2426
* Fri Oct 14 2022 tiwai@suse.de
- wifi: cfg80211: update hidden BSSes to avoid WARN_ON
  (git-fixes).
- wifi: mac80211_hwsim: avoid mac80211 warning on bad rate
  (git-fixes).
- commit d78eec4
* Fri Oct 14 2022 tiwai@suse.de
- Move upstreamed WiFi fixes into sorted section
- commit 2dec8da
* Fri Oct 14 2022 tiwai@suse.de
- Move upstreamed WiFi fixes into sorted section
- commit 05342a3
* Thu Oct 13 2022 dfaggioli@suse.com
- kABI: fix kABI after "KVM: Add infrastructure and macro to mark
  VM as bugged" (bsc#1200788 CVE-2022-2153).
- commit 1ddb693
* Thu Oct 13 2022 dfaggioli@suse.com
- KVM: Add infrastructure and macro to mark VM as bugged
  (bsc#1200788 CVE-2022-2153).
- commit 07862de
* Thu Oct 13 2022 jgross@suse.com
- locking/csd_lock: Change csdlock_debug from early_param to
  __setup (git-fixes).
- Refresh
  patches.suse/0002-kernel-smp-make-csdlock-timeout-depend-on-boot-param.patch.
- commit 4abed38
* Thu Oct 13 2022 jgross@suse.com
- s390/hypfs: avoid error message under KVM (bsc#1032323).
- commit 2cf708c
* Thu Oct 13 2022 dfaggioli@suse.com
- KVM: x86: Forbid VMM to set SYNIC/STIMER MSRs when SynIC wasn't
  activated (bsc#1200788 CVE-2022-2153).
- commit 8712ddf
* Thu Oct 13 2022 dfaggioli@suse.com
- KVM: x86: hyper-v: disallow configuring SynIC timers with no
  SynIC (bsc#1200788 CVE-2022-2153).
- commit 75749d4
* Wed Oct 12 2022 jgross@suse.com
- KVM: nVMX: Unconditionally purge queued/injected events on
  nested "exit" (git-fixes).
- commit 04b8316
* Wed Oct 12 2022 dfaggioli@suse.com
- KVM: x86: Avoid theoretical NULL pointer dereference in
  kvm_irq_delivery_to_apic_fast() (bsc#1200788 CVE-2022-2153).
- commit f23b172
* Wed Oct 12 2022 jgross@suse.com
- KVM: x86/emulator: Fix handing of POP SS to correctly set
  interruptibility (git-fixes).
- commit 3671e7c
* Wed Oct 12 2022 dfaggioli@suse.com
- KVM: x86: Check lapic_in_kernel() before attempting to set a
  SynIC irq (bsc#1200788 CVE-2022-2153).
- commit e02caef
* Wed Oct 12 2022 ddiss@suse.de
- io_uring: disable polling signalfd pollfree files (CVE-2022-3176
  bsc#1203391).
- fs: fix UAF/GPF bug in nilfs_mdt_destroy (CVE-2022-2978
  bsc#1202700).
- commit 8c7541d
* Wed Oct 12 2022 tiwai@suse.de
- sbitmap: Avoid leaving waitqueue in invalid state in
  __sbq_wake_up() (git-fixes).
- commit 89e6f60
* Wed Oct 12 2022 tiwai@suse.de
- staging: vt6655: fix some erroneous memory clean-up loops
  (git-fixes).
- Revert "usb: storage: Add quirk for Samsung Fit flash"
  (git-fixes).
- usb: mon: make mmapped memory read only (git-fixes).
- usb: gadget: function: fix dangling pnp_string in f_printer.c
  (git-fixes).
- xhci: Don't show warning for reinit on known broken suspend
  (git-fixes).
- USB: serial: console: move mutex_unlock() before
  usb_serial_put() (git-fixes).
- vhost/vsock: Use kvmalloc/kvfree for larger packets (git-fixes).
- wifi: rtl8xxxu: Improve rtl8xxxu_queue_select (git-fixes).
- wifi: rtl8xxxu: Fix AIFS written to REG_EDCA_*_PARAM
  (git-fixes).
- wifi: rtl8xxxu: Remove copy-paste leftover in
  gen2_update_rate_mask (git-fixes).
- wifi: rtl8xxxu: gen2: Fix mistake in path B IQ calibration
  (git-fixes).
- wifi: rtl8xxxu: Fix skb misuse in TX queue selection
  (git-fixes).
- wifi: rtl8xxxu: tighten bounds checking in rtl8xxxu_read_efuse()
  (git-fixes).
- wifi: ath10k: add peer map clean up for peer delete in
  ath10k_sta_state() (git-fixes).
- wifi: mac80211: allow bw change during channel switch in mesh
  (git-fixes).
- commit d4e6eb9
* Wed Oct 12 2022 tiwai@suse.de
- soc: sunxi_sram: Make use of the helper function
  devm_platform_ioremap_resource() (git-fixes).
- Refresh
  patches.suse/soc-sunxi-sram-Prevent-the-driver-from-being-unbound.patch.
- commit 1478c4f
* Wed Oct 12 2022 tiwai@suse.de
- PCI: Sanitise firmware BAR assignments behind a PCI-PCI bridge
  (git-fixes).
- PCI: Fix used_buses calculation in pci_scan_child_bus_extend()
  (git-fixes).
- pinctrl: rockchip: add pinmux_ops.gpio_set_direction callback
  (git-fixes).
- pinctrl: armada-37xx: Checks for errors in gpio_request_enable
  callback (git-fixes).
- pinctrl: armada-37xx: Fix definitions for MPP pins 20-22
  (git-fixes).
- pinctrl: armada-37xx: Add missing GPIO-only pins (git-fixes).
- tty: serial: fsl_lpuart: disable dma rx/tx use flags in
  lpuart_dma_shutdown (git-fixes).
- drivers: serial: jsm: fix some leaks in probe (git-fixes).
- tty: xilinx_uartps: Fix the ignore_status (git-fixes).
- phy: qualcomm: call clk_disable_unprepare in the error handling
  (git-fixes).
- sbitmap: fix possible io hung due to lost wakeup (git-fixes).
- soc: qcom: smem_state: Add refcounting for the 'state->of_node'
  (git-fixes).
- soc: qcom: smsm: Fix refcount leak bugs in qcom_smsm_probe()
  (git-fixes).
- platform/x86: msi-laptop: Fix resource cleanup (git-fixes).
- platform/x86: msi-laptop: Fix old-ec check for backlight
  registering (git-fixes).
- spi: s3c64xx: Fix large transfers with DMA (git-fixes).
- spi/omap100k:Fix PM disable depth imbalance in
  omap1_spi100k_probe (git-fixes).
- spi: qup: add missing clk_disable_unprepare on error in
  spi_qup_pm_resume_runtime() (git-fixes).
- spi: qup: add missing clk_disable_unprepare on error in
  spi_qup_resume() (git-fixes).
- spi: mt7621: Fix an error message in mt7621_spi_probe()
  (git-fixes).
- regulator: qcom_rpm: Fix circular deferral regression
  (git-fixes).
- uas: ignore UAS for Thinkplus chips (git-fixes).
- usb-storage: Add Hiksemi USB3-FW to IGNORE_UAS (git-fixes).
- uas: add no-uas quirk for Hiksemi usb_disk (git-fixes).
- net: usb: qmi_wwan: Add new usb-id for Dell branded EM7455
  (git-fixes).
- commit d4e37ac
* Wed Oct 12 2022 tiwai@suse.de
- Input: i8042 - fix refount leak on sparc (git-fixes).
- Input: xpad - fix wireless 360 controller breaking after suspend
  (git-fixes).
- lib/sg_pool: change module_init(sg_pool_init) to subsys_initcall
  (git-fixes).
- mailbox: bcm-ferxrm-mailbox: Fix error check for dma_map_sg
  (git-fixes).
- iio: adc: ad7923: fix channel readings for some variants
  (git-fixes).
- iio: dac: ad5593r: Fix i2c read protocol requirements
  (git-fixes).
- iio: ABI: Fix wrong format of differential capacitance channel
  ABI (git-fixes).
- iio: inkern: only release the device node when done with it
  (git-fixes).
- iio: adc: at91-sama5d2_adc: lock around oversampling and sample
  freq (git-fixes).
- iio: adc: at91-sama5d2_adc: check return status for pressure
  and touch (git-fixes).
- iio: adc: at91-sama5d2_adc: fix AT91_SAMA5D2_MR_TRACKTIM_MAX
  (git-fixes).
- misc: ocxl: fix possible refcount leak in afu_ioctl()
  (git-fixes).
- mtd: rawnand: atmel: Unmap streaming DMA mappings (git-fixes).
- mtd: rawnand: meson: fix bit map use in meson_nfc_ecc_correct()
  (git-fixes).
- mtd: devices: docg3: check the return value of devm_ioremap()
  in the probe (git-fixes).
- mfd: sm501: Add check for platform_driver_register()
  (git-fixes).
- mfd: lp8788: Fix an error handling path in lp8788_irq_init()
  and lp8788_irq_init() (git-fixes).
- mfd: lp8788: Fix an error handling path in lp8788_probe()
  (git-fixes).
- mfd: fsl-imx25: Fix an error handling path in
  mx25_tsadc_setup_irq() (git-fixes).
- mfd: intel_soc_pmic: Fix an error handling path in
  intel_soc_pmic_i2c_probe() (git-fixes).
- HID: multitouch: Add memory barriers (git-fixes).
- media: xilinx: vipp: Fix refcount leak in xvip_graph_dma_init
  (git-fixes).
- media: cedrus: Set the platform driver data earlier (git-fixes).
- memory: of: Fix refcount leak bug in of_get_ddr_timings()
  (git-fixes).
- memory: pl353-smc: Fix refcount leak bug in pl353_smc_probe()
  (git-fixes).
- mmc: wmt-sdmmc: Fix an error handling path in wmt_mci_probe()
  (git-fixes).
- mmc: au1xmmc: Fix an error handling path in au1xmmc_probe()
  (git-fixes).
- mISDN: fix use-after-free bugs in l1oip timer handlers
  (git-fixes).
- commit ea51746
* Wed Oct 12 2022 tiwai@suse.de
- gpio: rockchip: request GPIO mux to pinctrl when setting
  direction (git-fixes).
- crypto: cavium - prevent integer overflow loading firmware
  (git-fixes).
- crypto: ccp - Release dma channels before dmaengine unrgister
  (git-fixes).
- crypto: akcipher - default implementation for setting a private
  key (git-fixes).
- crypto: hisilicon/zip - fix mismatch in get/set sgl_sge_nr
  (git-fixes).
- efi: libstub: drop pointless get_memory_map() call (git-fixes).
- clk: bcm2835: fix bcm2835_clock_rate_from_divisor declaration
  (git-fixes).
- firmware: google: Test spinlock on panic path to avoid lockups
  (git-fixes).
- fpga: prevent integer overflow in dfl_feature_ioctl_set_irq()
  (git-fixes).
- dyndbg: let query-modname override actual module name
  (git-fixes).
- dyndbg: fix module.dyndbg handling (git-fixes).
- dmaengine: ioat: stop mod_timer from resurrecting deleted
  timer in __cleanup() (git-fixes).
- hid: hid-logitech-hidpp: avoid unnecessary assignments in
  hidpp_connect_event (git-fixes).
- drm/udl: Restore display mode on resume (git-fixes).
- drm/omap: dss: Fix refcount leak bugs (git-fixes).
- drm/msm/dpu: Fix comment typo (git-fixes).
- drm/msm/dpu: index dpu_kms->hw_vbif using vbif_idx (git-fixes).
- drm/scheduler: quieten kernel-doc warnings (git-fixes).
- drm/bridge: megachips: Fix a null pointer dereference bug
  (git-fixes).
- drm: fix drm_mipi_dbi build errors (git-fixes).
- drm/msm: Make .remove and .shutdown HW shutdown consistent
  (git-fixes).
- drm:pl111: Add of_node_put() when breaking out of
  for_each_available_child_of_node() (git-fixes).
- drm/bridge: parade-ps8640: Fix regulator supply order
  (git-fixes).
- drm/mipi-dsi: Detach devices when removing the host (git-fixes).
- drm/bridge: Avoid uninitialized variable warning (git-fixes).
- drm/nouveau: fix a use-after-free in
  nouveau_gem_prime_import_sg_table() (git-fixes).
- drm: bridge: adv7511: fix CEC power down control register offset
  (git-fixes).
- efi: Correct Macmini DMI match in uefi cert quirk (git-fixes).
- docs: update mediator information in CoC docs (git-fixes).
- commit 6db482b
* Wed Oct 12 2022 tiwai@suse.de
- ACPI: APEI: do not add task_work to kernel thread to avoid
  memory leak (git-fixes).
- clk: qcom: gcc-msm8916: use ARRAY_SIZE instead of specifying
  num_parents (git-fixes).
- clk: mediatek: mt8183: mfgcfg: Propagate rate changes to parent
  (git-fixes).
- clk: ti: dra7-atl: Fix reference leak in of_dra7_atl_clk_probe
  (git-fixes).
- clk: tegra20: Fix refcount leak in tegra20_clock_init
  (git-fixes).
- clk: tegra: Fix refcount leak in tegra114_clock_init
  (git-fixes).
- clk: tegra: Fix refcount leak in tegra210_clock_init
  (git-fixes).
- clk: berlin: Add of_node_put() for of_get_parent() (git-fixes).
- clk: qoriq: Hold reference returned by of_get_parent()
  (git-fixes).
- clk: oxnas: Hold reference returned by of_get_parent()
  (git-fixes).
- ata: fix ata_id_has_dipm() (git-fixes).
- ata: fix ata_id_has_ncq_autosense() (git-fixes).
- ata: fix ata_id_has_devslp() (git-fixes).
- ata: fix ata_id_sense_reporting_enabled() and
  ata_id_has_sense_reporting() (git-fixes).
- ASoC: mt6660: Fix PM disable depth imbalance in mt6660_i2c_probe
  (git-fixes).
- ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe
  (git-fixes).
- ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe
  (git-fixes).
- ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe
  (git-fixes).
- ASoC: eureka-tlv320: Hold reference returned from of_find_xxx
  API (git-fixes).
- ASoC: rsnd: Add check for rsnd_mod_power_on (git-fixes).
- ASoC: fsl_sai: Remove unnecessary FIFO reset in ISR (git-fixes).
- ALSA: hda/hdmi: Don't skip notification handling during PM
  operation (git-fixes).
- ALSA: dmaengine: increment buffer pointer atomically
  (git-fixes).
- ALSA: asihpi - Remove useless code in hpi_meter_get_peak()
  (git-fixes).
- ASoC: wcd934x: fix order of Slimbus unprepare/disable
  (git-fixes).
- ASoC: wcd9335: fix order of Slimbus unprepare/disable
  (git-fixes).
- Bluetooth: hci_core: Fix not handling link timeouts propertly
  (git-fixes).
- commit 058f8fc
* Mon Oct 10 2022 vbabka@suse.cz
- Update
  patches.suse/mm-rmap-Fix-anon_vma-degree-ambiguity-leading-to-double-reuse.patch
  (CVE-2022-42703, bsc#1204168, git-fixes, bsc#1203098).
- commit 15fe693
* Mon Oct 10 2022 tiwai@suse.de
- misc: sgi-gru: fix use-after-free error in
  gru_set_context_option, gru_fault and gru_handle_user_call_os
  (CVE-2022-3424 bsc#1204166).
- commit 721c580
* Mon Oct 10 2022 tiwai@suse.de
- wifi: mac80211: fix crash in beacon protection for P2P-device
  (CVE-2022-42722 bsc#1204125).
- commit a6f4ca8
* Mon Oct 10 2022 tiwai@suse.de
- wifi: mac80211: refactor elements parsing with parameter struct
  (CVE-2022-42719 bsc#1204051).
- commit 26c2d4f
* Mon Oct 10 2022 tiwai@suse.de
- mac80211: fix memory leaks with element parsing (CVE-2022-42719
  bsc#1204051).
- commit a818808
* Mon Oct 10 2022 tiwai@suse.de
- mac80211: always allocate struct ieee802_11_elems
  (CVE-2022-42719 bsc#1204051).
- commit a183a67
* Mon Oct 10 2022 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vc4: hdmi: Prevent access to crtc->state outside of KMS'
- commit 39988a9
* Mon Oct 10 2022 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vc4: hdmi: Use a mutex to prevent concurrent framework access'
- commit c6967e3
* Mon Oct 10 2022 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vc4: hdmi: Add a spinlock to protect register access'
- commit 7d9f3f3
* Mon Oct 10 2022 tiwai@suse.de
- wifi: cfg80211: avoid nontransmitted BSS list corruption
  (CVE-2022-42721 bsc#1204060).
- commit 5fe81ec
* Mon Oct 10 2022 tiwai@suse.de
- wifi: mac80211: fix MBSSID parsing use-after-free
  (CVE-2022-42719 bsc#1204051).
- commit 6462e9c
* Mon Oct 10 2022 tiwai@suse.de
- wifi: mac80211: refactor elements parsing with parameter struct
  (CVE-2022-42719 bsc#1204051).
- commit 7b3171e
* Mon Oct 10 2022 tiwai@suse.de
- mac80211: fix memory leaks with element parsing (CVE-2022-42719
  bsc#1204051).
- mac80211: always allocate struct ieee802_11_elems
  (CVE-2022-42719 bsc#1204051).
- commit 1d0e42c
* Mon Oct 10 2022 tiwai@suse.de
- wifi: cfg80211: fix BSS refcounting bugs (CVE-2022-42720
  bsc#1204059).
- mac80211: mlme: find auth challenge directly (CVE-2022-42719
  bsc#1204051).
- mac80211: move CRC into struct ieee802_11_elems (CVE-2022-42719
  bsc#1204051).
- wifi: cfg80211: fix BSS refcounting bugs (CVE-2022-42720
  bsc#1204059).
- cfg80211: hold bss_lock while updating nontrans_list
  (CVE-2022-42719 bsc#1204051).
- mac80211: mlme: find auth challenge directly (CVE-2022-42719
  bsc#1204051).
- mac80211: move CRC into struct ieee802_11_elems (CVE-2022-42719
  bsc#1204051).
- mac80211: don't re-parse elems in ieee80211_assoc_success()
  (CVE-2022-42719 bsc#1204051).
- commit cf17eed
* Mon Oct 10 2022 tiwai@suse.de
- exfat: Return ENAMETOOLONG consistently for oversized paths
  (bsc#1204053 bsc#1201725).
- commit 955135a
* Mon Oct 10 2022 msuchanek@suse.de
- selftests/powerpc: Skip energy_scale_info test on older firmware
  (git-fixes).
- commit 2a9f2c0
* Mon Oct 10 2022 oneukum@suse.com
- blacklist.conf: prerequisite too risky
- commit 67fdf07
* Mon Oct 10 2022 osalvador@suse.de
- Refresh metadata
  Refresh:
  patches.suse/nvme-ensure-subsystem-reset-is-single-threaded.patch
  patches.suse/nvme-restrict-management-ioctls-to-admin.patch
- commit 32aee9f
* Mon Oct 10 2022 osalvador@suse.de
- Rename colliding patches before the next cve/linux-5.3 -> SLE15-SP3 merge
- commit 3394628
* Mon Oct 10 2022 oneukum@suse.com
- net: usb: qmi_wwan: Add new usb-id for Dell branded EM7455
  (git-fixes).
- commit 71e1adc
* Mon Oct 10 2022 neilb@suse.de
- blacklist.conf: ignore unwanted nfs patches
- commit 5bb5269
* Mon Oct 10 2022 neilb@suse.de
- blacklist.conf: ignore unwanted md patches
- commit ff9f04a
* Sun Oct  9 2022 lduncan@suse.com
- scsi: stex: Properly zero out the passthrough command structure
  (bsc#1203514 CVE-2022-40768).
- commit b5c1e4b
* Fri Oct  7 2022 ailiop@suse.com
- xfs: enable big timestamps (bsc#1203387).
- commit e8c654f
* Fri Oct  7 2022 ailiop@suse.com
- xfs: widen ondisk quota expiration timestamps to handle y2038+
  (bsc#1203387).
- commit f11211b
* Fri Oct  7 2022 ailiop@suse.com
- quota: widen timestamps for the fs_disk_quota structure
  (bsc#1203387).
- commit 1a9210f
* Fri Oct  7 2022 ailiop@suse.com
- xfs: widen ondisk inode timestamps to deal with y2038+
  (bsc#1203387).
- commit ef6704e
* Fri Oct  7 2022 mgorman@suse.de
- ACPI: processor idle: Practically limit "Dummy wait" workaround
  to old Intel systems (bnc#1203802).
- commit 5c74e0f
* Fri Oct  7 2022 ailiop@suse.com
- xfs: redefine xfs_ictimestamp_t (bsc#1203387).
  Refresh
  patches.suse/xfs-repair-malformed-inode-items-during-log-recovery.patch.
- commit 79f8f1e
* Fri Oct  7 2022 ailiop@suse.com
- xfs: redefine xfs_timestamp_t (bsc#1203387).
- commit f6d0842
* Fri Oct  7 2022 ailiop@suse.com
- xfs: use a struct timespec64 for the in-core crtime
  (bsc#1203387).
- commit d683559
* Fri Oct  7 2022 ailiop@suse.com
- xfs: quota: move to time64_t interfaces (bsc#1203387).
- commit e4afdb9
* Fri Oct  7 2022 ailiop@suse.com
- xfs: explicitly define inode timestamp range (bsc#1203387).
- commit d8ae99a
* Thu Oct  6 2022 dwagner@suse.de
- nvme: ensure subsystem reset is single threaded (bsc#1203290
  CVE-2022-3169).
- nvme: restrict management ioctls to admin (bsc#1203290
  CVE-2022-3169).
- commit fb89dd3
* Wed Oct  5 2022 oneukum@suse.com
- media: aspeed-video: ignore interrupts that aren't enabled
  (git-fixes).
- commit 36a70fa
* Wed Oct  5 2022 oneukum@suse.com
- media: coda: Add more H264 levels for CODA960 (git-fixes).
- commit 6094fd3
* Wed Oct  5 2022 oneukum@suse.com
- media: coda: Fix reported H264 profile (git-fixes).
- commit af3ba3e
* Wed Oct  5 2022 ailiop@suse.com
- xfs: enable new inode btree counters feature (bsc#1203387).
- commit 06361ad
* Wed Oct  5 2022 ailiop@suse.com
- xfs: use the finobt block counts to speed up mount times
  (bsc#1203387).
- commit debb8f9
* Wed Oct  5 2022 ailiop@suse.com
- xfs: store inode btree block counts in AGI header (bsc#1203387).
- commit f9fb0f8
* Wed Oct  5 2022 tzimmermann@suse.de
- blacklist.conf: Append 'sysfb: Enable boot time VESA graphic mode selection'
- commit 49f0f34
* Tue Oct  4 2022 dwagner@suse.de
- Add CVE reference on lightnvm removal patch
  modified:
  - patches.drivers/lightnvm-remove-lightnvm-implemenation.patch
- commit 6251214
* Tue Oct  4 2022 tiwai@suse.de
- drm/amdgpu: don't register a dirty callback for non-atomic
  (git-fixes).
- commit 0b4b37a
* Tue Oct  4 2022 tiwai@suse.de
- wifi: mac80211: Fix UAF in ieee80211_scan_rx() (git-fixes).
- commit 0b58855
* Tue Oct  4 2022 tiwai@suse.de
- usb: typec: ucsi: Remove incorrect warning (git-fixes).
- USB: serial: option: add Quectel RM520N (git-fixes).
- USB: serial: option: add Quectel BG95 0x0203 composition
  (git-fixes).
- Revert "usb: add quirks for Lenovo OneLink+ Dock" (git-fixes).
- usb: add quirks for Lenovo OneLink+ Dock (git-fixes).
- video: fbdev: pxa3xx-gcu: Fix integer overflow in
  pxa3xx_gcu_write (git-fixes).
- usb: dwc3: gadget: Prevent repeat pullup() (git-fixes).
- usb: dwc3: gadget: Avoid starting DWC3 gadget during UDC unbind
  (git-fixes).
- usb: xhci-mtk: fix issue of out-of-bounds array access
  (git-fixes).
- commit 2e55e74
* Tue Oct  4 2022 tiwai@suse.de
- soc: sunxi: sram: Fix debugfs info for A64 SRAM C (git-fixes).
- soc: sunxi: sram: Prevent the driver from being unbound
  (git-fixes).
- soc: sunxi: sram: Actually claim SRAM regions (git-fixes).
- usb: xhci-mtk: add some schedule error number (git-fixes).
- usb: xhci-mtk: add a function to (un)load bandwidth info
  (git-fixes).
- usb: xhci-mtk: use @sch_tt to check whether need do TT schedule
  (git-fixes).
- usb: xhci-mtk: add only one extra CS for FS/LS INTR (git-fixes).
- usb: xhci-mtk: get the microframe boundary for ESIT (git-fixes).
- tty/serial: atmel: RS485 & ISO7816: wait for TXRDY before
  sending data (git-fixes).
- commit e040102
* Tue Oct  4 2022 bp@suse.de
- blacklist.conf: df5b035b5683 x86/cacheinfo: Add a cpu_llc_shared_mask() UP variant
- commit 51fbc8c
* Tue Oct  4 2022 tiwai@suse.de
- media: dvb_vb2: fix possible out of bound access (git-fixes).
- clk: iproc: Do not rely on node name for correct PLL setup
  (git-fixes).
- clk: imx: imx6sx: remove the SET_RATE_PARENT flag for QSPI
  clocks (git-fixes).
- Revert "drm: bridge: analogix/dp: add panel prepare/unprepare
  in suspend/resume time" (git-fixes).
- libata: add ATA_HORKAGE_NOLPM for Pioneer BDR-207M and BDR-205
  (git-fixes).
- mmc: moxart: fix 4-bit bus width and remove 8-bit bus width
  (git-fixes).
- reset: imx7: Fix the iMX8MP PCIe PHY PERST support (git-fixes).
- ASoC: tas2770: Reinit regcache on reset (git-fixes).
- serial: tegra-tcu: Use uart_xmit_advance(), fixes icount.tx
  accounting (git-fixes).
- serial: tegra: Use uart_xmit_advance(), fixes icount.tx
  accounting (git-fixes).
- serial: Create uart_xmit_advance() (git-fixes).
- can: gs_usb: gs_can_open(): fix race dev->can.state condition
  (git-fixes).
- ALSA: hda/realtek: Add quirk for ASUS GA503R laptop (git-fixes).
- ALSA: hda/realtek: Add pincfg for ASUS G533Z HP jack
  (git-fixes).
- ALSA: hda/realtek: Add pincfg for ASUS G513 HP jack (git-fixes).
- ALSA: hda/realtek: Enable 4-speaker output Dell Precision 5530
  laptop (git-fixes).
- ALSA: hda/realtek: Add quirk for Huawei WRT-WX9 (git-fixes).
- ALSA: hda: add Intel 5 Series / 3400 PCI DID (git-fixes).
- drm/rockchip: Fix return type of cdn_dp_connector_mode_valid
  (git-fixes).
- drm/amd/display: Limit user regamma to a valid value
  (git-fixes).
- drm/amdgpu: use dirty framebuffer helper (git-fixes).
- ASoC: nau8824: Fix semaphore unbalance at error paths
  (git-fixes).
- ALSA: hda/tegra: Align BDL entry to 4KB boundary (git-fixes).
- ALSA: hda/sigmatel: Fix unused variable warning for beep power
  change (git-fixes).
- ALSA: hda/sigmatel: Keep power up while beep is enabled
  (git-fixes).
- regulator: pfuze100: Fix the global-out-of-bounds access in
  pfuze100_regulator_probe() (git-fixes).
- net: usb: qmi_wwan: add Quectel RM520N (git-fixes).
- commit e7744dc
* Tue Oct  4 2022 bp@suse.de
- blacklist.conf: 00da0cb385d0 Documentation/ABI: Mention retbleed vulnerability info file for sysfs
- commit 24c89c9
* Tue Oct  4 2022 oneukum@suse.com
- USB: serial: option: add Quectel RM520N (git-fixes).
- commit e500762
* Tue Oct  4 2022 oneukum@suse.com
- USB: serial: option: add Quectel BG95 0x0203 composition
  (git-fixes).
- commit 75be355
* Tue Oct  4 2022 tzimmermann@suse.de
- Revert "drivers/video/backlight/platform_lcd.c: add support for (bsc#1152489)
- commit b42e64a
* Tue Oct  4 2022 tzimmermann@suse.de
- parisc/sticon: fix reverse colors (bsc#1152489)
  Backporting notes:
  * context changes
- commit 206cd49
* Tue Oct  4 2022 tzimmermann@suse.de
- parisc: parisc-agp requires SBA IOMMU driver (bsc#1152489)
- commit f67e434
* Tue Oct  4 2022 tiwai@suse.de
- char: pcmcia: synclink_cs: Fix use-after-free in mgslpc_ops
  (CVE-2022-41848 bsc#1203987).
- commit c6f643b
* Tue Oct  4 2022 tiwai@suse.de
- fbdev: smscufx: Fix use-after-free in ufx_ops_open()
  (CVE-2022-41849 bsc#1203992).
- commit 1b1c9cc
* Tue Oct  4 2022 oneukum@suse.com
- Input: snvs_pwrkey - fix SNVS_HPVIDR1 register address
  (git-fixes).
- commit d6b115e
* Tue Oct  4 2022 oneukum@suse.com
- Input: melfas_mip4 - fix return value check in mip4_probe()
  (git-fixes).
- commit 6863cfd
* Tue Oct  4 2022 oneukum@suse.com
- blacklist.conf: cleanup that breaks kABI
- commit 9b1761f
* Tue Oct  4 2022 oneukum@suse.com
- USB: core: Fix RST error in hub.c (git-fixes).
- commit 0a4bc80
* Tue Oct  4 2022 oneukum@suse.com
- struct ehci_hcd: hide new member (git-fixes).
- commit 47be3bf
* Tue Oct  4 2022 oneukum@suse.com
- usb: ehci: handshake CMD_RUN instead of STS_HALT (git-fixes).
- commit 6d316e7
* Tue Oct  4 2022 oneukum@suse.com
- struct otg_fsm: hide new boolean member in gap (git-fixes).
- commit f6f0e1f
* Tue Oct  4 2022 oneukum@suse.com
- usb: otg-fsm: Fix hrtimer list corruption (git-fixes).
- commit 659ffb3
* Tue Oct  4 2022 oneukum@suse.com
- blacklist.conf: breaks kABI for an issue relevant only in a minor HC
- commit 803fd47
* Tue Oct  4 2022 oneukum@suse.com
- usbnet: Fix memory leak in usbnet_disconnect() (git-fixes).
- commit cd54e08
* Mon Oct  3 2022 msuchanek@suse.de
- bpf: Compile out btf_parse_module() if module BTF is not enabled
  (git-fixes).
- commit 1eec519
* Mon Oct  3 2022 ohering@suse.de
- net: mana: Add rmb after checking owner bits (git-fixes).
- commit 78526f5
* Mon Oct  3 2022 iivanov@suse.de
- arm64: dts: rockchip: Remove 'enable-active-low' from rk3399-puma (git-fixes)
- commit 1907554
* Mon Oct  3 2022 iivanov@suse.de
- arm64: dts: rockchip: Set RK3399-Gru PCLK_EDP to 24 MHz (git-fixes)
- commit b65f350
* Mon Oct  3 2022 iivanov@suse.de
- arm64: dts: rockchip: Pull up wlan wake# on Gru-Bob (git-fixes)
- commit bdc6c6e
* Sat Oct  1 2022 ohering@suse.de
- net: mana: Add support of XDP_REDIRECT action (bug#1201310, jsc#PED-529).
- commit a9060b8
* Fri Sep 30 2022 ohering@suse.de
- net: mana: Add the Linux MANA PF driver (bug#1201309, jsc#PED-529).
- commit 25390e7
* Fri Sep 30 2022 dwagner@suse.de
- scsi: lpfc: Update lpfc version to 14.2.0.7 (bsc#1203939).
- scsi: lpfc: Fix various issues reported by tools (bsc#1203939).
- scsi: lpfc: Add reporting capability for Link Degrade Signaling
  (bsc#1203939).
- scsi: lpfc: Rework FDMI attribute registration for unintential
  padding (bsc#1203939).
- scsi: lpfc: Rework lpfc_fdmi_cmd() routine for cleanup and
  consistency (bsc#1203939).
- scsi: lpfc: Rename mp/bmp dma buffers to rq/rsp in lpfc_fdmi_cmd
  (bsc#1203939).
- scsi: lpfc: Update congestion mode logging for Emulex SAN
  Manager application (bsc#1203939).
- scsi: lpfc: Move scsi_host_template outside dynamically
  allocated/freed phba (bsc#1185032 bsc#1203939).
  Dropped:
  patches.suse/lpfc-decouple-port_template-and-vport_template.patch
- scsi: lpfc: Fix multiple NVMe remoteport registration calls
  for the same NPort ID (bsc#1203939).
- scsi: lpfc: Add missing free iocb and nlp kref put for early
  return VMID cases (bsc#1203939).
- scsi: lpfc: Fix mbuf pool resource detected as busy at driver
  unload (bsc#1203939).
- scsi: lpfc: Fix FLOGI ACC with wrong SID in PT2PT topology
  (bsc#1203939).
- scsi: lpfc: Fix prli_fc4_req checks in PRLI handling
  (bsc#1203939).
- scsi: lpfc: Remove unneeded result variable (bsc#1203939).
- scsi: lpfc: Remove the unneeded result variable (bsc#1203939).
- commit 829fcfa
* Fri Sep 30 2022 dwagner@suse.de
- scsi: lpfc: Add missing destroy_workqueue() in error path
  (bsc#1203939).
- scsi: lpfc: Return DID_TRANSPORT_DISRUPTED instead of
  DID_REQUEUE (bsc#1203939).
- commit 26a6fd8
* Fri Sep 30 2022 tiwai@suse.de
- wifi: cfg80211: ensure length byte is present before access
  (CVE-2022-41674 bsc#1203770).
- wifi: cfg80211/mac80211: reject bad MBSSID elements
  (CVE-2022-41674 bsc#1203770).
- wifi: cfg80211: fix u8 overflow in
  cfg80211_update_notlisted_nontrans() (CVE-2022-41674
  bsc#1203770).
- commit a878ee7
* Fri Sep 30 2022 dwagner@suse.de
- scsi: qla2xxx: Remove unused declarations for qla2xxx
  (bsc#1203935).
- scsi: qla2xxx: Drop DID_TARGET_FAILURE use (bsc#1203935).
- scsi: qla2xxx: Update version to 10.02.07.900-k (bsc#1203935).
- scsi: qla2xxx: Add NVMe parameters support in Auxiliary Image
  Status (bsc#1203935).
- scsi: qla2xxx: Add debugfs create/delete helpers (bsc#1203935).
- scsi: qla2xxx: Fix response queue handler reading stale packets
  (bsc#1203935).
- scsi: qla2xxx: Revert "scsi: qla2xxx: Fix response queue
  handler reading stale packets" (bsc#1203935).
- scsi: qla2xxx: Log message "skipping scsi_scan_host()" as
  informational (bsc#1203935).
- scsi: qla2xxx: Avoid flush_scheduled_work() usage (bsc#1203935).
- scsi: qla2xxx: Always wait for qlt_sess_work_fn() from
  qlt_stop_phase1() (bsc#1203935).
- scsi: qla2xxx: Remove unused qlt_tmr_work() (bsc#1203935).
- scsi: qla2xxx: Remove unused del_sess_list field (bsc#1203935).
- commit 7c106a6
* Fri Sep 30 2022 dwagner@suse.de
- scsi: qla2xxx: Fix memory leak in __qlt_24xx_handle_abts()
  (bsc#1203935).
- scsi: qla2xxx: Disable ATIO interrupt coalesce for quad port
  ISP27XX (bsc#1203935).
- commit 80690be
* Thu Sep 29 2022 mkoutny@suse.com
- psi: Fix uaf issue when psi trigger is destroyed while being
  polled (bsc#1203909).
- commit fd0515b
* Thu Sep 29 2022 mkoutny@suse.com
- cgroup: cgroup_get_from_id() must check the looked-up kn is
  a directory (bsc#1203906).
- Refresh patches.suse/scsi-cgroup-Add-cgroup_get_from_id.patch.
- commit f918358
* Tue Sep 27 2022 vbabka@suse.cz
- mm/mremap: hold the rmap lock in write mode when moving page
  table entries (CVE-2022-41222 bsc#1203622).
- commit 07909f0
* Tue Sep 27 2022 oneukum@suse.com
- USB: core: Prevent nested device-reset calls (git-fixes).
- commit 5a61004
* Tue Sep 27 2022 oneukum@suse.com
- blacklist.conf: irrelevant in our kernel configurations
- commit 0547ac8
* Tue Sep 27 2022 oneukum@suse.com
- usb: dwc3: disable USB core PHY management (git-fixes).
- commit 5595967
* Tue Sep 27 2022 lhenriques@suse.de
- blacklist.conf: black list commit 2fdbb8dd0155
  Add commit 2fdbb8dd0155 ("fuse: fix deadlock between atomic O_TRUNC and page
  invalidation") to the blacklist.  It's a real bug, but it's been there for a
  long time, it seems to have low impact and the backport risks are high.
- commit e45fa09
* Tue Sep 27 2022 oneukum@suse.com
- usb.h: struct usb_device: hide new member (git-fixes).
- commit 345c930
* Tue Sep 27 2022 tiwai@suse.de
- ALSA: pcm: oss: Fix race at SNDCTL_DSP_SYNC (CVE-2022-3303
  bsc#1203769).
- commit aa1dc74
* Tue Sep 27 2022 neilb@suse.de
- Revert "SUNRPC: Remove unreachable error condition" (git-fixes).
- md: call __md_stop_writes in md_stop (git-fixes).
- SUNRPC: RPC level errors should set task->tk_rpc_status
  (git-fixes).
- SUNRPC: Reinitialise the backchannel request buffers before
  reuse (git-fixes).
- NFSv4.1: RECLAIM_COMPLETE must handle EACCES (git-fixes).
- NFSv4: Fix races in the legacy idmapper upcall (git-fixes).
- sunrpc: fix expiry of auth creds (git-fixes).
- NFSv4.1: Handle NFS4ERR_DELAY replies to OP_SEQUENCE correctly
  (git-fixes).
- NFSv4.1: Don't decrease the value of seq_nr_highest_sent
  (git-fixes).
- md-raid10: fix KASAN warning (git-fixes).
- SUNRPC: Don't leak sockets in xs_local_connect() (git-fixes).
- SUNRPC: Don't call connect() more than once on a TCP socket
  (git-fixes).
- NFSD: Fix offset type in I/O trace points (git-fixes).
- SUNRPC: Partial revert of commit 6f9f17287e78 (git-fixes).
- sunrpc: Fix misplaced barrier in call_decode (git-fixes).
- xprtrdma: Fix cwnd update ordering (git-fixes).
- svcrdma: Hold private mutex while invoking rdma_accept()
  (git-fixes).
- commit 3437f45
* Mon Sep 26 2022 bp@suse.de
- blacklist.conf: 441947019138 Documentation: Add documentation for Processor MMIO Stale Data
- commit 7da5a85
* Mon Sep 26 2022 osalvador@suse.de
- Rename colliding patches before the next origin/cve/linux-5.3 -> SLE15-SP3 merge
- commit 2078b95
* Mon Sep 26 2022 nstange@suse.de
- padata: make padata_free_shell() to respect pd's ->refcnt
  (bsc#1202638).
- commit 2827da5
* Mon Sep 26 2022 nstange@suse.de
- padata: introduce internal padata_get/put_pd() helpers
  (bsc#1202638).
- commit 8fd1f6c
* Mon Sep 26 2022 msuchanek@suse.de
- ima: force signature verification when CONFIG_KEXEC_SIG is
  configured (bsc#1203737).
- kexec: do not verify the signature without the lockdown or
  mandatory signature (bsc#1203737).
- commit 6aaef78
* Fri Sep 23 2022 msuchanek@suse.de
- kABI: x86: kexec: hide new include from genksyms (bsc#1196444).
- commit f16766a
* Fri Sep 23 2022 msuchanek@suse.de
- kexec, KEYS, s390: Make use of built-in and secondary keyring
  for signature verification (bsc#1196444).
- arm64: kexec_file: use more system keyrings to verify kernel
  image signature (bsc#1196444).
- kexec, KEYS: make the code in bzImage64_verify_sig generic
  (bsc#1196444).
- kexec: clean up arch_kexec_kernel_verify_sig (bsc#1196444).
- kexec: drop weak attribute from functions (bsc#1196444).
- kexec_file: drop weak attribute from functions (bsc#1196444).
- x86/kexec: fix memory leak of elf header buffer (bsc#1196444).
- kexec_file: drop weak attribute from
  arch_kexec_apply_relocations[_add] (bsc#1196444).
- commit 57f8f15
* Thu Sep 22 2022 lduncan@suse.com
- scsi: mpt3sas: Fix use-after-free warning (git-fixes).
- scsi: sg: Allow waiting for commands to complete on removed
  device (git-fixes).
- scsi: smartpqi: Fix DMA direction for RAID requests (git-fixes).
- scsi: core: Fix bad pointer dereference when ehandler kthread
  is invalid (git-fixes).
- commit 3a8854b
* Thu Sep 22 2022 lduncan@suse.com
- blacklist.conf: add git-fixes not needed to list
- commit 0514bb0
* Thu Sep 22 2022 tiwai@suse.de
- gpio: mpc8xxx: Fix support for IRQ_TYPE_LEVEL_LOW flow_type
  in mpc85xx (git-fixes).
- pinctrl: rockchip: Enhance support for IRQ_TYPE_EDGE_BOTH
  (git-fixes).
- drm/meson: Fix OSD1 RGB to YCbCr coefficient (git-fixes).
- drm/meson: Correct OSD1 global alpha value (git-fixes).
- of/device: Fix up of_dma_configure_id() stub (git-fixes).
- of: fdt: fix off-by-one error in unflatten_dt_nodes()
  (git-fixes).
- efi: capsule-loader: Fix use-after-free in efi_capsule_write
  (git-fixes).
- soc: brcmstb: pm-arm: Fix refcount leak and __iomem leak bugs
  (git-fixes).
- Input: iforce - add support for Boeder Force Feedback Wheel
  (git-fixes).
- vt: Clear selection before changing the font (git-fixes).
- drm/i915/glk: ECS Liva Q2 needs GLK HDMI port timing quirk
  (git-fixes).
- usb: storage: Add ASUS <0x0b05:0x1932> to IGNORE_UAS
  (git-fixes).
- USB: serial: cp210x: add Decagon UCA device id (git-fixes).
- USB: serial: option: add support for Cinterion MV32-WA/WB
  RmNet mode (git-fixes).
- USB: serial: ftdi_sio: add Omron CS1W-CIF31 device id
  (git-fixes).
- USB: serial: option: add Quectel EM060K modem (git-fixes).
- USB: serial: option: add support for OPPO R11 diag port
  (git-fixes).
- USB: cdc-acm: Add Icom PMR F3400 support (0c26:0020)
  (git-fixes).
- usb-storage: Add ignore-residue quirk for NXP PN7462AU
  (git-fixes).
- platform/x86: acer-wmi: Acer Aspire One AOD270/Packard Bell
  Dot keymap fixes (git-fixes).
- ieee802154: cc2520: add rc code in cc2520_tx() (git-fixes).
- hid: intel-ish-hid: ishtp: Fix ishtp client sending disordered
  message (git-fixes).
- HID: ishtp-hid-clientHID: ishtp-hid-client: Fix comment typo
  (git-fixes).
- fbdev: chipsfb: Add missing pci_disable_device() in
  chipsfb_pci_init() (git-fixes).
- fbdev: fb_pm2fb: Avoid potential divide by zero error
  (git-fixes).
- drm/amdgpu: mmVM_L2_CNTL3 register not initialized correctly
  (git-fixes).
- drm/radeon: add a force flush to delay work when radeon
  (git-fixes).
- drm/amdgpu: Check num_gfx_rings for gfx v9_0 rb setup
  (git-fixes).
- drm/gem: Fix GEM handle release errors (git-fixes).
- vt: selection, introduce vc_is_sel (git-fixes).
- commit 41cd9fa
* Thu Sep 22 2022 tiwai@suse.de
- blacklist.conf: Remove vt patch entry that is needed by other fix
- commit d86dd83
* Thu Sep 22 2022 tiwai@suse.de
- Revert "ALSA: usb-audio: Split endpoint setups for hw_params
  and prepare" (git-fixes).
- ALSA: hda/realtek: Re-arrange quirk table entries (git-fixes).
- ALSA: emu10k1: Fix out of bounds access in
  snd_emu10k1_pcm_channel_alloc() (git-fixes).
- ALSA: usb-audio: Fix an out-of-bounds bug in
  __snd_usb_parse_audio_interface() (git-fixes).
- ALSA: aloop: Fix random zeros in capture data when using
  jiffies timer (git-fixes).
- drm/msm/rd: Fix FIFO-full deadlock (git-fixes).
- ALSA: seq: Fix data-race at module auto-loading (git-fixes).
- ALSA: seq: oss: Fix data-race for max_midi_devs access
  (git-fixes).
- commit c844286
* Wed Sep 21 2022 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit 8fc0f8a
* Wed Sep 21 2022 tiwai@suse.de
- media: dvb-core: Fix UAF due to refcount races at releasing
  (CVE-2022-41218 bsc#1202960).
- commit 260d985
* Tue Sep 20 2022 bp@suse.de
- blacklist.conf: e9b6013a7ce3 x86/speculation: Update link to AMD speculation whitepaper
- commit 698f0eb
* Tue Sep 20 2022 denis.kirjanov@suse.com
- Refresh
  patches.suse/netfilter-nf_conntrack_irc-Fix-forged-IP-logic.patch.
- commit a7baae2
* Tue Sep 20 2022 oneukum@suse.com
- Delete
  patches.suse/net-usb-ax88179_178a-write-mac-to-hardware-in-get_ma.patch.
  (bsc#1203313)
- commit 95f983b
* Tue Sep 20 2022 bp@suse.de
- blacklist.conf: ad2c302bc604 EDAC/sifive: Fix non-kernel-doc comment
- commit de5ca80
* Tue Sep 20 2022 tiwai@suse.de
- media: em28xx: initialize refcount before kref_get
  (CVE-2022-3239 bsc#1203552).
- commit b9d53ba
* Tue Sep 20 2022 msuchanek@suse.de
- powerpc/memhotplug: Make lmb size 64bit (bsc#1203424
  ltc#199544).
- powerpc/drmem: Make lmb_size 64 bit (bsc#1203424 ltc#199544).
- commit 7105c05
* Tue Sep 20 2022 aabdallah@suse.de
- scsi: smartpqi: Shorten drive visibility after removal
  (bsc#1200622).
  Delete no longer needed SUSE-specific patch that adds tunable
  parameters for smartpqi reset.
  Deleted:
  patches.suse/scsi-smartpqi-create-module-parameters-for-LUN-reset.patch.
- commit 46fd862
* Tue Sep 20 2022 ailiop@suse.com
- squashfs: fix divide error in calculate_skip() (git-fixes).
- commit 8eb4b9e
* Tue Sep 20 2022 iivanov@suse.de
- arm64: dts: allwinner: a64-sopine-baseboard: change RGMII mode to (bsc#1202341)
- commit 6f5d84d
* Mon Sep 19 2022 colyli@suse.de
- dm verity: set DM_TARGET_IMMUTABLE feature flag (CVE-2022-2503,
  bsc#1202677).
- commit 8fdd2ed
* Mon Sep 19 2022 colyli@suse.de
- dm verity: set DM_TARGET_IMMUTABLE feature flag (CVE-2022-2503,
  bsc#1202677).
- commit cb91fc5
* Mon Sep 19 2022 bp@suse.de
- x86/bugs: Reenable retbleed=off
  While for older kernels the return thunks are statically built in and
  cannot be dynamically patched out, retbleed=off should still work so
  that it can be disabled.
- Refresh
  patches.suse/x86-bugs-Add-AMD-retbleed-boot-parameter.patch.
- Refresh patches.suse/x86-bugs-Enable-STIBP-for-JMP2RET.patch.
- commit 922ee7a
* Mon Sep 19 2022 colyli@suse.de
- md: unlock mddev before reap sync_thread in action_store
  (bsc#1197659).
- commit a26c618
* Fri Sep 16 2022 jgross@suse.com
- xen/xenbus: fix return type in xenbus_file_read() (git-fixes).
- commit b06f37e
* Fri Sep 16 2022 jgross@suse.com
- KVM: nVMX: Let userspace set nVMX MSR to any _host_ supported
  value (git-fixes).
- commit 16015a8
* Fri Sep 16 2022 jgross@suse.com
- KVM: x86: Set error code to segment selector on LLDT/LTR
  non-canonical #GP (git-fixes).
- commit 3f756c3
* Fri Sep 16 2022 jgross@suse.com
- KVM: x86: Mark TSS busy during LTR emulation _after_ all fault
  checks (git-fixes).
- commit 56bf87e
* Fri Sep 16 2022 jgross@suse.com
- x86/xen: Remove undefined behavior in setup_features()
  (git-fixes).
- commit a4e3370
* Fri Sep 16 2022 mkubecek@suse.cz
- Update references:
  - patches.kabi/kabi-return-type-change-of-secure_ipv-46-_port_ephem.patch
  - patches.suse/secure_seq-use-the-64-bits-of-the-siphash-for-port-o.patch
  - patches.suse/tcp-add-small-random-increments-to-the-source-port.patch
  - patches.suse/tcp-drop-the-hash_32-part-from-the-index-calculation.patch
  - patches.suse/tcp-dynamically-allocate-the-perturb-table-used-by-s.patch
  - patches.suse/tcp-increase-source-port-perturb-table-to-2-16.patch
  - patches.suse/tcp-resalt-the-secret-every-10-seconds.patch
  - patches.suse/tcp-use-different-parts-of-the-port_offset-for-index.patch
  (add CVE-2022-32296 bsc#1200288)
- commit 01ba066
* Fri Sep 16 2022 osalvador@suse.de
- Rename colliding patches before the next origin/cve/linux-5.3 -> SLE15-SP3 merge
- commit 3a4afff
* Thu Sep 15 2022 msuchanek@suse.de
- Revert "random: fix crash on multiple early calls to (bsc#1201645)"
  This reverts commit d8168ccb1401eeeed63fa376ac53b5ab983f6d1e.
  This version of the patch causes regression of the problem it's supposed
  to fix, drop it again.
- commit 55b3759
* Thu Sep 15 2022 msuchanek@suse.de
- Refresh sorted patches, move out-of-tree ppc patches to ppc section.
- commit 4fb7690
* Thu Sep 15 2022 msuchanek@suse.de
- ppc64/kdump: Limit kdump base to 512MB (bsc#1203410 ltc#199904).
- commit d91e617
* Wed Sep 14 2022 ailiop@suse.com
- JFS: more checks for invalid superblock (git-fixes).
- commit 9d9aa1f
* Wed Sep 14 2022 ailiop@suse.com
- JFS: fix memleak in jfs_mount (git-fixes).
- commit aaf1dca
* Wed Sep 14 2022 ailiop@suse.com
- jfs: prevent NULL deref in diFree (bsc#1203389).
- commit 55c4d53
* Wed Sep 14 2022 ailiop@suse.com
- jfs: fix GPF in diFree (bsc#1203389).
- commit 48bda4c
* Wed Sep 14 2022 tiwai@suse.de
- mmc: block: fix read single on recovery logic (CVE-2022-20008
  bsc#1199564).
- commit de3f02b
* Tue Sep 13 2022 petr.pavlu@suse.com
- tracing: hold caller_addr to hardirq_{enable,disable}_ip
  (git-fixes).
- commit 16424ba
* Tue Sep 13 2022 petr.pavlu@suse.com
- ftrace: Fix NULL pointer dereference in is_ftrace_trampoline
  when ftrace is dead (git-fixes).
- commit 5b60469
* Tue Sep 13 2022 iivanov@suse.de
- arm64: dts: uniphier: Fix USB interrupts for PXs3 SoC (git-fixes)
- commit 9208a35
* Tue Sep 13 2022 iivanov@suse.de
- crypto: arm64/poly1305 - fix a read out-of-bound (git-fixes)
- commit 790c147
* Tue Sep 13 2022 iivanov@suse.de
- crypto: arm64/gcm - Select AEAD for GHASH_ARM64_CE (git-fixes)
- commit 68c8906
* Tue Sep 13 2022 iivanov@suse.de
- arm64: tegra: Fix SDMMC1 CD on P2888 (git-fixes)
- commit ec68a76
* Tue Sep 13 2022 iivanov@suse.de
- arm64: cpufeature: Allow different PMU versions in ID_DFR0_EL1 (git-fixes)
- commit 3cd5dd6
* Tue Sep 13 2022 iivanov@suse.de
- arm64: mm: fix p?d_leaf() (git-fixes)
- commit a914a52
* Tue Sep 13 2022 iivanov@suse.de
- blacklist.conf: ("arm64: fix clang warning about TRAMP_VALIAS")
- commit 77f79cc
* Tue Sep 13 2022 iivanov@suse.de
- arm64: tegra: Remove non existent Tegra194 reset (git-fixes)
- commit 500bc08
* Tue Sep 13 2022 iivanov@suse.de
- arm64: tlb: fix the TTL value of tlb_get_level (git-fixes)
- commit 93eea81
* Tue Sep 13 2022 iivanov@suse.de
- arm64: mm: use a 48-bit ID map when possible on 52-bit VA builds (git-fixes)
- commit f1a43b3
* Tue Sep 13 2022 iivanov@suse.de
- arm64: mm: Always update TCR_EL1 from __cpu_set_tcr_t0sz() (git-fixes)
- commit b0eb54a
* Tue Sep 13 2022 iivanov@suse.de
- blacklist.conf: ("arm64: Fix kernel address detection of __is_lm_address()")
- commit 2aab643
* Tue Sep 13 2022 iivanov@suse.de
- arm64: dts: allwinner: H5: NanoPi Neo Plus2: phy-mode rgmii-id (git-fixes)
- commit f8968ca
* Tue Sep 13 2022 iivanov@suse.de
- arm64: dts: allwinner: A64 Sopine: phy-mode rgmii-id (git-fixes)
- commit cfcfe62
* Tue Sep 13 2022 iivanov@suse.de
- arm64/mm: Validate hotplug range before creating linear mapping (git-fixes)
- commit 067e57e
* Tue Sep 13 2022 iivanov@suse.de
- blacklist.conf: ("arm64: Drop unnecessary include from asm/smp.h")
- commit 998d48c
* Mon Sep 12 2022 mkubecek@suse.cz
- netfilter: nf_tables: do not allow CHAIN_ID to refer to another
  table (CVE-2022-2586 bsc#1202095).
  Note: this patch is a backport of a 5.9-rc1 mainline commit which was only
  backported into SLE15-SP3 so that it cannot be added to cve/linux-5.3.
- commit 10f848d
* Mon Sep 12 2022 mkubecek@suse.cz
- dccp: don't duplicate ccid when cloning dccp sock
  (CVE-2020-16119 bsc#1177471).
- commit 7c77568
* Mon Sep 12 2022 mkubecek@suse.cz
- netfilter: nf_tables: do not allow RULE_ID to refer to another
  chain (CVE-2022-2586 bsc#1202095).
- netfilter: nf_tables: do not allow SET_ID to refer to another
  table (CVE-2022-2586 bsc#1202095).
- commit 9335568
* Mon Sep 12 2022 jdelvare@suse.de
- watchdog: wdat_wdt: Set the min and max timeout values properly
  (bsc#1194023).
- commit cc91c04
* Mon Sep 12 2022 tiwai@suse.de
- ALSA: usb-audio: Split endpoint setups for hw_params and prepare
  (git-fixes).
- ALSA: usb-audio: Register card again for iface over
  delayed_register option (git-fixes).
- ALSA: usb-audio: Inform the delayed registration more properly
  (git-fixes).
- ALSA: usb-audio: fix spelling mistakes (git-fixes).
- commit b46a495
* Fri Sep  9 2022 ptesarik@suse.cz
- s390/qeth: cache link_info for ethtool (bsc#1202984 LTC#199607).
- s390/qeth: improve selection of ethtool link modes (bsc#1202984
  LTC#199607).
- s390/qeth: use QUERY OAT for initial link info (bsc#1202984
  LTC#199607).
- s390/qeth: clean up default cases for ethtool link mode
  (bsc#1202984 LTC#199607).
- s390/qeth: set static link info during initialization
  (bsc#1202984 LTC#199607).
- s390/qeth: improve QUERY CARD INFO processing (bsc#1202984
  LTC#199607).
- s390/qeth: tolerate error when querying card info (bsc#1202984
  LTC#199607).
- commit 9031a4b
* Fri Sep  9 2022 tiwai@suse.de
- regulator: core: Clean up on enable failure (git-fixes).
- wifi: iwlegacy: 4965: corrected fix for potential off-by-one
  overflow in il4965_rs_fill_link_cmd() (git-fixes).
- commit e4c4fe1
* Wed Sep  7 2022 oneukum@suse.com
- USB: serial: ch341: fix disabled rx timer on older devices
  (git-fixes).
- commit 85a0dd6
* Wed Sep  7 2022 oneukum@suse.com
- USB: serial: ch341: fix lost character on LCR updates
  (git-fixes).
- commit bf1a320
* Wed Sep  7 2022 oneukum@suse.com
- USB: serial: ch341: name prescaler, divisor registers
  (git-fixes).
- commit 63aa28e
* Tue Sep  6 2022 dwagner@suse.de
- nvme-tcp: fix UAF when detecting digest errors (bsc#1200313
  bsc#1201489).
- commit d4bd81f
* Tue Sep  6 2022 dwagner@suse.de
- nvme-rdma: Handle number of queue changes (bsc#1201865).
- nvme-tcp: Handle number of queue changes (bsc#1201865).
- nvmet: Expose max queues to configfs (bsc#1201865).
- commit cdc0881
* Tue Sep  6 2022 dwagner@suse.de
- nvme-fabrics: parse nvme connect Linux error codes
  (bsc#1201865).
- commit 9e2c1de
* Tue Sep  6 2022 vbabka@suse.cz
- mm: pagewalk: Fix race between unmap and page walker (git-fixes,
  bsc#1203159).
- commit 173564a
* Tue Sep  6 2022 osalvador@suse.de
- Rename colliding patches before the next origin/cve/linux-5.3 -> SLE15-SP3 merge
- commit ed68f11
* Mon Sep  5 2022 vbabka@suse.cz
- mm: Force TLB flush for PFNMAP mappings before unlink_file_vma()
  (CVE-2022-39188, bsc#1203107).
- commit 84aac57
* Mon Sep  5 2022 denis.kirjanov@suse.com
- netfilter: nf_tables: disallow binding to already bound chain
  (bsc#1203117 CVE-2022-39190).
- commit 933f567
* Mon Sep  5 2022 lhenriques@suse.de
- fuse: Remove the control interface for virtio-fs (bsc#1203137).
- fuse: ioctl: translate ENOSYS (bsc#1203136).
- fuse: limit nsec (bsc#1203135).
- commit e82b600
* Mon Sep  5 2022 mkubecek@suse.cz
- netfilter: nf_conntrack_irc: Tighten matching on DCC message
  (CVE-2022-2663 bsc#1202097).
- netfilter: nf_conntrack_irc: Fix forged IP logic (CVE-2022-2663
  bsc#1202097).
- commit a949534
* Mon Sep  5 2022 tiwai@suse.de
- Revert "clk: core: Honor CLK_OPS_PARENT_ENABLE for clk gate ops"
  (git-fixes).
- Revert "usb: gadget: udc-xilinx: replace memcpy with
  memcpy_toio" (git-fixes).
- commit 855ba08
* Mon Sep  5 2022 tiwai@suse.de
- gpio: pca953x: Add mutex_lock for regcache sync in PM
  (git-fixes).
- Input: iforce - wake up after clearing IFORCE_XMIT_RUNNING flag
  (git-fixes).
- Input: rk805-pwrkey - fix module autoloading (git-fixes).
- tty: serial: lpuart: disable flow control while waiting for
  the transmit engine to complete (git-fixes).
- serial: fsl_lpuart: RS485 RTS polariy is inverse (git-fixes).
- staging: rtl8712: fix use after free bugs (git-fixes).
- clk: bcm: rpi: Fix error handling of raspberrypi_fw_get_rate
  (git-fixes).
- clk: core: Fix runtime PM sequence in clk_core_unprepare()
  (git-fixes).
- clk: core: Honor CLK_OPS_PARENT_ENABLE for clk gate ops
  (git-fixes).
- hwmon: (gpio-fan) Fix array out of bounds access (git-fixes).
- drm/msm/dsi: Fix number of regulators for SDM660 (git-fixes).
- drm/msm/dsi: Fix number of regulators for msm8996_dsi_cfg
  (git-fixes).
- drm/msm/dsi: fix the inconsistent indenting (git-fixes).
- drm/i915/reg: Fix spelling mistake "Unsupport" -> "Unsupported"
  (git-fixes).
- driver core: Don't probe devices after bus_type.match() probe
  deferral (git-fixes).
- misc: fastrpc: fix memory corruption on open (git-fixes).
- misc: fastrpc: fix memory corruption on probe (git-fixes).
- iio: adc: mcp3911: use correct formula for AD conversion
  (git-fixes).
- iio: adc: mcp3911: make use of the sign bit (git-fixes).
- usb: gadget: mass_storage: Fix cdrom data transfers on MAC-OS
  (git-fixes).
- usb: dwc2: fix wrong order of phy_power_on and phy_init
  (git-fixes).
- usb: gadget: udc-xilinx: replace memcpy with memcpy_toio
  (git-fixes).
- thunderbolt: Use the actual buffer in tb_async_error()
  (git-fixes).
- usb: typec: altmodes/displayport: correct pin assignment for
  UFP receptacles (git-fixes).
- platform/x86: pmc_atom: Fix SLP_TYPx bitfield mask (git-fixes).
- ieee802154/adf7242: defer destroy_workqueue call (git-fixes).
- Bluetooth: L2CAP: Fix build errors in some archs (git-fixes).
- wifi: cfg80211: debugfs: fix return type in ht40allow_map_read()
  (git-fixes).
- wifi: mac80211: Don't finalize CSA in IBSS mode if state is
  disconnected (git-fixes).
- HID: steam: Prevent NULL pointer dereference in
  steam_{recv,send}_report (git-fixes).
- commit ed7b741
* Mon Sep  5 2022 tiwai@suse.de
- ratelimit: Fix data-races in ___ratelimit() (git-fixes).
- serial: mvebu-uart: uart2 error bits clearing (git-fixes).
- tty: vt: initialize unicode screen buffer (git-fixes).
- tty: serial: Fix refcount leak bug in ucc_uart.c (git-fixes).
- video: fbdev: i740fb: Check the argument of i740_calc_vclk()
  (git-fixes).
- usb: renesas: Fix refcount leak bug (git-fixes).
- usb: host: ohci-ppc-of: Fix refcount leak bug (git-fixes).
- usb: gadget: uvc: call uvc uvcg_warn on completed status
  instead of uvcg_info (git-fixes).
- vboxguest: Do not use devm for irq (git-fixes).
- wifi: mac80211_hwsim: use 32-bit skb cookie (git-fixes).
- wifi: mac80211_hwsim: add back erroneously removed cast
  (git-fixes).
- wifi: mac80211_hwsim: fix race condition in pending packet
  (git-fixes).
- spi: synquacer: Add missing clk_disable_unprepare() (git-fixes).
- spi: spi-rspi: Fix PIO fallback on RZ platforms (git-fixes).
- commit 86912f8
* Mon Sep  5 2022 tiwai@suse.de
- mmc: pxamci: Fix another error handling path in pxamci_probe()
  (git-fixes).
- mtd: rawnand: meson: Fix a potential double free issue
  (git-fixes).
- mtd: st_spi_fsm: Add a clk_disable_unprepare() in .probe()'s
  error path (git-fixes).
- mtd: partitions: Fix refcount leak in parse_redboot_of
  (git-fixes).
- mtd: sm_ftl: Fix deadlock caused by cancel_work_sync in
  sm_release (git-fixes).
- mtd: maps: Fix refcount leak in ap_flash_init (git-fixes).
- mtd: maps: Fix refcount leak in of_flash_probe_versatile
  (git-fixes).
- PCI/ACPI: Guard ARM64-specific mcfg_quirks (git-fixes).
- PCI: Add ACS quirk for Broadcom BCM5750x NICs (git-fixes).
- net: rose: fix netdev reference changes (git-fixes).
- commit b9934d3
* Mon Sep  5 2022 tiwai@suse.de
- i2c: imx: Make sure to unregister adapter on remove()
  (git-fixes).
- mmc: pxamci: Fix an error handling path in pxamci_probe()
  (git-fixes).
- lib/list_debug.c: Detect uninitialized lists (git-fixes).
- mfd: max77620: Fix refcount leak in max77620_initialise_fps
  (git-fixes).
- mfd: t7l66xb: Drop platform disable callback (git-fixes).
- HID: alps: Declare U1_UNICORN_LEGACY support (git-fixes).
- HID: wacom: Don't register pad_input for touch switch
  (git-fixes).
- intel_th: pci: Add Raptor Lake-S CPU support (git-fixes).
- intel_th: pci: Add Raptor Lake-S PCH support (git-fixes).
- intel_th: pci: Add Meteor Lake-P support (git-fixes).
- commit f90560c
* Mon Sep  5 2022 tiwai@suse.de
- drm/amdgpu: remove useless condition in
  amdgpu_job_stop_all_jobs_on_sched() (git-fixes).
- drm/sun4i: dsi: Prevent underflow when computing packet sizes
  (git-fixes).
- drm/meson: Fix refcount bugs in
  meson_vpu_has_available_connectors() (git-fixes).
- drm/meson: Fix overflow implicit truncation warnings
  (git-fixes).
- dmaengine: sprd: Cleanup in .remove() after
  pm_runtime_get_sync() failed (git-fixes).
- HID: wacom: Only report rotation for art pen (git-fixes).
- gadgetfs: ep_io - wait until IRQ finishes (git-fixes).
- drm/amdgpu: Check BO's requested pinning domains against its
  preferred_domains (git-fixes).
- fbcon: Fix boundary checks for fbcon=vc:n1-n2 parameters
  (git-fixes).
- commit 9b0074c
* Mon Sep  5 2022 tiwai@suse.de
- asm-generic: sections: refactor memory_intersects (git-fixes).
- ACPI: processor: Remove freq Qos request for all CPUs
  (git-fixes).
- ata: libata-eh: Add missing command name (git-fixes).
- ALSA: info: Fix llseek return value when using callback
  (git-fixes).
- ASoC: tas2770: Allow mono streams (git-fixes).
- ASoC: SOF: debug: Fix potential buffer overflow by snprintf()
  (git-fixes).
- ASoC: audio-graph-card: Add of_node_put() in fail path
  (git-fixes).
- ASoC: qcom: q6dsp: Fix an off-by-one in q6adm_alloc_copp()
  (git-fixes).
- ASoC: codecs: wcd9335: move gains from SX_TLV to S8_TLV
  (git-fixes).
- ASoC: codecs: msm8916-wcd-digital: move gains from SX_TLV to
  S8_TLV (git-fixes).
- ASoC: codecs: da7210: add check for i2c_add_driver (git-fixes).
- ASoC: mt6797-mt6351: Fix refcount leak in
  mt6797_mt6351_dev_probe (git-fixes).
- clk: qcom: ipq8074: dont disable gcc_sleep_clk_src (git-fixes).
- ACPI: LPSS: Fix missing check in register_device_clock()
  (git-fixes).
- ACPI: PM: save NVS memory for Lenovo G40-45 (git-fixes).
- ACPI: EC: Remove duplicate ThinkPad X1 Carbon 6th entry from
  DMI quirks (git-fixes).
- ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for
  HP machine (git-fixes).
- clk: rockchip: add sclk_mac_lbtest to rk3188_critical_clocks
  (git-fixes).
- commit a8924db
* Mon Sep  5 2022 osalvador@suse.de
- Rename colliding patches before the next origin/cve/linux-5.3 -> SLE15-SP3 merge
- commit f477eb5
* Sun Sep  4 2022 vbabka@suse.cz
- mm/rmap: Fix anon_vma->degree ambiguity leading to double-reuse
  (git-fixes, bsc#1203098).
  kABI: Fix kABI after "mm/rmap: Fix anon_vma->degree ambiguity
  leading to double-reuse" (git-fixes, bsc#1203098).
- commit cfac9ee
* Fri Sep  2 2022 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.2.0.6 patches
  (bsc#1203063).
- scsi: lpfc: Update lpfc version to 14.2.0.6 (bsc#1203063).
- scsi: lpfc: Remove SANDiags related code (bsc#1203063).
- scsi: lpfc: Add warning notification period to CMF_SYNC_WQE
  (bsc#1203063).
- scsi: lpfc: Rework MIB Rx Monitor debug info logic
  (bsc#1203063).
- scsi: lpfc: Fix null ndlp ptr dereference in abnormal exit
  path for GFT_ID (bsc#1203063).
- scsi: lpfc: Fix unsolicited FLOGI receive handling during
  PT2PT discovery (bsc#1203063).
- scsi: lpfc: Check the return value of alloc_workqueue()
  (bsc#1203063).
- commit e207225
* Fri Sep  2 2022 jgross@suse.com
- KVM: nVMX: Snapshot pre-VM-Enter DEBUGCTL for
  !nested_run_pending case (git-fixes).
- commit 17df333
* Fri Sep  2 2022 jgross@suse.com
- blacklist.conf: add dbac14a5a05f, as it would break kabi
- commit 55dfee4
* Fri Sep  2 2022 jgross@suse.com
- KVM: nVMX: Snapshot pre-VM-Enter BNDCFGS for !nested_run_pending
  case (git-fixes).
- commit 1a5a475
* Fri Sep  2 2022 jgross@suse.com
- KVM: x86: accept userspace interrupt only if no event is
  injected (git-fixes).
- commit b61f5d7
* Fri Sep  2 2022 jgross@suse.com
- KVM: VMX: Refuse to load kvm_intel if EPT and NX are disabled
  (git-fixes).
- commit b27e2cd
* Thu Sep  1 2022 mkoutny@suse.com
- blacklist.conf: Add three patches
  44585f7bc0cb psi: fix "defined but not used" warnings when CONFIG_PROC_FS=n
  5102bb1c9f82 psi: Fix "defined but not used" warnings when CONFIG_PROC_FS=n
  ec2444530612 psi: Fix "no previous prototype" warnings when CONFIG_CGROUPS=n
- commit f8fef55
* Thu Sep  1 2022 ptesarik@suse.cz
- s390/mm: do not trigger write fault when vma does not allow
  VM_WRITE (git-fixes).
- s390/crash: fix incorrect number of bytes to copy to user space
  (git-fixes).
- s390/crash: make copy_oldmem_page() return number of bytes
  copied (git-fixes).
- s390/mm: fix 2KB pgtable release race (git-fixes).
- commit 32b8c39
* Thu Sep  1 2022 jslaby@suse.cz
- rpm/kernel-source.spec.in: simplify finding of broken symlinks
  "find -xtype l" will report them, so use that to make the search a bit
  faster (without using shell).
- commit 13bbc51
* Wed Aug 31 2022 msuchanek@suse.de
- mkspec: eliminate @NOSOURCE@ macro
  This should be alsways used with @SOURCES@, just include the content
  there.
- commit 403d89f
* Wed Aug 31 2022 msuchanek@suse.de
- kernel-source: include the kernel signature file
  We assume that the upstream tarball is used for released kernels.
  Then we can also include the signature file and keyring in the
  kernel-source src.rpm.
  Because of mkspec code limitation exclude the signature and keyring from
  binary packages always - mkspec does not parse spec conditionals.
- commit e76c4ca
* Wed Aug 31 2022 msuchanek@suse.de
- kernel-binary: move @NOSOURCE@ to @SOURCES@ as in other packages
- commit 4b42fb2
* Wed Aug 31 2022 msuchanek@suse.de
- dtb: Do not include sources in src.rpm - refer to kernel-source
  Same as other kernel binary packages there is no need to carry duplicate
  sources in dtb packages.
- commit 1bd288c
* Tue Aug 30 2022 dwagner@suse.de
- nvme: fix RCU hole that allowed for endless looping in multipath
  round robin (bsc#1202636).
- commit e7e083b
* Tue Aug 30 2022 denis.kirjanov@suse.com
- af_key: Do not call xfrm_probe_algs in parallel (bsc#1202898
  CVE-2022-3028).
- commit 50479c7
* Tue Aug 30 2022 oneukum@suse.com
- usb: dwc3: gadget: Fix IN endpoint max packet size allocation
  (git-fixes).
- commit 4ad76ff
* Tue Aug 30 2022 msuchanek@suse.de
- Update patches.suse/watchdog-export-lockup_detector_reconfigure.patch (bsc#1202872 ltc#197920).
- commit 52cb092
* Tue Aug 30 2022 oneukum@suse.com
- usb: dwc3: gadget: Store resource index of start cmd
  (git-fixes).
- commit 4fd8e68
* Tue Aug 30 2022 tiwai@suse.de
- Update patch reference for USB gadget fix (CVE-2020-27784 bsc#1202895)
- commit 8033d12
* Tue Aug 30 2022 oneukum@suse.com
- usb: dwc3: gadget: Refactor dwc3_gadget_ep_dequeue (git-fixes).
- Refresh
  patches.suse/usb-dwc3-add-cancelled-reasons-for-dwc3-requests.patch.
- commit 32c5550
* Tue Aug 30 2022 oneukum@suse.com
- usb: dwc3: gadget: Remove unnecessary checks (git-fixes).
- Refresh
  patches.suse/usb-dwc3-add-cancelled-reasons-for-dwc3-requests.patch.
- commit 7db43e6
* Tue Aug 30 2022 oneukum@suse.com
- usb: dwc3: Switch to platform_get_irq_byname_optional()
  (git-fixes).
- commit 73d1e58
* Mon Aug 29 2022 ailiop@suse.com
- xfs: map unwritten blocks in XFS_IOC_{ALLOC,FREE}SP just like
  fallocate (bsc#1194272 CVE-2021-4155).
- commit 049d5e6
* Mon Aug 29 2022 oneukum@suse.com
- usb: gadget: u_audio: fix race condition on endpoint stop
  (git-fixes).
- commit 152ca21
* Mon Aug 29 2022 oneukum@suse.com
- usb: dwc3: ep0: Fix delay status handling (git-fixes).
- commit af1df0f
* Mon Aug 29 2022 oneukum@suse.com
- usbnet: Fix linkwatch use-after-free on disconnect (git-fixes).
- commit 9881846
* Mon Aug 29 2022 shung-hsi.yu@suse.com
- bpf: Don't use tnum_range on array range checking for poke
  descriptors (bsc#1202564 bsc#1202860 CVE-2022-2905).
- commit c59b8fc
* Mon Aug 29 2022 msuchanek@suse.de
- blacklist.conf: Add reverted patch
  d11219ad53dc amdgpu: disable powerpc support for the newer display engine
  c653c591789b drm/amdgpu: Re-enable DCN for 64-bit powerpc
- commit b8f5e97
* Mon Aug 29 2022 petr.pavlu@suse.com
- SUNRPC: Don't dereference xprt->snd_task if it's a cookie
  (git-fixes).
- commit 16c3d44
* Fri Aug 26 2022 tbogendoerfer@suse.de
- vmxnet3: do not reschedule napi for rx processing (bsc#1200431).
- vmxnet3: Implement ethtool's get_channels command (bsc#1200431).
- vmxnet3: Record queue number to incoming packets (bsc#1200431).
- vmxnet3: disable overlay offloads if UPT device does not support
  (bsc#1200431).
- vmxnet3: update to version 7 (bsc#1200431).
- vmxnet3: use ext1 field to indicate encapsulated packet
  (bsc#1200431).
- vmxnet3: limit number of TXDs used for TSO packet (bsc#1200431).
- vmxnet3: add command to set ring buffer sizes (bsc#1200431).
- vmxnet3: add support for out of order rx completion
  (bsc#1200431).
- vmxnet3: add support for large passthrough BAR register
  (bsc#1200431).
- vmxnet3: add support for capability registers (bsc#1200431).
- vmxnet3: prepare for version 7 changes (bsc#1200431).
- net: vmxnet3: fix possible NULL pointer dereference in
  vmxnet3_rq_cleanup() (bsc#1200431).
- net: vmxnet3: fix possible use-after-free bugs in
  vmxnet3_rq_alloc_rx_buf() (bsc#1200431).
- vmxnet3: Remove useless DMA-32 fallback configuration
  (bsc#1200431).
- net: vmxnet3: remove multiple false checks in vmxnet3_ethtool.c
  (bsc#1200431).
- vmxnet3: do not stop tx queues after netif_device_detach()
  (bsc#1200431).
- vmxnet3: switch from 'pci_' to 'dma_' API (bsc#1200431).
- commit b577aa9
* Fri Aug 26 2022 msuchanek@suse.de
- kbuild: do not create built-in objects for external module
  builds (jsc#SLE-24559 bsc#1202756).
- commit 56b8142
* Fri Aug 26 2022 petr.pavlu@suse.com
- tracing/probes: Have kprobes and uprobes use $COMM too
  (git-fixes).
- commit 26bf0d1
* Fri Aug 26 2022 petr.pavlu@suse.com
- spmi: trace: fix stack-out-of-bound access in SPMI tracing
  functions (git-fixes).
- commit 8c340f6
* Fri Aug 26 2022 petr.pavlu@suse.com
- tracing/histograms: Fix memory leak problem (git-fixes).
- commit 07d4ab9
* Fri Aug 26 2022 petr.pavlu@suse.com
- blacklist.conf: tracepoint cleanup for drivers/char/random
- commit f75eb58
* Fri Aug 26 2022 petr.pavlu@suse.com
- tracing/histogram: Fix a potential memory leak for kstrdup()
  (git-fixes).
- commit cce24b0
* Fri Aug 26 2022 lhenriques@suse.de
- ceph: don't truncate file in atomic_open (bsc#1202811).
- ceph: don't leak snap_rwsem in handle_cap_grant (bsc#1202810).
- commit 75744b6
* Fri Aug 26 2022 lhenriques@suse.de
- blacklist.conf: blacklist fea013e020e6
- commit 2fc68a2
* Fri Aug 26 2022 petr.pavlu@suse.com
- tracing: Add ustring operation to filtering string pointers
  (git-fixes).
- commit 3fbf519
* Fri Aug 26 2022 petr.pavlu@suse.com
- cgroup: Trace event cgroup id fields should be u64 (git-fixes).
- commit dade489
* Fri Aug 26 2022 petr.pavlu@suse.com
- blacklist.conf: not-relevant cleanup for drivers/char/random
- commit c90e359
* Fri Aug 26 2022 petr.pavlu@suse.com
- blktrace: fix blk_rq_merge documentation (git-fixes).
- commit c03c0ec
* Fri Aug 26 2022 ohering@suse.de
- hv_netvsc: Load and store the proper (NBL_HASH_INFO) per-packet
  info (bsc#1202701).
- commit 173844d
* Thu Aug 25 2022 tiwai@suse.de
- tpm: fix reference counting for struct tpm_chip (CVE-2022-2977
  bsc#1202672).
- commit b71aab0
* Thu Aug 25 2022 jack@suse.cz
- list: add "list_del_init_careful()" to go with
  "list_empty_careful()" (bsc#1202745).
- commit 71ed084
* Thu Aug 25 2022 osalvador@suse.de
- Rename colliding patches before the next cve/linux-5.3 -> SLE15-SP3 merge
- commit 595e8a4
* Wed Aug 24 2022 jack@suse.cz
- blk-iocost: clamp inuse and skip noops in __propagate_weights()
  (bsc#1202722).
- commit f84d929
* Wed Aug 24 2022 jack@suse.cz
- blk-iocost: rename propagate_active_weights() to
  propagate_weights() (bsc#1202722).
- commit 2724a56
* Wed Aug 24 2022 jack@suse.cz
- blacklist.conf: Blacklist aebf5db91705
- commit 578fbe5
* Wed Aug 24 2022 jack@suse.cz
- blk-iocost: fix operation ordering in iocg_wake_fn()
  (bsc#1202720).
- commit 31b540e
* Wed Aug 24 2022 jack@suse.cz
- loop: Fix missing discard support when using LOOP_CONFIGURE
  (bsc#1202718).
- commit c85296f
* Wed Aug 24 2022 jack@suse.cz
- blk-iocost: fix weight updates of inner active iocgs
  (bsc#1202717).
- commit 06cf027
* Wed Aug 24 2022 jack@suse.cz
- mm: bdi: initialize bdi_min_ratio when bdi is unregistered
  (bsc#1197763).
- commit f7b5cbd
* Wed Aug 24 2022 jack@suse.cz
- jbd2: fix assertion 'jh->b_frozen_data == NULL' failure when
  journal aborted (bsc#1202716).
- commit d741558
* Wed Aug 24 2022 jack@suse.cz
- jbd2: fix outstanding credits assert in
  jbd2_journal_commit_transaction() (bsc#1202715).
- commit 4df2139
* Wed Aug 24 2022 jack@suse.cz
- fs-writeback: writeback_sb_inodes: Recalculate 'wrote' according skipped pages
  (bsc#1200873).
- commit b654d4c
* Wed Aug 24 2022 jack@suse.cz
- ocfs2: fix crash when initialize filecheck kobj fails
  (bsc#1197920).
- commit 137054f
* Wed Aug 24 2022 jack@suse.cz
- ocfs2: mount fails with buffer overflow in strlen (bsc#1197760).
- commit 24a97d8
* Wed Aug 24 2022 jack@suse.cz
- ocfs2: drop acl cache for directories too (bsc#1191667).
- commit d8cc34a
* Wed Aug 24 2022 jack@suse.cz
- reiserfs: fix handling of -EOPNOTSUPP in reiserfs_for_each_xattr
  (bsc#1202714).
- commit 4fc81aa
* Wed Aug 24 2022 jack@suse.cz
- ext4: recover csum seed of tmp_inode after migrating to extents
  (bsc#1202713).
- commit 79e5db2
* Wed Aug 24 2022 jack@suse.cz
- ext4: add reserved GDT blocks check (bsc#1202712).
- commit e96e640
* Wed Aug 24 2022 jack@suse.cz
- ext4: fix bug_on in ext4_writepages (bsc#1200872).
- commit 8d9a89d
* Wed Aug 24 2022 jack@suse.cz
- ext4: fix use-after-free in ext4_rename_dir_prepare
  (bsc#1200871).
- commit c9d1b13
* Wed Aug 24 2022 jack@suse.cz
- ext4: fix warning in ext4_handle_inode_extension (bsc#1202711).
- commit f4c59a1
* Wed Aug 24 2022 jack@suse.cz
- ext4: force overhead calculation if the s_overhead_cluster
  makes no sense (bsc#1200870).
- commit 24d5cfc
* Wed Aug 24 2022 jack@suse.cz
- ext4: fix overhead calculation to account for the reserved
  gdt blocks (bsc#1200869).
- commit 8fa6a02
* Wed Aug 24 2022 jack@suse.cz
- ext4: fix use-after-free in ext4_search_dir (bsc#1202710).
- commit bc9242b
* Wed Aug 24 2022 jack@suse.cz
- ext4: fix symlink file size not match to file content
  (bsc#1200868).
- commit 888bc97
* Wed Aug 24 2022 jack@suse.cz
- ext4: fix error handling in ext4_restore_inline_data()
  (bsc#1197757).
- commit ed0d1f6
* Wed Aug 24 2022 jack@suse.cz
- ext4: don't use the orphan list when migrating an inode
  (bsc#1197756).
- commit 2d21beb
* Wed Aug 24 2022 jack@suse.cz
- ext4: Fix BUG_ON in ext4_bread when write quota data
  (bsc#1197755).
- commit 0551e1a
* Wed Aug 24 2022 jack@suse.cz
- ext4: fix potential infinite loop in ext4_dx_readdir()
  (bsc#1191662).
- commit 26c80a3
* Wed Aug 24 2022 jack@suse.cz
- ext4: fix loff_t overflow in ext4_max_bitmap_size()
  (bsc#1202709).
- commit bb20240
* Wed Aug 24 2022 jack@suse.cz
- ext4: do not set SB_ACTIVE in ext4_orphan_cleanup()
  (bsc#1202708).
- commit 070ad26
* Wed Aug 24 2022 jack@suse.cz
- ext4: fix invalid inode checksum (bsc#1179723).
- commit e670453
* Wed Aug 24 2022 jack@suse.cz
- ext4: fix error handling code in add_new_gdb (bsc#1179722).
- commit 5b945e4
* Wed Aug 24 2022 jack@suse.cz
- blacklist.conf: Blacklist ext2 since we don't even compile it
- commit 8f69ba8
* Wed Aug 24 2022 ailiop@suse.com
- xfs: prevent a UAF when log IO errors race with unmount
  (git-fixes).
- commit f7eb5c7
* Wed Aug 24 2022 ailiop@suse.com
- xfs: use kmem_cache_free() for kmem_cache objects (git-fixes).
- commit f514fcd
* Wed Aug 24 2022 ailiop@suse.com
- xfs: make xfs_rtalloc_query_range input parameters const
  (git-fixes).
- commit 0b84c2b
* Wed Aug 24 2022 ailiop@suse.com
- xfs: only reset incore inode health state flags when reclaiming
  an inode (git-fixes).
- commit a9e17d5
* Wed Aug 24 2022 ailiop@suse.com
- xfs: bunmapi has unnecessary AG lock ordering issues
  (git-fixes).
- commit a76eaaf
* Wed Aug 24 2022 ailiop@suse.com
- xfs: mark a data structure sick if there are cross-referencing
  errors (git-fixes).
- commit b0269a0
* Wed Aug 24 2022 ailiop@suse.com
- xfs: Fix assert failure in xfs_setattr_size() (git-fixes).
- commit 1433b65
* Wed Aug 24 2022 denis.kirjanov@suse.com
- fuse: handle kABI change in struct sock (bsc#1194535
  CVE-2021-4203).
- commit 53bc420
* Wed Aug 24 2022 oneukum@suse.com
- usb: dwc3: qcom: fix missing optional irq warnings.
- commit de0c0d4
* Wed Aug 24 2022 oneukum@suse.com
- usb: dwc3: gadget: Remove FS bInterval_m1 limitation
  (git-fixes).
- commit fff57cf
* Wed Aug 24 2022 denis.kirjanov@suse.com
- af_unix: fix races in sk_peer_pid and sk_peer_cred accesses
  (bsc#1194535 CVE-2021-4203).
- commit 603bd9d
* Tue Aug 23 2022 msuchanek@suse.de
- powerpc/perf: Optimize clearing the pending PMI and remove
  WARN_ON for PMI check in power_pmu_disable (bsc#1156395).
- commit d72c6fd
* Tue Aug 23 2022 msuchanek@suse.de
- powerpc/xive: Fix refcount leak in xive_get_max_prio
  (fate#322438 git-fixess).
- commit 76798e0
* Tue Aug 23 2022 msuchanek@suse.de
- powerpc: Enable execve syscall exit tracepoint (bsc#1065729).
- commit 35df6ef
* Tue Aug 23 2022 msuchanek@suse.de
- powerpc: define get_cycles macro for arch-override
  (bsc#1065729).
- commit 39ee615
* Tue Aug 23 2022 msuchanek@suse.de
- blacklist.conf: Add c26d4c5d4f0d powerpc/kvm: Remove obsolete and unneeded select
- commit b069bcf
* Tue Aug 23 2022 msuchanek@suse.de
- blacklist.conf: Add 235cee162459 KVM: PPC: Tick accounting should defer vtime accounting 'til after IRQ handling
- commit a0b9b11
* Tue Aug 23 2022 mkubecek@suse.cz
- net_sched: cls_route: disallow handle of 0 (bsc#1202393).
- net_sched: cls_route: remove from list when handle is 0
  (CVE-2022-2588 bsc#1202096).
- commit b08a235
* Tue Aug 23 2022 msuchanek@suse.de
- KVM: PPC: Fix vmx/vsx mixup in mmio emulation (bsc#1156395).
- KVM: PPC: Book3S HV: Prevent POWER7/8 TLB flush flushing SLB
  (bsc#1156395).
- KVM: PPC: Book3S HV: Use GLOBAL_TOC for
  kvmppc_h_set_dabr/xdabr() (bsc#1156395).
- commit b08465c
* Tue Aug 23 2022 oneukum@suse.com
- blacklist.conf: duplicate
- commit 23a0769
* Tue Aug 23 2022 oneukum@suse.com
- usb: dwc3: gadget: END_TRANSFER before CLEAR_STALL command
  (git-fixes).
- Refresh
  patches.suse/usb-dwc3-add-cancelled-reasons-for-dwc3-requests.patch.
- commit 86ac68c
* Tue Aug 23 2022 msuchanek@suse.de
- KVM: PPC: Book3S HV: Context tracking exit guest context before
  enabling irqs (bsc#1065729).
- commit b7e4839
* Tue Aug 23 2022 oneukum@suse.com
- blacklist.conf: later reverted in upstream
- commit 31b3f5b
* Tue Aug 23 2022 oneukum@suse.com
- usbnet: smsc95xx: Fix deadlock on runtime resume (git-fixes).
- commit f3043dc
* Tue Aug 23 2022 oneukum@suse.com
- ipheth: fix EOVERFLOW in ipheth_rcvbulk_callback (git-fixes).
- commit 1ba1d86
* Tue Aug 23 2022 dwagner@suse.de
- lightnvm: Remove lightnvm implemenation (bsc#1191881 bsc#1201420
  ZDI-CAN-17325).
- commit 1b534db
* Tue Aug 23 2022 ailiop@suse.com
- xfs: check sb_meta_uuid for dabuf buffer recovery (bsc#1202577).
- commit 47070d3
* Mon Aug 22 2022 jack@suse.cz
- ext4: Fix check for block being out of directory size
  (bsc#1198577 CVE-2022-1184).
- commit e41d129
* Mon Aug 22 2022 jack@suse.cz
- ext4: make sure ext4_append() always allocates new block
  (bsc#1198577 CVE-2022-1184).
- commit 5c3a0a2
* Mon Aug 22 2022 jack@suse.cz
- ext4: check if directory block is within i_size (bsc#1198577
  CVE-2022-1184).
- commit d289dcd
* Fri Aug 19 2022 jwiesner@suse.de
- Refresh
  patches.suse/locking-lockdep-Avoid-potential-access-of-invalid-me.patch.
  Fix builds with CONFIG_LOCKDEP on.
- commit b4f11f2
* Fri Aug 19 2022 ohering@suse.de
- PCI: hv: Only reuse existing IRTE allocation for Multi-MSI
  (bsc#1200845).
- PCI: hv: Fix interrupt mapping for multi-MSI (bsc#1200845).
- PCI: hv: Reuse existing IRTE allocation in compose_msi_msg()
  (bsc#1200845).
- PCI: hv: Fix hv_arch_irq_unmask() for multi-MSI (bsc#1200845).
- PCI: hv: Fix multi-MSI to allow more than one MSI vector
  (bsc#1200845).
- PCI: hv: Make the code arch neutral by adding arch specific
  interfaces (bsc#1200845).
- commit 7ab7313
* Fri Aug 19 2022 jack@suse.cz
- ext4: fix race when reusing xattr blocks (bsc#1198971).
- commit 18b6fb8
* Fri Aug 19 2022 jack@suse.cz
- ext4: unindent codeblock in ext4_xattr_block_set()
  (bsc#1198971).
- commit 948b7e8
* Fri Aug 19 2022 jack@suse.cz
- ext4: remove EA inode entry from mbcache on inode eviction
  (bsc#1198971).
- commit d96ae24
* Fri Aug 19 2022 jack@suse.cz
- mbcache: add functions to delete entry if unused (bsc#1198971).
- commit dc90bf2
* Fri Aug 19 2022 jack@suse.cz
- mbcache: don't reclaim used entries (bsc#1198971).
- commit 9b2430e
* Fri Aug 19 2022 petr.pavlu@suse.com
- net: sock: tracing: Fix sock_exceed_buf_limit not to dereference
  stale pointer (git-fixes).
- commit 267c700
* Fri Aug 19 2022 petr.pavlu@suse.com
- ARM: 9077/1: PLT: Move struct plt_entries definition to header
  (git-fixes).
- commit ece08bc
* Fri Aug 19 2022 petr.pavlu@suse.com
- ARM: 9078/1: Add warn suppress parameter to
  arm_gen_branch_link() (git-fixes).
- commit 3398bca
* Fri Aug 19 2022 petr.pavlu@suse.com
- ARM: 9098/1: ftrace: MODULE_PLT: Fix build problem without
  DYNAMIC_FTRACE (git-fixes).
- commit 1d2e217
* Fri Aug 19 2022 petr.pavlu@suse.com
- ARM: 9079/1: ftrace: Add MODULE_PLTS support (git-fixes).
- commit 83b5d04
* Fri Aug 19 2022 petr.pavlu@suse.com
- blacklist.conf: rework and optimization ftrace commits, not bug fixes
- commit e11832c
* Thu Aug 18 2022 msuchanek@suse.de
- Update config files.
- commit 7f7a8ef
* Thu Aug 18 2022 msuchanek@suse.de
- Update config files (bsc#1201361 bsc#1192968 https://github.com/rear/rear/issues/2554).
  ppc64: NVRAM=y
- commit 5e8bf01
* Thu Aug 18 2022 mbenes@suse.cz
- Refresh
  patches.suse/x86-speculation-Add-RSB-VM-Exit-protections.patch.
- Updated
  patches.suse/x86-speculation-change-fill_return_buffer-to-work-with-objtool.patch.
  Add missing objtool annotations from upstream commits and update the latter
  patch to fix bsc#1202396.
- commit 8f03705
* Thu Aug 18 2022 mbenes@suse.cz
- objtool: Add support for intra-function calls (bsc#1202396).
- commit eabf007
* Thu Aug 18 2022 mbenes@suse.cz
- objtool: Remove INSN_STACK (bsc#1202396).
- commit c48377d
* Thu Aug 18 2022 mbenes@suse.cz
- objtool: Make handle_insn_ops() unconditional (bsc#1202396).
- commit ef33ad6
* Thu Aug 18 2022 mbenes@suse.cz
- objtool: Rework allocating stack_ops on decode (bsc#1202396).
- commit cd6e886
* Thu Aug 18 2022 mbenes@suse.cz
- objtool: Support multiple stack_op per instruction
  (bsc#1202396).
- Refresh
  patches.suse/objtool-allow-no-op-cfi-ops-in-alternatives.patch.
- Refresh
  patches.suse/objtool-fix-cfi-insn_state-propagation.patch.
- Refresh patches.suse/objtool-fix-orc-vs-alternatives.patch.
- Refresh patches.suse/objtool-rename-struct-cfi_state.patch.
- commit 5c735b5
* Thu Aug 18 2022 ptesarik@suse.cz
- s390/ptrace: pass invalid syscall numbers to tracing
  (bsc#1192594 LTC#197522).
- commit ad9e50e
* Thu Aug 18 2022 ykaukab@suse.de
- lib: bitmap: provide devm_bitmap_alloc() and
  devm_bitmap_zalloc() (git-fixes).
- commit 2469dd3
* Wed Aug 17 2022 ykaukab@suse.de
- firmware: tegra: bpmp: Do only aligned access to IPC memory area
  (git-fixes).
- commit 99eaa98
* Wed Aug 17 2022 petr.pavlu@suse.com
- module: Ignore _GLOBAL_OFFSET_TABLE_ when warning for undefined
  symbols (git-fixes).
- commit 35509ca
* Wed Aug 17 2022 petr.pavlu@suse.com
- blacklist.conf: unneeded and kABI-breaking module loader commits
- commit 3ccf763
* Tue Aug 16 2022 mkoutny@suse.com
- mm: memcontrol: fix potential oom_lock recursion deadlock
  (bsc#1202447).
- commit bc21375
* Tue Aug 16 2022 mkoutny@suse.com
- blacklist.conf: Add 7b3c36fc4c23 ptrace: fix task_join_group_stop() for the case when current is traced
- commit 572eadd
* Tue Aug 16 2022 jslaby@suse.cz
- rpm/kernel-binary.spec.in: move vdso to a separate package (bsc#1202385)
  We do the move only on 15.5+.
- commit 9c7ade3
* Tue Aug 16 2022 jslaby@suse.cz
- rpm/kernel-binary.spec.in: simplify find for usrmerged
  The type test and print line are the same for both cases. The usrmerged
  case only ignores more, so refactor it to make it more obvious.
- commit 583c9be
* Mon Aug 15 2022 ykaukab@suse.de
- net: enetc: Use pci_release_region() to release some resources
  (git-fixes).
- PCI: qcom: Fix pipe clock imbalance (git-fixes).
- net: cpsw: add missing of_node_put() in cpsw_probe_dt()
  (git-fixes).
- net: dsa: felix: suppress -EPROBE_DEFER errors (git-fixes).
- net: enetc: report software timestamping via SO_TIMESTAMPING
  (git-fixes).
- net:enetc: allocate CBD ring data memory using DMA coherent
  methods (git-fixes).
- arm64: signal: nofpsimd: Do not allocate fp/simd context when
  not available (git-fixes).
- dpaa2-eth: unregister the netdev before disconnecting from
  the PHY (git-fixes).
- net: cpsw: Properly initialise struct page_pool_params
  (git-fixes).
- pinctrl/rockchip: fix gpio device creation (git-fixes).
- spi: Fix incorrect cs_setup delay handling (git-fixes).
- random: fix crash on multiple early calls to
  add_bootloader_randomness() (git-fixes).
- tee: optee: Fix incorrect page free bug (git-fixes).
- ipmi: ssif: initialize ssif_info->client early (git-fixes).
- serial: tegra: Change lower tolerance baud rate limit for
  tegra20 and tegra30 (git-fixes).
- net: mscc: ocelot: correctly report the timestamping RX filters
  in ethtool (git-fixes).
- net: mscc: ocelot: don't downgrade timestamping RX filters in
  SIOCSHWTSTAMP (git-fixes).
- net: ethernet: ti: cpsw_ale: Fix access to un-initialized memory
  (git-fixes).
- coresight: cti: Correct the parameter for pm_runtime_put
  (git-fixes).
- net: enetc: unmap DMA in enetc_send_cmd() (git-fixes).
- enetc: Fix endianness issues for enetc_qos (git-fixes).
- commit b9e0ed7
* Mon Aug 15 2022 jwiesner@suse.de
- selftests: futex: Use variable MAKE instead of make (git-fixes).
- commit 7d8ce88
* Mon Aug 15 2022 jwiesner@suse.de
- locking/lockdep: Avoid potential access of invalid memory in
  lock_class (git-fixes).
- commit 6e699d5
* Mon Aug 15 2022 denis.kirjanov@suse.com
- Update
  patches.suse/can-ems_usb-ems_usb_start_xmit-fix-double-dev_kfree_.patch
  (CVE-2022-28390 bsc#1198031).
- commit 9c17688
* Mon Aug 15 2022 denis.kirjanov@suse.com
- Update
  patches.suse/can-mcba_usb-mcba_usb_start_xmit-fix-double-dev_kfre.patch
  (CVE-2022-28389 bsc#1198033).
- commit 1983a37
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: ethernet: ezchip: fix error handling (git-fixes).
- commit 5d377ed
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: ethernet: ezchip: remove redundant check (git-fixes).
- commit cb426d4
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: ethernet: ezchip: fix UAF in nps_enet_remove (git-fixes).
- commit ed56f34
* Mon Aug 15 2022 jwiesner@suse.de
- blacklist.conf: v5.16-rc2-1-gd257cc8cb8d5 introduces a rwsem regression
- commit edee2a5
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: ethernet: aeroflex: fix UAF in greth_of_remove (git-fixes).
- commit f83edca
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: bcmgenet: Add mdio-bcm-unimac soft dependency (git-fixes).
- commit d5e4943
* Mon Aug 15 2022 jwiesner@suse.de
- perf bench: Share some global variables to fix build with gcc 10
  (git-fixes).
- commit a397021
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: moxa: Use devm_platform_get_and_ioremap_resource()
  (git-fixes).
- commit d13dcd2
* Mon Aug 15 2022 denis.kirjanov@suse.com
- ehea: fix error return code in ehea_restart_qps() (git-fixes).
- commit f14e06e
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: pch_gbe: Propagate error from devm_gpio_request_one()
  (git-fixes).
- commit 51f37b6
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: ethernet: fix potential use-after-free in ec_bhf_remove
  (git-fixes).
- commit 7175e70
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: fec_ptp: add clock rate zero check (git-fixes).
- commit 16317aa
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: stmmac: disable clocks in stmmac_remove_config_dt()
  (git-fixes).
- commit 1bbbc9a
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: stmmac: dwmac1000: Fix extended MAC address registers
  definition (git-fixes).
- commit c6d0ccf
* Mon Aug 15 2022 denis.kirjanov@suse.com
- ice: report supported and advertised autoneg using PHY
  capabilities (git-fixes).
- commit 2243129
* Mon Aug 15 2022 denis.kirjanov@suse.com
- ixgbevf: add correct exception tracing for XDP (git-fixes).
- commit b4db988
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net/mlx5e: Check for needed capability for cvlan matching
  (git-fixes).
- commit e46f646
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: hns: Fix kernel-doc (git-fixes).
- commit 80f2716
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: dsa: mt7530: fix VLAN traffic leaks (git-fixes).
- commit 99b3a0b
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: lantiq: fix memory corruption in RX ring (git-fixes).
- commit 55781d8
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: fec: fix the potential memory leak in fec_enet_init()
  (git-fixes).
- commit 43431b4
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: netcp: Fix an error message (git-fixes).
- commit 0432102
* Mon Aug 15 2022 denis.kirjanov@suse.com
- qlcnic: Add null check after calling netdev_alloc_skb
  (git-fixes).
- commit 9764dcc
* Mon Aug 15 2022 denis.kirjanov@suse.com
- ethernet: sun: niu: fix missing checks of niu_pci_eeprom_read()
  (git-fixes).
- commit ca3de9d
* Mon Aug 15 2022 denis.kirjanov@suse.com
- Revert "niu: fix missing checks of niu_pci_eeprom_read"
  (git-fixes).
- commit c1a547c
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: stmicro: handle clk_prepare() failure during init
  (git-fixes).
- commit 1249947
* Mon Aug 15 2022 denis.kirjanov@suse.com
- Revert "net: stmicro: fix a missing check of clk_prepare"
  (git-fixes).
- commit c8483b4
* Mon Aug 15 2022 denis.kirjanov@suse.com
- Revert "net: fujitsu: fix a potential NULL pointer dereference"
  (git-fixes).
- commit 35e4846
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net:emac/emac-mac: Fix a use after free in emac_mac_tx_buf_send
  (git-fixes).
- commit 11b1f00
* Mon Aug 15 2022 denis.kirjanov@suse.com
- net: davinci_emac: Fix incorrect masking of tx and rx error
  channel (git-fixes).
- commit cef2ac2
* Mon Aug 15 2022 denis.kirjanov@suse.com
- blacklist.conf: update blacklist
- commit e0f7a96
* Sun Aug 14 2022 jroedel@suse.de
- blacklist.conf: Add 59b18a1e65b7 x86/msi: Fix msi message data shadow struct
- commit b422277
* Sun Aug 14 2022 tiwai@suse.de
- ALSA: hda/realtek: Add new alc285-hp-amp-init model (git-fixes).
- commit 090b87e
* Sun Aug 14 2022 tiwai@suse.de
- ALSA: hda/realtek: Fix deadlock by COEF mutex (git-fixes).
- ALSA: hda: realtek: Fix race at concurrent COEF updates
  (git-fixes).
- commit 5b77923
* Sun Aug 14 2022 tiwai@suse.de
- ALSA: hda/realtek: Add quirk for Clevo NV45PZ (git-fixes).
- ALSA: hda/realtek: Add quirk for Clevo L140PU (git-fixes).
- ALSA: hda/realtek: Add quirk for Clevo NS50PU (git-fixes).
- ALSA: hda/realtek: Add quirk for TongFang devices with pop noise
  (git-fixes).
- ALSA: hda/realtek: Add quirk for the Framework Laptop
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Clevo NP70PNP (git-fixes).
- ALSA: hda/realtek: Add quirk for Clevo NP50PNJ (git-fixes).
- ALSA: hda/realtek: Add quirk for Clevo NP70PNJ (git-fixes).
- commit 8286b1b
* Sun Aug 14 2022 tiwai@suse.de
- ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for
  HP machines (git-fixes).
- Refresh
  patches.suse/ALSA-hda-realtek-Add-quirk-for-HP-Dev-One.patch.
- Refresh
  patches.suse/ALSA-hda-realtek-fix-mute-micmute-LEDs-for-HP-machin.patch.
- commit 3b1083d
* Sun Aug 14 2022 tiwai@suse.de
- NTB: ntb_tool: uninitialized heap data in tool_fn_write()
  (git-fixes).
- ALSA: bcd2000: Fix a UAF bug on the error path of probing
  (git-fixes).
- commit e17531e
* Sat Aug 13 2022 tiwai@suse.de
- ALSA: hda/realtek: fix mute/micmute LEDs for HP machines
  (git-fixes).
- commit 6646862
* Sat Aug 13 2022 tiwai@suse.de
- ALSA: hda/realtek: Add quirk for HP Spectre x360 15-eb0xxx
  (git-fixes).
- ALSA: hda/realtek: Add quirk for HP Dev One (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook
  (git-fixes).
- ALSA: hda/realtek: Fix LED on HP ProBook 435 G7 (git-fixes).
- commit 4dbfddf
* Sat Aug 13 2022 tiwai@suse.de
- ALSA: hda/realtek: Add quirk for Dell Latitude 7520 (git-fixes).
- commit 99b2a82
* Sat Aug 13 2022 tiwai@suse.de
- ALSA: hda/realtek: Add a quirk for HP OMEN 15 (8786) mute LED
  (git-fixes).
- ALSA: hda/realtek: Fix headset mic for Acer SF313-51
  (git-fixes).
- ALSA: hda/realtek: Add mute LED quirk for HP Omen laptop
  (git-fixes).
- commit a6cb05c
* Sat Aug 13 2022 tiwai@suse.de
- ALSA: hda/cirrus - support for iMac 12,1 model (git-fixes).
- ALSA: usb-audio: More comprehensive mixer map for ASUS ROG
  Zenith II (git-fixes).
- ALSA: hda/conexant: Add quirk for LENOVO 20149 Notebook model
  (git-fixes).
- ALSA: hda/realtek: Add quirk for another Asus K42JZ model
  (git-fixes).
- drm/gem: Properly annotate WW context on
  drm_gem_lock_reservations() error (git-fixes).
- commit fc95967
* Fri Aug 12 2022 denis.kirjanov@suse.com
- xfrm: xfrm_policy: fix a possible double xfrm_pols_put()
  in xfrm_bundle_lookup() (CVE-2022-36879 bsc#1201948).
- commit 97b83f0
* Fri Aug 12 2022 tiwai@suse.de
- devlink: Fix use-after-free after a failed reload (git-fixes).
- vsock: Set socket state back to SS_UNCONNECTED in
  vsock_connect_timeout() (git-fixes).
- vsock: Fix memory leak in vsock_connect() (git-fixes).
- can: ems_usb: fix clang's -Wunaligned-access warning
  (git-fixes).
- geneve: do not use RT_TOS for IPv6 flowlabel (git-fixes).
- geneve: fix TOS inheriting for ipv4 (git-fixes).
- Bluetooth: MGMT: Fixes build warnings with C=1 (git-fixes).
- Bluetooth: L2CAP: Fix l2cap_global_chan_by_psm regression
  (git-fixes).
- atm: idt77252: fix use-after-free bugs caused by tst_timer
  (git-fixes).
- virtio_net: fix memory leak inside XPD_TX with mergeable
  (git-fixes).
- ACPI: property: Return type of acpi_add_nondev_subnodes()
  should be bool (git-fixes).
- pinctrl: sunxi: Add I/O bias setting for H6 R-PIO (git-fixes).
- pinctrl: qcom: msm8916: Allow CAMSS GP clocks to be muxed
  (git-fixes).
- pinctrl: nomadik: Fix refcount leak in
  nmk_pinctrl_dt_subnode_to_map (git-fixes).
- kbuild: dummy-tools: avoid tmpdir leak in dummy gcc (git-fixes).
- Revert "scripts/mod/modpost.c: permit '.cranges' secton for
  sh64 architecture." (git-fixes).
- ACPI: video: Force backlight native for some TongFang devices
  (git-fixes).
- thermal: Fix NULL pointer dereferences in of_thermal_ functions
  (git-fixes).
- commit 4ff3e1b
* Fri Aug 12 2022 jroedel@suse.de
- blacklist.conf: Add 5f89468e2f06 swiotlb: manipulate orig_addr when tlb_addr has offset
- commit a6010ca
* Fri Aug 12 2022 jroedel@suse.de
- iommu/amd: Simplify and Consolidate Virtual APIC (AVIC) Enablement (git-fixes).
- commit f1b6523
* Fri Aug 12 2022 jroedel@suse.de
- iommu/mediatek: Add list_del in mtk_iommu_remove (git-fixes).
- commit c36c19c
* Fri Aug 12 2022 jroedel@suse.de
- iommu/vt-d: Calculate mask for non-aligned flushes (git-fixes).
- commit 34bbfc0
* Fri Aug 12 2022 jroedel@suse.de
- iommu/exynos: Handle failed IOMMU device registration properly
  (git-fixes).
- vfio/ccw: Remove UUID from s390 debug log (git-fixes).
- iommu/vt-d: Fix RID2PASID setup/teardown failure (git-fixes).
- iommu/vt-d: Fix PCI bus rescan device hot add (git-fixes).
- iommu/msm: Fix an incorrect NULL check on list iterator
  (git-fixes).
- iommu/omap: Fix regression in probe for NULL pointer dereference
  (git-fixes).
- iommu/iova: Improve 32-bit free space estimate (git-fixes).
- iommu/ipmmu-vmsa: Check for error num after setting mask
  (git-fixes).
- commit 040a9c6
* Fri Aug 12 2022 ykaukab@suse.de
- blacklist.conf: add various fixes
- commit 73738d1
* Fri Aug 12 2022 tiwai@suse.de
- net/packet: fix slab-out-of-bounds access in packet_recvmsg()
  (CVE-2022-20368 bsc#1202346).
- commit e8bbbca
* Fri Aug 12 2022 tiwai@suse.de
- media: v4l2-mem2mem: Apply DST_QUEUE_OFF_BASE on MMAP buffers
  across ioctls (bsc#1202347 CVE-2022-20369).
- commit 36d8575
* Thu Aug 11 2022 jroedel@suse.de
- iommu/vt-d: avoid invalid memory access via
  node_online(NUMA_NO_NODE) (git-fixes).
- iommu/arm-smmu: qcom_iommu: Add of_node_put() when breaking
  out of loop (git-fixes).
- commit c88bace
* Thu Aug 11 2022 msuchanek@suse.de
- kbuild: dummy-tools: avoid tmpdir leak in dummy gcc (bsc#1181862
  git-fixes).
- commit d5191b9
* Thu Aug 11 2022 mhocko@suse.com
- mm: proc: smaps_rollup: do not stall write attempts on mmap_lock
  (bsc#1201990).
- mm: smaps*: extend smap_gather_stats to support specified
  beginning (bsc#1201990).
- mmap locking API: add mmap_lock_is_contended() (bsc#1201990).
- commit 7944adf
* Thu Aug 11 2022 neilb@suse.de
- SUNRPC: Fix READ_PLUS crasher (git-fixes).
- dm raid: fix KASAN warning in raid5_add_disks (git-fixes).
- NFSD: Fix possible sleep during nfsd4_release_lockowner()
  (git-fixes).
- NFSD: prevent integer overflow on 32 bit systems (git-fixes).
- NFSD: prevent underflow in nfssvc_decode_writeargs()
  (git-fixes).
- NFSD: Clamp WRITE offsets (git-fixes).
- nfsd: fix use-after-free due to delegation race (git-fixes).
- SUNRPC: Prevent immediate close+reconnect (git-fixes).
- SUNRPC: Clean up scheduling of autoclose (git-fixes).
- NFSv4: Fix second deadlock in nfs4_evict_inode() (git-fixes).
- NFSv4: nfs4_proc_set_acl needs to restore NFS_CAP_UIDGID_NOMAP
  on error (git-fixes).
- xprtrdma: Fix XDRBUF_SPARSE_PAGES support (git-fixes).
- NFSD: Add missing NFSv2 .pc_func methods (git-fixes).
- silence nfscache allocation warnings with kvzalloc (git-fixes).
- NFSv4.2: support EXCHGID4_FLAG_SUPP_FENCE_OPS 4.2 EXCHANGE_ID
  flag (git-fixes).
- NFS: fix nfs_path in case of a rename retry (git-fixes).
- SUNRPC reverting d03727b248d0 ("NFSv4 fix CLOSE not waiting
  for direct IO compeletion") (git-fixes).
- commit a827eeb
* Thu Aug 11 2022 heming.zhao@suse.com
- md/bitmap: don't set sb values if can't pass sanity check
  (bsc#1197158).
- commit 3927074
* Wed Aug 10 2022 denis.kirjanov@suse.com
- kabi/severities: add stmmac driver local sumbols
- commit 31f077f
* Wed Aug 10 2022 denis.kirjanov@suse.com
- net: lapbether: Prevent racing when checking whether the netif
  is running (git-fixes).
- commit 9af3eff
* Wed Aug 10 2022 denis.kirjanov@suse.com
- octeontx2-af: fix infinite loop in unmapping NPC counter
  (git-fixes).
- commit c88fc73
* Wed Aug 10 2022 denis.kirjanov@suse.com
- net: mvpp2: fix interrupt mask/unmask skip condition
  (git-fixes).
- commit 3584e08
* Wed Aug 10 2022 denis.kirjanov@suse.com
- net: hdlc_x25: Return meaningful error code in x25_open
  (git-fixes).
- commit 212e2be
* Wed Aug 10 2022 denis.kirjanov@suse.com
- Update metadata references
- commit b372491
* Wed Aug 10 2022 denis.kirjanov@suse.com
- net: dsa: b53: fix an off by one in checking "vlan->vid"
  (git-fixes).
- commit ea4caa5
* Wed Aug 10 2022 denis.kirjanov@suse.com
- can: m_can: process interrupt only when not runtime suspended
  (git-fixes).
- commit bd4c919
* Wed Aug 10 2022 ohering@suse.de
- VMCI: Add support for ARM64 (bsc#1199291, jsc#SLE-24635).
- VMCI: Release notification_bitmap in error path (bsc#1199291, jsc#SLE-24635).
- VMCI: Check exclusive_vectors when freeing interrupt 1 (bsc#1199291, jsc#SLE-24635).
- VMCI: Fix some error handling paths in vmci_guest_probe_device() (bsc#1199291, jsc#SLE-24635).
- VMCI: dma dg: add support for DMA datagrams receive (bsc#1199291, jsc#SLE-24635).
- VMCI: dma dg: add support for DMA datagrams sends (bsc#1199291, jsc#SLE-24635).
- VMCI: dma dg: allocate send and receive buffers for DMA datagrams (bsc#1199291, jsc#SLE-24635).
- VMCI: dma dg: register dummy IRQ handlers for DMA datagrams (bsc#1199291, jsc#SLE-24635).
- VMCI: dma dg: set OS page size (bsc#1199291, jsc#SLE-24635).
- VMCI: dma dg: detect DMA datagram capability (bsc#1199291, jsc#SLE-24635).
- VMCI: dma dg: add MMIO access to registers (bsc#1199291, jsc#SLE-24635).
- VMCI: dma dg: whitespace formatting change for vmci register defines (bsc#1199291, jsc#SLE-24635).
- VMCI: Enforce queuepair max size for IOCTL_VMCI_QUEUEPAIR_ALLOC (bsc#1199291, jsc#SLE-24635).
- commit 834df98
* Wed Aug 10 2022 tiwai@suse.de
- remoteproc: qcom: q6v5-mss: add powerdomains to MSM8996 config
  (git-fixes).
- remoteproc: qcom: wcnss: Fix handling of IRQs (git-fixes).
- watchdog: armada_37xx_wdt: check the return value of
  devm_ioremap() in armada_37xx_wdt_probe() (git-fixes).
- tools/thermal: Fix possible path truncations (git-fixes).
- thermal: sysfs: Fix cooling_device_stats_setup() error code path
  (git-fixes).
- serial: 8250_dw: Store LSR into lsr_saved_flags in
  dw8250_tx_wait_empty() (git-fixes).
- x86/olpc: fix 'logical not is only applied to the left hand
  side' (git-fixes).
- kfifo: fix kfifo_to_user() return type (git-fixes).
- profiling: fix shift too large makes kernel panic (git-fixes).
- video: fbdev: s3fb: Check the size of screen before memset_io()
  (git-fixes).
- video: fbdev: arkfb: Check the size of screen before memset_io()
  (git-fixes).
- video: fbdev: vt8623fb: Check the size of screen before
  memset_io() (git-fixes).
- video: fbdev: arkfb: Fix a divide-by-zero bug in
  ark_set_pixclock() (git-fixes).
- video: fbdev: sis: fix typos in SiS_GetModeID() (git-fixes).
- video: fbdev: amba-clcd: Fix refcount leak bugs (git-fixes).
- usb: dwc3: gadget: Replace list_for_each_entry_safe() if using
  giveback (git-fixes).
- kfifo: fix ternary sign extension bugs (git-fixes).
- commit c5d77c5
* Tue Aug  9 2022 bp@suse.de
- x86/speculation: Add LFENCE to RSB fill sequence (bsc#1201726
  CVE-2022-26373).
- commit abba98d
* Tue Aug  9 2022 bp@suse.de
- x86/speculation: Add RSB VM Exit protections (bsc#1201726
  CVE-2022-26373).
- commit 061bcfd
* Tue Aug  9 2022 bp@suse.de
- x86/speculation: Change FILL_RETURN_BUFFER to work with objtool
  (bsc#1201726 CVE-2022-26373).
- commit 16768aa
* Tue Aug  9 2022 jlee@suse.com
- acpi: Disable APEI error injection if the kernel is locked down
  (bsc#1023051, CVE-2016-3695).
- commit 80750a7
* Tue Aug  9 2022 denis.kirjanov@suse.com
- net: ftgmac100: Fix crash when removing driver (git-fixes).
- commit 6458cfa
* Tue Aug  9 2022 denis.kirjanov@suse.com
- net: stmmac: Modify configuration method of EEE timers
  (git-fixes).
- commit b6da91b
* Tue Aug  9 2022 denis.kirjanov@suse.com
- net: stmmac: Use resolved link config in mac_link_up()
  (git-fixes).
- commit 4dba15f
* Tue Aug  9 2022 denis.kirjanov@suse.com
- net/sonic: Fix a resource leak in an error handling path in
  'jazz_sonic_probe()' (git-fixes).
- commit 8d37be1
* Tue Aug  9 2022 denis.kirjanov@suse.com
- blacklist.conf: update blacklist
- commit 51d7b18
* Tue Aug  9 2022 msuchanek@suse.de
- powerpc: powernv: kABI: add back powernv_get_random_long
  (bsc#1065729).
- commit f61a28c
* Tue Aug  9 2022 msuchanek@suse.de
- KVM: PPC: Use arch_get_random_seed_long instead of powernv
  variant (bsc#1156395).
- commit 3e6dc98
* Tue Aug  9 2022 msuchanek@suse.de
- powerpc/powernv: rename remaining rng powernv_ functions to pnv_
  (bsc#1065729).
- powerpc/powernv: delay rng platform device creation until
  later in boot (bsc#1065729).
- commit 74ae44c
* Mon Aug  8 2022 msuchanek@suse.de
- powerpc/powernv/kvm: Use darn for H_RANDOM on Power9
  (bsc#1065729).
- powerpc/powernv: Avoid crashing if rng is NULL (bsc#1065729).
- commit a69b0d7
* Mon Aug  8 2022 msuchanek@suse.de
- powerpc/powernv: wire up rng during setup_arch (bsc#1065729).
- powerpc/pseries: wire up rng during setup_arch() (bsc#1065729).
- Refresh patches.suse/powerpc-64s-rename-pnv-pseries_setup_rfi_flush-to-_s.patch
- powerpc/powernv: Staticify functions without prototypes
  (bsc#1065729).
- commit 98a575d
* Mon Aug  8 2022 iivanov@suse.de
- KVM: arm64: Avoid setting the upper 32 bits of TCR_EL2 and CPTR_EL2 (bsc#1201442)
- commit ec6a677
* Mon Aug  8 2022 denis.kirjanov@suse.com
- blacklist.conf: update blacklist
- commit 63fa2f9
* Sat Aug  6 2022 denis.kirjanov@suse.com
- blacklist.conf: update blacklist
- commit cc1d04f
* Fri Aug  5 2022 tiwai@suse.de
- mmc: cavium-thunderx: Add of_node_put() when breaking out of
  loop (git-fixes).
- mmc: cavium-octeon: Add of_node_put() when breaking out of loop
  (git-fixes).
- mmc: sdhci-of-at91: fix set_uhs_signaling rewriting of MC1R
  (git-fixes).
- memstick/ms_block: Fix a memory leak (git-fixes).
- memstick/ms_block: Fix some incorrect memory allocation
  (git-fixes).
- mmc: sdhci-of-esdhc: Fix refcount leak in
  esdhc_signal_voltage_switch (git-fixes).
- PCI: tegra194: Fix link up retry sequence (git-fixes).
- PCI: tegra194: Fix Root Port interrupt handling (git-fixes).
- PCI: tegra194: Fix PM error handling in tegra_pcie_config_ep()
  (git-fixes).
- PCI: qcom: Power on PHY before IPQ8074 DBI register accesses
  (git-fixes).
- PCI: qcom: Set up rev 2.1.0 PARF_PHY before enabling clocks
  (git-fixes).
- PCI: dwc: Always enable CDM check if "snps,enable-cdm-check"
  exists (git-fixes).
- PCI: dwc: Deallocate EPC memory on dw_pcie_ep_init() errors
  (git-fixes).
- PCI: dwc: Disable outbound windows only for controllers using
  iATU (git-fixes).
- PCI: dwc: Add unroll iATU space support to dw_pcie_disable_atu()
  (git-fixes).
- PCI: dwc: Stop link on host_init errors and de-initialization
  (git-fixes).
- PCI/portdrv: Don't disable AER reporting in
  get_port_device_capability() (git-fixes).
- platform/olpc: Fix uninitialized data in debugfs write
  (git-fixes).
- USB: Follow-up to SPDX identifiers addition - remove now
  useless comments (git-fixes).
- staging: rtl8192u: Fix sleep in atomic context bug in
  dm_fsync_timer_callback (git-fixes).
- usb: typec: ucsi: Acknowledge the GET_ERROR_STATUS command
  completion (git-fixes).
- USB: serial: fix tty-port initialized comments (git-fixes).
- usb: gadget: udc: amd5536 depends on HAS_DMA (git-fixes).
- usb: host: xhci: use snprintf() in xhci_decode_trb()
  (git-fixes).
- usb: xhci: tegra: Fix error check (git-fixes).
- usb: ohci-nxp: Fix refcount leak in ohci_hcd_nxp_probe
  (git-fixes).
- usb: host: Fix refcount leak in ehci_hcd_ppc_of_probe
  (git-fixes).
- iio: light: isl29028: Fix the warning in isl29028_remove()
  (git-fixes).
- soundwire: bus_type: fix remove and shutdown support
  (git-fixes).
- iio: resolver: ad2s90: Fix alignment for DMA safety (git-fixes).
- iio: resolver: ad2s1200: Fix alignment for DMA safety
  (git-fixes).
- iio: proximity: as3935: Fix alignment for DMA safety
  (git-fixes).
- intel_th: msu: Fix vmalloced buffers (git-fixes).
- intel_th: msu-sink: Potential dereference of null pointer
  (git-fixes).
- intel_th: Fix a resource leak in an error handling path
  (git-fixes).
- misc: rtsx: Fix an error handling path in rtsx_pci_probe()
  (git-fixes).
- commit 2bc728a
* Fri Aug  5 2022 tiwai@suse.de
- iio: potentiometer: mcp4131: Fix alignment for DMA safety
  (git-fixes).
- iio: potentiometer: mcp41010: Fix alignment for DMA safety
  (git-fixes).
- iio: potentiometer: max5481: Fix alignment for DMA safety
  (git-fixes).
- iio: potentiometer: ad5272: Fix alignment for DMA safety
  (git-fixes).
- iio: gyro: fxas210002c: Fix alignment for DMA safety
  (git-fixes).
- iio: gyro: adxrs450: Fix alignment for DMA safety (git-fixes).
- iio: gyro: adis16130: Fix alignment for DMA safety (git-fixes).
- iio: gyro: adis16080: Fix alignment for DMA safety (git-fixes).
- iio: frequency: adf4371: Fix alignment for DMA safety
  (git-fixes).
- iio: frequency: adf4350: Fix alignment for DMA safety
  (git-fixes).
- iio: frequency: ad9523: Fix alignment for DMA safety
  (git-fixes).
- iio: dac: ti-dac7612: Fix alignment for DMA safety (git-fixes).
- iio: dac: ti-dac7311: Fix alignment for DMA safety (git-fixes).
- iio: dac: ti-dac5571: Fix alignment for DMA safety (git-fixes).
- iio: dac: ti-dac082s085: Fix alignment for DMA safety
  (git-fixes).
- iio: dac: mcp4922: Fix alignment for DMA safety (git-fixes).
- iio: dac: ad8801: Fix alignment for DMA safety (git-fixes).
- iio: dac: ad7303: Fix alignment for DMA safety (git-fixes).
- iio: dac: ad5791: Fix alignment for DMA saftey (git-fixes).
- iio: dac: ad5764: Fix alignment for DMA safety (git-fixes).
- iio: dac: ad5761: Fix alignment for DMA safety (git-fixes).
- iio: dac: ad5755: Fix alignment for DMA safety (git-fixes).
- iio: dac: ad5504: Fix alignment for DMA safety (git-fixes).
- iio: dac: ad5449: Fix alignment for DMA safety (git-fixes).
- iio: dac: ad5421: Fix alignment for DMA safety (git-fixes).
- iio: dac: ad5360: Fix alignment for DMA safety (git-fixes).
- iio: dac: ad5064: Fix alignment for DMA safety (git-fixes).
- commit 7981ef6
* Fri Aug  5 2022 tiwai@suse.de
- clk: qcom: camcc-sdm845: Fix topology around titan_top power
  domain (git-fixes).
- clk: qcom: ipq8074: set BRANCH_HALT_DELAY flag for UBI clocks
  (git-fixes).
- clk: qcom: ipq8074: fix NSS port frequency tables (git-fixes).
- clk: qcom: ipq8074: SW workaround for UBI32 PLL lock
  (git-fixes).
- clk: qcom: ipq8074: fix NSS core PLL-s (git-fixes).
- clk: qcom: clk-krait: unlock spin after mux completion
  (git-fixes).
- clk: renesas: r9a06g032: Fix UART clkgrp bitsel (git-fixes).
- gpio: gpiolib-of: Fix refcount bugs in of_mm_gpiochip_add_data()
  (git-fixes).
- HID: cp2112: prevent a buffer overflow in cp2112_xfer()
  (git-fixes).
- driver core: fix potential deadlock in __driver_attach
  (git-fixes).
- iio: amplifiers: ad8366: Fix alignment for DMA safety
  (git-fixes).
- iio: adc: ti-tlc4541: Fix alignment for DMA safety (git-fixes).
- iio: adc: ti-ads8688: Fix alignment for DMA safety (git-fixes).
- iio: adc: ti-ads8344: Fix alignment for DMA safety (git-fixes).
- iio: adc: ti-ads7950: Fix alignment for DMA safety (git-fixes).
- iio: adc: ti-ads124s08: Fix alignment for DMA safety
  (git-fixes).
- iio: adc: ti-adc161s626: Fix alignment for DMA safety
  (git-fixes).
- iio: adc: ti-adc128s052: Fix alignment for DMA safety
  (git-fixes).
- iio: adc: ti-adc12138: Fix alignment for DMA safety (git-fixes).
- iio: adc: ti-adc084s021: Fix alignment for DMA safety
  (git-fixes).
- iio: adc: ti-adc0832: Fix alignment for DMA safety (git-fixes).
- iio: adc: mcp320x: Fix alignment for DMA safety (git-fixes).
- iio: adc: max1118: Fix alignment for DMA safety (git-fixes).
- iio: adc: max11100: Fix alignment for DMA safety (git-fixes).
- iio: adc: max1027: Fix alignment for DMA safety (git-fixes).
- iio: adc: ltc2497: Fix alignment for DMA safety (git-fixes).
- iio: adc: hi8435: Fix alignment for DMA safety (git-fixes).
- iio: adc: ad7887: Fix alignment for DMA safety (git-fixes).
- iio: adc: ad7768-1: Fix alignment for DMA safety (git-fixes).
- iio: adc: ad7766: Fix alignment for DMA safety (git-fixes).
- iio: adc: ad7476: Fix alignment for DMA safety (git-fixes).
- iio: adc: ad7298: Fix alignment for DMA safety (git-fixes).
- iio: adc: ad7266: Fix alignment for DMA safety (git-fixes).
- iio: accel: sca3000: Fix alignment for DMA safety (git-fixes).
- iio: accel: bma220: Fix alignment for DMA safety (git-fixes).
- iio: core: Fix IIO_ALIGN and rename as it was not sufficiently
  large (git-fixes).
- fpga: altera-pr-ip: fix unsigned comparison with less than zero
  (git-fixes).
- commit 9bda156
* Fri Aug  5 2022 tiwai@suse.de
- openvswitch: fix OOB access in reserve_sfa_size() (CVE-2022-2639
  bsc#1202154).
- commit bfc6551
* Thu Aug  4 2022 denis.kirjanov@suse.com
- blacklist.conf: update blacklist
- commit 847721e
* Thu Aug  4 2022 tiwai@suse.de
- virtio-gpu: fix a missing check to avoid NULL dereference
  (git-fixes).
- media: hdpvr: fix error value returns in hdpvr_read (git-fixes).
- media: tw686x: Register the irq at the end of probe (git-fixes).
- wifi: wil6210: debugfs: fix uninitialized variable use in
  `wil_write_file_wmi()` (git-fixes).
- wifi: libertas: Fix possible refcount leak in if_usb_probe()
  (git-fixes).
- wifi: iwlwifi: mvm: fix double list_add at
  iwl_mvm_mac_wake_tx_queue (git-fixes).
- wifi: wil6210: debugfs: fix info leak in wil_write_file_wmi()
  (git-fixes).
- wifi: p54: add missing parentheses in p54_flush() (git-fixes).
- wifi: p54: Fix an error handling path in p54spi_probe()
  (git-fixes).
- mediatek: mt76: mac80211: Fix missing of_node_put() in
  mt76_led_init() (git-fixes).
- mt76: mt76x02u: fix possible memory leak in
  __mt76x02u_mcu_send_msg (git-fixes).
- can: pch_can: pch_can_error(): initialize errc before using it
  (git-fixes).
- wifi: iwlegacy: 4965: fix potential off-by-one overflow in
  il4965_rs_fill_link_cmd() (git-fixes).
- wifi: rtlwifi: fix error codes in rtl_debugfs_set_write_h2c()
  (git-fixes).
- thermal/tools/tmon: Include pthread and time headers in tmon.h
  (git-fixes).
- regulator: of: Fix refcount leak bug in
  of_get_regulation_constraints() (git-fixes).
- soc: fsl: guts: machine variable might be unset (git-fixes).
- meson-mx-socinfo: Fix refcount leak in meson_mx_socinfo_init
  (git-fixes).
- virtio-net: fix the race between refill work and close
  (git-fixes).
- mt7601u: add USB device ID for some versions of XiaoDu WiFi
  Dongle (git-fixes).
- commit 347666b
* Thu Aug  4 2022 tiwai@suse.de
- drm/amd/display: Enable building new display engine with KCOV
  enabled (git-fixes).
- drm/exynos/exynos7_drm_decon: free resources when
  clk_set_parent() failed (git-fixes).
- drm/msm/mdp5: Fix global state lock backoff (git-fixes).
- drm/msm/hdmi: enable core-vcc/core-vdda-supply for 8996 platform
  (git-fixes).
- drm/mediatek: dpi: Only enable dpi after the bridge is enabled
  (git-fixes).
- drm/mediatek: dpi: Remove output format of YUV (git-fixes).
- drm/mediatek: Add pull-down MIPI operation in mtk_dsi_poweroff
  function (git-fixes).
- drm: bridge: sii8620: fix possible off-by-one (git-fixes).
- drm/rockchip: Fix an error handling path rockchip_dp_probe()
  (git-fixes).
- drm/rockchip: vop: Don't crash for invalid duplicate_state()
  (git-fixes).
- drm/radeon: fix incorrrect SPDX-License-Identifiers (git-fixes).
- drm/radeon: fix potential buffer overflow in
  ni_set_mc_special_registers() (git-fixes).
- drm/vc4: hdmi: Correct HDMI timing registers for interlaced
  modes (git-fixes).
- drm/vc4: hdmi: Fix timings for interlaced modes (git-fixes).
- drm/vc4: dsi: Add correct stop condition to
  vc4_dsi_encoder_disable iteration (git-fixes).
- drm/vc4: dsi: Correct pixel order for DSI0 (git-fixes).
- drm/vc4: dsi: Correct DSI divider calculations (git-fixes).
- drm/vc4: plane: Fix margin calculations for the right/bottom
  edges (git-fixes).
- drm/vc4: plane: Remove subpixel positioning check (git-fixes).
- drm/doc: Fix comment typo (git-fixes).
- drm/mcde: Fix refcount leak in mcde_dsi_bind (git-fixes).
- drm: bridge: adv7511: Add check for mipi_dsi_driver_register
  (git-fixes).
- drm: adv7511: override i2c address of cec before accessing it
  (git-fixes).
- drm/nouveau: fix another off-by-one in nvbios_addr (git-fixes).
- drm/mipi-dbi: align max_chunk to 2 in spi_transfer (git-fixes).
- drm/st7735r: Fix module autoloading for Okaya RH128128T
  (git-fixes).
- i2c: mux-gpmux: Add of_node_put() when breaking out of loop
  (git-fixes).
- i2c: cadence: Support PEC for SMBus block read (git-fixes).
- i2c: Fix a potential use after free (git-fixes).
- commit cce0615
* Thu Aug  4 2022 tiwai@suse.de
- drm/bridge: tc358767: Make sure Refclk clock are enabled
  (git-fixes).
- Bluetooth: hci_intel: Add check for platform_driver_register
  (git-fixes).
- can: error: specify the values of data[5..7] of CAN error frames
  (git-fixes).
- can: usb_8dev: do not report txerr and rxerr during bus-off
  (git-fixes).
- can: kvaser_usb_leaf: do not report txerr and rxerr during
  bus-off (git-fixes).
- can: kvaser_usb_hydra: do not report txerr and rxerr during
  bus-off (git-fixes).
- can: sun4i_can: do not report txerr and rxerr during bus-off
  (git-fixes).
- can: hi311x: do not report txerr and rxerr during bus-off
  (git-fixes).
- can: sja1000: do not report txerr and rxerr during bus-off
  (git-fixes).
- can: rcar_can: do not report txerr and rxerr during bus-off
  (git-fixes).
- can: pch_can: do not report txerr and rxerr during bus-off
  (git-fixes).
- ath10k: do not enforce interrupt trigger type (git-fixes).
- can: Break loopback loop on loopback documentation (git-fixes).
- ACPI: video: Shortening quirk list by identifying Clevo by
  board_name only (git-fixes).
- ACPI: APEI: Better fix to avoid spamming the console with old
  error logs (git-fixes).
- bus: hisi_lpc: fix missing platform_device_put() in
  hisi_lpc_acpi_probe() (git-fixes).
- ACPI: CPPC: Do not prevent CPPC from working in the future
  (git-fixes).
- Bluetooth: L2CAP: Fix use-after-free caused by l2cap_chan_put
  (git-fixes).
- ath10k: Fix error handling in ath10k_setup_msa_resources
  (git-fixes).
- commit 6ee2d65
* Wed Aug  3 2022 mkubecek@suse.cz
- ipv4: avoid using shared IP generator for connected sockets
  (CVE-2020-36516 bsc#1196616).
- ipv4: tcp: send zero IPID in SYNACK messages (CVE-2020-36516
  bsc#1196616).
- commit 6c53c05
* Wed Aug  3 2022 fweisbecker@suse.de
- blacklist.conf: add "sched: Reenable interrupts in do_sched_yield()"
  This patch caused unexplained regressions and it's not fixing any
  important issue.
- commit 7b4ecae
* Wed Aug  3 2022 iivanov@suse.de
- Revert "Refresh patches.suse/random-fix-crash-on-multiple-early-calls..." (bsc#1201645)
  This reverts commit f01d1a85f6c5334e324db629b3d43a8be5461b46.
- commit ef555c8
* Wed Aug  3 2022 oneukum@suse.com
- media: smipcie: fix interrupt handling and IR timeout
  (git-fixes).
- commit 72251a4
* Wed Aug  3 2022 mgorman@suse.de
- sched/fair: Revise comment about lb decision matrix (git fixes
  (sched/fair)).
- tick/nohz: Use WARN_ON_ONCE() to prevent console saturation
  (git fixes (kernel/time)).
- random: remove useless header comment (git fixes).
- profiling: fix shift-out-of-bounds bugs (git fixes).
- sched/membarrier: fix missing local execution of
  ipi_sync_rq_state() (git fixes (sched/membarrier)).
- mm: fix page reference leak in soft_offline_page() (git fixes
  (mm/memory-failure)).
- commit b0029fe
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: xtensa not used
- commit c7e553d
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: UML not used
- commit d38c3c3
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: Cosmetic patch
- commit 137482b
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: GCC-12 not used
- commit b35581e
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: KASAN not configured
- commit ddca4d2
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: Clang not used for build
- commit f6cb05a
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: KASAN not configured
- commit db5c6ef
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: 6ffbb45826f5d9ae09aa60cd88594b7816c96190
- commit ae569d4
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: Build time micro-optimisation
- commit 091232d
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: Build time micro-optimisation
- commit 06fea81
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: Build time micro-optimisation
- commit c5a48f8
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: Build fix that assumes bash does not exist
- commit a35739b
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: Comment fix only
- commit 1f940f0
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: Fixes pointing to misleading commit
- commit b94c0dc
* Wed Aug  3 2022 mgorman@suse.de
- blacklist.conf: Patch has a number of high risk dependencies
- commit 58c61ac
* Tue Aug  2 2022 msuchanek@suse.de
- Fix parsing of rpm/macros.kernel-source on SLE12 (bsc#1201019).
- commit 9816878
* Tue Aug  2 2022 oneukum@suse.com
- media: rtl28xxu: add missing sleep before probing slave demod
  (git-fixes).
- commit ac926ca
* Tue Aug  2 2022 oneukum@suse.com
- media: usb: dvb-usb-v2: rtl28xxu: convert to use
  i2c_new_client_device() (git-fixes).
- commit 47f6029
* Tue Aug  2 2022 oneukum@suse.com
- media: rtl28xxu: Add support for PROlectrix DV107669 DVB-T
  dongle (git-fixes).
- commit cf3cc2d
* Tue Aug  2 2022 oneukum@suse.com
- media: rtl28xxu: set keymap for Astrometa DVB-T2 (git-fixes).
- commit 27a23c1
* Tue Aug  2 2022 oneukum@suse.com
- media: rc: increase rc-mm tolerance and add debug message
  (git-fixes).
- commit 532733e
* Tue Aug  2 2022 oneukum@suse.com
- media: v4l2-mem2mem: always consider OUTPUT queue during poll
  (git-fixes).
- commit 981dce5
* Tue Aug  2 2022 oneukum@suse.com
- media: v4l2-mem2mem: reorder checks in v4l2_m2m_poll()
  (git-fixes).
- commit 691e7d8
* Tue Aug  2 2022 oneukum@suse.com
- PM: runtime: Remove link state checks in rpm_get/put_supplier()
  (git-fixes).
- commit 2786445
* Tue Aug  2 2022 oneukum@suse.com
- usb: dwc3: add cancelled reasons for dwc3 requests (git-fixes).
- Refresh
  patches.suse/Revert-usb-dwc3-gadget-Use-list_replace_init-before-.patch.
- Refresh
  patches.suse/usb-dwc3-gadget-Use-list_replace_init-before-travers.patch.
- commit de6720f
* Tue Aug  2 2022 osalvador@suse.de
- Rename colliding patches before the next origin/cve/linux-5.3 -> SLE15-SP3 merge
- commit bafbca0
* Mon Aug  1 2022 fweisbecker@suse.de
- sched/debug: Remove mpol_get/put and task_lock/unlock from (git-fixes)
- commit a77b059
* Mon Aug  1 2022 jgross@suse.com
- KVM: x86: Update vCPU's hv_clock before back to guest when
  tsc_offset is adjusted (git-fixes).
- commit 143ba5a
* Mon Aug  1 2022 jeffm@suse.com
- Updated commit IDs from a rebased upstream branch:
- patches.suse/powerpc-pseries-mobility-set-NMI-watchdog-factor-dur.patch.
- patches.suse/powerpc-watchdog-introduce-a-NMI-watchdog-s-factor.patch.
- patches.suse/watchdog-export-lockup_detector_reconfigure.patch.
- commit a3cdcd5
* Mon Aug  1 2022 jgross@suse.com
- KVM: x86: Fix split-irqchip vs interrupt injection window
  request (git-fixes).
- commit 69e8da6
* Mon Aug  1 2022 jgross@suse.com
- KVM: x86: handle !lapic_in_kernel case in kvm_cpu_*_extint
  (git-fixes).
- commit 156ec3b
* Mon Aug  1 2022 oneukum@suse.com
- net: usb: ax88179_178a: add Allied Telesis AT-UMCs (git-fixes).
- commit 2fe0bb0
* Mon Aug  1 2022 oneukum@suse.com
- net: usb: use eth_hw_addr_set() (git-fixes).
- commit cd08705
* Mon Aug  1 2022 jgross@suse.com
- KVM: VMX: Don't freeze guest when event delivery causes an
  APIC-access exit (git-fixes).
- commit 13e27e5
* Mon Aug  1 2022 oneukum@suse.com
- net: usb: ax88179_178a: add MCT usb 3.0 adapter (git-fixes).
- commit 5a414a0
* Mon Aug  1 2022 oneukum@suse.com
- net: usb: ax88179_178a: add Toshiba usb 3.0 adapter (git-fixes).
- commit 65c08ec
* Mon Aug  1 2022 oneukum@suse.com
- net: usb: ax88179_178a: remove redundant assignment to variable
  ret (git-fixes).
- commit 75d1e2c
* Mon Aug  1 2022 oneukum@suse.com
- ax88179_178a: add ethtool_op_get_ts_info() (git-fixes).
- commit 8bcd286
* Mon Aug  1 2022 oneukum@suse.com
- net: usb: ax88179_178a: write mac to hardware in get_mac_addr
  (git-fixes).
- commit 18afbc0
* Mon Aug  1 2022 jgross@suse.com
- KVM: VMX: Add non-canonical check on writes to RTIT address MSRs
  (git-fixes).
- commit ad2b012
* Mon Aug  1 2022 bp@suse.de
- lkdtm: Disable return thunks in rodata.c (bsc#1178134).
- commit 564965b
* Sun Jul 31 2022 bp@suse.de
- x86/retbleed: Add fine grained Kconfig knobs (bsc#1178134).
- commit 8fc5407
* Sat Jul 30 2022 denis.kirjanov@suse.com
- netfilter: nf_queue: do not allow packet truncation below
  transport header offset (bsc#1201940 CVE-2022-36946).
- commit f4f33cd
* Fri Jul 29 2022 bp@suse.de
- kvm/emulate: Fix SETcc emulation function offsets with SLS
  (bsc#1201930).
- commit 0a6851d
* Fri Jul 29 2022 dwagner@suse.de
- nvme: consider also host_iface when checking ip options
  (bsc#1199670).
- commit edd56ec
* Fri Jul 29 2022 denis.kirjanov@suse.com
- drivers/net: Fix kABI in tun.c (git-fixes).
- commit 3adafd5
* Fri Jul 29 2022 denis.kirjanov@suse.com
- FDDI: defxx: Make MMIO the configuration default except for EISA
  (git-fixes).
- commit 49c7c8d
* Fri Jul 29 2022 denis.kirjanov@suse.com
- FDDI: defxx: Bail out gracefully with unassigned PCI resource
  for CSR (git-fixes).
- commit 87b1bf0
* Fri Jul 29 2022 denis.kirjanov@suse.com
- net: tun: set tun->dev->addr_len during TUNSETLINK processing
  (git-fixes).
- commit 11d0ba1
* Fri Jul 29 2022 denis.kirjanov@suse.com
- net: macb: restore cmp registers on resume path (git-fixes).
- commit 73e4cc3
* Fri Jul 29 2022 denis.kirjanov@suse.com
- drivers: net: fix memory leak in peak_usb_create_dev
  (git-fixes).
- commit bf7b83d
* Fri Jul 29 2022 denis.kirjanov@suse.com
- drivers: net: fix memory leak in atusb_probe (git-fixes).
- commit 1811ff5
* Fri Jul 29 2022 denis.kirjanov@suse.com
- amd-xgbe: Update DMA coherency values (git-fixes).
- commit 58be63e
* Fri Jul 29 2022 denis.kirjanov@suse.com
- net: dsa: lantiq_gswip: Let GSWIP automatically set the xMII
  clock (git-fixes).
- commit 5683f5d
* Fri Jul 29 2022 denis.kirjanov@suse.com
- net: stmmac: dwmac-sun8i: Provide TX and RX fifo sizes
  (git-fixes).
- commit a1e8450
* Fri Jul 29 2022 denis.kirjanov@suse.com
- ftgmac100: Restart MAC HW once (git-fixes).
- commit 9b2ea44
* Fri Jul 29 2022 denis.kirjanov@suse.com
- net: dsa: bcm_sf2: Qualify phydev->dev_flags based on port
  (git-fixes).
- commit 74dff8e
* Fri Jul 29 2022 denis.kirjanov@suse.com
- net/mlx5e: When changing XDP program without reset, take refs
  for XSK RQs (git-fixes).
- commit 4584eb8
* Fri Jul 29 2022 denis.kirjanov@suse.com
- net: lapbether: Remove netif_start_queue / netif_stop_queue
  (git-fixes).
- commit 9195d10
* Fri Jul 29 2022 denis.kirjanov@suse.com
- net: stmmac: fix incorrect DMA channel intr enable setting of
  EQoS v4.10 (git-fixes).
- commit 3eac36a
* Fri Jul 29 2022 denis.kirjanov@suse.com
- net: enetc: keep RX ring consumer index in sync with hardware
  (git-fixes).
- commit 5b9c123
* Fri Jul 29 2022 denis.kirjanov@suse.com
- net: enetc: fix incorrect TPID when receiving 802.1ad tagged
  packets (git-fixes).
- commit d2c7696
* Fri Jul 29 2022 denis.kirjanov@suse.com
- net: hns3: fix error mask definition of flow director
  (git-fixes).
- commit e86b116
* Fri Jul 29 2022 denis.kirjanov@suse.com
- blacklist.conf: update blacklist
- commit 545a342
* Fri Jul 29 2022 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.2.0.5 patches
  (bsc#1201956).
- scsi: lpfc: Update lpfc version to 14.2.0.5 (bsc#1201956).
- scsi: lpfc: Remove Menlo/Hornet related code (bsc#1201956).
- scsi: lpfc: Refactor lpfc_nvmet_prep_abort_wqe() into
  lpfc_sli_prep_abort_xri() (bsc#1201956).
- scsi: lpfc: Revert RSCN_MEMENTO workaround for misbehaved
  configuration (bsc#1201956).
- scsi: lpfc: Fix lost NVMe paths during LIF bounce stress test
  (bsc#1201956 bsc#1200521).
- scsi: lpfc: Fix attempted FA-PWWN usage after feature disable
  (bsc#1201956).
- scsi: lpfc: Fix possible memory leak when failing to issue
  CMF WQE (bsc#1201956).
- scsi: lpfc: Remove extra atomic_inc on cmd_pending in
  queuecommand after VMID (bsc#1201956).
- scsi: lpfc: Set PU field when providing D_ID in
  XMIT_ELS_RSP64_CX iocb (bsc#1201956).
- scsi: lpfc: Prevent buffer overflow crashes in debugfs with
  malformed user input (bsc#1201956).
- scsi: lpfc: Fix uninitialized cqe field in
  lpfc_nvme_cancel_iocb() (bsc#1201956).
- commit 6e7b732
* Fri Jul 29 2022 dwagner@suse.de
- scsi: qla2xxx: Update version to 10.02.07.800-k (bsc#1201958).
- scsi: qla2xxx: Update manufacturer details (bsc#1201958).
- scsi: qla2xxx: Fix sparse warning for dport_data (bsc#1201958).
- scsi: qla2xxx: Fix discovery issues in FC-AL topology
  (bsc#1201958).
- scsi: qla2xxx: Fix imbalance vha->vref_count (bsc#1201958).
- scsi: qla2xxx: edif: Fix dropped IKE message (bsc#1201958).
- scsi: qla2xxx: Fix response queue handler reading stale packets
  (bsc#1201958).
- scsi: qla2xxx: Zero undefined mailbox IN registers
  (bsc#1201958).
- scsi: qla2xxx: Fix incorrect display of max frame size
  (bsc#1201958).
- scsi: qla2xxx: Check correct variable in qla24xx_async_gffid()
  (bsc#1201958).
- commit d5c3642
* Fri Jul 29 2022 dwagner@suse.de
- Drop qla2xxx patch which prevented nvme port discovery
  (bsc#1200651 bsc#1200644 bsc#1201954 bsc#1201958)
  Upstream fixed the problem by reverting the offending commit.
  Delete:
  - patches.suse/scsi-qla2xxx-Fix-disk-failure-to-rediscover.patch.
- commit 1cb16fb
* Thu Jul 28 2022 ohering@suse.de
- hv_netvsc: Add support for XDP_REDIRECT (bsc#1199364).
- hv_netvsc: Add comment of netvsc_xdp_xmit() (bsc#1199364).
- hv_netvsc: Fix validation in netvsc_linkstatus_callback()
  (bsc#1199364).
- net, xdp: Introduce xdp_build_skb_from_frame utility routine
  (bsc#1199364).
- net, xdp: Introduce __xdp_build_skb_from_frame utility routine
  (bsc#1199364).
- hv_netvsc: Copy packets sent by Hyper-V out of the receive
  buffer (bsc#1199364).
- hv_netvsc: Add (more) validation for untrusted Hyper-V values
  (bsc#1199364).
- bpf, cpumap: Remove rcpu pointer from cpu_map_build_skb
  signature (bsc#1199364).
- commit cffae99
* Thu Jul 28 2022 bp@suse.de
- KVM: emulate: do not adjust size of fastop and setcc subroutines
  (bsc#1201930).
- commit 317f350
* Wed Jul 27 2022 bp@suse.de
- Refresh
  patches.suse/x86-prepare-asm-files-for-straight-line-speculation.patch.
- commit c513474
* Wed Jul 27 2022 mkubecek@suse.cz
- Update
  patches.suse/netfilter-nf_tables-disallow-non-stateful-expression.patch
  references (add CVE-2022-32250).
- commit 8871b3f
* Wed Jul 27 2022 mkubecek@suse.cz
- net/sched: cls_u32: fix netns refcount changes in u32_change()
  (CVE-2022-29581 bsc#1199665).
- commit e1d6992
* Wed Jul 27 2022 oneukum@suse.com
- random: fix typo in comments (git-fixes).
- commit 49bfcbe
* Wed Jul 27 2022 oneukum@suse.com
- blacklist.conf: a cleanup that breaks kABI
- commit f8d13cb
* Wed Jul 27 2022 oneukum@suse.com
- random: document add_hwgenerator_randomness() with other input
  functions (git-fixes).
- commit 9a03f2f
* Wed Jul 27 2022 lduncan@suse.com
- drbd: fix potential silent data corruption (git-fixes).
- block: drbd: drbd_nl: Make conversion to 'enum drbd_ret_code'
  explicit (git-fixes).
- linux/random.h: Mark CONFIG_ARCH_RANDOM functions __must_check
  (git-fixes).
- linux/random.h: Use false with bool (git-fixes).
- linux/random.h: Remove arch_has_random, arch_has_random_seed
  (git-fixes).
- commit a9f5081
* Tue Jul 26 2022 pmladek@suse.com
- kABI workaround for including mm.h in fs/sysfs/file.c
  (bsc#1200598 cve-2022-20166).
- commit 29d7d8a
* Tue Jul 26 2022 denis.kirjanov@suse.com
- net: stmmac: fix watchdog timeout during suspend/resume stress
  test (git-fixes).
- commit b651717
* Tue Jul 26 2022 denis.kirjanov@suse.com
- net: stmmac: stop each tx channel independently (git-fixes).
- commit 3ba5a53
* Tue Jul 26 2022 denis.kirjanov@suse.com
- net: stmmac: fix CBS idleslope and sendslope calculation
  (git-fixes).
- commit e0b11c6
* Tue Jul 26 2022 denis.kirjanov@suse.com
- net: ag71xx: remove unnecessary MTU reservation (git-fixes).
- commit 6020ebf
* Tue Jul 26 2022 denis.kirjanov@suse.com
- net: amd-xgbe: Fix network fluctuations when using 1G BELFUSE
  SFP (git-fixes).
- commit 858de54
* Tue Jul 26 2022 denis.kirjanov@suse.com
- net: amd-xgbe: Reset link when the link never comes back
  (git-fixes).
- commit 75c3dff
* Tue Jul 26 2022 denis.kirjanov@suse.com
- net: amd-xgbe: Fix NETDEV WATCHDOG transmit queue timeout
  warning (git-fixes).
- commit 2d480f1
* Tue Jul 26 2022 denis.kirjanov@suse.com
- net: amd-xgbe: Reset the PHY rx data path when mailbox command
  timeout (git-fixes).
- commit 5734e3e
* Tue Jul 26 2022 denis.kirjanov@suse.com
- net: axienet: Handle deferred probe on clock properly
  (git-fixes).
- commit c2493d6
* Tue Jul 26 2022 denis.kirjanov@suse.com
- net: mvneta: Remove per-cpu queue mapping for Armada 3700
  (git-fixes).
- commit 421a813
* Tue Jul 26 2022 denis.kirjanov@suse.com
- igb: Enable RSS for Intel I211 Ethernet Controller (git-fixes).
- commit f6ff8de
* Tue Jul 26 2022 denis.kirjanov@suse.com
- macvlan: remove redundant null check on data (git-fixes).
- commit 37296a9
* Tue Jul 26 2022 denis.kirjanov@suse.com
- net: dsa: bcm_sf2: put device node before return (git-fixes).
- commit d83cfd7
* Tue Jul 26 2022 msuchanek@suse.de
- powerpc/pseries/mobility: set NMI watchdog factor during an LPM
  (bsc#1201846 ltc#198761).
- powerpc/watchdog: introduce a NMI watchdog's factor (bsc#1201846
  ltc#198761).
- watchdog: export lockup_detector_reconfigure (bsc#1201846
  ltc#198761).
- powerpc/mobility: wait for memory transfer to complete
  (bsc#1201846 ltc#198761).
- commit 4aa9f78
* Tue Jul 26 2022 denis.kirjanov@suse.com
- net: macb: unprepare clocks in case of failure (git-fixes).
- commit 9b3aefc
* Tue Jul 26 2022 denis.kirjanov@suse.com
- net: macb: add function to disable all macb clocks (git-fixes).
- commit e67caf5
* Mon Jul 25 2022 denis.kirjanov@suse.com
- net: dsa: lantiq_gswip: Exclude RMII from modes that report 1 GbE (git-fixes).
- commit 2629e74
* Mon Jul 25 2022 denis.kirjanov@suse.com
- octeontx2-af: fix memory leak of lmac and lmac->name (git-fixes).
- commit 12700d6
* Mon Jul 25 2022 denis.kirjanov@suse.com
- net/sonic: Fix some resource leaks in error handling paths (git-fixes).
- commit 823b92f
* Mon Jul 25 2022 denis.kirjanov@suse.com
- net: allwinner: Fix some resources leak in the error handling path of the probe and in the remove function (git-fixes).
- commit 3311dc2
* Mon Jul 25 2022 denis.kirjanov@suse.com
- net: evaluate net.ipv4.conf.all.proxy_arp_pvlan (git-fixes).
- commit 0e7bc32
* Mon Jul 25 2022 denis.kirjanov@suse.com
- net: evaluate net.ipvX.conf.all.ignore_routes_with_linkdown
  (git-fixes).
- commit 0b9accc
* Mon Jul 25 2022 denis.kirjanov@suse.com
- cxgb4: Fix the -Wmisleading-indentation warning (git-fixes).
- commit 96affe9
* Mon Jul 25 2022 denis.kirjanov@suse.com
- net: ll_temac: Fix potential NULL dereference in temac_probe()
  (git-fixes).
- commit 9f3a68c
* Mon Jul 25 2022 denis.kirjanov@suse.com
- net: stmmac: dwmac1000: provide multicast filter fallback
  (git-fixes).
- commit 173655e
* Mon Jul 25 2022 denis.kirjanov@suse.com
- net: ll_temac: Use devm_platform_ioremap_resource_byname()
  (git-fixes).
- commit bd77f60
* Mon Jul 25 2022 denis.kirjanov@suse.com
- net: mscc: Fix OF_MDIO config check (git-fixes).
- commit 6a2a9df
* Mon Jul 25 2022 denis.kirjanov@suse.com
- blacklist.conf: update blacklist
- commit 5495889
* Mon Jul 25 2022 denis.kirjanov@suse.com
- blacklist.conf: update blacklist
- commit ccb0438
* Sat Jul 23 2022 tiwai@suse.de
- i2c: cadence: Change large transfer count reset logic to be
  unconditional (git-fixes).
- gpio: pca953x: use the correct register address when regcache
  sync during init (git-fixes).
- gpio: pca953x: use the correct range when do regmap sync
  (git-fixes).
- gpio: pca953x: only use single read/write for No AI mode
  (git-fixes).
- commit 20d420c
* Fri Jul 22 2022 tiwai@suse.de
- USB: serial: ftdi_sio: add Belimo device ids (git-fixes).
- serial: 8250: fix return error code in
  serial8250_request_std_resource() (git-fixes).
- wifi: mac80211: fix queue selection for mesh/OCB interfaces
  (git-fixes).
- ALSA: hda/realtek - Enable the headset-mic on a Xiaomi's laptop
  (git-fixes).
- ALSA: hda/realtek - Fix headset mic problem for a HP machine
  with alc221 (git-fixes).
- ALSA: hda/realtek - Fix headset mic problem for a HP machine
  with alc671 (git-fixes).
- ALSA: hda - Add fixup for Dell Latitidue E5430 (git-fixes).
- ALSA: hda/conexant: Apply quirk for another HP ProDesk 600 G3
  model (git-fixes).
- ASoC: madera: Fix event generation for rate controls
  (git-fixes).
- ASoC: madera: Fix event generation for OUT1 demux (git-fixes).
- ASoC: cs47l15: Fix event generation for low power mux control
  (git-fixes).
- ASoC: wm5110: Fix DRE control (git-fixes).
- ASoC: ops: Fix off by one in range control validation
  (git-fixes).
- soc: ixp4xx/npe: Fix unused match warning (git-fixes).
- NFC: nxp-nci: don't print header length mismatch on i2c error
  (git-fixes).
- platform/x86: hp-wmi: Ignore Sanitization Mode event
  (git-fixes).
- virtio_mmio: Restore guest page size on resume (git-fixes).
- virtio_mmio: Add missing PM calls to freeze/restore (git-fixes).
- commit 7b686cc
* Thu Jul 21 2022 mkoutny@suse.com
- KABI: cgroup: Restore KABI of css_set (bsc#1201610).
- cgroup: Use separate src/dst nodes when preloading css_sets
  for migration (bsc#1201610).
- commit fecc544
* Thu Jul 21 2022 denis.kirjanov@suse.com
-  Fix 1201644, 1201664, 1201672, 1201673, 1201676
  All are reports of the same problem - the IBRS_* regs push/popping was
  wrong but it needs
  1b331eeea7b8 ("x86/entry: Remove skip_r11rcx")
  too.
- commit cc90276
* Thu Jul 21 2022 jslaby@suse.cz
- Update patches.suse/vt-vt_ioctl-fix-race-in-VT_RESIZEX.patch
  (git-fixes bsc#1200910 CVE-2020-36558).
  Add references.
- commit d84e9d7
* Thu Jul 21 2022 jslaby@suse.cz
- Update
  patches.suse/vt-vt_ioctl-fix-VT_DISALLOCATE-freeing-in-use-virtua.patch
  (git-fixes bsc#1201429 CVE-2020-36557).
  Add references.
- commit 76ab189
* Thu Jul 21 2022 tiwai@suse.de
- lockdown: Fix kexec lockdown bypass with ima policy
  (CVE-2022-21505 bsc#1201458).
- commit 5806b46
* Thu Jul 21 2022 iivanov@suse.de
- arm64: dts: marvell: espressobin: Add ethernet switch aliases (git-fixes)
- commit b51a741
* Wed Jul 20 2022 bp@suse.de
- Refresh
  patches.suse/x86-bugs-Do-not-enable-IBPB-on-entry-when-IBPB-is-not-supp.patch.
- commit 9493568
* Wed Jul 20 2022 bp@suse.de
- Fix 1201644, 1201664, 1201672, 1201673, 1201676
  All are reports of the same problem - the IBRS_* regs push/popping was
  wrong but it needs
  1b331eeea7b8 ("x86/entry: Remove skip_r11rcx")
  too.
- commit 7226005
* Wed Jul 20 2022 bp@suse.de
- x86/entry: Remove skip_r11rcx (bsc#1201644).
- Refresh
  patches.suse/x86-entry-Add-kernel-IBRS-implementation.patch.
- commit b81e242
* Wed Jul 20 2022 ludwig.nussel@suse.de
- kernel-obs-build: include qemu_fw_cfg (boo#1201705)
- commit e2263d4
* Wed Jul 20 2022 oneukum@suse.com
- blacklist.conf: updated blacklist for new issue
- commit 93feb45
* Wed Jul 20 2022 pmladek@suse.com
- mm: and drivers core: Convert hugetlb_report_node_meminfo to
  sysfs_emit (bsc#1200598 cve-2022-20166).
- commit 6f05f26
* Wed Jul 20 2022 pmladek@suse.com
- drivers core: Miscellaneous changes for sysfs_emit (bsc#1200598
  cve-2022-20166).
- commit 6ff7ebb
* Wed Jul 20 2022 pmladek@suse.com
- drivers core: Remove strcat uses around sysfs_emit and neaten
  (bsc#1200598 cve-2022-20166).
- commit 4cafd1f
* Wed Jul 20 2022 jslaby@suse.cz
- vt: drop old FONT ioctls (bsc#1201636 CVE-2021-33656).
- commit bcf7213
* Wed Jul 20 2022 pmladek@suse.com
- drivers core: Use sysfs_emit and sysfs_emit_at for show(device
  * ...) functions (bsc#1200598 cve-2022-20166).
- commit 747b6a7
* Tue Jul 19 2022 pmladek@suse.com
- sysfs: Add sysfs_emit and sysfs_emit_at to format sysfs output
  (bsc#1200598 cve-2022-20166).
- commit 4aaf7f0
* Tue Jul 19 2022 tiwai@suse.de
- fbmem: Check virtual screen sizes in fb_set_var()
  (CVE-2021-33655 bsc#1201635).
- fbcon: Prevent that screen size is smaller than font size
  (CVE-2021-33655 bsc#1201635).
- fbcon: Disallow setting font bigger than screen size
  (CVE-2021-33655 bsc#1201635).
- commit a7693d8
* Tue Jul 19 2022 tiwai@suse.de
- Delete patches.suse/hwmon-Make-chip-parameter-for-with_info-API-mandator.patch (bsc#1201206)
  The patch seems causing a regression on Mac.
- commit f885f68
* Tue Jul 19 2022 iivanov@suse.de
- arm64: mm: Don't invalidate FROM_DEVICE buffers at start of DMA (git-fixes)
- commit 036b703
* Tue Jul 19 2022 iivanov@suse.de
- arm64: stackleak: fix current_top_of_stack() (git-fixes)
- commit 9d510a3
* Tue Jul 19 2022 iivanov@suse.de
- cpuidle: PSCI: Move the `has_lpi` check to the beginning of the (git-fixes)
- commit e7722fa
* Tue Jul 19 2022 iivanov@suse.de
- arm64: module: remove (NOLOAD) from linker script (git-fixes)
- commit 2f78693
* Tue Jul 19 2022 iivanov@suse.de
- arm64 module: set plt* section addresses to 0x0 (git-fixes)
- commit 5213f10
* Mon Jul 18 2022 tiwai@suse.de
- kABI workaround for rtsx_usb (git-fixes).
- commit 4ee0d92
* Mon Jul 18 2022 bp@suse.de
- x86/bugs: Remove apostrophe typo (bsc#1178134).
- commit 0dca060
* Mon Jul 18 2022 tiwai@suse.de
- power/reset: arm-versatile: Fix refcount leak in
  versatile_reboot_probe (git-fixes).
- serial: stm32: Clear prev values before setting RTS delays
  (git-fixes).
- serial: pl011: UPSTAT_AUTORTS requires .throttle/unthrottle
  (git-fixes).
- spi: amd: Limit max transfer and message size (git-fixes).
- drm/i915/gt: Serialize TLB invalidates with GT resets
  (git-fixes).
- drm/i915/selftests: fix a couple IS_ERR() vs NULL tests
  (git-fixes).
- raw: Fix a data-race around sysctl_raw_l3mdev_accept
  (git-fixes).
- sysctl: Fix data-races in proc_dointvec_ms_jiffies()
  (git-fixes).
- sysctl: Fix data races in proc_dointvec_jiffies() (git-fixes).
- sysctl: Fix data races in proc_douintvec_minmax() (git-fixes).
- sysctl: Fix data races in proc_dointvec_minmax() (git-fixes).
- sysctl: Fix data races in proc_douintvec() (git-fixes).
- sysctl: Fix data races in proc_dointvec() (git-fixes).
- ima: Fix potential memory leak in ima_init_crypto() (git-fixes).
- ima: Fix a potential integer overflow in
  ima_appraise_measurement (git-fixes).
- drm/panfrost: Fix shrinker list corruption by madvise IOCTL
  (git-fixes).
- drm/panfrost: Put mapping instead of shmem obj on
  panfrost_mmu_map_fault_addr() error (git-fixes).
- drm/i915: fix a possible refcount leak in
  intel_dp_add_mst_connector() (git-fixes).
- ida: don't use BUG_ON() for debugging (git-fixes).
- dmaengine: pl330: Fix lockdep warning about non-static key
  (git-fixes).
- misc: rtsx_usb: set return value in rsp_buf alloc err path
  (git-fixes).
- misc: rtsx_usb: use separate command and response buffers
  (git-fixes).
- misc: rtsx_usb: fix use of dma mapped buffer for usb bulk
  transfer (git-fixes).
- i2c: cadence: Unregister the clk notifier in error path
  (git-fixes).
- memregion: Fix memregion_free() fallback definition (git-fixes).
- fbmem: Check virtual screen sizes in fb_set_var() (git-fixes).
- fbcon: Prevent that screen size is smaller than font size
  (git-fixes).
- fbcon: Disallow setting font bigger than screen size
  (git-fixes).
- video: of_display_timing.h: include errno.h (git-fixes).
- fbdev: fbmem: Fix logo center image dx issue (git-fixes).
- r8169: fix accessing unset transport header (git-fixes).
- net: rose: fix UAF bug caused by rose_t0timer_expiry
  (git-fixes).
- pinctrl: sunxi: sunxi_pconf_set: use correct offset (git-fixes).
- pinctrl: sunxi: a83t: Fix NAND function name for some pins
  (git-fixes).
- commit aa669e5
* Mon Jul 18 2022 tiwai@suse.de
- ASoC: Intel: Skylake: Correct the handling of fmt_config
  flexible array (git-fixes).
- ASoC: Intel: Skylake: Correct the ssp rate discovery in
  skl_get_ssp_clks() (git-fixes).
- ASoC: sgtl5000: Fix noise on shutdown/remove (git-fixes).
- dmaengine: at_xdma: handle errors of at_xdmac_alloc_desc()
  correctly (git-fixes).
- dmaengine: imx-sdma: Allow imx8m for imx7 FW revs (git-fixes).
- dmaengine: ti: Add missing put_device in
  ti_dra7_xbar_route_allocate (git-fixes).
- dmaengine: ti: Fix refcount leak in ti_dra7_xbar_route_allocate
  (git-fixes).
- can: gs_usb: gs_usb_open/close(): fix memory leak (git-fixes).
- ASoC: Remove unused hw_write_t type (git-fixes).
- commit 2be6c70
* Mon Jul 18 2022 iivanov@suse.de
- arm64: fix compat syscall return truncation (git-fixes)
- commit 24bf105
* Mon Jul 18 2022 iivanov@suse.de
- arm64: vdso: Avoid ISB after reading from cntvct_el0 (git-fixes)
- commit 992de8b
* Mon Jul 18 2022 iivanov@suse.de
- arm64: fix inline asm in load_unaligned_zeropad() (git-fixes)
- commit 867aa84
* Mon Jul 18 2022 iivanov@suse.de
- arm64: uprobe: Return EOPNOTSUPP for AARCH32 instruction probing (git-fixes)
- commit ad8af15
* Mon Jul 18 2022 iivanov@suse.de
- arm64: Extend workaround for erratum 1024718 to all versions of (git-fixes)
- commit 02d9d74
* Mon Jul 18 2022 iivanov@suse.de
- arm64: compat: Ensure upper 32 bits of x0 are zero on syscall return (git-fixes)
- commit 4265617
* Mon Jul 18 2022 iivanov@suse.de
- arm64: ptrace: Override SPSR.SS when single-stepping is enabled (git-fixes)
- commit 080c096
* Mon Jul 18 2022 iivanov@suse.de
- arm64: ptrace: Consistently use pseudo-singlestep exceptions (git-fixes)
- commit ddc1d85
* Mon Jul 18 2022 iivanov@suse.de
- KVM: arm64: Fix definition of PAGE_HYP_DEVICE (git-fixes)
- commit aff711b
* Mon Jul 18 2022 iivanov@suse.de
- arm64: perf: Report the PC value in REGS_ABI_32 mode (git-fixes)
- commit d286e63
* Mon Jul 18 2022 iivanov@suse.de
- arm64: dts: marvell: armada-37xx: Set pcie_reset_pin to gpio function (git-fixes)
- commit 437cb00
* Mon Jul 18 2022 oneukum@suse.com
- usb: typec: add missing uevent when partner support PD
  (git-fixes).
- commit 8f7dacd
* Mon Jul 18 2022 oneukum@suse.com
- usb: dwc3: gadget: Fix event pending check (git-fixes).
- commit 052f747
* Mon Jul 18 2022 oneukum@suse.com
- blacklist.conf: will speed up booting in exchange for breaking charging
  from a switched off laptop with some firmwares
- commit bd8e45d
* Mon Jul 18 2022 oneukum@suse.com
- blacklist.conf: build fix that does not matter on a released kernel
- commit 3296a39
* Mon Jul 18 2022 oneukum@suse.com
- net: usb: qmi_wwan: add Telit 0x1070 composition (git-fixes).
- commit a69d674
* Mon Jul 18 2022 oneukum@suse.com
- net: usb: qmi_wwan: add Telit 0x1060 composition (git-fixes).
- commit 1caf14d
* Mon Jul 18 2022 bp@suse.de
- Sort in RETbleed backport into the sorted section
  Now that it is upstream..
- Refresh
  patches.suse/KVM-VMX-Convert-launched-argument-to-flags.patch.
- Refresh
  patches.suse/KVM-VMX-Fix-IBRS-handling-after-vmexit.patch.
- Refresh patches.suse/KVM-VMX-Flatten-__vmx_vcpu_run.patch.
- Refresh
  patches.suse/KVM-VMX-Prevent-RSB-underflow-before-vmenter.patch.
- Refresh
  patches.suse/KVM-VMX-Prevent-guest-RSB-poisoning-attacks-with-eIBRS.patch.
- Refresh
  patches.suse/KVM-x86-speculation-Disable-Fill-buffer-clear-within-guests.patch.
- Refresh
  patches.suse/intel_idle-Disable-IBRS-during-long-idle.patch.
- Refresh patches.suse/x86-Add-magic-AMD-return-thunk.patch.
- Refresh patches.suse/x86-Undo-return-thunk-damage.patch.
- Refresh patches.suse/x86-Use-return-thunk-in-asm-code.patch.
- Refresh patches.suse/x86-bpf-Use-alternative-RET-encoding.patch.
- Refresh
  patches.suse/x86-bugs-Add-AMD-retbleed-boot-parameter.patch.
- Refresh
  patches.suse/x86-bugs-Add-Cannon-lake-to-RETBleed-affected-CPU-list.patch.
- Refresh patches.suse/x86-bugs-Add-retbleed-ibpb.patch.
- Refresh
  patches.suse/x86-bugs-Do-IBPB-fallback-check-only-once.patch.
- Refresh
  patches.suse/x86-bugs-Do-not-enable-IBPB-on-entry-when-IBPB-is-not-supp.patch.
- Refresh patches.suse/x86-bugs-Enable-STIBP-for-JMP2RET.patch.
- Refresh
  patches.suse/x86-bugs-Group-MDS-TAA-Processor-MMIO-Stale-Data-mitigations.patch.
- Refresh
  patches.suse/x86-bugs-Keep-a-per-CPU-IA32_SPEC_CTRL-value.patch.
- Refresh
  patches.suse/x86-bugs-Optimize-SPEC_CTRL-MSR-writes.patch.
- Refresh
  patches.suse/x86-bugs-Report-AMD-retbleed-vulnerability.patch.
- Refresh
  patches.suse/x86-bugs-Report-Intel-retbleed-vulnerability.patch.
- Refresh
  patches.suse/x86-bugs-Split-spectre_v2_select_mitigation-and-spectre_v2.patch.
- Refresh
  patches.suse/x86-common-Stamp-out-the-stepping-madness.patch.
- Refresh patches.suse/x86-cpu-amd-Add-Spectral-Chicken.patch.
- Refresh patches.suse/x86-cpu-amd-Enumerate-BTC_NO.patch.
- Refresh
  patches.suse/x86-cpufeatures-Move-RETPOLINE-flags-to-word-11.patch.
- Refresh
  patches.suse/x86-entry-Add-kernel-IBRS-implementation.patch.
- Refresh
  patches.suse/x86-kvm-Fix-SETcc-emulation-for-return-thunks.patch.
- Refresh patches.suse/x86-retpoline-Use-mfunction-return.patch.
- Refresh
  patches.suse/x86-sev-Avoid-using-__x86_return_thunk.patch.
- Refresh
  patches.suse/x86-speculation-Add-a-common-function-for-MD_CLEAR-mitigation-update.patch.
- Refresh
  patches.suse/x86-speculation-Add-spectre_v2-ibrs-option-to-support-Kern.patch.
- Refresh
  patches.suse/x86-speculation-Fill-RSB-on-vmexit-for-IBRS.patch.
- Refresh
  patches.suse/x86-speculation-Fix-SPEC_CTRL-write-on-SMT-state-change.patch.
- Refresh
  patches.suse/x86-speculation-Fix-firmware-entry-SPEC_CTRL-handling.patch.
- Refresh
  patches.suse/x86-speculation-Remove-x86_spec_ctrl_mask.patch.
- Refresh
  patches.suse/x86-speculation-Use-cached-host-SPEC_CTRL-value-for-guest-.patch.
- Refresh
  patches.suse/x86-speculation-mmio-Add-mitigation-for-Processor-MMIO-Stale-Data.patch.
- Refresh
  patches.suse/x86-speculation-mmio-Add-sysfs-reporting-for-Processor-MMIO-Stale-Data.patch.
- Refresh
  patches.suse/x86-speculation-mmio-Enable-CPU-Fill-buffer-clearing-on-idle.patch.
- Refresh
  patches.suse/x86-speculation-mmio-Enumerate-Processor-MMIO-Stale-Data-bug.patch.
- Refresh
  patches.suse/x86-speculation-mmio-Reuse-SRBDS-mitigation-for-SBDS.patch.
- Refresh
  patches.suse/x86-speculation-srbds-Update-SRBDS-mitigation-selection.patch.
- Refresh
  patches.suse/x86-vsyscall_emu-64-Don-t-use-RET-in-vsyscall-emulation.patch.
- Refresh patches.suse/x86-xen-Rename-SYS-entry-points.patch.
- commit 94dfede
* Mon Jul 18 2022 iivanov@suse.de
- arm64: dts: marvell: espressobin: add ethernet alias (git-fixes)
- commit ed82a39
* Mon Jul 18 2022 oneukum@suse.com
- blacklist.conf: blocks a driver from building
- commit 2f8d19f
* Mon Jul 18 2022 iivanov@suse.de
- arm64: dts: mcbin: support 2W SFP modules (git-fixes)
- commit 1950671
* Mon Jul 18 2022 iivanov@suse.de
- arm64: lib: Use modern annotations for assembly functions (git-fixes)
  Refresh patches.suse/arm64-clear_page-shouldn-t-use-DC-ZVA-when-DCZID_EL0.DZP-1.patch.
- commit fb5a868
* Mon Jul 18 2022 oneukum@suse.com
- spi: <linux/spi/spi.h>: add missing struct kernel-doc entry
  (git-fixes).
- Refresh
  patches.kabi/move-devm_allocate-to-end-of-structure-for-kABI.patch.
- commit 8e36894
* Mon Jul 18 2022 iivanov@suse.de
- arm64: asm: Add new-style position independent function annotations (git-fixes)
- commit a5d53f5
* Mon Jul 18 2022 oneukum@suse.com
- usbnet: fix memory leak in error case (git-fixes).
- commit 988ba16
* Mon Jul 18 2022 iivanov@suse.de
- arm64: module: rework special section handling (git-fixes)
- commit 7d368bc
* Mon Jul 18 2022 osalvador@suse.de
- Rename colliding patches before the next origin/cve/linux-5.3 -> SLE15-SP3 merge
- commit fb0447a
* Mon Jul 18 2022 colyli@suse.de
- dm mirror log: round up region bitmap size to BITS_PER_LONG
  (git-fixes).
- md: bcache: check the return value of kzalloc() in
  detached_dev_do_request() (git-fixes).
- dm crypt: make printing of the key constant-time (git-fixes).
- dm integrity: fix error code in dm_integrity_ctr() (git-fixes).
- dm stats: add cond_resched when looping over entries
  (git-fixes).
- md/raid0: Ignore RAID0 layout if the second zone has only one
  device (git-fixes).
- hex2bin: make the function hex_to_bin constant-time (git-fixes).
- dm integrity: fix memory corruption when tag_size is less than
  digest size (git-fixes).
- block/compat_ioctl: fix range check in BLKGETSIZE (git-fixes).
- dm crypt: fix get_key_size compiler warning if !CONFIG_KEYS
  (git-fixes).
- block: don't delete queue kobject before its children
  (git-fixes).
- block: bio-integrity: Advance seed correctly for larger interval
  sizes (git-fixes).
- block: Fix wrong offset in bio_truncate() (git-fixes).
- block: Fix fsync always failed if once failed (git-fixes).
- dm btree remove: fix use after free in rebalance_children()
  (git-fixes).
- dm: fix mempool NULL pointer race when completing IO
  (git-fixes).
- dm crypt: Avoid percpu_counter spinlock contention in
  crypt_page_alloc() (git-fixes).
- blk-zoned: allow BLKREPORTZONE without CAP_SYS_ADMIN
  (git-fixes).
- blk-zoned: allow zone management send operations without
  CAP_SYS_ADMIN (git-fixes).
- dm btree remove: assign new_root only when removal succeeds
  (git-fixes).
- dm snapshot: properly fix a crash when an origin has no
  snapshots (git-fixes).
- dm snapshot: fix crash with transient storage and zero chunk
  size (git-fixes).
- dm raid: fix inconclusive reshape layout on fast raid4/5/6
  table reload sequences (git-fixes).
- dm space map common: fix division bug in sm_ll_find_free_block()
  (git-fixes).
- dm persistent data: packed struct should have an aligned()
  attribute too (git-fixes).
- md/bitmap: wait for external bitmap writes to complete during
  tear down (git-fixes).
- dm verity: fix FEC for RS roots unaligned to block size
  (git-fixes).
- dm bufio: subtract the number of initial sectors in
  dm_bufio_get_device_size (git-fixes).
- md: Set prev_flush_start and flush_bio in an atomic way
  (git-fixes).
- dm integrity: conditionally disable "recalculate" feature
  (git-fixes).
- dm integrity: fix a crash if "recalculate" used without
  "internal_hash" (git-fixes).
- dm integrity: fix the maximum number of arguments (git-fixes).
- dm snapshot: flush merged data before committing metadata
  (git-fixes).
- lib/string.c: implement stpcpy (git-fixes).
- commit ab41893
* Fri Jul 15 2022 jgross@suse.com
- xen/netback: avoid entering xenvif_rx_next_skb() with an empty
  rx queue (bsc#1201381).
- commit ae4d431
* Fri Jul 15 2022 duwe@suse.de
- Refresh
  patches.suse/crypto-qat-remove-dma_free_coherent-for-DH.patch.
  revert the effect of mainline 453431a54934d917153 on patch.
- Refresh
  patches.suse/crypto-qat-remove-dma_free_coherent-for-RSA.patch.
  revert the effect of mainline 453431a54934d917153 on patch.
- commit 5e710e7
* Fri Jul 15 2022 duwe@suse.de
- crypto: qat - remove dma_free_coherent() for DH (git-fixes).
- crypto: qat - remove dma_free_coherent() for RSA (git-fixes).
- crypto: qat - fix memory leak in RSA (git-fixes).
- crypto: qat - set to zero DH parameters before free (git-fixes).
- crypto: qat - disable registration of algorithms (git-fixes).
- commit 8d18bba
* Thu Jul 14 2022 jeffm@suse.com
- rpm/kernel-binary.spec.in: Require dwarves >= 1.22 on SLE15-SP3 or newer
  Dwarves 1.22 or newer is required to build kernels with BTF information
  embedded in modules.
- commit 2dbbe9d
* Thu Jul 14 2022 jeffm@suse.com
- scripts: dummy-tools, add pahole (jsc#SLE-24559).
- commit 6a3fc85
* Thu Jul 14 2022 jslaby@suse.cz
- pty: do tty_flip_buffer_push without port->lock in pty_write
  (bsc#1198829 CVE-2022-1462).
- commit ce8f318
* Thu Jul 14 2022 jslaby@suse.cz
- tty: use new tty_insert_flip_string_and_push_buffer() in
  pty_write() (bsc#1198829 CVE-2022-1462).
- tty: extract tty_flip_buffer_commit() from
  tty_flip_buffer_push() (bsc#1198829 CVE-2022-1462).
- commit cbf8ad3
* Thu Jul 14 2022 jeffm@suse.com
- bpf: Add config to allow loading modules with BTF mismatches (jsc#SLE-24559).
- Update config files:
  - MODULE_ALLOW_BTF_MISMATCH=y
- commit 0660602
* Thu Jul 14 2022 jeffm@suse.com
- bpf: Keep module's btf_data_size intact after load (jsc#SLE-24559).
- Refresh
  patches.kabi/kabi-create-module-private-struct-to-hold-btf-size-data.patch.
- commit 6a4211c
* Thu Jul 14 2022 jeffm@suse.com
- bpf: Sanitize BTF data pointer after module is loaded (jsc#SLE-24559).
- Refresh
  patches.kabi/kabi-create-module-private-struct-to-hold-btf-size-data.patch.
- commit ec84a18
* Thu Jul 14 2022 jeffm@suse.com
- kbuild: Skip module BTF generation for out-of-tree external
  modules (jsc#SLE-24559).
- commit b411a90
* Thu Jul 14 2022 jeffm@suse.com
- bpf: Load and verify kernel module BTFs (jsc#SLE-24559).
- kabi: create module private struct to hold btf size/data (jsc#SLE-24559).
- commit dd48d54
* Thu Jul 14 2022 jeffm@suse.com
- kbuild: Build kernel module BTFs if BTF is enabled and pahole
  supports it (jsc#SLE-24559).
- Update config files:
  - PAHOLE_HAS_SPLIT_BTF=y
  - DEBUG_INFO_BTF_MODULES=y
- commit 00469b9
* Thu Jul 14 2022 jeffm@suse.com
- bpf: Assign ID to vmlinux BTF and return extra info for BTF
  in GET_OBJ_INFO (jsc#SLE-24559).
- commit bf525c4
* Thu Jul 14 2022 jeffm@suse.com
- bpf: Add in-kernel split BTF support (jsc#SLE-24559).
- commit de75fe3
* Thu Jul 14 2022 jeffm@suse.com
- bpf: Provide function to get vmlinux BTF information (jsc#SLE-24559).
- Refresh
  patches.suse/bpf-Add-bpf_patch_call_args-prototype-to-include-lin.patch.
- commit 97960b8
* Thu Jul 14 2022 jeffm@suse.com
- kbuild: rename any-prereq to newer-prereqs (jsc#SLE-24559).
- commit d74c2bd
* Thu Jul 14 2022 jeffm@suse.com
- kbuild: drop $(wildcard $^) check in if_changed* for faster
  rebuild (jsc#SLE-24559).
- commit 2b23691
* Thu Jul 14 2022 jeffm@suse.com
- kbuild: split final module linking out into Makefile.modfinal (jsc#SLE-24559).
- Refresh
  patches.suse/0008-scripts-Coccinelle-script-for-namespace-dependencies.patch.
- Refresh
  patches.suse/0026-modpost-do-not-invoke-extra-modpost-for-nsdeps.patch.
- Refresh
  patches.suse/0028-modpost-dump-missing-namespaces-into-a-single-module.patch.
- Refresh
  patches.suse/0029-scripts-nsdeps-support-nsdeps-for-external-module-bu.patch.
- commit 860eb7e
* Thu Jul 14 2022 jeffm@suse.com
- kbuild: rebuild modules when module linker scripts are updated (jsc#SLE-24559).
- Refresh
  patches.suse/kbuild-stop-filtering-out-GCC_PLUGINS_CFLAGS-from-cc.patch.
- commit e48ca3e
* Thu Jul 14 2022 jeffm@suse.com
- kbuild: add marker for build log of *.mod.o (jsc#SLE-24559).
- commit 089d37f
* Wed Jul 13 2022 rgoldwyn@suse.com
- io_uring: fix fs->users overflow  (CVE-2022-1116, bsc#1199647).
- commit e8dfed6
* Tue Jul 12 2022 lduncan@suse.com
- scsi: sd: Fix potential NULL pointer dereference (git-fixes).
- scsi: scsi_debug: Sanity check block descriptor length in
  resp_mode_select() (git-fixes).
- scsi: core: Put LLD module refcnt after SCSI device is released
  (git-fixes).
- scsi: core: Retry I/O for Notify (Enable Spinup) Required error
  (git-fixes).
- scsi: core: Only put parent device if host state differs from
  SHOST_CREATED (git-fixes).
- scsi: core: Put .shost_dev in failure path if host state
  changes to RUNNING (git-fixes).
- scsi: core: Fix failure handling of scsi_add_host_with_dma()
  (git-fixes).
- scsi: core: Fix error handling of scsi_host_alloc() (git-fixes).
- scsi: ufs: handle cleanup correctly on devm_reset_control_get
  error (git-fixes).
- scsi: ufs: Release clock if DMA map fails (git-fixes).
- commit cad0d5f
* Mon Jul 11 2022 neilb@suse.de
- don't call utsname() after ->nsproxy is NULL (bsc#1201196).
- commit 12197a1
* Fri Jul  8 2022 bp@suse.de
- x86/kexec: Disable RET on kexec (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit ef1c2ca
* Fri Jul  8 2022 bp@suse.de
- x86/bugs: Do not enable IBPB-on-entry when IBPB is not supported
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- commit 41afdd9
* Fri Jul  8 2022 bp@suse.de
- x86/bugs: Add Cannon lake to RETBleed affected CPU list
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- commit 6b54061
* Fri Jul  8 2022 aabdallah@suse.de
- ibmvnic: Properly dispose of all skbs during a failover
  (bsc#1200925).
- commit 06221e8
* Thu Jul  7 2022 vbabka@suse.cz
- mm/slub: add missing TID updates on slab deactivation
  (git-fixes).
- commit af73675
* Wed Jul  6 2022 jgross@suse.com
- xen: detect uninitialized xenbus in xenbus_init (git-fixes).
- commit 89b5cfc
* Wed Jul  6 2022 jgross@suse.com
- xen: don't continue xenstore initialization in case of errors
  (git-fixes).
- commit a397042
* Wed Jul  6 2022 jgross@suse.com
- x86/kvmclock: Move this_cpu_pvti into kvmclock.h (git-fixes).
- commit 223f7ba
* Wed Jul  6 2022 jgross@suse.com
- KVM: x86/pmu: Fix UBSAN shift-out-of-bounds warning in
  intel_pmu_refresh() (git-fixes).
- commit 2a600a1
* Wed Jul  6 2022 jgross@suse.com
- KVM: nVMX: avoid NULL pointer dereference with incorrect EVMCS
  GPAs (git-fixes).
- commit a048eb5
* Wed Jul  6 2022 jgross@suse.com
- KVM: apic: avoid calculating pending eoi from an uninitialized
  val (git-fixes).
- commit bd607c6
* Wed Jul  6 2022 jgross@suse.com
- KVM: nVMX: handle nested posted interrupts when apicv is
  disabled for L1 (git-fixes).
- commit a486b7a
* Wed Jul  6 2022 jgross@suse.com
- KVM: x86: Refactor prefix decoding to prevent Spectre-v1/L1TF
  attacks (git-fixes).
- commit eb73c2f
* Wed Jul  6 2022 jgross@suse.com
- KVM: x86: Don't let userspace set host-reserved cr4 bits
  (git-fixes).
- commit 404b24a
* Wed Jul  6 2022 oneukum@suse.com
- net: hso: bail out on interrupt URB allocation failure
  (git-fixes).
- commit f562212
* Wed Jul  6 2022 oneukum@suse.com
- blacklist.conf: misattributed in upstream
- commit 202e210
* Wed Jul  6 2022 tiwai@suse.de
- net: rose: fix UAF bugs caused by timer handler (CVE-2022-2318
  bsc#1201251).
- commit 84c7e09
* Wed Jul  6 2022 tiwai@suse.de
- Update patch reference for rose fix (CVE-2022-2318 bsc#1201251)
- commit 4566057
* Wed Jul  6 2022 aabdallah@suse.de
- scsi: smartpqi: Update LUN reset handler (bsc#1200622).
- commit 8890fb5
* Wed Jul  6 2022 jgross@suse.com
- xen/netfront: force data bouncing when backend is untrusted
  (bsc#1200762, CVE-2022-33741, XSA-403).
- commit 7daee4f
* Wed Jul  6 2022 jgross@suse.com
- xen/netfront: fix leaking data in shared pages (bsc#1200762,
  CVE-2022-33740, XSA-403).
- commit bfb8cc2
* Wed Jul  6 2022 jgross@suse.com
- xen/blkfront: force data bouncing when backend is untrusted
  (bsc#1200762, CVE-2022-33742, XSA-403).
- commit 9c6c1df
* Wed Jul  6 2022 jgross@suse.com
- xen/blkfront: fix leaking data in shared pages (bsc#1200762,
  CVE-2022-26365, XSA-403).
- commit 7095954
* Tue Jul  5 2022 bp@suse.de
- x86/cpu/amd: Enumerate BTC_NO (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit b7a3331
* Tue Jul  5 2022 bp@suse.de
- x86/common: Stamp out the stepping madness (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit 3962a01
* Tue Jul  5 2022 bp@suse.de
- KVM: VMX: Prevent RSB underflow before vmenter (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit a2b7d09
* Tue Jul  5 2022 bp@suse.de
- x86/speculation: Fill RSB on vmexit for IBRS (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit fd58624
* Tue Jul  5 2022 bp@suse.de
- KVM: VMX: Fix IBRS handling after vmexit (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit 79152af
* Tue Jul  5 2022 bp@suse.de
- KVM: VMX: Prevent guest RSB poisoning attacks with eIBRS
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- commit f625aa5
* Tue Jul  5 2022 bp@suse.de
- KVM: VMX: Convert launched argument to flags (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit e0dd694
* Tue Jul  5 2022 bp@suse.de
- KVM/nVMX: Use __vmx_vcpu_run in nested_vmx_check_vmentry_hw
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- commit 528b21e
* Tue Jul  5 2022 bp@suse.de
- KVM: VMX: Flatten __vmx_vcpu_run() (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit 5c70c82
* Tue Jul  5 2022 bp@suse.de
- x86/speculation: Remove x86_spec_ctrl_mask (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit 4f79cdb
* Tue Jul  5 2022 bp@suse.de
- x86/speculation: Use cached host SPEC_CTRL value for guest
  entry/exit (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- commit 140d756
* Tue Jul  5 2022 bp@suse.de
- x86/speculation: Fix SPEC_CTRL write on SMT state change
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- commit 43488f5
* Tue Jul  5 2022 bp@suse.de
- x86/speculation: Fix firmware entry SPEC_CTRL handling
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- commit 410bedf
* Tue Jul  5 2022 bp@suse.de
- x86/cpu/amd: Add Spectral Chicken (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit 3ed82bb
* Tue Jul  5 2022 bp@suse.de
- x86/bugs: Do IBPB fallback check only once (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit 914bf03
* Tue Jul  5 2022 bp@suse.de
- x86/bugs: Add retbleed=ibpb (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit 0636a43
* Tue Jul  5 2022 tiwai@suse.de
- net: rose: fix UAF bugs caused by timer handler (git-fixes).
- net: usb: ax88179_178a: Fix packet receiving (git-fixes).
- usbnet: fix memory allocation in helpers (git-fixes).
- NFC: nxp-nci: Don't issue a zero length i2c_master_read()
  (git-fixes).
- nfc: nfcmrvl: Fix irq_of_parse_and_map() return value
  (git-fixes).
- linux/dim: Fix divide by 0 in RDMA DIM (git-fixes).
- virtio-net: fix race between ndo_open() and
  virtio_device_ready() (git-fixes).
- soc: bcm: brcmstb: pm: pm-arm: Fix refcount leak in
  brcmstb_pm_probe (git-fixes).
- iio: accel: mma8452: ignore the return value of reset operation
  (git-fixes).
- usb: chipidea: udc: check request status before setting device
  address (git-fixes).
- USB: serial: option: add Quectel RM500K module support
  (git-fixes).
- USB: serial: option: add Quectel EM05-G modem (git-fixes).
- USB: serial: option: add Telit LE910Cx 0x1250 composition
  (git-fixes).
- mtd: rawnand: gpmi: Fix setting busy timeout setting
  (git-fixes).
- regmap-irq: Fix a bug in regmap_irq_enable() for type_in_mask
  chips (git-fixes).
- virtio_net: fix xdp_rxq_info bug after suspend/resume
  (git-fixes).
- commit 3920c43
* Tue Jul  5 2022 tiwai@suse.de
- drivers: cpufreq: Add missing of_node_put() in qoriq-cpufreq.c
  (git-fixes).
- hwmon: (ibmaem) don't call platform_device_del() if
  platform_device_add() fails (git-fixes).
- caif_virtio: fix race between virtio_device_ready() and
  ndo_open() (git-fixes).
- iio: adc: vf610: fix conversion mode sysfs node name
  (git-fixes).
- iio:chemical:ccs811: rearrange iio trigger get and register
  (git-fixes).
- iio:accel:bma180: rearrange iio trigger get and register
  (git-fixes).
- iio: trigger: sysfs: fix use-after-free on remove (git-fixes).
- iio: gyro: mpu3050: Fix the error handling in mpu3050_power_up()
  (git-fixes).
- iio: adc: axp288: Override TS pin bias current for some models
  (git-fixes).
- gpio: winbond: Fix error code in winbond_gpio_get() (git-fixes).
- drm/msm/mdp4: Fix refcount leak in mdp4_modeset_init_intf
  (git-fixes).
- drm/msm: Fix double pm_runtime_disable() call (git-fixes).
- drm/sun4i: Fix crash during suspend after component bind failure
  (git-fixes).
- ata: libata: add qc->flags in ata_qc_complete_template
  tracepoint (git-fixes).
- ALSA: hda/realtek: Add quirk for Clevo PD70PNT (git-fixes).
- ALSA: hda/realtek - ALC897 headset MIC no sound (git-fixes).
- commit aa4e5a5
* Tue Jul  5 2022 dwagner@suse.de
- block: Fix handling of offline queues in blk_mq_alloc_request_hctx() (bsc#1185762).
- blacklist.conf:
  remove this entry
- commit 6e5bc29
* Tue Jul  5 2022 dwagner@suse.de
- blk-mq: drop workarounds for cpu hotplug queue management (bsc#1185762)
  This patches never made it to mainline. Instead a simpler solution was
  added upstream 14dc7a18abbe ("block: Fix handling of offline queues in
  blk_mq_alloc_request_hctx().
- commit a4e1276
* Tue Jul  5 2022 oneukum@suse.com
- blacklist.conf: breaks kABI in an unfixable manner
- commit de9d595
* Tue Jul  5 2022 dwagner@suse.de
- kabi: nvme workaround header include (bsc#1201193).
- commit 1e4257b
* Tue Jul  5 2022 bp@suse.de
- x86/xen: Rename SYS* entry points (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit b3da909
* Tue Jul  5 2022 bp@suse.de
- intel_idle: Disable IBRS during long idle (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit bff00e1
* Tue Jul  5 2022 oneukum@suse.com
- xhci: Add reset resume quirk for AMD xhci controller
  (git-fixes).
- commit 144d367
* Tue Jul  5 2022 bp@suse.de
- x86/bugs: Report Intel retbleed vulnerability (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit 9a4b6fa
* Tue Jul  5 2022 oneukum@suse.com
- usb: xhci: Workaround for S3 issue on AMD SNPS 3.0 xHC
  (git-fixes).
- Refresh
  patches.suse/usb-pci-quirks-disable-D3cold-on-xhci-suspend-for-s2.patch.
- Refresh
  patches.suse/usb-xhci-do-not-perform-Soft-Retry-for-some-xHCI-hos.patch.
- commit 1d0d070
* Tue Jul  5 2022 bp@suse.de
- x86/bugs: Split spectre_v2_select_mitigation() and
  spectre_v2_user_select_mitigation() (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit eda1e45
* Tue Jul  5 2022 bp@suse.de
- x86/speculation: Add spectre_v2=ibrs option to support Kernel
  IBRS (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- commit c12a655
* Tue Jul  5 2022 bp@suse.de
- x86/bugs: Optimize SPEC_CTRL MSR writes (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit 94eb4a2
* Tue Jul  5 2022 bp@suse.de
- x86/entry: Add kernel IBRS implementation (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit 7077b17
* Tue Jul  5 2022 bp@suse.de
- x86/bugs: Keep a per-CPU IA32_SPEC_CTRL value (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit c21cae3
* Tue Jul  5 2022 tiwai@suse.de
- netfilter: nf_tables: stricter validation of element data
  (CVE-2022-34918 bsc#1201171).
- commit d3cb893
* Tue Jul  5 2022 dwagner@suse.de
- scsi: nvme: Added a new sysfs attribute appid_store
  (bsc#1201193).
- commit 946af0d
* Tue Jul  5 2022 hare@suse.de
- blacklist.conf: update
- blacklist.conf: Add new commit
- commit 6c8c02b
* Tue Jul  5 2022 hare@suse.de
- block/keyslot-manager: prevent crash when num_slots=1
  (git-fixes).
- blk-cgroup: fix a hd_struct leak in blkcg_fill_root_iostats
  (git-fixes).
- commit ef13f5c
* Tue Jul  5 2022 hare@suse.de
- nvmet: fix freeing unallocated p2pmem (git-fixes).
- nvmet-rdma: Fix NULL deref when SEND is completed with error
  (git-fixes).
- nvmet-rdma: Fix NULL deref when setting pi_enable and traddr
  INADDR_ANY (git-fixes).
- commit ad1ec47
* Tue Jul  5 2022 hare@suse.de
- blacklist.conf: Add nvmet patch
- commit f8744f6
* Tue Jul  5 2022 hare@suse.de
- nvme-tcp: fix H2CData PDU send accounting (again) (git-fixes).
- commit 781a006
* Mon Jul  4 2022 bp@suse.de
- x86/bugs: Enable STIBP for JMP2RET (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit 3a3473f
* Mon Jul  4 2022 bp@suse.de
- x86/bugs: Add AMD retbleed= boot parameter (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- Update config files.
- commit 89f84ec
* Mon Jul  4 2022 bp@suse.de
- x86/bugs: Report AMD retbleed vulnerability (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit 13522d3
* Mon Jul  4 2022 bp@suse.de
- x86: Add magic AMD return-thunk (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit b13e1ec
* Mon Jul  4 2022 bp@suse.de
- x86: Use return-thunk in asm code (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit ba20e78
* Mon Jul  4 2022 bp@suse.de
- x86/sev: Avoid using __x86_return_thunk (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit e26025b
* Mon Jul  4 2022 bp@suse.de
- x86/vsyscall_emu/64: Don't use RET in vsyscall emulation
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- commit a16eea7
* Mon Jul  4 2022 bp@suse.de
- x86/kvm: Fix SETcc emulation for return thunks (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit 1744d2e
* Mon Jul  4 2022 bp@suse.de
- x86/bpf: Use alternative RET encoding (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit 3599ff8
* Mon Jul  4 2022 bp@suse.de
- x86: Undo return-thunk damage (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit 9c190f7
* Mon Jul  4 2022 dwagner@suse.de
- scsi: lpfc: Update lpfc version to 14.2.0.4 (bsc#1201193).
- scsi: lpfc: Allow reduced polling rate for
  nvme_admin_async_event cmd completion (bsc#1201193).
- scsi: lpfc: Add more logging of cmd and cqe information for
  aborted NVMe cmds (bsc#1201193).
- scsi: lpfc: Fix port stuck in bypassed state after LIP in
  PT2PT topology (bsc#1201193).
- scsi: lpfc: Resolve NULL ptr dereference after an ELS LOGO is
  aborted (bsc#1201193).
- scsi: lpfc: Address NULL pointer dereference after
  starget_to_rport() (bsc#1201193).
- scsi: lpfc: Resolve some cleanup issues following SLI path
  refactoring (bsc#1201193).
- scsi: lpfc: Resolve some cleanup issues following abort path
  refactoring (bsc#1201193).
- scsi: lpfc: Correct BDE type for XMIT_SEQ64_WQE in
  lpfc_ct_reject_event() (bsc#1201193).
- scsi: lpfc: Add support for ATTO Fibre Channel devices
  (bsc#1201193).
- scsi: lpfc: Add support for VMID tagging of NVMe I/Os
  (bsc#1201193).
- scsi: lpfc: Rework lpfc_vmid_get_appid() to be protocol
  independent (bsc#1201193).
- scsi: lpfc: Commonize VMID code location (bsc#1201193).
- scsi: nvme-fc: Add new routine nvme_fc_io_getuuid()
  (bsc#1201193).
- commit 7f7c840
* Mon Jul  4 2022 denis.kirjanov@suse.com
- net: stmmac: reset Tx desc base address before restarting Tx
  (git-fixes).
- commit db66d0c
* Mon Jul  4 2022 denis.kirjanov@suse.com
- net: lantiq: Add locking for TX DMA channel (git-fixes).
- commit 021df50
* Mon Jul  4 2022 denis.kirjanov@suse.com
- net: ethernet: stmmac: Disable hardware multicast filter
  (git-fixes).
- commit 36ce5b8
* Mon Jul  4 2022 denis.kirjanov@suse.com
- sunvnet: use icmp_ndo_send helper (git-fixes).
- commit 22762aa
* Mon Jul  4 2022 denis.kirjanov@suse.com
- gtp: use icmp_ndo_send helper (git-fixes).
- commit b9a3ced
* Mon Jul  4 2022 denis.kirjanov@suse.com
- veth: fix races around rq->rx_notify_masked (git-fixes).
- commit c90500d
* Mon Jul  4 2022 denis.kirjanov@suse.com
- net: ieee802154: ca8210: Stop leaking skb's (git-fixes).
- commit 8c700c0
* Mon Jul  4 2022 denis.kirjanov@suse.com
- Update config files.
- commit d2069d8
* Mon Jul  4 2022 dwagner@suse.de
- scsi: qla2xxx: Update version to 10.02.07.700-k (bsc#1201160).
- scsi: qla2xxx: Fix erroneous mailbox timeout after PCI error
  injection (bsc#1201160).
- scsi: qla2xxx: Fix losing FCP-2 targets on long port disable
  with I/Os (bsc#1201160).
  Refresh:
  - patches.suse/revert-scsi-qla2xxx-Changes-to-support-FCP2-Target.patch
- scsi: qla2xxx: Add debug prints in the device remove path
  (bsc#1201160).
- scsi: qla2xxx: Fix losing target when it reappears during delete
  (bsc#1201160).
- scsi: qla2xxx: Fix losing FCP-2 targets during port perturbation
  tests (bsc#1201160).
- scsi: qla2xxx: Fix crash due to stale SRB access around I/O
  timeouts (bsc#1201160).
- scsi: qla2xxx: Turn off multi-queue for 8G adapters
  (bsc#1201160).
- scsi: qla2xxx: Wind down adapter after PCIe error (bsc#1201160).
- scsi: qla2xxx: Add a new v2 dport diagnostic feature
  (bsc#1201160).
- scsi: qla2xxx: Fix excessive I/O error messages by default
  (bsc#1201160).
- scsi: qla2xxx: Update version to 10.02.07.600-k (bsc#1201160).
- scsi: qla2xxx: edif: Fix slow session teardown (bsc#1201160).
- scsi: qla2xxx: edif: Reduce N2N thrashing at app_start time
  (bsc#1201160).
- scsi: qla2xxx: edif: Fix no logout on delete for N2N
  (bsc#1201160).
- scsi: qla2xxx: edif: Fix session thrash (bsc#1201160).
- scsi: qla2xxx: edif: Tear down session if keys have been removed
  (bsc#1201160).
- scsi: qla2xxx: edif: Fix no login after app start (bsc#1201160).
- scsi: qla2xxx: edif: Reduce disruption due to multiple app start
  (bsc#1201160).
- scsi: qla2xxx: edif: Send LOGO for unexpected IKE message
  (bsc#1201160).
- scsi: qla2xxx: edif: Fix I/O timeout due to over-subscription
  (bsc#1201160).
- scsi: qla2xxx: Update version to 10.02.07.500-k (bsc#1201160).
- scsi: qla2xxx: edif: Fix n2n login retry for secure device
  (bsc#1201160).
- scsi: qla2xxx: edif: Fix n2n discovery issue with secure target
  (bsc#1201160).
- scsi: qla2xxx: edif: Remove old doorbell interface
  (bsc#1201160).
- scsi: qla2xxx: edif: Add retry for ELS passthrough
  (bsc#1201160).
- scsi: qla2xxx: edif: Synchronize NPIV deletion with
  authentication application (bsc#1201160).
- scsi: qla2xxx: edif: Fix potential stuck session in sa update
  (bsc#1201160).
- scsi: qla2xxx: edif: Add bsg interface to read doorbell events
  (bsc#1201160).
- scsi: qla2xxx: edif: Wait for app to ack on sess down
  (bsc#1201160).
- scsi: qla2xxx: edif: bsg refactor (bsc#1201160).
- scsi: qla2xxx: edif: Reduce Initiator-Initiator thrashing
  (bsc#1201160).
- commit d2cb0ed
* Mon Jul  4 2022 hare@suse.de
- Revert "block: Fix a lockdep complaint triggered by request
  queue flushing" (git-fixes).
- commit 4eca7cd
* Mon Jul  4 2022 dwagner@suse.de
- scsi: qla2xxx: Remove unused 'ql_dm_tgt_ex_pct' parameter
  (bsc#1201160).
- scsi: qla2xxx: Remove setting of 'req' and 'rsp' parameters
  (bsc#1201160).
- commit 4780b01
* Mon Jul  4 2022 hare@suse.de
- nvme-multipath: set nr_zones for zoned namespaces (git-fixes). - Refresh patches.suse/nvme-fix-refcounting-imbalance-when-all-paths-are-do.patch.
- commit 76d2349
* Mon Jul  4 2022 lhenriques@suse.de
- ceph: clean up locking annotation for ceph_get_snap_realm and
  __lookup_snap_realm (bsc#1201149).
- Refresh
  patches.suse/ceph-take-snap_empty_lock-atomically-with-snaprealm-refcount-change.patch.
- commit d26c619
* Mon Jul  4 2022 lhenriques@suse.de
- ceph: add some lockdep assertions around snaprealm handling
  (bsc#1201147).
- Refresh
  patches.suse/ceph-take-snap_empty_lock-atomically-with-snaprealm-refcount-change.patch.
- commit 2f1c9fc
* Mon Jul  4 2022 hare@suse.de
- blacklist.conf: add commit
- commit aaeabea
* Mon Jul  4 2022 bp@suse.de
- x86/retpoline: Use -mfunction-return (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit 9a7c312
* Mon Jul  4 2022 lhenriques@suse.de
- fuse: annotate lock in fuse_reverse_inval_entry() (bsc#1201143).
- commit 8a0b165
* Mon Jul  4 2022 hare@suse.de
- bio: fix page leak bio_add_hw_page failure (git-fixes).
- blk-mq: update hctx->dispatch_busy in case of real scheduler (git-fixes).
- block: advance iov_iter on bio_add_hw_page failure (git-fixes).
- commit 7e67c38
* Mon Jul  4 2022 lhenriques@suse.de
- blacklist.conf: ignore documentation fix
- commit ea0880a
* Mon Jul  4 2022 hare@suse.de
- scsi: core: Show SCMD_LAST in text form (git-fixes).
- commit d76d5ab
* Mon Jul  4 2022 hare@suse.de
- scsi: sd_zbc: Support disks with more than 2**32 logical
  (git-fixes).
- scsi: sd_zbc: Ensure buffer size is aligned to SECTOR_SIZE
  (git-fixes).
- scsi: sd: sd_zbc: Don't pass GFP_NOIO to kvcalloc (git-fixes).
- commit 29c91b5
* Mon Jul  4 2022 bp@suse.de
- x86/cpufeatures: Move RETPOLINE flags to word 11 (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit ea71447
* Mon Jul  4 2022 bp@suse.de
- crypto: x86/poly1305 - Fixup SLS (bsc#1201050 CVE-2021-26341).
- commit af7f65a
* Mon Jul  4 2022 hare@suse.de
- scsi: sd: sd_zbc: Fix ZBC disk initialization (git-fixes).
- commit 9db78a9
* Mon Jul  4 2022 hare@suse.de
- scsi: sd: sd_zbc: Fix handling of host-aware ZBC disks
  (git-fixes).
- blacklist.conf: Remove entry from blacklist
- commit 5cb2eb0
* Mon Jul  4 2022 hare@suse.de
- scsi: sd_zbc: Improve zone revalidation (git-fixes).
- scsi: sd_zbc: Don't limit max_zone_append sectors to
  (git-fixes).
- scsi: sd_zbc: Remove unused inline functions (git-fixes).
- scsi: sd: Signal drive managed SMR disks (git-fixes).
- commit 6f51c10
* Mon Jul  4 2022 bp@suse.de
- x86: Add straight-line-speculation mitigation (bsc#1201050
  CVE-2021-26341).
- Update config files.
- Refresh
  patches.suse/x86-speculation-rename-retpoline_amd-to-retpoline_lfence.patch.
- commit d2ed44a
* Sun Jul  3 2022 bp@suse.de
- x86/alternative: Relax text_poke_bp() constraint (bsc#1201050
  CVE-2021-26341).
- commit 2e7822c
* Sun Jul  3 2022 bp@suse.de
- x86/alternatives: Teach text_poke_bp() to emulate RET
  (bsc#1201050 CVE-2021-26341).
- commit 4eb3542
* Sun Jul  3 2022 bp@suse.de
- x86/alternatives: Implement a better poke_int3_handler()
  completion scheme (bsc#1201050 CVE-2021-26341).
- commit cf0f438
* Sun Jul  3 2022 bp@suse.de
- x86/alternative: Shrink text_poke_loc (bsc#1201050
  CVE-2021-26341).
- commit db3f434
* Sun Jul  3 2022 bp@suse.de
- x86/alternative: Remove text_poke_loc::len (bsc#1201050
  CVE-2021-26341).
- commit 90aebc8
* Sun Jul  3 2022 bp@suse.de
- x86/alternative: Add text_opcode_size() (bsc#1201050
  CVE-2021-26341).
- commit 83d7faa
* Sun Jul  3 2022 bp@suse.de
- x86/alternatives: Add and use text_gen_insn() helper
  (bsc#1201050 CVE-2021-26341).
- commit 5121e4e
* Sun Jul  3 2022 bp@suse.de
- x86/alternatives, jump_label: Provide better text_poke()
  batching interface (bsc#1201050 CVE-2021-26341).
- commit 1b220c6
* Sun Jul  3 2022 bp@suse.de
- x86: Prepare inline-asm for straight-line-speculation
  (bsc#1201050 CVE-2021-26341).
- commit 6687132
* Sun Jul  3 2022 bp@suse.de
- x86: Prepare asm files for straight-line-speculation
  (bsc#1201050 CVE-2021-26341).
- commit f2fec2e
* Sun Jul  3 2022 bp@suse.de
- x86/lib/atomic64_386_32: Rename things (bsc#1201050
  CVE-2021-26341).
- commit 88d97d1
* Sun Jul  3 2022 bp@suse.de
- x86: Use -mindirect-branch-cs-prefix for RETPOLINE builds
  (bsc#1201050 CVE-2021-26341).
- commit 59b7688
* Thu Jun 30 2022 denis.kirjanov@suse.com
- Update metadata references
- commit 45bbc74
* Thu Jun 30 2022 oneukum@suse.com
- usb: gadget: u_ether: fix regression in setting fixed MAC
  address (git-fixes).
- commit 23f9eaa
* Thu Jun 30 2022 oneukum@suse.com
- move devm_allocate to end of structure for kABI (git-fixes).
- commit 39ff4a9
* Thu Jun 30 2022 oneukum@suse.com
- spi: Fix use-after-free with devm_spi_alloc_* (git-fixes).
- commit 531527e
* Mon Jun 27 2022 denis.kirjanov@suse.com
- sctp: handle kABI change in struct sctp_endpoint (CVE-2022-20154
  bsc#1200599).
- commit b1e8eec
* Mon Jun 27 2022 denis.kirjanov@suse.com
- sctp: use call_rcu to free endpoint (CVE-2022-20154
  bsc#1200599).
- commit 44ec44b
* Mon Jun 27 2022 otto.hollmann@suse.com
- kABI fix of sysctl_run_estimation (git-fixes).
- ipvs: add sysctl_run_estimation to support disable estimation
  (bsc#1195504).
- commit 326d103
* Sat Jun 25 2022 colyli@suse.de
- bcache: avoid unnecessary soft lockup in kworker
  update_writeback_rate() (bsc#1197362).
- bcache: memset on stack variables in bch_btree_check() and
  bch_sectors_dirty_init() (git-fixes).
- bcache: avoid journal no-space deadlock by reserving 1 journal
  bucket (git-fixes).
- bcache: remove incremental dirty sector counting for
  bch_sectors_dirty_init() (git-fixes).
- bcache: improve multithreaded bch_sectors_dirty_init()
  (git-fixes).
- bcache: improve multithreaded bch_btree_check() (git-fixes).
- nvdimm: Fix firmware activation deadlock scenarios (git-fixes).
- nvdimm/region: Fix default alignment for small regions
  (git-fixes).
- bcache: fixup multiple threads crash (git-fixes).
- md: fix update super 1.0 on rdev size change (git-fixes).
- commit 702bf9b
* Fri Jun 24 2022 jack@suse.cz
- Fixup !CONFIG_BLK_CGROUP build in
  patches.suse/block-don-t-merge-across-cgroup-boundaries-if-blkcg-.patch.
- commit bfec8fb
* Fri Jun 24 2022 tiwai@suse.de
- phy: aquantia: Fix AN when higher speeds than 1G are not
  advertised (git-fixes).
- ALSA: hda/via: Fix missing beep setup (git-fixes).
- ALSA: hda/conexant: Fix missing beep setup (git-fixes).
- bus: fsl-mc-bus: fix KASAN use-after-free in fsl_mc_bus_remove()
  (git-fixes).
- i2c: designware: Use standard optional ref clock implementation
  (git-fixes).
- tty: goldfish: Fix free_irq() on remove (git-fixes).
- usb: gadget: lpc32xx_udc: Fix refcount leak in lpc32xx_udc_probe
  (git-fixes).
- usb: dwc2: Fix memory leak in dwc2_hcd_init (git-fixes).
- USB: serial: option: add support for Cinterion MV31 with new
  baseline (git-fixes).
- USB: serial: io_ti: add Agilent E5805A support (git-fixes).
- virtio-mmio: fix missing put_device() when vm_cmdline_parent
  registration failed (git-fixes).
- ata: libata-core: fix NULL pointer deref in
  ata_host_alloc_pinfo() (git-fixes).
- ALSA: hda/realtek - Add HW8326 support (git-fixes).
- ASoC: wm_adsp: Fix event generation for wm_adsp_fw_put()
  (git-fixes).
- ASoC: es8328: Fix event generation for deemphasis control
  (git-fixes).
- ASoC: wm8962: Fix suspend while playing music (git-fixes).
- ASoC: cs42l56: Correct typo in minimum level for SX volume
  controls (git-fixes).
- ASoC: cs42l52: Correct TLV for Bypass Volume (git-fixes).
- ASoC: cs53l30: Correct number of volume levels on SX controls
  (git-fixes).
- ASoC: cs35l36: Update digital volume TLV (git-fixes).
- ASoC: cs42l52: Fix TLV scales for mixer controls (git-fixes).
- ASoC: nau8822: Add operation for internal PLL off and on
  (git-fixes).
- nfc: nfcmrvl: Fix memory leak in nfcmrvl_play_deferred
  (git-fixes).
- virtio-pci: Remove wrong address verification in vp_del_vqs()
  (git-fixes).
- commit 3c059bb
* Thu Jun 23 2022 iivanov@suse.de
- arm64: ftrace: fix branch range checks (git-fixes)
- commit 78ca39c
* Thu Jun 23 2022 jack@suse.cz
- block: Fix kABI in blk-merge.c (bsc#1198020).
- commit fa9f9d3
* Thu Jun 23 2022 jack@suse.cz
- ext4: add check to prevent attempting to resize an fs with
  sparse_super2 (bsc#1197754).
- commit 063f013
* Thu Jun 23 2022 dwagner@suse.de
- kabi/severities: ignore KABI for NVMe target (bsc#1192761)
  Exported symbols under drivers/nvme/target/ are only used by the
  nvmet subsystem itself.
- commit 60db37f
* Thu Jun 23 2022 jack@suse.cz
- blacklist.conf: Blacklist 14dc7a18abbe
- commit e3d2bff
* Thu Jun 23 2022 tbogendoerfer@suse.de
- vmxnet3: fix minimum vectors alloc issue (bsc#1199489).
- commit 5d5a2b9
* Thu Jun 23 2022 dwagner@suse.de
- nvme: kabi fix nvme subsystype change (bsc#1192761)
- commit e2cebc4
* Wed Jun 22 2022 jack@suse.cz
- blacklist.conf: Blacklist e583b5c472bd
- commit e1ae80a
* Wed Jun 22 2022 jack@suse.cz
- iomap: iomap_write_failed fix (bsc#1200829).
- commit c8ee717
* Wed Jun 22 2022 jack@suse.cz
- jfs: fix divide error in dbNextAG (bsc#1200828).
- commit 8668968
* Wed Jun 22 2022 jack@suse.cz
- ext4: make variable "count" signed (bsc#1200820).
- commit 8506661
* Wed Jun 22 2022 jack@suse.cz
- init: Initialize noop_backing_dev_info early (bsc#1200822).
- commit 9bcd180
* Wed Jun 22 2022 jack@suse.cz
- writeback: Fix inode->i_io_list not be protected by
  inode->i_lock error (bsc#1200821).
- commit 5276354
* Wed Jun 22 2022 jack@suse.cz
- blk-mq: do not update io_ticks with passthrough requests
  (bsc#1200816).
- commit 25cf6a6
* Wed Jun 22 2022 jack@suse.cz
- blacklist.conf: Blacklist 14362a254179 and e730558adffb
- commit 84080f8
* Wed Jun 22 2022 jack@suse.cz
- blacklist.conf: Blacklist 623af4f538b5
- commit e09c291
* Wed Jun 22 2022 jack@suse.cz
- inotify: show inotify mask flags in proc fdinfo (bsc#1200600).
- commit dd7c510
* Wed Jun 22 2022 jack@suse.cz
- Update tags in:
  patches.suse/bfq-Drop-pointless-unlock-lock-pair.patch.
  patches.suse/bfq-Get-rid-of-__bio_blkcg-usage.patch.
  patches.suse/bfq-Make-sure-bfqg-for-which-we-are-queueing-request.patch.
  patches.suse/bfq-Remove-pointless-bfq_init_rq-calls.patch.
  patches.suse/bfq-Split-shared-queues-on-move-between-cgroups.patch.
  patches.suse/bfq-Track-whether-bfq_group-is-still-online.patch.
  patches.suse/bfq-Update-cgroup-information-before-merging-bio.patch.
- commit fa82b91
* Wed Jun 22 2022 jack@suse.cz
- writeback: Avoid skipping inode writeback (bsc#1200813).
- commit fbc0033
* Wed Jun 22 2022 jack@suse.cz
- blk-iolatency: Fix inflight count imbalances and IO hangs on
  offline (bsc#1200825).
- commit 77a71d2
* Wed Jun 22 2022 jack@suse.cz
- block: don't merge across cgroup boundaries if blkcg is enabled
  (bsc#1198020).
- commit 08df09c
* Wed Jun 22 2022 jack@suse.cz
- ext4: fix bug_on ext4_mb_use_inode_pa (bsc#1200810).
- commit 90ad366
* Wed Jun 22 2022 jack@suse.cz
- ext4: fix bug_on in __es_tree_search (bsc#1200809).
- commit 599d1b0
* Wed Jun 22 2022 jack@suse.cz
- blacklist.conf: Blacklist cb8435dc8ba3
- commit 82be35e
* Wed Jun 22 2022 jack@suse.cz
- ext4: fix race condition between ext4_write and
  ext4_convert_inline_data (bsc#1200807).
- commit ab76d02
* Wed Jun 22 2022 jack@suse.cz
- ext4: limit length to bitmap_maxbytes - blocksize in punch_hole
  (bsc#1200806).
- commit 6fb9b0d
* Wed Jun 22 2022 dwagner@suse.de
- nvmet: register discovery subsystem as 'current' (bsc#1192761).
- nvmet: switch check for subsystem type (bsc#1192761).
- nvme: add new discovery log page entry definitions
  (bsc#1192761).
- nvme: display correct subsystem NQN (bsc#1192761).
- nvme: Add connect option 'discovery' (bsc#1192761).
  Refresh:
  - patches.suse/nvme-add-iopolicy-module-parameter.patch
- nvme: expose subsystem type in sysfs attribute 'subsystype'
  (bsc#1192761).
  Refresh:
  - patches.suse/nvme-add-iopolicy-module-parameter.patch
- nvmet: set 'CNTRLTYPE' in the identify controller data
  (bsc#1192761).
- nvmet: add nvmet_is_disc_subsys() helper (bsc#1192761).
- nvme: add CNTRLTYPE definitions for 'identify controller'
  (bsc#1192761).
- nvmet: make discovery NQN configurable (bsc#1192761).
- nvmet: don't check iosqes,iocqes for discovery controllers
  (bsc#1192761).
- nvmet: add nvmet_req_subsys() helper (bsc#1192761).
- commit 829b0a6
* Wed Jun 22 2022 jack@suse.cz
- blk-mq: clear active_queues before clearing
  BLK_MQ_F_TAG_QUEUE_SHARED (bsc#1200263).
- commit e0430df
* Wed Jun 22 2022 jslaby@suse.cz
- rpm/check-for-config-changes: ignore GCC12/CC_NO_ARRAY_BOUNDS
  Upstream commit f0be87c42cbd (gcc-12: disable '-Warray-bounds'
  universally for now) added two new compiler-dependent configs:
  * CC_NO_ARRAY_BOUNDS
  * GCC12_NO_ARRAY_BOUNDS
  Ignore them -- they are unset by dummy tools (they depend on gcc version
  == 12), but set as needed during real compilation.
- commit a14607c
* Tue Jun 21 2022 tiwai@suse.de
- ath9k: fix use-after-free in ath9k_hif_usb_rx_cb (CVE-2022-1679
  bsc#1199487).
- commit 1ae14c9
* Tue Jun 21 2022 mkoutny@suse.com
- blacklist.conf: Add 6a2d90ba027a ptrace: Reimplement PTRACE_KILL by always sending SIGKILL
- commit 272b7b1
* Tue Jun 21 2022 msuchanek@suse.de
- powerpc/perf: Fix the threshold compare group constraint for
  power9 (bsc#1065729).
- powerpc/idle: Fix return value of __setup() handler
  (bsc#1065729).
- commit 60a1a9d
* Tue Jun 21 2022 msuchanek@suse.de
- scsi: ibmvfc: Store vhost pointer during subcrq allocation
  (jsc#SLE-15442 bsc#1180814 ltc#187461 git-fixes).
- scsi: ibmvfc: Allocate/free queue resource only during
  probe/remove (jsc#SLE-15442 bsc#1180814 ltc#187461 git-fixes).
- commit 161dd5d
* Tue Jun 21 2022 neilb@suse.de
- pNFS: Don't keep retrying if the server replied
  NFS4ERR_LAYOUTUNAVAILABLE (git-fixes).
- SUNRPC: Fix the calculation of xdr->end in
  xdr_get_next_encode_buffer() (git-fixes).
- NFS: Further fixes to the writeback error handling (git-fixes).
- NFSv4/pNFS: Do not fail I/O when we fail to allocate the pNFS
  layout (git-fixes).
- NFS: Memory allocation failures are not server fatal errors
  (git-fixes).
- NFS: Don't report errors from nfs_pageio_complete() more than
  once (git-fixes).
- NFS: Do not report flush errors in nfs_write_end() (git-fixes).
- NFS: Do not report EINTR/ERESTARTSYS as mapping errors
  (git-fixes).
- commit b6dcac2
* Mon Jun 20 2022 neilb@suse.de
- Update patches.suse/pNFS-flexfiles-fix-incorrect-size-check-in-decode_nf.patch
  (git-fixes CVE-2021-4157 bnc#1194013).
- commit fccebe3
* Fri Jun 17 2022 msuchanek@suse.de
- random: Add and use pr_fmt() (bsc#1184924).
- commit 565b0b7
* Fri Jun 17 2022 msuchanek@suse.de
- random: remove unnecessary unlikely() (bsc#1184924).
- commit 30b0d5d
* Fri Jun 17 2022 msuchanek@suse.de
- Refresh patches.suse/random-fix-crash-on-multiple-early-calls-to-add_bootloader_randomness.patch.
  Update to  upstream version.
- commit f01d1a8
* Fri Jun 17 2022 msuchanek@suse.de
- powerpc/rtas: Allow ibm,platform-dump RTAS call with null
  buffer address (bsc#1200343 ltc#198477).
- commit eae5ebe
* Fri Jun 17 2022 tiwai@suse.de
- exec: Force single empty string when argv is empty
  (bsc#1200571).
- commit dffa04e
* Fri Jun 17 2022 aabdallah@suse.de
- scsi: smartpqi: create module parameters for LUN reset
  (bsc#1179195 bsc#1200622).
- commit 96f3f82
* Fri Jun 17 2022 tiwai@suse.de
- HID: add USB_HID dependancy to hid-prodikeys (CVE-2022-20132
  bsc#1200619).
- HID: add USB_HID dependancy to hid-chicony (CVE-2022-20132
  bsc#1200619).
- HID: bigbenff: prevent null pointer dereference (CVE-2022-20132
  bsc#1200619).
- HID: add USB_HID dependancy on some USB HID drivers
  (CVE-2022-20132 bsc#1200619).
- commit f2f08be
* Fri Jun 17 2022 tiwai@suse.de
- HID: holtek: fix mouse probing (CVE-2022-20132 bsc#1200619).
- commit f8ff78e
* Fri Jun 17 2022 tiwai@suse.de
- HID: check for valid USB device for many HID drivers
  (CVE-2022-20132 bsc#1200619).
- HID: add hid_is_usb() function to make it simpler for USB
  detection (CVE-2022-20132 bsc#1200619).
- commit 3fe30db
* Fri Jun 17 2022 tiwai@suse.de
- blacklist.conf: add already cherry-picked usb revert commit
- commit 5b3636f
* Fri Jun 17 2022 tiwai@suse.de
- certs/blacklist_hashes.c: fix const confusion in certs blacklist
  (git-fixes).
- commit 6e1c6be
* Fri Jun 17 2022 tiwai@suse.de
- drm/i915/reset: Fix error_state_read ptr + offset use
  (git-fixes).
- net: ax25: Fix deadlock caused by skb_recv_datagram in
  ax25_recvmsg (git-fixes).
- commit 24d4858
* Thu Jun 16 2022 denis.kirjanov@suse.com
- igmp: Add ip_mc_list lock in ip_check_mc_rcu (bsc#1200604
  CVE-2022-20141).
- commit 34bf464
* Wed Jun 15 2022 msuchanek@suse.de
- selftest/powerpc: Add PAPR sysfs attributes sniff test
  (bsc#1200465 ltc#197256 jsc#PED-1931).
- powerpc/pseries: Interface to represent PAPR firmware attributes
  (bsc#1200465 ltc#197256 jsc#PED-1931).
- commit 9795281
* Wed Jun 15 2022 tiwai@suse.de
- ALSA: usb-audio: Optimize TEAC clock quirk (git-fixes).
- commit 4bfd1c5
* Wed Jun 15 2022 tiwai@suse.de
- vringh: Fix loop descriptors check in the indirect cases
  (git-fixes).
- mmc: block: Fix CQE recovery reset success (git-fixes).
- modpost: fix undefined behavior of is_arm_mapping_symbol()
  (git-fixes).
- modpost: fix removing numeric suffixes (git-fixes).
- misc: rtsx: set NULL intfdata when probe fails (git-fixes).
- USB: new quirk for Dell Gen 2 devices (git-fixes).
- USB: serial: option: add Quectel BG95 modem (git-fixes).
- usb: core: hcd: Add support for deferring roothub registration
  (git-fixes).
- usb: dwc2: gadget: don't reset gadget's driver->bus (git-fixes).
- USB: hcd-pci: Fully suspend across freeze/thaw cycle
  (git-fixes).
- drivers: usb: host: Fix deadlock in oxu_bus_suspend()
  (git-fixes).
- USB: host: isp116x: check return value after calling
  platform_get_resource() (git-fixes).
- serial: msm_serial: disable interrupts in __msm_console_write()
  (git-fixes).
- drivers: tty: serial: Fix deadlock in sa1100_set_termios()
  (git-fixes).
- tty: Fix a possible resource leak in icom_probe (git-fixes).
- tty: synclink_gt: Fix null-pointer-dereference in slgt_clean()
  (git-fixes).
- staging: rtl8712: fix uninit-value in r871xu_drv_init()
  (git-fixes).
- staging: rtl8712: fix uninit-value in usb_read8() and friends
  (git-fixes).
- drivers: staging: rtl8192e: Fix deadlock in
  rtllib_beacons_stop() (git-fixes).
- drivers: staging: rtl8192u: Fix deadlock in
  ieee80211_beacons_stop() (git-fixes).
- watchdog: wdat_wdt: Stop watchdog when rebooting the system
  (git-fixes).
- pcmcia: db1xxx_ss: restrict to MIPS_DB1XXX boards (git-fixes).
- video: fbdev: pxa3xx-gcu: release the resources correctly in
  pxa3xx_gcu_probe/remove() (git-fixes).
- rtlwifi: Use pr_warn instead of WARN_ONCE (git-fixes).
- rtl818x: Prevent using not initialized queues (git-fixes).
- mwifiex: add mutex lock for call in
  mwifiex_dfs_chan_sw_work_queue (git-fixes).
- media: cx25821: Fix the warning when removing the module
  (git-fixes).
- media: pci: cx23885: Fix the error handling in cx23885_initdev()
  (git-fixes).
- media: venus: hfi: avoid null dereference in deinit (git-fixes).
- PM / devfreq: rk3399_dmc: Disable edev on remove() (git-fixes).
- spi: stm32-qspi: Fix wait_cmd timeout in APM mode (git-fixes).
- spi: spi-rspi: Remove setting {src,dst}_{addr,addr_width}
  based on DMA direction (git-fixes).
- mmc: jz4740: Apply DMA engine limits to maximum segment size
  (git-fixes).
- pinctrl: sunxi: fix f1c100s uart2 function (git-fixes).
- platform/chrome: cros_ec_proto: Send command again when timeout
  occurs (git-fixes).
- commit f8749e6
* Wed Jun 15 2022 tiwai@suse.de
- efi: Do not import certificates from UEFI Secure Boot for T2
  Macs (git-fixes).
- Refresh
  patches.suse/0003-MODSIGN-load-blacklist-from-MOKx.patch.
- commit 316d54d
* Wed Jun 15 2022 tiwai@suse.de
- drm/atomic: Force bridge self-refresh-exit on CRTC switch
  (git-fixes).
- drm/bridge: analogix_dp: Support PSR-exit to disable transition
  (git-fixes).
- Input: bcm5974 - set missing URB_NO_TRANSFER_DMA_MAP urb flag
  (git-fixes).
- iio: dummy: iio_simple_dummy: check the return value of
  kstrdup() (git-fixes).
- drm/amdgpu/cs: make commands with 0 chunks illegal behaviour
  (git-fixes).
- drm/radeon: fix a possible null pointer dereference (git-fixes).
- i2c: cadence: Increase timeout per message if necessary
  (git-fixes).
- drm/amdgpu/ucode: Remove firmware load type check in
  amdgpu_ucode_free_bo (git-fixes).
- drm: msm: fix error check return value of irq_of_parse_and_map()
  (git-fixes).
- drm/plane: Move range check for format_count earlier
  (git-fixes).
- drm/komeda: return early if drm_universal_plane_init() fails
  (git-fixes).
- fbcon: Consistently protect deferred_takeover with
  console_lock() (git-fixes).
- drm/virtio: fix NULL pointer dereference in
  virtio_gpu_conn_get_modes (git-fixes).
- drm/i915: Fix -Wstringop-overflow warning in call to
  intel_read_wm_latency() (git-fixes).
- iwlwifi: mvm: fix assert 1F04 upon reconfig (git-fixes).
- mac80211: upgrade passive scan to active scan on DFS channels
  after beacon rx (git-fixes).
- ipw2x00: Fix potential NULL dereference in libipw_xmit()
  (git-fixes).
- HID: bigben: fix slab-out-of-bounds Write in bigben_probe
  (git-fixes).
- HID: multitouch: Add support for Google Whiskers Touchpad
  (git-fixes).
- hwmon: Make chip parameter for with_info API mandatory
  (git-fixes).
- irqchip: irq-xtensa-mx: fix initial IRQ affinity (git-fixes).
- irqchip/armada-370-xp: Do not touch Performance Counter Overflow
  on A375, A38x, A39x (git-fixes).
- irqchip/aspeed-i2c-ic: Fix irq_of_parse_and_map() return value
  (git-fixes).
- irqchip/exiu: Fix acknowledgment of edge triggered interrupts
  (git-fixes).
- efi: Add missing prototype for efi_capsule_setup_info
  (git-fixes).
- drivers: i2c: thunderx: Allow driver to work with ACPI defined
  TWSI controllers (git-fixes).
- i2c: ismt: Provide a DMA buffer for Interrupt Cause Logging
  (git-fixes).
- Input: goodix - fix spurious key release events (git-fixes).
- commit 71b82f0
* Wed Jun 15 2022 tiwai@suse.de
- ata: libata-transport: fix {dma|pio|xfer}_mode sysfs files
  (git-fixes).
- ALSA: hda/conexant - Fix loopback issue with CX20632
  (git-fixes).
- ALSA: usb-audio: Set up (implicit) sync for Saffire 6
  (git-fixes).
- ALSA: usb-audio: Skip generic sync EP parse for secondary EP
  (git-fixes).
- clocksource/drivers/oxnas-rps: Fix irq_of_parse_and_map()
  return value (git-fixes).
- clocksource/drivers/sp804: Avoid error on multiple instances
  (git-fixes).
- dmaengine: zynqmp_dma: In struct zynqmp_dma_chan fix desc_size
  data type (git-fixes).
- ASoC: max98357a: remove dependency on GPIOLIB (git-fixes).
- ASoC: rt5645: Fix errorenous cleanup order (git-fixes).
- ASoC: tscs454: Add endianness flag in snd_soc_component_driver
  (git-fixes).
- ASoC: dapm: Don't fold register value changes into notifications
  (git-fixes).
- ALSA: usb-audio: Workaround for clock setup on TEAC devices
  (git-fixes).
- ath9k: fix QCA9561 PA bias level (git-fixes).
- b43: Fix assigning negative value to unsigned variable
  (git-fixes).
- b43legacy: Fix assigning negative value to unsigned variable
  (git-fixes).
- ACPI: sysfs: Fix BERT error region memory mapping (git-fixes).
- ACPI: PM: Block ASUS B1400CEAE from suspend to idle by default
  (git-fixes).
- cfg80211: set custom regdomain after wiphy registration
  (git-fixes).
- ACPI: sysfs: Make sparse happy about address space in use
  (git-fixes).
- commit d8922a7
* Wed Jun 15 2022 mkubecek@suse.cz
- kabi: return type change of secure_ipv_port_ephemeral()
  (CVE-2022-1012 bsc#1199482).
- tcp: drop the hash_32() part from the index calculation
  (CVE-2022-1012 bsc#1199482).
- tcp: increase source port perturb table to 2^16 (CVE-2022-1012
  bsc#1199482).
- tcp: dynamically allocate the perturb table used by source ports
  (CVE-2022-1012 bsc#1199482).
- tcp: add small random increments to the source port
  (CVE-2022-1012 bsc#1199482).
- tcp: resalt the secret every 10 seconds (CVE-2022-1012
  bsc#1199482).
- tcp: use different parts of the port_offset for index and offset
  (CVE-2022-1012 bsc#1199482).
- secure_seq: use the 64 bits of the siphash for port offset
  calculation (CVE-2022-1012 bsc#1199482).
- commit f0bb4ae
* Wed Jun 15 2022 iivanov@suse.de
- arm64: dts: rockchip: Move drive-impedance-ohm to emmc phy on rk3399 (git-fixes)
- commit 000b775
* Tue Jun 14 2022 osalvador@suse.de
- Refresh 0002-PKCS-7-Check-codeSigning-EKU-for-kernel-module-and-k.patch
- commit 4835ae7
* Tue Jun 14 2022 mkubecek@suse.cz
- kernel-binary.spec: check s390x vmlinux location
  As a side effect of mainline commit edd4a8667355 ("s390/boot: get rid of
  startup archive"), vmlinux on s390x moved from "compressed" subdirectory
  directly into arch/s390/boot. As the specfile is shared among branches,
  check both locations and let objcopy use one that exists.
- commit cd15543
* Tue Jun 14 2022 oneukum@suse.com
- platform/x86: wmi: Fix driver->notify() vs ->probe() race
  (git-fixes).
- commit e932131
* Tue Jun 14 2022 oneukum@suse.com
- platform/x86: wmi: Replace read_takes_no_args with a flags field
  (git-fixes).
- commit 2771a0e
* Tue Jun 14 2022 tiwai@suse.de
- Add missing recommends of kernel-install-tools to kernel-source-vanilla (bsc#1200442)
- commit 93b1375
* Tue Jun 14 2022 osalvador@suse.de
- Update config files
- commit 0d6e862
* Tue Jun 14 2022 ptesarik@suse.cz
- s390/mcck: isolate SIE instruction when setting CIF_MCCK_GUEST
  flag (git-fixes).
- s390/crypto: fix scatterwalk_unmap() callers in AES-GCM
  (git-fixes).
- s390/lcs: fix variable dereferenced before check (git-fixes).
- s390/ctcm: fix potential memory leak (git-fixes).
- s390/ctcm: fix variable dereferenced before check (git-fixes).
- s390/dasd: Fix read inconsistency for ESE DASD devices
  (bsc#1200206 LTC#198455).
- s390/dasd: Fix read for ESE with blksize < 4k (bsc#1200206
  LTC#198455).
- s390/dasd: prevent double format of tracks for ESE devices
  (bsc#1200207 LTC#198454).
- s390/dasd: fix data corruption for ESE devices (bsc#1200207
  LTC#198454).
- KVM: s390: vsie/gmap: reduce gmap_rmap overhead (git-fixes).
- s390/nmi: handle vector validity failures for KVM guests
  (git-fixes).
- s390/nmi: handle guarded storage validity failures for KVM
  guests (git-fixes).
- vfio/ccw: Remove unneeded GFP_DMA (git-fixes).
- KVM: s390: pv: avoid stalls for kvm_s390_pv_init_vm (git-fixes).
- KVM: s390: pv: avoid double free of sida page (git-fixes).
- KVM: s390: pv: add macros for UVC CC values (git-fixes).
- s390: fix strrchr() implementation (git-fixes).
- s390/pv: fix the forcing of the swiotlb (git-fixes).
- s390/qdio: cancel the ESTABLISH ccw after timeout (git-fixes).
- s390/qdio: fix roll-back after timeout on ESTABLISH ccw
  (git-fixes).
- s390/ftrace: fix ftrace_update_ftrace_func implementation
  (git-fixes).
- s390/cio: dont call css_wait_for_slow_path() inside a lock
  (git-fixes).
- s390/cio: Fix the "type" field in s390_cio_tpi tracepoint
  (git-fixes).
- s390/mcck: fix invalid KVM guest condition check (git-fixes).
- vfio-ccw: Check initialized flag in cp_init() (git-fixes).
- s390: fix detection of vector enhancements facility 1 vs. vector
  packed decimal facility (git-fixes).
- s390/vfio-ap: fix circular lockdep when setting/clearing crypto
  masks (git-fixes).
- virtio/s390: implement virtio-ccw revision 2 correctly
  (git-fixes).
- commit 61a09d5
* Tue Jun 14 2022 neilb@suse.de
- NFS: Don't report ENOSPC write errors twice (git-fixes).
- nfsd: Fix null-ptr-deref in nfsd_fill_super() (git-fixes).
- md: fix an incorrect NULL check in md_reload_sb (git-fixes).
- md: fix an incorrect NULL check in does_sb_need_changing
  (git-fixes).
- raid5: introduce MD_BROKEN (git-fixes).
- commit a49fc21
* Tue Jun 14 2022 osalvador@suse.de
- Rename colliding patches before the next origin/cve/linux-5.3 -> SLE15-SP3 merge
- commit 070ca14
* Mon Jun 13 2022 jack@suse.cz
- blk-mq: Fix wrong wakeup batch configuration which will cause
  hang (bsc#1200263).
- commit d25a54b
* Mon Jun 13 2022 jack@suse.cz
- blk-mq: fix tag_get wait task can't be awakened (bsc#1200263).
- commit 0a1fb57
* Mon Jun 13 2022 ohering@suse.de
- PCI: hv: Fix NUMA node assignment when kernel boots with custom
  NUMA topology (bsc#1199365).
- commit 533234b
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix uninitialized pointer in error case in
  dfs_cache_get_tgt_share (bsc#1200217).
- commit 61fbb01
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: skip trailing separators of prefix paths (bsc#1200217).
- commit ee56e7d
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: update internal module number (bsc#1200217).
- commit f5cdb99
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: version operations for smb20 unneeded when legacy support
  disabled (bsc#1200217).
- commit 1734132
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: do not build smb1ops if legacy support is disabled
  (bsc#1200217).
- commit aba3c47
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix potential deadlock in direct reclaim (bsc#1200217).
- commit e9cc20c
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: when extending a file with falloc we should make files
  not-sparse (bsc#1200217).
- commit 294d1b1
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: remove repeated debug message on cifs_put_smb_ses()
  (bsc#1200217).
- commit 98c0db1
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix potential double free during failed mount
  (bsc#1200217).
- commit bce142b
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: avoid parallel session setups on same channel
  (bsc#1200217).
- commit 1f42004
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: use new enum for ses_status (bsc#1200217).
- commit 7268b31
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: do not use tcpStatus after negotiate completes
  (bsc#1200217).
- commit 7674d31
* Fri Jun 10 2022 ematsumiya@suse.de
- smb3: add mount parm nosparse (bsc#1200217).
- commit 2ffada9
* Fri Jun 10 2022 ematsumiya@suse.de
- smb3: don't set rc when used and unneeded in query_info_compound
  (bsc#1200217).
- commit 6fd63ad
* Fri Jun 10 2022 ematsumiya@suse.de
- smb3: check for null tcon (bsc#1200217).
- commit b858070
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix minor compile warning (bsc#1200217).
- commit fd0fc4d
* Fri Jun 10 2022 ematsumiya@suse.de
- Add various fsctl structs (bsc#1200217).
- commit 90bede3
* Fri Jun 10 2022 ematsumiya@suse.de
- smb3: add trace point for oplock not found (bsc#1200217).
- commit 346f7ed
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: return the more nuanced writeback error on close()
  (bsc#1200217).
- commit 7742646
* Fri Jun 10 2022 ematsumiya@suse.de
- smb3: add trace point for lease not found issue (bsc#1200217).
- commit 0658354
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: smbd: fix typo in comment (bsc#1200217).
- commit c4afc8a
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: set the CREATE_NOT_FILE when opening the directory in
  use_cached_dir() (bsc#1200217).
- commit 706627f
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: check for smb1 in open_cached_dir() (bsc#1200217).
- commit 6a639c3
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: move definition of cifs_fattr earlier in cifsglob.h
  (bsc#1200217).
- commit f6bc702
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: print TIDs as hex (bsc#1200217).
- commit e89f4ca
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: return ENOENT for DFS lookup_cache_entry() (bsc#1200217).
- commit 415ae81
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: don't call cifs_dfs_query_info_nonascii_quirk() if nodfs
  was set (bsc#1200217).
- commit a90922b
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix signed integer overflow when fl_end is OFFSET_MAX
  (bsc#1200217).
- commit 586cc75
* Fri Jun 10 2022 ematsumiya@suse.de
- SMB3: EBADF/EIO errors in rename/open caused by race condition
  in smb2_compound_op (bsc#1200217).
- commit ee0782f
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: destage any unwritten data to the server before calling
  copychunk_write (bsc#1200217).
- commit 1bda1c7
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: use correct lock type in cifs_reconnect() (bsc#1200217).
- commit 8a9f3fb
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix NULL ptr dereference in refresh_mounts()
  (bsc#1200217).
- commit 6a33928
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: Use kzalloc instead of kmalloc/memset (bsc#1200217).
- commit b1096ec
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: verify that tcon is valid before dereference in
  cifs_kill_sb (bsc#1200217).
- commit 7b9058f
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: potential buffer overflow in handling symlinks
  (bsc#1200217).
- commit 6cb9820
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: Split the smb3_add_credits tracepoint (bsc#1200217).
- commit 349ed65
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: release cached dentries only if mount is complete
  (bsc#1200217).
- commit 6b464d5
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: Check the IOCB_DIRECT flag, not O_DIRECT (bsc#1200217).
- commit dde64e8
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: update internal module number (bsc#1193629).
- commit 92220f4
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: force new session setup and tcon for dfs (bsc#1200217).
- commit 83df40d
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: remove check of list iterator against head past the loop
  body (bsc#1200217).
- commit c041716
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix potential race with cifsd thread (bsc#1200217).
- commit 4db1b1e
* Fri Jun 10 2022 ematsumiya@suse.de
- smb3: fix ksmbd bigendian bug in oplock break, and move its
  struct to smbfs_common (bsc#1200217).
  [ ematsumiya: remove ksmbd parts ]
- commit 49a5253
* Fri Jun 10 2022 ematsumiya@suse.de
- smb3: cleanup and clarify status of tree connections
  (bsc#1200217).
- commit 7a8d282
* Fri Jun 10 2022 ematsumiya@suse.de
- smb3: move defines for query info and query fsinfo to
  smbfs_common (bsc#1200217).
  [ ematsumiya: remove ksmbd parts ]
- commit 980c599
* Fri Jun 10 2022 ematsumiya@suse.de
- smb3: move defines for ioctl protocol header and SMB2 sizes
  to smbfs_common (bsc#1200217).
  [ ematsumiya: remove ksmbd parts ]
- commit 4816364
* Fri Jun 10 2022 ematsumiya@suse.de
- [smb3] move more common protocol header definitions to
  smbfs_common (bsc#1200217).
  [ ematsumiya: remove ksmbd parts ]
- commit 6224ee1
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix incorrect use of list iterator after the loop
  (bsc#1200217).
- commit aef3af4
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: change smb2_query_info_compound to use a cached fid,
  if available (bsc#1200217).
- commit 351d3bd
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: use a different reconnect helper for non-cifsd threads
  (bsc#1200217).
- commit f30e918
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: we do not need a spinlock around the tree access during
  umount (bsc#1200217).
- commit 7cfcd55
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix handlecache and multiuser (bsc#1200217).
- commit 3ed19f3
* Fri Jun 10 2022 ematsumiya@suse.de
- smb3: fix incorrect session setup check for multiuser mounts
  (bsc#1200217).
- commit 7016d61
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix confusing unneeded warning message on smb2.1 and
  earlier (bsc#1200217).
- commit 5c8e870
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: modefromsids must add an ACE for authenticated users
  (bsc#1200217).
- commit 48a34af
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix double free race when mount fails in cifs_get_root()
  (bsc#1200217).
- commit f99992c
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: do not use uninitialized data in the owner/group sid
  (bsc#1200217).
- commit 84b55ef
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix set of group SID via NTSD xattrs (bsc#1200217).
- commit eb184a1
* Fri Jun 10 2022 ematsumiya@suse.de
- smb3: fix snapshot mount option (bsc#1200217).
- commit 874c094
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: mark sessions for reconnection in helper function
  (bsc#1200217).
- commit 0a58bbf
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: call helper functions for marking channels for reconnect
  (bsc#1200217).
- commit 9ee8dff
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: call cifs_reconnect when a connection is marked
  (bsc#1200217).
- commit da0085d
* Fri Jun 10 2022 ematsumiya@suse.de
- [smb3] improve error message when mount options conflict with
  posix (bsc#1200217).
- commit 2105c8f
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix workstation_name for multiuser mounts (bsc#1200217).
- commit 5c19405
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: unlock chan_lock before calling cifs_put_tcp_session
  (bsc#1200217).
- commit 154c129
* Fri Jun 10 2022 ematsumiya@suse.de
- Fix a warning about a malformed kernel doc comment in cifs
  (bsc#1200217).
- commit b2b7511
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: update internal module number (bsc#1200217).
- commit fd57627
* Fri Jun 10 2022 ematsumiya@suse.de
- smb3: send NTLMSSP version information (bsc#1200217).
- commit 713e861
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: cifs_ses_mark_for_reconnect should also update reconnect
  bits (bsc#1200217).
- commit 9a2f0ac
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: update tcpStatus during negotiate and sess setup
  (bsc#1200217).
- commit d9e3178
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: make status checks in version independent callers
  (bsc#1200217).
- commit bd7b0d4
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: remove repeated state change in dfs tree connect
  (bsc#1200217).
- commit 010f86c
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix the cifs_reconnect path for DFS (bsc#1200217).
- commit 8872018
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: remove unused variable ses_selected (bsc#1200217).
- commit ff25a18
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: protect all accesses to chan_* with chan_lock
  (bsc#1200217).
- commit 570e7fa
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix the connection state transitions with multichannel
  (bsc#1200217).
- commit 9e04600
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: check reconnects for channels of active tcons too
  (bsc#1200217).
- commit 7d36579
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: serialize all mount attempts (bsc#1200217).
- commit 551fdd3
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: quirk for STATUS_OBJECT_NAME_INVALID returned for
  non-ASCII dfs refs (bsc#1200217).
- commit c9efbf1
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: alloc_path_with_tree_prefix: do not append sep. if the
  path is empty (bsc#1200217).
- commit 764a91d
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: clean up an inconsistent indenting (bsc#1200217).
- commit 248e46d
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: free ntlmsspblob allocated in negotiate (bsc#1200217).
- commit 43eb5cf
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix FILE_BOTH_DIRECTORY_INFO definition (bsc#1200217).
- commit 41d17b7
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: move superblock magic defitions to magic.h (bsc#1200217).
- commit ef6d710
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: Fix smb311_update_preauth_hash() kernel-doc comment
  (bsc#1200217).
- commit f53ea90
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: avoid race during socket reconnect between send and recv
  (bsc#1200217).
- commit 722c8b7
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: maintain a state machine for tcp/smb/tcon sessions
  (bsc#1200217).
- commit 51b486f
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix hang on cifs_get_next_mid() (bsc#1200217).
- commit fd0e196
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: take cifs_tcp_ses_lock for status checks (bsc#1200217).
- commit 27f6fb8
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: reconnect only the connection and not smb session where
  possible (bsc#1200217).
- commit 16bf87d
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: add WARN_ON for when chan_count goes below minimum
  (bsc#1200217).
- commit a58714b
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: adjust DebugData to use chans_need_reconnect for conn
  status (bsc#1200217).
- commit 7ddcbf5
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: use the chans_need_reconnect bitmap for reconnect status
  (bsc#1200217).
- commit d6f970b
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: track individual channel status using chans_need_reconnect
  (bsc#1200217).
- commit b7aed75
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: remove redundant assignment to pointer p (bsc#1200217).
- commit a5a52e3
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: sanitize multiple delimiters in prepath (bsc#1200217).
- commit d076172
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: ignore resource_id while getting fscache super cookie
  (bsc#1200217).
- commit 2d5c0e6
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix ntlmssp auth when there is no key exchange
  (bsc#1200217).
- commit 93704ce
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: wait for tcon resource_id before getting fscache super
  (bsc#1200217).
- commit b7f6657
* Fri Jun 10 2022 ematsumiya@suse.de
- cifs: fix missed refcounting of ipc tcon (bsc#1200217).
- commit e83f639
* Fri Jun 10 2022 jgross@suse.com
- kvm: x86/cpuid: Only provide CPUID leaf 0xA if host has
  architectural PMU (git-fixes).
- commit b46bf26
* Fri Jun 10 2022 jgross@suse.com
- KVM: x86/emulator: Defer not-present segment check in
  __load_segment_descriptor() (git-fixes).
- commit 27bee90
* Fri Jun 10 2022 jgross@suse.com
- KVM: x86: Fix emulation in writing cr8 (git-fixes).
- commit a28f4e5
* Fri Jun 10 2022 jgross@suse.com
- KVM: nVMX: Query current VMCS when determining if MSR bitmaps
  are in use (git-fixes).
- commit d008aa3
* Fri Jun 10 2022 jgross@suse.com
- kvm: fix wrong exception emulation in check_rdtsc (git-fixes).
- commit 5797afc
* Fri Jun 10 2022 jgross@suse.com
- KVM: nVMX: Unconditionally clear nested.pi_pending on nested
  VM-Enter (git-fixes).
- commit acadff0
* Fri Jun 10 2022 jgross@suse.com
- KVM: VMX: Use current VMCS to query WAITPKG support for MSR
  emulation (git-fixes).
- commit e4539a4
* Fri Jun 10 2022 jgross@suse.com
- KVM: x86: Don't force set BSP bit when local APIC is managed
  by userspace (git-fixes).
- commit eb244fb
* Fri Jun 10 2022 jgross@suse.com
- KVM: x86: Migrate the PIT only if vcpu0 is migrated, not any
  BSP (git-fixes).
- commit e4d1ca5
* Fri Jun 10 2022 jgross@suse.com
- KVM: nVMX: Set LDTR to its architecturally defined value on
  nested VM-Exit (git-fixes).
- commit 738798b
* Fri Jun 10 2022 jgross@suse.com
- KVM: x86: Immediately reset the MMU context when the SMM flag
  is cleared (git-fixes).
- commit 09330a5
* Fri Jun 10 2022 vkarasulli@suse.de
- floppy: disable FDRAWCMD by default (bsc#1198866 CVE-2022-1836).
- Update config files.
- commit f9d0532
* Fri Jun 10 2022 jgross@suse.com
- KVM: x86/pmu: Fix HW_REF_CPU_CYCLES event pseudo-encoding in
  intel_arch_events[] (git-fixes).
- commit d9ed32f
* Fri Jun 10 2022 jgross@suse.com
- KVM: x86: clflushopt should be treated as a no-op by emulation
  (git-fixes).
- commit 9620f9a
* Fri Jun 10 2022 jgross@suse.com
- kvm: x86: Toggling CR4.PKE does not load PDPTEs in PAE mode
  (git-fixes).
- commit ef4dd36
* Fri Jun 10 2022 jgross@suse.com
- kvm: x86: Toggling CR4.SMAP does not load PDPTEs in PAE mode
  (git-fixes).
- commit f6cd4b8
* Fri Jun 10 2022 jgross@suse.com
- KVM: x86: Mark CR4.TSD as being possibly owned by the guest
  (git-fixes).
- commit 0207dce
* Fri Jun 10 2022 jgross@suse.com
- KVM: x86: Inject #GP if guest attempts to toggle CR4.LA57 in
  64-bit mode (git-fixes).
- commit 167dd6e
* Fri Jun 10 2022 jgross@suse.com
- Revert "KVM: x86: work around leak of uninitialized stack
  contents" (git-fixes).
- commit 750d1b0
* Fri Jun 10 2022 tiwai@suse.de
- nfc: st21nfca: fix incorrect sizing calculations in
  EVT_TRANSACTION (git-fixes).
- nfc: st21nfca: fix memory leaks in EVT_TRANSACTION handling
  (git-fixes).
- nfc: st21nfca: fix incorrect validating logic in EVT_TRANSACTION
  (git-fixes).
- drm: imx: fix compiler warning with gcc-12 (git-fixes).
- commit 31b71c0
* Fri Jun 10 2022 jgross@suse.com
- KVM: x86: Fix off-by-one error in kvm_vcpu_ioctl_x86_setup_mce
  (git-fixes).
- commit 006ad54
* Fri Jun 10 2022 jgross@suse.com
- KVM: nVMX: Invalidate all roots when emulating INVVPID without
  EPT (git-fixes).
- commit 6adfb0f
* Fri Jun 10 2022 jgross@suse.com
- KVM: VMX: Flush all EPTP/VPID contexts on remote TLB flush
  (git-fixes).
- commit a06b778
* Wed Jun  8 2022 mbenes@suse.cz
- ftrace: Clean up hash direct_functions on register failures
  (git-fixes).
- commit adaac4e
* Wed Jun  8 2022 pjakobsson@suse.de
- tilcdc: tilcdc_external: fix an incorrect NULL check on list
  iterator (git-fixes).
- commit 8f16892
* Wed Jun  8 2022 pjakobsson@suse.de
- Refresh
  patches.suse/drm-vmwgfx-Initialize-drm_mode_fb_cmd2.patch.
  Alt-commit
- commit 30ee9bf
* Wed Jun  8 2022 pjakobsson@suse.de
- Refresh
  patches.suse/0001-drm-vmwgfx-Remove-unused-compile-options.patch.
  Alt-commit
- commit e57beef
* Wed Jun  8 2022 pjakobsson@suse.de
- blacklist.conf: Remove blacklisting of backported patch
- Refresh
  patches.suse/drm-vc4-hdmi-Move-the-HSM-clock-enable-to-runtime_pm.patch.
  Alt-commit
- commit 64d3607
* Wed Jun  8 2022 jack@suse.cz
- block: fix bio_clone_blkg_association() to associate with
  proper blkcg_gq (bsc#1200259).
- commit ce6dfd1
* Wed Jun  8 2022 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-Call-i915_globals_exit-if-pci_register_devi.patch.
  Alt-commit
- commit fbaa188
* Wed Jun  8 2022 pjakobsson@suse.de
- drm/msm/dsi: fix address for second DSI PHY on SDM660
  (git-fixes).
- commit 2435776
* Wed Jun  8 2022 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-gem-add-missing-boundary-check-in-vm_access.patch.
  Alt-commit
- commit 693f083
* Wed Jun  8 2022 pjakobsson@suse.de
- Refresh patches.suse/drm-amdkfd-Fix-GWS-queue-count.patch.
  Alt-commit
- commit cef7148
* Wed Jun  8 2022 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amdgpu-smu10-fix-SoC-fclk-units-in-auto-mode.patch.
  Alt-commit
- commit 7e7296e
* Wed Jun  8 2022 pjakobsson@suse.de
- dma-buf: fix use of DMA_BUF_SET_NAME_{A,B} in userspace
  (git-fixes).
- commit 25b074b
* Wed Jun  8 2022 pjakobsson@suse.de
- drm/amdgpu/smu10: fix SoC/fclk units in auto mode (git-fixes).
- commit cd35e5a
* Wed Jun  8 2022 pjakobsson@suse.de
- blacklist.conf: 0d979509539e drm/ttm: remove ttm_bo_vm_insert_huge()
- commit b0d7e4a
* Wed Jun  8 2022 pjakobsson@suse.de
- blacklist.conf: 10a6de19cad6 seq_file: fix passing wrong private data
- commit 88787ec
* Wed Jun  8 2022 pjakobsson@suse.de
- drm/i915: fix i915_globals_exit() section mismatch error
  (git-fixes).
- commit f035fef
* Tue Jun  7 2022 ohering@suse.de
- add mainline tag for a pci-hyperv change
- commit 77f42e9
* Tue Jun  7 2022 mkubecek@suse.cz
- netfilter: nf_tables: sanitize nft_set_desc_concat_parse()
  (CVE-2022-1972 bsc#1200019).
- commit 323e166
* Mon Jun  6 2022 mkubecek@suse.cz
- netfilter: nf_tables: disallow non-stateful expression in sets
  earlier (CVE-2022-1966 bsc#1200015).
- commit 41de480
* Mon Jun  6 2022 lduncan@suse.com
- scsi: ufs: qcom: Add a readl() to make sure ref_clk gets enabled
  (git-fixes).
- scsi: dc395x: Fix a missing check on list iterator (git-fixes).
- scsi: ufs: core: Exclude UECxx from SFR dump list (git-fixes).
- scsi: ufs: qcom: Fix ufs_qcom_resume() (git-fixes).
- drbd: fix duplicate array initializer (git-fixes).
- drbd: use bdev_alignment_offset instead of
  queue_alignment_offset (git-fixes).
- drbd: use bdev based limit helpers in drbd_send_sizes
  (git-fixes).
- drbd: remove assign_p_sizes_qlim (git-fixes).
- commit d165ee8
* Mon Jun  6 2022 lduncan@suse.com
- Added blacklist git-fix: just fixes compiler warning but breaks kabi
- commit 2f740d4
* Mon Jun  6 2022 jack@suse.cz
- jbd2: Fake symbols defined under CONFIG_JBD2_DEBUG
  (bsc#1198971).
- Update config files to disable mistakenly enabled CONFIG_JBD2_DEBUG
- commit 1c1f326
* Mon Jun  6 2022 denis.kirjanov@suse.com
- net: stmmac: dwmac-sun8i: Balance syscon (de)initialization (git-fixes).
- commit 3c1ac51
* Mon Jun  6 2022 denis.kirjanov@suse.com
- net: stmmac: dwmac-sun8i: Balance internal PHY power (git-fixes).
- commit a293be9
* Mon Jun  6 2022 denis.kirjanov@suse.com
- net: stmmac: dwmac-sun8i: Balance internal PHY resource references (git-fixes).
- commit 5ddd111
* Mon Jun  6 2022 denis.kirjanov@suse.com
- net: stmmac: dwmac-sun8i: Fix probe error handling (git-fixes).
- commit b7d0c5f
* Mon Jun  6 2022 denis.kirjanov@suse.com
- net: dsa: lantiq_gswip: Fix GSWIP_MII_CFG(p) register access (git-fixes).
- commit ac2aae4
* Mon Jun  6 2022 denis.kirjanov@suse.com
- net: dsa: lantiq_gswip: Enable GSWIP_MII_CFG_EN also for internal PHYs (git-fixes).
- commit dd8afe7
* Mon Jun  6 2022 denis.kirjanov@suse.com
- net: ethernet: ti: cpts: fix ethtool output when no ptp_clock registered (git-fixes).
- commit de37b40
* Mon Jun  6 2022 denis.kirjanov@suse.com
- net: ethernet: Fix memleak in ethoc_probe (git-fixes).
- commit b06c831
* Mon Jun  6 2022 denis.kirjanov@suse.com
- qlcnic: Fix error code in probe (git-fixes).
- commit 34dcd67
* Mon Jun  6 2022 denis.kirjanov@suse.com
- net: korina: fix return value (git-fixes).
- commit 2399b03
* Mon Jun  6 2022 denis.kirjanov@suse.com
- ice: Fix race conditions between virtchnl handling and VF ndo ops (git-fixes).
- commit ecd49f2
* Mon Jun  6 2022 denis.kirjanov@suse.com
- net: hns3: fix kernel crash when unload VF while it is being reset (git-fixes).
- commit 5655db7
* Mon Jun  6 2022 wqu@suse.com
- btrfs: tree-checker: fix incorrect printk format (bsc#1200249).
- commit 9d94c81
* Sat Jun  4 2022 tiwai@suse.de
- netdevice: demote the type of some dev_addr_set() helpers
  (bsc#1200216).
- commit eaa7009
* Sat Jun  4 2022 tiwai@suse.de
- ALSA: hda/realtek - Fix microphone noise on ASUS TUF B550M-PLUS
  (git-fixes).
- ALSA: hda/realtek: Enable 4-speaker output for Dell XPS 15
  9520 laptop (git-fixes).
- ALSA: hda/realtek - Add new type for ALC245 (git-fixes).
- ASoC: rt5514: Fix event generation for "DSP Voice Wake Up"
  control (git-fixes).
- ALSA: ctxfi: Add SB046x PCI ID (git-fixes).
- commit f5268ed
* Sat Jun  4 2022 tiwai@suse.de
- gpio: adp5588: Remove support for platform setup and teardown
  callbacks (git-fixes).
- gpio: pca953x: use the correct register address to do regcache
  sync (git-fixes).
- driver core: fix deadlock in __device_attach (git-fixes).
- driver: base: fix UAF when driver_attach failed (git-fixes).
- selftests: firmware: Use smaller dictionary for XZ compression
  (git-fixes).
- bus: ti-sysc: Fix warnings for unbind for serial (git-fixes).
- firmware: dmi-sysfs: Fix memory leak in
  dmi_sysfs_register_handle (git-fixes).
- phy: qcom-qmp: fix pipe-clock imbalance on power-on failure
  (git-fixes).
- phy: qcom-qmp: fix reset-controller leak on probe errors
  (git-fixes).
- phy: qcom-qmp: fix struct clk leak on probe errors (git-fixes).
- iio: adc: sc27xx: Fine tune the scale calibration values
  (git-fixes).
- iio: adc: sc27xx: fix read big scale voltage not right
  (git-fixes).
- iio: adc: stmpe-adc: Fix wait_for_completion_timeout return
  value check (git-fixes).
- iio: adc: ad7124: Remove shift from scan_type (git-fixes).
- firmware: stratix10-svc: fix a missing check on list iterator
  (git-fixes).
- usb: ehci-omap: drop unused ehci_read() function (git-fixes).
- usb: typec: mux: Check dev_set_name() return value (git-fixes).
- usb: dwc3: pci: Fix pm_runtime_get_sync() error checking
  (git-fixes).
- usb: musb: Fix missing of_node_put() in omap2430_probe
  (git-fixes).
- USB: storage: karma: fix rio_karma_init return (git-fixes).
- usb: usbip: add missing device lock on tweak configuration cmd
  (git-fixes).
- usb: usbip: fix a refcount leak in stub_probe() (git-fixes).
- serial: stm32-usart: Correct CSIZE, bits, and parity
  (git-fixes).
- serial: st-asc: Sanitize CSIZE and correct PARENB for CS7
  (git-fixes).
- serial: sifive: Sanitize CSIZE and c_iflag (git-fixes).
- serial: sh-sci: Don't allow CS5-6 (git-fixes).
- serial: txx9: Don't allow CS5-6 (git-fixes).
- serial: rda-uart: Don't allow CS5-6 (git-fixes).
- serial: digicolor-usart: Don't allow CS5-6 (git-fixes).
- serial: 8250_fintek: Check SER_RS485_RTS_* only with RS485
  (git-fixes).
- serial: meson: acquire port->lock in startup() (git-fixes).
- serial: pch: don't overwrite xmit->buf[0] by x_char (git-fixes).
- serial: 8250: pxa: Remove unneeded <linux/pm_runtime.h>
  (git-fixes).
- serial: 8250: core: Remove unneeded <linux/pm_runtime.h>
  (git-fixes).
- tty: serial: fsl_lpuart: fix potential bug when using both
  of_alias_get_id and ida_simple_get (git-fixes).
- tty: serial: owl: Fix missing clk_disable_unprepare() in
  owl_uart_probe (git-fixes).
- tty: goldfish: Use tty_port_destroy() to destroy port
  (git-fixes).
- staging: fieldbus: Fix the error handling path in
  anybuss_host_common_probe() (git-fixes).
- ASoC: fsl_sai: Fix FSL_SAI_xDR/xFR definition (git-fixes).
- commit e15e5e6
* Fri Jun  3 2022 msuchanek@suse.de
- powerpc/xive: Add some error handling code to
  'xive_spapr_init()' (fate#322438 git-fixes).
- commit 29a15ff
* Fri Jun  3 2022 mkubecek@suse.cz
- net: sched: fixed barrier to prevent skbuff sticking in qdisc
  backlog (bsc#1183405).
- commit 5f8489b
* Fri Jun  3 2022 mbenes@suse.cz
- tracing: Fix return value of trace_pid_write() (git-fixes).
- commit 332fdc6
* Fri Jun  3 2022 mbenes@suse.cz
- tracing: Fix potential double free in create_var_ref()
  (git-fixes).
- commit 142f9d7
* Fri Jun  3 2022 dwagner@suse.de
- wireguard: device: check for metadata_dst with skb_valid_dst()
  (git-fixes).
- commit 9790edc
* Fri Jun  3 2022 dwagner@suse.de
- nvme-tcp: use __dev_get_by_name instead dev_get_by_name for
  OPT_HOST_IFACE (bsc#1199670).
- commit a8aa700
* Fri Jun  3 2022 lhenriques@suse.de
- ceph: fix setting of xattrs on async created inodes
  (bsc#1200192).
- commit 91687d7
* Fri Jun  3 2022 tiwai@suse.de
- i2c: at91: Initialize dma_buf in at91_twi_xfer() (git-fixes).
- commit 9250a63
* Fri Jun  3 2022 tiwai@suse.de
- soc: rockchip: Fix refcount leak in rockchip_grf_init
  (git-fixes).
- wifi: mac80211: fix use-after-free in chanctx code (git-fixes).
- assoc_array: Fix BUG_ON during garbage collect (git-fixes).
- rtc: mt6397: check return value after calling
  platform_get_resource() (git-fixes).
- watchdog: ts4800_wdt: Fix refcount leak in ts4800_wdt_probe
  (git-fixes).
- pwm: raspberrypi-poe: Fix endianness in firmware struct
  (git-fixes).
- pwm: lp3943: Fix duty calculation in case period was clamped
  (git-fixes).
- i2c: at91: use dma safe buffers (git-fixes).
- video: fbdev: clcdfb: Fix refcount leak in clcdfb_of_vram_setup
  (git-fixes).
- commit db358bc
* Thu Jun  2 2022 msuchanek@suse.de
- powerpc/xive: Fix refcount leak in xive_spapr_init (fate#322438
  git-fixes).
- commit 4062633
* Thu Jun  2 2022 tiwai@suse.de
- NFC: netlink: fix sleep in atomic bug when firmware download
  timeout (CVE-2022-1975 bsc#1200143).
- commit bcae1e0
* Thu Jun  2 2022 tiwai@suse.de
- nfc: replace improper check device_is_registered() in netlink
  related functions (CVE-2022-1974 bsc#1200144).
- Refresh
  patches.suse/NFC-SUSE-specific-brutal-fix-for-runtime-PM.patch.
- commit 8ab4a08
* Wed Jun  1 2022 jlee@suse.com
- certs: Add EFI_CERT_X509_GUID support for dbx entries
  (bsc#1177282 CVE-2020-26541).
- Update config files.
- commit 6bf28b7
* Wed Jun  1 2022 iivanov@suse.de
- ARM: omap: remove debug-leds driver (git-fixes)
- commit 43f073a
* Wed Jun  1 2022 iivanov@suse.de
- arm: mediatek: select arch timer for mt7629 (git-fixes)
- commit 013d17b
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: qcom: msm8974: Drop flags for mdss irqs (git-fixes)
- commit 42eec11
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: suniv: F1C100: fix watchdog compatible (git-fixes)
- commit 93d1bda
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: bcm2835-rpi-b: Fix GPIO line names (git-fixes)
- commit 7e7bd88
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: bcm2837-rpi-3-b-plus: Fix GPIO line name of power LED (git-fixes)
- commit 5ee912a
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: bcm2837-rpi-cm3-io3: Fix GPIO line names for SMPS I2C (git-fixes)
- commit 8161416
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: bcm2835-rpi-zero-w: Fix GPIO line name for Wifi/BT (git-fixes)
- commit 4e538b6
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: imx6ull-colibri: fix vqmmc regulator (git-fixes)
- commit 676db9a
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: logicpd-som-lv: Fix wrong pinmuxing on OMAP35 (git-fixes)
- commit 70b2b9b
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: am3517-evm: Fix misc pinmuxing (git-fixes)
- commit 50fc702
* Wed Jun  1 2022 iivanov@suse.de
- ARM: OMAP2+: Fix refcount leak in omap_gic_of_init (git-fixes)
- commit 12ddc7c
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: at91: Map MCLK for wm8731 on at91sam9g20ek (git-fixes)
- commit 123bc41
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: imx6qdl-apalis: Fix sgtl5000 detection issue (git-fixes)
- commit d5627c3
* Wed Jun  1 2022 iivanov@suse.de
- ARM: config: u8500: Re-enable AB8500 battery charging (git-fixes)
- commit 5b0fb4f
* Wed Jun  1 2022 iivanov@suse.de
- ARM: davinci: da850-evm: Avoid NULL pointer dereference (git-fixes)
- commit 7371c56
* Wed Jun  1 2022 iivanov@suse.de
- ARM: 9187/1: JIVE: fix return value of __setup handler (git-fixes)
- commit f4ca8bd
* Wed Jun  1 2022 iivanov@suse.de
- blacklist.conf: ("ARM: dts: spear1340: Update serial node properties")
- commit 2719ba1
* Wed Jun  1 2022 iivanov@suse.de
- blacklist.conf: ("ARM: dts: spear13xx: Update SPI dma properties")
- commit d4905d6
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: qcom: ipq4019: fix sleep clock (git-fixes)
- commit 23153db
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: Fix OpenBMC flash layout label addresses (git-fixes)
- commit 5fc1380
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: at91: sama5d2: Fix PMERRLOC resource size (git-fixes)
- commit 71afe29
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: imx: Add missing LVDS decoder on M53Menlo (git-fixes)
- commit afc6580
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: exynos: fix UART3 pins configuration in Exynos5250 (git-fixes)
- commit bc1fb03
* Wed Jun  1 2022 iivanov@suse.de
- ARM: ftrace: ensure that ADR takes the Thumb bit into account (git-fixes)
- commit fee81b1
* Wed Jun  1 2022 iivanov@suse.de
- blacklist.conf: ("ARM: iop32x: offset IRQ numbers by 1")
- commit abcec77
* Wed Jun  1 2022 iivanov@suse.de
- ARM: tegra: Move panels to AUX bus (git-fixes)
- commit 50fd172
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: meson8b: Fix the UART device-tree schema validation (git-fixes)
- commit 0f51816
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: meson8: Fix the UART device-tree schema validation (git-fixes)
- commit 40ff6d7
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: meson: Fix the UART compatible strings (git-fixes)
- commit 27df56a
* Wed Jun  1 2022 iivanov@suse.de
- ARM: socfpga: fix missing RESET_CONTROLLER (git-fixes)
- commit 62b05df
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: imx23-evk: Remove MX23_PAD_SSP1_DETECT from hog group (git-fixes)
- commit 587bb4a
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: imx6qdl-udoo: Properly describe the SD card detect (git-fixes)
- commit 8309249
* Wed Jun  1 2022 iivanov@suse.de
- ARM: 9170/1: fix panic when kasan and kprobe are enabled (git-fixes)
- commit 2e353f0
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: armada-38x: Add generic compatible to UART nodes (git-fixes)
- commit c7c1408
* Wed Jun  1 2022 iivanov@suse.de
- ARM: 9169/1: entry: fix Thumb2 bug in iWMMXt exception handling (git-fixes)
- commit ca31c5d
* Wed Jun  1 2022 iivanov@suse.de
- ARM: dts: imx6ull-pinfunc: Fix CSI_DATA07__ESAI_TX0 pad name (git-fixes)
- commit 43a6857
* Wed Jun  1 2022 iivanov@suse.de
- ARM: socfpga: dts: fix qspi node compatible (git-fixes)
- commit 8773156
* Wed Jun  1 2022 dwagner@suse.de
- nvme-tcp: allow selecting the network interface for connections
  (bsc#1199670).
- commit 24adf25
* Wed Jun  1 2022 dwagner@suse.de
- scsi: qla2xxx: edif: Remove unneeded variable (bsc#1200046).
- scsi: qla2xxx: Remove unneeded flush_workqueue() (bsc#1200046).
- scsi: qla2xxx: Remove free_sg command flag (bsc#1200046).
- scsi: qla2xxx: Fix missed DMA unmap for aborted commands
  (bsc#1200046).
- commit 0e2231e
* Wed Jun  1 2022 dwagner@suse.de
- Refresh
  patches.suse/nvme-multipath-use-vmalloc-for-ana-log-buffer.patch.
- commit 971fe0e
* Wed Jun  1 2022 dwagner@suse.de
- scsi: lpfc: Update lpfc version to 14.2.0.3 (bsc#1200045).
- scsi: lpfc: Use sg_dma_address() and sg_dma_len() macros for
  NVMe I/O (bsc#1200045).
- scsi: lpfc: Alter FPIN stat accounting logic (bsc#1200045).
- scsi: lpfc: Rework FDMI initialization after link up
  (bsc#1200045).
- scsi: lpfc: Change VMID registration to be based on fabric
  parameters (bsc#1200045).
- scsi: lpfc: Decrement outstanding gidft_inp counter if
  lpfc_err_lost_link() (bsc#1200045).
- scsi: lpfc: Use list_for_each_entry_safe() in
  rscn_recovery_check() (bsc#1200045).
- scsi: lpfc: Fix dmabuf ptr assignment in lpfc_ct_reject_event()
  (bsc#1200045).
- scsi: lpfc: Inhibit aborts if external loopback plug is inserted
  (bsc#1200045).
- scsi: lpfc: Fix ndlp put following a LOGO completion
  (bsc#1200045).
- scsi: lpfc: Fill in missing ndlp kref puts in error paths
  (bsc#1200045).
- scsi: lpfc: Fix element offset in __lpfc_sli_release_iocbq_s4()
  (bsc#1200045).
- scsi: lpfc: Remove redundant lpfc_sli_prep_wqe() call
  (bsc#1200045).
- scsi: lpfc: Fix additional reference counting in
  lpfc_bsg_rport_els() (bsc#1200045).
- scsi: lpfc: Fix resource leak in lpfc_sli4_send_seq_to_ulp()
  (bsc#1200045).
- scsi: lpfc: Remove unnecessary null ndlp check in
  lpfc_sli_prep_wqe() (bsc#1200045).
- scsi: lpfc: Remove unneeded variable (bsc#1200045).
- scsi: lpfc: Copyright updates for 14.2.0.2 patches
  (bsc#1200045).
- scsi: lpfc: Update lpfc version to 14.2.0.2 (bsc#1200045).
- scsi: lpfc: Expand setting ELS_ID field in ELS_REQUEST64_WQE
  (bsc#1200045).
- scsi: lpfc: Update stat accounting for READ_STATUS mbox command
  (bsc#1200045).
- scsi: lpfc: Change FA-PWWN detection methodology (bsc#1200045).
- scsi: lpfc: Refactor cleanup of mailbox commands (bsc#1200045).
- scsi: lpfc: Fix field overload in lpfc_iocbq data structure
  (bsc#1200045).
- scsi: lpfc: Introduce FC_RSCN_MEMENTO flag for tracking post
  RSCN completion (bsc#1200045).
- scsi: lpfc: Register for Application Services FC-4 type in
  Fabric topology (bsc#1200045).
- scsi: lpfc: Remove false FDMI NVMe FC-4 support for NPIV ports
  (bsc#1200045).
- scsi: lpfc: Revise FDMI reporting of supported port speed for
  trunk groups (bsc#1200045).
- scsi: lpfc: Fix call trace observed during I/O with CMF enabled
  (bsc#1200045).
- scsi: lpfc: Correct CRC32 calculation for congestion stats
  (bsc#1200045).
- scsi: lpfc: Move MI module parameter check to handle dynamic
  disable (bsc#1200045).
- scsi: lpfc: Remove unnecessary NULL pointer assignment for
  ELS_RDF path (bsc#1200045).
- scsi: lpfc: Transition to NPR state upon LOGO cmpl if link
  down or aborted (bsc#1200045).
- scsi: lpfc: Update fc_prli_sent outstanding only after
  guaranteed IOCB submit (bsc#1200045).
- scsi: lpfc: Protect memory leak for NPIV ports sending PLOGI_RJT
  (bsc#1200045).
- scsi: lpfc: Fix null pointer dereference after failing to
  issue FLOGI and PLOGI (bsc#1200045).
- scsi: lpfc: Clear fabric topology flag before initiating a
  new FLOGI (bsc#1200045).
- scsi: lpfc: Fix SCSI I/O completion and abort handler deadlock
  (bsc#1200045).
- scsi: lpfc: Requeue SCSI I/O to upper layer when fw reports
  link down (bsc#1200045).
- scsi: lpfc: Zero SLI4 fcp_cmnd buffer's fcpCntl0 field
  (bsc#1200045).
- scsi: lpfc: Fix diagnostic fw logging after a function reset
  (bsc#1200045).
- scsi: lpfc: Move cfg_log_verbose check before calling
  lpfc_dmp_dbg() (bsc#1200045).
- scsi: lpfc: Tweak message log categories for ELS/FDMI/NVMe
  rescan (bsc#1200045).
- blk-cgroup: move blkcg_{get,set}_fc_appid out of line
  (bsc#1200045).
- scsi: lpfc: Correct BDE DMA address assignment for GEN_REQ_WQE
  (bsc#1200045 bsc#1198989 bsc#1197675).
- scsi: lpfc: Fix split code for FLOGI on FCoE (bsc#1200045
  bsc#1198989 bsc#1197675).
- commit d7157b7
* Wed Jun  1 2022 jroedel@suse.de
- iommu/amd: Increase timeout waiting for GA log enablement
  (bsc#1199052).
- commit fe9fbe6
* Wed Jun  1 2022 dwagner@suse.de
- lpfc: Readd update to version 14.2.0.1 (bsc#1197675 bsc#1196478 bsc#1198989)
  The update was reverted due to some regression on older
  hardware. These have been fixed in the meantime, thus update the
  driver.
- commit 200ac05
* Tue May 31 2022 dbond@suse.com
- revert scsi: qla2xxx: Changes to support FCP2 Target
  (bsc#1198438).
- commit 12ff2a5
* Tue May 31 2022 oneukum@suse.com
- net: rtlwifi: properly check for alloc_workqueue() failure
  (git-fixes).
- Revert "rtlwifi: fix a potential NULL pointer dereference"
  (git-fixes).
- commit 24fe374
* Tue May 31 2022 oneukum@suse.com
- mt76: check return value of mt76_txq_send_burst in
  mt76_txq_schedule_list (git-fixes).
- commit 962a439
* Tue May 31 2022 oneukum@suse.com
- spi: Introduce device-managed SPI controller allocation
  (git-fixes).
- commit 9cd5722
* Tue May 31 2022 msuchanek@suse.de
- powerpc/64s: Add CPU_FTRS_POWER10 to ALWAYS mask (jsc#SLE-13521
  git-fixes).
- powerpc/64s: Add CPU_FTRS_POWER9_DD2_2 to CPU_FTRS_ALWAYS mask
  (bsc#1061840 git-fixes).
- commit 6362663
* Tue May 31 2022 oneukum@suse.com
- blacklist.conf: kABI, cleanup that renames constants
- commit e8bfcff
* Tue May 31 2022 oneukum@suse.com
- blacklist.conf: kABI, renames declarations
- commit 1b506e7
* Tue May 31 2022 oneukum@suse.com
- blacklist.conf: switches off compilation of a driver on some arches. Either irrelevant or breaks kABI.
- commit a8132c8
* Tue May 31 2022 oneukum@suse.com
- media: netup_unidvb: Don't leak SPI master in probe error path
  (git-fixes).
- commit 539b59b
* Tue May 31 2022 jlee@suse.com
- Refresh
  patches.suse/lockdown-also-lock-down-previous-kgdb-use.patch.
  In this case, we can not simply use __GENKSYMS__ to wrap new
  LOCKDOWN_DBG_WRITE/READ_KERNEL fields in enum lockdown_reason
  struct. So let's remove __GENKSYMS__ and add a kabi workaround
  patch. (bsc#1199426 CVE-2022-21499)
- commit 88eddb5
* Tue May 31 2022 jlee@suse.com
- lockdown: kABI workaround for lockdown_reason changes
  (bsc#1199426, CVE-2022-21499).
- commit fe7a29a
* Mon May 30 2022 msuchanek@suse.de
- powerpc/powernv: Get STF barrier requirements from device-tree
  (bsc#1188885 ltc#193722 git-fixes).
- powerpc/powernv: Get L1D flush requirements from device-tree
  (bsc#1188885 ltc#193722 git-fixes).
- powerpc/powernv: Add __init attribute to eligible functions
  (bsc#1188885 ltc#193722 git-fixes).
- powerpc/powernv: Remove POWER9 PVR version check for entry
  and uaccess flushes (bsc#1188885 ltc#193722 git-fixes).
- commit 4e35232
* Mon May 30 2022 msuchanek@suse.de
- powerpc/fadump: fix PT_LOAD segment for boot memory area
  (bsc#1103269 ltc#169948 git-fixes).
- commit 726e54b
* Mon May 30 2022 denis.kirjanov@suse.com
- Update patch metadata references
- commit c29f6ae
* Mon May 30 2022 jgross@suse.com
- KVM: VMX: Fix stale docs for
  kvm-intel.emulate_invalid_guest_state (git-fixes).
- commit 56b5e51
* Mon May 30 2022 jgross@suse.com
- Kconfig.debug: drop selecting non-existing
  HARDLOCKUP_DETECTOR_ARCH (git-fixes).
- commit 9876873
* Mon May 30 2022 jgross@suse.com
- arm64: paravirt: Use RCU read locks to guard stolen_time
  (git-fixes).
- commit 06cf912
* Mon May 30 2022 jgross@suse.com
- smp: Fix offline cpu check in flush_smp_call_function_queue()
  (git-fixes).
- commit 798956d
* Mon May 30 2022 jgross@suse.com
- mm, page_alloc: fix build_zonerefs_node() (git-fixes).
- commit 25a1706
* Mon May 30 2022 tiwai@suse.de
- Input: stmfts - do not leave device disabled in
  stmfts_input_open (git-fixes).
- commit 7f01cd9
* Mon May 30 2022 tiwai@suse.de
- dmaengine: stm32-mdma: remove GISR1 register (git-fixes).
- dmaengine: idxd: Fix the error handling path in
  idxd_cdev_register() (git-fixes).
- Input: sparcspkr - fix refcount leak in bbc_beep_probe
  (git-fixes).
- misc: ocxl: fix possible double free in ocxl_file_register_afu
  (git-fixes).
- pinctrl: mvebu: Fix irq_of_parse_and_map() return value
  (git-fixes).
- pinctrl/rockchip: support deferring other gpio params
  (git-fixes).
- commit 9a75e78
* Mon May 30 2022 wqu@suse.com
- btrfs: extent-tree: kill the BUG_ON() in
  insert_inline_extent_backref() (CVE-2019-19377 bsc#1158266).
- commit 31a8792
* Mon May 30 2022 wqu@suse.com
- btrfs: extent-tree: kill BUG_ON() in  __btrfs_free_extent()
  (CVE-2019-19377 bsc#1158266).
- commit 75b17c1
* Sat May 28 2022 tiwai@suse.de
- crypto: ecrdsa - Fix incorrect use of vli_cmp (git-fixes).
- crypto: caam - fix i.MX6SX entropy delay value (git-fixes).
- crypto: x86 - eliminate anonymous module_init & module_exit
  (git-fixes).
- mfd: ipaq-micro: Fix error check return value of
  platform_get_irq() (git-fixes).
- clk: imx8mp: fix usb_root_clk parent (git-fixes).
- clk: renesas: r9a06g032: Fix the RTC hclock description
  (git-fixes).
- PCI: rockchip: Fix find_first_zero_bit() limit (git-fixes).
- PCI: qcom: Fix unbalanced PHY init on probe errors (git-fixes).
- PCI: qcom: Fix runtime PM imbalance on probe errors (git-fixes).
- PCI: imx6: Fix PERST# start-up sequence (git-fixes).
- PCI: dwc: Fix setting error return on MSI DMA mapping failure
  (git-fixes).
- PCI: cadence: Fix find_first_zero_bit() limit (git-fixes).
- PCI/PM: Power up all devices during runtime resume (git-fixes).
- PCI/AER: Clear MULTI_ERR_COR/UNCOR_RCV bits (git-fixes).
- tty: fix deadlock caused by calling printk() under
  tty_port->lock (git-fixes).
- commit ec70afa
* Fri May 27 2022 tiwai@suse.de
- NFC: hci: fix sleep in atomic context bugs in
  nfc_hci_hcp_message_tx (git-fixes).
- commit 61459e4
* Fri May 27 2022 tiwai@suse.de
- soc: qcom: smsm: Fix missing of_node_put() in smsm_parse_ipc
  (git-fixes).
- soc: qcom: smp2p: Fix missing of_node_put() in smp2p_parse_ipc
  (git-fixes).
- nl80211: show SSID for P2P_GO interfaces (git-fixes).
- NFC: NULL out the dev->rfkill to prevent UAF (git-fixes).
- media: ov7670: remove ov7670_power_off from ov7670_remove
  (git-fixes).
- media: pvrusb2: fix array-index-out-of-bounds in
  pvr2_i2c_core_init (git-fixes).
- thermal/drivers/broadcom: Fix potential NULL dereference in
  sr_thermal_probe (git-fixes).
- thermal/drivers/bcm2711: Don't clamp temperature at zero
  (git-fixes).
- spi: spi-fsl-qspi: check return value after calling
  platform_get_resource_byname() (git-fixes).
- spi: img-spfi: Fix pm_runtime_get_sync() error checking
  (git-fixes).
- spi: spi-ti-qspi: Fix return value handling of
  wait_for_completion_timeout (git-fixes).
- spi: spi-cadence: Fix kernel-doc format for resume/suspend
  (git-fixes).
- regulator: pfuze100: Fix refcount leak in
  pfuze_parse_regulators_dt (git-fixes).
- regulator: core: Fix enable_count imbalance with EXCLUSIVE_GET
  (git-fixes).
- mtd: spi-nor: core: Check written SR value in
  spi_nor_write_16bit_sr_and_check() (git-fixes).
- tpm: Fix buffer access in tpm2_get_tpm_pt() (git-fixes).
- platform/chrome: cros_ec_debugfs: detach log reader wq from devm
  (git-fixes).
- rtc: mc146818-lib: Fix the AltCentury for AMD platforms
  (git-fixes).
- rtc: fix use-after-free on device removal (git-fixes).
- mmc: block: Use generic_cmd6_time when modifying
  INAND_CMD38_ARG_EXT_CSD (git-fixes).
- mmc: core: Specify timeouts for BKOPS and CACHE_FLUSH for eMMC
  (git-fixes).
- commit 45f0e7e
* Fri May 27 2022 tiwai@suse.de
- gma500: fix an incorrect NULL check on list iterator
  (git-fixes).
- media: uvcvideo: Fix missing check to determine if element is
  found in list (git-fixes).
- media: media-entity.h: Fix documentation for
  media_create_intf_link (git-fixes).
- HID: elan: Fix potential double free in elan_input_configured
  (git-fixes).
- HID: hid-led: fix maximum brightness for Dream Cheeky
  (git-fixes).
- Fix double fget() in vhost_net_set_backend() (git-fixes).
- mac80211: fix rx reordering with non explicit / psmp ack policy
  (git-fixes).
- Input: stmfts - fix reference leak in stmfts_input_open
  (git-fixes).
- Input: add bounds checking to input_set_capability()
  (git-fixes).
- commit 6469b91
* Fri May 27 2022 tiwai@suse.de
- firmware: arm_scmi: Validate BASE_DISCOVER_LIST_PROTOCOLS
  response (git-fixes).
- firmware: arm_scmi: Fix list protocols enumeration in the base
  protocol (git-fixes).
- drm/i915: Fix CFI violation with show_dynamic_id() (git-fixes).
- drm: msm: fix possible memory leak in mdp5_crtc_cursor_set()
  (git-fixes).
- drm/msm/a6xx: Fix refcount leak in a6xx_gpu_init (git-fixes).
- drm/msm: return an error pointer in msm_gem_prime_get_sg_table()
  (git-fixes).
- drm/msm/mdp5: Return error code in mdp5_mixer_release when
  deadlock is detected (git-fixes).
- drm/msm/mdp5: Return error code in mdp5_pipe_release when
  deadlock is detected (git-fixes).
- drm/msm/hdmi: fix error check return value of
  irq_of_parse_and_map() (git-fixes).
- commit 0cce114
* Fri May 27 2022 tiwai@suse.de
- drm/msm/hdmi: check return value after calling
  platform_get_resource_byname() (git-fixes).
- drm/msm/dsi: fix error checks and return values for DSI xmit
  functions (git-fixes).
- drm/msm/disp/dpu1: set vbif hw config to NULL to avoid use
  after memory free during pm runtime resume (git-fixes).
- drm/msm/dpu: adjust display_v_end for eDP and DP (git-fixes).
- drm/mediatek: Fix mtk_cec_mask() (git-fixes).
- drm/rockchip: vop: fix possible null-ptr-deref in vop_bind()
  (git-fixes).
- drm/panel: simple: Add missing bus flags for Innolux G070Y2-L01
  (git-fixes).
- drm/bridge: Fix error handling in analogix_dp_probe (git-fixes).
- drm: mali-dp: potential dereference of null pointer (git-fixes).
- commit def8c76
* Fri May 27 2022 tiwai@suse.de
- drivers/base/memory: fix an unlikely reference counting issue
  in __add_memory_block() (git-fixes).
- drivers/base/node.c: fix compaction sysfs file leak (git-fixes).
- ALSA: usb-audio: Configure sync endpoints before data
  (git-fixes).
- ASoC: max98090: Move check for invalid values before casting
  in max98090_put_enab_tlv() (git-fixes).
- ASoC: wm2000: fix missing clk_disable_unprepare() on error in
  wm2000_anc_transition() (git-fixes).
- ASoC: ti: j721e-evm: Fix refcount leak in j721e_soc_probe_*
  (git-fixes).
- ASoC: mxs-saif: Fix refcount leak in mxs_saif_probe (git-fixes).
- ASoC: atmel-classd: Remove endianness flag on class d component
  (git-fixes).
- ASoC: atmel-pdmic: Remove endianness flag on pdmic component
  (git-fixes).
- ASoC: rk3328: fix disabling mclk on pclk probe failure
  (git-fixes).
- ASoC: mediatek: Fix missing of_node_put in
  mt2701_wm8960_machine_probe (git-fixes).
- ASoC: mediatek: Fix error handling in mt8173_max98090_dev_probe
  (git-fixes).
- ALSA: usb-audio: Add missing ep_idx in fixed EP quirks
  (git-fixes).
- ALSA: pcm: Check for null pointer of pointer substream before
  dereferencing it (git-fixes).
- drm/komeda: Fix an undefined behavior bug in komeda_plane_add()
  (git-fixes).
- drm/vc4: txp: Force alpha to be 0xff if it's disabled
  (git-fixes).
- drm/vc4: txp: Don't set TXP_VSTART_AT_EOF (git-fixes).
- drm/vc4: hvs: Reset muxes at probe time (git-fixes).
- drm: sti: don't use kernel-doc markers (git-fixes).
- drm/nouveau/clk: Fix an incorrect NULL check on list iterator
  (git-fixes).
- drm/bridge: adv7511: clean up CEC adapter when probe fails
  (git-fixes).
- drm/edid: fix invalid EDID extension block filtering
  (git-fixes).
- drm/nouveau/kms/nv50-: atom: fix an incorrect NULL check on
  list iterator (git-fixes).
- drm/blend: fix typo in the comment (git-fixes).
- drm/bridge: analogix_dp: Grab runtime PM reference for DP-AUX
  (git-fixes).
- Bluetooth: hci_qca: Use del_timer_sync() before freeing
  (git-fixes).
- Bluetooth: fix dangling sco_conn and use-after-free in
  sco_sock_timeout (git-fixes).
- carl9170: tx: fix an incorrect use of list iterator (git-fixes).
- ath9k_htc: fix potential out of bounds access with invalid
  rxstatus->rs_keyix (git-fixes).
- ath9k: fix ar9003_get_eepmisc (git-fixes).
- docs: submitting-patches: Fix crossref to 'The canonical patch
  format' (git-fixes).
- ACPI: property: Release subnode properties with data nodes
  (git-fixes).
- ALSA: wavefront: Proper check of get_user() error (git-fixes).
- ALSA: hda/realtek: Enable headset mic on Lenovo P360
  (git-fixes).
- crypto: x86/chacha20 - Avoid spurious jumps to other functions
  (git-fixes).
- crypto: stm32 - fix reference leak in stm32_crc_remove
  (git-fixes).
- Bluetooth: call hci_le_conn_failed with hdev lock in
  hci_le_conn_failed (git-fixes).
- commit 72b8536
* Fri May 27 2022 tiwai@suse.de
- Update patch reference for libata fix (bsc#1118212).
- commit 9e93177
* Thu May 26 2022 bp@suse.de
- KVM: x86/speculation: Disable Fill buffer clear within guests (bsc#1199650 CVE-2022-21166 CVE-2022-21127 CVE-2022-21123 CVE-2022-21125 CVE-2022-21180).
- commit 3afdfd4
* Thu May 26 2022 jlee@suse.com
- lockdown: also lock down previous kgdb use (bsc#1199426
  CVE-2022-21499).
- commit 090b59e
* Thu May 26 2022 msuchanek@suse.de
- kernel-binary.spec: Support radio selection for debuginfo.
  To disable debuginfo on 5.18 kernel a radio selection needs to be
  switched to a different selection. This requires disabling the currently
  active option and selecting NONE as debuginfo type.
- commit 43b5dd3
* Thu May 26 2022 tonyj@suse.de
- perf: Fix sys_perf_event_open() race against self
  (CVE-2022-1729, bsc#1199507).
- commit feaf8f1
* Wed May 25 2022 bp@suse.de
- x86/speculation/mmio: Reuse SRBDS mitigation for SBDS (bsc#1199650 CVE-2022-21166 CVE-2022-21127 CVE-2022-21123 CVE-2022-21125 CVE-2022-21180).
- commit 7356a15
* Wed May 25 2022 pvorel@suse.cz
- Update bug reference to bsc#1196840
  bsc#1195826 is for SLE15-SP4
- commit c323b60
* Wed May 25 2022 jack@suse.cz
- ext4: avoid cycles in directory h-tree (bsc#1198577
  CVE-2022-1184).
- commit b98a7a0
* Wed May 25 2022 jack@suse.cz
- ext4: verify dir block before splitting it (bsc#1198577
  CVE-2022-1184).
- commit 1b10a51
* Wed May 25 2022 bp@suse.de
- x86/speculation/srbds: Update SRBDS mitigation selection (bsc#1199650 CVE-2022-21166 CVE-2022-21127 CVE-2022-21123 CVE-2022-21125 CVE-2022-21180).
- commit f7e3619
* Wed May 25 2022 denis.kirjanov@suse.com
- series.conf: sort the patches
- commit 77394cc
* Wed May 25 2022 bp@suse.de
- x86/speculation/mmio: Add sysfs reporting for Processor MMIO Stale Data (bsc#1199650 CVE-2022-21166 CVE-2022-21127 CVE-2022-21123 CVE-2022-21125 CVE-2022-21180).
- commit 449a24c
* Wed May 25 2022 msuchanek@suse.de
- tpm: ibmvtpm: Correct the return value in tpm_ibmvtpm_probe()
  (bsc#1065729).
- commit 55daac9
* Tue May 24 2022 lduncan@suse.com
- scsi: fnic: Replace DMA mask of 64 bits with 47 bits
  (bsc#1199631).
- commit 9223fba
* Tue May 24 2022 tbogendoerfer@suse.de
- ionic: fix missing pci_release_regions() on error in
  ionic_probe() (bsc#1167773).
- net/mlx5e: Fix the calling of update_buffer_lossy() API
  (jsc#SLE-15172).
- bnxt_en: Fix unnecessary dropping of RX packets (jsc#SLE-15075).
- bnxt_en: Fix possible bnxt_open() failure caused by wrong RFS
  flag (jsc#SLE-8371 bsc#1153274).
- hinic: fix bug of wq out of bound access (bsc#1176447).
- net: hns3: clear inited state and stop client after failed to
  register netdev (bsc#1154353).
- netfilter: nft_set_rbtree: overlap detection with element
  re-addition after deletion (bsc#1176447).
- mm/mmu_notifier.c: fix race in mmu_interval_notifier_remove()
  (jsc#SLE-15176, jsc#SLE-16387).
- ice: arfs: fix use-after-free when freeing @rx_cpu_rmap
  (jsc#SLE-12878).
- ice: synchronize_rcu() when terminating rings (jsc#SLE-7926).
- ice: Do not skip not enabled queues in ice_vc_dis_qs_msg
  (jsc#SLE-7926).
- ice: Clear default forwarding VSI during VSI release
  (jsc#SLE-12878).
- net: hns3: fix bug when PF set the duplicate MAC address for
  VFs (jsc#SLE-14777).
- ionic: remove the dbid_inuse bitmap (bsc#1167773).
- ionic: disable napi when ionic_lif_init() fails (bsc#1167773).
- ionic: Cleanups in the Tx hotpath code (bsc#1167773).
- ionic: Don't send reset commands if FW isn't running
  (bsc#1167773).
- ionic: start watchdog after all is setup (bsc#1167773).
- ionic: fix type complaint in ionic_dev_cmd_clean()
  (jsc#SLE-16649).
- net/mlx5: Fix a race on command flush flow (jsc#SLE-15172).
- i40e: stop disabling VFs due to PF error responses (git-fixes).
- ionic: monitor fw status generation (bsc#1167773).
- ionic: avoid races in ionic_heartbeat_check (bsc#1167773).
- commit 16310e3
* Tue May 24 2022 bp@suse.de
- x86/speculation/mmio: Enable CPU Fill buffer clearing on idle (bsc#1199650 CVE-2022-21166 CVE-2022-21127 CVE-2022-21123 CVE-2022-21125 CVE-2022-21180).
- commit c2d3c0f
* Tue May 24 2022 msuchanek@suse.de
- docs: powerpc: Fix misspellings and grammar errors (bsc#1055117
  ltc#159753).
- commit a757a54
* Tue May 24 2022 bp@suse.de
- x86/bugs: Group MDS, TAA & Processor MMIO Stale Data mitigations (bsc#1199650 CVE-2022-21166 CVE-2022-21127 CVE-2022-21123 CVE-2022-21125 CVE-2022-21180).
- commit 93d2214
* Tue May 24 2022 msuchanek@suse.de
- powerpc: Enable the DAWR on POWER9 DD2.3 and above (bsc#1055117
  ltc#159753).
- commit 76e65ef
* Tue May 24 2022 bp@suse.de
- x86/speculation/mmio: Add mitigation for Processor MMIO Stale Data (bsc#1199650 CVE-2022-21166 CVE-2022-21127 CVE-2022-21123 CVE-2022-21125 CVE-2022-21180).
- commit f354e6f
* Tue May 24 2022 denis.kirjanov@suse.com
- blacklist.conf: add Renesas SuperH Ethernet
- commit d918a41
* Mon May 23 2022 bp@suse.de
- x86/speculation: Add a common function for MD_CLEAR mitigation update (bsc#1199650 CVE-2022-21166 CVE-2022-21127 CVE-2022-21123 CVE-2022-21125 CVE-2022-21180).
- commit e71b0a6
* Mon May 23 2022 mkoutny@suse.com
- cgroup/cpuset: Remove cpus_allowed/mems_allowed setup in
  cpuset_init_smp() (bsc#1199839).
- commit 1cc3b7f
* Mon May 23 2022 tiwai@suse.de
- Update patch reference for crypto fix (bsc#1197601)
- commit afd04b9
* Mon May 23 2022 schwab@suse.de
- Add dtb-starfive
- commit 85335b1
* Mon May 23 2022 tiwai@suse.de
- Update patch references for ax25 fixes (CVE-2022-1204 bsc#1198025)
- commit 18cea2f
* Mon May 23 2022 msuchanek@suse.de
- KVM: PPC: Fix TCE handling for VFIO (bsc#1061840 git-fixes).
- commit b16b2e0
* Mon May 23 2022 msuchanek@suse.de
- blacklist.conf: riscv architecture not supported.
- commit c0e1845
* Mon May 23 2022 tiwai@suse.de
- i2c: mt7621: fix missing clk_disable_unprepare() on error in
  mtk_i2c_probe() (git-fixes).
- commit ee5045f
* Sun May 22 2022 bp@suse.de
- x86/speculation/mmio: Enumerate Processor MMIO Stale Data bug (bsc#1199650 CVE-2022-21166 CVE-2022-21127 CVE-2022-21123 CVE-2022-21125 CVE-2022-21180).
- commit 81d7b12
* Sun May 22 2022 tiwai@suse.de
- Input: ili210x - fix reset timing (git-fixes).
- commit 6a3dd7d
* Sat May 21 2022 tiwai@suse.de
- clk: at91: generated: consider range when calculating best rate
  (git-fixes).
- clk: bcm2835: fix bcm2835_clock_choose_div (git-fixes).
- gpio: mvebu/pwm: Refuse requests with inverted polarity
  (git-fixes).
- gpio: gpio-vf610: do not touch other bits when set the target
  bit (git-fixes).
- commit cb7aee7
* Sat May 21 2022 pvorel@suse.cz
- ping: fix the sk_bound_dev_if match in ping_lookup
  (bsc#1195826).
- commit fc7752f
* Fri May 20 2022 tiwai@suse.de
- NFC: nci: fix sleep in atomic context bugs caused by
  nci_skb_alloc (git-fixes).
- ALSA: usb-audio: Restore Rane SL-1 quirk (git-fixes).
- ALSA: hda - fix unused Realtek function when PM is not enabled
  (git-fixes).
- tty/serial: digicolor: fix possible null-ptr-deref in
  digicolor_uart_probe() (git-fixes).
- USB: serial: qcserial: add support for Sierra Wireless EM7590
  (git-fixes).
- USB: serial: option: add Fibocom MA510 modem (git-fixes).
- USB: serial: option: add Fibocom L610 modem (git-fixes).
- USB: serial: pl2303: add device id for HP LM930 Display
  (git-fixes).
- drm/nouveau/tegra: Stop using iommu_present() (git-fixes).
- ASoC: ops: Validate input values in snd_soc_put_volsw_range()
  (git-fixes).
- ASoC: max98090: Generate notifications on changes for custom
  control (git-fixes).
- ASoC: max98090: Reject invalid values in custom control put()
  (git-fixes).
- hwmon: (f71882fg) Fix negative temperature (git-fixes).
- commit f35fecc
* Thu May 19 2022 jroedel@suse.de
- kABI: Fix kABI after CVE-2022-0171 backport (CVE-2022-0171
  bsc#1199509).
- commit da4b250
* Thu May 19 2022 jroedel@suse.de
- KVM: SEV: add cache flush to solve SEV cache incoherency issues
  (CVE-2022-0171 bsc#1199509).
- commit b851a8d
* Thu May 19 2022 pvorel@suse.cz
- ping: remove pr_err from ping_lookup (bsc#1195826).
- commit d9c0959
* Thu May 19 2022 pvorel@suse.cz
- patches.suse/ping-fix-the-dif-and-sdif-check-in-ping_lookup.patch:
  (bsc#1195826).
- commit 964b9e7
* Wed May 18 2022 pmladek@suse.com
- floppy: use a statically allocated error counter (bsc#1199063
  CVE-2022-1652).
- commit 3cde83e
* Wed May 18 2022 oneukum@suse.com
- media: vim2m: Register video device after setting up internals
  (git-fixes).
- commit c68692a
* Wed May 18 2022 aabdallah@suse.de
- netfilter: nf_conntrack_tcp: re-init for syn packets only
  (bsc#1199035).
- commit adf0a01
* Wed May 18 2022 aabdallah@suse.de
- netfilter: nf_conntrack_tcp: preserve liberal flag in tcp
  options (bsc#1199035).
- commit 306abaf
* Wed May 18 2022 aabdallah@suse.de
- netfilter: conntrack: re-init state for retransmitted syn-ack
  (bsc#1199035).
- commit 9167545
* Wed May 18 2022 aabdallah@suse.de
- netfilter: conntrack: move synack init code to helper
  (bsc#1199035).
- commit 0f49ef3
* Wed May 18 2022 aabdallah@suse.de
- netfilter: conntrack: connection timeout after re-register
  (bsc#1199035).
- commit f95a3ee
* Tue May 17 2022 mkoutny@suse.com
- copy_process(): Move fd_install() out of sighand->siglock
  critical section (bsc#1199626).
- commit 7c0210b
* Tue May 17 2022 mkoutny@suse.com
- blacklist.conf: Add 7d613f9f72ec signal: Remove the bogus sigkill_pending in ptrace_stop
- commit e163427
* Tue May 17 2022 mkoutny@suse.com
- blacklist.conf: Add e7f7c99ba911 signal: In get_signal test for signal_group_exit every time through the loop
- commit b279627
* Tue May 17 2022 tiwai@suse.de
- Update patch reference for NFC fix (CVE-2022-1734 bsc#1199605).
- commit d3208d6
* Tue May 17 2022 tiwai@suse.de
- nfc: nfcmrvl: main: reorder destructive operations in
  nfcmrvl_nci_unregister_dev to avoid bugs (CVE-2022-1734
  bsc#1199605 git-fixes).
- commit 4841312
* Tue May 17 2022 oneukum@suse.com
- blacklist.conf: kABI
- commit 3cbffe4
* Tue May 17 2022 oneukum@suse.com
- blacklist.conf: fixes only a warning, generated code not changed
- commit e762772
* Tue May 17 2022 oneukum@suse.com
- blacklist.conf: depends on support for the AST2600, which we don't have
- commit 10f8b9b
* Tue May 17 2022 oneukum@suse.com
- media: platform: add missing put_device() call in
  mtk_jpeg_probe() and mtk_jpeg_remove() (git-fixes).
- commit 686e148
* Tue May 17 2022 tiwai@suse.de
- slimbus: qcom: Fix IRQ check in qcom_slim_probe (git-fixes).
- serial: 8250_mtk: Fix register address for XON/XOFF character
  (git-fixes).
- serial: 8250_mtk: Fix UART_EFR register address (git-fixes).
- usb: typec: tcpci: Don't skip cleanup in .remove() on error
  (git-fixes).
- drm/nouveau: Fix a potential theorical leak in
  nouveau_get_backlight_name() (git-fixes).
- drm/vmwgfx: Initialize drm_mode_fb_cmd2 (git-fixes).
- hwmon: (ltq-cputemp) restrict it to SOC_XWAY (git-fixes).
- hwmon: (tmp401) Add OF device ID table (git-fixes).
- Bluetooth: Fix the creation of hdev->name (git-fixes).
- drm/amd/display/dc/gpio/gpio_service: Pass around correct
  dce_{version, environment} types (git-fixes).
- commit ffb14db
* Tue May 17 2022 neilb@suse.de
- SUNRPC: Ensure that the gssproxy client can start in a connected
  state (git-fixes).
- commit d77dab5
* Tue May 17 2022 neilb@suse.de
- Revert "SUNRPC: Ensure gss-proxy connects on setup" (git-fixes).
- commit 7ee04aa
* Tue May 17 2022 neilb@suse.de
- NFS: limit use of ACCESS cache for negative responses
  (bsc#1196570).
- Refresh
  patches.kabi/NFS-pass-cred-explicitly-for-access-tests.patch.
- commit 0b13da9
* Mon May 16 2022 mkubecek@suse.cz
- Update
  patches.suse/sctp-delay-auto_asconf-init-until-binding-the-first-.patch
  headers (CVE-2021-23133 bsc#1184675).
  Remove unwanted patch headers which have hidden intended CVE and bugzilla
  references (shown above) when the patch was added. The primary purpose of
  this commit is to get the CVE/bugzilla references to git and rpm changelog.
- commit 33c2a2f
* Mon May 16 2022 oneukum@suse.com
- ata: pata_hpt37x: fix PCI clock detection (git-fixes).
- commit 8a557d3
* Mon May 16 2022 oneukum@suse.com
- sata_fsl: fix warning in remove_proc_entry when rmmod sata_fsl
  (git-fixes).
- commit 287c3d2
* Mon May 16 2022 oneukum@suse.com
- sata_fsl: fix UAF in sata_fsl_port_stop when rmmod sata_fsl
  (git-fixes).
- commit 8690a8c
* Mon May 16 2022 iivanov@suse.de
- ARM: dts: at91: fix pinctrl phandles (git-fixes)
- commit f0cde52
* Mon May 16 2022 iivanov@suse.de
- ARM: dts: at91: sama5d4_xplained: fix pinctrl phandle name (git-fixes)
- commit 61bf915
* Mon May 16 2022 tiwai@suse.de
- mmc: block: fix read single on recovery logic (CVE-2022-20008
  bsc#1199564).
- commit b8775dd
* Mon May 16 2022 oneukum@suse.com
- usb: cdc-wdm: fix reading stuck on device close (git-fixes).
- commit 8f25bcd
* Fri May 13 2022 lduncan@suse.com
- scsi: sr: Do not leak information in ioctl (git-fixes).
- scsi: pm80xx: Enable upper inbound, outbound queues (git-fixes).
- scsi: pm80xx: Mask and unmask upper interrupt vectors 32-63
  (git-fixes).
- scsi: zorro7xx: Fix a resource leak in zorro7xx_remove_one()
  (git-fixes).
- scsi: virtio-scsi: Eliminate anonymous module_init & module_exit
  (git-fixes).
- drbd: fix an invalid memory access caused by incorrect use of
  list iterator (git-fixes).
- drbd: Fix five use after free bugs in get_initial_state
  (git-fixes).
- scsi: hisi_sas: Change permission of parameter prot_mask
  (git-fixes).
- scsi: pm8001: Fix abort all task initialization (git-fixes).
- scsi: pm8001: Fix NCQ NON DATA command completion handling
  (git-fixes).
- scsi: pm8001: Fix NCQ NON DATA command task initialization
  (git-fixes).
- scsi: pm8001: Fix le32 values handling in pm80xx_chip_sata_req()
  (git-fixes).
- scsi: pm8001: Fix le32 values handling in
  pm80xx_chip_ssp_io_req() (git-fixes).
- scsi: pm8001: Fix payload initialization in
  pm80xx_encrypt_update() (git-fixes).
- scsi: pm8001: Fix le32 values handling in
  pm80xx_set_sas_protocol_timer_config() (git-fixes).
- scsi: pm8001: Fix payload initialization in
  pm80xx_set_thermal_config() (git-fixes).
- scsi: pm8001: Fix command initialization in
  pm8001_chip_ssp_tm_req() (git-fixes).
- scsi: pm8001: Fix command initialization in
  pm80XX_send_read_log() (git-fixes).
- scsi: fnic: Fix a tracing statement (git-fixes).
- commit 4f3c957
* Fri May 13 2022 lduncan@suse.com
- Added two git-fixes to be blacklisted
- commit 35e3e29
* Fri May 13 2022 tiwai@suse.de
- ptrace: Check PTRACE_O_SUSPEND_SECCOMP permission on
  PTRACE_SEIZE (CVE-2022-30594 bsc#1199505 bsc#1198413).
- commit fd4d93d
* Fri May 13 2022 tiwai@suse.de
- Add patch reference to seccomp fix (CVE-2022-30594 bsc#1199505 bsc#1198413)
  Also shorten the patch file name to standard size
- commit 483f56d
* Fri May 13 2022 tiwai@suse.de
- mac80211_hwsim: call ieee80211_tx_prepare_skb under RCU
  protection (git-fixes).
- mac80211: Reset MBSSID parameters upon connection (git-fixes).
- iwlwifi: iwl-dbg: Use del_timer_sync() before freeing
  (git-fixes).
- batman-adv: Don't skb_split skbuffs with frag_list (git-fixes).
- dim: initialize all struct fields (git-fixes).
- ASoC: meson: Fix event generation for G12A tohdmi mux
  (git-fixes).
- ASoC: da7219: Fix change notifications for tone generator
  frequency (git-fixes).
- ASoC: wm8958: Fix change notifications for DSP controls
  (git-fixes).
- firewire: core: extend card->lock in fw_core_handle_bus_reset
  (git-fixes).
- firewire: remove check of list iterator against head past the
  loop body (git-fixes).
- firewire: fix potential uaf in outbound_phy_packet_callback()
  (git-fixes).
- PCI: aardvark: Clear all MSIs at setup (git-fixes).
- commit 7fe0786
* Thu May 12 2022 tiwai@suse.de
- smsc911x: allow using IRQ0 (git-fixes).
- serial: 8250: Correct the clock for EndRun PTP/1588 PCIe device
  (git-fixes).
- USB: serial: whiteheat: fix heap overflow in
  WHITEHEAT_GET_DTR_RTS (git-fixes).
- USB: serial: cp210x: add PIDs for Kamstrup USB Meter Reader
  (git-fixes).
- USB: serial: option: add support for Cinterion MV32-WA/MV32-WB
  (git-fixes).
- USB: serial: option: add Telit 0x1057, 0x1058, 0x1075
  compositions (git-fixes).
- usb: gadget: configfs: clear deactivation flag in
  configfs_composite_unbind() (git-fixes).
- usb: misc: fix improper handling of refcount in uss720_probe()
  (git-fixes).
- xhci: increase usb U3 -> U0 link resume timeout from 100ms to
  500ms (git-fixes).
- xhci: stop polling roothubs after shutdown (git-fixes).
- thermal: int340x: Fix attr.show callback prototype (git-fixes).
- commit 432e747
* Thu May 12 2022 tiwai@suse.de
- NFC: netlink: fix sleep in atomic bug when firmware download
  timeout (git-fixes).
- nfc: nfcmrvl: main: reorder destructive operations in
  nfcmrvl_nci_unregister_dev to avoid bugs (git-fixes).
- iio: dac: ad5446: Fix read_raw not returning set value
  (git-fixes).
- iio: magnetometer: ak8975: Fix the error handling in
  ak8975_power_on() (git-fixes).
- phy: ti: Add missing pm_runtime_disable() in serdes_am654_probe
  (git-fixes).
- phy: mapphone-mdm6600: Fix PM error handling in
  phy_mdm6600_probe (git-fixes).
- phy: ti: omap-usb2: Fix error handling in
  omap_usb2_enable_clocks (git-fixes).
- phy: samsung: exynos5250-sata: fix missing device put in probe
  error paths (git-fixes).
- phy: samsung: Fix missing of_node_put() in exynos_sata_phy_probe
  (git-fixes).
- serial: 8250: Also set sticky MCR bits in console restoration
  (git-fixes).
- serial: imx: fix overrun interrupts in DMA mode (git-fixes).
- mtd: rawnand: Fix return value check of
  wait_for_completion_timeout (git-fixes).
- mtd: rawnand: fix ecc parameters for mt7622 (git-fixes).
- pinctrl: pistachio: fix use of irq_of_parse_and_map()
  (git-fixes).
- pinctrl: rockchip: fix RK3308 pinmux bits (git-fixes).
- reset: tegra-bpmp: Restore Handle errors in BPMP response
  (git-fixes).
- mt76: Fix undefined behavior due to shift overflowing the
  constant (git-fixes).
- platform/x86: samsung-laptop: Fix an unsigned comparison which
  can never be negative (git-fixes).
- PCI: Do not enable AtomicOps on VFs (git-fixes).
- PCI: iproc: Set affinity mask on MSI interrupts (git-fixes).
- commit 6ee3f02
* Thu May 12 2022 tiwai@suse.de
- ASoC: dmaengine: Restore NULL prepare_slave_config() callback
  (git-fixes).
- ALSA: fireworks: fix wrong return count shorter than expected
  by 4 bytes (git-fixes).
- gpio: pca953x: fix irq_stat not updated when irq is disabled
  (irq_mask not set) (git-fixes).
- gpiolib: of: fix bounds check for 'gpio-reserved-ranges'
  (git-fixes).
- can: grcan: use ofdev->dev when allocating DMA memory
  (git-fixes).
- can: grcan: grcan_close(): fix deadlock (git-fixes).
- iio: dac: ad5592r: Fix the missing return value (git-fixes).
- bus: sunxi-rsb: Fix the return value of
  sunxi_rsb_device_create() (git-fixes).
- clk: sunxi: sun9i-mmc: check return value after calling
  platform_get_resource() (git-fixes).
- drm/amdkfd: Fix GWS queue count (git-fixes).
- drm/i915: Fix SEL_FETCH_PLANE_*(PIPE_B+) register addresses
  (git-fixes).
- hex2bin: fix access beyond string end (git-fixes).
- ata: pata_marvell: Check the 'bmdma_addr' beforing reading
  (git-fixes).
- ALSA: usb-audio: Clear MIDI port active flag after draining
  (git-fixes).
- drm/msm/mdp5: check the return of kzalloc() (git-fixes).
- brcmfmac: sdio: Fix undefined behavior due to shift overflowing
  the constant (git-fixes).
- ALSA: usb-audio: Fix undefined behavior due to shift overflowing
  the constant (git-fixes).
- commit 12e07e6
* Wed May 11 2022 bp@suse.de
- EDAC/synopsys: Read the error count from the correct register
  (bsc#1178134).
- commit 247c29e
* Wed May 11 2022 msuchanek@suse.de
- powerpc/64s/radix: Fix huge vmap false positive (bsc#1156395).
- commit 72503c7
* Wed May 11 2022 msuchanek@suse.de
- blacklist.conf: Add 35d2f249ef0 powerpc/64s: Fix copy-paste data exposure into newly created tasks
- commit f5594b7
* Wed May 11 2022 vkarasulli@suse.de
- NFSv4: nfs_atomic_open() can race when looking up a non-regular
  file (bsc#1195612 CVE-2022-24448).
- commit db3a8ef
* Wed May 11 2022 oneukum@suse.com
- kABI: ivtv: restore caps member (git-fixes).
- commit 2c3f6cc
* Wed May 11 2022 oneukum@suse.com
- ivtv: fix incorrect device_caps for ivtvfb (git-fixes).
- commit 2ffad22
* Wed May 11 2022 oneukum@suse.com
- media: saa7134: fix incorrect use to determine if list is empty
  (git-fixes).
- commit faf8c31
* Wed May 11 2022 oneukum@suse.com
- blacklist.conf: changes API visible to user space
- commit e83f4b0
* Wed May 11 2022 oneukum@suse.com
- blacklist.conf: cleanup designed to break kABI
- commit a17a5f2
* Wed May 11 2022 oneukum@suse.com
- media: davinci: vpif: fix use-after-free on driver unbind
  (git-fixes).
- commit 0d124d5
* Wed May 11 2022 oneukum@suse.com
- media: davinci: vpif: fix unbalanced runtime PM enable
  (git-fixes).
- commit 62da1d6
* Wed May 11 2022 oneukum@suse.com
- media: davinci: Make use of the helper function
  devm_platform_ioremap_resource() (git-fixes).
- commit 8aa4890
* Wed May 11 2022 oneukum@suse.com
- media: videobuf2: Fix the size printk format (git-fixes).
- commit 0442925
* Wed May 11 2022 ohering@suse.de
- PCI: hv: Do not set PCI_COMMAND_MEMORY to reduce VM boot time (bsc#1199314).
- commit 039ffb2
* Wed May 11 2022 osalvador@suse.de
- Rename colliding patches before the next cve/linux-5.3 -> SLE15-SP3 merge
- commit 46bcd39
* Tue May 10 2022 oneukum@suse.com
- usb: mtu3: fix USB 3.0 dual-role-switch from device to host
  (git-fixes).
- commit e008ec3
* Tue May 10 2022 oneukum@suse.com
- usb: typec: ucsi: Fix role swapping (git-fixes).
- commit 0f6815d
* Tue May 10 2022 oneukum@suse.com
- usb: typec: ucsi: Fix reuse of completion structure (git-fixes).
- commit 384b054
* Tue May 10 2022 oneukum@suse.com
- USB: quirks: add STRING quirk for VCOM device (git-fixes).
- commit 9995a55
* Tue May 10 2022 oneukum@suse.com
- USB: quirks: add a Realtek card reader (git-fixes).
- commit 1c7cb74
* Tue May 10 2022 fweisbecker@suse.de
- timekeeping: Really make sure wall_to_monotonic isn't (git-fixes)
- commit e27a1b4
* Tue May 10 2022 fweisbecker@suse.de
- sched/pelt: Fix attach_entity_load_avg() corner case (git-fixes)
- commit d7997c9
* Mon May  9 2022 fweisbecker@suse.de
- genirq/affinity: Consider that CPUs on nodes can be (git-fixes)
- commit abdcbca
* Mon May  9 2022 fweisbecker@suse.de
- genirq/timings: Fix error return code in (git-fixes)
- commit 12c2013
* Mon May  9 2022 fweisbecker@suse.de
- genirq/msi: Ensure deactivation on teardown (git-fixes)
- commit f56bf3a
* Mon May  9 2022 fweisbecker@suse.de
- genirq/timings: Prevent potential array overflow in (git-fixes)
- commit 218e50c
* Mon May  9 2022 fweisbecker@suse.de
- genirq: Let GENERIC_IRQ_IPI select IRQ_DOMAIN_HIERARCHY (git-fixes)
- commit 8a841da
* Mon May  9 2022 dmueller@suse.com
- lib/raid6/test: fix multiple definition linking error
  (git-fixes).
- commit 22722bc
* Mon May  9 2022 fweisbecker@suse.de
- genirq/affinity: Handle affinity setting on inactive (git-fixes)
- commit bc0a024
* Mon May  9 2022 tiwai@suse.de
- drm/i915: Update TGL and RKL DMC firmware versions
  (bsc#1198924).
- commit cce0630
* Mon May  9 2022 fweisbecker@suse.de
- genirq: Fix reference leaks on irq affinity notifiers (git-fixes)
- commit 7b2fde0
* Mon May  9 2022 fweisbecker@suse.de
- genirq/proc: Reject invalid affinity masks (again) (git-fixes)
- commit 420a601
* Mon May  9 2022 ydfan@suse.com
- series.conf: cleanup
  - Move submitted patch to "sorted" section
    patches.suse/SUNRPC-change-locking-for-xs_swap_enable-disable.patch
- commit d411c20
* Mon May  9 2022 fweisbecker@suse.de
- timers: Fix warning condition in __run_timers() (git-fixes)
- commit 91079b8
* Mon May  9 2022 neilb@suse.de
- Revert "SUNRPC: attempt AF_LOCAL connect on setup" (git-fixes).
- SUNRPC: Ensure gss-proxy connects on setup (git-fixes).
- NFSv4: Don't invalidate inode attributes on delegation return
  (git-fixes).
- commit c794712
* Fri May  6 2022 palcantara@suse.de
- cifs: fix NULL ptr dereference in smb2_ioctl_query_info()
  (CVE-2022-0168 bsc#1197472).
- commit 5256a40
* Fri May  6 2022 palcantara@suse.de
- cifs: prevent bad output lengths in smb2_ioctl_query_info()
  (CVE-2022-0168 bsc#1197472).
- commit 3989909
* Fri May  6 2022 msuchanek@suse.de
- nvdimm/region: always show the 'align' attribute (bsc#1199114).
- commit 6437352
* Fri May  6 2022 denis.kirjanov@suse.com
- net: hns3: add a check for index in hclge_get_rss_key()
  (git-fixes).
- commit 43b8d6e
* Fri May  6 2022 denis.kirjanov@suse.com
- net: hdlc_ppp: Fix issues when mod_timer is called while timer
  is running (git-fixes).
- commit e3f1aee
* Fri May  6 2022 denis.kirjanov@suse.com
- net: bcmgenet: Fix a resource leak in an error handling path
  in the probe functin (git-fixes).
- commit 93f6ac8
* Fri May  6 2022 denis.kirjanov@suse.com
- lan743x: fix rx_napi_poll/interrupt ping-pong (git-fixes).
- commit 47f1751
* Fri May  6 2022 denis.kirjanov@suse.com
- lan743x: remove redundant assignment to variable
  rx_process_result (git-fixes).
- commit 529465d
* Fri May  6 2022 denis.kirjanov@suse.com
- series.conf: sort out patches
- commit a6ad4ca
* Fri May  6 2022 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: Also depend on dracut-systemd (bsc#1195775)
- commit 5d4e32c
* Thu May  5 2022 msuchanek@suse.de
- sched/topology: Skip updating masks for non-online nodes
  (bsc#1197446 ltc#183000).
- commit 1e43cf6
* Thu May  5 2022 msuchanek@suse.de
- Update patches.suse/powerpc-numa-Update-cpu_cpu_map-on-CPU-online-offlin.patch
  (jsc#SLE-13615 bsc#1180100 ltc#190257 git-fixes bsc#1197446 ltc#183000).
- commit 89f63a7
* Wed May  4 2022 oneukum@suse.com
- iwlwifi: mvm: fix the return type for DSM functions 1 and 2
  (git-fixes).
- commit 7bb7073
* Wed May  4 2022 mbenes@suse.cz
- objtool: Fix type of reloc::addend (git-fixes).
- commit 9c82829
* Wed May  4 2022 tbogendoerfer@suse.de
- ixgbevf: add disable link state (bsc#1196426 CVE-2021-33061).
- ixgbe: add improvement for MDD response functionality
  (bsc#1196426 CVE-2021-33061).
- ixgbe: add the ability for the PF to disable VF link state
  (bsc#1196426 CVE-2021-33061).
- commit c5d1777
* Wed May  4 2022 oneukum@suse.com
- mt76: mt7663s: fix rx buffer refcounting (git-fixes).
- commit 098565a
* Wed May  4 2022 oneukum@suse.com
- usb: dwc3: gadget: Return proper request status (git-fixes).
- commit 73a340f
* Wed May  4 2022 oneukum@suse.com
- usb: dwc3: core: Only handle soft-reset in DCTL (git-fixes).
- commit 454e4d6
* Wed May  4 2022 oneukum@suse.com
- usb: dwc3: core: Fix tx/rx threshold settings (git-fixes).
- commit c81dcdc
* Wed May  4 2022 martin.wilck@suse.com
- Revert lpfc driver update to 14.2.0.1 (bsc#1198989)
- commit eb15c95
* Wed May  4 2022 iivanov@suse.de
- blacklist.conf: ("arm64: patch_text: Fixup last cpu should be master")
- commit ec52e4c
* Wed May  4 2022 iivanov@suse.de
- blacklist.conf: ("arm64: prevent instrumentation of bp hardening callbacks")
- commit 4711dc6
* Wed May  4 2022 iivanov@suse.de
- blacklist.conf: ("arm64: dts: ls1046a: Update i2c node dma properties")
- commit 35426a5
* Wed May  4 2022 iivanov@suse.de
- blacklist.conf: ("arm64: dts: ls1043a: Update i2c dma properties")
- commit 080fa21
* Wed May  4 2022 iivanov@suse.de
- arm64: dts: rockchip: Fix SDIO regulator supply properties on (git-fixes)
- commit ff56d7c
* Wed May  4 2022 iivanov@suse.de
- arm64: dts: broadcom: Fix sata nodename (git-fixes)
- commit ae709d6
* Wed May  4 2022 iivanov@suse.de
- arm64: dts: ns2: Fix spi-cpol and spi-cpha property (git-fixes)
- commit 7fe2a15
* Wed May  4 2022 iivanov@suse.de
- arm64/mm: avoid fixmap race condition when create pud mapping (git-fixes)
- commit 86007a2
* Wed May  4 2022 ohering@suse.de
- net: mana: Remove unnecessary check of cqe_type in
  mana_process_rx_cqe() (bsc#1195651).
- net: mana: Add handling of CQE_RX_TRUNCATED (bsc#1195651).
- net: mana: Reuse XDP dropped page (bsc#1195651).
- net: mana: Add counter for XDP_TX (bsc#1195651).
- net: mana: Add counter for packet dropped by XDP (bsc#1195651).
- net: mana: Use struct_size() helper in
  mana_gd_create_dma_region() (bsc#1195651).
- commit c23f4de
* Wed May  4 2022 iivanov@suse.de
- arm64: pgtable: make __pte_to_phys/__phys_to_pte_val inline functions (git-fixes)
- commit 1b82f10
* Wed May  4 2022 iivanov@suse.de
- drivers: base: cacheinfo: Get rid of DEFINE_SMP_CALL_CACHE_FUNCTION() (git-fixes)
- commit dd7ee34
* Wed May  4 2022 iivanov@suse.de
- arm64: Always force a branch protection mode when the compiler has one (git-fixes).
  Refresh patches.suse/arm64-enable-tlbi-range-instructions.patch.
- commit fa4122b
* Tue May  3 2022 osalvador@suse.de
- Rename colliding patches before the next cve/linux-5.3 -> SLE15-SP3 merge
- commit a40b3c9
* Tue May  3 2022 tzimmermann@suse.de
- blacklist.conf: Append 'drm/tegra: Add back arm_iommu_detach_device()'
- commit f7fdb0f
* Tue May  3 2022 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix syncmap memory leak'
- commit 5ad47f2
* Tue May  3 2022 tzimmermann@suse.de
- drm/amd/display: Fix memory leak in dcn21_clock_source_create (bsc#1152472)
- commit f640496
* Tue May  3 2022 tzimmermann@suse.de
- USB: hcd-pci: Use PCI_STD_NUM_BARS when checking standard BARs (bsc#1152489)
- commit 30a990e
* Tue May  3 2022 tzimmermann@suse.de
- drm/fb-helper: Mark screen buffers in system memory with (bsc#1152472)
- commit 40b57d4
* Tue May  3 2022 tzimmermann@suse.de
- drm/amdgpu: fix amdgpu_ras_block_late_init error handler (bsc#1152489)
- commit e9f409a
* Tue May  3 2022 tzimmermann@suse.de
- drm/i915: s/JSP2/ICP2/ PCH (bsc#1152489)
- commit 20ca121
* Tue May  3 2022 tzimmermann@suse.de
- drm/cma-helper: Set VM_DONTEXPAND for mmap (bsc#1152472)
- commit dd83cfa
* Tue May  3 2022 tzimmermann@suse.de
- backlight: qcom-wled: Respect enabled-strings in set_brightness (bsc#1152489)
- commit 9612dd6
* Tue May  3 2022 tzimmermann@suse.de
- drm/vmwgfx: Remove unused compile options (bsc#1152472)
- commit fdc716b
* Tue May  3 2022 oneukum@suse.com
- mwl8k: Fix a double Free in mwl8k_probe_hw (git-fixes).
- commit 83451f5
* Tue May  3 2022 oneukum@suse.com
- adm8211: fix error return code in adm8211_probe() (git-fixes).
- blacklist.conf:
- commit 88c7ed6
* Tue May  3 2022 tbogendoerfer@suse.de
- bnx2x: fix napi API usage sequence (bsc#1198217).
- commit 62d4fc3
* Tue May  3 2022 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/i915/tgl/dsi: Gate the ddi clocks after pll mapping"'
- commit f314ea7
* Tue May  3 2022 tzimmermann@suse.de
- Revert "drm/i915/tgl/dsi: Gate the ddi clocks after pll mapping" (bsc#1152489)
- commit 3316fe5
* Tue May  3 2022 tzimmermann@suse.de
- drm/prime: Fix use after free in mmap with drm_gem_ttm_mmap (bsc#1152472)
- commit 1614767
* Tue May  3 2022 tzimmermann@suse.de
- drm/i915: Keep gem ctx->vm alive until the final put (bsc#1152489)
- commit c29d398
* Tue May  3 2022 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Drop all references to DRM IRQ midlayer'
- commit 0f90ce0
* Tue May  3 2022 tzimmermann@suse.de
- drm/i915: Drop all references to DRM IRQ midlayer (bsc#1152489)
- commit 7533a77
* Mon May  2 2022 msuchanek@suse.de
- powerpc/perf: Fix power10 event alternatives (jsc#SLE-13513
  git-fixes).
- commit 2fb7add
* Mon May  2 2022 msuchanek@suse.de
- powerpc/perf: Fix power9 event alternatives (bsc#1137728,
  LTC#178106, git-fixes).
- Revert "ibmvnic: Add ethtool private flag for driver-defined
  queue limits" (bsc#1121726 ltc#174633 git-fixes).
- commit fb3d244
* Mon May  2 2022 oneukum@suse.com
- usb: gadget: uvc: Fix crash when encoding data for usb request
  (git-fixes).
- commit 41fb68a
* Mon May  2 2022 oneukum@suse.com
- USB: Fix xhci event ring dequeue pointer ERDP update issue
  (git-fixes).
- commit a4a5749
* Mon May  2 2022 denis.kirjanov@suse.com
- net/x25: Fix null-ptr-deref caused by x25_disconnect
  (CVE-2022-1516 bsc#1199012).
- commit bd2f1ec
* Mon May  2 2022 tzimmermann@suse.de
- blacklist.conf: Append 'vt: Fix character height handling with VT_RESIZEX'
- commit c8d9e53
* Mon May  2 2022 tzimmermann@suse.de
- video: fbdev: udlfb: properly check endpoint type (bsc#1152489)
- commit 6f1b5e7
* Mon May  2 2022 tzimmermann@suse.de
- vgacon: Propagate console boot parameters before calling `vc_resize' (bsc#1152489)
- commit 9480dc7
* Fri Apr 29 2022 iivanov@suse.de
- drm/vc4: crtc: Lookup the encoder from the register at boot (bsc#1198534)
  Refresh patches.suse/drm-vc4-crtc-Make-sure-the-HDMI-controller-is-powere.patch.
- commit f23bc57
* Fri Apr 29 2022 msuchanek@suse.de
- Refresh patches.suse/nvme-pci-disable-the-write-zeros-command-for-Intel-6.patch.
  Workaround rapidquilt patch parsing bug.
- commit 87d73da
* Fri Apr 29 2022 jack@suse.cz
- bfq: Make sure bfqg for which we are queueing requests is online
  (bsc#1197926).
- bfq: Get rid of __bio_blkcg() usage (bsc#1197926).
- bfq: Track whether bfq_group is still online (bsc#1197926).
- bfq: Remove pointless bfq_init_rq() calls (bsc#1197926).
  Refresh patches.kabi/block-fixup-kabi-blk_mq_sched_try_insert_merge.patch
- bfq: Drop pointless unlock-lock pair (bsc#1197926).
- bfq: Update cgroup information before merging bio (bsc#1197926).
- bfq: Split shared queues on move between cgroups (bsc#1197926).
- bfq: Avoid merging queues with different parents (bsc#1197926).
- commit ad5069e
* Fri Apr 29 2022 msuchanek@suse.de
- Update config files (bsc#1199024).
  arm LIBNVDIMM y->m
  ppc64le ND_BLK ->m
- commit bfd0e0e
* Wed Apr 27 2022 mbenes@suse.cz
- SUNRPC: Fix the svc_deferred_event trace class (git-fixes).
- commit f31a75c
* Wed Apr 27 2022 ddiss@suse.de
- ovl: fix missing negative dentry check in ovl_rename()
  (CVE-2021-20321 bsc#1191647).
- commit 14422d8
* Wed Apr 27 2022 jgross@suse.com
- Update of patches.suse/xen-x86-obtain-full-video-frame-buffer-address-for-D.patch
- commit e4f67dd
* Wed Apr 27 2022 jgross@suse.com
- Update of patches.suse/xen-x86-obtain-upper-32-bits-of-video-frame-buffer-a.patch
- commit 62cffc1
* Wed Apr 27 2022 ydfan@suse.com
- SUNRPC: change locking for xs_swap_enable/disable (bsc#1196367).
- commit 5792732
* Tue Apr 26 2022 tabraham@suse.com
- scsi: scsi_dh_alua: Avoid crash during alua_bus_detach()
  (bsc#1028340 bsc#1198825).
- commit daeb829
* Tue Apr 26 2022 jdelvare@suse.de
- block: Drop leftover references to RQF_SORTED (bsc#1182073).
- commit 8b93fb0
* Tue Apr 26 2022 neilb@suse.de
- Report kabi after Revert "NFSv4: Handle the special Linux file
  open access mode" (git-fixes).
- commit eaf3351
* Tue Apr 26 2022 neilb@suse.de
- SUNRPC: Handle low memory situations in call_status()
  (git-fixes).
- SUNRPC: Handle ENOMEM in call_transmit_status() (git-fixes).
- SUNRPC: Ensure we flush any closed sockets before xs_xprt_free()
  (git-fixes).
- NFSv4: fix open failure with O_ACCMODE flag (git-fixes).
- Revert "NFSv4: Handle the special Linux file open access mode"
  (git-fixes).
- commit bc9b111
* Tue Apr 26 2022 neilb@suse.de
- Refresh
  patches.suse/SUNRPC-avoid-race-between-mod_timer-and-del_timer_sy.patch.
  update info now this has landed in mainline
- commit 62eff20
* Mon Apr 25 2022 oneukum@suse.com
- Input: omap4-keypad - fix pm_runtime_get_sync() error checking
  (git-fixes).
- commit ae48f44
* Mon Apr 25 2022 msuchanek@suse.de
- pahole 1.22 required for full BTF features.
  also recommend pahole for kernel-source to make the kernel buildable
  with standard config
- commit 364f54b
* Mon Apr 25 2022 oneukum@suse.com
- net: asix: add proper error handling of usb read errors
  (git-fixes).
- commit ff1011e
* Mon Apr 25 2022 oneukum@suse.com
- blacklist.conf: breaks ABI
- commit 8ec9040
* Mon Apr 25 2022 oneukum@suse.com
- Update
  patches.suse/net-usb-ax88179_178a-Fix-out-of-bounds-accesses-in-R.patch
  (bsc#1196018 CVE-2022-28748).
  added CVE number
- commit dfbe27e
* Mon Apr 25 2022 jslaby@suse.cz
- random: check for signal_pending() outside of need_resched()
  check (git-fixes).
- hwrng: cavium - HW_RANDOM_CAVIUM should depend on ARCH_THUNDER
  (git-fixes).
- ipmi: Fix UAF when uninstall ipmi_si and ipmi_msghandler module
  (git-fixes).
- ipmi: bail out if init_srcu_struct fails (git-fixes).
- ipmi: Move remove_work to dedicated workqueue (git-fixes).
- ath5k: fix building with LEDS=m (git-fixes).
- commit 628fd01
* Mon Apr 25 2022 jslaby@suse.cz
- blacklist.conf: add one ARCH_NOMADIK entry
- commit e6296cd
* Sun Apr 24 2022 tiwai@suse.de
- drm/vc4: Use pm_runtime_resume_and_get to fix
  pm_runtime_get_sync() usage (git-fixes).
- drm/panel/raspberrypi-touchscreen: Initialise the bridge in
  prepare (git-fixes).
- drm/panel/raspberrypi-touchscreen: Avoid NULL deref if not
  initialised (git-fixes).
- ASoC: codecs: wcd934x: do not switch off SIDO Buck when codec
  is in use (git-fixes).
- ASoC: msm8916-wcd-digital: Check failure for
  devm_snd_soc_register_component (git-fixes).
- ASoC: soc-dapm: fix two incorrect uses of list iterator
  (git-fixes).
- ASoC: atmel: Remove system clock tree configuration for
  at91sam9g20ek (git-fixes).
- ALSA: hda/hdmi: fix warning about PCM count when used with SOF
  (git-fixes).
- commit 964158d
* Fri Apr 22 2022 pjakobsson@suse.de
- drm/mediatek: Add AAL output size configuration (git-fixes).
- commit 655aeed
* Fri Apr 22 2022 pjakobsson@suse.de
- drm/i915: Call i915_globals_exit() if pci_register_device()
  fails (git-fixes).
- commit 1f2658b
* Fri Apr 22 2022 pjakobsson@suse.de
- blacklist.conf: 0abb33bfca0f drm/i915/gtt: drop the page table optimisation
- commit e68827f
* Fri Apr 22 2022 pjakobsson@suse.de
- blacklist.conf: 11e3c676683c drm/imx: ipuv3-plane: Remove two unnecessary export symbols
- commit 6474a0a
* Fri Apr 22 2022 pjakobsson@suse.de
- blacklist.conf: b2423184ac33 drm/i915: Enable -Wuninitialized
- commit d70d26a
* Fri Apr 22 2022 pjakobsson@suse.de
- blacklist.conf: 34b07d47dd00 drm/i915: Enable -Wuninitialized
- commit fb880ad
* Fri Apr 22 2022 pjakobsson@suse.de
- drm/mediatek: Fix aal size config (git-fixes).
- commit 0c5a7bd
* Fri Apr 22 2022 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-gem-Flush-coherency-domains-on-first-set-do.patch.
  Alt-commit
- commit 4d3e42c
* Fri Apr 22 2022 pjakobsson@suse.de
- drm/i915/gem: Flush coherency domains on first set-domain-ioctl
  (git-fixes).
- commit 174f497
* Fri Apr 22 2022 dmueller@suse.com
- use jobs not processors in the constraints
  jobs is the number of vcpus available to the build, while processors
  is the total processor count of the machine the VM is running on.
- commit a6e141d
* Fri Apr 22 2022 pjakobsson@suse.de
- Refresh
  patches.suse/0007-drm-vc4-hdmi-Make-sure-the-controller-is-powered-in-.patch.
  Alt-commit
- commit 02dff0c
* Fri Apr 22 2022 pjakobsson@suse.de
- Refresh
  patches.suse/0004-drm-amdgpu-Don-t-query-CE-and-UE-errors.patch.
  Alt-commit
- commit 875e622
* Fri Apr 22 2022 pjakobsson@suse.de
- Refresh
  patches.suse/drm-radeon-Avoid-power-table-parsing-memory-leaks.patch.
  Alt-commit
- commit 5dbb1a1
* Fri Apr 22 2022 pjakobsson@suse.de
- Refresh
  patches.suse/drm-radeon-Fix-off-by-one-power_state-index-heap-ove.patch.
  Alt-commit
- commit 0db3384
* Fri Apr 22 2022 pjakobsson@suse.de
- Refresh
  patches.suse/0003-amdgpu-fix-GEM-obj-leak-in-amdgpu_display_user_frame.patch.
  Alt-commit
- commit f3ae579
* Fri Apr 22 2022 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-gt-Prevent-use-of-engine-wa_ctx-after-error.patch.
  Alt-commit
- commit bdf1613
* Fri Apr 22 2022 tiwai@suse.de
- Update patch reference for drm fix (CVE-2022-1419 bsc#1198742)
- commit 5c0501b
* Fri Apr 22 2022 tiwai@suse.de
- dmaengine: idxd: add RO check for wq max_transfer_size write
  (git-fixes).
- dmaengine: idxd: add RO check for wq max_batch_size write
  (git-fixes).
- dmaengine: mediatek:Fix PM usage reference leak of
  mtk_uart_apdma_alloc_chan_resources (git-fixes).
- dmaengine: imx-sdma: Fix error checking in sdma_event_remap
  (git-fixes).
- dma: at_xdmac: fix a missing check on list iterator (git-fixes).
- e1000e: Fix possible overflow in LTR decoding (git-fixes).
- commit c3cb470
* Thu Apr 21 2022 tbogendoerfer@suse.de
- RDMA/hfi1: Fix use-after-free bug for mm struct (bsc#1179878
  CVE-2020-27835).
- RDMA/mlx5: Add a missing update of cache->last_add
  (jsc#SLE-15175).
- RDMA/mlx5: Don't remove cache MRs when a delay is needed
  (jsc#SLE-15175).
- IB/hfi1: Allow larger MTU without AIP (jsc#SLE-13208).
- RDMA/mlx5: Fix the flow of a miss in the allocation of a cache
  ODP MR (jsc#SLE-15175).
- RDMA/core: Set MR type in ib_reg_user_mr (jsc#SLE-8449).
- bareudp: use ipv6_mod_enabled to check if IPv6 enabled
  (jsc#SLE-15172).
- commit 8664ee1
* Thu Apr 21 2022 tiwai@suse.de
- drm/amd/display: don't ignore alpha property on pre-multiplied
  mode (git-fixes).
- ALSA: pcm: Test for "silence" field in struct "pcm_format_data"
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Clevo PD50PNT (git-fixes).
- regulator: wm8994: Add an off-on delay for WM8994 variant
  (git-fixes).
- drm/amd/display: Fix allocate_mst_payload assert on resume
  (git-fixes).
- gpu: ipu-v3: Fix dev_dbg frequency output (git-fixes).
- drm/amdkfd: Check for potential null return of kmalloc_array()
  (git-fixes).
- drm/amdkfd: Fix Incorrect VMIDs passed to HWS (git-fixes).
- drm/amd/display: Update VTEM Infopacket definition (git-fixes).
- drm/amd/display: fix audio format not updated after edid updated
  (git-fixes).
- drm/amd: Add USBC connector ID (git-fixes).
- net: usb: aqc111: Fix out-of-bounds accesses in RX fixup
  (git-fixes).
- ata: libata-core: Disable READ LOG DMA EXT for Samsung 840 EVOs
  (git-fixes).
- commit d7352af
* Thu Apr 21 2022 jroedel@suse.de
- KVM: x86/mmu: do compare-and-exchange of gPTE via the user address (CVE-2022-1158 bsc#1197660).
- commit 0581a66
* Wed Apr 20 2022 tiwai@suse.de
- Update patch reference for NFC fix (CVE-2021-38208 bsc#1187055)
- commit 37ea6b2
* Wed Apr 20 2022 msuchanek@suse.de
- Update patches.suse/powerpc-pseries-Fix-use-after-free-in-remove_phb_dyn.patch
  (bsc#1065729 bsc#1198660 ltc#197803).
- commit d408779
* Wed Apr 20 2022 tiwai@suse.de
- ath9k: Fix usage of driver-private space in tx_info (git-fixes).
- ALSA: usb-audio: Limit max buffer and period sizes per time
  (git-fixes).
- ALSA: usb-audio: Increase max buffer size (git-fixes).
- commit fa0433d
* Wed Apr 20 2022 tiwai@suse.de
- Delete patches.suse/PM-wakeup-simplify-the-output-logic-of-pm_show_wakel.patch
  The patch is superfluous (config not enabled) and would break the build.
- commit 6270819
* Wed Apr 20 2022 tiwai@suse.de
- spi: atmel-quadspi: Fix the buswidth adjustment between spi-mem
  and controller (git-fixes).
- nfc: nci: add flush_workqueue to prevent uaf (git-fixes).
- staging: mt7621-dts: fix LEDs and pinctrl on GB-PC1 devicetree
  (git-fixes).
- virtio_console: eliminate anonymous module_init & module_exit
  (git-fixes).
- w1: w1_therm: fixes w1_seq for ds28ea00 sensors (git-fixes).
- USB: usb-storage: Fix use of bitfields for hardware data in
  ene_ub6250.c (git-fixes).
- usb: dwc3: omap: fix "unbalanced disables for smps10_out1"
  on omap5evm (git-fixes).
- USB: serial: pl2303: add IBM device IDs (git-fixes).
- USB: serial: simple: add Nokia phone driver (git-fixes).
- xhci: fix runtime PM imbalance in USB2 resume (git-fixes).
- xhci: fix uninitialized string returned by
  xhci_decode_ctrl_ctx() (git-fixes).
- mtd: rawnand: atmel: fix refcount issue in
  atmel_nand_controller_init (git-fixes).
- mtd: rawnand: gpmi: fix controller timings setting (git-fixes).
- mtd: onenand: Check for error irq (git-fixes).
- spi: mxic: Fix the transmit path (git-fixes).
- power: supply: wm8350-power: Add missing free in
  free_charger_irq (git-fixes).
- power: supply: wm8350-power: Handle error for
  wm8350_register_irq (git-fixes).
- power: supply: bq24190_charger: Fix bq24190_vbus_is_enabled()
  wrong false return (git-fixes).
- power: supply: axp288-charger: Set Vhold to 4.4V (git-fixes).
- power: supply: ab8500: Fix memory leak in ab8500_fg_sysfs_init
  (git-fixes).
- power: supply: axp20x_battery: properly report current when
  discharging (git-fixes).
- power: reset: gemini-poweroff: Fix IRQ check in
  gemini_poweroff_probe (git-fixes).
- PCI: imx6: Allow to probe when dw_pcie_wait_for_link() fails
  (git-fixes).
- PCI: aardvark: Fix reading PCI_EXP_RTSTA_PME bit on emulated
  bridge (git-fixes).
- PCI: aardvark: Fix support for MSI interrupts (git-fixes).
- PCI: pciehp: Add Qualcomm quirk for Command Completed erratum
  (git-fixes).
- PCI: pciehp: Clear cmd_busy bit in polling mode (git-fixes).
- mt76: mt7615: check sta_rates pointer in
  mt7615_sta_rate_tbl_update (git-fixes).
- mt76: mt7603: check sta_rates pointer in
  mt7603_sta_rate_tbl_update (git-fixes).
- ray_cs: Check ioremap return value (git-fixes).
- video: fbdev: sm712fb: Fix crash in smtcfb_write() (git-fixes).
- video: fbdev: sm712fb: Fix crash in smtcfb_read() (git-fixes).
- video: fbdev: atari: Atari 2 bpp (STe) palette bugfix
  (git-fixes).
- video: fbdev: cirrusfb: check pixclock to avoid divide by zero
  (git-fixes).
- video: fbdev: w100fb: Reset global state (git-fixes).
- video: fbdev: nvidiafb: Use strscpy() to prevent buffer overflow
  (git-fixes).
- spi: Fix erroneous sgs value with min_t() (git-fixes).
- spi: tegra20: Use of_device_get_match_data() (git-fixes).
- PM: core: keep irq flags in device_pm_check_callbacks()
  (git-fixes).
- spi: Fix invalid sgs value (git-fixes).
- virtio_console: break out of buf poll on remove (git-fixes).
- commit a1662ac
* Wed Apr 20 2022 tiwai@suse.de
- i2c: dev: Force case user pointers in compat_i2cdev_ioctl()
  (git-fixes).
- gpiolib: acpi: use correct format characters (git-fixes).
- memory: atmel-ebi: Fix missing of_node_put in atmel_ebi_probe
  (git-fixes).
- firmware: arm_scmi: Fix sorting of retrieved clock rates
  (git-fixes).
- drm/msm/dsi: Use connector directly in
  msm_dsi_manager_connector_init() (git-fixes).
- lz4: fix LZ4_decompress_safe_partial read out of bound
  (git-fixes).
- mmc: mmci: stm32: correctly check all elements of sg list
  (git-fixes).
- drm/edid: check basic audio support on CEA extension block
  (git-fixes).
- mfd: asic3: Add missing iounmap() on error asic3_mfd_probe
  (git-fixes).
- mfd: mc13xxx: Add check for mc13xxx_irq_request (git-fixes).
- HID: i2c-hid: fix GET/SET_REPORT for unnumbered reports
  (git-fixes).
- HID: intel-ish-hid: Use dma_alloc_coherent for firmware update
  (git-fixes).
- drm/bridge: cdns-dsi: Make sure to to create proper aliases
  for dt (git-fixes).
- drm/tegra: Fix reference leak in tegra_dsi_ganged_probe
  (git-fixes).
- drm/amd/display: Remove vupdate_int_entry definition
  (git-fixes).
- drm/amdkfd: make CRAT table missing message informational only
  (git-fixes).
- drm/amdgpu: Fix recursive locking warning (git-fixes).
- drm/amd/display: Fix a NULL pointer dereference in
  amdgpu_dm_connector_add_common_modes() (git-fixes).
- drm/amd/amdgpu/amdgpu_cs: fix refcount leak of a dma_fence obj
  (git-fixes).
- drm: Add orientation quirk for GPD Win Max (git-fixes).
- drm/edid: Don't clear formats if using deep color (git-fixes).
- drm/bridge: Add missing pm_runtime_disable() in
  __dw_mipi_dsi_probe (git-fixes).
- iwlwifi: mvm: Fix an error code in iwl_mvm_up() (git-fixes).
- iwlwifi: Fix -EIO error code that is never returned (git-fixes).
- media: cx88-mpeg: clear interrupt status register before
  streaming video (git-fixes).
- media: hdpvr: initialize dev->worker at hdpvr_register_videodev
  (git-fixes).
- mmc: host: Return an error when ->enable_sdio_irq() ops is
  missing (git-fixes).
- KEYS: fix length validation in keyctl_pkey_params_get_2()
  (git-fixes).
- mmc: mmci_sdmmc: Replace sg_dma_xxx macros (git-fixes).
- commit f6dc585
* Wed Apr 20 2022 tiwai@suse.de
- cfg80211: hold bss_lock while updating nontrans_list
  (git-fixes).
- ath9k: Properly clear TX status area before reporting to
  mac80211 (git-fixes).
- ALSA: usb-audio: Cap upper limits of buffer/period bytes for
  implicit fb (git-fixes).
- dmaengine: Revert "dmaengine: shdma: Fix runtime PM imbalance
  on error" (git-fixes).
- clk: Enforce that disjoints limits are invalid (git-fixes).
- clk: si5341: fix reported clk_rate when output divider is 2
  (git-fixes).
- dma-debug: fix return value of __setup handlers (git-fixes).
- Documentation: update stable tree link (git-fixes).
- Documentation: add link to stable release candidate tree
  (git-fixes).
- drm/bridge: Fix free wrong object in sii8620_init_rcp_input_dev
  (git-fixes).
- Bluetooth: btmtksdio: Fix kernel oops in btmtksdio_interrupt
  (git-fixes).
- Bluetooth: Fix use after free in hci_send_acl (git-fixes).
- carl9170: fix missing bit-wise or operator for tx_params
  (git-fixes).
- brcmfmac: pcie: Fix crashes due to early IRQs (git-fixes).
- brcmfmac: pcie: Replace brcmf_pcie_copy_mem_todev with
  memcpy_toio (git-fixes).
- brcmfmac: firmware: Allocate space for default boardrev in nvram
  (git-fixes).
- brcmfmac: pcie: Release firmwares in the brcmf_pcie_setup
  error path (git-fixes).
- ath9k_htc: fix uninit value bugs (git-fixes).
- ath5k: fix OOB in ath5k_eeprom_read_pcal_info_5111 (git-fixes).
- ath10k: fix memory overwrite of the WoWLAN wakeup packet pattern
  (git-fixes).
- Bluetooth: hci_serdev: call init_rwsem() before p->open()
  (git-fixes).
- ALSA: hda/realtek: Add alc256-samsung-headphone fixup
  (git-fixes).
- ASoC: soc-compress: Change the check for codec_dai (git-fixes).
- ASoC: soc-compress: prevent the potentially use of null pointer
  (git-fixes).
- ASoC: soc-core: skip zero num_dai component in searching dai
  name (git-fixes).
- ACPI: processor idle: Check for architectural support for LPI
  (git-fixes).
- ACPI/APEI: Limit printable size of BERT table data (git-fixes).
- ACPICA: Avoid walking the ACPI Namespace if it is not there
  (git-fixes).
- commit d3a3908
* Tue Apr 19 2022 ailiop@suse.com
- fibmap: Reject negative block numbers (bsc#1198448).
- commit a2724a8
* Tue Apr 19 2022 ailiop@suse.com
- fibmap: Use bmap instead of ->bmap method in ioctl_fibmap
  (bsc#1198448).
- commit d8c35f2
* Tue Apr 19 2022 denis.kirjanov@suse.com
- af_key: add __GFP_ZERO flag for compose_sadb_supported in
  function pfkey_register (CVE-2022-1353 bsc#1198516).
- commit 981f1ec
* Tue Apr 19 2022 tbogendoerfer@suse.de
- Update
  patches.suse/RDMA-rtrs-clt-Fix-possible-double-free-in-error-case.patch
  (jsc#SLE-15176 bsc#1198515 CVE-2022-29156).
  Added CVE reference.
- commit 377f598
* Thu Apr 14 2022 vkarasulli@suse.de
- SUNRPC: Ensure we flush any closed sockets before
  xs_xprt_free() (bsc#1198330 CVE-2022-28893).
- commit f607730
* Wed Apr 13 2022 tiwai@suse.de
- Update patch reference for dma-buf fix (CVE-2021-0707 bsc#1198437)
- commit 05bffce
* Tue Apr 12 2022 mkoutny@suse.com
- ptrace: Check PTRACE_O_SUSPEND_SECCOMP permission on
  PTRACE_SEIZE (bsc#1198413).
- commit daaf8a2
* Tue Apr 12 2022 mkoutny@suse.com
- blacklist.conf: Add 460a79e18842 mm/memcontrol: return 1 from cgroup.memory __setup() handler
- commit 91b4481
* Tue Apr 12 2022 mkoutny@suse.com
- Update patches.suse/cgroup-verify-that-source-is-a-string.patch
  (bsc#1190131 bsc#1193842 CVE-2021-4154).
- commit 0f6b5cd
* Tue Apr 12 2022 tiwai@suse.de
- Update patch references of drm fixes (CVE-2022-1280 bsc#1197914)
- commit 5e3bc51
* Tue Apr 12 2022 shung-hsi.yu@suse.com
- bpf: Resolve to prog->aux->dst_prog->type only for
  BPF_PROG_TYPE_EXT (git-fixes bsc#1177028).
- commit 3b5cd8a
* Mon Apr 11 2022 oneukum@suse.com
- blacklist.conf: kABI
- commit 2d0be1f
* Mon Apr 11 2022 tiwai@suse.de
- Update patch reference for DRM fix (CVE-2021-20292 bsc#1183723)
- commit f6cdff5
* Mon Apr 11 2022 tiwai@suse.de
- spi: bcm-qspi: fix MSPI only access with bcm_qspi_exec_mem_op()
  (git-fixes).
- mmc: renesas_sdhi: don't overwrite TAP settings when HS400
  tuning is complete (git-fixes).
- Revert "mmc: sdhci-xenon: fix annoying 1.8V regulator warning"
  (git-fixes).
- drm/imx: Fix memory leak in imx_pd_connector_get_modes
  (git-fixes).
- drm/amdgpu: fix off by one in amdgpu_gfx_kiq_acquire()
  (git-fixes).
- commit 5e07dff
* Sun Apr 10 2022 lduncan@suse.com
- scsi: mpt3sas: Fix use after free in
  _scsih_expander_node_remove() (git-fixes).
- commit 139e22c
* Sun Apr 10 2022 lduncan@suse.com
- scsi: libsas: Fix sas_ata_qc_issue() handling of NCQ NON DATA
  commands (git-fixes).
- scsi: mpt3sas: Page fault in reply q processing (git-fixes).
- commit 1ac8b89
* Fri Apr  8 2022 tbogendoerfer@suse.de
- Update
  patches.suse/RDMA-cma-Do-not-change-route.addr.src_addr.ss_family.patch
  (bsc#1181147 bsc#1192845 CVE-2021-43975).
  Added CVE reference
- commit 3261376
* Fri Apr  8 2022 lhenriques@suse.de
- fuse: handle kABI change in struct fuse_req (bsc#1197343
  CVE-2022-1011).
- fuse: fix pipe buffer lifetime for direct_io (bsc#1197343
  CVE-2022-1011).
- commit 5920a58
* Fri Apr  8 2022 jroedel@suse.de
- x86/sev: Unroll string mmio with CC_ATTR_GUEST_UNROLL_STRING_IO
  (git-fixes).
- commit caea381
* Fri Apr  8 2022 tiwai@suse.de
- Update patch reference for NFS/RDMA fix (CVE-2022-0812 bsc#1196639)
- commit 7e276c6
* Fri Apr  8 2022 mbenes@suse.cz
- livepatch: Don't block removal of patches that are safe to
  unload (bsc#1071995).
- commit 21cea26
* Fri Apr  8 2022 tiwai@suse.de
- ata: sata_dwc_460ex: Fix crash due to OOB write (git-fixes).
- ASoC: mediatek: mt6358: add missing EXPORT_SYMBOLs (git-fixes).
- ALSA: hda/realtek: Fix audio regression on Mi Notebook Pro 2020
  (git-fixes).
- ALSA: cs4236: fix an incorrect NULL check on list iterator
  (git-fixes).
- rtc: check if __rtc_read_time was successful (git-fixes).
- rtc: wm8350: Handle error for wm8350_register_irq (git-fixes).
- USB: storage: ums-realtek: fix error code in rts51x_read_mem()
  (git-fixes).
- commit 1e2cb1a
* Fri Apr  8 2022 tiwai@suse.de
- Move upstreamed ALSA, BT and input patches into sorted section
- commit d4e3d80
* Thu Apr  7 2022 bp@suse.de
- x86/speculation: Restore speculation related MSRs during S3
  resume (bsc#1198400).
- commit aece496
* Thu Apr  7 2022 iivanov@suse.de
- arm64: dts: marvell: armada-37xx: Remap IO space to bus address 0x0 (git-fixes)
- commit 087a75e
* Thu Apr  7 2022 iivanov@suse.de
- arm64: clear_page() shouldn't use DC ZVA when DCZID_EL0.DZP == 1 (git-fixes)
- commit cb1ef60
* Thu Apr  7 2022 iivanov@suse.de
- arm64: dts: lx2160a: fix scl-gpios property name (git-fixes)
- commit e6f7c40
* Thu Apr  7 2022 iivanov@suse.de
- arm64: dts: allwinner: orangepi-zero-plus: fix PHY mode (git-fixes)
- commit 5770b13
* Thu Apr  7 2022 iivanov@suse.de
- blacklist.conf: ("arm64: dts: rockchip: fix audio-supply for Rock Pi 4")
- commit 65a864d
* Thu Apr  7 2022 iivanov@suse.de
- arm64: dts: rockchip: remove mmc-hs400-enhanced-strobe from (git-fixes)
- commit 66efebd
* Thu Apr  7 2022 iivanov@suse.de
- arm64: dts: rockchip: Fix GPU register width for RK3328 (git-fixes)
- commit 1a4266e
* Thu Apr  7 2022 bp@suse.de
- x86/pm: Save the MSR validity status at context setup
  (bsc#1198400).
- commit 2364cfa
* Thu Apr  7 2022 iivanov@suse.de
- arm64: dts: allwinner: h5: NanoPI Neo 2: Fix ethernet node (git-fixes)
- commit 45ad518
* Thu Apr  7 2022 iivanov@suse.de
- arm64/sve: Use correct size when reinitialising SVE state (git-fixes)
- commit 470d68d
* Thu Apr  7 2022 iivanov@suse.de
- arm64: dts: marvell: armada-37xx: Extend PCIe MEM space (git-fixes)
- commit 9b2d9f5
* Thu Apr  7 2022 iivanov@suse.de
- arm64: dts: exynos: correct GIC CPU interfaces address range on (git-fixes)
- commit 146ef42
* Thu Apr  7 2022 iivanov@suse.de
- arm64: head: avoid over-mapping in map_memory (git-fixes)
- commit 027cf90
* Thu Apr  7 2022 iivanov@suse.de
- arm64: dts: ls1028a: fix node name for the sysclk (git-fixes)
- commit 6684287
* Thu Apr  7 2022 iivanov@suse.de
- arm64: dts: marvell: armada-37xx: Fix reg for standard variant of (git-fixes)
- commit 4fac006
* Thu Apr  7 2022 iivanov@suse.de
- blacklist.conf: ("arm64/mm: Fix ttbr0 values stored in struct thread_info for")
- commit db10f73
* Thu Apr  7 2022 iivanov@suse.de
- arm64: dts: zii-ultra: fix 12V_MAIN voltage (git-fixes)
- commit c603535
* Thu Apr  7 2022 iivanov@suse.de
- arm64: dts: ls1028a: fix memory node (git-fixes)
- commit 578cf73
* Thu Apr  7 2022 iivanov@suse.de
- blacklist.conf: ("arm64: Change .weak to SYM_FUNC_START_WEAK_PI for")
- commit 61796af
* Wed Apr  6 2022 jack@suse.cz
- direct-io: defer alignment check until after the EOF check
  (bsc#1197656).
- commit 709fa3b
* Wed Apr  6 2022 jack@suse.cz
- direct-io: don't force writeback for reads beyond EOF
  (bsc#1197656).
- commit 8628885
* Wed Apr  6 2022 jack@suse.cz
- direct-io: clean up error paths of do_blockdev_direct_IO
  (bsc#1197656).
- commit 16ec2fe
* Wed Apr  6 2022 jgross@suse.com
- xen: fix is_xen_pmu() (git-fixes).
- commit b66d3d5
* Wed Apr  6 2022 jgross@suse.com
- xen/blkfront: fix comment for need_copy (git-fixes).
- commit 0c15cd4
* Wed Apr  6 2022 jgross@suse.com
- blacklist.conf: add 1dbd11ca75 ("xen: remove gnttab_query_foreign_access()")
- commit f877952
* Tue Apr  5 2022 msuchanek@suse.de
- powerpc/perf: Expose Performance Monitor Counter SPR's as part
  of extended regs (bsc#1198077 ltc#197299).
- powerpc/perf: Include PMCs as part of per-cpu cpuhw_events
  struct (bsc#1198077 ltc#197299).
- commit 141f049
* Tue Apr  5 2022 mkubecek@suse.cz
- Update
  patches.suse/llc-fix-netdevice-reference-leaks-in-llc_ui_bind.patch
  references (add CVE-2022-28356 bsc#1197391).
- commit bf5ad66
* Tue Apr  5 2022 palcantara@suse.de
- cifs: fix bad fids sent over wire (bsc#1197157).
- commit 604b674
* Tue Apr  5 2022 palcantara@suse.de
- cifs: do not skip link targets when an I/O fails (bsc#1194625).
- commit e700718
* Tue Apr  5 2022 ptesarik@suse.cz
- s390/tape: fix timer initialization in tape_std_assign()
  (bsc#1197677 LTC#197378).
- commit cc6ef16
* Tue Apr  5 2022 tiwai@suse.de
- drm: drm_file struct kABI compatibility workaround
  (bsc#1197914).
- commit dd24982
* Tue Apr  5 2022 tiwai@suse.de
- drm: use the lookup lock in drm_is_current_master (bsc#1197914).
- drm: protect drm_master pointers in drm_lease.c (bsc#1197914).
- drm: serialize drm_file.master with a new spinlock
  (bsc#1197914).
- drm: add a locked version of drm_is_current_master
  (bsc#1197914).
- commit 82a498a
* Tue Apr  5 2022 tiwai@suse.de
- drm: drm_file struct kABI compatibility workaround
  (bsc#1197914).
- commit 7d8a3b5
* Tue Apr  5 2022 tiwai@suse.de
- drm: use the lookup lock in drm_is_current_master (bsc#1197914).
- drm: protect drm_master pointers in drm_lease.c (bsc#1197914).
- drm: serialize drm_file.master with a new spinlock
  (bsc#1197914).
- drm: add a locked version of drm_is_current_master
  (bsc#1197914).
- commit 05fda16
* Tue Apr  5 2022 tiwai@suse.de
- blacklist.conf: Add reverted/reverting swiotlb change (CVE-2022-0854 bsc#1196823 bsc#1197460)
- commit 8d52c36
* Tue Apr  5 2022 tiwai@suse.de
- Reinstate some of "swiotlb: rework "fix info leak with
  DMA_FROM_DEVICE"" (CVE-2022-0854 bsc#1196823).
- swiotlb: fix info leak with DMA_FROM_DEVICE (CVE-2022-0854
  bsc#1196823).
- commit ff554b5
* Tue Apr  5 2022 neilb@suse.de
- blacklist.conf: list unneeded commit
- commit 27adcc4
* Tue Apr  5 2022 neilb@suse.de
- NFSv4/pNFS: Fix another issue with a list iterator pointing
  to the head (git-fixes).
- NFSv4.1: don't retry BIND_CONN_TO_SESSION on session error
  (git-fixes).
- NFS: Return valid errors from nfs2/3_decode_dirent()
  (git-fixes).
- NFS: Use of mapping_set_error() results in spurious errors
  (git-fixes).
- commit 0460a48
* Mon Apr  4 2022 mkubecek@suse.cz
- netfilter: nf_tables: initialize registers in nft_do_chain()
  (CVE-2022-1016 bsc#1197227).
- commit 7111961
* Mon Apr  4 2022 mkubecek@suse.cz
- Delete
  patches.suse/net-tipc-validate-domain-record-count-on-input.patch.
  This was the original work-in-progress patch for CVE-2022-0435 /
  bsc#1195254. Later, a proper backport of mainline commit 9aa422ad3266
  ("tipc: improve size validations for received domain records") was added as
  patches.suse/tipc-improve-size-validations-for-received-domain-re.patch but
  this patch was left in place. As it adds the check a bit later than
  upstream fix, it did not cause a conflict so nobody noticed the duplicity.
- commit ef08708
* Mon Apr  4 2022 mkubecek@suse.cz
- llc: fix netdevice reference leaks in llc_ui_bind() (git-fixes).
- commit 2237578
* Mon Apr  4 2022 tiwai@suse.de
- net: kABI workaround for ax25_dev (CVE-2022-1199 bsc#1198028).
- commit 49e69cc
* Mon Apr  4 2022 tiwai@suse.de
- ax25: Fix UAF bugs in ax25 timers (CVE-2022-1205 bsc#1198027).
- ax25: fix UAF bug in ax25_send_control() (CVE-2022-1205
  bsc#1198027).
- ax25: Fix NULL pointer dereferences in ax25 timers
  (CVE-2022-1205 bsc#1198027).
- ax25: Fix refcount leaks caused by ax25_cb_del() (CVE-2022-1205
  bsc#1198027).
- ax25: fix UAF bugs of net_device caused by rebinding operation
  (CVE-2022-1205 bsc#1198027).
- ax25: fix reference count leaks of ax25_dev (CVE-2022-1205
  bsc#1198027).
- commit cfa1c37
* Mon Apr  4 2022 tiwai@suse.de
- Update patch reference for ax25 fixes (CVE-2022-1199 bsc#1198028)
- commit 1b5a483
* Mon Apr  4 2022 tiwai@suse.de
- ax25: fix NPD bug in ax25_disconnect (CVE-2022-1199
  bsc#1198028).
- ax25: add refcount in ax25_dev to avoid UAF bugs (CVE-2022-1199
  bsc#1198028).
- commit f30e94a
* Mon Apr  4 2022 tiwai@suse.de
- drivers: hamradio: 6pack: fix UAF bug caused by mod_timer()
  (CVE-2022-1198 bsc#1198030).
- commit 6da2b7d
* Mon Apr  4 2022 tiwai@suse.de
- hamradio: remove needs_free_netdev to avoid UAF (CVE-2022-1195
  bsc#1198029).
- commit fcd70e2
* Mon Apr  4 2022 tiwai@suse.de
- hamradio: improve the incomplete fix to avoid NPD (CVE-2022-1195
  bsc#1198029).
- hamradio: defer 6pack kfree after unregister_netdev
  (CVE-2022-1195 bsc#1198029).
- hamradio: defer ax25 kfree after unregister_netdev
  (CVE-2022-1195 bsc#1198029).
- net: hamradio: fix memory leak in mkiss_close (CVE-2022-1195
  bsc#1198029).
- commit d30e348
* Mon Apr  4 2022 tiwai@suse.de
- can: mcba_usb: mcba_usb_start_xmit(): fix double dev_kfree_skb
  in error path (CVE-2022-28389 bsc#1198033).
- can: usb_8dev: usb_8dev_start_xmit(): fix double dev_kfree_skb()
  in error path (CVE-2022-28388 bsc#1198032).
- can: ems_usb: ems_usb_start_xmit(): fix double dev_kfree_skb()
  in error path (CVE-2022-28390 bsc#1198031).
- commit d6e6523
* Mon Apr  4 2022 mkubecek@suse.cz
- tcp: add some entropy in __inet_hash_connect() (bsc#1180153).
- tcp: change source port randomizarion at connect() time
  (bsc#1180153).
- commit 96da58a
* Mon Apr  4 2022 neilb@suse.de
- VFS: filename_create(): fix incorrect intent (bsc#1197534).
- commit bd0a18b
* Fri Apr  1 2022 bp@suse.de
- KVM: SVM: Don't flush cache if hardware enforces cache coherency
  across encryption domains (bsc#1178134).
- commit 706a179
* Fri Apr  1 2022 ptesarik@suse.cz
- i915_vma: Rename vma_lookup to i915_vma_lookup (git-fixes).
- commit e2095ad
* Fri Apr  1 2022 msuchanek@suse.de
- powerpc/lib/sstep: Fix 'sthcx' instruction (bsc#1156395).
- powerpc/perf: Don't use perf_hw_context for trace IMC PMU
  (bsc#1156395).
- commit 130da3b
* Fri Apr  1 2022 mhocko@suse.com
- mm/page_alloc.c: do not warn allocation failure on zone DMA
  if no managed pages (bsc#1197501).
- dma/pool: create dma atomic pool only if dma zone has managed
  pages (bsc#1197501).
- mm_zone: add function to check if managed dma zone exists
  (bsc#1197501).
- commit c0f79a1
* Fri Apr  1 2022 dwagner@suse.de
- wireguard: socket: ignore v6 endpoints when ipv6 is disabled
  (git-fixes).
- wireguard: socket: free skb in send6 when ipv6 is disabled
  (git-fixes).
- wireguard: queueing: use CFI-safe ptr_ring cleanup function
  (git-fixes).
- wireguard: selftests: rename DEBUG_PI_LIST to DEBUG_PLIST
  (git-fixes).
- commit 972eb7f
* Fri Apr  1 2022 dwagner@suse.de
- scsi: lpfc: Fix locking for lpfc_sli_iocbq_lookup()
  (bsc#1197675).
- scsi: lpfc: Fix broken SLI4 abort path (bsc#1197675).
- scsi: lpfc: Update lpfc version to 14.2.0.1 (bsc#1197675).
- scsi: lpfc: Fix queue failures when recovering from PCI parity
  error (bsc#1197675 bsc#1196478).
- scsi: lpfc: Fix unload hang after back to back PCI EEH faults
  (bsc#1197675 bsc#1196478).
- scsi: lpfc: Improve PCI EEH Error and Recovery Handling
  (bsc#1197675 bsc#1196478).
- commit 6fc0429
* Fri Apr  1 2022 tiwai@suse.de
- ACPI: CPPC: Avoid out of bounds access when parsing _CPC data
  (git-fixes).
- can: mcba_usb: properly check endpoint type (git-fixes).
- can: mcba_usb: mcba_usb_start_xmit(): fix double dev_kfree_skb
  in error path (git-fixes).
- can: ems_usb: ems_usb_start_xmit(): fix double dev_kfree_skb()
  in error path (git-fixes).
- pwm: lpc18xx-sct: Initialize driver data and hardware before
  pwmchip_add() (git-fixes).
- remoteproc: qcom_wcnss: Add missing of_node_put() in
  wcnss_alloc_memory_region (git-fixes).
- remoteproc: qcom: Fix missing of_node_put in
  adsp_alloc_memory_region (git-fixes).
- clk: qcom: gcc-msm8994: Fix gpll4 width (git-fixes).
- clk: qcom: clk-rcg2: Update the frac table for pixel clock
  (git-fixes).
- clk: qcom: clk-rcg2: Update logic to calculate D value for RCG
  (git-fixes).
- clk: qcom: ipq8074: Use floor ops for SDCC1 clock (git-fixes).
- clk: uniphier: Fix fixed-rate initialization (git-fixes).
- clk: Initialize orphan req_rate (git-fixes).
- clk: bcm2835: Remove unused variable (git-fixes).
- clk: tegra: tegra124-emc: Fix missing put_device() call in
  emc_ensure_emc_driver (git-fixes).
- clk: clps711x: Terminate clk_div_table with sentinel element
  (git-fixes).
- clk: loongson1: Terminate clk_div_table with sentinel element
  (git-fixes).
- clk: actions: Terminate clk_div_table with sentinel element
  (git-fixes).
- clk: imx7d: Remove audio_mclk_root_clk (git-fixes).
- clk: nxp: Remove unused variable (git-fixes).
- commit 01f6f64
* Thu Mar 31 2022 pmladek@suse.com
- printk: disable optimistic spin during panic (bsc#1197894).
- commit 0716386
* Thu Mar 31 2022 pmladek@suse.com
- printk: Add panic_in_progress helper (bsc#1197894).
- commit f29520c
* Thu Mar 31 2022 pmladek@suse.com
- blacklist.conf: printk: cosmetic problem
- commit eabafef
* Thu Mar 31 2022 pmladek@suse.com
- vsprintf: Fix %%pK with kptr_restrict == 0 (bsc#1197889).
- commit dcd324e
* Thu Mar 31 2022 fdmanana@suse.com
- btrfs: Remove unnecessary check from join_running_log_trans
  (bsc#1194649).
- commit dc4697b
* Thu Mar 31 2022 fdmanana@suse.com
- btrfs: do not commit delayed inode when logging a file in full
  sync mode (bsc#1194649).
- btrfs: do not log new dentries when logging that a new name
  exists (bsc#1194649).
- commit b03bb01
* Thu Mar 31 2022 pmladek@suse.com
- Revert "module, async: async_synchronize_full() on module init
  iff async is used" (bsc#1197888).
- commit 2252be2
* Thu Mar 31 2022 fdmanana@suse.com
- btrfs: avoid unnecessary lock and leaf splits when updating
  inode in the log (bsc#1194649).
- btrfs: remove unnecessary list head initialization when syncing
  log (bsc#1194649).
- btrfs: avoid unnecessary log mutex contention when syncing log
  (bsc#1194649).
- commit c49b58c
* Thu Mar 31 2022 fdmanana@suse.com
- btrfs: avoid unnecessary logging of xattrs during fast fsyncs
  (bsc#1194649).
- commit bcb58d4
* Thu Mar 31 2022 fdmanana@suse.com
- btrfs: check error value from btrfs_update_inode in tree log
  (bsc#1194649).
- btrfs: fixup error handling in fixup_inode_link_counts
  (bsc#1194649).
- commit 215b0a5
* Thu Mar 31 2022 fdmanana@suse.com
- btrfs: remove unnecessary directory inode item update when
  deleting dir entry (bsc#1194649).
- commit ebbb134
* Thu Mar 31 2022 bp@suse.de
- x86/mm/pat: Don't flush cache if hardware enforces cache
  coherency across encryption domnains (bsc#1178134).
- commit ed78280
* Thu Mar 31 2022 fdmanana@suse.com
- btrfs: fix race leading to unnecessary transaction commit when
  logging inode (bsc#1194649).
- btrfs: fix race that makes inode logging fallback to transaction
  commit (bsc#1194649).
- btrfs: fix race that causes unnecessary logging of ancestor
  inodes (bsc#1194649).
- btrfs: fix race that results in logging old extents during a
  fast fsync (bsc#1194649).
- commit 54994e0
* Thu Mar 31 2022 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.2.0.0 patches
  (bsc#1197675).
- scsi: lpfc: Update lpfc version to 14.2.0.0 (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor BSG paths (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor Abort paths (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor SCSI paths (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor CT paths (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor misc ELS paths
  (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor VMID paths (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor FDISC paths (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor LS_RJT paths (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor LS_ACC paths (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor the RSCN/SCR/RDF/EDC/FARPR
  paths (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor PLOGI/PRLI/ADISC/LOGO paths
  (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor base ELS paths and the
  FLOGI path (bsc#1197675).
- scsi: lpfc: SLI path split: Introduce lpfc_prep_wqe
  (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor fast and slow paths to
  native SLI4 (bsc#1197675).
- scsi: lpfc: SLI path split: Refactor lpfc_iocbq (bsc#1197675).
- scsi: lpfc: Use kcalloc() (bsc#1197675).
- scsi: lpfc: Fix typos in comments (bsc#1197675).
- scsi: lpfc: Remove failing soft_wwn support (bsc#1197675).
- scsi: lpfc: Use rport as argument for lpfc_chk_tgt_mapped()
  (bsc#1197675).
- scsi: lpfc: Use rport as argument for lpfc_send_taskmgmt()
  (bsc#1197675).
- scsi: lpfc: Use fc_block_rport() (bsc#1197675).
- scsi: lpfc: Drop lpfc_no_handler() (bsc#1197675).
- scsi: lpfc: Kill lpfc_bus_reset_handler() (bsc#1197675).
- scsi: lpfc: Remove redundant flush_workqueue() call
  (bsc#1197675).
- scsi: lpfc: Reduce log messages seen after firmware download
  (bsc#1197675).
- scsi: lpfc: Remove NVMe support if kernel has NVME_FC disabled
  (bsc#1197675).
- commit e642242
* Thu Mar 31 2022 fdmanana@suse.com
- btrfs: check if a log tree exists at inode_logged()
  (bsc#1194649).
- commit 1fd0acd
* Thu Mar 31 2022 fdmanana@suse.com
- btrfs: remove no longer needed full sync flag check at
  inode_logged() (bsc#1194649).
- btrfs: eliminate some false positives when checking if inode
  was logged (bsc#1194649).
- commit df30719
* Thu Mar 31 2022 fdmanana@suse.com
- btrfs: skip unnecessary searches for xattrs when logging an
  inode (bsc#1194649).
- commit e2ffdf0
* Thu Mar 31 2022 fdmanana@suse.com
- btrfs: check if a log root exists before locking the log_mutex
  on unlink (bsc#1194649).
- Refresh
  patches.suse/0002-btrfs-qgroup-try-to-flush-qgroup-space-when-we-get-E.patch.
- commit 2097b4a
* Thu Mar 31 2022 jack@suse.cz
- ext2: correct max file size computing (bsc#1197820).
- commit f1d2053
* Thu Mar 31 2022 jack@suse.cz
- block/wbt: fix negative inflight counter when remove scsi device
  (bsc#1197819).
- commit 6f18f30
* Thu Mar 31 2022 jack@suse.cz
- block: update io_ticks when io hang (bsc#1197817).
- commit 4ee5ce6
* Thu Mar 31 2022 jack@suse.cz
- fscrypt: don't ignore minor_hash when hash is 0 (bsc#1197815).
- commit 0c58e0d
* Thu Mar 31 2022 jack@suse.cz
- ecryptfs: fix kernel panic with null dev_name (bsc#1197812).
- commit 18f264d
* Thu Mar 31 2022 jack@suse.cz
- ecryptfs: Fix typo in message (bsc#1197811).
- commit 9a64b6f
* Wed Mar 30 2022 tiwai@suse.de
- ALSA: pcm: Fix potential AB/BA lock with buffer_mutex and
  mmap_lock (CVE-2022-1048 bsc#1197331).
- Refresh
  patches.kabi/ALSA-kABI-workaround-for-snd_pcm_runtime-changes.patch.
- commit 2d63590
* Wed Mar 30 2022 tiwai@suse.de
- ALSA: pcm: Fix potential AB/BA lock with buffer_mutex and
  mmap_lock (CVE-2022-1048 bsc#1197331).
- Refresh
  patches.kabi/ALSA-kABI-workaround-for-snd_pcm_runtime-changes.patch.
- commit db7647d
* Wed Mar 30 2022 shung-hsi.yu@suse.com
- bpf: Remove config check to enable bpf support for branch
  records (git-fixes bsc#1177028).
- commit 5fff22c
* Wed Mar 30 2022 tiwai@suse.de
- net: sched: fix use-after-free in tc_new_tfilter()
  (CVE-2022-1055 bsc#1197702).
- commit 4c7dc78
* Wed Mar 30 2022 oneukum@suse.com
- net: mcs7830: handle usb read errors properly (git-fixes).
- commit b5b4cb6
* Wed Mar 30 2022 oneukum@suse.com
- blacklist.conf: kABI
- commit 79d1df3
* Wed Mar 30 2022 oneukum@suse.com
- blacklist.conf: cleanup, not a bugfix
- commit 3a5b1ab
* Wed Mar 30 2022 oneukum@suse.com
- blacklist.conf: cleanup, not a bugfix
- commit a1c1b85
* Wed Mar 30 2022 oneukum@suse.com
- Revert "usb: dwc3: gadget: Use list_replace_init() before
  traversing lists" (git-fixes).
- commit 978c488
* Tue Mar 29 2022 dwagner@suse.de
- scsi: qla2xxx: Fix typos in comments (bsc#1197661).
- scsi: qla2xxx: Update version to 10.02.07.400-k (bsc#1197661).
- scsi: qla2xxx: Increase max limit of ql2xnvme_queues
  (bsc#1197661).
- scsi: qla2xxx: Use correct feature type field during RFF_ID
  processing (bsc#1197661).
- scsi: qla2xxx: Fix stuck session of PRLI reject (bsc#1197661).
- scsi: qla2xxx: Reduce false trigger to login (bsc#1197661).
- scsi: qla2xxx: Fix laggy FC remote port session recovery
  (bsc#1197661).
- scsi: qla2xxx: Fix hang due to session stuck (bsc#1197661).
- scsi: qla2xxx: Fix N2N inconsistent PLOGI (bsc#1197661).
- scsi: qla2xxx: Fix crash during module load unload test
  (bsc#1197661).
- scsi: qla2xxx: Fix missed DMA unmap for NVMe ls requests
  (bsc#1197661).
- scsi: qla2xxx: Fix loss of NVMe namespaces after driver reload
  test (bsc#1197661).
- scsi: qla2xxx: Fix disk failure to rediscover (bsc#1197661).
- scsi: qla2xxx: Fix incorrect reporting of task management
  failure (bsc#1197661).
- scsi: qla2xxx: Use named initializers for q_dev_state
  (bsc#1197661).
- scsi: qla2xxx: Use named initializers for port_state_str
  (bsc#1197661).
- scsi: qla2xxx: Stop using the SCSI pointer (bsc#1197661).
- commit d7f7c48
* Tue Mar 29 2022 msuchanek@suse.de
- powerpc/pseries: Fix use after free in remove_phb_dynamic()
  (bsc#1065729).
- powerpc/tm: Fix more userspace r13 corruption (bsc#1065729).
- powerpc/xive: fix return value of __setup handler (bsc#1065729).
- powerpc/sysdev: fix incorrect use to determine if list is empty
  (bsc#1065729).
- commit 14ca561
* Tue Mar 29 2022 oneukum@suse.com
- usb: bdc: Fix a resource leak in the error handling path of
  'bdc_probe()' (git-fixes).
- commit b8afee8
* Tue Mar 29 2022 oneukum@suse.com
- usb: bdc: remove duplicated error message (git-fixes).
- commit 3971aef
* Tue Mar 29 2022 oneukum@suse.com
- usb: bdc: Fix unused assignment in bdc_probe() (git-fixes).
- commit 0a2966f
* Tue Mar 29 2022 oneukum@suse.com
- usb: bdc: Use devm_clk_get_optional() (git-fixes).
- commit f4c7fea
* Tue Mar 29 2022 oneukum@suse.com
- usb: bdc: Adb shows offline after resuming from S2 (git-fixes).
- commit 3293f5c
* Tue Mar 29 2022 oneukum@suse.com
- usb: gadget: bdc: use readl_poll_timeout() to simplify code
  (git-fixes).
- commit 686f431
* Tue Mar 29 2022 tiwai@suse.de
- net: phy: broadcom: Fix brcm_fet_config_init() (git-fixes).
- serial: 8250: Fix race condition in RTS-after-send handling
  (git-fixes).
- serial: 8250_lpss: Balance reference count for PCI DMA device
  (git-fixes).
- serial: 8250_mid: Balance reference count for PCI DMA device
  (git-fixes).
- serial: core: Fix the definition name in the comment of UPF_*
  flags (git-fixes).
- soundwire: intel: fix wrong register name in intel_shim_wake
  (git-fixes).
- misc: sgi-gru: Don't cast parameter in bit operations
  (git-fixes).
- VMCI: Fix the description of vmci_check_host_caps() (git-fixes).
- misc: alcor_pci: Fix an error handling path (git-fixes).
- pinctrl/rockchip: Add missing of_node_put() in
  rockchip_pinctrl_probe (git-fixes).
- pinctrl: nomadik: Add missing of_node_put() in nmk_pinctrl_probe
  (git-fixes).
- pinctrl: mediatek: paris: Fix pingroup pin config state readback
  (git-fixes).
- pinctrl: mediatek: paris: Fix "argument" argument type for
  mtk_pinconf_get() (git-fixes).
- pinctrl: pinconf-generic: Print arguments for bias-pull-*
  (git-fixes).
- pinctrl: mediatek: Fix missing of_node_put() in mtk_pctrl_init
  (git-fixes).
- pinctrl: nuvoton: npcm7xx: Rename DS() macro to DSTR()
  (git-fixes).
- pinctrl: nuvoton: npcm7xx: Use %%zu printk format for
  ARRAY_SIZE() (git-fixes).
- mac80211: fix potential double free on mesh join (git-fixes).
- commit ed99607
* Tue Mar 29 2022 oneukum@suse.com
- usb: bdc: use devm_platform_ioremap_resource() to simplify code
  (git-fixes).
- commit d8de3ca
* Tue Mar 29 2022 tiwai@suse.de
- driver core: dd: fix return value of __setup handler
  (git-fixes).
- firmware: google: Properly state IOMEM dependency (git-fixes).
- iio: accel: mma8452: use the correct logic to get mma8452_data
  (git-fixes).
- iio: adc: Add check for devm_request_threaded_irq (git-fixes).
- staging:iio:adc:ad7280a: Fix handing of device address bit
  reversing (git-fixes).
- iio: afe: rescale: use s64 for temporary scale calculations
  (git-fixes).
- iio: inkern: make a best effort on offset calculation
  (git-fixes).
- iio: inkern: apply consumer scale when no channel scale is
  available (git-fixes).
- iio: inkern: apply consumer scale on IIO_VAL_INT cases
  (git-fixes).
- ALSA: pci: fix reading of swapped values from pcmreg in AC97
  codec (git-fixes).
- ALSA: pcm: Add stream lock during PCM reset ioctl operations
  (git-fixes).
- ALSA: oss: Fix PCM OSS buffer allocation overflow (git-fixes).
- ALSA: hda/realtek: Add quirk for ASUS GA402 (git-fixes).
- ALSA: usb-audio: Add mute TLV for playback volumes on RODE
  NT-USB (git-fixes).
- ALSA: hda/realtek - Fix headset mic problem for a HP machine
  with alc671 (git-fixes).
- ACPI: video: Force backlight native for Clevo NL5xRU and NL5xNU
  (git-fixes).
- ACPI: battery: Add device HID and quirk for Microsoft Surface
  Go 3 (git-fixes).
- ACPI / x86: Work around broken XSDT on Advantech DAC-BJ01 board
  (git-fixes).
- drm/vc4: crtc: Fix runtime_pm reference counting (git-fixes).
- commit 34d0dc9
* Tue Mar 29 2022 shung-hsi.yu@suse.com
- blacklist.conf: Add 1e9d74660d4d "bpf: Fix mount source show for bpffs"
  Missing required dependency
- commit 5a8e47e
* Tue Mar 29 2022 shung-hsi.yu@suse.com
- udp_tunnel: Fix end of loop test in udp_tunnel_nic_unregister()
  (git-fixes).
- commit 36f2c3d
* Tue Mar 29 2022 shung-hsi.yu@suse.com
- bpf: Fix comment for helper bpf_current_task_under_cgroup()
  (git-fixes).
- commit b94b06c
* Mon Mar 28 2022 bp@suse.de
- x86/cpu: Add hardware-enforced cache coherency as a CPUID
  feature (bsc#1178134).
- Refresh patches.suse/x86-cpufeatures-add-sev-es-cpu-feature.
- commit 9b8fd9f
* Mon Mar 28 2022 denis.kirjanov@suse.com
- Metadata update
- commit 20a72ea
* Mon Mar 28 2022 tiwai@suse.de
- Revert "Input: clear BTN_RIGHT/MIDDLE on buttonpads"
  (bsc#1197243).
- commit 1e324a1
* Mon Mar 28 2022 tiwai@suse.de
- Drop HID multitouch fix patch (bsc#1197243)
  Delete patches.suse/HID-multitouch-fix-Dell-Precision-7550-and-7750-butt.patch.
  Replaced with another revert patch.
- commit 169cf98
* Mon Mar 28 2022 oneukum@suse.com
- usb: dwc3: qcom: add IRQ check (git-fixes).
- commit 0f04f35
* Mon Mar 28 2022 oneukum@suse.com
- usb: dwc3: gadget: Use list_replace_init() before traversing
  lists (git-fixes).
- commit fa45b43
* Mon Mar 28 2022 oneukum@suse.com
- xhci: fix garbage USBSTS being logged in some cases (git-fixes).
- commit 6c80c92
* Mon Mar 28 2022 jack@suse.cz
- Add CVE tags to
  patches.suse/ext4-fix-kernel-infoleak-via-ext4_extent_header.patch
  (bsc#1189562 bsc#1196761 CVE-2022-0850).
- commit f3cb08f
* Mon Mar 28 2022 pjakobsson@suse.de
- blacklist.conf: 3a84fd1ed535 drm/i915/display: Fix HPD short pulse handling for eDP
- commit ae70ffd
* Mon Mar 28 2022 pjakobsson@suse.de
- drm/i915/gem: add missing boundary check in vm_access
  (git-fixes).
- commit 99cd925
* Mon Mar 28 2022 pjakobsson@suse.de
- drm/msm/dpu: add DSPP blocks teardown (git-fixes).
- commit 9c986de
* Mon Mar 28 2022 pjakobsson@suse.de
- drm/bridge: dw-hdmi: use safe format when first in bridge chain
  (git-fixes).
- commit 38ac9a8
* Mon Mar 28 2022 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-Fix-bw-atomic-check-when-switching-between-.patch.
  Alt-commit
- commit 81cf826
* Mon Mar 28 2022 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-Correctly-populate-use_sagv_wm-for-all-pipe.patch.
  Alt-commit
- commit 9f55faf
* Mon Mar 28 2022 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-Fix-dbuf-slice-config-lookup.patch.
  Alt-commit
- commit eb12d1f
* Mon Mar 28 2022 pjakobsson@suse.de
- drm/amd/display: Add affected crtcs to atomic state for dsc
  mst unplug (git-fixes).
- commit 1b3e76b
* Mon Mar 28 2022 pjakobsson@suse.de
- blacklist.conf: 3f3a24a0a3a5 drm/amdgpu: Don\'t offset by 2 in FRU EEPROM
- commit 6877985
* Mon Mar 28 2022 pjakobsson@suse.de
- drm/amd/pm: return -ENOTSUPP if there is no
  get_dpm_ultimate_freq function (git-fixes).
- commit fb7d1f2
* Mon Mar 28 2022 pjakobsson@suse.de
- drm/nouveau/acr: Fix undefined behavior in
  nvkm_acr_hsfw_load_bl() (git-fixes).
- commit 4a1a717
* Mon Mar 28 2022 pjakobsson@suse.de
- drm/doc: overview before functions for drm_writeback.c
  (git-fixes).
- commit 6d05b7f
* Mon Mar 28 2022 pjakobsson@suse.de
- drm: bridge: adv7511: Fix ADV7535 HPD enablement (git-fixes).
- commit 8027fb9
* Mon Mar 28 2022 pjakobsson@suse.de
- drm/bridge: nwl-dsi: Fix PM disable depth imbalance in
  nwl_dsi_probe (git-fixes).
- commit c253ca8
* Mon Mar 28 2022 pjakobsson@suse.de
- drm/meson: Fix error handling when afbcd.ops->init fails
  (git-fixes).
- commit 42a3562
* Mon Mar 28 2022 pjakobsson@suse.de
- drm/meson: osd_afbcd: Add an exit callback to struct
  meson_afbcd_ops (git-fixes).
- commit f2138e4
* Mon Mar 28 2022 msuchanek@suse.de
- powerpc/mm/numa: skip NUMA_NO_NODE onlining in
  parse_numa_properties() (bsc#1179639 ltc#189002 git-fixes).
- commit 4765cfb
* Mon Mar 28 2022 pjakobsson@suse.de
- video: fbdev: controlfb: Fix COMPILE_TEST build (git-fixes).
- commit 047d2b7
* Mon Mar 28 2022 pjakobsson@suse.de
- video: fbdev: matroxfb: set maxvram of vbG200eW to the same
  as vbG200 to avoid black screen (git-fixes).
- commit 3094fd1
* Mon Mar 28 2022 pjakobsson@suse.de
- drm/vc4: crtc: Make sure the HDMI controller is powered when
  disabling (git-fixes).
- commit 0e082ec
* Fri Mar 25 2022 denis.kirjanov@suse.com
- esp: Fix possible buffer overflow in ESP transformation
  (bsc#1197131 CVE-2022-0886 CVE-2022-27666).
- commit 39a5891
* Fri Mar 25 2022 vkarasulli@suse.de
- Update
  patches.suse/quota-check-block-number-when-reading-the-block-in-q.patch
  (bsc#1194589 bsc#1197366 CVE-2021-45868).
- commit 1a6f8a7
* Thu Mar 24 2022 tiwai@suse.de
- pinctrl: samsung: drop pin banks references on error paths
  (git-fixes).
- memory: emif: check the pointer temp in get_device_details()
  (git-fixes).
- memory: emif: Add check for setup_interrupts (git-fixes).
- soc: qcom: aoss: remove spurious IRQF_ONESHOT flags (git-fixes).
- soc: qcom: rpmpd: Check for null return of devm_kcalloc
  (git-fixes).
- soc: ti: wkup_m3_ipc: Fix IRQ check in wkup_m3_ipc_probe
  (git-fixes).
- media: usb: go7007: s2250-board: fix leak in probe()
  (git-fixes).
- media: em28xx: initialize refcount before kref_get (git-fixes).
- media: stk1160: If start stream fails, return buffers with
  VB2_BUF_STATE_QUEUED (git-fixes).
- media: Revert "media: em28xx: add missing
  em28xx_close_extension" (git-fixes).
- media: video/hdmi: handle short reads of hdmi info frame
  (git-fixes).
- media: aspeed: Correct value for h-total-pixels (git-fixes).
- media: hantro: Fix overfill bottom register field name
  (git-fixes).
- media: coda: Fix missing put_device() call in coda_get_vdoa_data
  (git-fixes).
- media: bttv: fix WARNING regression on tunerless devices
  (git-fixes).
- video: fbdev: omapfb: Add missing of_node_put() in dvic_probe_of
  (git-fixes).
- video: fbdev: fbcvt.c: fix printing in fb_cvt_print_name()
  (git-fixes).
- video: fbdev: atmel_lcdfb: fix an error code in
  atmel_lcdfb_probe() (git-fixes).
- video: fbdev: smscufx: Fix null-ptr-deref in ufx_usb_probe()
  (git-fixes).
- video: fbdev: matroxfb: set maxvram of vbG200eW to the same
  as vbG200 to avoid black screen (git-fixes).
- mmc: davinci_mmc: Handle error for clk_enable (git-fixes).
- usb: usbtmc: Fix bug in pipe direction for control transfers
  (git-fixes).
- net: phy: marvell: Fix invalid comparison in the resume and
  suspend functions (git-fixes).
- commit 33bac97
* Thu Mar 24 2022 tiwai@suse.de
- firmware: qcom: scm: Remove reassignment to desc following
  initializer (git-fixes).
- ASoC: sti: Fix deadlock via snd_pcm_stop_xrun() call
  (git-fixes).
- ASoC: codecs: wcd934x: Add missing of_node_put() in
  wcd934x_codec_parse_data (git-fixes).
- ASoC: msm8916-wcd-analog: Fix error handling in
  pm8916_wcd_analog_spmi_probe (git-fixes).
- ASoC: msm8916-wcd-digital: Fix missing clk_disable_unprepare()
  in msm8916_wcd_digital_probe (git-fixes).
- ASoC: imx-es8328: Fix error return code in imx_es8328_probe()
  (git-fixes).
- ASoC: fsl_spdif: Disable TX clock when stop (git-fixes).
- ASoC: SOF: topology: remove redundant code (git-fixes).
- ASoC: dmaengine: do not use a NULL prepare_slave_config()
  callback (git-fixes).
- ASoC: mxs: Fix error handling in mxs_sgtl5000_probe (git-fixes).
- ASoC: SOF: Add missing of_node_put() in imx8m_probe (git-fixes).
- ASoC: fsi: Add check for clk_enable (git-fixes).
- ASoC: wm8350: Handle error for wm8350_register_irq (git-fixes).
- ASoC: atmel: Add missing of_node_put() in
  at91sam9g20ek_audio_probe (git-fixes).
- ASoC: dwc-i2s: Handle errors for clk_enable (git-fixes).
- ASoC: atmel_ssc_dai: Handle errors for clk_enable (git-fixes).
- ASoC: mxs-saif: Handle errors for clk_enable (git-fixes).
- ASoC: ti: davinci-i2s: Add check for clk_enable() (git-fixes).
- ASoC: rt5663: check the return value of devm_kzalloc() in
  rt5663_parse_dp() (git-fixes).
- ASoC: xilinx: xlnx_formatter_pcm: Handle sysclk setting
  (git-fixes).
- ASoC: topology: Optimize soc_tplg_dapm_graph_elems_load behavior
  (git-fixes).
- ASoC: topology: Allow TLV control to be either read or write
  (git-fixes).
- ALSA: spi: Add check for clk_enable() (git-fixes).
- ALSA: cmipci: Restore aux vol on suspend/resume (git-fixes).
- ASoC: codecs: wcd934x: fix return value of
  wcd934x_rx_hph_mode_put (git-fixes).
- ALSA: firewire-lib: fix uninitialized flag for AV/C deferred
  transaction (git-fixes).
- media: davinci: vpif: fix unbalanced runtime PM get (git-fixes).
- drm/panel: simple: Fix Innolux G070Y2-L01 BPP settings
  (git-fixes).
- commit 364280e
* Thu Mar 24 2022 tiwai@suse.de
- ALSA: pcm: Fix races among concurrent prealloc proc writes
  (CVE-2022-1048 bsc#1197331).
- ALSA: pcm: Fix races among concurrent prepare and
  hw_params/hw_free calls (CVE-2022-1048 bsc#1197331).
- ALSA: pcm: Fix races among concurrent read/write and buffer
  changes (CVE-2022-1048 bsc#1197331).
- ALSA: pcm: Fix races among concurrent hw_params and hw_free
  calls (CVE-2022-1048 bsc#1197331).
- commit 0f1f53e
* Thu Mar 24 2022 ematsumiya@suse.de
- cifs: use the correct max-length for dentry_path_raw()
  (bsc1196196).
- commit d014f56
* Wed Mar 23 2022 bp@suse.de
- blacklist.conf: a5ce9f2bb665 x86/speculation: Merge one test in spectre_v2_user_select_mitigation()
- commit 2d7347b
* Wed Mar 23 2022 jeffm@suse.com
- config: enable DEBUG_INFO_BTF
  This option allows users to access the btf type information for vmlinux
  but not kernel modules.
- commit fb07e10
* Wed Mar 23 2022 vkarasulli@suse.de
- quota: check block number when reading the block in quota file
  (bsc#1197366 CVE-2021-45868).
- commit a7d4915
* Tue Mar 22 2022 tiwai@suse.de
- ALSA: kABI workaround for snd_pcm_runtime changes (CVE-2022-1048
  bsc#1197331).
- commit 8a9b87d
* Tue Mar 22 2022 tiwai@suse.de
- ALSA: kABI workaround for snd_pcm_runtime changes (CVE-2022-1048
  bsc#1197331).
- commit 12628f8
* Tue Mar 22 2022 tiwai@suse.de
- ALSA: pcm: Fix races among concurrent prealloc proc writes
  (CVE-2022-1048 bsc#1197331).
- ALSA: pcm: Fix races among concurrent prepare and
  hw_params/hw_free calls (CVE-2022-1048 bsc#1197331).
- ALSA: pcm: Fix races among concurrent read/write and buffer
  changes (CVE-2022-1048 bsc#1197331).
- ALSA: pcm: Fix races among concurrent hw_params and hw_free
  calls (CVE-2022-1048 bsc#1197331).
- commit aee063f
* Tue Mar 22 2022 fweisbecker@suse.de
- membarrier: Execute SYNC_CORE on the calling thread (git-fixes)
- commit 8c138d0
* Tue Mar 22 2022 lhenriques@suse.de
- fuse: handle kABI change in struct fuse_args (bsc#1197343
  CVE-2022-1011).
- fuse: fix pipe buffer lifetime for direct_io (bsc#1197343
  CVE-2022-1011).
- commit 112493c
* Tue Mar 22 2022 tiwai@suse.de
- spi: pxa2xx-pci: Balance reference count for PCI DMA device
  (git-fixes).
- spi: tegra114: Add missing IRQ check in tegra_spi_probe
  (git-fixes).
- regulator: qcom_smd: fix for_each_child.cocci warnings
  (git-fixes).
- hwmon: (pmbus) Add Vin unit off handling (git-fixes).
- hwmon: (sch56xx-common) Replace WDOG_ACTIVE with WDOG_HW_RUNNING
  (git-fixes).
- hwmon: (pmbus) Add mutex to regulator ops (git-fixes).
- crypto: ccp - ccp_dmaengine_unregister release dma channels
  (git-fixes).
- crypto: cavium/nitrox - don't cast parameter in bit operations
  (git-fixes).
- crypto: vmx - add missing dependencies (git-fixes).
- hwrng: atmel - disable trng on failure path (git-fixes).
- crypto: ccree - don't attempt 0 len DMA mappings (git-fixes).
- crypto: qat - don't cast parameter in bit operations
  (git-fixes).
- crypto: mxs-dcp - Fix scatterlist processing (git-fixes).
- crypto: authenc - Fix sleep in atomic context in decrypt_tail
  (git-fixes).
- crypto: rsa-pkcs1pad - fix buffer overread in
  pkcs1pad_verify_complete() (git-fixes).
- crypto: rsa-pkcs1pad - restore signature length check
  (git-fixes).
- crypto: rsa-pkcs1pad - correctly get hash from source
  scatterlist (git-fixes).
- thermal: int340x: Increase bitmap size (git-fixes).
- thermal: int340x: Check for NULL after calling kmemdup()
  (git-fixes).
- PM: suspend: fix return value of __setup handler (git-fixes).
- PM: hibernate: fix __setup handler error handling (git-fixes).
- ACPI: docs: enumeration: Remove redundant .owner assignment
  (git-fixes).
- ACPI: docs: enumeration: Update UART serial bus resource
  documentation (git-fixes).
- ACPI: docs: enumeration: Discourage to use custom _DSM methods
  (git-fixes).
- ACPI: APEI: fix return value of __setup handlers (git-fixes).
- clocksource: acpi_pm: fix return value of __setup handler
  (git-fixes).
- ACPI: properties: Consistently return -ENOENT if there are no
  more references (git-fixes).
- clocksource/drivers/timer-of: Check return value of of_iomap
  in timer_of_base_init() (git-fixes).
- Input: aiptek - properly check endpoint type (git-fixes).
- usb: gadget: Fix use-after-free bug by not setting
  udc->dev.driver (git-fixes).
- usb: gadget: rndis: prevent integer overflow in
  rndis_set_response() (git-fixes).
- drm/vrr: Set VRR capable prop only if it is attached to
  connector (git-fixes).
- nl80211: Update bss channel on channel switch for P2P_CLIENT
  (git-fixes).
- iwlwifi: don't advertise TWT support (git-fixes).
- mac80211: refuse aggregations sessions before authorized
  (git-fixes).
- can: rcar_canfd: rcar_canfd_channel_probe(): register the CAN
  device when fully ready (git-fixes).
- commit 240077f
* Tue Mar 22 2022 fweisbecker@suse.de
- membarrier: Explicitly sync remote cores when SYNC_CORE is (git-fixes)
- commit 4fc5228
* Tue Mar 22 2022 fweisbecker@suse.de
- blacklist.conf: Add 2ecedd756908 ("membarrier: Add an actual barrier before rseq_preempt()")
- commit e7a5059
* Tue Mar 22 2022 fweisbecker@suse.de
- cpufreq: schedutil: Destroy mutex before kobject_put() frees (git-fixes)
- commit 3a3c855
* Tue Mar 22 2022 aabdallah@suse.de
- netfilter: conntrack: don't refresh sctp entries in closed state
  (bsc#1197389).
- commit d30cf2f
* Tue Mar 22 2022 neilb@suse.de
- NFS: Do not report writeback errors in nfs_getattr()
  (git-fixes).
- NFS: LOOKUP_DIRECTORY is also ok with symlinks (git-fixes).
- NFS: Fix initialisation of nfs_client cl_flags field
  (git-fixes).
- NFS: Avoid duplicate uncached readdir calls on eof (git-fixes).
- NFS: Don't skip directory entries when doing uncached readdir
  (git-fixes).
- nfsd: nfsd4_setclientid_confirm mistakenly expires confirmed
  client (git-fixes).
- NFS: Ensure the server has an up to date ctime before
  hardlinking (git-fixes).
- commit 0dffa33
* Mon Mar 21 2022 bp@suse.de
- blacklist.conf: fbd5969d1ff2 x86/cpufeatures: Mark two free bits in word 3
- commit 7de8046
* Mon Mar 21 2022 dmueller@suse.com
- rpm/constraints.in: skip SLOW_DISK workers for kernel-source
- commit e84694f
* Mon Mar 21 2022 denis.kirjanov@suse.com
- net: hns3: add a check for tqp_index in
  hclge_get_ring_chain_from_mbx() (git-fixes).
- commit 197c612
* Mon Mar 21 2022 denis.kirjanov@suse.com
- net: watchdog: hold device global xmit lock during tx disable
  (git-fixes).
- commit 5f626af
* Mon Mar 21 2022 denis.kirjanov@suse.com
- net: stmmac: set TxQ mode back to DCB after disabling CBS
  (git-fixes).
- commit 64e0e15
* Mon Mar 21 2022 denis.kirjanov@suse.com
- net: enetc: initialize the RFS and RSS memories (git-fixes).
- commit 48628ab
* Mon Mar 21 2022 denis.kirjanov@suse.com
- net: dsa: mv88e6xxx: override existent unicast portvec in
  port_fdb_add (git-fixes).
- commit d733e4e
* Mon Mar 21 2022 denis.kirjanov@suse.com
- team: protect features update by RCU to avoid deadlock
  (git-fixes).
- commit 0917ada
* Mon Mar 21 2022 denis.kirjanov@suse.com
- netxen_nic: fix MSI/MSI-x interrupts (git-fixes).
- commit e20b4bd
* Mon Mar 21 2022 msuchanek@suse.de
- Update config files.
- commit 5e3d4fd
* Mon Mar 21 2022 pjakobsson@suse.de
- drm/i915: Fix dbuf slice config lookup (git-fixes).
- commit 2e1e919
* Mon Mar 21 2022 pjakobsson@suse.de
- drm/imx: parallel-display: Remove bus flags check in
  imx_pd_bridge_atomic_check() (git-fixes).
- commit 37de9a5
* Mon Mar 21 2022 msuchanek@suse.de
- macros.kernel-source: Fix conditional expansion.
  Fixes: bb95fef3cf19 ("rpm: Use bash for %%() expansion (jsc#SLE-18234).")
- commit 7e857f7
* Mon Mar 21 2022 msuchanek@suse.de
- ibmvnic: fix race between xmit and reset (bsc#1197302
  ltc#197259).
- commit 1372669
* Mon Mar 21 2022 msuchanek@suse.de
- Revert "Revert "build initrd without systemd" (bsc#1197300)"
  This reverts commit ff2b28e76a7040ae5ce82c0145965d62159216fd.
- commit 72ed14f
* Mon Mar 21 2022 msuchanek@suse.de
- Update config files (bsc#1195926 bsc#1175667).
  VIRTIO_PCI=m -> VIRTIO_PCI=y
- commit 3edad5c
* Mon Mar 21 2022 denis.kirjanov@suse.com
- Revert "Revert "rpm/kernel-source.spec.in: call fdupes per subpackage""
  This reverts commit f349b8133b949dee1721081d9fbc80cc43327d15.
  Which was propagated from my local local tree. Restore the commit
- commit ee9cedc
* Sat Mar 19 2022 msuchanek@suse.de
- rpm: Use bash for %%() expansion (jsc#SLE-18234).
  Since 15.4 alternatives for /bin/sh are provided by packages
  <something>-sh. While the interpreter for the build script can be
  selected the interpreter for %%() cannot.
  The kernel spec files use bashisms in %%().
  While this could technically be fixed there is more serious underlying
  problem: neither bash nor any of the alternatives are 100%% POSIX
  compliant nor bug-free.
  It is not my intent to maintain bug compatibility with any number of
  shells for shell scripts embedded in the kernel spec file. The spec file
  syntax is not documented so embedding the shell script in it causes some
  unspecified transformation to be applied to it. That means that
  ultimately any changes must be tested by building the kernel, n times if
  n shells are supported.
  To reduce maintenance effort require that bash is used for kernel build
  always.
- commit bb95fef
* Sat Mar 19 2022 bp@suse.de
- x86/speculation: Warn about Spectre v2 LFENCE mitigation
  (bsc#1178134).
- Refresh
  patches.suse/x86-speculation-warn-about-eibrs-lfence-unprivileged-ebpf-smt.patch.
- commit 8588aa6
* Sat Mar 19 2022 msuchanek@suse.de
- powerpc/mm: Fix verification of MMU_FTR_TYPE_44x (bsc#1156395).
- commit 5c5db21
* Sat Mar 19 2022 bp@suse.de
- x86/speculation: Warn about eIBRS + LFENCE + Unprivileged eBPF +
  SMT (bsc#1178134).
- commit a719566
* Sat Mar 19 2022 tiwai@suse.de
- HID: multitouch: fix Dell Precision 7550 and 7750 button type
  (bsc#1197243).
- commit 53c2db3
* Fri Mar 18 2022 bp@suse.de
- Sort in upstreamed BHB patches
- Refresh
  patches.suse/documentation-hw-vuln-update-spectre-doc.patch.
- Refresh
  patches.suse/x86-speculation-add-eibrs-retpoline-options.patch.
- Refresh
  patches.suse/x86-speculation-include-unprivileged-ebpf-status-in-spectre-v2-mitigation-reporting.patch.
- Refresh
  patches.suse/x86-speculation-rename-retpoline_amd-to-retpoline_lfence.patch.
- Refresh
  patches.suse/x86-speculation-use-generic-retpoline-by-default-on-amd.patch.
- commit 4062a7a
* Fri Mar 18 2022 ptesarik@suse.cz
- s390/mm: fix VMA and page table handling code in storage key
  handling functions (git-fixes).
- s390/mm: validate VMA in PGSTE manipulation functions
  (git-fixes).
- s390/gmap: don't unconditionally call pte_unmap_unlock()
  in __gmap_zap() (git-fixes).
- s390/gmap: validate VMA in __gmap_zap() (git-fixes).
- s390/pci_mmio: fully validate the VMA before calling
  follow_pte() (git-fixes).
- mm: add vma_lookup(), update find_vma_intersection() comments
  (git-fixes).
- commit 808c094
* Fri Mar 18 2022 denis.kirjanov@suse.com
- Revert "rpm/kernel-source.spec.in: call fdupes per subpackage"
  This reverts commit 1da843983718d4cfdd652a76e428abee98e37450.
- commit f349b81
* Fri Mar 18 2022 tiwai@suse.de
- Revert "build initrd without systemd" (bsc#1197300)
  This reverts commit ef4c569b998635a9369390d4e9cfe3a922815c76.
  It seems to be the cause of a stall in OBS build that resulted in
  the failure with obs-build-qa (and possibly others).
- commit ff2b28e
* Fri Mar 18 2022 ptesarik@suse.cz
- net/smc: Reset conn->lgr when link group registration fails
  (git-fixes).
- net/smc: fix using of uninitialized completions (git-fixes).
- net/smc: fix wrong list_del in smc_lgr_cleanup_early
  (git-fixes).
- net/smc: Fix loop in smc_listen (git-fixes).
- net/smc: Make sure the link_id is unique (git-fixes).
- commit 759dc2b
* Fri Mar 18 2022 ptesarik@suse.cz
- blacklist.conf: net/smc cleanup with no functional change
- commit 5a33cbb
* Thu Mar 17 2022 tiwai@suse.de
- Update patch reference for USB gadget fix (CVE-2022-27223 bsc#1197245)
- commit fd3b6e8
* Thu Mar 17 2022 ptesarik@suse.cz
- s390/hypfs: include z/VM guests with access control group set
  (bsc#1195640 LTC#196352).
- commit 598f26f
* Thu Mar 17 2022 oneukum@suse.com
- net: usb: ax88179_178a: Fix out-of-bounds accesses in RX fixup
  (bsc#1196018).
- commit 1580ab2
* Thu Mar 17 2022 oneukum@suse.com
- ax88179_178a: Merge memcpy + le32_to_cpus to get_unaligned_le32
  (bsc#1196018).
- commit 1cdc779
* Wed Mar 16 2022 osalvador@suse.de
- Rename colliding patches before the next cve/linux-5.3 -> SLE15-SP3 merge
- commit 891ddc4
* Wed Mar 16 2022 msuchanek@suse.de
- rpm: Run external scriptlets on uninstall only when available
  (bsc#1196514 bsc#1196114 bsc#1196942).
  When dependency cycles are encountered package dependencies may not be
  fulfilled during zypper transaction at the time scriptlets are run.
  This is a problem for kernel scriptlets provided by suse-module-tools
  when migrating to a SLE release that provides these scriptlets only as
  part of LTSS. The suse-module-tools that provides kernel scriptlets may
  be removed early causing migration to fail.
- commit ab8dd2d
* Wed Mar 16 2022 oneukum@suse.com
- sr9700: sanity check for packet length (bsc#1196836
  CVE-2022-26966).
- commit edaafdd
* Wed Mar 16 2022 dmueller@suse.com
- rpm/*.spec.in: remove backtick usage
- commit 87ca1fb
* Wed Mar 16 2022 ptesarik@suse.cz
- s390/module: fix loading modules with a lot of relocations
  (git-fixes).
- commit bc1865f
* Wed Mar 16 2022 oneukum@suse.com
- blacklist.conf: prerequisites break kABI
- commit d0b972b
* Wed Mar 16 2022 msuchanek@suse.de
- rpm: SC2006: Use $(...) notation instead of legacy backticked `...`.
- commit f0d0e90
* Wed Mar 16 2022 ptesarik@suse.cz
- s390/kexec_file: fix error handling when applying relocations
  (git-fixes).
- s390/kexec: fix memory leak of ipl report buffer (git-fixes).
- s390/kexec: fix return code handling (git-fixes).
- commit 2f0dd10
* Wed Mar 16 2022 ptesarik@suse.cz
- s390/bpf: Perform r1 range checking before accessing
  jit->seen_reg (git-fixes).
- commit 1cc7c78
* Tue Mar 15 2022 oneukum@suse.com
- usb: dwc2: gadget: Fix GOUTNAK flow for Slave mode (git-fixes).
- commit 3863766
* Tue Mar 15 2022 oneukum@suse.com
- usb: dwc2: Fix Stalling a Non-Isochronous OUT EP (git-fixes).
- commit 9d7504f
* Tue Mar 15 2022 tiwai@suse.de
- aio: fix use-after-free due to missing POLLFREE handling
  (CVE-2021-39698 bsc#1196956).
- aio: keep poll requests on waitqueue until completed
  (CVE-2021-39698 bsc#1196956).
- signalfd: use wake_up_pollfree() (CVE-2021-39698 bsc#1196956).
- binder: use wake_up_pollfree() (CVE-2021-39698 bsc#1196956).
- wait: add wake_up_pollfree() (CVE-2021-39698 bsc#1196956).
- commit b026506
* Tue Mar 15 2022 oneukum@suse.com
- usb: dwc2: gadget: Fix kill_all_requests race (git-fixes).
- commit 5ad82f7
* Tue Mar 15 2022 oneukum@suse.com
- usb: dwc3: meson-g12a: Disable the regulator in the error
  handling path of the probe (git-fixes).
- commit 6109544
* Tue Mar 15 2022 tiwai@suse.de
- mmc: meson: Fix usage of meson_mmc_post_req() (git-fixes).
- drm/sun4i: mixer: Fix P010 and P210 format numbers (git-fixes).
- commit 44ceec6
* Tue Mar 15 2022 dmueller@suse.com
- rpm/kernel-source.spec.in: call fdupes per subpackage
  It is a waste of time to do a global fdupes when we have
  subpackages.
- commit 1da8439
* Mon Mar 14 2022 denis.kirjanov@suse.com
- af_unix: fix garbage collect vs MSG_PEEK (CVE-2021-0920
  bsc#1193731).
- commit 7040fdd
* Mon Mar 14 2022 denis.kirjanov@suse.com
- Refresh patches.suse/xfrm-fix-mtu-regression.patch.
- commit 8d867d6
* Sat Mar 12 2022 tonyj@suse.de
- bpf, selftests: Add test case trying to taint map value pointer
  (bsc#1196130,CVE-2021-45402).
- bpf: Make 32->64 bounds propagation slightly more robust
  (bsc#1196130,CVE-2021-45402).
- bpf: Fix signed bounds propagation after mov32
  (bsc#1196130,CVE-2021-45402).
- commit 63a6298
* Fri Mar 11 2022 tiwai@suse.de
- net: phy: DP83822: clear MISR2 register to disable interrupts
  (git-fixes).
- gianfar: ethtool: Fix refcount leak in gfar_get_ts_info
  (git-fixes).
- NFC: port100: fix use-after-free in port100_send_complete
  (git-fixes).
- ax25: Fix NULL pointer dereference in ax25_kill_by_device
  (git-fixes).
- staging: gdm724x: fix use after free in gdm_lte_rx()
  (git-fixes).
- gpio: ts4900: Do not set DAT and OE together (git-fixes).
- gpiolib: acpi: Convert ACPI value of debounce to microseconds
  (git-fixes).
- usb: hub: Fix locking issues with address0_mutex (git-fixes).
- commit ea6e976
* Thu Mar 10 2022 bp@suse.de
- EDAC: Fix calculation of returned address and next offset in
  edac_align_ptr() (bsc#1178134).
- commit c292d6b
* Thu Mar 10 2022 jgross@suse.com
- xen/netfront: react properly to failing
  gnttab_end_foreign_access_ref() (bsc#1196488, XSA-396,
  CVE-2022-23042).
- commit fe0a923
* Thu Mar 10 2022 jgross@suse.com
- xen/gnttab: fix gnttab_end_foreign_access() without page
  specified (bsc#1196488, XSA-396, CVE-2022-23041).
- commit 58c801b
* Thu Mar 10 2022 jgross@suse.com
- xen/pvcalls: use alloc/free_pages_exact() (bsc#1196488,
  XSA-396, CVE-2022-23041).
- commit afb2dba
* Thu Mar 10 2022 jgross@suse.com
- xen/9p: use alloc/free_pages_exact() (bsc#1196488, XSA-396,
  CVE-2022-23041).
- commit cee63b9
* Thu Mar 10 2022 jgross@suse.com
- xen/usb: don't use gnttab_end_foreign_access() in
  xenhcd_gnttab_done() (bsc#1196488, XSA-396).
- commit b1d434d
* Thu Mar 10 2022 jgross@suse.com
- xen/gntalloc: don't use gnttab_query_foreign_access()
  (bsc#1196488, XSA-396, CVE-2022-23039).
- commit a4ec4aa
* Thu Mar 10 2022 jgross@suse.com
- xen/scsifront: don't use gnttab_query_foreign_access() for
  mapped status (bsc#1196488, XSA-396, CVE-2022-23038).
- commit fd9cb30
* Thu Mar 10 2022 jgross@suse.com
- xen/netfront: don't use gnttab_query_foreign_access() for
  mapped status (bsc#1196488, XSA-396, CVE-2022-23037).
- commit 4e33999
* Thu Mar 10 2022 jgross@suse.com
- xen/blkfront: don't use gnttab_query_foreign_access() for
  mapped status (bsc#1196488, XSA-396, CVE-2022-23036).
- commit 4334af7
* Thu Mar 10 2022 jgross@suse.com
- xen/grant-table: add gnttab_try_end_foreign_access()
  (bsc#1196488, XSA-396, CVE-2022-23036, CVE-2022-23038).
- commit 19b769a
* Thu Mar 10 2022 jgross@suse.com
- xen/xenbus: don't let xenbus_grant_ring() remove grants in
  error case (bsc#1196488, XSA-396, CVE-2022-23040).
- commit 5aacf1f
* Thu Mar 10 2022 bp@suse.de
- EDAC/altera: Fix deferred probing (bsc#1178134).
- commit 13cc9b2
* Thu Mar 10 2022 dmueller@suse.com
- rpm/arch-symbols,guards,*driver: Replace Novell with SUSE.
- commit 174a64f
* Thu Mar 10 2022 dwagner@suse.de
- nvme-rdma: fix possible use-after-free in transport
  error_recovery work (git-fixes).
- commit f4a5de3
* Thu Mar 10 2022 jgross@suse.com
- usb: host: xen-hcd: add missing unlock in error path
  (git-fixes).
- commit daa9ea7
* Thu Mar 10 2022 jgross@suse.com
- Refresh
  patches.suse/0002-usb-Introduce-Xen-pvUSB-frontend-xen-hcd.patch.
- commit d9066f6
* Thu Mar 10 2022 jgross@suse.com
- Refresh
  patches.suse/0001-usb-Add-Xen-pvUSB-protocol-description.patch.
- commit 5c41eb3
* Thu Mar 10 2022 dmueller@suse.com
- rpm/kernel-docs.spec.in: use %%%%license for license declarations
  Limited to SLE15+ to avoid compatibility nightmares.
- commit 73d560e
* Wed Mar  9 2022 dmueller@suse.com
- rpm/*.spec.in: Use https:// urls
- commit 77b5f8e
* Wed Mar  9 2022 dwagner@suse.de
- nvme-multipath: use vmalloc for ANA log buffer (bsc#1193787).
- commit 8823060
* Wed Mar  9 2022 tiwai@suse.de
- Bluetooth: btusb: Add missing Chicony device for Realtek
  RTL8723BE (bsc#1196779).
- commit 504b440
* Wed Mar  9 2022 tbogendoerfer@suse.de
- ixgbe: xsk: change !netif_carrier_ok() handling in
  ixgbe_xmit_zc() (git-fixes).
- selftests: mlxsw: tc_police_scale: Make test more robust
  (bsc#1176774).
- net: fix up skbs delta_truesize in UDP GRO frag_list
  (bsc#1176447).
- igc: igc_write_phy_reg_gpy: drop premature return (git-fixes).
- igc: igc_read_phy_reg_gpy: drop premature return (git-fixes).
- iavf: Fix missing check for running netdev (git-fixes).
- RDMA/cma: Do not change route.addr.src_addr outside state checks
  (bsc#1181147).
- RDMA/ib_srp: Fix a deadlock (git-fixes).
- RDMA/rtrs-clt: Fix possible double free in error case
  (jsc#SLE-15176).
- net/mlx5e: TC, Reject rules with forward and drop actions
  (git-fixes).
- net/mlx5e: TC, Reject rules with drop and modify hdr action
  (git-fixes).
- net/mlx5e: kTLS, Use CHECKSUM_UNNECESSARY for device-offloaded
  packets (jsc#SLE-15172).
- net/mlx5e: Fix wrong return value on ioctl EEPROM query failure
  (git-fixes).
- net/mlx5: Fix possible deadlock on rule deletion (git-fixes).
- net/mlx5: Fix wrong limitation of metadata match on ecpf
  (git-fixes).
- net/mlx5: Update the list of the PCI supported devices
  (git-fixes).
- netfilter: nf_tables: fix memory leak during stateful obj update
  (bsc#1176447).
- bnxt_en: Fix incorrect multicast rx mask setting when not
  requested (git-fixes).
- bnxt_en: Fix occasional ethtool -t loopback test failures
  (git-fixes).
- bnxt_en: Fix offline ethtool selftest with RDMA enabled
  (git-fixes).
- bnxt_en: Fix active FEC reporting to ethtool (jsc#SLE-16649).
- ice: initialize local variable 'tlv' (jsc#SLE-12878).
- nfp: flower: Fix a potential leak in nfp_tunnel_add_shared_mac()
  (git-fixes).
- net/sched: act_ct: Fix flow table lookup after ct clear or
  switching zones (jsc#SLE-15172).
- bonding: force carrier update when releasing slave (git-fixes).
- RDMA/mlx4: Don't continue event handler after memory allocation
  failure (git-fixes).
- RDMA/siw: Fix broken RDMA Read Fence/Resume logic (git-fixes).
- IB/rdmavt: Validate remote_addr during loopback atomic tests
  (git-fixes).
- RDMA/cxgb4: Set queue pair state when being queried (git-fixes).
- RDMA/rxe: Fix a typo in opcode name (git-fixes).
- RDMA/cma: Let cma_resolve_ib_dev() continue search even after
  empty entry (git-fixes).
- RDMA/core: Let ib_find_gid() continue search even after empty
  entry (git-fixes).
- RDMA/uverbs: Remove the unnecessary assignment (git-fixes).
- RDMA/cma: Remove open coding of overflow checking for
  private_data_len (git-fixes).
- RDMA/hns: Validate the pkey index (git-fixes).
- RDMA/bnxt_re: Scan the whole bitmap when checking if "disabling
  RCFW with pending cmd-bit" (git-fixes).
- RDMA/core: Don't infoleak GRH fields (git-fixes).
- RDMA/uverbs: Check for null return of kmalloc_array (git-fixes).
- IB/hfi1: Fix leak of rcvhdrtail_dummy_kvaddr (git-fixes).
- IB/hfi1: Fix early init panic (git-fixes).
- IB/hfi1: Insure use of smp_processor_id() is preempt disabled
  (git-fixes).
- IB/hfi1: Correct guard on eager buffer deallocation (git-fixes).
- net/mlx5: Update the list of the PCI supported devices
  (git-fixes).
- commit 5d0d3c3
* Wed Mar  9 2022 oneukum@suse.com
- asix: fix uninit-value in asix_mdio_read() (git-fixes).
- commit 954cba8
* Wed Mar  9 2022 oneukum@suse.com
- usb: hub: Fix usb enumeration issue due to address0 race
  (git-fixes).
- commit 831632a
* Wed Mar  9 2022 oneukum@suse.com
- USB: hub: Clean up use of port initialization schemes and
  retries (git-fixes).
- commit 39e09e3
* Wed Mar  9 2022 msuchanek@suse.de
- powerpc/powernv/memtrace: Fix dcache flushing (bsc#1196433
  ltc#196449).
- commit 5cf33af
* Wed Mar  9 2022 oneukum@suse.com
- mask out added spinlock in rndis_params (git-fixes).
- commit cf77fd5
* Wed Mar  9 2022 oneukum@suse.com
- usb: gadget: rndis: add spinlock for rndis response list
  (git-fixes).
- commit 6500e0b
* Wed Mar  9 2022 tiwai@suse.de
- HID: add mapping for KEY_ALL_APPLICATIONS (git-fixes).
- HID: add mapping for KEY_DICTATE (git-fixes).
- Input: elan_i2c - fix regulator enable count imbalance after
  suspend/resume (git-fixes).
- Input: elan_i2c - move regulator_[en|dis]able() out of
  elan_[en|dis]able_power() (git-fixes).
- arm64: dts: rockchip: Switch RK3399-Gru DP to SPDIF output
  (git-fixes).
- dmaengine: shdma: Fix runtime PM imbalance on error (git-fixes).
- i2c: bcm2835: Avoid clock stretching timeouts (git-fixes).
- Input: clear BTN_RIGHT/MIDDLE on buttonpads (git-fixes).
- ASoC: rt5682: do not block workqueue if card is unbound
  (git-fixes).
- ASoC: rt5668: do not block workqueue if card is unbound
  (git-fixes).
- net: usb: cdc_mbim: avoid altsetting toggling for Telit FN990
  (git-fixes).
- mac80211_hwsim: initialize ieee80211_tx_info at hw_scan_work
  (git-fixes).
- mac80211_hwsim: report NOACK frames in tx_status (git-fixes).
- hamradio: fix macro redefine warning (git-fixes).
- commit add4eb4
* Wed Mar  9 2022 lduncan@suse.com
- scsi: bnx2fc: Make bnx2fc_recv_frame() mp safe (git-fixes).
- scsi: bnx2fc: Flush destroy_work queue before calling
  bnx2fc_interface_put() (git-fixes).
- scsi: nsp_cs: Check of ioremap return value (git-fixes).
- scsi: qedf: Fix potential dereference of NULL pointer
  (git-fixes).
- scsi: ufs: Fix race conditions related to driver data
  (git-fixes).
- scsi: lpfc: Terminate string in lpfc_debugfs_nvmeio_trc_write()
  (git-fixes).
- commit 2185cf5
* Wed Mar  9 2022 lduncan@suse.com
- Add SCSI git-fix to blacklist: too pervasive
- commit 3f4a3f6
* Tue Mar  8 2022 mkoutny@suse.com
- blacklist.conf: Add 05c7b7a92cc8 cgroup/cpuset: Fix a race between cpuset_attach() and cpu hotplug
- commit 511f680
* Tue Mar  8 2022 mkoutny@suse.com
- cgroup/cpuset: Fix "suspicious RCU usage" lockdep warning
  (bsc#1196868).
- commit 30013c2
* Tue Mar  8 2022 mkoutny@suse.com
- cpuset: Fix the bug that subpart_cpus updated wrongly in
  update_cpumask() (bsc#1196866).
- commit 8ee9c97
* Tue Mar  8 2022 oneukum@suse.com
- blacklist.conf: prerequisites break kABI
- commit 88b00ea
* Tue Mar  8 2022 oneukum@suse.com
- blacklist.conf: kABI
- commit 11980b2
* Tue Mar  8 2022 oneukum@suse.com
- blacklist.conf: patch not applicable due to missing infrastructure
- commit be9f64f
* Tue Mar  8 2022 oneukum@suse.com
- usb: dwc2: use well defined macros for power_down (git-fixes).
- commit 781db9c
* Tue Mar  8 2022 osalvador@suse.de
- ename colliding patches before the next cve/linux-5.3 -> SLE15-SP3 merge
- commit 59d5e34
* Tue Mar  8 2022 mbenes@suse.cz
- Hand over the maintainership to SLE15-SP3 maintainers
- commit 0c92742
* Tue Mar  8 2022 neilb@suse.de
- SUNRPC: avoid race between mod_timer() and del_timer_sync()
  (bnc#1195403).
- commit f6cf219
* Tue Mar  8 2022 fweisbecker@suse.de
- cputime, cpuacct: Include guest time in user time in (git-fixes)
- commit b360f79
* Tue Mar  8 2022 fweisbecker@suse.de
- sched/core: Mitigate race (git-fixes)
- commit d6e526f
* Tue Mar  8 2022 fweisbecker@suse.de
- cpufreq: schedutil: Use kobject release() method to free (git-fixes)
- commit 3b82dc0
* Tue Mar  8 2022 fweisbecker@suse.de
- blacklist.conf: Blacklist uclamp related fixes
- commit af69679
* Mon Mar  7 2022 oneukum@suse.com
- sr9700: sanity check for packet length (bsc#1196836).
- commit 558034f
* Mon Mar  7 2022 mbenes@suse.cz
- tracing: Fix return value of __setup handlers (git-fixes).
- commit 184ff86
* Mon Mar  7 2022 rgoldwyn@suse.com
- exfat: fix i_blocks for files truncated over 4 GiB  (git-fixes).
- exfat: fix incorrect loading of i_blocks for large files
  (git-fixes).
- commit f1e7b8d
* Mon Mar  7 2022 tiwai@suse.de
- nfc: st21nfca: Fix potential buffer overflows in EVT_TRANSACTION
  (CVE-2022-26490 bsc#1196830).
- commit fd10ace
* Mon Mar  7 2022 dwagner@suse.de
- nvme-tcp: fix possible use-after-free in transport
  error_recovery work (git-fixes).
- nvme: fix a possible use-after-free in controller reset during
  load (git-fixes).
- commit 8b4713c
* Mon Mar  7 2022 denis.kirjanov@suse.com
- Update patches.suse/0001-mmc-moxart_remove-Fix-UAF.patch
  (bsc#1194516 CVE-2022-0487).
- Update
  patches.suse/NFSv4-Handle-case-where-the-lookup-of-a-directory-fa.patch
  (bsc#1195612 CVE-2022-24448).
- Update
  patches.suse/udf-Fix-NULL-ptr-deref-when-converting-from-inline-f.patch
  (bsc#1196079 CVE-2022-0617).
- Update
  patches.suse/udf-Restore-i_lenAlloc-when-inode-expansion-fails.patch
  (bsc#1196079 CVE-2022-0617).
- Update
  patches.suse/vfs-check-fd-has-read-access-in-kernel_read_file_from_fd.patch
  (bsc#1194888 CVE-2022-0644 bsc#1196155).
- commit 096ea36
* Sat Mar  5 2022 tiwai@suse.de
- ALSA: intel_hdmi: Fix reference to PCM buffer address
  (git-fixes).
- ASoC: cs4265: Fix the duplicated control name (git-fixes).
- ASoC: ops: Shift tested values in snd_soc_put_volsw() by +min
  (git-fixes).
- commit 46ecf36
* Sat Mar  5 2022 lduncan@suse.com
- scsi: smartpqi: Add PCI IDs (bsc#1196627).
- commit 0f3e3c7
* Fri Mar  4 2022 tiwai@suse.de
- Revert PCI MSI-X patch that caused a regression on network devices (bsc#1196403)
  Deleted:
  patches.suse/PCI-MSI-Mask-MSI-X-vectors-only-on-success.patch
- commit 0c68bb9
* Fri Mar  4 2022 denis.kirjanov@suse.com
- vrf: Fix fast path output packet handling with async Netfilter
  rules (git-fixes).
- commit 4dafe3d
* Fri Mar  4 2022 denis.kirjanov@suse.com
- net/mlx5e: Fix modify header actions memory leak (git-fixes).
- commit 2d08f14
* Fri Mar  4 2022 denis.kirjanov@suse.com
- net: ethernet: ti: cpsw: disable PTPv1 hw timestamping
  advertisement (git-fixes).
- commit 644c57f
* Fri Mar  4 2022 denis.kirjanov@suse.com
- net: hns3: Clear the CMDQ registers before unmapping BAR region
  (git-fixes).
- commit 09653f6
* Fri Mar  4 2022 denis.kirjanov@suse.com
- netsec: ignore 'phy-mode' device property on ACPI systems
  (git-fixes).
- commit b2241ca
* Fri Mar  4 2022 denis.kirjanov@suse.com
- net: sfc: Replace in_interrupt() usage (git-fixes).
- commit 254377d
* Fri Mar  4 2022 denis.kirjanov@suse.com
- gtp: remove useless rcu_read_lock() (git-fixes).
- commit 2588833
* Fri Mar  4 2022 denis.kirjanov@suse.com
- net: dsa: mv88e6xxx: MV88E6097 does not support jumbo
  configuration (git-fixes).
- commit 28ecaea
* Fri Mar  4 2022 denis.kirjanov@suse.com
- Refresh
  patches.suse/ibmvnic-Allow-queueing-resets-during-probe.patch.
- Refresh
  patches.suse/ibmvnic-clear-fop-when-retrying-probe.patch.
- Refresh
  patches.suse/ibmvnic-complete-init_done-on-transport-events.patch.
- Refresh
  patches.suse/ibmvnic-define-flush_reset_queue-helper.patch.
- Refresh
  patches.suse/ibmvnic-don-t-release-napi-in-__ibmvnic_open.patch.
- Refresh
  patches.suse/ibmvnic-free-reset-work-item-when-flushing.patch.
- Refresh patches.suse/ibmvnic-init-init_done_rc-earlier.patch.
- Refresh
  patches.suse/ibmvnic-initialize-rc-before-completing-wait.patch.
- Refresh
  patches.suse/ibmvnic-register-netdev-after-init-of-adapter.patch.
- Refresh
  patches.suse/ibmvnic-schedule-failover-only-if-vioctl-fails.patch.
- Refresh
  patches.suse/scsi-lpfc-Fix-pt2pt-NVMe-PRLI-reject-LOGO-loop.patch.
- Refresh patches.suse/xfrm-fix-mtu-regression.patch.
- commit 25457d5
* Fri Mar  4 2022 tbogendoerfer@suse.de
- netfilter: nf_tables_offload: incorrect flow offload action
  array size (bsc#1196299 CVE-2022-25636).
- commit 30b89a9
* Fri Mar  4 2022 tiwai@suse.de
- batman-adv: Don't expect inter-netns unique iflink indices
  (git-fixes).
- batman-adv: Request iflink once in batadv_get_real_netdevice
  (git-fixes).
- batman-adv: Request iflink once in batadv-on-batadv check
  (git-fixes).
- nl80211: Handle nla_memdup failures in handle_nan_filter
  (git-fixes).
- mac80211: fix forwarded mesh frames AC & queue selection
  (git-fixes).
- can: gs_usb: change active_channels's type from atomic_t to u8
  (git-fixes).
- commit 1c8fa49
* Fri Mar  4 2022 tiwai@suse.de
- Update patch reference for iov security fix (CVE-2022-0847 bsc#1196584)
- commit 1dafeb6
* Thu Mar  3 2022 mkoutny@suse.com
- cgroup-v1: Correct privileges check in release_agent writes
  (bsc#1196723).
- commit 3d0b2e2
* Thu Mar  3 2022 mkoutny@suse.com
- blacklist.conf: Add 51e50fbd3efc psi: fix "no previous prototype" warnings when CONFIG_CGROUPS=n
- commit 2727993
* Thu Mar  3 2022 tiwai@suse.de
- ARM: 9182/1: mmu: fix returns from early_param() and __setup()
  functions (git-fixes).
- ARM: Fix kgdb breakpoint for Thumb2 (git-fixes).
- ntb: intel: fix port config status offset for SPR (git-fixes).
- USB: serial: option: add Telit LE910R1 compositions (git-fixes).
- USB: serial: option: add support for DW5829e (git-fixes).
- USB: gadget: validate endpoint index for xilinx udc (git-fixes).
- xhci: re-initialize the HC during resume if HCE was set
  (git-fixes).
- drm/amdgpu: disable MMHUB PG for Picasso (git-fixes).
- USB: zaurus: support another broken Zaurus (git-fixes).
- USB: gadget: validate interface OS descriptor requests
  (git-fixes).
- commit a54291e
* Thu Mar  3 2022 msuchanek@suse.de
- Update patches.suse/ibmvnic-don-t-stop-queue-in-xmit.patch
  (bsc#1192273 ltc#194629 bsc#1191428 ltc#193985).
- commit 59ca885
* Thu Mar  3 2022 tbogendoerfer@suse.de
- net/mlx5e: Fix page DMA map/unmap attributes (bsc#1196468).
- commit 6dcfd65
* Thu Mar  3 2022 dwagner@suse.de
- blk-mq: don't free tags if the tag_set is used by other device
  in queue initialztion (bsc#1193787).
- commit 5b79ad2
* Wed Mar  2 2022 msuchanek@suse.de
- kernel-binary.spec: Also exclude the kernel signing key from devel package.
  There is a check in OBS that fails when it is included. Also the key is
  not reproducible.
  Fixes: bb988d4625a3 ("kernel-binary: Do not include sourcedir in certificate path.")
- commit 68fa069
* Wed Mar  2 2022 msuchanek@suse.de
- powerpc/fadump: register for fadump as early as possible
  (bsc#1179439 ltc#190038).
- commit 3f54d95
* Wed Mar  2 2022 msuchanek@suse.de
- rpm/check-for-config-changes: Ignore PAHOLE_VERSION.
- commit 88ba5ec
* Wed Mar  2 2022 msuchanek@suse.de
- powerpc/pseries/iommu: Fix window size for direct mapping with
  pmem (bsc#1196472 ltc#192278).
- powerpc/dma: Fallback to dma_ops when persistent memory present
  (bsc#1196472 ltc#192278).
  Update config files.
- dma-mapping: Allow mixing bypass and mapped DMA operation
  (bsc#1196472 ltc#192278).
- dma-direct: Fix potential NULL pointer dereference (bsc#1196472
  ltc#192278).
- commit a04953d
* Tue Mar  1 2022 mbrugger@suse.com
- arm64: Use the clearbhb instruction in mitigations (bsc#1191580
  CVE-2022-0001 CVE-2022-0002).
- arm64: add ID_AA64ISAR2_EL1 sys register (bsc#1191580
  CVE-2022-0001 CVE-2022-0002).
- KVM: arm64: Allow SMCCC_ARCH_WORKAROUND_3 to be discovered
  and migrated (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- commit b546cd9
* Tue Mar  1 2022 mbrugger@suse.com
- arm64: Mitigate spectre style branch history side channels
  (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- Update config files.
- commit d035616
* Tue Mar  1 2022 mbrugger@suse.com
- KVM: arm64: Add templates for BHB mitigation sequences
  (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- Refresh
  patches.suse/kabi-arm64-reserve-space-in-cpu_hwcaps-and-cpu_hwcap.patch.
- commit 8c9b0c2
* Tue Mar  1 2022 mbrugger@suse.com
- arm64: Add Cortex-X2 CPU part definition (bsc#1191580
  CVE-2022-0001 CVE-2022-0002).
- commit c3c4a06
* Tue Mar  1 2022 mbrugger@suse.com
- arm64: Add Neoverse-N2, Cortex-A710 CPU part definition
  (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- arm64: Add part number for Arm Cortex-A77 (bsc#1191580
  CVE-2022-0001 CVE-2022-0002).
- arm64: proton-pack: Report Spectre-BHB vulnerabilities as part
  of Spectre-v2 (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- arm64: Add percpu vectors for EL1 (bsc#1191580 CVE-2022-0001
  CVE-2022-0002).
- arm64: entry: Add macro for reading symbol addresses from the
  trampoline (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- arm64: entry: Add vectors that have the bhb mitigation sequences
  (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- arm64: entry: Add non-kpti __bp_harden_el1_vectors for
  mitigations (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- arm64: entry: Allow the trampoline text to occupy multiple pages
  (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- arm64: entry: Make the kpti trampoline's kpti sequence optional
  (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- arm64: entry: Move trampoline macros out of ifdef'd section
  (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- arm64: entry: Don't assume tramp_vectors is the start of the
  vectors (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- arm64: entry: Allow tramp_alias to access symbols after the
  4K boundary (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- arm64: entry: Move the trampoline data page before the text page
  (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- arm64: entry: Free up another register on kpti's tramp_exit path
  (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- arm64: entry: Make the trampoline cleanup optional (bsc#1191580
  CVE-2022-0001 CVE-2022-0002).
- arm64: entry.S: Add ventry overflow sanity checks (bsc#1191580
  CVE-2022-0001 CVE-2022-0002).
- commit 284cd49
* Tue Mar  1 2022 tiwai@suse.de
- lib/iov_iter: initialize "flags" in new pipe_buffer
  (bsc#1196584).
- commit 4f3bbf5
* Tue Mar  1 2022 tiwai@suse.de
- soc: fsl: qe: Check of ioremap return value (git-fixes).
- soc: fsl: Correct MAINTAINERS database (SOC) (git-fixes).
- soc: fsl: Correct MAINTAINERS database (QUICC ENGINE LIBRARY)
  (git-fixes).
- firmware: arm_scmi: Remove space in MODULE_ALIAS name
  (git-fixes).
- efivars: Respect "block" flag in efivar_entry_set_safe()
  (git-fixes).
- gpio: tegra186: Fix chip_data type confusion (git-fixes).
- gpio: rockchip: Reset int_bothedge when changing trigger
  (git-fixes).
- spi: spi-zynq-qspi: Fix a NULL pointer dereference in
  zynq_qspi_exec_mem_op() (git-fixes).
- iio: Fix error handling for PM (git-fixes).
- iio: adc: men_z188_adc: Fix a resource leak in an error handling
  path (git-fixes).
- iio: adc: ad7124: fix mask used for setting AIN_BUFP & AIN_BUFM
  bits (git-fixes).
- tty: n_gsm: fix proper link termination after failed open
  (git-fixes).
- tty: n_gsm: fix encoding of control signal octet bit DV
  (git-fixes).
- Revert "USB: serial: ch341: add new Product ID for CH341A"
  (git-fixes).
- usb: dwc3: gadget: Let the interrupt handler disable bottom
  halves (git-fixes).
- usb: dwc3: pci: Fix Bay Trail phy GPIO mappings (git-fixes).
- xhci: Prevent futile URB re-submissions due to incorrect return
  value (git-fixes).
- ata: pata_hpt37x: disable primary channel on HPT371 (git-fixes).
- clk: jz4725b: fix mmc0 clock gating (git-fixes).
- drm/edid: Always set RGB444 (git-fixes).
- commit c381750
* Mon Feb 28 2022 bp@suse.de
- x86/speculation: Use generic retpoline by default on AMD
  (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- commit bed48b1
* Mon Feb 28 2022 msuchanek@suse.de
- ibmvnic: Allow queueing resets during probe (bsc#1196516
  ltc#196391).
- ibmvnic: clear fop when retrying probe (bsc#1196516 ltc#196391).
- ibmvnic: init init_done_rc earlier (bsc#1196516 ltc#196391).
- ibmvnic: register netdev after init of adapter (bsc#1196516
  ltc#196391).
- ibmvnic: complete init_done on transport events (bsc#1196516
  ltc#196391).
- ibmvnic: define flush_reset_queue helper (bsc#1196516
  ltc#196391).
- ibmvnic: initialize rc before completing wait (bsc#1196516
  ltc#196391).
- ibmvnic: free reset-work-item when flushing (bsc#1196516
  ltc#196391).
- commit 1cc99d0
* Mon Feb 28 2022 mbenes@suse.cz
- tracing: Have traceon and traceoff trigger honor the instance
  (git-fixes).
- commit 92ab7ec
* Mon Feb 28 2022 mbenes@suse.cz
- tracing: Dump stacktrace trigger to the corresponding instance
  (git-fixes).
- commit a3c85e9
* Mon Feb 28 2022 dwagner@suse.de
- nvme: also mark passthrough-only namespaces ready in
  nvme_update_ns_info (git-fixes).
- nvme: don't return an error from nvme_configure_metadata
  (git-fixes).
- nvme: let namespace probing continue for unsupported features
  (git-fixes).
- commit a5b2a87
* Mon Feb 28 2022 dwagner@suse.de
- blk-mq: avoid to iterate over stale request (bsc#1193787).
- blk-mq: fix is_flush_rq (bsc#1193787 git-fixes).
- blk-mq: fix kernel panic during iterating over flush request
  (bsc#1193787 git-fixes).
- blk-mq: don't grab rq's refcount in blk_mq_check_expired()
  (bsc#1193787 git-fixes).
- blk-mq: always allow reserved allocation in hctx_may_queue
  (bsc#1193787).
- commit cc53802
* Sun Feb 27 2022 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: add systemd-initrd and terminfo dracut module (bsc#1195775)
- commit d9a821b
* Fri Feb 25 2022 pjakobsson@suse.de
- drm/i915: Fix bw atomic check when switching between SAGV
  vs. no SAGV (git-fixes).
- commit 209cee8
* Fri Feb 25 2022 pjakobsson@suse.de
- drm/i915: Correctly populate use_sagv_wm for all pipes
  (git-fixes).
- commit 5d7b5fe
* Thu Feb 24 2022 ptesarik@suse.cz
- kABI fixup after adding vcpu_idx to struct kvm_cpu (bsc#1190972
  LTC#194674).
- KVM: remember position in kvm->vcpus array (bsc#1190972
  LTC#194674).
- commit 81f3dbb
* Thu Feb 24 2022 ptesarik@suse.cz
- s390/cpumf: Support for CPU Measurement Sampling Facility LS
  bit (bsc#1195081 LTC#196088).
- s390/cpumf: Support for CPU Measurement Facility CSVN 7
  (bsc#1195081 LTC#196088).
- commit 0ce3482
* Thu Feb 24 2022 ptesarik@suse.cz
- s390/cio: verify the driver availability for path_event call
  (bsc#1195928 LTC#196418).
- commit 4741f1a
* Thu Feb 24 2022 ptesarik@suse.cz
- scsi: zfcp: Fix failed recovery on gone remote port with
  non-NPIV FCP devices (bsc#1195378 LTC#196244).
- commit 6fb3d19
* Thu Feb 24 2022 ptesarik@suse.cz
- s390/pci: add s390_iommu_aperture kernel parameter (bsc#1193233
  LTC#195540).
- commit 79f1350
* Thu Feb 24 2022 ptesarik@suse.cz
- s390/pci: move pseudo-MMIO to prevent MIO overlap (bsc#1194967
  LTC#196028).
- commit 512e596
* Thu Feb 24 2022 ptesarik@suse.cz
- s390/cio: make ccw_device_dma_* more robust (bsc#1193243
  LTC#195549).
- commit 6f84bff
* Thu Feb 24 2022 msuchanek@suse.de
- powerpc/mm: Remove dcache flush from memory remove (bsc#1196433
  ltc#196449).
- commit 72793cf
* Thu Feb 24 2022 dwagner@suse.de
- block: do not send a rezise udev event for hidden block device
  (bsc#1193096).
- commit c3addda
* Thu Feb 24 2022 ptesarik@suse.cz
- s390/bpf: Fix optimizing out zero-extensions (git-fixes).
- commit 542287e
* Thu Feb 24 2022 ptesarik@suse.cz
- s390/bpf: Fix 64-bit subtraction of the -0x80000000 constant
  (git-fixes).
- commit 774f927
* Thu Feb 24 2022 msuchanek@suse.de
- ibmvnic: schedule failover only if vioctl fails (bsc#1196400
  ltc#195815).
- commit 7099d61
* Thu Feb 24 2022 jack@suse.cz
- ext4: prevent partial update of the extent blocks (bsc#1194163
  bsc#1196339).
- commit 9b7f6a6
* Thu Feb 24 2022 jack@suse.cz
- ext4: check for inconsistent extents between index and leaf
  block (bsc#1194163 bsc#1196339).
- commit 8a25180
* Thu Feb 24 2022 jack@suse.cz
- ext4: check for out-of-order index extents in
  ext4_valid_extent_entries() (bsc#1194163 bsc#1196339).
- commit b72afd9
* Thu Feb 24 2022 tiwai@suse.de
- i2c: brcmstb: fix support for DSL and CM variants (git-fixes).
- mtd: rawnand: brcmnand: Fixed incorrect sub-page ECC status
  (git-fixes).
- mtd: rawnand: gpmi: don't leak PM reference in error path
  (git-fixes).
- mtd: rawnand: qcom: Fix clock sequencing in qcom_nandc_probe()
  (git-fixes).
- ASoC: Revert "ASoC: mediatek: Check for error clk pointer"
  (git-fixes).
- ASoC: ops: Fix stereo change notifications in
  snd_soc_put_volsw_range() (git-fixes).
- ASoC: ops: Fix stereo change notifications in
  snd_soc_put_volsw() (git-fixes).
- ALSA: hda: Fix missing codec probe on Shenker Dock 15
  (git-fixes).
- ALSA: hda: Fix regression on forced probe mask option
  (git-fixes).
- drm/radeon: Fix backlight control on iMac 12,1 (git-fixes).
- HID:Add support for UGTABLET WP5540 (git-fixes).
- ata: libata-core: Disable TRIM on M88V29 (git-fixes).
- drm/rockchip: dw_hdmi: Do not leave clock enabled in error case
  (git-fixes).
- net: macb: Align the dma and coherent dma masks (git-fixes).
- net: usb: qmi_wwan: Add support for Dell DW5829e (git-fixes).
- drm/amdgpu: fix logic inversion in check (git-fixes).
- ax25: improve the incomplete fix to avoid UAF and NPD bugs
  (git-fixes).
- commit ea7f847
* Wed Feb 23 2022 jack@suse.cz
- udf: Restore i_lenAlloc when inode expansion fails (bsc#1196079
  CVE-2022-0617).
- commit a1deb2a
* Wed Feb 23 2022 jack@suse.cz
- udf: Fix NULL ptr deref when converting from inline format
  (bsc#1196079 CVE-2022-0617).
- commit 43cd4ed
* Wed Feb 23 2022 dwagner@suse.de
- blk-tag: Hide spin_lock (bsc#1193787).
- commit 78741a7
* Wed Feb 23 2022 dwagner@suse.de
- blk-mq: clearing flush request reference in tags->rqs
  (bsc#1193787).
- blk-mq: clear stale request in tags->rq before freeing one
  request pool (bsc#1193787).
- blk-mq: grab rq->refcount before calling ->fn in
  blk_mq_tagset_busy_iter (bsc#1193787).
- block: avoid double io accounting for flush request
  (bsc#1193787).
- block: mark flush request as IDLE when it is really finished
  (bsc#1193787).
- blk-mq: mark flush request as IDLE in flush_end_io()
  (bsc#1193787).
- commit 2d33352
* Wed Feb 23 2022 nborisov@suse.com
- btrfs: do not do preemptive flushing if the majority is global rsv (bsc#1196195).
- commit 445785b
* Wed Feb 23 2022 nborisov@suse.com
- btrfs: handle preemptive delalloc flushing slightly differently (bsc#1196195).
- commit 436acc9
* Wed Feb 23 2022 nborisov@suse.com
- btrfs: only ignore delalloc if delalloc is much smaller than ordered (bsc#1196195).
- commit a9ec6c0
* Wed Feb 23 2022 nborisov@suse.com
- btrfs: don't include the global rsv size in the preemptive used amount (bsc#1196195).
- commit ace9b16
* Wed Feb 23 2022 nborisov@suse.com
- btrfs: use the global rsv size in the preemptive thresh calculation (bsc#1196195).
- commit 4beb0b0
* Wed Feb 23 2022 nborisov@suse.com
- btrfs: take into account global rsv in need_preemptive_reclaim (bsc#1196195).
- Refresh patches.suse/btrfs-reduce-the-preemptive-flushing-threshold-to-90.patch.
- commit 41c6188
* Wed Feb 23 2022 nborisov@suse.com
- btrfs: only clamp the first time we have to start flushing (bsc#1196195).
- commit b25996b
* Wed Feb 23 2022 nborisov@suse.com
- btrfs: check worker before need_preemptive_reclaim (bsc#1196195).
- commit f36b423
* Wed Feb 23 2022 nborisov@suse.com
- btrfs: reduce the preemptive flushing threshold to 90%% (bsc#1196195).
- commit ef6e83a
* Tue Feb 22 2022 bp@suse.de
- x86/speculation: Include unprivileged eBPF status in Spectre v2
  mitigation reporting (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- commit d42fa20
* Tue Feb 22 2022 bp@suse.de
- Documentation/hw-vuln: Update spectre doc (bsc#1191580
  CVE-2022-0001 CVE-2022-0002).
- commit a48cfcc
* Tue Feb 22 2022 bp@suse.de
- x86/speculation: Add eIBRS + Retpoline options (bsc#1191580
  CVE-2022-0001 CVE-2022-0002).
- commit 1a20a7e
* Mon Feb 21 2022 bp@suse.de
- x86/speculation: Rename RETPOLINE_AMD to RETPOLINE_LFENCE
  (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- commit 80f47a3
* Mon Feb 21 2022 bp@suse.de
- x86,bugs: Unconditionally allow spectre_v2=retpoline,amd
  (bsc#1191580 CVE-2022-0001 CVE-2022-0002).
- commit 1f9dd65
* Mon Feb 21 2022 jroedel@suse.de
- kABI: Fix kABI for AMD IOMMU driver (git-fixes).
- commit 718c631
* Mon Feb 21 2022 jroedel@suse.de
- blacklist.conf: Add 2cbc61a1b166 iommu/dma: Account for min_align_mask w/swiotlb
- commit 142c6ac
* Mon Feb 21 2022 jroedel@suse.de
- iommu/amd: Fix loop timeout issue in iommu_ga_log_enable()
  (git-fixes).
- iommu/vt-d: Fix potential memory leak in
  intel_setup_irq_remapping() (git-fixes).
- iommu/iova: Fix race between FQ timeout and teardown
  (git-fixes).
- iommu/io-pgtable-arm: Fix table descriptor paddr formatting
  (git-fixes).
- iommu/amd: Remove useless irq affinity notifier (git-fixes).
- iommu/amd: X2apic mode: mask/unmask interrupts on suspend/resume
  (git-fixes).
- iommu/amd: X2apic mode: setup the INTX registers on mask/unmask
  (git-fixes).
- iommu/amd: X2apic mode: re-enable after resume (git-fixes).
- iommu/amd: Restore GA log/tail pointer on host resume
  (git-fixes).
- iommu/io-pgtable-arm-v7s: Add error handle for page table
  allocation failure (git-fixes).
- commit 50e60e3
* Mon Feb 21 2022 tiwai@suse.de
- Update patch reference for USB gadget fix (CVE-2022-25375 bsc#1196235)
- commit b7dc18b
* Mon Feb 21 2022 tiwai@suse.de
- usb: gadget: rndis: check size of RNDIS_MSG_SET command
  (CVE-2022-25375 bsc#1196235).
- commit 4e7d746
* Fri Feb 18 2022 tiwai@suse.de
- Update patch reference for vfs fix (CVE-2022-0644 bsc#1196155)
- commit 900b4f0
* Fri Feb 18 2022 msuchanek@suse.de
- net/ibmvnic: Cleanup workaround doing an EOI after partition
  migration (bsc#1089644 ltc#166495 ltc#165544 git-fixes).
- commit 0dfd4da
* Fri Feb 18 2022 tiwai@suse.de
- drm/i915/opregion: check port number bounds for SWSCI display
  power state (git-fixes).
- drm/i915/gvt: Make DRM_I915_GVT depend on X86 (git-fixes).
- drm/i915/gvt: clean up kernel-doc in gtt.c (git-fixes).
- iwlwifi: fix use-after-free (git-fixes).
- iwlwifi: pcie: gen2: fix locking when "HW not ready"
  (git-fixes).
- iwlwifi: pcie: fix locking when "HW not ready" (git-fixes).
- libsubcmd: Fix use-after-free for realloc(..., 0) (git-fixes).
- USB: serial: cp210x: add CPI Bulk Coin Recycler id (git-fixes).
- USB: serial: cp210x: add NCR Retail IO box id (git-fixes).
- USB: serial: ftdi_sio: add support for Brainboxes US-159/235/320
  (git-fixes).
- USB: serial: option: add ZTE MF286D modem (git-fixes).
- USB: serial: ch341: add support for GW Instek USB2.0-Serial
  devices (git-fixes).
- usb: gadget: rndis: check size of RNDIS_MSG_SET command
  (git-fixes).
- usb: gadget: f_uac2: Define specific wTerminalType (git-fixes).
- ACPI/IORT: Check node revision for PMCG resources (git-fixes).
- net: phy: marvell: Fix RGMII Tx/Rx delays setting in
  88e1121-compatible PHYs (git-fixes).
- net: phy: marvell: Fix MDI-x polarity setting in
  88e1118-compatible PHYs (git-fixes).
- usb: dwc2: gadget: don't try to disable ep0 in
  dwc2_hsotg_suspend (git-fixes).
- PM: hibernate: Remove register_nosave_region_late() (git-fixes).
- drm: panel-orientation-quirks: Add quirk for the 1Netbook
  OneXPlayer (git-fixes).
- net: phy: marvell: configure RGMII delays for 88E1118
  (git-fixes).
- commit cc7a24c
* Fri Feb 18 2022 neilb@suse.de
- NFSD: Fix the behavior of READ near OFFSET_MAX (bsc#1195957).
- commit 9af94a7
* Thu Feb 17 2022 tiwai@suse.de
- USB: gadget: validate interface OS descriptor requests
  (CVE-2022-25258 bsc#1196095).
- commit 4c69367
* Thu Feb 17 2022 tiwai@suse.de
- Drop PCI xgene patch that caused a regression for mxl4 (bsc#1195352)
  Delete patches.suse/PCI-xgene-Fix-IB-window-setup.patch
  Also update blacklist
- commit 4f68062
* Thu Feb 17 2022 tbogendoerfer@suse.de
- gve: Recording rx queue before sending to napi (bsc#1191655).
- gve: Add consumed counts to ethtool stats (bsc#1191655).
- gve: Implement suspend/resume/shutdown (bsc#1191655).
- gve: Add optional metadata descriptor type GVE_TXD_MTD
  (bsc#1191655).
- gve: remove memory barrier around seqno (bsc#1191655).
- gve: Update gve_free_queue_page_list signature (bsc#1191655).
- gve: Move the irq db indexes out of the ntfy block struct
  (bsc#1191655).
- gve: Correct order of processing device options (bsc#1191655).
- gve: fix for null pointer dereference (bsc#1191655).
- gve: fix unmatched u64_stats_update_end() (bsc#1191655).
- gve: Fix off by one in gve_tx_timeout() (bsc#1191655).
- gve: Add a jumbo-frame device option (bsc#1191655).
- gve: Implement packet continuation for RX (bsc#1191655).
- gve: Add RX context (bsc#1191655).
- gve: Recover from queue stall due to missed IRQ (bsc#1191655).
- gve: Use kvcalloc() instead of kvzalloc() (bsc#1191655).
- commit 4a8e1e2
* Thu Feb 17 2022 hare@suse.de
- scsi_transport_fc: kabi fix blank out FC_PORTSTATE_MARGINAL
  (bsc#1195506).
- commit c74c330
* Thu Feb 17 2022 hare@suse.de
- scsi: kABI fix for 'eh_should_retry_cmd' (bsc#1195506).
- commit 8ef8f22
* Thu Feb 17 2022 colyli@suse.de
- md/raid5: fix oops during stripe resizing (bsc#1181588).
- commit bcd3697
* Wed Feb 16 2022 msuchanek@suse.de
- powerpc/pseries: read the lpar name from the firmware
  (bsc#1187716 ltc#193451).
- commit 181541b
* Wed Feb 16 2022 msuchanek@suse.de
- Refresh patches.suse/rpadlpar_io-Add-MODULE_DESCRIPTION-entries-to-kernel.patch
- commit c964381
* Wed Feb 16 2022 msuchanek@suse.de
- powerpc: add link stack flush mitigation status in debugfs
  (bsc#1157038 bsc#1157923 ltc#182612 git-fixes).
- powerpc/64s: Fix debugfs_simple_attr.cocci warnings (bsc#1157038
  bsc#1157923 ltc#182612 git-fixes).
- commit 5862a79
* Wed Feb 16 2022 msuchanek@suse.de
- powerpc: Set crashkernel offset to mid of RMA region
  (bsc#1190812).
- powerpc/64: Move paca allocation later in boot (bsc#1190812).
- commit 11e3668
* Wed Feb 16 2022 dwagner@suse.de
- nvme-fabrics: fix state check in nvmf_ctlr_matches_baseopts()
  (bsc#1195012).
- commit 4d29ac4
* Wed Feb 16 2022 dwagner@suse.de
- scsi: lpfc: Fix pt2pt NVMe PRLI reject LOGO loop (bsc#1189126).
- commit 73dbd5c
* Wed Feb 16 2022 dwagner@suse.de
- scsi: qla2xxx: Remove unused qla_sess_op_cmd_list from
  scsi_qla_host_t (bsc#1195823).
- scsi: qla2xxx: Add qla2x00_async_done() for async routines
  (bsc#1195823).
- scsi: qla2xxx: Update version to 10.02.07.300-k (bsc#1195823).
- scsi: qla2xxx: Check for firmware dump already collected
  (bsc#1195823).
- scsi: qla2xxx: Add devids and conditionals for 28xx
  (bsc#1195823).
- scsi: qla2xxx: Suppress a kernel complaint in qla_create_qpair()
  (bsc#1195823).
- scsi: qla2xxx: Fix T10 PI tag escape and IP guard options for
  28XX adapters (bsc#1195823).
- scsi: qla2xxx: edif: Fix clang warning (bsc#1195823).
- scsi: qla2xxx: Fix warning for missing error code (bsc#1195823).
- scsi: qla2xxx: Fix device reconnect in loop topology
  (bsc#1195823).
- scsi: qla2xxx: Add ql2xnvme_queues module param to configure
  number of NVMe queues (bsc#1195823).
- scsi: qla2xxx: Fix wrong FDMI data for 64G adapter
  (bsc#1195823).
- scsi: qla2xxx: Add retry for exec firmware (bsc#1195823).
- scsi: qla2xxx: Fix scheduling while atomic (bsc#1195823).
- scsi: qla2xxx: Fix premature hw access after PCI error
  (bsc#1195823).
- scsi: qla2xxx: Fix warning message due to adisc being flushed
  (bsc#1195823).
- scsi: qla2xxx: Fix stuck session in gpdb (bsc#1195823).
- scsi: qla2xxx: Implement ref count for SRB (bsc#1195823).
- scsi: qla2xxx: Refactor asynchronous command initialization
  (bsc#1195823).
- scsi: qla2xxx: Update version to 10.02.07.200-k (bsc#1195823).
- scsi: qla2xxx: edif: Fix inconsistent check of db_flags
  (bsc#1195823).
- scsi: qla2xxx: edif: Reduce connection thrash (bsc#1195823).
- scsi: qla2xxx: edif: Tweak trace message (bsc#1195823).
- scsi: qla2xxx: edif: Replace list_for_each_safe with
  list_for_each_entry_safe (bsc#1195823).
- scsi: qla2xxx: Remove a declaration (bsc#1195823).
- scsi: qla2xxx: Fix unmap of already freed sgl (bsc#1195823).
- scsi: qla2xxx: Return -ENOMEM if kzalloc() fails (bsc#1195823).
- commit c358f38
* Wed Feb 16 2022 tbogendoerfer@suse.de
- ice: fix IPIP and SIT TSO offload (git-fixes).
- ice: fix an error code in ice_cfg_phy_fec() (jsc#SLE-12878).
- net: mdio: aspeed: Add missing MODULE_DEVICE_TABLE
  (bsc#1176447).
- nfp: flower: fix ida_idx not being released (bsc#1154353).
- bonding: pair enable_port with slave_arr_updates (git-fixes).
- ixgbevf: Require large buffers for build_skb on 82599VF
  (git-fixes).
- RDMA/cma: Use correct address when leaving multicast group
  (bsc#1181147).
- IB/cma: Do not send IGMP leaves for sendonly Multicast groups
  (git-fixes).
- commit 679175c
* Wed Feb 16 2022 oneukum@suse.com
- USB: serial: mos7840: remove duplicated 0xac24 device ID
  (git-fixes).
- commit 546d043
* Wed Feb 16 2022 mbenes@suse.cz
- tracing: Don't inc err_log entry count if entry allocation fails
  (git-fixes).
- commit 5c45742
* Wed Feb 16 2022 mbenes@suse.cz
- tracing: Propagate is_signed to expression (git-fixes).
- commit a834cba
* Wed Feb 16 2022 mbenes@suse.cz
- blacklist.conf: b59f2f2b865c ("tracing: Fix smatch warning for do while check in event_hist_trigger_parse()")
  Cosmetic only.
- commit f0fcec9
* Wed Feb 16 2022 mbenes@suse.cz
- tracing: Fix smatch warning for null glob in
  event_hist_trigger_parse() (git-fixes).
- commit 329e4ac
* Tue Feb 15 2022 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: use default dracut modules (bsc#1195926,
  bsc#1198484)
  Let's iron out the reduced initrd optimisation in Tumbleweed.
  Build full blown dracut initrd with systemd for SLE15 SP4.
- commit ea76821
* Tue Feb 15 2022 msuchanek@suse.de
- powerpc/pseries/ddw: Revert "Extend upper limit for huge DMA
  window for persistent memory" (bsc#1195995 ltc#196394).
- commit 877b9c1
* Tue Feb 15 2022 tiwai@suse.de
- f2fs: fix to do sanity check on inode type during garbage
  collection (CVE-2021-44879 bsc#1195987).
- commit 139271b
* Tue Feb 15 2022 tiwai@suse.de
- misc: fastrpc: avoid double fput() on failed usercopy
  (git-fixes).
- staging: fbtft: Fix error path in fbtft_driver_module_init()
  (git-fixes).
- usb: dwc3: gadget: Prevent core from processing stale TRBs
  (git-fixes).
- usb: gadget: udc: renesas_usb3: Fix host to USB_ROLE_NONE
  transition (git-fixes).
- usb: ulpi: Call of_node_put correctly (git-fixes).
- usb: ulpi: Move of_node_put to ulpi_dev_release (git-fixes).
- usb: f_fs: Fix use-after-free for epfile (git-fixes).
- PM: s2idle: ACPI: Fix wakeup interrupts handling (git-fixes).
- drm/rockchip: vop: Correct RK3399 VOP register fields
  (git-fixes).
- drm/panel: simple: Assign data from panel_dpi_probe() correctly
  (git-fixes).
- drm/vc4: hdmi: Allow DBLCLK modes even if horz timing is odd
  (git-fixes).
- ASoC: ops: Reject out of bounds values in snd_soc_put_xr_sx()
  (git-fixes).
- ASoC: ops: Reject out of bounds values in snd_soc_put_volsw_sx()
  (git-fixes).
- ASoC: ops: Reject out of bounds values in snd_soc_put_volsw()
  (git-fixes).
- ALSA: hda/realtek: Add quirk for ASUS GU603 (git-fixes).
- ALSA: hda/realtek: Fix silent output on Gigabyte X570 Aorus
  Xtreme after reboot from Windows (git-fixes).
- ALSA: hda/realtek: Fix silent output on Gigabyte X570S Aorus
  Master (newer chipset) (git-fixes).
- ALSA: hda/realtek: Add missing fixup-model entry for Gigabyte
  X570 ALC1220 quirks (git-fixes).
- staging/fbtft: Fix backlight (git-fixes).
- commit 033cee4
* Tue Feb 15 2022 oneukum@suse.com
- usb: dwc2: Fix NULL qh in dwc2_queue_transaction (git-fixes).
- commit 7b9eed7
* Tue Feb 15 2022 oneukum@suse.com
- blacklist.conf: misattributed upstream
- commit f62cf37
* Tue Feb 15 2022 oneukum@suse.com
- usb: gadget: s3c: remove unused 'udc' variable (git-fixes).
- commit a103972
* Tue Feb 15 2022 denis.kirjanov@suse.com
- tipc: improve size validations for received domain records
  (bsc#1195254, CVE-2022-0435).
- commit 48911da
* Tue Feb 15 2022 tiwai@suse.de
- yam: fix a memory leak in yam_siocdevprivate() (CVE-2022-24959
  bsc#1195897).
- commit 60220af
* Mon Feb 14 2022 tiwai@suse.de
- usb: gadget: clear related members when goto fail
  (CVE-2022-24958 bsc#1195905).
- usb: gadget: don't release an existing dev->buf (CVE-2022-24958
  bsc#1195905).
- commit 96dda76
* Mon Feb 14 2022 lhenriques@suse.de
- scsi: target: iscsi: Fix cmd abort fabric stop race
  (bsc#1195286).
- commit 52d26b6
* Mon Feb 14 2022 ptesarik@suse.cz
- kabi: Hide changes to s390/AP structures (jsc#SLE-20807).
- commit 3d90f3c
* Mon Feb 14 2022 vkarasulli@suse.de
- Update patches.suse/0001-mmc-moxart_remove-Fix-UAF.patch
  (bsc#1194516 CVE-2022-0487).
- commit f68f189
* Mon Feb 14 2022 neilb@suse.de
- nfsd: don't admin-revoke NSv4.0 state ids (bsc#1192483).
- nfsd: allow delegation state ids to be revoked and then freed (bsc#1192483).
- nfsd: allow lock state ids to be revoked and then freed (bsc#1192483).
- nfsd: allow open state ids to be revoked and then freed (bsc#1192483).
- nfsd: prepare for supporting admin-revocation of state (bsc#1192483).
- commit c0baca0
* Sun Feb 13 2022 bp@suse.de
- EDAC/xgene: Fix deferred probing (bsc#1178134).
- commit 9308a14
* Fri Feb 11 2022 msuchanek@suse.de
- kernel-binary: Do not include sourcedir in certificate path.
  The certs macro runs before build directory is set up so it creates the
  aggregate of supplied certificates in the source directory.
  Using this file directly as the certificate in kernel config works but
  embeds the source directory path in the kernel config.
  To avoid this symlink the certificate to the build directory and use
  relative path to refer to it.
  Also fabricate a certificate in the same location in build directory
  when none is provided.
- commit bb988d4
* Fri Feb 11 2022 msuchanek@suse.de
- constraints: Also adjust disk requirement for x86 and s390.
- commit 9719db0
* Fri Feb 11 2022 msuchanek@suse.de
- constraints: Increase disk space for aarch64
- commit 09c2882
* Fri Feb 11 2022 ptesarik@suse.cz
- s390/protvirt: fix error return code in uv_info_init()
  (jsc#SLE-22135).
- commit 7f8b088
* Fri Feb 11 2022 ptesarik@suse.cz
- s390/AP: support new dynamic AP bus size limit (jsc#SLE-20807).
- commit 004f3c6
* Thu Feb 10 2022 lizhang@suse.de
- KVM: s390: Return error on SIDA memop on normal guest
  (bsc#1195516 CVE-2022-0516).
- commit d46602b
* Thu Feb 10 2022 lhenriques@suse.de
- ceph: set pool_ns in new inode layout for async creates
  (bsc#1195799).
- ceph: properly put ceph_string reference after async create
  attempt (bsc#1195798).
- commit 8f44ef0
* Thu Feb 10 2022 rgoldwyn@suse.com
- btrfs: make sure SB_I_VERSION doesn't get unset by remount (bsc#1192210).
- commit 9acc804
* Thu Feb 10 2022 ptesarik@suse.cz
- s390/uv: fix prot virt host indication compilation
  (jsc#SLE-22135).
- s390/uv: add prot virt guest/host indication files
  (jsc#SLE-22135).
- commit f479d35
* Wed Feb  9 2022 tiwai@suse.de
- drm/i915: Remove memory frequency calculation (bsc#1195211).
- commit ea4d32b
* Wed Feb  9 2022 tiwai@suse.de
- drm/i915: Rename is_16gb_dimm to wm_lv_0_adjust_needed
  (bsc#1195211).
- drm/i915/gen11+: Only load DRAM information from pcode
  (bsc#1195211).
- drm/i915: Nuke not needed members of dram_info (bsc#1195211).
- drm/i915/dg1: Wait for pcode/uncore handshake at startup
  (bsc#1195211).
- commit d7995a2
* Wed Feb  9 2022 msuchanek@suse.de
- ibmvnic: don't release napi in __ibmvnic_open() (bsc#1195668
  ltc#195811).
- commit 902d854
* Wed Feb  9 2022 vkarasulli@suse.de
- NFSv4: Handle case where the lookup of a directory fails
  (bsc#1195612 CVE-2022-24448).
- commit 1023a28
* Wed Feb  9 2022 tabraham@suse.com
- btrfs: check for missing device in btrfs_trim_fs (bsc#1195701).
- commit ccd41ed
* Tue Feb  8 2022 mkoutny@suse.com
- cgroup-v1: Require capabilities to set release_agent
  (bsc#1195543 CVE-2022-0492).
- commit 413d689
* Tue Feb  8 2022 tbogendoerfer@suse.de
- RDMA/ucma: Protect mc during concurrent multicast leaves
  (bsc#1181147).
- IB/hfi1: Fix AIP early init panic (jsc#SLE-13208).
- net/mlx5e: Fix handling of wrong devices during bond netevent
  (jsc#SLE-15172).
- gve: fix the wrong AdminQ buffer queue index check
  (bsc#1176940).
- gve: Fix GFP flags when allocing pages (git-fixes).
- i40e: fix unsigned stat widths (git-fixes).
- i40e: Fix for failed to init adminq while VF reset (git-fixes).
- i40e: Fix queues reservation for XDP (git-fixes).
- i40e: Fix issue when maximum queues is exceeded (git-fixes).
- i40e: Increase delay to 1 s after global EMP reset (git-fixes).
- commit 6aa87c4
* Tue Feb  8 2022 tiwai@suse.de
- Update patch reference for HD-audio fix (bsc#1183872)
- commit 1e16eaa
* Tue Feb  8 2022 oneukum@suse.com
- usb: host: ehci-tegra: Fix error handling in tegra_ehci_probe()
  (git-fixes).
- commit 2492c7d
* Tue Feb  8 2022 tiwai@suse.de
- mmc: sdhci-of-esdhc: Check for error num after setting mask
  (git-fixes).
- ima: Do not print policy rule with inactive LSM labels
  (git-fixes).
- ima: Allow template selection with ima_template[_fmt]= after
  ima_hash= (git-fixes).
- ima: Remove ima_policy file before directory (git-fixes).
- integrity: check the return value of audit_log_start()
  (git-fixes).
- integrity: double check iint_cache was initialized (git-fixes).
- integrity: Make function integrity_add_key() static (git-fixes).
- commit a8bf0cb
* Tue Feb  8 2022 nmoreychaisemartin@suse.com
- RDMA/core: Always release restrack object (git-fixes)
- commit a4c74f1
* Tue Feb  8 2022 nmoreychaisemartin@suse.com
- RDMA/siw: Release xarray entry (git-fixes)
- commit cfa201c
* Tue Feb  8 2022 nmoreychaisemartin@suse.com
- RDMA/cxgb4: check for ipv6 address properly while destroying listener (git-fixes)
- commit 06f1504
* Tue Feb  8 2022 tonyj@suse.de
- blacklist.conf: blacklist a672b2e36a64 bpf: Fix ringbuf memory type confusion when passing to helpers
- commit 2bfec1b
* Tue Feb  8 2022 tonyj@suse.de
- bpf: Disallow BPF_LOG_KERNEL log level for bpf(BPF_BTF_LOAD)
  (git-fixes).
- bpf: Adjust BTF log size limit (git-fixes).
- commit 5e3ed1a
* Mon Feb  7 2022 ptesarik@suse.cz
- s390/sclp: fix Secure-IPL facility detection (bsc#1191741
  LTC#194816).
- commit 5aa085e
* Mon Feb  7 2022 oneukum@suse.com
- usb: dwc3: don't set gadget->is_otg flag (git-fixes).
- commit 5b20187
* Mon Feb  7 2022 msuchanek@suse.de
- powerpc/perf: Fix power_pmu_disable to call
  clear_pmi_irq_pending only if PMI is pending (bsc#1156395).
- commit a08ca77
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/uverbs: Fix a NULL vs IS_ERR() bug (git-fixes)
- commit 82ce09e
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Fix query DCT via DEVX (git-fixes)
- commit 4b56cb2
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/core: Don't access cm_id after its destruction (git-fixes)
- commit 4a117e6
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Recover from fatal event in dual port mode (git-fixes)
- commit 875e0ed
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Clear all QP fields if creation failed (git-fixes)
- commit 07c8b4d
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/siw: Properly check send and receive CQ pointers (git-fixes)
- commit d84b45b
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/bnxt_re: Fix a double free in bnxt_qplib_alloc_res (git-fixes)
- commit 8c226d5
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/siw: Fix a use after free in siw_alloc_mr (git-fixes)
- commit a7eff62
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/i40iw: Fix error unwinding when i40iw_hmc_sd_one fails (git-fixes)
- commit 2db1c84
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/cxgb4: add missing qpid increment (git-fixes)
- commit 591cdce
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/core: Unify RoCE check and re-factor code (git-fixes)
- commit e5e3d6f
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/bnxt_re: Fix error return code in bnxt_qplib_cq_process_terminal() (git-fixes)
- commit 76267d4
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- IB/hfi1: Fix error return code in parse_platform_config() (git-fixes)
- commit 270bb46
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- IB/hfi1: Use kzalloc() for mmu_rb_handler allocation (git-fixes)
- commit 05c0e16
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/core: Fix corrupted SL on passive side (git-fixes)
- commit d86d9cb
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- IB/isert: Fix a use after free in isert_connect_request (git-fixes)
- commit fa7abfc
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/addr: Be strict with gid size (git-fixes)
- commit 0b96850
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/cxgb4: Fix adapter LE hash errors while destroying ipv6 listening server (git-fixes)
- commit 0f86491
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- IB/mlx5: Add missing error code (git-fixes)
- commit 06919f0
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix missing kconfig dependency on CRYPTO (git-fixes)
- commit 1cb9b27
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/siw: Fix calculation of tx_valid_cpus size (git-fixes)
- commit 35656e8
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Correct skb on loopback path (git-fixes)
- commit 328cd44
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix coding error in rxe_rcv_mcast_pkt (git-fixes)
- commit ad066a1
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Remove useless code in rxe_recv.c (git-fixes)
- commit 6a7743e
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix coding error in rxe_recv.c (git-fixes)
- commit 671cb83
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- IB/cm: Avoid a loop when device has 255 ports (git-fixes)
- commit 2186e0a
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- IB/mlx5: Return appropriate error code instead of ENOMEM (git-fixes)
- commit ba2e4e5
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- IB/umad: Return EPOLLERR in case of when device disassociated (git-fixes)
- commit 0fc8532
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- IB/umad: Return EIO in case of when device disassociated (git-fixes)
- commit 1beb1a9
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- IB/mlx5: Add mutex destroy call to cap_mask_mutex mutex (git-fixes)
- commit b747600
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Use the correct obj_id upon DEVX TIR creation (git-fixes)
- commit d209b75
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/siw: Fix handling of zero-sized Read and Receive Queues. (git-fixes)
- commit 1bcb139
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/cxgb4: Fix the reported max_recv_sge value (git-fixes)
- commit 000358b
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Fix wrong free of blue flame register on error (git-fixes)
- commit a95b8b5
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- IB/mlx5: Fix error unwinding when set_has_smi_cap fails (git-fixes)
- commit c125ce0
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/ocrdma: Fix use after free in ocrdma_dealloc_ucontext_pd() (git-fixes)
- commit 717d46c
* Mon Feb  7 2022 nmoreychaisemartin@suse.com
- RDMA/usnic: Fix memleak in find_free_vf_and_create_qp_grp (git-fixes)
- commit e2b003d
* Mon Feb  7 2022 tiwai@suse.de
- Input: wm97xx: Simplify resource management (git-fixes).
- ASoC: fsl: Add missing error handling in pcm030_fabric_probe
  (git-fixes).
- ASoC: max9759: fix underflow in speaker_gain_control_put()
  (git-fixes).
- ASoC: cpcap: Check for NULL pointer after calling
  of_get_child_by_name (git-fixes).
- ASoC: xilinx: xlnx_formatter_pcm: Make buffer bytes multiple
  of period bytes (git-fixes).
- ALSA: usb-audio: Correct quirk for VF0770 (git-fixes).
- ALSA: usb-audio: initialize variables that could ignore errors
  (git-fixes).
- drm/i915/overlay: Prevent divide by zero bugs in scaling
  (git-fixes).
- dma-buf: heaps: Fix potential spectre v1 gadget (git-fixes).
- drm/nouveau: fix off by one in BIOS boundary checking
  (git-fixes).
- pinctrl: intel: Fix a glitch when updating IRQ flags on a
  preconfigured line (git-fixes).
- pinctrl: intel: fix unexpected interrupt (git-fixes).
- commit 78392e2
* Mon Feb  7 2022 hare@suse.de
- nvme: fix use after free when disconnecting a reconnecting ctrl
  (git-fixes).
- commit 6b18639
* Mon Feb  7 2022 hare@suse.de
- nvme-tcp: validate R2T PDU in nvme_tcp_handle_r2t() (git-fixes).
- nvme-tcp: fix data digest pointer calculation (git-fixes).
- nvme-tcp: fix incorrect h2cdata pdu offset accounting
  (git-fixes).
- commit 64fba5e
* Mon Feb  7 2022 hare@suse.de
- nvme-tcp: fix possible use-after-completion (git-fixes).
- commit 656adbf
* Mon Feb  7 2022 hare@suse.de
- nvme-fabrics: avoid double completions in
  nvmf_fail_nonready_command (git-fixes).
- nvme: introduce a nvme_host_path_error helper (git-fixes).
- blk-mq: introduce blk_mq_set_request_complete (git-fixes).
- nvme: refactor ns->ctrl by request (git-fixes).
- nvme-core: use list_add_tail_rcu instead of list_add_tail for
  nvme_init_ns_head (git-fixes).
- commit 35ee4c2
* Mon Feb  7 2022 neilb@suse.de
- Refresh patches.suse/NFS-don-t-store-struct-cred-in-struct-nfs_access_ent.patch.
  Update upstream info
- commit 7228799
* Mon Feb  7 2022 neilb@suse.de
- NFSv4: nfs_atomic_open() can race when looking up a non-regular
  file (git-fixes).
- NFSv4: Handle case where the lookup of a directory fails
  (git-fixes).
- NFS: Ensure the server has an up to date ctime before renaming
  (git-fixes).
- commit 1b23644
* Fri Feb  4 2022 lduncan@suse.com
- scsi: ufs: Correct the LUN used in eh_device_reset_handler()
  callback (bsc#1193864 CVE-2021-39657).
- commit 5ec67f9
* Fri Feb  4 2022 hare@suse.de
- scsi: qla2xxx: Add marginal path handling support (bsc#1195506).
- scsi: lpfc: Add support for eh_should_retry_cmd() (bsc#1195506).
- scsi: scsi_transport_fc: Add store capability to rport port_state in sysfs (bsc#1195506).
- scsi: scsi_transport_fc: Add a new rport state FC_PORTSTATE_MARGINAL (bsc#1195506).
- scsi: core: No retries on abort success (bsc#1195506).
- scsi: core: Add a new error code DID_TRANSPORT_MARGINAL in scsi.h (bsc#1195506).
- scsi: core: Add limitless cmd retry support (bsc#1195506).
- commit af99987
* Thu Feb  3 2022 jack@suse.cz
- blk-cgroup: fix missing put device in error path from
  blkg_conf_pref() (bsc#1195481).
- commit 1d9f7ed
* Thu Feb  3 2022 jack@suse.cz
- ext4: fix an use-after-free issue about data=journal writeback
  mode (bsc#1195482).
- commit dec4e3b
* Thu Feb  3 2022 jack@suse.cz
- ext4: make sure quota gets properly shutdown on error
  (bsc#1195480).
- commit 37600f0
* Thu Feb  3 2022 jack@suse.cz
- blacklist.conf: blacklist 4013d47a5307
- commit 3d0f1d1
* Thu Feb  3 2022 jack@suse.cz
- fsnotify: fix fsnotify hooks in pseudo filesystems
  (bsc#1195479).
- commit 3ed7ace
* Thu Feb  3 2022 jack@suse.cz
- fsnotify: invalidate dcache before IN_DELETE event
  (bsc#1195478).
- commit 776f92d
* Thu Feb  3 2022 jack@suse.cz
- udf: Restore i_lenAlloc when inode expansion fails
  (bsc#1195477).
- commit fa5618c
* Thu Feb  3 2022 jack@suse.cz
- udf: Fix NULL ptr deref when converting from inline format
  (bsc#1195476).
- commit 26d7db1
* Thu Feb  3 2022 jack@suse.cz
- blacklist.conf: Blacklist ee12595147ac
- commit 1e354ac
* Wed Feb  2 2022 oneukum@suse.com
- USB: serial: mos7840: fix probe error handling (git-fixes).
- commit 3875819
* Wed Feb  2 2022 oneukum@suse.com
- xhci-pci: Allow host runtime PM as default for Intel Alpine
  Ridge LP (git-fixes).
- commit 7bdac2d
* Wed Feb  2 2022 tiwai@suse.de
- Update patch reference for radeon regression fix (bsc#1195142)
- commit 3e139f1
* Wed Feb  2 2022 tiwai@suse.de
- spi: mediatek: Avoid NULL pointer crash in interrupt
  (git-fixes).
- spi: bcm-qspi: check for valid cs before applying chip select
  (git-fixes).
- spi: meson-spicc: add IRQ check in meson_spicc_probe
  (git-fixes).
- tty: Add support for Brainboxes UC cards (git-fixes).
- USB: core: Fix hang in usb_kill_urb by adding memory barriers
  (git-fixes).
- usb-storage: Add unusual-devs entry for VL817 USB-SATA bridge
  (git-fixes).
- PM: wakeup: simplify the output logic of pm_show_wakelocks()
  (git-fixes).
- drm/msm/dsi: Fix missing put_device() call in dsi_get_phy
  (git-fixes).
- rpmsg: char: Fix race between the release of rpmsg_eptdev and
  cdev (git-fixes).
- rpmsg: char: Fix race between the release of rpmsg_ctrldev
  and cdev (git-fixes).
- Bluetooth: refactor malicious adv data check (git-fixes).
- commit 0420ac4
* Tue Feb  1 2022 tbogendoerfer@suse.de
- Update
  patches.suse/bonding-fix-null-dereference-in-bond_ipsec_add_sa.patch
  (bsc#1176447 bsc#1195371 CVE-2022-0286).
  Added CVE reference.
- commit e1eaedd
* Tue Feb  1 2022 tbogendoerfer@suse.de
- net: bridge: vlan: fix memory leak in __allowed_ingress
  (bsc#1176447).
- net: bridge: vlan: fix single net device option dumping
  (bsc#1176447).
- net: sfp: fix high power modules without diagnostic monitoring
  (bsc#1154353).
- net: bonding: fix bond_xmit_broadcast return value error bug
  (bsc#1176447).
- RDMA/rxe: Remove the unnecessary variable (jsc#SLE-15176).
- Revert "net/mlx5e: Block offload of outer header csum for GRE
  tunnel" (git-fixes).
- Revert "net/mlx5e: Block offload of outer header csum for UDP
  tunnels" (git-fixes).
- igc: Fix TX timestamp support for non-MSI-X platforms
  (bsc#1160634).
- net/mlx5: E-Switch, fix changing vf VLANID (jsc#SLE-15172).
- RDMA/core: Clean up cq pool mechanism (jsc#SLE-15176).
- net/mlx5: DR, Proper handling of unsupported Connect-X6DX SW
  steering (jsc#SLE-8464).
- vxlan: fix error return code in __vxlan_dev_create()
  (bsc#1154353).
- netdevsim: set .owner to THIS_MODULE (bsc#1154353).
- net/mlx5e: Protect encap route dev from concurrent release
  (jsc#SLE-8464).
- mlxsw: Only advertise link modes supported by both driver and
  device (bsc#1154488).
- commit 8d79e55
* Mon Jan 31 2022 msuchanek@suse.de
- Refresh patches.suse/ALSA-pcm-oss-Place-the-plugin-buffer-overflow-checks.patch.
  Remove duplicated tag.
- commit 6c506e7
* Mon Jan 31 2022 dmueller@suse.com
- scripts/dtc: only append to HOST_EXTRACFLAGS instead of
  overwriting (git-fixes).
- commit 644966c
* Mon Jan 31 2022 ludwig.nussel@suse.de
- kernel-obs-build: include 9p (boo#1195353)
  To be able to share files between host and the qemu vm of the build
  script, the 9p and 9p_virtio kernel modules need to be included in
  the initrd of kernel-obs-build.
- commit 0cfe67a
* Mon Jan 31 2022 tiwai@suse.de
- drm/etnaviv: relax submit size limits (git-fixes).
- commit de0ae66
* Mon Jan 31 2022 tiwai@suse.de
- usb: common: ulpi: Fix crash in ulpi_match() (git-fixes).
- usb: gadget: f_sourcesink: Fix isoc transfer for
  USB_SPEED_SUPER_PLUS (git-fixes).
- usb: typec: tcpm: Do not disconnect while receiving VBUS off
  (git-fixes).
- usb: roles: fix include/linux/usb/role.h compile issue
  (git-fixes).
- phylib: fix potential use-after-free (git-fixes).
- x86/gpu: Reserve stolen memory for first integrated Intel GPU
  (git-fixes).
- PCI: Add function 1 DMA alias quirk for Marvell 88SE9125 SATA
  controller (git-fixes).
- phy: uniphier-usb3ss: fix unintended writing zeros to PHY
  register (git-fixes).
- usb: hub: Add delay for SuperSpeed hub resume to let links
  transit to U0 (git-fixes).
- usb: uhci: add aspeed ast2600 uhci support (git-fixes).
- usb: gadget: f_fs: Use stream_open() for endpoint files
  (git-fixes).
- serial: core: Keep mctrl register state and cached copy in sync
  (git-fixes).
- serial: pl010: Drop CR register reset on set_termios
  (git-fixes).
- serial: Fix incorrect rs485 polarity on uart open (git-fixes).
- serial: amba-pl011: do not request memory region twice
  (git-fixes).
- mmc: core: Fixup storing of OCR for MMC_QUIRK_NONSTD_SDIO
  (git-fixes).
- regulator: qcom_smd: Align probe function with rpmh-regulator
  (git-fixes).
- mtd: rawnand: gpmi: Add ERR007117 protection for
  nfc_apply_timings (git-fixes).
- mtd: rawnand: gpmi: Remove explicit default gpmi clock setting
  for i.MX6 (git-fixes).
- rsi: Fix use-after-free in rsi_rx_done_handler() (git-fixes).
- media: coda/imx-vdoa: Handle dma_set_coherent_mask error codes
  (git-fixes).
- mtd: nand: bbt: Fix corner case in bad block table handling
  (git-fixes).
- commit ceccaf4
* Mon Jan 31 2022 tiwai@suse.de
- lib82596: Fix IRQ check in sni_82596_probe (git-fixes).
- i2c: designware-pci: Fix to change data types of hcnt and lcnt
  parameters (git-fixes).
- i2c: mpc: Correct I2C reset procedure (git-fixes).
- i2c: i801: Don't silently correct invalid transfer size
  (git-fixes).
- gpiolib: acpi: Do not set the IRQ type if the IRQ is already
  in use (git-fixes).
- HID: apple: Do not reset quirks when the Fn key is not found
  (git-fixes).
- HID: quirks: Allow inverting the absolute X/Y values
  (git-fixes).
- mac80211: allow non-standard VHT MCS-10/11 (git-fixes).
- iwlwifi: mvm: Fix calculation of frame length (git-fixes).
- iwlwifi: remove module loading failure message (git-fixes).
- iwlwifi: fix leaks/bad data after failed firmware load
  (git-fixes).
- iwlwifi: mvm: Increase the scan timeout guard to 30 seconds
  (git-fixes).
- iwlwifi: mvm: synchronize with FW after multicast commands
  (git-fixes).
- media: saa7146: hexium_gemini: Fix a NULL pointer dereference
  in hexium_attach() (git-fixes).
- media: igorplugusb: receiver overflow should be reported
  (git-fixes).
- media: m920x: don't use stack on USB reads (git-fixes).
- media: saa7146: hexium_orion: Fix a NULL pointer dereference
  in hexium_attach() (git-fixes).
- media: uvcvideo: Increase UVC_CTRL_CONTROL_TIMEOUT to 5 seconds
  (git-fixes).
- media: b2c2: Add missing check in flexcop_pci_isr: (git-fixes).
- commit a86fa77
* Mon Jan 31 2022 tiwai@suse.de
- floppy: Add max size check for user space request (git-fixes).
- gpio: aspeed: Convert aspeed_gpio.lock to raw_spinlock
  (git-fixes).
- Bluetooth: Fix debugfs entry leak in hci_register_dev()
  (git-fixes).
- drm/amdgpu: fixup bad vram size on gmc v8 (git-fixes).
- drm/etnaviv: limit submit sizes (git-fixes).
- drm/bridge: megachips: Ensure both bridges are probed before
  registration (git-fixes).
- drm: panel-orientation-quirks: Add quirk for the Lenovo Yoga
  Book X91F/L (git-fixes).
- drm/nouveau/kms/nv04: use vzalloc for nv04_display (git-fixes).
- drm/nouveau/pmu/gm200-: avoid touching PMU outside of
  DEVINIT/PREOS/ACR (git-fixes).
- drm/lima: fix warning when CONFIG_DEBUG_SG=y &
  CONFIG_DMA_API_DEBUG=y (git-fixes).
- commit d637736
* Mon Jan 31 2022 tiwai@suse.de
- ASoC: mediatek: mt8173: fix device_node leak (git-fixes).
- ALSA: seq: Set upper limit of processed events (git-fixes).
- ACPICA: Hardware: Do not flush CPU cache when entering S4 and S5
  (git-fixes).
- ACPICA: Fix wrong interpretation of PCC address (git-fixes).
- ACPICA: Executer: Fix the REFCLASS_REFOF case in
  acpi_ex_opcode_1A_0T_1R() (git-fixes).
- ACPICA: Utilities: Avoid deleting the same object twice in a
  row (git-fixes).
- batman-adv: allow netlink usage in unprivileged containers
  (git-fixes).
- ath9k: Fix out-of-bound memcpy in ath9k_hif_usb_rx_stream
  (git-fixes).
- ath10k: Fix tx hanging (git-fixes).
- ar5523: Fix null-ptr-deref with unexpected WDCMSG_TARGET_START
  reply (git-fixes).
- commit b090e4d
* Mon Jan 31 2022 tiwai@suse.de
- hwmon: (lm90) Mark alert as broken for MAX6646/6647/6649
  (git-fixes).
- hwmon: (lm90) Mark alert as broken for MAX6680 (git-fixes).
- hwmon: (lm90) Mark alert as broken for MAX6654 (git-fixes).
- hwmon: (lm90) Reduce maximum conversion rate for G781
  (git-fixes).
- drm/msm/dsi: invalid parameter check in msm_dsi_phy_enable
  (git-fixes).
- drm/msm: Fix wrong size calculation (git-fixes).
- drm/msm/dpu: invalid parameter check in dpu_setup_dspp_pcc
  (git-fixes).
- ACPI: battery: Add the ThinkPad "Not Charging" quirk
  (git-fixes).
- ACPICA: actypes.h: Expand the ACPI_ACCESS_ definitions
  (git-fixes).
- hwmom: (lm90) Fix citical alarm status for MAX6680/MAX6681
  (git-fixes).
- commit e06c812
* Mon Jan 31 2022 tiwai@suse.de
- serial: stm32: fix software flow control transfer (git-fixes).
- tty: n_gsm: fix SW flow control encoding/handling (git-fixes).
- serial: 8250: of: Fix mapped region size when using reg-offset
  property (git-fixes).
- ucsi_ccg: Check DEV_INT bit only when starting CCG4 (git-fixes).
- ata: pata_platform: Fix a NULL pointer dereference in
  __pata_platform_probe() (git-fixes).
- drm/msm/hdmi: Fix missing put_device() call in msm_hdmi_get_phy
  (git-fixes).
- pinctrl: bcm2835: Add support for wake-up interrupts
  (git-fixes).
- pinctrl: bcm2835: Match BCM7211 compatible string (git-fixes).
- commit 34e1762
* Mon Jan 31 2022 tiwai@suse.de
- Update patch reference for vgacon patch (CVE-2020-28097 bsc#1187723 jsc#SLE-23485)
- commit 589ca07
* Mon Jan 31 2022 ohering@suse.de
- video: hyperv_fb: Fix validation of screen resolution
  (git-fixes).
- commit c92ca58
* Mon Jan 31 2022 denis.kirjanov@suse.com
- net: tipc: validate domain record count on input (bsc#1195254).
- commit 5e4e31e
* Mon Jan 31 2022 mkoutny@suse.com
- blacklist.conf: Add e1fbbd073137 prctl: allow to setup brk for et_dyn executables
- commit d38c68f
* Mon Jan 31 2022 msuchanek@suse.de
- ibmvnic: remove unused defines (bsc#1195293 ltc#196198).
- ibmvnic: Update driver return codes (bsc#1195293 ltc#196198).
- commit 2e27858
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/hns: Remove unnecessary access right set during INIT2INIT (git-fixes)
- commit 4f52905
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/core: Do not indicate device ready when device enablement fails (git-fixes)
- commit 8c078d4
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/uverbs: Tidy input validation of ib_uverbs_rereg_mr() (git-fixes)
- commit b76b1bf
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/hns: Remove the portn field in UD SQ WQE (git-fixes)
- commit 6b9c3b4
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/cxgb4: Validate the number of CQEs (git-fixes)
- commit 2d78782
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Fix corruption of reg_pages in mlx5_ib_rereg_user_mr() (git-fixes)
- commit 555e8b8
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/rxe: Compute PSN windows correctly (git-fixes)
- commit 6546545
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/bnxt_re: Set queue pair state when being queried (git-fixes)
- commit 68f6d87
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/cm: Fix an attempt to use non-valid pointer when cleaning timewait (git-fixes)
- commit 64a081e
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/i40iw: Address an mmap handler exploit in i40iw (git-fixes)
- commit 1f8fac6
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RMDA/sw: Don't allow drivers using dma_virt_ops on highmem configs (git-fixes)
- commit 09fe3b5
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Fix type warning of sizeof in __mlx5_ib_alloc_counters() (git-fixes)
- commit e969537
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- i40iw: Add support to make destroy QP synchronous (git-fixes)
- commit 1d9fde7
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Issue FW command to destroy SRQ on reentry (git-fixes)
- commit 7b4149b
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/mlx5: Fix potential race between destroy and CQE poll (git-fixes)
- commit a2e5b72
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- RDMA/hns: Add a check for current state before modifying QP (git-fixes)
- commit 8117a96
* Mon Jan 31 2022 nmoreychaisemartin@suse.com
- IB/mlx4: Separate tunnel and wire bufs parameters (git-fixes)
- commit 780f173
* Sun Jan 30 2022 denis.kirjanov@suse.com
- update
- commit 8000467
* Sat Jan 29 2022 jbohac@suse.cz
- phonet: refcount leak in pep_sock_accep (bsc#1193867,
  CVE-2021-45095).
- commit 98c27cb
* Fri Jan 28 2022 jbohac@suse.cz
- xfrm: fix MTU regression (bsc#1185377, bsc#1194048).
- Delete
  patches.suse/xfrm-xfrm_state_mtu-should-return-at-least-1280-for-.patch.
  which caused a regression (bsc#1194048).
- fix patches.kabi/revert-xfrm-xfrm_state_mtu-should-return-at-least-1280.patch
  fixes the resulting KABI change
- Replace with an alternative fix for bsc#1185377
- commit ccdfbb9
* Fri Jan 28 2022 denis.kirjanov@suse.com
- Refresh
  patches.suse/ibmvnic-Allow-extra-failures-before-disabling.patch.
- Refresh patches.suse/ibmvnic-don-t-spin-in-tasklet.patch.
- Refresh patches.suse/ibmvnic-init-running_cap_crqs-early.patch.
- Refresh
  patches.suse/ibmvnic-remove-unused-wait_capability.patch.
- commit 6439146
* Fri Jan 28 2022 denis.kirjanov@suse.com
- net: tipc: validate domain record count on input (bsc#1195254).
- commit 96de11b
* Fri Jan 28 2022 lhenriques@suse.de
- ext4: set csum seed in tmp inode while migrating to extents
  (bsc#1195267).
- commit 22e9600
* Fri Jan 28 2022 tiwai@suse.de
- drm/vmwgfx: Fix stale file descriptors on failed usercopy
  (CVE-2022-22942 bsc#1195065).
- commit b93c2a4
* Fri Jan 28 2022 dwagner@suse.de
- nvme: add 'iopolicy' module parameter (bsc#1177599 bsc#1193096).
- commit 552f664
* Thu Jan 27 2022 tonyj@suse.de
- bpf: Verifer, adjust_scalar_min_max_vals to always call
  update_reg_bounds() (bsc#1194227).
- commit bf95985
* Thu Jan 27 2022 vliaskovitis@suse.com
- xen/x86: obtain full video frame buffer address for Dom0 also under EFI (bsc#1193556).
- commit b8c892e
* Thu Jan 27 2022 vliaskovitis@suse.com
- xen/x86: obtain upper 32 bits of video frame buffer address for Dom0 (bsc#1193556).
- commit c13ff0b
* Thu Jan 27 2022 tbogendoerfer@suse.de
- net/packet: rx_owner_map depends on pg_vec (bsc#1195184
  CVE-2021-22600).
- commit ef975a8
* Thu Jan 27 2022 msuchanek@suse.de
- powerpc/book3s64/radix: make tlb_single_page_flush_ceiling a
  debugfs entry (bsc#1195183 ltc#193865).
- commit a3b42d2
* Thu Jan 27 2022 oneukum@suse.com
- scsi: ufs: Correct the LUN used in eh_device_reset_handler()
  callback (bsc#1193864 CVE-2021-39657).
- commit 74b4241
* Wed Jan 26 2022 dwagner@suse.de
- lightnvm: Remove lightnvm implemenation (bsc#1191881).
- commit e978276
* Wed Jan 26 2022 tiwai@suse.de
- supported.conf: mark rtw88 modules as supported (jsc#SLE-22690)
- commit 0d3c7d0
* Wed Jan 26 2022 oneukum@suse.com
- Update
  patches.suse/usb-gadget-configfs-Fix-use-after-free-issue-with-ud.patch
  (bsc#1193861 CVE-2021-39648).
  updated references for a CVE that became known after the fix
  had been applied for other reasons
- commit f7fa182
* Wed Jan 26 2022 oneukum@suse.com
- Update
  patches.suse/USB-gadget-detect-too-big-endpoint-0-requests.patch
  (bsc#1193802 CVE-2021-39685).
  Updated references to a CVE that became known after the fix had
  been applied for other reasons
- commit eeaa33a
* Wed Jan 26 2022 oneukum@suse.com
- crypto: qat - fix undetected PFVF timeout in ACK loop
  (git-fixes).
- commit 3cc9984
* Wed Jan 26 2022 oneukum@suse.com
- asix: fix wrong return value in asix_check_host_enable()
  (git-fixes).
- commit 9e94c23
* Tue Jan 25 2022 ohering@suse.de
- net: mana: Add RX fencing (bsc#1193506).
- commit aa896c0
* Tue Jan 25 2022 ohering@suse.de
- net: mana: Add XDP support (bsc#1193506).
- commit d5e53a9
* Tue Jan 25 2022 ohering@suse.de
- hv_netvsc: Set needed_headroom according to VF (bsc#1193506).
- commit f4f411e
* Tue Jan 25 2022 ohering@suse.de
- net, xdp: Introduce xdp_prepare_buff utility routine
  (bsc#1193506).
- commit aca9d96
* Tue Jan 25 2022 ohering@suse.de
- net, xdp: Introduce xdp_init_buff utility routine (bsc#1193506).
- commit 9770783
* Tue Jan 25 2022 msuchanek@suse.de
- ibmvnic: remove unused ->wait_capability (bsc#1195073
  ltc#195713).
- ibmvnic: don't spin in tasklet (bsc#1195073 ltc#195713).
- ibmvnic: init ->running_cap_crqs early (bsc#1195073 ltc#195713).
- ibmvnic: Allow extra failures before disabling (bsc#1195073
  ltc#195713).
- commit e820667
* Tue Jan 25 2022 mgorman@suse.de
- sched/fair: Fix detection of per-CPU kthreads waking a task
  (git fixes (sched/fair)).
- sched/numa: Fix is_core_idle() (git fixes (sched/numa)).
- commit 8f3f43a
* Tue Jan 25 2022 mgorman@suse.de
- blacklist.conf: !SMP configs are not supported
- commit c80ad41
* Tue Jan 25 2022 tiwai@suse.de
- scripts/dtc: dtx_diff: remove broken example from help text
  (git-fixes).
- Documentation: fix firewire.rst ABI file path error (git-fixes).
- HID: wacom: Reset expected and received contact counts at the
  same time (git-fixes).
- HID: uhid: Fix worker destroying device without any protection
  (git-fixes).
- drm/radeon: fix error handling in radeon_driver_open_kms
  (git-fixes).
- clk: si5341: Fix clock HW provider cleanup (git-fixes).
- vfio/iommu_type1: replace kfree with kvfree (git-fixes).
- nfc: llcp: fix NULL error pointer dereference on sendmsg()
  after failed bind() (git-fixes).
- commit 8163787
* Tue Jan 25 2022 nborisov@suse.com
- btrfs: tree-checker: check for BTRFS_BLOCK_FLAG_FULL_BACKREF being  set improperly (bsc#1195009).
- commit dad9348
* Tue Jan 25 2022 nborisov@suse.com
- btrfs: tree-checker: annotate all error branches as unlikely (bsc#1195009).
- commit f9364fe
* Tue Jan 25 2022 nborisov@suse.com
- btrfs: tree-checker: Add EXTENT_ITEM and METADATA_ITEM check (bsc#1195009).
- commit 58912c3
* Mon Jan 24 2022 msuchanek@suse.de
- kernel-binary.spec.in: Move 20-kernel-default-extra.conf to the correctr
  directory (bsc#1195051).
- commit c80b5de
* Mon Jan 24 2022 pmladek@suse.com
- blacklist.conf: test_stackinit module is not built
- commit 79fa675
* Mon Jan 24 2022 pmladek@suse.com
- blacklist.conf: bug: clean up; compiler likely does the same optimization
- commit 0f2e872
* Mon Jan 24 2022 pmladek@suse.com
- workqueue: Fix unbind_workers() VS wq_worker_running() race
  (bsc#1195062).
- commit 4a6e4c5
* Sun Jan 23 2022 osalvador@suse.de
- Rename colliding patches before the next cve/linux-5.3 -> SLE15-SP3 merge
- commit 84178b8
* Fri Jan 21 2022 tiwai@suse.de
- drm/i915: Flush TLBs before releasing backing store
  (CVE-2022-0330 bsc#1194880).
- commit 9eddfd3
* Fri Jan 21 2022 tiwai@suse.de
- drm/i915: Flush TLBs before releasing backing store
  (CVE-2022-0330 bsc#1194880).
- commit 34a8919
* Fri Jan 21 2022 bp@suse.de
- kabi/severities: Add a kabi exception for drivers/tee/tee
  According to the partner modules database, the structs of this driver
  are not used by anything external so make a kABI exception for them.
  Do that on purpose so that any external module using this fails to load
  instead of causing a potential memory corruption due to a kabi
  workaround which would use the same offset but for a different thing:
  - struct dma_buf *dmabuf;
  +	refcount_t refcount;
  See upstream commit
  dfd0743f1d9e ("tee: handle lookup of shm with reference count 0")
- commit c1b7aec
* Fri Jan 21 2022 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  - patches.suse/powerpc-fadump-Fix-inaccurate-CPU-state-info-in-vmco.patch
  - patches.suse/powerpc-handle-kdump-appropriately-with-crash_kexec_.patch
  - patches.suse/powerpc-watchdog-Avoid-holding-wd_smp_lock-over-prin.patch
  - patches.suse/powerpc-watchdog-Fix-missed-watchdog-reset-due-to-me.patch
  - patches.suse/powerpc-watchdog-Fix-wd_smp_last_reset_tb-reporting.patch
  - patches.suse/powerpc-watchdog-read-TB-close-to-where-it-is-used.patch
  - patches.suse/powerpc-watchdog-tighten-non-atomic-read-modify-writ.patch
- commit 72b7db7
* Fri Jan 21 2022 mkubecek@suse.cz
- series.conf: cleanup
- move to "mainline soon" section:
  - patches.suse/0001-mmc-moxart_remove-Fix-UAF.patch
- commit 07d55c3
* Fri Jan 21 2022 ddiss@suse.de
- vfs: fs_context: fix up param length parsing in
  legacy_parse_param (CVE-2022-0185 bsc#1194517).
- Rename and retag following upstream merge from:
  patches.suse/vfs-Out-of-bounds-write-of-heap-buffer-in-fs_context-c.patch
  to patches.suse/vfs-fs_context-fix-up-param-length-parsing-in-legacy.patch
- commit 33860f2
* Fri Jan 21 2022 tbogendoerfer@suse.de
- sctp: account stream padding length for reconf chunk
  (bsc#1194985 CVE-2022-0322).
- commit a6cab40
* Fri Jan 21 2022 clin@suse.com
- Update config files.
- commit eae3c71
* Fri Jan 21 2022 mkubecek@suse.cz
- net: allow retransmitting a TCP packet if original is still
  in queue (bsc#1188605 bsc#1187428).
- commit 372a9a4
* Thu Jan 20 2022 vkarasulli@suse.de
- moxart: fix potential use-after-free on remove path
  (bsc#1194516).
- commit 3fae095
* Thu Jan 20 2022 rgoldwyn@suse.com
- vfs: check fd has read access in kernel_read_file_from_fd() (bsc#1194888).
- commit 4717473
* Thu Jan 20 2022 msuchanek@suse.de
- kernel-binary.spec: Do not use the default certificate path (bsc#1194943).
  Using the the default path is broken since Linux 5.17
- commit 68b36f0
* Thu Jan 20 2022 msuchanek@suse.de
- powerpc/pseries/mobility: ignore ibm, platform-facilities
  updates (bsc#1065729).
- commit b253330
* Thu Jan 20 2022 msuchanek@suse.de
- powerpc/traps: do not enable irqs in _exception (bsc#1065729).
- powerpc: add interrupt_cond_local_irq_enable helper
  (bsc#1065729).
- commit 65f660c
* Thu Jan 20 2022 bp@suse.de
- tee: handle lookup of shm with reference count 0 (bsc#1193767
  CVE-2021-44733).
- commit be75d82
* Thu Jan 20 2022 msuchanek@suse.de
- powerpc/64s: fix program check interrupt emergency stack path
  (bsc#1156395).
- commit a3c26ed
* Thu Jan 20 2022 msuchanek@suse.de
- blacklist.conf: Add a2308836880b powerpc: Fix arch_stack_walk() to have
  running function as first entry
  The stacktrace interface in this kernel version does not provide the
  parameters used to implement the fix.
- commit ee041a3
* Thu Jan 20 2022 lhenriques@suse.de
- fuse: Pass correct lend value to filemap_write_and_wait_range()
  (bsc#1194953).
- commit d2355ea
* Thu Jan 20 2022 hare@suse.de
- nvme-fabrics: ignore invalid fast_io_fail_tmo values
  (git-fixes).
- nvme-tcp: fix memory leak when freeing a queue (git-fixes).
- nvme-multipath: fix ANA state updates when a namespace is not
  present (git-fixes).
- nvme-fabrics: remove superfluous nvmf_host_put in
  nvmf_parse_options (git-fixes).
- commit 51e4a5d
* Thu Jan 20 2022 clin@suse.com
- arm64: Kconfig: add a choice for endianness (jsc#SLE-23432).
- commit 51a5c79
* Wed Jan 19 2022 bp@suse.de
- tee: don't assign shm id for private shms (bsc#1193767
  CVE-2021-44733).
- commit 9ab9ee2
* Wed Jan 19 2022 msuchanek@suse.de
- Update patches.suse/tpm-fix-potential-NULL-pointer-access-in-tpm_del_cha.patch
  (git-fixes bsc#1193660 ltc#195634).
- commit 11ac3f6
* Wed Jan 19 2022 msuchanek@suse.de
- blacklist.conf: Add 79ca6f74dae0 tpm: fix Atmel TPM crash caused by too frequent queries
  Breaks kABI, there is no report of this problem affecting users, likely
  broken old TPM firmware.
- commit 4ea9f96
* Wed Jan 19 2022 bp@suse.de
- tee: remove linked list of struct tee_shm (bsc#1193767
  CVE-2021-44733).
- commit a3c7739
* Wed Jan 19 2022 mbenes@suse.cz
- livepatch: Avoid CPU hogging with cond_resched (bsc#1071995).
- commit 27c7aa0
* Wed Jan 19 2022 msuchanek@suse.de
- powerpc/perf: Fix PMU callbacks to clear pending PMI before
  resetting an overflown PMC (bsc#1156395).
- commit 8bdce1e
* Wed Jan 19 2022 msuchanek@suse.de
- powerpc/prom_init: Fix improper check of prom_getprop()
  (bsc#1065729).
- commit 954fa51
* Wed Jan 19 2022 tiwai@suse.de
- dmaengine: at_xdmac: Fix at_xdmac_lld struct definition
  (git-fixes).
- dmaengine: at_xdmac: Fix lld view setting (git-fixes).
- dmaengine: at_xdmac: Fix concurrency over xfers_list
  (git-fixes).
- dmaengine: at_xdmac: Print debug message after realeasing the
  lock (git-fixes).
- dmaengine: at_xdmac: Don't start transactions at tx_submit level
  (git-fixes).
- Documentation: dmaengine: Correctly describe dmatest with
  channel unset (git-fixes).
- rpmsg: core: Clean up resources on announce_create failure
  (git-fixes).
- ACPI: APD: Check for NULL pointer after calling devm_ioremap()
  (git-fixes).
- Input: ti_am335x_tsc - fix STEPCONFIG setup for Z2 (git-fixes).
- Input: ti_am335x_tsc - set ADCREFM for X configuration
  (git-fixes).
- i3c: master: dw: check return of dw_i3c_master_get_free_pos()
  (git-fixes).
- i3c: fix incorrect address slot lookup on 64-bit (git-fixes).
- commit 3d8614c
* Wed Jan 19 2022 msuchanek@suse.de
- powerpc/pseries/cpuhp: delete add/remove_by_count code
  (bsc#1065729).
- powerpc/pseries/cpuhp: cache node corrections (bsc#1065729).
- commit 9c04898
* Wed Jan 19 2022 tiwai@suse.de
- Add cherry-picked IDs for qemu fw_cfg patches
- commit 8f947ad
* Wed Jan 19 2022 msuchanek@suse.de
- powerpc/perf: Fix data source encodings for L2.1 and L3.1
  accesses (bsc#1065729).
- commit d096c51
* Tue Jan 18 2022 msuchanek@suse.de
- powerpc/xive: Add missing null check after calling kmalloc
  (bsc#1177437 ltc#188522 jsc#SLE-13294 git-fixes).
- commit d9ea6bb
* Tue Jan 18 2022 mbenes@suse.cz
- tracing/kprobes: 'nmissed' not showed correctly for kretprobe
  (git-fixes).
- commit fd3df8d
* Tue Jan 18 2022 mbenes@suse.cz
- tracing: Add test for user space strings when filtering on
  string pointers (git-fixes).
- commit 9a09d69
* Tue Jan 18 2022 hare@suse.de
- Update armv7hl config files.
- commit a54e64e
* Tue Jan 18 2022 hare@suse.de
- dm writecache: fix performance degradation in ssd mode
  (git-fixes).
- dm writecache: advance the number of arguments when reporting
  max_age (git-fixes).
- commit e385922
* Tue Jan 18 2022 hare@suse.de
- nvme-tcp: fix possible req->offset corruption (git-fixes).
- nvme-tcp: fix io_work priority inversion (git-fixes).
- nvme-tcp: don't update queue count when failing to set io queues
  (git-fixes).
- nvme-tcp: pair send_mutex init with destroy (git-fixes).
- nvme-tcp: can't set sk_user_data without write_lock (git-fixes).
- nvme-tcp: fix error codes in nvme_tcp_setup_ctrl() (git-fixes).
- nvme-tcp: remove incorrect Kconfig dep in BLK_DEV_NVME
  (git-fixes).
- nvme-tcp: check sgl supported by target (git-fixes).
- nvme-tcp: block BH in sk state_change sk callback (git-fixes).
- nvme-tcp: fix a NULL deref when receiving a 0-length r2t PDU
  (git-fixes).
- commit 0e83d53
* Tue Jan 18 2022 hare@suse.de
- nvme-tcp: fix crash triggered with a dataless request submission
  (git-fixes).
- nvme-tcp: pass multipage bvec to request iov_iter (git-fixes).
- nvme-tcp: get rid of unused helper function (git-fixes).
- nvme-tcp: fix wrong setting of request iov_iter (git-fixes).
- nvme-tcp: fix possible data corruption with bio merges
  (git-fixes).
- commit 1412d58
* Tue Jan 18 2022 mbenes@suse.cz
- blacklist.conf: 3e2a56e6f639 ("tracing: Have syscall trace events use trace_event_buffer_lock_reserve()")
  Optimization only.
- commit 9d680b6
* Tue Jan 18 2022 hare@suse.de
- dm writecache: add "cleaner" and "max_age" to Documentation
  (git-fixes).
- dm writecache: flush origin device when writing and cache is
  full (git-fixes).
- commit eeda715
* Tue Jan 18 2022 neilb@suse.de
- blacklist.conf: blacklist unnecessary commit
- commit 3eae3eb
* Tue Jan 18 2022 neilb@suse.de
- NFSD: Fix zero-length NFSv3 WRITEs (git-fixes).
- nfsd: Fix nsfd startup race (again) (git-fixes).
- NFSv42: Fix pagecache invalidation after COPY/CLONE (git-fixes).
- NFSv42: Don't fail clone() unless the OP_CLONE operation failed
  (git-fixes).
- commit 53bf6fe
* Mon Jan 17 2022 pjakobsson@suse.de
- blacklist.conf: 244a36e50da0 drm/vc4: kms: Wait for the commit before increasing our clock rate
- commit f34f06b
* Mon Jan 17 2022 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amd-display-Set-plane-update-flags-for-all-plane.patch.
  Alt-commit
- commit efcd4f5
* Mon Jan 17 2022 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-fb-Fix-rounding-error-in-subsampled-plane-s.patch.
  Alt-commit
- commit e0cab26
* Mon Jan 17 2022 pjakobsson@suse.de
- blacklist.conf: 0c980a006d3f drm/vc4: kms: Wait for the commit before increasing our clock rate
- commit a752ba6
* Mon Jan 17 2022 pjakobsson@suse.de
- drm/i915/fb: Fix rounding error in subsampled plane size
  calculation (git-fixes).
- commit 559ebf7
* Mon Jan 17 2022 pjakobsson@suse.de
- drm/amdgpu: revert "Add autodump debugfs node for gpu reset v8"
  (git-fixes).
- commit 3dac018
* Mon Jan 17 2022 pjakobsson@suse.de
- blacklist.conf: 93b713304188 drm/i915: Revert "drm/i915/gem: Asynchronous cmdparser"
- commit 41290de
* Mon Jan 17 2022 pjakobsson@suse.de
- blacklist.conf: 5810323ba692 drm/amd/pm: Fix a bug communicating with the SMU (v5)
- commit 5594ee7
* Mon Jan 17 2022 mbenes@suse.cz
- tracing/uprobes: Check the return value of kstrdup() for
  tu->filename (git-fixes).
- commit 9da2bcc
* Mon Jan 17 2022 pjakobsson@suse.de
- blacklist.conf: c9d9fdbc108a drm/i915: Revert "drm/i915/gem: Asynchronous cmdparser"
- commit fcd19bb
* Mon Jan 17 2022 pjakobsson@suse.de
- blacklist.conf: b601c16b7ba8 drm/vc4: crtc: Lookup the encoder from the register at boot
- commit 2647c26
* Mon Jan 17 2022 mbenes@suse.cz
- tracing: Fix check for trace_percpu_buffer validity in
  get_trace_buf() (git-fixes).
- commit 15d2ff9
* Mon Jan 17 2022 lizhang@suse.de
- selftests: KVM: Explicitly use movq to read xmm registers
  (git-fixes).
- commit 28d1c00
* Mon Jan 17 2022 tiwai@suse.de
- dmaengine: idxd: enable SVA feature for IOMMU (bsc#1192931).
- dmaengine: idxd: add module parameter to force disable of SVA
  (bsc#1192931).
- commit 13e606d
* Mon Jan 17 2022 pjakobsson@suse.de
- blacklist.conf: 5a184d959d5a drm/vc4: crtc: Fix vc4_get_crtc_encoder logic
- commit 3bf3f00
* Mon Jan 17 2022 pjakobsson@suse.de
- blacklist.conf: c6883985d463 drm/vc4: crtc: Pass the drm_atomic_state to config_pv
- commit babde3e
* Mon Jan 17 2022 dwagner@suse.de
- Revert patches.suse/block-simplify-set_init_blocksize.patch (bsc#1191929)
  Upstream reverted 8dc932d3e8af ("Revert "block: simplify
  set_init_blocksize" to regain lost performance"). Drop the initial
  patch and fixup conflicts.
- commit fca2173
* Mon Jan 17 2022 jack@suse.cz
- select: Fix indefinitely sleeping task in
  poll_schedule_timeout() (bsc#1194027).
- commit 18b9c4e
* Mon Jan 17 2022 pjakobsson@suse.de
- blacklist.conf: 2e4c6c1a9db5 drm/i915: Remove i915_request.lock requirement for execution callbacks
- commit a56a2e1
* Mon Jan 17 2022 tiwai@suse.de
- usb: ftdi-elan: fix memory leak on device disconnect
  (git-fixes).
- commit d92ffd0
* Mon Jan 17 2022 tiwai@suse.de
- clk: imx8mn: Fix imx8mn_clko1_sels (git-fixes).
- clk: stm32: Fix ltdc's clock turn off by clk_disable_unused()
  after system enter shell (git-fixes).
- clk: Gemini: fix struct name in kernel-doc (git-fixes).
- clk: imx: pllv1: fix kernel-doc notation for struct clk_pllv1
  (git-fixes).
- tty: serial: uartlite: allow 64 bit address (git-fixes).
- tty: serial: atmel: Call dma_async_issue_pending() (git-fixes).
- tty: serial: atmel: Check return code of dmaengine_submit()
  (git-fixes).
- staging: rtl8192e: rtllib_module: fix error handle case in
  alloc_rtllib() (git-fixes).
- staging: rtl8192e: return error code from rtllib_softmac_init()
  (git-fixes).
- floppy: Fix hang in watchdog when disk is ejected (git-fixes).
- commit 83ffd12
* Mon Jan 17 2022 tiwai@suse.de
- misc: lattice-ecp3-config: Fix task hung when firmware load
  failed (git-fixes).
- firmware: qemu_fw_cfg: fix sysfs information leak (git-fixes).
- firmware: qemu_fw_cfg: fix kobject leak in probe error path
  (git-fixes).
- firmware: qemu_fw_cfg: fix NULL-pointer deref on duplicate
  entries (git-fixes).
- firmware: Update Kconfig help text for Google firmware
  (git-fixes).
- uio: uio_dmem_genirq: Catch the Exception (git-fixes).
- dmaengine: pxa/mmp: stop referencing config->slave_id
  (git-fixes).
- mailbox: hi3660: convert struct comments to kernel-doc notation
  (git-fixes).
- PCI/MSI: Fix pci_irq_vector()/pci_irq_get_affinity()
  (git-fixes).
- net: usb: lan78xx: add Allied Telesis AT29M2-AF (git-fixes).
- commit 7a442ee
* Mon Jan 17 2022 tiwai@suse.de
- char/mwave: Adjust io port register size (git-fixes).
- ASoC: fsl_asrc: refine the check of available clock divider
  (git-fixes).
- ASoC: fsl_mqs: fix MODULE_ALIAS (git-fixes).
- ASoC: samsung: idma: Check of ioremap return value (git-fixes).
- ASoC: mediatek: Check for error clk pointer (git-fixes).
- ASoC: rt5663: Handle device_property_read_u32_array error codes
  (git-fixes).
- ASoC: uniphier: drop selecting non-existing
  SND_SOC_UNIPHIER_AIO_DMA (git-fixes).
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus
  Master after reboot from Windows (git-fixes).
- ALSA: usb-audio: Drop superfluous '0' in Presonus Studio
  1810c's ID (git-fixes).
- ALSA: oss: fix compile error when OSS_DEBUG is enabled
  (git-fixes).
- commit 0e71106
* Mon Jan 17 2022 tiwai@suse.de
- random: fix data race on crng init time (git-fixes).
- Refresh
  patches.suse/0008-random-move-FIPS-continuous-test-to-output-functions.patch.
- commit 792475c
* Mon Jan 17 2022 tiwai@suse.de
- ALSA: hda: Make proper use of timecounter (git-fixes).
- ALSA: hda: Add missing rwsem around snd_ctl_remove() calls
  (git-fixes).
- ALSA: PCM: Add missing rwsem around snd_ctl_remove() calls
  (git-fixes).
- ALSA: jack: Add missing rwsem around snd_ctl_remove() calls
  (git-fixes).
- USB: core: Fix bug in resuming hub's handling of wakeup requests
  (git-fixes).
- USB: Fix "slab-out-of-bounds Write" bug in
  usb_hcd_poll_rh_status (git-fixes).
- random: fix data race on crng_node_pool (git-fixes).
- staging: wlan-ng: Avoid bitwise vs logical OR warning in
  hfa384x_usb_throttlefn() (git-fixes).
- commit c91af43
* Mon Jan 17 2022 tiwai@suse.de
- PCI: pci-bridge-emul: Set PCI_STATUS_CAP_LIST for PCIe device
  (git-fixes).
- PCI: pci-bridge-emul: Properly mark reserved PCIe bits in PCI
  config space (git-fixes).
- PCI: xgene: Fix IB window setup (git-fixes).
- PCI: mvebu: Fix support for DEVCAP2, DEVCTL2 and LNKCTL2
  registers on emulated bridge (git-fixes).
- PCI: mvebu: Fix support for PCI_EXP_RTSTA on emulated bridge
  (git-fixes).
- PCI: mvebu: Fix support for PCI_EXP_DEVCTL on emulated bridge
  (git-fixes).
- PCI: mvebu: Do not modify PCI IO type bits in conf_write
  (git-fixes).
- commit f746eae
* Mon Jan 17 2022 tiwai@suse.de
- PCI: mvebu: Check for errors from pci_bridge_emul_init() call
  (git-fixes).
- PCI: dwc: Do not remap invalid res (git-fixes).
- PCI: pciehp: Fix infinite loop in IRQ handler upon power fault
  (git-fixes).
- drm/amdkfd: Check for null pointer after calling kmemdup
  (git-fixes).
- drm/sun4i: dw-hdmi: Fix missing put_device() call in
  sun8i_hdmi_phy_get (git-fixes).
- drm/atomic: Check new_crtc_state->active to determine if CRTC
  needs disable in self refresh mode (git-fixes).
- mmc: sdhci-pci: Add PCI ID for Intel ADL (git-fixes).
- Bluetooth: bfusb: fix division by zero in send path (git-fixes).
- drm/i915: Avoid bitwise vs logical OR warning in
  snb_wm_latency_quirk() (git-fixes).
- commit 3526b61
* Mon Jan 17 2022 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit e663fe4
* Fri Jan 14 2022 lduncan@suse.com
- Updated mpi3mr entry in supported.conf (bsc#1194578 jsc#SLE-18120)
  Moving this driver into the "supported" package.
- commit 6f2da7c
* Wed Jan 12 2022 tiwai@suse.de
- tpm: fix potential NULL pointer access in tpm_del_char_device
  (git-fixes).
- tpm: add request_locality before write TPM_INT_ENABLE
  (git-fixes).
- spi: spi-meson-spifc: Add missing pm_runtime_disable() in
  meson_spifc_probe (git-fixes).
- usb: mtu3: fix interval value for intr and isoc (git-fixes).
- commit c1e5df4
* Wed Jan 12 2022 tiwai@suse.de
- selinux: fix potential memleak in selinux_add_opt() (git-fixes).
- pcmcia: fix setting of kthread task states (git-fixes).
- pcmcia: rsrc_nonstatic: Fix a NULL pointer dereference in
  nonstatic_find_mem_region() (git-fixes).
- pcmcia: rsrc_nonstatic: Fix a NULL pointer dereference in
  __nonstatic_find_io_region() (git-fixes).
- spi: spi-rspi: Drop redeclaring ret variable in
  qspi_transfer_in() (git-fixes).
- regmap: Call regmap_debugfs_exit() prior to _init() (git-fixes).
- mtd: rawnand: mpc5121: Remove unused variable in
  ads5121_select_chip() (git-fixes).
- power: reset: ltc2952: Fix use of floating point literals
  (git-fixes).
- rndis_host: support Hytera digital radios (git-fixes).
- commit 5c51144
* Wed Jan 12 2022 tiwai@suse.de
- mmc: meson-mx-sdio: add IRQ check (git-fixes).
- mfd: intel-lpss: Fix too early PM enablement in the ACPI
  - >probe() (git-fixes).
- HID: hid-uclogic-params: Invalid parameter check in
  uclogic_params_frame_init_v1_buttonpad (git-fixes).
- HID: hid-uclogic-params: Invalid parameter check in
  uclogic_params_huion_init (git-fixes).
- HID: hid-uclogic-params: Invalid parameter check in
  uclogic_params_get_str_desc (git-fixes).
- HID: hid-uclogic-params: Invalid parameter check in
  uclogic_params_init (git-fixes).
- crypto: stm32/crc32 - Fix kernel BUG triggered in probe()
  (git-fixes).
- crypto: stm32/cryp - fix lrw chaining mode (git-fixes).
- Documentation: refer to config RANDOMIZE_BASE for kernel
  address-space randomization (git-fixes).
- mISDN: change function names to avoid conflicts (git-fixes).
- commit 6c1c0d0
* Wed Jan 12 2022 tiwai@suse.de
- backlight: qcom-wled: Override default length with
  qcom,enabled-strings (git-fixes).
- backlight: qcom-wled: Fix off-by-one maximum with default
  num_strings (git-fixes).
- backlight: qcom-wled: Pass number of elements to read to
  read_u32_array (git-fixes).
- backlight: qcom-wled: Validate enabled string indices in DT
  (git-fixes).
- crypto: stm32/cryp - fix double pm exit (git-fixes).
- crypto: stm32/cryp - fix xts and race condition in crypto_engine
  requests (git-fixes).
- crypto: qce - fix uaf on qce_ahash_register_one (git-fixes).
- crypto: caam - replace this_cpu_ptr with raw_cpu_ptr
  (git-fixes).
- atlantic: Fix buff_ring OOB in aq_ring_rx_clean (git-fixes).
- commit 8421e32
* Wed Jan 12 2022 mbenes@suse.cz
- blacklist.conf: f28439db470c ("tracing: Tag trace_percpu_buffer as a percpu pointer")
  It fixes a sparse warning only.
- commit 3c1db23
* Wed Jan 12 2022 mkoutny@suse.com
- cgroup: cgroup.{procs,threads} factor out common parts
  (bsc#1194302 CVE-2021-4197).
- commit 0d9ce26
* Wed Jan 12 2022 tbogendoerfer@suse.de
- Revert "net/mlx5: Add retry mechanism to the command entry
  index allocation" (jsc#SLE-15172).
- net/mlx5: Set command entry semaphore up once got index free
  (jsc#SLE-15172).
- netfilter: nft_set_pipapo: allocate pcpu scratch maps on clone
  (bsc#1176447).
- iavf: Fix limit of total number of queues to active queues of VF
  (git-fixes).
- i40e: Fix incorrect netdev's real number of RX/TX queues
  (git-fixes).
- i40e: Fix for displaying message regarding NVM version
  (git-fixes).
- i40e: fix use-after-free in i40e_sync_filters_subtask()
  (git-fixes).
- i40e: Fix to not show opcode msg on unsuccessful VF MAC change
  (git-fixes).
- sfc: The RX page_ring is optional (git-fixes).
- net: ena: Fix error handling when calculating max IO queues
  number (bsc#1154492).
- net: ena: Fix wrong rx request id by resetting device
  (git-fixes).
- net: ena: Fix undefined state when tx request id is out of
  bounds (bsc#1154492).
- net/mlx5e: Fix wrong features assignment in case of error
  (git-fixes).
- ionic: Initialize the 'lif->dbid_inuse' bitmap (bsc#1167773).
- net/mlx5e: Wrap the tx reporter dump callback to extract the sq
  (jsc#SLE-15172).
- net/mlx5: DR, Fix NULL vs IS_ERR checking in
  dr_domain_init_resources (jsc#SLE-8464).
- sfc: falcon: Check null pointer of rx_queue->page_ring
  (git-fixes).
- sfc: Check null pointer of rx_queue->page_ring (git-fixes).
- qlcnic: potential dereference null pointer of
  rx_queue->page_ring (git-fixes).
- RDMA/hns: Replace kfree() with kvfree() (jsc#SLE-14777).
- sfc_ef100: potential dereference of null pointer
  (jsc#SLE-16683).
- ixgbe: set X550 MDIO speed before talking to PHY (git-fixes).
- igc: Fix typo in i225 LTR functions (jsc#SLE-13533).
- igbvf: fix double free in `igbvf_probe` (git-fixes).
- igb: Fix removal of unicast MAC filters of VFs (git-fixes).
- flow_offload: return EOPNOTSUPP for the unsupported mpls action
  type (bsc#1154353).
- net/sched: sch_ets: don't remove idle classes from the
  round-robin list (bsc#1176774).
- net: hns3: fix use-after-free bug in hclgevf_send_mbx_msg
  (jsc#SLE-14777).
- net/sched: fq_pie: prevent dismantle issue (jsc#SLE-15172).
- nft_set_pipapo: Fix bucket load in AVX2 lookup routine for
  six 8-bit groups (bsc#1176447).
- i40e: Fix NULL pointer dereference in i40e_dbg_dump_desc
  (git-fixes).
- iavf: restore MSI state on reset (git-fixes).
- netfilter: nf_tables: initialize set before expression setup
  (bsc#1194518 CVE-2021-46283).
- commit 472b838
* Wed Jan 12 2022 jack@suse.cz
- blacklist.conf: Blacklist 2fc428f6b7ca
- commit 19cda1c
* Wed Jan 12 2022 jack@suse.cz
- blacklist.conf: Blacklist b781d8db580c
- commit 062524a
* Wed Jan 12 2022 jack@suse.cz
- blacklist.conf: Blacklist 480d42dc001b
- commit 25e1570
* Wed Jan 12 2022 mkoutny@suse.com
- cgroup: Use open-time cgroup namespace for process migration
  perm checks (bsc#1194302 CVE-2021-4197).
- cgroup: Allocate cgroup_file_ctx for kernfs_open_file->priv
  (bsc#1194302 CVE-2021-4197).
- cgroup: Use open-time credentials for process migraton perm
  checks (bsc#1194302 CVE-2021-4197).
- commit 716e0d8
* Wed Jan 12 2022 jack@suse.cz
- patches.suse/ext4-Avoid-trim-error-on-fs-with-small-groups.patch: Update
  tags
- commit 2f64a4f
* Wed Jan 12 2022 jack@suse.cz
- blacklist.conf: Blacklist 86399ea07109 and 81dedaf10c20
- commit c1c9a79
* Wed Jan 12 2022 jack@suse.cz
- udf: Fix crash after seekdir (bsc#1194592).
- commit 0c1ff08
* Wed Jan 12 2022 jack@suse.cz
- isofs: Fix out of bound access for corrupted isofs image
  (bsc#1194591).
- commit 416efa6
* Wed Jan 12 2022 jack@suse.cz
- quota: correct error number in free_dqentry() (bsc#1194590).
- commit 6a7c013
* Wed Jan 12 2022 jack@suse.cz
- quota: check block number when reading the block in quota file
  (bsc#1194589).
- commit a1f09c3
* Wed Jan 12 2022 jack@suse.cz
- pipe: increase minimum default pipe size to 2 pages
  (bsc#1194587).
- commit e2fa7de
* Wed Jan 12 2022 jack@suse.cz
- block: fix ioprio_get(IOPRIO_WHO_PGRP) vs setuid(2)
  (bsc#1194586).
- commit b32b906
* Wed Jan 12 2022 jack@suse.cz
- blacklist.conf: Blacklist 7607c44c157d and 35e4c6c1a2fc
- commit 94191c1
* Wed Jan 12 2022 jack@suse.cz
- blk-cgroup: synchronize blkg creation against policy
  deactivation (bsc#1194584).
- commit 2ff6aca
* Wed Jan 12 2022 jack@suse.cz
- ext4: fix lazy initialization next schedule time computation
  in more granular unit (bsc#1194580).
- commit 5b27386
* Wed Jan 12 2022 jack@suse.cz
- fget: clarify and improve __fget_files() implementation
  (bsc#1193727).
- commit 4b3242f
* Tue Jan 11 2022 ddiss@suse.de
- vfs: Out-of-bounds write of heap buffer in fs_context.c
  (CVE-2022-0185 bsc#1194517).
- commit 11341d2
* Tue Jan 11 2022 tabraham@suse.com
- x86/platform/uv: Add more to secondary CPU kdump info
  (bsc#1194493).
- commit 0c6f56d
* Tue Jan 11 2022 tbogendoerfer@suse.de
- netdevsim: Zero-initialize memory for new map's value in
  function nsim_bpf_map_alloc (bsc#1193927 CVE-2021-4135).
- commit 4b3887a
* Tue Jan 11 2022 tiwai@suse.de
- Update patch references for NFC security fixes (CVE-2021-4202 bsc#1194529)
- commit 69a4a1d
* Tue Jan 11 2022 tiwai@suse.de
- iwlwifi: mvm: Use div_s64 instead of do_div in
  iwl_mvm_ftm_rtt_smoothing() (git-fixes).
- commit 51f4dbd
* Tue Jan 11 2022 tiwai@suse.de
- wireless: iwlwifi: Fix a double free in iwl_txq_dyn_alloc_dma
  (git-fixes).
- commit 0c49000
* Tue Jan 11 2022 tiwai@suse.de
- thermal/drivers/imx8mm: Enable ADC when enabling monitor
  (git-fixes).
- PCI/ACPI: Fix acpi_pci_osc_control_set() kernel-doc comment
  (git-fixes).
- rtlwifi: rtl8192cu: Fix WARNING when calling local_irq_restore()
  with interrupts enabled (git-fixes).
- mwifiex: Fix possible ABBA deadlock (git-fixes).
- wcn36xx: Release DMA channel descriptor allocations (git-fixes).
- wcn36xx: Indicate beacon not connection loss on
  MISSED_BEACON_IND (git-fixes).
- media: hantro: Fix probe func error path (git-fixes).
- media: msi001: fix possible null-ptr-deref in msi001_probe()
  (git-fixes).
- commit 945c228
* Tue Jan 11 2022 tiwai@suse.de
- media: dw2102: Fix use after free (git-fixes).
- media: streamzap: remove unnecessary ir_raw_event_reset and
  handle (git-fixes).
- media: si2157: Fix "warm" tuner state detection (git-fixes).
- media: saa7146: mxb: Fix a NULL pointer dereference in
  mxb_attach() (git-fixes).
- media: dib8000: Fix a memleak in dib8000_init() (git-fixes).
- media: uvcvideo: fix division by zero at stream start
  (git-fixes).
- media: venus: core: Fix a resource leak in the error handling
  path of 'venus_probe()' (git-fixes).
- media: mtk-vcodec: call v4l2_m2m_ctx_release first when file
  is released (git-fixes).
- media: si470x-i2c: fix possible memory leak in
  si470x_i2c_probe() (git-fixes).
- media: imx-pxp: Initialize the spinlock prior to using it
  (git-fixes).
- commit 5761229
* Tue Jan 11 2022 tiwai@suse.de
- media: rcar-csi2: Optimize the selection PHTW register
  (git-fixes).
- media: rcar-csi2: Correct the selection of hsfreqrange
  (git-fixes).
- media: i2c: imx274: fix trivial typo obainted/obtained
  (git-fixes).
- media: i2c: imx274: fix trivial typo expsoure/exposure
  (git-fixes).
- media: dib0700: fix undefined behavior in tuner shutdown
  (git-fixes).
- media: dmxdev: fix UAF when dvb_register_device() fails
  (git-fixes).
- media: stk1160: fix control-message timeouts (git-fixes).
- media: s2255: fix control-message timeouts (git-fixes).
- media: pvrusb2: fix control-message timeouts (git-fixes).
- media: em28xx: fix control-message timeouts (git-fixes).
- commit 46bba79
* Tue Jan 11 2022 tiwai@suse.de
- iwlwifi: mvm: test roc running status bits before removing
  the sta (git-fixes).
- iwlwifi: mvm: fix 32-bit build in FTM (git-fixes).
- media: cpia2: fix control-message timeouts (git-fixes).
- media: flexcop-usb: fix control-message timeouts (git-fixes).
- media: redrat3: fix control-message timeouts (git-fixes).
- media: mceusb: fix control-message timeouts (git-fixes).
- media: aspeed: Update signal status immediately to ensure sane
  hw state (git-fixes).
- media: em28xx: fix memory leak in em28xx_init_dev (git-fixes).
- media: aspeed: fix mode-detect always time out at 2nd run
  (git-fixes).
- gpu: host1x: Add back arm_iommu_detach_device() (git-fixes).
- commit a0fd0ab
* Tue Jan 11 2022 tiwai@suse.de
- drm/msm/dpu: fix safe status debugfs file (git-fixes).
- drm/tegra: vic: Fix DMA API misuse (git-fixes).
- drm/radeon/radeon_kms: Fix a NULL pointer dereference in
  radeon_driver_open_kms() (git-fixes).
- drm/amdgpu: Fix a NULL pointer dereference in
  amdgpu_connector_lcd_native_mode() (git-fixes).
- drm/bridge: ti-sn65dsi86: Set max register for regmap
  (git-fixes).
- drm/vboxvideo: fix a NULL vs IS_ERR() check (git-fixes).
- drm/bridge: analogix_dp: Make PSR-exit block less (git-fixes).
- drm/vc4: hdmi: Make sure the controller is powered up during
  bind (git-fixes).
- drm/vc4: hdmi: Set a default HSM rate (git-fixes).
- commit a48eb6b
* Tue Jan 11 2022 tiwai@suse.de
- Documentation: ACPI: Fix data node reference documentation
  (git-fixes).
- dma_fence_array: Fix PENDING_ERROR leak in
  dma_fence_array_signaled() (git-fixes).
- drm/rockchip: dsi: Disable PLL clock on bind error (git-fixes).
- drm/rockchip: dsi: Fix unbalanced clock on probe error
  (git-fixes).
- drm/rockchip: dsi: Reconfigure hardware on resume() (git-fixes).
- drm/rockchip: dsi: Hold pm-runtime across bind/unbind
  (git-fixes).
- drm/panel: innolux-p079zca: Delete panel on attach() failure
  (git-fixes).
- drm/panel: kingdisplay-kd097d04: Delete panel on attach()
  failure (git-fixes).
- drm: fix null-ptr-deref in drm_dev_init_release() (git-fixes).
- drm/bridge: display-connector: fix an uninitialized pointer
  in probe() (git-fixes).
- commit 5ae7d41
* Tue Jan 11 2022 tiwai@suse.de
- device property: Fix documentation for
  FWNODE_GRAPH_DEVICE_DISABLED (git-fixes).
- can: gs_usb: gs_can_start_xmit(): zero-initialize
  hf->{flags,reserved} (git-fixes).
- can: xilinx_can: xcan_probe(): check for error irq (git-fixes).
- can: softing: softing_startstop(): fix set but not used variable
  warning (git-fixes).
- can: softing_cs: softingcs_probe(): fix memleak on registration
  failure (git-fixes).
- can: gs_usb: fix use of uninitialized variable, detach device
  on reception of invalid USB data (git-fixes).
- Bluetooth: hci_bcm: Check for error irq (git-fixes).
- can: usb_8dev: remove unused member echo_skb from struct
  usb_8dev_priv (git-fixes).
- clk: bcm-2835: Remove rounding up the dividers (git-fixes).
- clk: bcm-2835: Pick the closest clock rate (git-fixes).
- commit bd7a33a
* Tue Jan 11 2022 tiwai@suse.de
- ACPI: scan: Create platform device for BCM4752 and LNV4752
  ACPI nodes (git-fixes).
- Bluetooth: hci_qca: Stop IBS timer during BT OFF (git-fixes).
- Bluetooth: L2CAP: Fix using wrong mode (git-fixes).
- Bluetooth: btmtksdio: fix resume failure (git-fixes).
- Bluetooth: stop proccessing malicious adv data (git-fixes).
- Bluetooth: cmtp: fix possible panic when cmtp_init_sockets()
  fails (git-fixes).
- Bluetooth: btusb: fix memory leak in
  btusb_mtk_submit_wmt_recv_urb() (git-fixes).
- commit aa5f21e
* Mon Jan 10 2022 tiwai@suse.de
- power: supply: core: Break capacity loop (git-fixes).
- ieee802154: atusb: fix uninit value in atusb_set_extended_addr
  (git-fixes).
- mac80211: initialize variable have_higher_than_11mbit
  (git-fixes).
- batman-adv: mcast: don't send link-local multicast to mcast
  routers (git-fixes).
- Input: spaceball - fix parsing of movement data packets
  (git-fixes).
- net: usb: pegasus: Do not drop long Ethernet frames (git-fixes).
- Input: i8042 - enable deferred probe quirk for ASUS UM325UA
  (bsc#1190256).
- Input: i8042 - add deferred probe support (bsc#1190256).
- platform/x86: apple-gmux: use resource_size() with res
  (git-fixes).
- drm/mediatek: Check plane visibility in atomic_update
  (git-fixes).
- HID: asus: Add depends on USB_HID to HID_ASUS Kconfig option
  (git-fixes).
- ASoC: sunxi: fix a sound binding broken reference (git-fixes).
- commit 3be695f
* Mon Jan 10 2022 osalvador@suse.de
- Rename colliding patches before the next SLE15-SP2 -> SLE15-SP3 merge
- commit daf9fb8
* Fri Jan  7 2022 msuchanek@suse.de
- debugfs: lockdown: Allow reading debugfs files that are not
  world readable (bsc#1193328 ltc#195566).
- commit 8830882
* Thu Jan  6 2022 mkubecek@suse.cz
- series.conf: cleanup
- move submitted patch to "almost mainline" section
  patches.suse/ext4-Avoid-trim-error-on-fs-with-small-groups.patch
- commit dc09b47
* Thu Jan  6 2022 jack@suse.cz
- ext4: Avoid trim error on fs with small groups (bsc#1191271).
- commit f67e52e
* Wed Jan  5 2022 msuchanek@suse.de
- powerpc/fadump: Fix inaccurate CPU state info in vmcore
  generated with panic (bsc#1193901 ltc#194976).
- powerpc: handle kdump appropriately with
  crash_kexec_post_notifiers option (bsc#1193901 ltc#194976).
- commit 8924f63
* Wed Jan  5 2022 tiwai@suse.de
- USB: gadget: bRequestType is a bitfield, not a enum (git-fixes).
- usb: dwc3: pci: Enable dis_uX_susphy_quirk for Intel Merrifield
  (git-fixes).
- commit b983cf3
* Wed Jan  5 2022 tiwai@suse.de
- xhci: Fresco FL1100 controller should not have BROKEN_MSI
  quirk set (git-fixes).
- usb: mtu3: set interval of FS intr and isoc endpoint
  (git-fixes).
- usb: mtu3: fix list_head check warning (git-fixes).
- usb: mtu3: add memory barrier before set GPD's HWO (git-fixes).
- usb: gadget: f_fs: Clear ffs_eventfd in ffs_data_clear
  (git-fixes).
- USB: serial: option: add Telit FN990 compositions (git-fixes).
- USB: serial: cp210x: fix CP2105 GPIO registration (git-fixes).
- USB: NO_LPM quirk Lenovo USB-C to Ethernet Adapher(RTL8153-04)
  (git-fixes).
- usb: xhci: Extend support for runtime power management for
  AMD's Yellow carp (git-fixes).
- usb: core: config: using bit mask instead of individual bits
  (git-fixes).
- usb: core: config: fix validation of wMaxPacketValue entries
  (git-fixes).
- USB: gadget: zero allocate endpoint 0 buffers (git-fixes).
- USB: gadget: detect too-big endpoint 0 requests (git-fixes).
- xhci: avoid race between disable slot command and host runtime
  suspend (git-fixes).
- xhci: Remove CONFIG_USB_DEFAULT_PERSIST to prevent xHCI from
  runtime suspending (git-fixes).
- USB: NO_LPM quirk Lenovo Powered USB-C Travel Hub (git-fixes).
- USB: chipidea: fix interrupt deadlock (git-fixes).
- USB: cdc-acm: fix break reporting (git-fixes).
- USB: cdc-acm: fix racy tty buffer accesses (git-fixes).
- usb: typec: tcpm: handle SRC_STARTUP state if cc changes
  (git-fixes).
- usb: dwc2: check return value after calling
  platform_get_resource() (git-fixes).
- Revert "USB: xhci: fix U1/U2 handling for hardware with
  XHCI_INTEL_HOST quirk set" (git-fixes).
- xhci: fix unsafe memory usage in xhci tracing (git-fixes).
- usb: gadget: composite: Allow bMaxPower=0 if self-powered
  (git-fixes).
- usb: dwc3: gadget: Ignore EP queue requests during bus reset
  (git-fixes).
- usb: dwc3: ulpi: Fix USB2.0 HS/FS/LS PHY suspend regression
  (git-fixes).
- usb: dwc3: ulpi: Replace CPU-based busyloop with Protocol-based
  one (git-fixes).
- usb: dwc3: gadget: Reclaim extra TRBs after request completion
  (git-fixes).
- usb: dwc3: ulpi: fix checkpatch warning (git-fixes).
- usb: dwc3: gadget: Continue to process pending requests
  (git-fixes).
- commit c6091eb
* Wed Jan  5 2022 tiwai@suse.de
- watchdog: f71808e_wdt: fix inaccurate report in WDIOC_GETTIMEOUT
  (git-fixes).
- wcn36xx: handle connection loss indication (git-fixes).
- watchdog: Fix OMAP watchdog early handling (git-fixes).
- wcn36xx: Fix missing frame timestamp for beacon/probe-resp
  (git-fixes).
- commit ac118b7
* Wed Jan  5 2022 tiwai@suse.de
- spi: change clk_disable_unprepare to clk_unprepare (git-fixes).
- firmware: tegra: Fix error application of sizeof() to pointer
  (git-fixes).
- serial: pl011: Add ACPI SBSA UART match id (git-fixes).
- thermal: core: Reset previous low and high trip during thermal
  zone init (git-fixes).
- video: backlight: Drop maximum brightness override for
  brightness zero (git-fixes).
- Revert "PM: sleep: Do not assume that "mem" is always present"
  (git-fixes).
- thermal/drivers/int340x: Do not set a wrong tcc offset on resume
  (git-fixes).
- tty: synclink_gt: rename a conflicting function name
  (git-fixes).
- shmem: shmem_writepage() split unlikely i915 THP (git-fixes).
- serial: tty: uartlite: fix console setup (git-fixes).
- tty: max310x: fix flexible_array.cocci warnings (git-fixes).
- slimbus: qcom: fix potential NULL dereference in
  qcom_slim_prg_slew() (git-fixes).
- tty: serial: earlycon dependency (git-fixes).
- usermodehelper: reset umask to default before executing user
  process (git-fixes).
- tty: serial: qcom_geni_serial: Drop __init from
  qcom_geni_console_setup (git-fixes).
- string.h: fix incompatibility between FORTIFY_SOURCE and KASAN
  (git-fixes).
- commit a735650
* Wed Jan  5 2022 tiwai@suse.de
- soc/tegra: fuse: Fix bitwise vs. logical OR warning (git-fixes).
- soc: fsl: dpaa2-console: free buffer before returning from
  dpaa2_console_read (git-fixes).
- soc: fsl: dpio: use the combined functions to protect critical
  zone (git-fixes).
- soc: fsl: dpio: replace smp_processor_id with
  raw_smp_processor_id (git-fixes).
- power: supply: max17042_battery: Clear status bits in interrupt
  handler (git-fixes).
- soc: fsl: dpio: rename the enqueue descriptor variable
  (git-fixes).
- soc: fsl: dpio: use an explicit NULL instead of 0 (git-fixes).
- pwm: mxs: Don't modify HW state in .probe() after the PWM chip
  was registered (git-fixes).
- rtw88: wow: fix size access error of probe request (git-fixes).
- rtw88: wow: build wow function only if CONFIG_PM is on
  (git-fixes).
- rtw88: use read_poll_timeout instead of fixed sleep (git-fixes).
- rtl8xxxu: Fix the handling of TX A-MPDU aggregation (git-fixes).
- pwm: tiecap: Drop .free() callback (git-fixes).
- seq_buf: Make trace_seq_putmem_hex() support data longer than 8
  (git-fixes).
- seq_buf: Fix overflow in seq_buf_putmem_hex() (git-fixes).
- sata: nv: fix debug format string mismatch (git-fixes).
- commit df942c0
* Wed Jan  5 2022 tiwai@suse.de
- pinctrl: stm32: consider the GPIO offset to expose all the
  GPIO lines (git-fixes).
- pinctrl: mediatek: fix global-out-of-bounds issue (git-fixes).
- platform/x86: thinkpad_acpi: Fix WWAN device disabled issue
  after S3 deep (git-fixes).
- PM: sleep: Do not assume that "mem" is always present
  (git-fixes).
- pinctrl: stm32: use valid pin identifier in
  stm32_pinctrl_resume() (git-fixes).
- pinctrl: qcom: spmi-gpio: correct parent irqspec translation
  (git-fixes).
- pcnet32: Use pci_resource_len to validate PCI resource
  (git-fixes).
- PM: runtime: Defer suspending suppliers (git-fixes).
- commit abf2572
* Wed Jan  5 2022 tiwai@suse.de
- NFC: st21nfca: Fix memory leak in device probe and remove
  (git-fixes).
- PCI/MSI: Clear PCI_MSIX_FLAGS_MASKALL on error (git-fixes).
- PCI/MSI: Mask MSI-X vectors only on success (git-fixes).
- nfc: fix potential NULL pointer deref in nfc_genl_dump_ses_done
  (git-fixes).
- nfc: fix segfault in nfc_genl_dump_devices_done (git-fixes).
- PCI: cadence: Add cdns_plat_pcie_probe() missing return
  (git-fixes).
- commit da0a149
* Wed Jan  5 2022 tiwai@suse.de
- mmc: sdhci-tegra: Fix switch to HS400ES mode (git-fixes).
- misc: fastrpc: fix improper packet size calculation (git-fixes).
- mtd: rawnand: fsmc: Fix timing computation (git-fixes).
- mtd: rawnand: fsmc: Take instruction delay into account
  (git-fixes).
- mt76: mt7915: fix NULL pointer dereference in
  mt7915_get_phy_mode (git-fixes).
- mmc: sdhci-esdhc-imx: disable CMDQ support (git-fixes).
- mtd: spi-nor: hisi-sfc: Remove excessive clk_disable_unprepare()
  (git-fixes).
- mt76: mt7915: fix an off-by-one bound check (git-fixes).
- mwifiex: Try waking the firmware until we get an interrupt
  (git-fixes).
- mmc: sdhci-esdhc-imx: clear the buffer_read_ready to reset
  standard tuning circuit (git-fixes).
- misc: fastrpc: Add missing lock before accessing find_vma()
  (git-fixes).
- commit 55425ab
* Wed Jan  5 2022 tiwai@suse.de
- Input: appletouch - initialize work before device registration
  (git-fixes).
- Input: atmel_mxt_ts - fix double free in mxt_read_info_block
  (git-fixes).
- Input: elantech - fix stack out of bound access in
  elantech_change_report_id() (git-fixes).
- libata: if T_LENGTH is zero, dma direction should be DMA_NONE
  (git-fixes).
- mac80211: mark TX-during-stop for TX in in_reconfig (git-fixes).
- mac80211: fix lookup when adding AddBA extension element
  (git-fixes).
- mac80211: validate extended element ID is present (git-fixes).
- mac80211: agg-tx: don't schedule_and_wake_txq() under sta->lock
  (git-fixes).
- mac80211: send ADDBA requests using the tid/queue of the
  aggregation session (git-fixes).
- mac80211: fix regression in SSN handling of addba tx
  (git-fixes).
- mac80211: track only QoS data frames for admission control
  (git-fixes).
- libata: add horkage for ASMedia 1092 (git-fixes).
- mac80211: do not access the IV when it was stripped (git-fixes).
- Input: max8925_onkey - don't mark comment as kernel-doc
  (git-fixes).
- staging: ks7010: select CRYPTO_HASH/CRYPTO_MICHAEL_MIC
  (git-fixes).
- iwlwifi: mvm: disable RX-diversity in powersave (git-fixes).
- iwlwifi: mvm: Fix scan channel flags settings (git-fixes).
- iwlwifi: fw: correctly limit to monitor dump (git-fixes).
- iwlwifi: mvm: fix access to BSS elements (git-fixes).
- iwlwifi: mvm: avoid static queue number aliasing (git-fixes).
- iwlwifi: pcie: free RBs during configure (git-fixes).
- mac80211: Fix monitor MTU limit so that A-MSDUs get through
  (git-fixes).
- memblock: ensure there is no overflow in
  memblock_overlaps_region() (git-fixes).
- kobject_uevent: remove warning in init_uevent_argv()
  (git-fixes).
- memory: emif: Remove bogus debugfs error handling (git-fixes).
- kobject: Restore old behaviour of kobject_del(NULL) (git-fixes).
- lockdown: Allow unprivileged users to see lockdown status
  (git-fixes).
- kmod: make request_module() return an error when autoloading
  is disabled (git-fixes).
- commit 0f3480f
* Wed Jan  5 2022 tiwai@suse.de
- iio: trigger: stm32-timer: fix MODULE_ALIAS (git-fixes).
- iio: at91-sama5d2: Fix incorrect sign extension (git-fixes).
- iio: adc: axp20x_adc: fix charging current reporting on AXP22x
  (git-fixes).
- iio: ad7768-1: Call iio_trigger_notify_done() on error
  (git-fixes).
- iio: itg3200: Call iio_trigger_notify_done() on error
  (git-fixes).
- iio: dln2: Check return value of devm_iio_trigger_register()
  (git-fixes).
- iio: trigger: Fix reference counting (git-fixes).
- iio: dln2-adc: Fix lockdep complaint (git-fixes).
- iio: mma8452: Fix trigger reference couting (git-fixes).
- iio: stk3310: Don't return error code in interrupt handler
  (git-fixes).
- iio: kxsd9: Don't return error code in trigger handler
  (git-fixes).
- iio: ltr501: Don't return error code in trigger handler
  (git-fixes).
- iio: accel: kxcjk-1013: Fix possible memory leak in probe and
  remove (git-fixes).
- commit 4c68be5
* Wed Jan  5 2022 tiwai@suse.de
- i2c: validate user data in compat ioctl (git-fixes).
- i2c: rk3x: Handle a spurious start completion interrupt flag
  (git-fixes).
- ieee802154: hwsim: fix GPF in hwsim_set_edge_lqi (git-fixes).
- ieee802154: hwsim: avoid possible crash in hwsim_del_edge_nl()
  (git-fixes).
- ieee802154: hwsim: Fix memory leak in hwsim_add_one (git-fixes).
- ieee802154: hwsim: Fix possible memory leak in
  hwsim_subscribe_all_others (git-fixes).
- ieee802154: fix error return code in
  ieee802154_llsec_getparams() (git-fixes).
- ieee802154: fix error return code in ieee802154_add_iface()
  (git-fixes).
- commit 5d3590c
* Wed Jan  5 2022 tiwai@suse.de
- hwmon: (lm90) Do not report 'busy' status bit as alarm
  (git-fixes).
- hwmon: (lm90) Drop critical attribute support for MAX6654
  (git-fixes).
- hwmon: (lm90) Fix usage of CONFIG2 register in detect function
  (git-fixes).
- HID: google: add eel USB id (git-fixes).
- HID: add USB_HID dependancy to hid-prodikeys (git-fixes).
- HID: add USB_HID dependancy to hid-chicony (git-fixes).
- HID: bigbenff: prevent null pointer dereference (git-fixes).
- HID: quirks: Add quirk for the Microsoft Surface 3 type-cover
  (git-fixes).
- hwmon: (lm90) Add basic support for TI TMP461 (git-fixes).
- hwmon: (lm90) Introduce flag indicating extended temperature
  support (git-fixes).
- gpiolib: acpi: Make set-debounce-timeout failures non fatal
  (git-fixes).
- hwmon: (lm90) Add max6654 support to lm90 driver (git-fixes).
- commit 8903a1a
* Wed Jan  5 2022 tiwai@suse.de
- firmware: arm_scpi: Fix string overflow in SCPI genpd driver
  (git-fixes).
- firmware: smccc: Fix check for ARCH_SOC_ID not implemented
  (git-fixes).
- firmware: arm_scmi: pm: Propagate return value to caller
  (git-fixes).
- firmware_loader: fix pre-allocated buf built-in firmware use
  (git-fixes).
- firmware: qcom_scm: Fix error retval in
  __qcom_scm_is_call_available() (git-fixes).
- firmware: tegra: Reduce stack usage (git-fixes).
- firmware: raspberrypi: Fix a leak in 'rpi_firmware_get()'
  (git-fixes).
- staging: fbtft: Don't spam logs when probe is deferred
  (git-fixes).
- staging: fbtft: Rectify GPIO handling (git-fixes).
- eeprom: idt_89hpesx: Restore printing the unsupported fwnode
  name (git-fixes).
- eeprom: idt_89hpesx: Put fwnode in matching case during
  - >probe() (git-fixes).
- staging: fieldbus: anybuss: jump to correct label in an error
  path (git-fixes).
- staging: emxx_udc: Fix passing of NULL to dma_alloc_coherent()
  (git-fixes).
- commit 6208a26
* Wed Jan  5 2022 tiwai@suse.de
- drm/amdgpu: correct register access for RLC_JUMP_TABLE_RESTORE
  (git-fixes).
- drm/ast: potential dereference of null pointer (git-fixes).
- drm/syncobj: Deal with signalled fences in
  drm_syncobj_find_fence (git-fixes).
- drm/amd/display: add connector type check for CRC source set
  (git-fixes).
- drm/amd/display: Fix for the no Audio bug with Tiled Displays
  (git-fixes).
- drm/msm/dsi: set default num_data_lanes (git-fixes).
- drm/sun4i: fix unmet dependency on RESET_CONTROLLER for
  PHY_SUN6I_MIPI_DPHY (git-fixes).
- drm/amd/display: dcn20_resource_construct reduce scope of FPU
  enabled (git-fixes).
- drm/msm: prevent NULL dereference in
  msm_gpu_crashstate_capture() (git-fixes).
- commit bdadc10
* Wed Jan  5 2022 tiwai@suse.de
- drm/msm/mdp5: fix cursor-related warnings (git-fixes).
- drm/amd/amdgpu: Increase HWIP_MAX_INSTANCE to 10 (git-fixes).
- drm/amd/display: Update bounding box states (v2) (git-fixes).
- drm/amd/display: Update number of DCN3 clock states (git-fixes).
- drm/amdkfd: Account for SH/SE count when setting up cu masks
  (git-fixes).
- drm/exynos: Always initialize mapping in
  exynos_drm_register_dma() (git-fixes).
- drm/display: fix possible null-pointer dereference in
  dcn10_set_clock() (git-fixes).
- drm/amd/display: fix incorrect CM/TF programming sequence in
  dwb (git-fixes).
- drm/amd/display: fix missing writeback disablement if plane
  is removed (git-fixes).
- drm/msm/dsi: Fix DSI and DSI PHY regulator config from SDM660
  (git-fixes).
- commit 792bcdc
* Wed Jan  5 2022 tiwai@suse.de
- drm/msm: mdp4: drop vblank get/put from prepare/complete_commit
  (git-fixes).
- drm: xlnx: zynqmp: release reset to DP controller before
  accessing DP registers (git-fixes).
- drm: xlnx: zynqmp_dpsub: Call pm_runtime_get_sync before
  setting pixel clock (git-fixes).
- drm/amdgpu: Fix a printing message (git-fixes).
- drm/amdgpu: Fix amdgpu_ras_eeprom_init() (git-fixes).
- drm/bridge: nwl-dsi: Avoid potential multiplication overflow
  on 32-bit (git-fixes).
- drm/vc4: hdmi: Set HD_CTL_WHOLSMP and HD_CTL_CHALIGN_SET
  (git-fixes).
- commit c849561
* Wed Jan  5 2022 tiwai@suse.de
- dmaengine: st_fdma: fix MODULE_ALIAS (git-fixes).
- dmaengine: bestcomm: fix system boot lockups (git-fixes).
- crypto: qat - fix reuse of completion variable (git-fixes).
- crypto: qat - handle both source of interrupt in VF ISR
  (git-fixes).
- crypto: omap-sham - clear dma flags only after
  omap_sham_update_dma_stop() (git-fixes).
- crypto: mxs-dcp - Use sg_mapping_iter to copy data (git-fixes).
- commit dc6c442
* Wed Jan  5 2022 tiwai@suse.de
- ax25: NPD bug when detaching AX25 device (git-fixes).
- clk: Don't parent clks until the parent is fully registered
  (git-fixes).
- clk: qcom: regmap-mux: fix parent clock lookup (git-fixes).
- can: kvaser_usb: get CAN clock frequency from device
  (git-fixes).
- can: sja1000: fix use after free in ems_pcmcia_add_card()
  (git-fixes).
- ata: ahci: Add Green Sardine vendor ID as board_ahci_mobile
  (git-fixes).
- clk: qcom: gcc-msm8996: Drop (again) gcc_aggre1_pnoc_ahb_clk
  (git-fixes).
- crypto: qat - do not ignore errors from enable_vf2pf_comms()
  (git-fixes).
- commit 56c7fe1
* Wed Jan  5 2022 tiwai@suse.de
- ASoC: meson: aiu: Move AIU_I2S_MISC hold setting to aiu-fifo-i2s
  (git-fixes).
- ASoC: meson: aiu: fifo: Add missing
  dma_coerce_mask_and_coherent() (git-fixes).
- ASoC: codecs: wsa881x: fix return values from kcontrol put
  (git-fixes).
- ASoC: codecs: wcd934x: return correct value from mixer put
  (git-fixes).
- ASoC: codecs: wcd934x: handle channel mappping list correctly
  (git-fixes).
- ASoC: qdsp6: q6routing: Fix return value from
  msm_routing_put_audio_mixer (git-fixes).
- ASoC: tegra: Fix kcontrol put callback in AHUB (git-fixes).
- ASoC: tegra: Fix kcontrol put callback in DSPK (git-fixes).
- ASoC: tegra: Fix kcontrol put callback in DMIC (git-fixes).
- ASoC: tegra: Fix kcontrol put callback in I2S (git-fixes).
- ASoC: tegra: Fix kcontrol put callback in ADMAIF (git-fixes).
- ASoC: tegra: Fix wrong value type in DSPK (git-fixes).
- ASoC: tegra: Fix wrong value type in DMIC (git-fixes).
- ASoC: tegra: Fix wrong value type in I2S (git-fixes).
- ASoC: tegra: Fix wrong value type in ADMAIF (git-fixes).
- ASoC: codecs: wcd934x: return error code correctly from
  hw_params (git-fixes).
- ASoC: cs42l42: Correct configuring of switch inversion from
  ts-inv (git-fixes).
- ASoC: soc-core: fix null-ptr-deref in
  snd_soc_del_component_unlocked() (git-fixes).
- amd/display: downgrade validation failure log level (git-fixes).
- ASoC: cs42l42: Use device_property API instead of of_property
  (git-fixes).
- ASoC: cs42l42: Disable regulators if probe fails (git-fixes).
- commit 4fe697d
* Wed Jan  5 2022 tiwai@suse.de
- ALSA: hda/realtek: Fix quirk for TongFang PHxTxX1 (git-fixes).
- commit 02956db
* Wed Jan  5 2022 tiwai@suse.de
- ALSA: hda/realtek: Add quirk for ASRock NUC Box 1100
  (git-fixes).
- commit 9c729e6
* Wed Jan  5 2022 tiwai@suse.de
- ALSA: hda/realtek: Fix quirk for Clevo NJ51CU (git-fixes).
- ALSA: hda/hdmi: Disable silent stream on GLK (git-fixes).
- ALSA: hda/realtek: Amp init fixup for HP ZBook 15 G6
  (git-fixes).
- ALSA: jack: Check the return value of kstrdup() (git-fixes).
- ALSA: drivers: opl3: Fix incorrect use of vp->state (git-fixes).
- ALSA: hda/realtek - Add headset Mic support for Lenovo ALC897
  platform (git-fixes).
- commit d2b626b
* Wed Jan  5 2022 jack@suse.cz
- fget: check that the fd still exists after getting a ref to it
  (bsc#1193727 CVE-2021-4083).
- commit 9958eae
* Wed Jan  5 2022 tiwai@suse.de
- ALSA: ctl: Fix copy of updated id with element read/write
  (git-fixes).
- ALSA: pcm: oss: Handle missing errors in
  snd_pcm_oss_change_params*() (git-fixes).
- ALSA: pcm: oss: Limit the period size to 16MB (git-fixes).
- ALSA: pcm: oss: Fix negative period/buffer sizes (git-fixes).
- ACPI: Add stubs for wakeup handler functions (git-fixes).
- ALSA: hda/realtek: Headset fixup for Clevo NH77HJQ (git-fixes).
- ALSA: usb-audio: Line6 HX-Stomp XL USB_ID for 48k-fixed quirk
  (git-fixes).
- ALSA: hda/realtek: Add a quirk for HP OMEN 15 mute LED
  (git-fixes).
- ALSA: hda/realtek: Fixes HP Spectre x360 15-eb1xxx speakers
  (git-fixes).
- commit 5e82764
* Tue Jan  4 2022 rgoldwyn@suse.com
- btrfs: unlock newly allocated extent buffer after error (bsc#1194001, CVE-2021-4149).
- commit 5719af8
* Tue Jan  4 2022 bp@suse.de
- kprobes: Limit max data_size of the kretprobe instances
  (bsc#1193669).
- commit c7a83f7
* Tue Jan  4 2022 mkoutny@suse.com
- cgroup/cpuset: Fix a partition bug with hotplug (bsc#1194291).
- commit 9a89323
* Tue Jan  4 2022 mkoutny@suse.com
- blacklist.conf: Add 7ee285395b21 cgroup: Make rebind_subsystems() disable v2 controllers all at once
- commit 11abfa4
* Tue Jan  4 2022 mkoutny@suse.com
- blacklist.conf: Add 6ba34d3c7367 cgroup/cpuset: Fix violation of cpuset locking rule
- commit a116f42
* Tue Jan  4 2022 denis.kirjanov@suse.com
- ipv6: use prandom_u32() for ID generation (CVE-2021-45485
  bsc#1194094).
- commit ea9f5f6
* Mon Jan  3 2022 dwagner@suse.de
- scsi: lpfc: Update lpfc version to 14.0.0.4 (bsc#1194266).
- scsi: lpfc: Add additional debugfs support for CMF
  (bsc#1194266).
- scsi: lpfc: Cap CMF read bytes to MBPI (bsc#1194266).
- scsi: lpfc: Adjust CMF total bytes and rxmonitor (bsc#1194266).
- scsi: lpfc: Trigger SLI4 firmware dump before doing driver
  cleanup (bsc#1194266).
- scsi: lpfc: Fix NPIV port deletion crash (bsc#1194266).
- scsi: lpfc: Fix lpfc_force_rscn ndlp kref imbalance
  (bsc#1194266).
- scsi: lpfc: Change return code on I/Os received during link
  bounce (bsc#1194266).
- scsi: lpfc: Fix leaked lpfc_dmabuf mbox allocations with NPIV
  (bsc#1194266).
- commit f7f7742
* Mon Jan  3 2022 dwagner@suse.de
- Update patches.suse/qla2xxx-synchronize-rport-dev_loss_tmo-setting.patch
  Update meta data and move the patch into the sorted section.
- commit 9223d1e
* Mon Jan  3 2022 dwagner@suse.de
- scsi: qla2xxx: Format log strings only if needed (git-fixes).
- wireguard: ratelimiter: use kvcalloc() instead of kvzalloc()
  (git-fixes).
- wireguard: receive: drop handshakes if queue lock is contended
  (git-fixes).
- wireguard: receive: use ring buffer for incoming handshakes
  (git-fixes).
- wireguard: device: reset peer src endpoint when netns exits
  (git-fixes).
- wireguard: selftests: actually test for routing loops
  (git-fixes).
- wireguard: selftests: increase default dmesg log size
  (git-fixes).
- wireguard: allowedips: add missing __rcu annotation to satisfy
  sparse (git-fixes).
- scsi: qla2xxx: edif: Fix off by one bug in
  qla_edif_app_getfcinfo() (git-fixes).
- scsi: qla2xxx: Fix mailbox direction flags in
  qla2xxx_get_adapter_id() (git-fixes).
- scsi: qla2xxx: edif: Fix EDIF bsg (git-fixes).
- scsi: qla2xxx: edif: Increase ELS payload (git-fixes).
- scsi: qla2xxx: edif: Flush stale events and msgs on session down
  (git-fixes).
- scsi: qla2xxx: edif: Fix app start delay (git-fixes).
- scsi: qla2xxx: edif: Fix app start fail (git-fixes).
- commit f28a9ca
* Mon Jan  3 2022 denis.kirjanov@suse.com
- ipv6: use prandom_u32() for ID generation (CVE-2021-45485
  bsc#1194094).
- commit 34edd9c
* Mon Jan  3 2022 denis.kirjanov@suse.com
- inet: use bigger hash table for IP ID generation (CVE-2021-45486
  bsc#1194087).
- commit 28e6987
* Mon Jan  3 2022 denis.kirjanov@suse.com
- inet: use bigger hash table for IP ID generation (CVE-2021-45486
  bsc#1194087).
- commit 1f316eb
* Mon Jan  3 2022 tiwai@suse.de
- media: Revert "media: uvcvideo: Set unique vdev name based in
  type" (bsc#1193255).
- commit 6d6cdd3
* Mon Jan  3 2022 oneukum@suse.com
- net: create netdev->dev_addr assignment helpers (git-fixes).
- commit 49be0aa
* Fri Dec 31 2021 tonyj@suse.de
- s390/bpf: Fix branch shortening during codegen pass
  (bsc#1193993).
- commit 2c7711e
* Fri Dec 31 2021 tonyj@suse.de
- Correct porting that occured from SP2:
  patches.suse/bpf-Fix-toctou-on-read-only-map-s-constant-scalar-tracking.patch.
- commit 89dd21e
* Thu Dec 30 2021 mbenes@suse.cz
- recordmcount.pl: fix typo in s390 mcount regex (bsc#1192267).
- commit cd27ffb
* Thu Dec 30 2021 dmueller@suse.com
- fix rpm build warning
  tumbleweed rpm is adding these warnings to the log:
  It's not recommended to have unversioned Obsoletes: Obsoletes:      microcode_ctl
- commit 3ba8941
* Thu Dec 30 2021 mbenes@suse.cz
- recordmcount.pl: look for jgnop instruction as well as bcrl
  on s390 (bsc#1192267).
- Delete patches.suse/ftrace-recordmcount-binutils.patch.
- commit b7ea99b
* Wed Dec 29 2021 bp@suse.de
- EDAC/amd64: Handle three rank interleaving mode (bsc#1152489).
- commit 24c4284
* Tue Dec 28 2021 osalvador@suse.de
- Rename colliding patches before the next SLE15-SP2 -> SLE15-SP3 merge
- commit 6bd4e83
* Mon Dec 27 2021 bp@suse.de
- x86/pkey: Fix undefined behaviour with PKRU_WD_BIT
  (bsc#1152489).
- commit 86f2e0e
* Mon Dec 27 2021 bp@suse.de
- x86/cpu: Fix migration safety with X86_BUG_NULL_SEL
  (bsc#1152489).
- commit 653ca7c
* Thu Dec 23 2021 denis.kirjanov@suse.com
- Update config files.
- commit 7b17171
* Wed Dec 22 2021 dmueller@suse.com
- build initrd without systemd
  This reduces the size of the initrd by over 25%%, which
  improves startup time of the virtual machine by 0.5-0.6s on
  very fast machines, more on slower ones.
- commit ef4c569
* Wed Dec 22 2021 jack@suse.cz
- bfq: Limit number of requests consumed by each cgroup
  (bsc#1184318).
- bfq: Store full bitmap depth in bfq_data (bsc#1184318).
- bfq: Track number of allocated requests in bfq_entity
  (bsc#1184318).
- block: Provide blk_mq_sched_get_icq() (bsc#1184318).
- commit b145381
* Wed Dec 22 2021 bp@suse.de
- blacklist.conf: ef775a0e36c6 x86/Kconfig: Fix an unused variable error in dell-smm-hwmon
- commit 77f7f56
* Wed Dec 22 2021 oneukum@suse.com
- bpf, s390: Fix potential memory leak about jit_data (git-fixes).
- commit a96c419
* Wed Dec 22 2021 oneukum@suse.com
- blacklist.conf: duplicate
- commit 21615d4
* Wed Dec 22 2021 oneukum@suse.com
- bpf, x86: Fix "no previous prototype" warning (git-fixes).
- commit 56004e0
* Wed Dec 22 2021 oneukum@suse.com
- serial: 8250: Fix RTS modem control while in rs485 mode
  (git-fixes).
- commit b2a12fa
* Tue Dec 21 2021 oneukum@suse.com
- usb: gadget: u_ether: fix race in setting MAC address in setup
  phase (git-fixes).
- commit e9c3803
* Mon Dec 20 2021 ematsumiya@suse.de
- Refresh patches.suse/new-helper-lookup_positive_unlocked.patch.
  Fix part of hunk removed by an earlier refresh.
  (non-functional change)
- commit 74aed66
* Mon Dec 20 2021 tonyj@suse.de
- handle KABI change in struct bpf_map (bsc#1192990
  CVE-2021-4001).
- bpf: Fix toctou on read-only map's constant scalar tracking
  (bsc#1192990 CVE-2021-4001).
- commit 38c062a
* Mon Dec 20 2021 jgross@suse.com
- xen/netback: don't queue unlimited number of packages
  (CVE-2021-28715 XSA-392 bsc#1193442).
- commit e989a63
* Mon Dec 20 2021 jgross@suse.com
- xen/netback: fix rx queue stall detection (CVE-2021-28714
  XSA-392 bsc#1193442).
- commit bee9756
* Mon Dec 20 2021 jgross@suse.com
- xen/console: harden hvc_xen against event channel storms
  (CVE-2021-28713 XSA-391 bsc#1193440).
- commit fc934bd
* Mon Dec 20 2021 jgross@suse.com
- xen/netfront: harden netfront against event channel storms
  (CVE-2021-28712 XSA-391 bsc#1193440).
- commit 0168f42
* Mon Dec 20 2021 jgross@suse.com
- xen/blkfront: harden blkfront against event channel storms
  (CVE-2021-28711 XSA-391 bsc#1193440).
- commit 80dd44a
* Mon Dec 20 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  - patches.suse/01-cifs-remove-redundant-initialization-of-variable-rc.patch
  - patches.suse/03-cifs-update-internal-module-version-number.patch
  - patches.suse/CIFS-Fix-bug-which-the-return-value-by-asynchronous-read-is-error.patch
  - patches.suse/CIFS-Spelling-s-EACCESS-EACCES-.patch
  - patches.suse/CIFS-Warn-less-noisily-on-default-mount.patch
  - patches.suse/CIFS-check-new-file-size-when-extending-file-by-fallocate.patch
  - patches.suse/Replace-HTTP-links-with-HTTPS-ones-CIFS.patch
  - patches.suse/SMB3-Add-new-compression-flags.patch
  - patches.suse/SMB3-Add-new-info-level-for-query-directory.patch
  - patches.suse/SMB3-Additional-compression-structures.patch
  - patches.suse/SMB3-Minor-cleanup-of-protocol-definitions.patch
  - patches.suse/cifs-Allocate-encryption-header-through-kmalloc.patch
  - patches.suse/cifs-Avoid-field-over-reading-memcpy-.patch
  - patches.suse/cifs-Constify-static-struct-genl_ops.patch
  - patches.suse/cifs-Do-not-leak-EDEADLK-to-dgetents64-for-STATUS_USER_SESSION_DELE.patch
  - patches.suse/cifs-allow-unlock-flock-and-OFD-lock-across-fork.patch
  - patches.suse/cifs-avoid-extra-calls-in-posix_info_parse.patch
  - patches.suse/cifs-cifs_md4-convert-to-SPDX-identifier.patch
  - patches.suse/cifs-cifspdu-h-Replace-zero-length-array-with-flexible-array-membe.patch
  - patches.suse/cifs-clear-PF_MEMALLOC-before-exiting-demultiplex-thread.patch
  - patches.suse/cifs-convert-list_for_each-to-entry-variant-in-cifs_debug-c.patch
  - patches.suse/cifs-convert-list_for_each-to-entry-variant-in-smb2misc-c.patch
  - patches.suse/cifs-create-a-MD4-module-and-switch-cifs-ko-to-use-it.patch
  - patches.suse/cifs-create-sd-context-must-be-a-multiple-of-8.patch
  - patches.suse/cifs-enable-extended-stats-by-default.patch
  - patches.suse/cifs-fix-NULL-dereference-in-smb2_check_message-.patch
  - patches.suse/cifs-fix-SMB1-error-path-in-cifs_get_file_info_unix.patch
  - patches.suse/cifs-fix-a-memleak-with-modefromsid.patch
  - patches.suse/cifs-fix-doc-warnings-in-cifs_dfs_ref-c.patch
  - patches.suse/cifs-fix-incorrect-kernel-doc-comments.patch
  - patches.suse/cifs-fix-ipv6-formating-in-cifs_ses_add_channel.patch
  - patches.suse/cifs-fix-missing-spinlock-around-update-to-ses-status.patch
  - patches.suse/cifs-fix-unneeded-null-check.patch
  - patches.suse/cifs-fix-wrong-release-in-sess_alloc_buffer-failed-path.patch
  - patches.suse/cifs-fork-arc4-and-create-a-separate-module-for-it-for-cifs-and-oth.patch
  - patches.suse/cifs-have-cifs_fattr_to_inode-refuse-to-change-type-on-live-inode.patch
  - patches.suse/cifs-have-mkdir-handle-race-with-another-client-sanely.patch
  - patches.suse/cifs-improve-fallocate-emulation.patch
  - patches.suse/cifs-missed-ref-counting-smb-session-in-find.patch
  - patches.suse/cifs-missing-null-check-for-newinode-pointer.patch
  - patches.suse/cifs-nosharesock-should-be-set-on-new-server.patch
  - patches.suse/cifs-populate-server_hostname-for-extra-channels.patch
  - patches.suse/cifs-remove-duplicated-prototype.patch
  - patches.suse/cifs-remove-pathname-for-file-from-SPDX-header.patch
  - patches.suse/cifs-remove-two-cases-where-rc-is-set-unnecessarily-in-sid_to_id.patch
  - patches.suse/cifs-retry-lookup-and-readdir-when-EAGAIN-is-returned-.patch
  - patches.suse/cifs-smb2pdu-h-Replace-zero-length-array-with-flexible-array-membe.patch
  - patches.suse/cifs-smbd-Calculate-the-correct-maximum-packet-size-for-segmented-.patch
  - patches.suse/cifs-smbd-Check-and-extend-sender-credits-in-interrupt-context.patch
  - patches.suse/cifs-update-internal-version-number-0b03fe6d.patch
  - patches.suse/cifs-use-SPDX-Licence-Identifier.patch
  - patches.suse/cifs_debug-use-pd-instead-of-messing-with-d_name.patch
  - patches.suse/do_cifs_create-don-t-set-i_mode-of-something-we-had-not-created.patch
  - patches.suse/fs-cifs-Initialize-filesystem-timestamp-ranges.patch
  - patches.suse/fs-cifs-fix-gcc-warning-in-sid_to_id.patch
  - patches.suse/linux-parser-h-add-include-guards.patch
  - patches.suse/smb2-clarify-rc-initialization-in-smb2_reconnect.patch
  - patches.suse/smb3-Avoid-Mid-pending-list-corruption.patch
  - patches.suse/smb3-Call-cifs-reconnect-from-demultiplex-thread.patch
  - patches.suse/smb3-Handle-error-case-during-offload-read-path.patch
  - patches.suse/smb3-fix-posix-extensions-mount-option.patch
  - patches.suse/smb3-fix-possible-access-to-uninitialized-pointer-to-DACL.patch
  - patches.suse/smb3-fix-uninitialized-value-for-port-in-witness-protocol-move.patch
  - patches.suse/smb3-prevent-races-updating-CurrentMid.patch
  - patches.suse/smb3-use-SMB2_SIGNATURE_SIZE-define.patch
  - patches.suse/smb311-remove-dead-code-for-non-compounded-posix-query-info.patch
  - patches.suse/smbdirect-missing-rc-checks-while-waiting-for-rdma-events.patch
  - patches.suse/vfs-don-t-parse-forbidden-flags.patch
- commit 9d51829
* Fri Dec 17 2021 jdelvare@suse.de
- hwmon: (k10temp) Remove residues of current and voltage
  (jsc#SLE-17823 jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) Add support for yellow carp (jsc#SLE-17823
  jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) Rework the temperature offset calculation
  (jsc#SLE-17823 jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) Don't show Tdie for all Zen/Zen2/Zen3 CPU/APU
  (jsc#SLE-17823 jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) Add additional missing Zen2 and Zen3 APUs
  (jsc#SLE-17823 jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) support Zen3 APUs (jsc#SLE-17823 jsc#SLE-23139
  jsc#ECO-3666).
- x86/amd_nb: Add AMD family 19h model 50h PCI ids (jsc#SLE-17823
  jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) Zen3 Ryzen Desktop CPUs support (jsc#SLE-17823
  jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) Remove support for displaying voltage and
  current on Zen CPUs (jsc#SLE-17823 jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) Add support for Zen3 CPUs (jsc#SLE-17823
  jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) Define SVI telemetry and current factors for
  Zen2 CPUs (jsc#SLE-17823 jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) Create common functions and macros for Zen
  CPU families (jsc#SLE-17823 jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) make some symbols static (jsc#SLE-17823
  jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) Update driver documentation (jsc#SLE-17823
  jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) Reorganize and simplify temperature support
  detection (jsc#SLE-17823 jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) Swap Tdie and Tctl on Family 17h CPUs
  (jsc#SLE-17823 jsc#SLE-23139 jsc#ECO-3666).
- hwmon: (k10temp) Update documentation and add temp2_input info
  (jsc#SLE-17823 jsc#SLE-23139 jsc#ECO-3666).
- commit 84d83f2
* Fri Dec 17 2021 dmueller@suse.com
- kernel-obs-build: remove duplicated/unused parameters
  lbs=0 - this parameters is just giving "unused parameter" and it looks
  like I can not find any version that implemented this.
  rd.driver.pre=binfmt_misc is not needed when setup_obs is used, it
  alread loads the kernel module.
  quiet and panic=1 will now be also always added by OBS, so we don't have
  to set it here anymore.
- commit 972c692
* Fri Dec 17 2021 tbogendoerfer@suse.de
- nfp: Fix memory leak in nfp_cpp_area_cache_add() (git-fixes).
- ice: ignore dropped packets during init (git-fixes).
- i40e: Fix pre-set max number of queues for VF (git-fixes).
- i40e: Fix failed opcode appearing if handling messages from VF
  (git-fixes).
- iavf: Fix reporting when setting descriptor count (git-fixes).
- qede: validate non LSO skb length (git-fixes).
- net/mlx4_en: Fix an use-after-free bug in
  mlx4_en_try_alloc_resources() (git-fixes).
- net: qlogic: qlcnic: Fix a NULL pointer dereference in
  qlcnic_83xx_add_rings() (git-fixes).
- rxrpc: Fix rxrpc_local leak in rxrpc_lookup_peer() (bsc#1154353
  bnc#1151927 5.3.9).
- igb: fix netpoll exit with traffic (git-fixes).
- ice: avoid bpf_prog refcount underflow (jsc#SLE-7926).
- nfp: checking parameter process for rx-usecs/tx-usecs is invalid
  (git-fixes).
- iavf: Prevent changing static ITR values if adaptive moderation
  is on (git-fixes).
- i40e: Fix ping is lost after configuring ADq on VF (git-fixes).
- net/mlx5: Update error handler for UCTX and UMEM (git-fixes).
- iavf: Restore VLAN filters after link down (git-fixes).
- iavf: don't clear a lock we don't hold (git-fixes).
- net/mlx5e: reset XPS on error flow if netdev isn't registered
  yet (git-fixes).
- commit 03289fd
* Fri Dec 17 2021 mbenes@suse.cz
- Update
  patches.suse/ring-buffer-Protect-ring_buffer_reset-from-reentrancy.patch
  (CVE-2020-27825 bsc#1179960).
- commit dc9e1e4
* Fri Dec 17 2021 osalvador@suse.de
- Rename colliding patches before the next SLE15-SP2 -> SLE15-SP3 merge
- commit 7a595e1
* Fri Dec 17 2021 iivanov@suse.de
- ARM: imx: fix missing 3rd argument in macro imx_mmdc_perf_init (git-fixes)
- commit 34f6968
* Thu Dec 16 2021 tbogendoerfer@suse.de
- ice: create scheduler aggregator node config and move VSIs
  (bsc#1182404 CVE-2020-24504).
- commit c99471f
* Thu Dec 16 2021 jeyu@suse.de
- blacklist.conf: Add commit ec2a29593c83
  Not a fix per-se, and removes a logging feature we need.
- commit a11b223
* Thu Dec 16 2021 mbenes@suse.cz
- tracing: Change STR_VAR_MAX_LEN (git-fixes).
- Refresh patches.suse/tracing-save-normal-string-variables.patch.
- commit 38905d3
* Wed Dec 15 2021 jgross@suse.com
- tty: hvc: replace BUG_ON() with negative return value
  (git-fixes).
- commit 7ffe7bd
* Wed Dec 15 2021 jgross@suse.com
- xen/netfront: don't trust the backend response data blindly
  (git-fixes).
- commit da41a54
* Wed Dec 15 2021 jgross@suse.com
- xen/netfront: disentangle tx_skb_freelist (git-fixes).
- commit b0fca08
* Wed Dec 15 2021 jgross@suse.com
- xen/netfront: don't read data from request on the ring page
  (git-fixes).
- commit 6ebcb04
* Wed Dec 15 2021 jgross@suse.com
- xen/netfront: read response from backend only once (git-fixes).
- commit fedf742
* Wed Dec 15 2021 jgross@suse.com
- xen/blkfront: don't trust the backend response data blindly
  (git-fixes).
- commit 6a791ee
* Wed Dec 15 2021 jgross@suse.com
- xen/blkfront: don't take local copy of a request from the ring
  page (git-fixes).
- commit 7bc0bc1
* Wed Dec 15 2021 jgross@suse.com
- xen/blkfront: read response from backend only once (git-fixes).
- commit 674c286
* Wed Dec 15 2021 jgross@suse.com
- xen: sync include/xen/interface/io/ring.h with Xen's newest
  version (git-fixes).
- commit 0333f3c
* Wed Dec 15 2021 bp@suse.de
- x86/sev: Fix SEV-ES INS/OUTS instructions for word, dword,
  and qword (bsc#1178134).
- commit d8e4de4
* Wed Dec 15 2021 jgross@suse.com
- xen/pvh: add missing prototype to header (git-fixes).
- commit 3762eb9
* Wed Dec 15 2021 jgross@suse.com
- x86/pvh: add prototype for xen_pvh_init() (git-fixes).
- commit 0b2da73
* Wed Dec 15 2021 mbenes@suse.cz
- tracing: Add length protection to histogram string copies
  (git-fixes).
- commit e386e69
* Wed Dec 15 2021 mbenes@suse.cz
- ring-buffer: Protect ring_buffer_reset() from reentrancy
  (bsc#1179960).
- commit c5cf6b9
* Wed Dec 15 2021 mbenes@suse.cz
- elfcore: correct reference to CONFIG_UML (git-fixes).
- commit 2b36804
* Wed Dec 15 2021 iivanov@suse.de
- blacklist.conf: ("ARM: at91: pm: do not panic if ram controllers are not enabled")
- commit ef792af
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: turris-omnia: fix hardware buffer management (git-fixes)
- commit e2dd35b
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: BCM5301X: Add interrupt properties to GPIO node (git-fixes)
- commit c7eba50
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: BCM5301X: Fix I2C controller interrupt (git-fixes)
- commit 119681c
* Wed Dec 15 2021 iivanov@suse.de
- ARM: 9155/1: fix early early_iounmap() (git-fixes)
- commit 70adb7b
* Wed Dec 15 2021 iivanov@suse.de
- blacklist.conf: ("ARM: dts: stm32: fix SAI sub nodes register range")
- commit e027ea9
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: qcom: msm8974: Add xo_board reference clock to DSI0 PHY (git-fixes)
- commit 48ea472
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: at91: tse850: the emac<->phy interface is rmii (git-fixes)
- commit 41f0870
* Wed Dec 15 2021 iivanov@suse.de
- arm: dts: omap3-gta04a4: accelerometer irq fix (git-fixes)
- commit 0163af2
* Wed Dec 15 2021 iivanov@suse.de
- ARM: s3c: irq-s3c24xx: Fix return value check for s3c24xx_init_intc() (git-fixes)
- commit ec0a139
* Wed Dec 15 2021 iivanov@suse.de
- blacklist.conf: ("ARM: 9131/1: mm: Fix PXN process with LPAE feature")
- commit 93193ac
* Wed Dec 15 2021 iivanov@suse.de
- ARM: 9141/1: only warn about XIP address when not compile testing (git-fixes)
- commit 8331a56
* Wed Dec 15 2021 iivanov@suse.de
- ARM: 9139/1: kprobes: fix arch_init_kprobes() prototype (git-fixes)
- commit 47dc5e0
* Wed Dec 15 2021 iivanov@suse.de
- ARM: 9134/1: remove duplicate memcpy() definition (git-fixes)
- commit 72d9e60
* Wed Dec 15 2021 iivanov@suse.de
- ARM: 9133/1: mm: proc-macros: ensure *_tlb_fns are 4B aligned (git-fixes)
- commit 8c43bfe
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: omap3430-sdp: Fix NAND device node (git-fixes)
- commit b68c97c
* Wed Dec 15 2021 iivanov@suse.de
- ARM: imx6: disable the GIC CPU interface before calling stby-poweroff (git-fixes)
- commit 1f4fc66
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: imx: Fix USB host power regulator polarity on M53Menlo (git-fixes)
- commit afd1b25
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: qcom: apq8064: Use 27MHz PXO clock as DSI PLL reference (git-fixes)
- commit f888650
* Wed Dec 15 2021 iivanov@suse.de
- bpf, arm: Fix register clobbering in div/mod implementation (git-fixes)
- commit 8a7bc09
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: vf610-zii-dev-rev-b: Remove #address-cells and #size-cells (git-fixes)
- commit 6cf3093
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: meson8b: ec100: Fix the pwm regulator supply properties (git-fixes)
- commit 51225a0
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: meson8b: mxq: Fix the pwm regulator supply properties (git-fixes)
- commit 47ca382
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: meson8b: odroidc1: Fix the pwm regulator supply properties (git-fixes)
- commit 7b83a15
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: meson8: Use a higher default GPU clock frequency (git-fixes)
- commit 9c0ad71
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: at91: add pinctrl-{names, 0} for all gpios (git-fixes)
- commit 87f59d6
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: imx: Swap M53Menlo pinctrl_power_button/pinctrl_power_out (git-fixes)
- commit f2b1a59
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: colibri-imx6ull: limit SDIO clock to 25MHz (git-fixes)
- commit 0950c36
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: imx6qdl-sr-som: Increase the PHY reset duration to 10ms (git-fixes)
- commit 2c0a46d
* Wed Dec 15 2021 iivanov@suse.de
- ARM: imx: add missing clk_disable_unprepare() (git-fixes)
- commit 7574099
* Wed Dec 15 2021 iivanov@suse.de
- ARM: imx: add missing iounmap() (git-fixes)
- commit ba7a7f4
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: am335x: align ti,pindir-d0-out-d1-in property with dt-shema (git-fixes)
- commit 0c3bad2
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: imx6q-dhcom: Add gpios pinctrl for i2c bus recovery (git-fixes)
- commit 9a36822
* Wed Dec 15 2021 iivanov@suse.de
- ARM: dts: imx6q-dhcom: Fix ethernet plugin detection problems (git-fixes)
- commit 510212d
* Tue Dec 14 2021 dmueller@suse.com
- Revert "- rpm/*build: use buildroot macro instead of env variable"
  buildroot macro is not being expanded inside a shell script. go
  back to the environment variable usage. This reverts parts of
  commit e2f60269b9330d7225b2547e057ef0859ccec155.
- commit fe85f96
* Tue Dec 14 2021 lduncan@suse.com
- scsi: pm80xx: Do not call scsi_remove_host() in pm8001_alloc()
  (git-fixes).
- scsi: mpi3mr: Fix duplicate device entries when scanning
  through sysfs (git-fixes).
- commit 571aab7
* Tue Dec 14 2021 dmueller@suse.com
- kernel-obs-build: include the preferred kernel parameters
  Currently the Open Build Service hardcodes the kernel boot parameters
  globally. Recently functionality was added to control the parameters
  by the kernel-obs-build package, so make use of that. parameters here
  will overwrite what is used by OBS otherwise.
- commit a631240
* Tue Dec 14 2021 oneukum@suse.com
- blacklist.conf: duplicate
- commit 9669784
* Tue Dec 14 2021 oneukum@suse.com
- blacklist.conf: this is a feature, not a bug fix
- commit e867f95
* Tue Dec 14 2021 oneukum@suse.com
- blacklist.conf: breaks kABI
- commit 8b90f7c
* Tue Dec 14 2021 oneukum@suse.com
- net: cdc_ncm: Allow for dwNtbOutMaxSize to be unset or zero
  (git-fixes).
- commit 2b7a551
* Tue Dec 14 2021 dwagner@suse.de
- Update patches.suse/qla2xxx-synchronize-rport-dev_loss_tmo-setting.patch (bsc#1189158)
- commit bf246e6
* Tue Dec 14 2021 iivanov@suse.de
- ARM: dts: imx6q-dhcom: Fix ethernet reset time properties (git-fixes)
- commit cff82d0
* Tue Dec 14 2021 iivanov@suse.de
- ARM: dts: at91: sama5d4: fix pinctrl muxing (git-fixes)
- commit a7ab48f
* Tue Dec 14 2021 iivanov@suse.de
- ARM: dts: exynos: fix PWM LED max brightness on Odroid XU4 (git-fixes)
- commit b28eb93
* Tue Dec 14 2021 iivanov@suse.de
- ARM: dts: exynos: fix PWM LED max brightness on Odroid HC1 (git-fixes)
- commit 4640950
* Tue Dec 14 2021 iivanov@suse.de
- ARM: dts: exynos: fix PWM LED max brightness on Odroid XU/XU3 (git-fixes)
- commit 07a7105
* Tue Dec 14 2021 iivanov@suse.de
- ARM: dts: r8a7779, marzen: Fix DU clock names (git-fixes)
- commit fb3d156
* Tue Dec 14 2021 osalvador@suse.de
- Rename colliding patches before the next SLE15-SP2 -> SLE15-SP3 merge
- commit fc7ecfa
* Mon Dec 13 2021 ematsumiya@suse.de
- cifs: modefromsid: write mode ACE first (bsc#1164565).
- commit 6f413fc
* Mon Dec 13 2021 ematsumiya@suse.de
- smb3: add missing worker function for SMB3 change notify
  (bsc#1164565).
- commit 7dfec0e
* Mon Dec 13 2021 ematsumiya@suse.de
- cifs: clarify comment about timestamp granularity for old
  servers (bsc#1192606).
- commit e302b8e
* Mon Dec 13 2021 ematsumiya@suse.de
- cifs: add shutdown support (bsc#1192606).
- commit 45b0629
* Mon Dec 13 2021 ematsumiya@suse.de
- fs/cifs: Fix resource leak (bsc#1192606).
- commit 435efab
* Mon Dec 13 2021 ematsumiya@suse.de
- SMB3: incorrect file id in requests compounded with open
  (bsc#1192606).
- commit 7138acd
* Mon Dec 13 2021 lduncan@suse.com
- scsi: mpt3sas: Fix system going into read-only mode (git-fixes).
- scsi: iscsi: Adjust iface sysfs attr detection (git-fixes).
- commit 7179a79
* Mon Dec 13 2021 ematsumiya@suse.de
- cifs: fix check of dfs interlinks (bsc#1185902).
- commit 243e364
* Mon Dec 13 2021 lduncan@suse.com
- scsi: mpt3sas: Fix kernel panic during drive powercycle test
  (git-fixes).
- commit 57e2087
* Mon Dec 13 2021 tbogendoerfer@suse.de
- net: linkwatch: fix failure to restore device state across
  suspend/resume (bsc#1192511).
- commit da353d0
* Mon Dec 13 2021 oneukum@suse.com
- usb: chipidea: ci_hdrc_imx: fix potential error pointer
  dereference in probe (git-fixes).
- commit 9219d9f
* Mon Dec 13 2021 ohering@suse.de
- net: mana: Fix memory leak in mana_hwc_create_wq (jsc#SLE-18779,
  bsc#1185726).
- commit dc924dc
* Mon Dec 13 2021 ohering@suse.de
- net: mana: Fix spelling mistake "calledd" -> "called"
  (jsc#SLE-18779, bsc#1185726).
- commit 171413e
* Mon Dec 13 2021 ohering@suse.de
- net: mana: Support hibernation and kexec (jsc#SLE-18779,
  bsc#1185726).
- commit ab32809
* Mon Dec 13 2021 ohering@suse.de
- net: mana: Improve the HWC error handling (jsc#SLE-18779,
  bsc#1185726).
- commit 0f23087
* Mon Dec 13 2021 ohering@suse.de
- net: mana: Fix the netdev_err()'s vPort argument in
  mana_init_port() (jsc#SLE-18779, bsc#1185726).
- commit 0f3038d
* Mon Dec 13 2021 ohering@suse.de
- net: mana: Allow setting the number of queues while the NIC
  is down (jsc#SLE-18779, bsc#1185726).
- commit 9e016ed
* Mon Dec 13 2021 ohering@suse.de
- net: mana: Use kcalloc() instead of kzalloc() (jsc#SLE-18779,
  bsc#1185726).
- commit dc3817d
* Mon Dec 13 2021 dmueller@suse.com
- kernel-obs-build: inform build service about virtio-serial
  Inform the build worker code that this kernel supports virtio-serial,
  which improves performance and relability of logging.
- commit 301a3a7
* Mon Dec 13 2021 dmueller@suse.com
- rpm/*.spec.in: use buildroot macro instead of env variable
  The RPM_BUILD_ROOT variable is considered deprecated over
  a buildroot macro. future proof the spec files.
- commit e2f6026
* Sun Dec 12 2021 martin.wilck@suse.com
- Bluetooth: btrtl: Refine the ic_id_table for clearer and more
  regular (bsc#1193655).
- commit 5fc0c7f
* Sat Dec 11 2021 martin.wilck@suse.com
- Bbluetooth: btusb: Add another Bluetooth part for Realtek 8852AE
  (bsc#1193655).
- commit d23fcbd
* Sat Dec 11 2021 martin.wilck@suse.com
- Bluetooth: Add additional Bluetooth part for Realtek 8852AE
  (bsc#1193655).
- commit 74054a3
* Sat Dec 11 2021 martin.wilck@suse.com
- Bluetooth: btusb: Add the more support IDs for Realtek RTL8822CE
  (bsc#1193655).
- commit 976fe83
* Sat Dec 11 2021 martin.wilck@suse.com
- Bluetooth: btusb: Add the new support ID for Realtek RTL8852A
  (bsc#1193655).
- commit e2de704
* Sat Dec 11 2021 martin.wilck@suse.com
- Bluetooth: btusb: btrtl: Add support for RTL8852A
  (bsc#1193655).
  Refresh
  patches.suse/Bluetooth-Add-a-new-USB-ID-for-RTL8822CE.patch.
- commit 1f6a020
* Fri Dec 10 2021 tbogendoerfer@suse.de
- ice: avoid bpf_prog refcount underflow (jsc#SLE-7926).
- net: hns3: remove check VF uc mac exist when set by PF
  (bsc#1154353).
- ice: Fix not stopping Tx queues for VFs (jsc#SLE-7926).
- net: hns3: fix misuse vf id and vport id in some logs
  (bsc#1154353).
- net: hns3: change affinity_mask to numa node range
  (bsc#1154353).
- commit 5fbb3a3
* Fri Dec 10 2021 dwagner@suse.de
- scsi: lpfc: Fix non-recovery of remote ports following an
  unsolicited LOGO (bsc#1189126).
- commit 96fe76d
* Fri Dec 10 2021 ykaukab@suse.de
- blacklist.conf: add RK3399 build fixes
- commit c24ec31
* Wed Dec  8 2021 tonyj@suse.de
- perf/x86/vlbr: Add c->flags to vlbr event constraints
  (git-fixes).
- perf/x86/intel: Fix unchecked MSR access error caused by
  VLBR_EVENT (git-fixes).
- commit 4672585
* Wed Dec  8 2021 bp@suse.de
- x86/xen: Add xenpv_restore_regs_and_return_to_usermode()
  (bsc#1152489).
- commit b35a237
* Wed Dec  8 2021 tonyj@suse.de
- perf/x86/intel/uncore: Fix Intel ICX IIO event constraints
  (git-fixes).
- perf/x86/intel/uncore: Support extra IMC channel on Ice Lake
  server (git-fixes).
- perf/x86/intel/uncore: Fix M2M event umask for Ice Lake server
  (git-fixes).
- perf/x86/intel/uncore: Fix the scale of the IMC free-running
  events (git-fixes).
- perf: Correctly handle failed perf_get_aux_event() (git-fixes).
- commit 3214492
* Wed Dec  8 2021 pjakobsson@suse.de
- drm/msm/a6xx: Allocate enough space for GMU registers
  (git-fixes).
- commit a2af3ce
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: gemini-rut1xx: remove duplicate ethernet node (git-fixes)
- commit cd23dfc
* Wed Dec  8 2021 iivanov@suse.de
- ARM: exynos: add missing of_node_put for loop iteration (git-fixes)
- commit 9fec7bf
* Wed Dec  8 2021 iivanov@suse.de
- ARM: 9091/1: Revert "mm: qsd8x50: Fix incorrect permission faults" (git-fixes)
- commit cc97587
* Wed Dec  8 2021 iivanov@suse.de
- ARM: 9081/1: fix gcc-10 thumb2-kernel regression (git-fixes)
- commit 9fd71ed
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: imx: emcon-avari: Fix nxp,pca8574 #gpio-cells (git-fixes)
- commit e361720
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: imx7d-pico: Fix the 'tuning-step' property (git-fixes)
- commit 39de4e4
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: imx7d-meerkat96: Fix the 'tuning-step' property (git-fixes)
- commit 2108be4
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: imx6q-dhcom: Add PU,VDD1P1,VDD2P5 regulators (git-fixes)
- commit 51106d9
* Wed Dec  8 2021 iivanov@suse.de
- ARM: 9064/1: hw_breakpoint: Do not directly check the event's (git-fixes)
- commit 8a73a55
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: imx6dl-yapp4: Fix RGMII connection to QCA8334 switch (git-fixes)
- commit 9dccbbe
* Wed Dec  8 2021 bp@suse.de
- x86/entry: Add a fence for kernel entry SWAPGS in
  paranoid_entry() (bsc#1178134).
- commit c461123
* Wed Dec  8 2021 iivanov@suse.de
- blacklist.conf: ("ARM: Qualify enabling of swiotlb_init()")
- commit 3a03503
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: uniphier: Change phy-mode to RGMII-ID to enable delay pins (git-fixes)
- commit c4443e6
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: correct PMIC interrupt trigger level on Snow (git-fixes)
- commit 0989312
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: correct PMIC interrupt trigger level on SMDK5250 (git-fixes)
- commit b1ce2e7
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: correct PMIC interrupt trigger level on Odroid X/U3 (git-fixes)
- commit efd5a9f
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: correct PMIC interrupt trigger level on Midas (git-fixes)
- commit 98458fd
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: correct MUIC interrupt trigger level on Midas (git-fixes)
- commit 35f11a7
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: correct fuel gauge interrupt trigger level on Midas (git-fixes)
- commit d659cd8
* Wed Dec  8 2021 iivanov@suse.de
- ARM: 9071/1: uprobes: Don't hook on thumb instructions (git-fixes)
- commit 9bc79c0
* Wed Dec  8 2021 iivanov@suse.de
- ARM: footbridge: fix PCI interrupt mapping (git-fixes)
- commit f0751f6
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: turris-omnia: configure LED[2]/INTn pin as interrupt pin (git-fixes)
- commit 76d939a
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: imx6: pbab01: Set vmmc supply for both SD interfaces (git-fixes)
- commit cf71c65
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: at91-sama5d27_som1: fix phy address to 7 (git-fixes)
- commit d08c1a8
* Wed Dec  8 2021 iivanov@suse.de
- ARM: 9046/1: decompressor: Do not clear SCTLR.nTLSMD for ARMv7+ cores (git-fixes)
- commit 54e3c21
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: correct PMIC interrupt trigger level on Odroid XU3 (git-fixes)
- commit ff66c7e
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: correct PMIC interrupt trigger level on Arndale (git-fixes)
- commit f75be8b
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: correct PMIC interrupt trigger level on Spring (git-fixes)
- commit 55a4d6f
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: correct PMIC interrupt trigger level on Rinato (git-fixes)
- commit 55c22ee
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: correct PMIC interrupt trigger level on Monk (git-fixes)
- commit 0c032b5
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: correct PMIC interrupt trigger level on Artik 5 (git-fixes)
- commit 76998ea
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: armada388-helios4: assign pinctrl to each fan (git-fixes)
- commit 022b373
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: armada388-helios4: assign pinctrl to LEDs (git-fixes)
- commit 99c5961
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: Configure missing thermal interrupt for 4430 (git-fixes)
- commit 41b7bae
* Wed Dec  8 2021 iivanov@suse.de
- blacklist.conf: ("ARM: s3c: fix fiq for clang IAS")
- commit 6ccea05
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: sun7i: a20: bananapro: Fix ethernet phy-mode (git-fixes)
- commit 9b80745
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: lpc32xx: Revert set default clock rate of HCLK PLL (git-fixes)
- commit 8b86722
* Wed Dec  8 2021 iivanov@suse.de
- ARM: imx: build suspend-imx6.S with arm instruction set (git-fixes)
- commit ec1774b
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: imx6qdl-gw52xx: fix duplicate regulator naming (git-fixes)
- commit 9bd1841
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: imx6qdl-kontron-samx6i: fix i2c_lcd/cam default status (git-fixes)
- commit 5590e0e
* Wed Dec  8 2021 iivanov@suse.de
- ARM: OMAP2+: omap_device: fix idling of devices during probe (git-fixes)
- commit 750c3a4
* Wed Dec  8 2021 iivanov@suse.de
- ARM: p2v: fix handling of LPAE translation in BE mode (git-fixes)
- commit 9b258e6
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: aspeed: tiogapass: Remove vuart (git-fixes)
- commit 3cf3bd7
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: aspeed: s2600wf: Fix VGA memory region location (git-fixes)
- commit dac825a
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: meson: fix PHY deassert timing requirements (git-fixes)
- commit ca1a6a8
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: at91: sama5d2: fix CAN message ram offset and size (git-fixes)
- commit ac20b20
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: at91: sama5d2: map securam as device (git-fixes)
- commit 5e0e26a
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: at91: at91sam9rl: fix ADC triggers (git-fixes)
- commit d32253c
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: turris-omnia: add SFP node (git-fixes)
- commit 264fa55
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: turris-omnia: describe switch interrupt (git-fixes)
- commit 8c11719
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: turris-omnia: add comphy handle to eth2 (git-fixes)
- commit 45dd6a7
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: turris-omnia: enable HW buffer management (git-fixes)
- commit 8c11cde
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: Remove non-existent i2c1 from 98dx3236 (git-fixes)
- commit bb3a041
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: at91: sama5d3_xplained: add pincontrol for USB Host (git-fixes)
- commit 4b9245d
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: at91: sama5d4_xplained: add pincontrol for USB Host (git-fixes)
- commit 24a6157
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: pandaboard: fix pinmux for gpio user button of Pandaboard (git-fixes)
- commit 0d31715
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: fix USB 3.0 pins supply being turned off on Odroid (git-fixes)
- commit 6c723a3
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: fix USB 3.0 VBUS control and over-current pins on (git-fixes)
- commit 4c799c5
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: exynos: fix roles of USB 3.0 ports on Odroid XU (git-fixes)
- commit 8a89ac4
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: imx6qdl-kontron-samx6i: fix I2C_PM scl pin (git-fixes)
- commit ed85b4a
* Wed Dec  8 2021 dwagner@suse.de
- nvme-multipath: Skip not ready namespaces when revalidating paths (bsc#1191793 bsc#1192507 bsc#1192969).
- commit 37f8e3a
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: sun7i: pcduino3-nano: enable RGMII RX/TX delay on PHY (git-fixes)
- commit eaab047
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: sun8i: v3s: fix GIC node memory range (git-fixes)
- commit 478b5c3
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: sun8i: v40: bananapi-m2-berry: Fix ethernet node (git-fixes)
- commit 1c3142f
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: sun8i: r40: bananapi-m2-berry: Fix dcdc1 regulator (git-fixes)
- commit dc84d7f
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: sun7i: bananapi: Enable RGMII RX/TX delay on Ethernet PHY (git-fixes)
- commit 181dea6
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: dra76x: m_can: fix order of clocks (git-fixes)
- commit 43c7beb
* Wed Dec  8 2021 iivanov@suse.de
- ARM: dts: imx50-evk: Fix the chip select 1 IOMUX (git-fixes)
- commit 87a64a2
* Wed Dec  8 2021 iivanov@suse.de
- arm: dts: imx6qdl-udoo: fix rgmii phy-mode for ksz9031 phy (git-fixes)
- commit 58f3f8d
* Wed Dec  8 2021 oneukum@suse.com
- usb: dwc2: hcd_queue: Fix use of floating point literal
  (git-fixes).
- commit 9a72c31
* Tue Dec  7 2021 oneukum@suse.com
- net: usb: lan78xx: lan78xx_phy_init(): use PHY_POLL instead of
  "0" if no IRQ is available (git-fixes).
- commit b87f8ef
* Tue Dec  7 2021 dwagner@suse.de
- lpfc: Reintroduce old IRQ probe logic (bsc#1183897).
- commit aae012d
* Tue Dec  7 2021 iivanov@suse.de
- ARM: dts: sunxi: bananapi-m2-plus: Enable RGMII RX/TX delay on (git-fixes)
- commit 2016228
* Tue Dec  7 2021 iivanov@suse.de
- ARM: dts: sun9i: Enable both RGMII RX/TX delay on Ethernet PHY (git-fixes)
- commit 1a093ea
* Tue Dec  7 2021 iivanov@suse.de
- ARM: dts: sun8i: a83t: Enable both RGMII RX/TX delay on Ethernet PHY (git-fixes)
- commit 531deee
* Tue Dec  7 2021 iivanov@suse.de
- ARM: dts: sun8i: h3: orangepi-plus2e: Enable RGMII RX/TX delay on (git-fixes)
- commit 88a897f
* Tue Dec  7 2021 iivanov@suse.de
- ARM: dts: sun7i: bananapi-m1-plus: Enable RGMII RX/TX delay on (git-fixes)
- commit 87e604e
* Tue Dec  7 2021 iivanov@suse.de
- ARM: dts: sun7i: cubietruck: Enable RGMII RX/TX delay on Ethernet PHY (git-fixes)
- commit a152164
* Tue Dec  7 2021 iivanov@suse.de
- ARM: dts: sun6i: a31-hummingbird: Enable RGMII RX/TX delay on (git-fixes)
- commit 6b97887
* Tue Dec  7 2021 iivanov@suse.de
- Revert "arm: sun8i: orangepi-pc-plus: Set EMAC activity LEDs to (git-fixes)
- commit 5efc234
* Tue Dec  7 2021 iivanov@suse.de
- ARM: dts: sun8i: r40: bananapi-m2-ultra: Fix ethernet node (git-fixes)
- commit 3f47a53
* Tue Dec  7 2021 iivanov@suse.de
- blacklist.conf: ("ARM: dts: stm32: Enable thermal sensor support on stm32mp15xx-dhcor")
- commit c1ed2bb
* Tue Dec  7 2021 iivanov@suse.de
- ARM: 9019/1: kprobes: Avoid fortify_panic() when copying optprobe (git-fixes)
- commit 1123941
* Tue Dec  7 2021 iivanov@suse.de
- blacklist.conf: Same fix was already added
- commit b659a50
* Tue Dec  7 2021 iivanov@suse.de
- ARM: mvebu: drop pointless check for coherency_base (git-fixes)
- commit 8b93ab4
* Tue Dec  7 2021 iivanov@suse.de
- ARM: dts: owl-s500: Fix incorrect PPI interrupt specifiers (git-fixes)
- commit 441e98d
* Tue Dec  7 2021 iivanov@suse.de
- ARM: dts: meson8: remove two invalid interrupt lines from the GPU (git-fixes)
- commit 5979072
* Tue Dec  7 2021 iivanov@suse.de
- arm: dts: mt7623: add missing pause for switchport (git-fixes)
- commit 96b3f01
* Tue Dec  7 2021 iivanov@suse.de
- ARM: dts: imx6sl: fix rng node (git-fixes)
- commit 39ee2e5
* Tue Dec  7 2021 iivanov@suse.de
- blacklist.conf: ("ARM: imx: Place "Cortex-A/Cortex-M" comment in the correct location")
- commit 3f47f6f
* Tue Dec  7 2021 iivanov@suse.de
- ARM: samsung: fix PM debug build with DEBUG_LL but !MMU (git-fixes)
- commit 18aa25f
* Tue Dec  7 2021 iivanov@suse.de
- ARM: at91: pm: of_node_put() after its usage (git-fixes)
- commit 1722a9b
* Tue Dec  7 2021 iivanov@suse.de
- ARM: samsung: don't build plat/pm-common for Exynos (git-fixes)
- commit 7b4ccbe
* Tue Dec  7 2021 iivanov@suse.de
- ARM: s3c24xx: fix mmc gpio lookup tables (git-fixes)
- commit 7a7156c
* Tue Dec  7 2021 iivanov@suse.de
- ARM: s3c24xx: fix missing system reset (git-fixes)
- commit e7eaa12
* Tue Dec  7 2021 iivanov@suse.de
- ARM: dts: am437x-l4: fix typo in can@0 node (git-fixes)
- commit 7cece2c
* Tue Dec  7 2021 ptesarik@suse.cz
- kabi: hide changes to struct uv_info (git-fixes).
- commit 1dd17d6
* Mon Dec  6 2021 tiwai@suse.de
- usb: typec: tcpm: Wait in SNK_DEBOUNCED until disconnect
  (git-fixes).
- serial: 8250_pci: rewrite pericom_do_set_divisor() (git-fixes).
- serial: 8250_pci: Fix ACCES entries in pci_serial_quirks array
  (git-fixes).
- tty: serial: msm_serial: Deactivate RX DMA for polling support
  (git-fixes).
- serial: core: fix transmit-buffer reset and memleak (git-fixes).
- i2c: stm32f7: stop dma transfer in case of NACK (git-fixes).
- i2c: stm32f7: recover the bus on access timeout (git-fixes).
- i2c: stm32f7: flush TX FIFO upon transfer errors (git-fixes).
- i2c: cbus-gpio: set atomic transfer callback (git-fixes).
- drm/msm: Do hw_init() before capturing GPU state (git-fixes).
- rt2x00: do not mark device gone on EPROTO errors during start
  (git-fixes).
- net: usb: lan78xx: lan78xx_phy_init(): use PHY_POLL instead of
  "0" if no IRQ is available (git-fixes).
- USB: serial: option: add Fibocom FM101-GL variants (git-fixes).
- USB: serial: option: add Telit LE910S1 0x9200 composition
  (git-fixes).
- ALSA: ctxfi: Fix out-of-range access (git-fixes).
- commit bab211f
* Mon Dec  6 2021 tiwai@suse.de
- xhci: Fix commad ring abort, write all 64 bits to CRCR register
  (bsc#1192569).
- commit 9d2b3aa
* Mon Dec  6 2021 mbenes@suse.cz
- tracing: Fix pid filtering when triggers are attached
  (git-fixes).
- commit 8872e72
* Mon Dec  6 2021 mbenes@suse.cz
- blacklist.conf: 27ff768fa21c ("tracing: Test the 'Do not trace this pid' case in create event")
  Not applicable. SLE15-SP2 does not have no_pid_list.
- commit a013b01
* Mon Dec  6 2021 mbenes@suse.cz
- tracing: Check pid filtering when creating events (git-fixes).
- commit 44dc77e
* Mon Dec  6 2021 tbogendoerfer@suse.de
- atlantic: Fix OOB read and write in hw_atl_utils_fw_rpc_wait
  (bsc#1192845 CVE-2021-43975).
- commit 6156c39
* Mon Dec  6 2021 ptesarik@suse.cz
- s390/uv: fully validate the VMA before calling follow_page()
  (git-fixes).
- commit 3c6388f
* Mon Dec  6 2021 ptesarik@suse.cz
- s390: mm: Fix secure storage access exception handling
  (git-fixes).
- commit 0d49ecf
* Mon Dec  6 2021 oneukum@suse.com
- usb: typec: tcpm: Wait in SNK_DEBOUNCED until disconnect
  (git-fixes).
- commit d4d7214
* Mon Dec  6 2021 oneukum@suse.com
- xhci: Fix commad ring abort, write all 64 bits to CRCR register
  (git-fixes).
- commit 39dcce2
* Mon Dec  6 2021 tiwai@suse.de
- Move upstreamed USB fix into sorted section
- commit 8151472
* Sat Dec  4 2021 colyli@suse.de
- kABI: dm: fix deadlock when swapping to encrypted device
  (bsc#1186332).
- md/raid10: Remove unnecessary rcu_dereference in
  raid10_handle_discard (bsc#1192320).
- dm raid: remove unnecessary discard limits for raid0 and raid10
  (bsc#1192320).
- md/raid10: improve discard request for far layout (bsc#1192320).
- md/raid10: improve raid10 discard request (bsc#1192320).
- md/raid10: pull the code that wait for blocked dev into one
  function (bsc#1192320).
- md/raid10: extend r10bio devs to raid disks (bsc#1192320).
- md: add md_submit_discard_bio() for submitting discard bio
  (bsc#1192320).
- dm: fix deadlock when swapping to encrypted device
  (bsc#1186332).
- md/raid10: initialize r10_bio->read_slot before use
  (bsc#1192320).
- commit 5a81276
* Fri Dec  3 2021 bp@suse.de
- x86/mpx: Disable MPX for 32-bit userland (bsc#1193139).
- commit cdba19a
* Fri Dec  3 2021 msuchanek@suse.de
- ibmvnic: drop bad optimization in reuse_tx_pools() (bsc#1193349
  ltc#195568).
- ibmvnic: drop bad optimization in reuse_rx_pools() (bsc#1193349
  ltc#195568).
- commit 718e27a
* Fri Dec  3 2021 tiwai@suse.de
- xhci: Fix commad ring abort, write all 64 bits to CRCR register
  (bsc#1192569).
- commit b70b7a9
* Thu Dec  2 2021 lhenriques@suse.de
- fuse: release pipe buf after last use (bsc#1193318).
- commit b7ec5ee
* Thu Dec  2 2021 osalvador@suse.de
- Rename colliding patches before the next SLE15-SP2 -> SLE15-SP3 merge
- commit 99db4af
* Thu Dec  2 2021 jslaby@suse.cz
- rpm/kernel-binary.spec.in: don't strip vmlinux again (bsc#1193306)
  After usrmerge, vmlinux file is not named vmlinux-<version>, but simply
  vmlinux. And this is not reflected in STRIP_KEEP_SYMTAB we set.
  So fix this by removing the dash...
- commit 83af88d
* Wed Dec  1 2021 lduncan@suse.com
- Blacklist SCSI commit that breaks kABI (git-fixes)
- commit 43a023a
* Wed Dec  1 2021 mkubecek@suse.cz
- series.conf: cleanup
- drop superfluous empty lines
- commit 72e63ac
* Wed Dec  1 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline and drop duplicate References tag:
  - patches.suse/hugetlbfs-flush-TLBs-correctly-after-huge_pmd_unshar.patch
- commit e2f354b
* Wed Dec  1 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  - patches.suse/NFS-Don-t-set-NFS_INO_DATA_INVAL_DEFER-and-NFS_INO_I.patch
  - patches.suse/NFS-Fix-deadlocks-in-nfs_scan_commit_list.patch
  - patches.suse/NFS-Fix-up-commit-deadlocks.patch
  - patches.suse/NFSv4-Fix-a-regression-in-nfs_set_open_stateid_locke.patch
  - patches.suse/md-fix-a-lock-order-reversal-in-md_alloc.patch
  - patches.suse/nfsd-don-t-alloc-under-spinlock-in-rpc_parse_scope_i.patch
  - patches.suse/nfsd-fix-error-handling-of-register_pernet_subsys-in.patch
  - patches.suse/nfsd4-Handle-the-NFSv4-READDIR-dircount-hint-being-z.patch
  - patches.suse/pnfs-flexfiles-Fix-misplaced-barrier-in-nfs4_ff_layo.patch
- commit baf4f8d
* Wed Dec  1 2021 iivanov@suse.de
- ARM: dts: sun8i: r40: bananapi-m2-ultra: Fix dcdc1 regulator (git-fixes)
- commit 85cbd0e
* Wed Dec  1 2021 iivanov@suse.de
- ARM: 9007/1: l2c: fix prefetch bits init in L2X0_AUX_CTRL using DT (git-fixes)
- commit 365e0a3
* Wed Dec  1 2021 iivanov@suse.de
- ARM: dts: BCM5301X: Fixed QSPI compatible string (git-fixes)
- commit 653ed7e
* Wed Dec  1 2021 iivanov@suse.de
- ARM: dts: NSP: Fixed QSPI compatible string (git-fixes)
- commit 6bfe2b5
* Wed Dec  1 2021 iivanov@suse.de
- ARM: dts: bcm: HR2: Fixed QSPI compatible string (git-fixes)
- commit 2da4f3c
* Wed Dec  1 2021 iivanov@suse.de
- ARM: dts: imx6sx: fix the pad QSPI1B_SCLK mux mode for uart3 (git-fixes)
- commit 3bc0dcb
* Wed Dec  1 2021 iivanov@suse.de
- ARM: dts: imx6sx: Add missing UART RTS/CTS pins mux (git-fixes)
- commit 9eeb7d3
* Wed Dec  1 2021 iivanov@suse.de
- ARM: dts: imx6sx: Improve UART pins macro defines (git-fixes)
- commit d0779ee
* Wed Dec  1 2021 iivanov@suse.de
- ARM: dts: logicpd-som-lv-baseboard: Fix missing video (git-fixes)
- commit de0d442
* Wed Dec  1 2021 iivanov@suse.de
- ARM: dts: logicpd-som-lv-baseboard: Fix broken audio (git-fixes)
- commit d1cc45c
* Wed Dec  1 2021 iivanov@suse.de
- blacklist.conf: ("ARM: dts: stm32: fix uart7_pins_a comments in stm32mp15-pinctrl")
  Fix comment in a devicetree file.
- commit 4d3a412
* Wed Dec  1 2021 tbogendoerfer@suse.de
- Update patches.suse/ixgbe-fix-large-MTU-request-from-VF.patch
  (bsc#1192877 CVE-2021-33098).
  Changed reference to CVE bug.
- commit 964f375
* Wed Dec  1 2021 iivanov@suse.de
- blacklist.conf: ("ARM: dts: sunxi: bananapi-m2-plus-v1.2: Add regulator supply to all")
  Unsupported platform
- commit a16ce64
* Wed Dec  1 2021 iivanov@suse.de
- blacklist.conf: ("ARM: dts: renesas: Fix SD Card/eMMC interface device node names")
  Cosmetic devicetree nodes name change
- commit 7ad6f49
* Wed Dec  1 2021 iivanov@suse.de
- ARM: dts: socfpga: Align L2 cache-controller nodename with dtschema (git-fixes)
- commit b39464e
* Wed Dec  1 2021 iivanov@suse.de
- blacklist.conf: ("ARM: dts: stm32: fix a typo for DAC io-channel-cells on stm32mp15")
- commit ad658c1
* Wed Dec  1 2021 iivanov@suse.de
- blacklist.conf: ("ARM: uaccess: fix DACR mismatch with nested exceptions")
  ARM cpus v3, v4, v4T, v5 are not supported
- commit 78b5a5d
* Wed Dec  1 2021 tiwai@suse.de
- mwifiex: Fix skb_over_panic in mwifiex_usb_recv()
  (CVE-2021-43976 bsc#1192847).
- commit 1075cc3
* Wed Dec  1 2021 dbueso@suse.de
- blacklist.conf: 85b6d24646e4 ("shm: extend forced shm destroy to support objects from several IPC nses")
  Unfortunately this breaks kABI and presents significant risk for
  addressing a theoretical issue.
- commit e55a163
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: logicpd-torpedo-baseboard: Fix broken audio (git-fixes)
- commit 8ec6f19
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: vfxxx: Add syscon compatible with OCOTP (git-fixes)
- commit 6f5837f
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: imx7ulp: Correct gpio ranges (git-fixes)
- commit 3f5621e
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: ls1021a: fix QuadSPI-memory reg range (git-fixes)
- commit 6c84d7b
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: socfpga: fix register entry for timer3 on Arria10 (git-fixes)
- commit 495045e
* Tue Nov 30 2021 iivanov@suse.de
- ARM: socfpga: PM: add missing put_device() call in socfpga_setup_ocram_self_refresh() (git-fixes)
- commit e76b97f
* Tue Nov 30 2021 iivanov@suse.de
- ARM: at91: pm: add missing put_device() call in at91_pm_sram_init() (git-fixes)
- commit d5fa0dd
* Tue Nov 30 2021 iivanov@suse.de
- ARM: exynos: MCPM: Restore big.LITTLE cpuidle support (git-fixes)
- commit dc169bf
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: at91: sama5d2_xplained: classd: pull-down the R1 and R3 lines (git-fixes)
- commit d09ddcf
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: sunxi: bananapi-m2-plus-v1.2: Fix CPU supply voltages (git-fixes)
- commit b837795
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: gose: Fix ports node name for adv7612 (git-fixes)
- commit e9fee74
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: gose: Fix ports node name for adv7180 (git-fixes)
- commit 40b6417
* Tue Nov 30 2021 iivanov@suse.de
- ARM: 8986/1: hw_breakpoint: Don't invoke overflow handler on uaccess watchpoints (git-fixes)
- commit 8ad414c
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: armada-38x: fix NETA lockup when repeatedly switching speeds (git-fixes)
- commit 40f3f7f
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: imx6qdl-icore: Fix OTG_ID pin and sdcard detect (git-fixes)
- commit 0fbc45e
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: imx6sx-sabreauto: Fix the phy-mode on fec2 (git-fixes)
- commit f3253e8
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: imx6sx-sdb: Fix the phy-mode on fec2 (git-fixes)
- commit c6689bd
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts sunxi: Relax a bit the CMA pool allocation range (git-fixes)
- commit d32973c
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: Fix dcan driver probe failed on am437x platform (git-fixes)
- commit c712eb3
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: imx6qdl-gw551x: fix audio SSI (git-fixes)
- commit 8b361c5
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: imx6qdl-gw551x: Do not use 'simple-audio-card,dai-link' (git-fixes)
- commit 2acafcb
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: Fix duovero smsc interrupt for suspend (git-fixes)
- commit f5f5222
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: am335x-pocketbeagle: Fix mmc0 Write Protect (git-fixes)
- commit a210c92
* Tue Nov 30 2021 iivanov@suse.de
- ARM: OMAP2+: Fix legacy mode dss_reset (git-fixes)
- commit 518acf3
* Tue Nov 30 2021 iivanov@suse.de
- ARM: imx5: add missing put_device() call in imx_suspend_alloc_ocram() (git-fixes)
- commit ab8eba4
* Tue Nov 30 2021 iivanov@suse.de
- ARM: bcm: Select ARM_TIMER_SP804 for ARCH_BCM_NSP (git-fixes)
- commit b7c7df8
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: NSP: Correct FA2 mailbox node (git-fixes)
- commit 9479804
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: NSP: Disable PL330 by default, add dma-coherent property (git-fixes)
- commit 4c7d3d5
* Tue Nov 30 2021 iivanov@suse.de
- Revert "ARM: sti: Implement dummy L2 cache's write_sec" (git-fixes)
- commit 29d8881
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: at91: sama5d2_ptc_ek: fix vbus pin (git-fixes)
- commit 159db4e
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: at91: sama5d2_ptc_ek: fix sdmmc0 node description (git-fixes)
- commit dc96655
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: sun8i-h2-plus-bananapi-m2-zero: Fix led polarity (git-fixes)
- commit 240d4e7
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: stm32: fix a typo for DAC io-channel-cells on stm32h743 (git-fixes)
- commit 7258033
* Tue Nov 30 2021 iivanov@suse.de
- ARM: dts: stm32: fix a typo for DAC io-channel-cells on stm32f429 (git-fixes)
- commit 64d852f
* Tue Nov 30 2021 ematsumiya@suse.de
- nvme-pci: add NO APST quirk for Kioxia device (git-fixes).
- commit 8c6d859
* Tue Nov 30 2021 tiwai@suse.de
- PM: hibernate: use correct mode for swsusp_close() (git-fixes).
- commit fef6f6f
* Tue Nov 30 2021 tiwai@suse.de
- xhci: Fix USB 3.1 enumeration issues by increasing roothub
  power-on-good delay (git-fixes).
- zram: off by one in read_block_state() (git-fixes).
- soc/tegra: Fix an error handling path in
  tegra_powergate_power_up() (git-fixes).
- spi: bcm-qspi: Fix missing clk_disable_unprepare() on error
  in bcm_qspi_probe() (git-fixes).
- spi: spl022: fix Microwire full duplex mode (git-fixes).
- zram: fix return value on writeback_store (git-fixes).
- commit 4e28ede
* Tue Nov 30 2021 tiwai@suse.de
- nfc: pn533: Fix double free when pn533_fill_fragment_skbs()
  fails (git-fixes).
- PCI: Add PCI_EXP_DEVCTL_PAYLOAD_* macros (git-fixes).
- PCI: Mark Atheros QCA6174 to avoid bus reset (git-fixes).
- platform/x86: wmi: do not fail if disabling fails (git-fixes).
- PM: hibernate: Get block device exclusively in swsusp_check()
  (git-fixes).
- mwl8k: Fix use-after-free in mwl8k_fw_state_machine()
  (git-fixes).
- r8169: Add device 10ec:8162 to driver r8169 (git-fixes).
- reset: socfpga: add empty driver allowing consumers to probe
  (git-fixes).
- commit 864c87f
* Tue Nov 30 2021 tiwai@suse.de
- mtd: core: don't remove debugfs directory if device is in use
  (git-fixes).
- mwifiex: Read a PCI register after writing the TX ring write
  pointer (git-fixes).
- mwifiex: Properly initialize private structure on interface
  type changes (git-fixes).
- mwifiex: Run SET_BSS_MODE when changing from P2P to STATION
  vif-type (git-fixes).
- memstick: r592: Fix a UAF bug when removing the driver
  (git-fixes).
- media: usb: dvd-usb: fix uninit-value bug in
  dibusb_read_eeprom_byte() (git-fixes).
- media: ipu3-imgu: VIDIOC_QUERYCAP: Fix bus_info (git-fixes).
- media: ipu3-imgu: imgu_fmt: Handle properly try (git-fixes).
- mmc: winbond: don't build on M68K (git-fixes).
- commit f93cc37
* Tue Nov 30 2021 tiwai@suse.de
- media: rcar-csi2: Add checking to rcsi2_start_receiver()
  (git-fixes).
- media: mceusb: return without resubmitting URB in case of
  - EPROTO error (git-fixes).
- media: ir-kbd-i2c: improve responsiveness of hauppauge zilog
  receivers (git-fixes).
- media: imx: set a media_device bus_info string (git-fixes).
- media: s5p-mfc: fix possible null-pointer dereference in
  s5p_mfc_probe() (git-fixes).
- media: uvcvideo: Set unique vdev name based in type (git-fixes).
- media: uvcvideo: Return -EIO for control errors (git-fixes).
- media: uvcvideo: Set capability in s_param (git-fixes).
- media: stm32: Potential NULL pointer dereference in
  dcmi_irq_thread() (git-fixes).
- media: netup_unidvb: handle interrupt properly according to
  the firmware (git-fixes).
- commit 0db8c1e
* Tue Nov 30 2021 tiwai@suse.de
- drm/plane-helper: fix uninitialized variable reference
  (git-fixes).
- Input: iforce - fix control-message timeout (git-fixes).
- i2c: xlr: Fix a resource leak in the error handling path of
  'xlr_i2c_probe()' (git-fixes).
- drm/panel-orientation-quirks: add Valve Steam Deck (git-fixes).
- libata: fix checking of DMA state (git-fixes).
- ipmi: Disable some operations during a panic (git-fixes).
- media: mt9p031: Fix corrupted frame after restarting stream
  (git-fixes).
- lib/xz: Validate the value before assigning it to an enum
  variable (git-fixes).
- lib/xz: Avoid overlapping memcpy() with invalid input with
  in-place decompression (git-fixes).
- commit 40bd6e4
* Tue Nov 30 2021 tiwai@suse.de
- dmaengine: dmaengine_desc_callback_valid(): Check for
  `callback_result` (git-fixes).
- dmaengine: at_xdmac: fix AT_XDMAC_CC_PERID() macro (git-fixes).
- drm: panel-orientation-quirks: Add quirk for the Samsung Galaxy
  Book 10.6 (git-fixes).
- drm: panel-orientation-quirks: Add quirk for KD Kurio Smart
  C15200 2-in-1 (git-fixes).
- drm: panel-orientation-quirks: Update the Lenovo Ideapad D330
  quirk (v2) (git-fixes).
- brcmfmac: Add DMI nvram filename quirk for Cyberbook T116 tablet
  (git-fixes).
- crypto: s5p-sss - Add error handling in s5p_aes_probe()
  (git-fixes).
- crypto: ecc - fix CRYPTO_DEFAULT_RNG dependency (git-fixes).
- drm: panel-orientation-quirks: Add quirk for GPD Win3
  (git-fixes).
- drm: panel-orientation-quirks: Add quirk for Aya Neo 2021
  (git-fixes).
- commit 6b1a3ad
* Tue Nov 30 2021 tiwai@suse.de
- ALSA: hda/realtek: Add quirk for HP EliteBook 840 G7 mute LED
  (git-fixes).
- ALSA: synth: missing check for possible NULL after the call
  to kstrdup (git-fixes).
- ALSA: hda/realtek: Add quirk for ASUS UX550VE (git-fixes).
- ALSA: timer: Unconditionally unlink slave instances, too
  (git-fixes).
- ALSA: hda/realtek: Add a quirk for Acer Spin SP513-54N
  (git-fixes).
- ALSA: timer: Fix use-after-free problem (git-fixes).
- ath10k: fix invalid dma_addr_t token assignment (git-fixes).
- ath: dfs_pattern_detector: Fix possible null-pointer dereference
  in channel_detector_create() (git-fixes).
- ath10k: high latency fixes for beacon buffer (git-fixes).
- Bluetooth: fix use-after-free error in lock_sock_nested()
  (git-fixes).
- commit 3915ea5
* Tue Nov 30 2021 tiwai@suse.de
- ASoC: topology: Add missing rwsem around snd_ctl_remove()
  calls (git-fixes).
- ASoC: qdsp6: q6routing: Conditionally reset FrontEnd Mixer
  (git-fixes).
- PCI/MSI: Deal with devices lying about their MSI mask capability
  (git-fixes).
- ACPI: PMIC: Fix intel_pmic_regs_handler() read accesses
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Clevo PC70HS (git-fixes).
- ALSA: usb-audio: Add registration quirk for JBL Quantum 400
  (git-fixes).
- ACPI: battery: Accept charges over the design capacity as full
  (git-fixes).
- ACPICA: Avoid evaluating methods too early during system resume
  (git-fixes).
- soc/tegra: pmc: Fix imbalanced clock disabling in error code
  path (git-fixes).
- commit ce23462
* Tue Nov 30 2021 tiwai@suse.de
- usb: typec: fusb302: Fix masking of comparator and bc_lvl
  interrupts (git-fixes).
- usb: dwc2: gadget: Fix ISOC flow for elapsed frames (git-fixes).
- drm/vc4: fix error code in vc4_create_object() (git-fixes).
- tty: tty_buffer: Fix the softlockup issue in flush_to_ldisc
  (git-fixes).
- usb-storage: Add compatibility quirk flags for iODD 2531/2541
  (git-fixes).
- usb: xhci: Enable runtime-pm by default on AMD Yellow Carp
  platform (git-fixes).
- usb: host: ohci-tmio: check return value after calling
  platform_get_resource() (git-fixes).
- usb: musb: tusb6010: check return value after calling
  platform_get_resource() (git-fixes).
- commit f36d57f
* Tue Nov 30 2021 tiwai@suse.de
- NFC: reorder the logic in nfc_{un,}register_device (git-fixes).
- Refresh
  patches.suse/NFC-SUSE-specific-brutal-fix-for-runtime-PM.patch.
- commit 176d8d4
* Tue Nov 30 2021 tiwai@suse.de
- drm/amdgpu: fix set scaling mode Full/Full aspect/Center not
  works on vga and dvi connectors (git-fixes).
- drm/nouveau: hdmigv100.c: fix corrupted HDMI Vendor InfoFrame
  (git-fixes).
- platform/x86: hp_accel: Fix an error handling path in
  'lis3lv02d_probe()' (git-fixes).
- NFC: add NCI_UNREG flag to eliminate the race (git-fixes).
- NFC: reorganize the functions in nci_request (git-fixes).
- clk: ingenic: Fix bugs with divided dividers (git-fixes).
- iio: imu: st_lsm6dsx: Avoid potential array overflow in
  st_lsm6dsx_set_odr() (git-fixes).
- mmc: dw_mmc: Dont wait for DRTO on Write RSP error (git-fixes).
- commit 84fae0c
* Tue Nov 30 2021 tiwai@suse.de
- ASoC: DAPM: Cover regression by kctl change notification fix
  (git-fixes).
- cfg80211: call cfg80211_stop_ap when switch from P2P_GO type
  (git-fixes).
- clk: imx: imx6ul: Move csi_sel mux to correct base register
  (git-fixes).
- ASoC: nau8824: Add DMI quirk mechanism for active-high
  jack-detect (git-fixes).
- ALSA: gus: fix null pointer dereference on pointer block
  (git-fixes).
- ALSA: ISA: not for M68K (git-fixes).
- ASoC: SOF: Intel: hda-dai: fix potential locking issue
  (git-fixes).
- ALSA: hda: hdac_ext_stream: fix potential locking issues
  (git-fixes).
- ALSA: hda: hdac_stream: fix potential locking issue in
  snd_hdac_stream_assign() (git-fixes).
- commit 970a05a
* Tue Nov 30 2021 tiwai@suse.de
- Move upstreamed i8042 patch into sorted section
- commit c3e6588
* Tue Nov 30 2021 tbogendoerfer@suse.de
- net/sched: sch_ets: don't peek at classes beyond 'nbands'
  (bsc#1176774).
- mdio: aspeed: Fix "Link is Down" issue (bsc#1176447).
- netfilter: flowtable: fix IPv6 tunnel addr match (bsc#1176447).
- netfilter: ctnetlink: do not erase error code with EINVAL
  (bsc#1176447).
- netfilter: ctnetlink: fix filtering with CTA_TUPLE_REPLY
  (bsc#1176447).
- net/mlx5: E-Switch, return error if encap isn't supported
  (jsc#SLE-15172).
- iavf: Fix for setting queues to 0 (jsc#SLE-12877).
- iavf: Fix return of set the new channel count (jsc#SLE-12877).
- ice: Remove toggling of antispoof for VF trusted promiscuous
  mode (jsc#SLE-12878).
- ice: Fix VF true promiscuous mode (jsc#SLE-12878).
- ethtool: fix ethtool msg len calculation for pause stats
  (jsc#SLE-15075).
- RDMA/bnxt_re: Update statistics counter name (jsc#SLE-16649).
- net: bridge: fix under estimation in br_get_linkxstats_size()
  (bsc#1176447).
- commit ab96379
* Tue Nov 30 2021 jroedel@suse.de
- iommu/amd: Remove iommu_init_ga() (git-fixes).
- iommu/amd: Relocate GAMSup check to early_enable_iommus
  (git-fixes).
- iommu: Check if group is NULL before remove device (git-fixes).
- swiotlb: Fix the type of index (git-fixes).
- commit 8842f17
* Mon Nov 29 2021 pjakobsson@suse.de
- drm/amd/display: Set plane update flags for all planes in reset
  (git-fixes).
- commit 55c8303
* Mon Nov 29 2021 pjakobsson@suse.de
- drm/nouveau/acr: fix a couple NULL vs IS_ERR() checks
  (git-fixes).
- commit 82083eb
* Mon Nov 29 2021 pjakobsson@suse.de
- drm/nouveau/svm: Fix refcount leak bug and missing check
  against null bug (git-fixes).
- commit 8795faa
* Mon Nov 29 2021 pjakobsson@suse.de
- drm/pl111: Actually fix CONFIG_VEXPRESS_CONFIG depends
  (git-fixes).
- commit 199d9e2
* Mon Nov 29 2021 msuchanek@suse.de
- powerpc/paravirt: correct preempt debug splat in
  vcpu_is_preempted() (bsc#1181148 ltc#190702 git-fixes).
- powerpc/paravirt: vcpu_is_preempted() commentary (bsc#1181148
  ltc#190702 git-fixes).
- powerpc: fix unbalanced node refcount in check_kvm_guest()
  (jsc#SLE-15869 jsc#SLE-16321 git-fixes).
- commit 62ae409
* Mon Nov 29 2021 msuchanek@suse.de
- powerpc/pseries: Move some PAPR paravirt functions to their own file
  (bsc#1181148 ltc#190702 git-fixes).
- Refresh patches.suse/powerpc-Fix-build-error-in-paravirt.h.patch.
- Refresh patches.suse/powerpc-paravirt-Use-is_kvm_guest-in-vcpu_is_preempt.patch.
- commit 70c6628
* Mon Nov 29 2021 msuchanek@suse.de
- powerpc/perf: Fix cycles/instructions as PM_CYC/PM_INST_CMPL
  in power10 (jsc#SLE-13513 git-fixes).
- commit 2f92337
* Mon Nov 29 2021 jroedel@suse.de
- iommu/mediatek: Fix out-of-range warning with clang (git-fixes).
- x86/sev: Allow #VC exceptions on the VC2 stack (git-fixes).
- x86/sev: Fix stack type check in vc_switch_off_ist()
  (git-fixes).
- powerpc/iommu: Report the correct most efficient DMA mask for
  PCI devices (git-fixes).
- iommu/vt-d: Update the virtual command related registers
  (git-fixes).
- firmware: qcom_scm: Mark string array const (git-fixes).
- x86/efi: Restore Firmware IDT before calling ExitBootServices()
  (git-fixes).
- iommu/vt-d: Fix incomplete cache flush in
  intel_pasid_tear_down_entry() (git-fixes).
- iommu/vt-d: Consolidate duplicate cache invaliation code
  (git-fixes).
- commit 9d0f833
* Mon Nov 29 2021 lhenriques@suse.de
- block: Fix use-after-free issue accessing struct io_cq
  (bsc#1193042).
- commit fba138d
* Mon Nov 29 2021 tbogendoerfer@suse.de
- ice: fix vsi->txq_map sizing (jsc#SLE-7926).
- igc: Remove phy->type checking (bsc#1193169).
- igc: Remove _I_PHY_ID checking (bsc#1193169).
- commit d98ae3f
* Mon Nov 29 2021 mkoutny@suse.com
- blacklist.conf: Add 78cc316e9583 bpf, cgroup: Assign cgroup in cgroup_sk_alloc when called from interrupt
- commit 0433f83
* Mon Nov 29 2021 osalvador@suse.de
- hugetlbfs: flush TLBs correctly after huge_pmd_unshare
  (bsc#1192946 CVE-2021-4002).
- commit 881e565
* Mon Nov 29 2021 osalvador@suse.de
- tlb: mmu_gather: add tlb_flush_*_range APIs
- commit d3b54bc
* Mon Nov 29 2021 iivanov@suse.de
- ARM: dts: s5pv210: Set keep-power-in-suspend for SDHCI1 on Aries (git-fixes)
- commit 8a979c1
* Sun Nov 28 2021 ematsumiya@suse.de
- vfs: don't parse forbidden flags (bsc#1192606).
- commit b4f81da
* Sun Nov 28 2021 ematsumiya@suse.de
- cifs: update internal version number (bsc#1192606).
- commit 533a712
* Sun Nov 28 2021 ematsumiya@suse.de
- smb2: clarify rc initialization in smb2_reconnect (bsc#1192606).
- commit 78cfa97
* Sun Nov 28 2021 ematsumiya@suse.de
- cifs: populate server_hostname for extra channels (bsc#1192606).
- commit e0e5007
* Sun Nov 28 2021 ematsumiya@suse.de
- cifs: nosharesock should be set on new server (bsc#1192606).
- commit b2eb0d5
* Sun Nov 28 2021 ematsumiya@suse.de
- cifs: introduce cifs_ses_mark_for_reconnect() helper
  (bsc#1192606).
- commit fabb658
* Sun Nov 28 2021 ematsumiya@suse.de
- cifs: protect srv_count with cifs_tcp_ses_lock (bsc#1192606).
- commit f988cac
* Sun Nov 28 2021 ematsumiya@suse.de
- cifs: move debug print out of spinlock (bsc#1192606).
- commit 72a7576
* Sat Nov 27 2021 ematsumiya@suse.de
- smb3: correct smb3 ACL security descriptor (bsc#1192606).
- commit 063d4ac
* Sat Nov 27 2021 ematsumiya@suse.de
- Pass consistent param->type to fs_parse() (bsc#1192606).
  [ ematsumiya:
  - drop the case fs_param_is_fd
  - leave .has_value in fs_parse_result so it doesn't break kabi
  - still set .has_value in fs_parse() for real kabi compatibility
  ]
- commit 079697d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs_debug: use %%pd instead of messing with ->d_name
  (bsc#1192606).
- commit 5879c56
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: do not duplicate fscache cookie for secondary channels
  (bsc#1192606).
- commit b392b26
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: connect individual channel servers to primary channel
  server (bsc#1192606).
- commit 6b9934f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: protect session channel fields with chan_lock
  (bsc#1192606).
- commit cba50eb
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: do not negotiate session if session already exists
  (bsc#1192606).
- commit 37b3456
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: do not setup the fscache_super_cookie until fsinfo
  initialized (bsc#1192606).
- commit dc8e6c9
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix potential use-after-free bugs (bsc#1192606, jsc#SLE-20042).
- commit 7bd3c2c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix memory leak of smb3_fs_context_dup::server_hostname
  (bsc#1192606).
- commit 57f8572
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add additional null check in SMB311_posix_mkdir
  (bsc#1192606).
- commit f7ca16b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: release lock earlier in dequeue_mid error case
  (bsc#1192606).
- commit 6ed3f27
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add additional null check in SMB2_tcon (bsc#1192606).
- commit 7f013cc
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add additional null check in SMB2_open (bsc#1192606).
- commit 5aa4789
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add additional null check in SMB2_ioctl (bsc#1192606).
- commit edaf472
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: remove trivial dfs compile warning (bsc#1192606, jsc#SLE-20042).
- commit 1b9729f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: support nested dfs links over reconnect (bsc#1192606, jsc#SLE-20042).
- commit 977ff65
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: do not error on fsync when readonly (bsc#1192606).
- commit a53c076
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: for compound requests, use open handle if possible
  (bsc#1192606).
- commit 523067d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: set a minimum of 120s for next dns resolution
  (bsc#1192606).
- commit 4683b0e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: split out dfs code from cifs_reconnect() (bsc#1192606, jsc#SLE-20042).
- commit 25eec6a
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: convert list_for_each to entry variant (bsc#1192606, jsc#SLE-20042).
- commit 5c260fb
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: introduce new helper for cifs_reconnect() (bsc#1192606, jsc#SLE-20042).
- commit 8cc2716
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix print of hdr_flags in dfscache_proc_show()
  (bsc#1192606, jsc#SLE-20042).
- commit d8767b8
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: send workstation name during ntlmssp session setup
  (bsc#1192606).
- commit 191b330
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: nosharesock should not share socket with future sessions
  (bsc#1192606).
- commit f8381d3
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add dynamic trace points for socket connection
  (bsc#1192606).
- commit af7190b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Move SMB2_Create definitions to the shared area
  (bsc#1192606).
- commit c39b2e7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Move more definitions into the shared area (bsc#1192606).
- commit 46ad0a8
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: move NEGOTIATE_PROTOCOL definitions out into the common
  area (bsc#1192606).
- commit 471ec2c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Create a new shared file holding smb2 pdu definitions
  (bsc#1192606).
- commit 666d060
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add mount parameter tcpnodelay (bsc#1192606).
- commit 3f1b011
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: To match file servers, make sure the server hostname
  matches (bsc#1192606).
- commit 3d59b5a
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix incorrect check for null pointer in header_assemble
  (bsc#1192606).
- commit 4a5b3cf
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: correct server pointer dereferencing check to be more
  consistent (bsc#1192606).
- commit cf76bd0
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Deal with some warnings from W=1 (bsc#1192606).
- commit f6eec49
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix a sign extension bug (bsc#1192606).
- commit c1600fb
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix incorrect kernel doc comments (bsc#1192606).
- commit ae1bb97
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove pathname for file from SPDX header (bsc#1192606).
- commit 7154307
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: properly invalidate cached root handle when closing it
  (bsc#1192606).
- commit 90012c3
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: move SMB FSCTL definitions to common code (bsc#1192606).
- commit f1d3f93
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: rename cifs_common to smbfs_common (bsc#1192606).
- Add to supported.conf:
  fs/smbfs_common/cifs_arc4
  fs/smbfs_common/cifs_md4
- Update configs to add CONFIG_SMBFS_COMMON=m.
- commit 8eb0a93
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update FSCTL definitions (bsc#1192606).
- commit fe93d4e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Do not leak EDEADLK to dgetents64 for
  STATUS_USER_SESSION_DELETED (bsc#1192606).
- commit 13a1d4e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: cifs_md4 convert to SPDX identifier (bsc#1192606).
- commit 0b7db2c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: create a MD4 module and switch cifs.ko to use it
  (bsc#1192606).
- commit 5c0b1ab
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fork arc4 and create a separate module for it for cifs
  and other users (bsc#1192606).
- commit 08b687d
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix posix extensions mount option (bsc#1192606).
- commit 447f6db
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix wrong release in sess_alloc_buffer() failed path
  (bsc#1192606).
- commit def0bcb
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: create sd context must be a multiple of 8 (bsc#1192606).
- commit 096d6a1
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add missing parsing of backupuid (bsc#1192606).
- commit 36915d3
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: rc uninitialized in one fallocate path (bsc#1192606).
- commit 81628e1
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: fix readpage for large swap cache (bsc#1192606).
- commit 50e1259
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix fallocate when trying to allocate a hole
  (bsc#1192606).
- commit 39a73fc
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Clarify SMB1 code for POSIX delete file (bsc#1192606).
- commit d18ffe8
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Clarify SMB1 code for POSIX Create (bsc#1192606).
- commit 5b09e6b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: support share failover when remounting (bsc#1192606, jsc#SLE-20042).
- commit 870c80c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: only write 64kb at a time when fallocating a small region
  of a file (bsc#1192606).
- commit dfb364b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: do not share tcp sessions of dfs connections
  (bsc#1185902).
- commit 7ce02ee
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3.1.1: fix mount failure to some servers when compression
  enabled (bsc#1192606).
- commit a8dda65
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: added WARN_ON for all the count decrements (bsc#1192606).
- commit 4b0d839
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix missing null session check in mount (bsc#1192606).
- commit 92a9403
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: handle reconnect of tcon when there is no cached dfs
  referral (bsc#1192606).
- commit 4ce8b06
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix the out of range assignment to bit fields in
  parse_server_interfaces (bsc#1192606).
- commit 42c8dc1
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Do not use the original cruid when following DFS links
  for multiuser mounts (bsc#1192606).
- commit 70bcc44
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: use the expiry output of dns_query to schedule next
  resolution (bsc#1192606).
- commit ea7928e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update internal version number (bsc#1192606).
- commit bf989a2
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: prevent NULL deref in cifs_compose_mount_options()
  (bsc#1185902).
- commit ad0c70e
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3.1.1: Add support for negotiating signing algorithm
  (bsc#1192606).
- commit f88f74e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: use helpers when parsing uid/gid mount options and
  validate them (bsc#1192606).
- commit 98e7d9d
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Clarify SMB1 code for POSIX Lock (bsc#1192606).
- commit 44c5e82
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Clarify SMB1 code for rename open file (bsc#1192606).
- commit 5a31de1
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Clarify SMB1 code for delete (bsc#1192606).
- commit a09e98c
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Clarify SMB1 code for SetFileSize (bsc#1192606).
- commit 7d84b0d
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix typo in header file (bsc#1192606).
- commit eec60ea
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Clarify SMB1 code for UnixSetPathInfo (bsc#1192606).
- commit 1df5f2f
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Clarify SMB1 code for UnixCreateSymLink (bsc#1192606).
- commit 7f112a3
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: clarify SMB1 code for UnixCreateHardLink (bsc#1192606).
- commit b93dd21
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: make locking consistent around the server session status
  (bsc#1192606).
- commit 7dc9081
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: prevent races updating CurrentMid (bsc#1192606).
- commit caed321
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix missing spinlock around update to ses->status
  (bsc#1192606).
- commit fae1702
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: missing null pointer check in cifs_mount (bsc#1185902).
- commit 72034e4
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix possible access to uninitialized pointer to DACL
  (bsc#1192606).
- commit 29f7d0b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: missing null check for newinode pointer (bsc#1192606).
- commit d21103a
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove two cases where rc is set unnecessarily in
  sid_to_id (bsc#1192606).
- commit 08acf32
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Add new info level for query directory (bsc#1192606).
- commit 83500f7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix NULL dereference in smb2_check_message()
  (bsc#1192606).
- commit ee58187
* Fri Nov 26 2021 ematsumiya@suse.de
- smbdirect: missing rc checks while waiting for rdma events
  (bsc#1192606).
- commit d6f86c9
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Avoid field over-reading memcpy() (bsc#1192606).
- commit befb9f9
* Fri Nov 26 2021 ematsumiya@suse.de
- smb311: remove dead code for non compounded posix query info
  (bsc#1192606).
- commit eb8a15a
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix SMB1 error path in cifs_get_file_info_unix
  (bsc#1192606).
- commit bdcf5b5
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix uninitialized value for port in witness protocol move
  (bsc#1192606).
- commit b99ff72
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix unneeded null check (bsc#1192606).
- commit 4e78f5e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: use SPDX-Licence-Identifier (bsc#1192606).
- commit fe025f6
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: convert list_for_each to entry variant in cifs_debug.c
  (bsc#1192606).
- commit 8d27424
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: convert list_for_each to entry variant in smb2misc.c
  (bsc#1192606).
- commit bf17685
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: avoid extra calls in posix_info_parse (bsc#1192606).
- commit df5a926
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: retry lookup and readdir when EAGAIN is returned
  (bsc#1192606).
- commit 503d9f4
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: avoid starvation when refreshing dfs cache (bsc#1185902).
- commit 93ab561
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: enable extended stats by default (bsc#1192606).
- commit 31058c0
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: missed ref-counting smb session in find (bsc#1192606).
- commit 036df29
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: do not share tcp servers with dfs mounts (bsc#1185902).
- commit 06c9b3f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: set a minimum of 2 minutes for refreshing dfs cache
  (bsc#1185902).
- commit 89e70a9
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix path comparison and hash calc (bsc#1185902).
- commit 1725c18
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: handle different charsets in dfs cache (bsc#1185902).
- commit 7cb133a
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: keep referral server sessions alive (bsc#1185902).
- commit 0f9891c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: get rid of @noreq param in __dfs_cache_find()
  (bsc#1185902).
- commit 8c17775
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: do not send tree disconnect to ipc shares (bsc#1185902).
- commit 5403cd0
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: improve fallocate emulation (bsc#1192606).
- commit 69387e0
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix doc warnings in cifs_dfs_ref.c (bsc#1192606).
- commit ed7aa17
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove redundant initialization of variable rc
  (bsc#1192606).
- commit 1db8433
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Constify static struct genl_ops (bsc#1192606).
- commit 8c8e6b1
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Remove unused inline function is_sysvol_or_netlogon()
  (bsc#1185902).
- commit f81891f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove duplicated prototype (bsc#1192606).
- commit e27f304
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix ipv6 formating in cifs_ses_add_channel (bsc#1192606).
- commit 231f6f1
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: change format of CIFS_FULL_KEY_DUMP ioctl (bsc#1192606).
- commit 1e18e17
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix string declarations and assignments in tracepoints
  (bsc#1192606).
- commit 5159f90
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: set server->cipher_type to AES-128-CCM for SMB3.0
  (bsc#1192606).
- commit f561ad9
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix inconsistent indenting (bsc#1192606).
- commit c386cb1
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix memory leak in smb2_copychunk_range (git-fixes).
- commit 845634d
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: if max_channels set to more than one channel request
  multichannel (bsc#1192606).
- commit 93e55f7
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: do not attempt multichannel to server which does not
  support it (bsc#1192606).
- commit e1b5be8
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: when mounting with multichannel include it in requested
  capabilities (bsc#1192606).
- commit b03c460
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix regression when mounting shares with prefix paths
  (bsc#1192606).
- commit 59233de
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: use echo_interval even when connection not ready
  (bsc#1192606).
- commit 15fd173
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: detect dead connections only when echoes are enabled
  (bsc#1192606).
- commit 5c84eeb
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3.1.1: allow dumping keys for multiuser mounts (bsc#1192606).
- commit 79c8410
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3.1.1: allow dumping GCM256 keys to improve debugging of
  encrypted shares (bsc#1192606).
- commit b4fea5b
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3.1.1: enable negotiating stronger encryption by default
  (bsc#1192606).
- commit 9da00b7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update internal version number (bsc#1192606).
- commit 13bc2c5
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add rasize mount parameter to improve readahead
  performance (bsc#1192606).
- commit 30ebb66
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: limit noisy error (bsc#1192606).
- commit 91e0ede
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix leak in cifs_smb3_do_mount() ctx (bsc#1192606).
- commit 8a2920f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove unnecessary copies of tcon->crfid.fid
  (bsc#1192606).
- commit 0b30781
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Return correct error code from smb2_get_enc_key
  (git-fixes).
- commit 846705c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix out-of-bound memory access when calling smb3_notify()
  at mount point (bsc#1192606).
- commit 0a3285f
* Fri Nov 26 2021 ematsumiya@suse.de
- smb2: fix use-after-free in smb2_ioctl_query_info()
  (bsc#1192606).
- commit 63f6c5e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: export supported mount options via new mount_params
  /proc file (bsc#1192606).
- commit 2dd1c61
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: log mount errors using cifs_errorf() (bsc#1192606).
- commit a2f6e3b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add fs_context param to parsing helpers (bsc#1192606).
- commit a1c2b3d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: make fs_context error logging wrapper (bsc#1192606).
- commit 3b6af06
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add FALLOC_FL_INSERT_RANGE support (bsc#1192606).
- commit ef118dc
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add support for FALLOC_FL_COLLAPSE_RANGE (bsc#1192606).
- commit ece4ddb
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: check the timestamp for the cached dirent when deciding
  on revalidate (bsc#1192606).
- commit aecc2fc
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: pass the dentry instead of the inode down to the
  revalidation check functions (bsc#1192606).
- commit c93ddc7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add a timestamp to track when the lease of the cached
  dir was taken (bsc#1192606).
- commit 3ac8e19
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add a function to get a cached dir based on its dentry
  (bsc#1192606).
- commit 24027a5
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Grab a reference for the dentry of the cached directory
  during the lifetime of the cache (bsc#1192606).
- commit 91b960b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: store a pointer to the root dentry in cifs_sb_info once
  we have completed mounting the share (bsc#1192606).
- commit 8a598fa
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: rename the *_shroot* functions to *_cached_dir*
  (bsc#1192606).
- commit 2a8dae4
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: pass a path to open_shroot and check if it is the root
  or not (bsc#1192606).
- commit 234424b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: move the check for nohandlecache into open_shroot
  (bsc#1192606).
- commit 99d7c2e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: switch build_path_from_dentry() to using dentry_path_raw()
  (bsc#1192606).
- commit fc6b596
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: allocate buffer in the caller of build_path_from_dentry()
  (bsc#1192606).
- commit 97679cd
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: make build_path_from_dentry() return const char *
  (bsc#1192606).
- commit ef657be
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: constify pathname arguments in a bunch of helpers
  (bsc#1192606).
- commit b93cc52
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: constify path argument of ->make_node() (bsc#1192606).
- commit 03fcdf4
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: constify get_normalized_path() properly (bsc#1185902).
- commit 90470dc
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: don't cargo-cult strndup() (bsc#1185902).
- commit ca5d72c
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: update structures for new compression protocol definitions
  (bsc#1192606).
- commit 4a8461d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove old dead code (bsc#1192606).
- commit 97b63df
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: cifspdu.h: Replace one-element array with flexible-array
  member (bsc#1192606).
- commit 4c15bf6
* Fri Nov 26 2021 ematsumiya@suse.de
- fs: cifs: Remove repeated struct declaration (bsc#1192606).
- commit 8e0ef67
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: simplify SWN code with dummy funcs instead of ifdefs
  (bsc#1192606).
- commit 619dc86
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: update protocol header definitions based to include new
  flags (bsc#1192606).
- commit 31de2ad
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: correct comments explaining internal semaphore usage in
  the module (bsc#1192606).
- commit 8016b0d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Remove useless variable (bsc#1192606).
- commit 4da0037
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix spelling of 'security' (bsc#1192606).
- commit 7f34541
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: escape spaces in share names (bsc#1192606).
- commit f9411a4
* Fri Nov 26 2021 ematsumiya@suse.de
- fs: cifs: Remove unnecessary struct declaration (bsc#1192606).
- commit c4877c5
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: On cifs_reconnect, resolve the hostname again
  (bsc#1192606).
- commit 0f5ba1b
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix cached file size problems in duplicate extents
  (reflink) (bsc#1192606).
- commit db5895f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Silently ignore unknown oplock break handle (bsc#1192606).
- commit fa1d6ea
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: revalidate mapping when we open files for SMB1 POSIX
  (bsc#1192606).
- Refresh
  patches.suse/cifs-have-cifs_fattr_to_inode-refuse-to-change-type-on-live-inode.patch.
- commit 2e4453d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix chmod with modefromsid when an older ACE already
  exists (bsc#1192606).
- commit 589d547
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Adjust key sizes and key generation routines for AES256
  encryption (bsc#1192606).
- commit 5dbb25b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix allocation size on newly created files (bsc#1192606).
- commit 4d93c82
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: warn and fail if trying to use rootfs without the config
  option (bsc#1192606).
- commit f552b34
* Fri Nov 26 2021 ematsumiya@suse.de
- fs/cifs/: fix misspellings using codespell tool (bsc#1192606).
- commit 2ea6114
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix preauth hash corruption (git-fixes).
- commit 7416f5d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update new ACE pointer after populate_new_aces
  (bsc#1192606).
- commit 0529102
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: have cifs_fattr_to_inode() refuse to change type on live
  inode (bsc#1192606).
- commit b158f7d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: have ->mkdir() handle race with another client sanely
  (bsc#1192606).
- commit 6b82284
* Fri Nov 26 2021 ematsumiya@suse.de
- do_cifs_create(): don't set ->i_mode of something we had not
  created (bsc#1192606).
- commit a0ecf85
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: do not send close in compound create+close requests
  (bsc#1181507).
- commit 11e6f22
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: return proper error code in statfs(2) (bsc#1181507).
- commit 4fc8874
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: change noisy error message to FYI (bsc#1181507).
- commit 3406540
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: print MIDs in decimal notation (bsc#1181507).
- commit c8f2cd7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: ask for more credit on async read/write code paths
  (bsc#1192606).
- commit 636078f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix credit accounting for extra channel (bsc#1192606).
- commit c477df8
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update internal version number (bsc#1192606).
- commit b82f71c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: use discard iterator to discard unneeded network data
  more efficiently (bsc#1192606).
- commit 34ea556
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: introduce helper for finding referral server
  (bsc#1181710).
- commit 78e0bf2
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: check all path components in resolved dfs target
  (bsc#1181710).
- commit daad3a2
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix DFS failover (bsc#1192606).
- commit 9182fbd
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix nodfs mount option (bsc#1181710).
- commit 415546c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix handling of escaped ',' in the password mount argument
  (bsc#1192606).
- commit f2b417d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Add new parameter "acregmax" for distinct file and
  directory metadata timeout (bsc#1192606).
- commit 958622c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: convert revalidate of directories to using directory
  metadata cache timeout (bsc#1192606).
- commit 1f13b2c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Add new mount parameter "acdirmax" to allow caching
  directory metadata (bsc#1192606).
- commit c620fbe
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: If a corrupted DACL is returned by the server, bail out
  (bsc#1192606).
- commit 0f619ca
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: minor simplification to smb2_is_network_name_deleted
  (bsc#1192606).
- commit 5c19466
* Fri Nov 26 2021 ematsumiya@suse.de
- TCON Reconnect during STATUS_NETWORK_NAME_DELETED (bsc#1192606).
- commit 4148056
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: cleanup a few le16 vs. le32 uses in cifsacl.c
  (bsc#1192606).
- commit 473d37a
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Change SIDs in ACEs while transferring file ownership
  (bsc#1192606).
- commit 8bda691
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Retain old ACEs when converting between mode bits and ACL
  (bsc#1192606).
- commit 47d65ee
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix cifsacl ACE mask for group and others (bsc#1192606).
- commit 34f7d02
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: clarify hostname vs ip address in /proc/fs/cifs/DebugData
  (bsc#1192606).
- commit 3c6d03e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: change confusing field serverName (to ip_addr)
  (bsc#1192606).
- commit ac396a8
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix inconsistent IS_ERR and PTR_ERR (bsc#1192606).
- commit b7f9076
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Reformat DebugData and index connections by conn_id
  (bsc#1192606).
- commit 4020fb6
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Identify a connection by a conn_id (bsc#1192606).
- commit 35d50c8
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix in error types returned for out-of-credit situations
  (bsc#1192606).
- commit 4143c6a
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: New optype for session operations (bsc#1181507).
- commit 171fe4d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix trivial typo (bsc#1192606).
- commit ab49627
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: negotiate current dialect (SMB3.1.1) when version 3 or
  greater requested (bsc#1192606).
- commit bda03f6
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Set CIFS_MOUNT_USE_PREFIX_PATH flag on setting
  cifs_sb->prepath (bsc#1192606).
- commit 61e03e7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: In the new mount api we get the full devname as source=
  (bsc#1192606).
- commit 280bd9e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: do not disable noperm if multiuser mount option is not
  provided (bsc#1192606).
- commit e136d3e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix dfs-links (bsc#1192606).
- commit 7cc0083
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: report error instead of invalid when revalidating a
  dentry fails (bsc#1177440).
- commit ae9593c
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix crediting for compounding when only one request in
  flight (bsc#1181507).
- commit ea94504
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: Fix out-of-bounds bug in SMB2_negotiate() (bsc#1183540).
- commit fc2901f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix dfs domain referrals (bsc#1192606).
- commit 4f2e59b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: returning mount parm processing errors correctly
  (bsc#1192606).
- commit fc19610
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix mounts to subdirectories of target (bsc#1192606).
- commit 9ca4904
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: ignore auto and noauto options if given (bsc#1192606).
- commit a69545d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: do not fail __smb_send_rqst if non-fatal signals are
  pending (git-fixes).
- commit c375e6f
* Fri Nov 26 2021 ematsumiya@suse.de
- fs/cifs: Simplify bool comparison (bsc#1192606).
- commit 4959fe1
* Fri Nov 26 2021 ematsumiya@suse.de
- fs/cifs: Assign boolean values to a bool variable (bsc#1192606).
- commit 8043a9e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: style: replace one-element array with flexible-array
  (bsc#1192606).
- commit ddf3e41
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: connect: style: Simplify bool comparison (bsc#1192606).
- commit 67852c0
* Fri Nov 26 2021 ematsumiya@suse.de
- fs: cifs: remove unneeded variable in smb3_fs_context_dup
  (bsc#1192606).
- commit fb653f6
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix interrupted close commands (git-fixes).
- commit f7a7f46
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: check pointer before freeing (bsc#1183534).
- commit 29af08c
* Fri Nov 26 2021 ematsumiya@suse.de
- Add SMB 2 support for getting and setting SACLs (bsc#1192606).
- commit dca2a26
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Add support for getting and setting SACLs (bsc#1192606).
- commit e9596e1
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Avoid error pointer dereference (bsc#1192606).
- commit e31fad7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Re-indent cifs_swn_reconnect() (bsc#1192606).
- commit 952b9c2
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Unlock on errors in cifs_swn_reconnect() (bsc#1192606).
- commit 3671d77
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Delete a stray unlock in cifs_swn_reconnect()
  (bsc#1192606).
- commit 81836d3
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update internal module version number (bsc#1192606).
- commit a3d9dc5
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix support for remount when not changing rsize/wsize
  (bsc#1192606).
- commit 6310efa
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: handle "guest" mount parameter (bsc#1192606).
- commit 041cbf9
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: correct four aliased mount parms to allow use of previous
  names (bsc#1192606).
- commit 25edec0
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Tracepoints and logs for tracing credit changes
  (bsc#1181507).
- commit 9012fa5
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix use after free in cifs_smb3_do_mount() (bsc#1192606).
- commit 36ab890
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix rsize/wsize to be negotiated values (bsc#1192606).
- commit ef43e93
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix some error pointers handling detected by static
  checker (bsc#1192606).
- commit 53cb7da
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: remind users that witness protocol is experimental
  (bsc#1192606).
- commit e734508
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update super_operations to show_devname (bsc#1192606).
- commit 24c46d7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix uninitialized variable in smb3_fs_context_parse_param
  (bsc#1192606).
- commit f9ee21b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update mnt_cifs_flags during reconfigure (bsc#1192606).
- commit c3245ce
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: move update of flags into a separate function
  (bsc#1192606).
- commit 0d92778
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove ctx argument from cifs_setup_cifs_sb (bsc#1192606).
- commit b64f601
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: do not allow changing posix_paths during remount
  (bsc#1192606).
- commit 9e6223d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: uncomplicate printing the iocharset parameter
  (bsc#1192606).
- commit e7f6359
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: don't create a temp nls in cifs_setup_ipc (bsc#1192606).
- commit 5345972
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: simplify handling of cifs_sb/ctx->local_nls (bsc#1192606).
- commit edc5b35
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: we do not allow changing username/password/unc/... during
  remount (bsc#1192606).
- commit 5a0ec9d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add initial reconfigure support (bsc#1192606).
- commit 1b949af
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: move [brw]size from cifs_sb to cifs_sb->ctx (bsc#1192606).
- commit 60ffa4e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: move cifs_cleanup_volume_info[_content] to fs_context.c
  (bsc#1192606).
- commit 9c231c6
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Add missing sentinel to smb3_fs_parameters (bsc#1192606).
- commit 75497fa
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Handle witness client move notification (bsc#1192606).
- commit 472f96f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove actimeo from cifs_sb (bsc#1192606).
- commit bf63550
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove [gu]id/backup[gu]id/file_mode/dir_mode from cifs_sb
  (bsc#1192606).
- commit fdf44d3
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove some minor warnings pointed out by kernel test
  robot (bsc#1192606).
- commit 9008f06
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove various function description warnings
  (bsc#1192606).
- commit d30d530
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Simplify reconnect code when dfs upcall is enabled
  (bsc#1192606).
- commit c156ee7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Send witness register messages to userspace daemon in
  echo task (bsc#1192606).
- commit ac7fc2c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Add witness information to debug data dump (bsc#1192606).
- commit 66d50bc
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Set witness notification handler for messages from
  userspace daemon (bsc#1192606).
- commit 302ad1a
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Send witness register and unregister commands to userspace
  daemon (bsc#1192606).
- commit b44003d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: minor updates to Kconfig (bsc#1192606).
- commit 5d17515
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add witness mount option and data structs (bsc#1192606).
- commit 501bdfb
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Register generic netlink family (bsc#1192606).
  Update configs with CONFIG_SWN_UPCALL unset.
- commit 163e9ea
* Fri Nov 26 2021 mbenes@suse.cz
- objtool: Support Clang non-section symbols in ORC generation
  (bsc#1169514).
- blacklist.conf updated (backported commit removed)
- commit 1709279
* Fri Nov 26 2021 mbenes@suse.cz
- elfcore: fix building with clang (bsc#1169514).
- commit 00fb734
* Fri Nov 26 2021 msuchanek@suse.de
- constraints: Build aarch64 on recent ARMv8.1 builders.
  Request asimdrdm feature which is available only on recent ARMv8.1 CPUs.
  This should prevent scheduling the kernel on an older slower builder.
- commit 60fc53f
* Fri Nov 26 2021 tiwai@suse.de
- drm/nouveau: clean up all clients on device removal
  (CVE-2020-27820 bsc#1179599).
- drm/nouveau: Add a dedicated mutex for the clients list
  (CVE-2020-27820 bsc#1179599).
- drm/nouveau: use drm_dev_unplug() during device removal
  (CVE-2020-27820 bsc#1179599).
- commit c130f04
* Fri Nov 26 2021 tiwai@suse.de
- drm/nouveau: clean up all clients on device removal
  (CVE-2020-27820 bsc#1179599).
- drm/nouveau: Add a dedicated mutex for the clients list
  (CVE-2020-27820 bsc#1179599).
- drm/nouveau: use drm_dev_unplug() during device removal
  (CVE-2020-27820 bsc#1179599).
- commit 52c5fe2
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: cleanup misc.c (bsc#1192606).
- commit d5aed73
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: minor kernel style fixes for comments (bsc#1192606).
- commit 56d2f6d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Make extract_sharename function public (bsc#1192606).
- commit 958ba69
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Make extract_hostname function public (bsc#1192606).
- commit 1e0579d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: get rid of cifs_sb->mountdata (bsc#1192606).
- commit d382da4
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add an smb3_fs_context to cifs_sb (bsc#1192606).
- commit ea2f54b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove the devname argument to cifs_compose_mount_options
  (bsc#1192606).
- commit 7690451
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: switch to new mount api (bsc#1192606).
- commit 3a872f9
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: move cifs_parse_devname to fs_context.c (bsc#1192606).
- commit 48f0a0e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: move the enum for cifs parameters into fs_context.h
  (bsc#1192606).
- commit 28a15fc
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: rename dup_vol to smb3_fs_context_dup and move it into
  fs_context.c (bsc#1192606).
- commit 74c4d04
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: rename smb_vol as smb3_fs_context and move it to
  fs_context.h (bsc#1192606).
- commit cfae22b
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3.1.1: do not log warning message if server doesn't populate
  salt (bsc#1192606).
- commit 52317ed
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3.1.1: update comments clarifying SPNEGO info in negprot
  response (bsc#1192606).
- commit 92662cf
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Enable sticky bit with cifsacl mount option (bsc#1192606).
- commit a44e471
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix unix perm bits to cifsacl conversion for "other"
  bits (bsc#1192606).
- commit c0e0d2e
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3.1.1: remove confusing mount warning when no SPNEGO info
  on negprot rsp (bsc#1192606).
- commit 644e3af
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: avoid confusing warning message on mount to Azure
  (bsc#1192606).
- commit 255c5fa
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix fall-through warnings for Clang (bsc#1192606).
- commit 2f2540d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: refactor create_sd_buf() and and avoid corrupting the
  buffer (bsc#1192606).
- commit 5e73e71
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add NULL check for ses->tcon_ipc (bsc#1178270).
- commit b49338b
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: set COMPOUND_FID to FileID field of subsequent compound
  request (bsc#1192606).
- commit f4b5ad9
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix potential use-after-free in cifs_echo_request()
  (bsc#1139944).
- commit 98843ac
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: allow syscalls to be restarted in __smb_send_rqst()
  (bsc#1176956).
- commit 1b00be4
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: Handle error case during offload read path (bsc#1192606).
- commit 65b8bfd
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: Avoid Mid pending list corruption (bsc#1192606).
- commit baea6c6
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: Call cifs reconnect from demultiplex thread (bsc#1192606).
- commit a61a83b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix a memleak with modefromsid (bsc#1192606).
- commit a599e96
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update internal module version number (bsc#1192606).
- commit 72d7f82
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add some missing definitions from MS-FSCC (bsc#1192606).
- commit c3d6868
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: remove two unused variables (bsc#1192606).
- commit def88ae
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add support for stat of WSL reparse points for special
  file types (bsc#1192606).
- commit 479bed9
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: add support for recognizing WSL reparse tags
  (bsc#1192606).
- commit a651550
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove bogus debug code (bsc#1179427).
- commit a82be88
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3.1.1: fix typo in compression flag (bsc#1192606).
- commit 4a64be3
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: move smb version mount options into fs_context.c
  (bsc#1192606).
- commit adb0785
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: move cache mount options to fs_context.ch (bsc#1192606).
- commit 8c53b27
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: move security mount options into fs_context.ch
  (bsc#1192606).
- commit a9ada64
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add files to host new mount api (bsc#1192606).
- commit a0ef4da
* Fri Nov 26 2021 ematsumiya@suse.de
- linux/parser.h: add include guards (bsc#1192606).
- commit f3801c4
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: do not try to cache root directory if dir leases not
  supported (bsc#1192606).
- commit 8218366
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix stat when special device file and mounted with
  modefromsid (bsc#1192606).
- commit a8ab74d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Print the address and port we are connecting to in
  generic_ip_connect() (bsc#1192606).
- commit 27567b1
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Resolve data corruption of TCP server info fields
  (bsc#1192606).
- commit e9bf4a1
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: make const array static, makes object smaller
  (bsc#1192606).
- commit b7f99c8
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3.1.1: Fix ids returned in POSIX query dir (bsc#1192606).
- commit 330caf7
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add dynamic trace point to trace when credits obtained
  (bsc#1181507).
- commit 58e9f6b
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3.1.1: do not fail if no encryption required but server
  doesn't support it (bsc#1192606).
- commit c7bf6a1
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Return the error from crypt_message when enc/dec key
  not found (bsc#1179426).
- commit b1cdf8b
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3.1.1: set gcm256 when requested (bsc#1192606).
- commit e9b39d5
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3.1.1: rename nonces used for GCM and CCM encryption
  (bsc#1192606).
- commit 255717e
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3.1.1: print warning if server does not support requested
  encryption type (bsc#1192606).
- commit 1fe18d9
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3.1.1: add new module load parm enable_gcm_256 (bsc#1192606).
- commit 9039e9b
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3.1.1: add new module load parm require_gcm_256
  (bsc#1192606).
- commit 7a312a4
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: map STATUS_ACCOUNT_LOCKED_OUT to -EACCES (bsc#1192606).
- commit 2c16fbc
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3.1.1: add defines for new signing negotiate context
  (bsc#1192606).
- commit 4d3ef02
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: handle -EINTR in cifs_setattr (bsc#1192606).
- commit 49f54f5
* Fri Nov 26 2021 ematsumiya@suse.de
- Handle STATUS_IO_TIMEOUT gracefully (bsc#1192606).
- commit 6bbd363
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: compute full_path already in cifs_readdir() (bsc#1192606).
- commit 6d2e8b4
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: return cached_fid from open_shroot (bsc#1192606).
- commit e7b74da
* Fri Nov 26 2021 ematsumiya@suse.de
- update structure definitions from updated protocol documentation
  (bsc#1192606).
- commit f34e9c8
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add defines for new crypto algorithms (bsc#1192606).
- commit c5a3bf6
* Fri Nov 26 2021 ematsumiya@suse.de
- Convert trailing spaces and periods in path components
  (bsc#1179424).
- commit ac355fa
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix incomplete memory allocation on setxattr path
  (bsc#1179211).
- commit 239bcd9
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix DFS mount with cifsacl/modefromsid (bsc#1178270).
- commit eacaaaa
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix check of tcon dfs in smb1 (bsc#1178270).
- commit d3716bf
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Fix mkdir when idsfromsid configured on mount
  (bsc#1192606).
- commit 5bdbc43
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Convert to use the fallthrough macro (bsc#1192606).
- commit efd5364
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix an error pointer dereference in cifs_mount()
  (bsc#1178270).
- commit 7505e01
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: document and cleanup dfs mount (bsc#1178270).
- commit 19e0536
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: only update prefix path of DFS links in
  cifs_tree_connect() (bsc#1178270).
- commit a0c2fcb
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix double free error on share and prefix (bsc#1178270).
- commit c41144c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: handle RESP_GET_DFS_REFERRAL.PathConsumed in reconnect
  (bsc#1178270).
- commit b9d9b79
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: handle empty list of targets in cifs_reconnect()
  (bsc#1178270).
- commit d696d71
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: rename reconn_inval_dfs_target() (bsc#1178270).
- commit 6d8fd3f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: reduce number of referral requests in DFS link lookups
  (bsc#1178270).
- commit 7c62723
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: merge __{cifs,smb2}_reconnect[_tcon]() into
  cifs_tree_connect() (bsc#1178270).
- commit 6b8c9d8
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: convert to use be32_add_cpu() (bsc#1192606).
- commit dd3314a
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: delete duplicated words in header files (bsc#1192606).
- commit 8115708
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Remove the superfluous break (bsc#1192606).
- commit 9953c3c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smb1: Try failing back to SetFileInfo if SetPathInfo fails
  (bsc#1192606).
- commit 851bcd7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs`: handle ERRBaduid for SMB1 (bsc#1192606).
- commit 0b09946
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove unused variable 'server' (bsc#1192606).
- commit 3c682cd
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: warn on confusing error scenario with sec=krb5
  (bsc#1176548).
- commit 42a38ce
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix leak when handling lease break for cached root fid
  (bsc#1176242).
- commit 677fd80
* Fri Nov 26 2021 ematsumiya@suse.de
- Revert "cifs: Fix the target file was deleted when rename
  failed." (bsc#1192606).
- commit e18cfc5
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update internal module version number (bsc#1192606).
- commit d61ab33
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix reference leak for tlink (bsc#1192606).
- commit 82e17a7
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix unneeded error message on change notify (bsc#1192606).
- commit e66ce2d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove the retry in cifs_poxis_lock_set (bsc#1192606).
- commit 332eb71
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix access denied on change notify request to some servers
  (bsc#1192606).
- commit fd93797
* Fri Nov 26 2021 ematsumiya@suse.de
- Replace HTTP links with HTTPS ones: CIFS (bsc#1192606).
- commit 0d6db48
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: prevent truncation from long to int in
  wait_for_free_credits (bsc#1192606).
- commit 9a0fb61
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix the target file was deleted when rename failed
  (bsc#1192606).
- commit db55866
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Honor 'posix' flag for multiuser mounts (bsc#1176559).
- commit 9a7a8a4
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Honor 'handletimeout' flag for multiuser mounts
  (bsc#1176558).
- commit b1e041c
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Honor lease disabling for multiuser mounts (git-fixes).
- commit 82468cf
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Honor persistent/resilient handle flags for multiuser
  mounts (bsc#1176546).
- commit 22a7ca5
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Honor 'seal' flag for multiuser mounts (bsc#1176545).
- commit a18cbde
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Display local UID details for SMB sessions in DebugData
  (bsc#1192606).
- commit 7f9fa20
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: misc: Use array_size() in if-statement controlling
  expression (bsc#1192606).
- commit c02caf9
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update ctime and mtime during truncate (bsc#1192606).
- commit 694deaf
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs/smb3: Fix data inconsistent when punch hole (bsc#1176544).
- commit 6c60807
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs/smb3: Fix data inconsistent when zero file range
  (bsc#1176536).
- commit 0f9acaa
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix double add page to memcg when cifs_readpages
  (bsc#1192606).
- commit 03bbe2c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix cached_fid refcnt leak in open_shroot (bsc#1192606).
- commit 4b170cc
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: Add debug message for new file creation with idsfromsid
  mount option (bsc#1192606).
- commit 348bed4
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix chown and chgrp when idsfromsid mount option enabled
  (bsc#1192606).
- commit b7dd38c
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: allow uid and gid owners to be set on create with
  idsfromsid mount option (bsc#1192606).
- commit e88def1
* Fri Nov 26 2021 ematsumiya@suse.de
- smb311: Add tracepoints for new compound posix query info
  (bsc#1192606).
- commit 7f1ddf2
* Fri Nov 26 2021 ematsumiya@suse.de
- smb311: add support for using info level for posix extensions
  query (bsc#1192606).
- commit 6cb7e86
* Fri Nov 26 2021 ematsumiya@suse.de
- smb311: Add support for lookup with posix extensions query info
  (bsc#1192606).
- commit 93c3e0d
* Fri Nov 26 2021 ematsumiya@suse.de
- smb311: Add support for SMB311 query info (non-compounded)
  (bsc#1192606).
- commit beec08d
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB311: Add support for query info using posix extensions
  (level 100) (bsc#1192606).
- commit e684a25
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add indatalen that can be a non-zero value to calculation
  of credit charge in smb2 ioctl (bsc#1192606).
- commit 7df3cc5
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix typo in mount options displayed in /proc/mounts
  (bsc#1192606).
- commit a44953f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Add get_security_type_str function to return sec type
  (bsc#1192606).
- commit 9a47f84
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: extend fscache mount volume coherency check (bsc#1192606).
- commit 68aff9c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update internal module version number (bsc#1192606).
- commit 9b30c03
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: multichannel: try to rebind when reconnecting a channel
  (bsc#1192606).
- commit c678b8e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: multichannel: use pointer for binding channel
  (bsc#1192606).
- commit b739f0c
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: remove static checker warning (bsc#1192606).
- commit 2f6dcf6
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: multichannel: move channel selection above transport layer
  (bsc#1192606).
- commit 7fd3164
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: multichannel: always zero struct cifs_io_parms
  (bsc#1192606).
- commit 33f2e0b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: dump Security Type info in DebugData (bsc#1192606).
- commit cf57493
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix incorrect number of credits when ioctl
  MaxOutputResponse > 64K (bsc#1192606).
- commit f5551f2
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: default to minimum of two channels when multichannel
  specified (bsc#1192606).
- commit 8393a97
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: multichannel: move channel selection in function
  (bsc#1192606).
- commit 8a917e2
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix minor typos in comments and log messages
  (bsc#1192606).
- commit 83af8a3
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: minor update to compression header definitions
  (bsc#1192606).
- commit 8ac2325
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: minor fix to two debug messages (bsc#1192606).
- commit fda6c8f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Standardize logging output (bsc#1192606).
- commit 6ffb916
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: Add new parm "nodelete" (bsc#1192606).
- commit 48827ed
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: move some variables off the stack in smb2_ioctl_query_info
  (bsc#1192606).
- commit 3f017a7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: reduce stack use in smb2_compound_op (bsc#1192606).
- commit 019bba7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: get rid of unused parameter in reconn_setup_dfs_targets()
  (bsc#1178270).
- commit 38ee91e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: handle hostnames that resolve to same ip in failover
  (bsc#1178270).
- commit 88fab96
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: set up next DFS target before generic_ip_connect()
  (bsc#1178270).
- commit ce3313b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove redundant initialization of variable rc
  (bsc#1192606).
- commit a99ffdf
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: handle "nolease" option for vers=1.0 (bsc#1192606).
- commit c8cf7e4
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix leaked reference on requeued write (bsc#1178270).
- commit 9bb24bb
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix null pointer check in cifs_read (bsc#1192606).
- commit ebcae90
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Spelling s/EACCESS/EACCES/ (bsc#1192606).
- commit 6cdaae9
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix uninitialised lease_key in open_shroot()
  (bsc#1178270).
- commit 3bdd1ac
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: ensure correct super block for DFS reconnect
  (bsc#1178270).
- commit 96f5629
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: do not share tcons with DFS (bsc#1178270).
- commit 6edb20b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: minor update to comments around the cifs_tcp_ses_lock
  mutex (bsc#1192606).
- commit 2eefc78
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: protect updating server->dstaddr with a spinlock
  (bsc#1192606).
- commit db4e78a
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: remove overly noisy debug line in signing errors
  (bsc#1192606).
- commit 96949dd
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: improve read performance for page size 64KB & cache=strict
  & vers=2.1+ (bsc#1192606).
- commit 7ce6d90
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: dump the session id and keys also for SMB2 sessions
  (bsc#1192606).
- commit 529d063
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: enable swap on SMB3 mounts (bsc#1192606).
- commit 30375b2
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: change noisy error message to FYI (bsc#1192606).
- commit 40ae9dd
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: smbdirect support can be configured by default
  (bsc#1192606).
- commit d407091
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smbd: Do not schedule work to send immediate packet on
  every receive (bsc#1192606).
- commit 11e7325
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smbd: Properly process errors on ib_post_send
  (bsc#1192606).
- commit 6c30aa6
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Allocate crypto structures on the fly for calculating
  signatures of incoming packets (bsc#1192606).
- commit 7ebc087
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smbd: Update receive credits before sending and deal
  with credits roll back on failure before sending (bsc#1192606).
- commit 86c6e08
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smbd: Check send queue size before posting a send
  (bsc#1192606).
- commit 4855370
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smbd: Merge code to track pending packets (bsc#1192606).
- commit d555442
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: ignore cached share root handle closing errors
  (bsc#1166780).
- commit 8f24623
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update internal module version number (bsc#1192606).
- commit 8e1f984
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Allocate encryption header through kmalloc (bsc#1192606).
- commit 653cd97
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smbd: Check and extend sender credits in interrupt context
  (bsc#1192606).
- commit 2815e1e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smbd: Calculate the correct maximum packet size for
  segmented SMBDirect send/receive (bsc#1192606).
- commit a92a6da
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: use SMB2_SIGNATURE_SIZE define (bsc#1192606).
- commit 5b1d684
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Fix bug which the return value by asynchronous read is
  error (bsc#1192606).
- commit 7103595
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: check new file size when extending file by fallocate
  (bsc#1192606).
- commit 58a2d12
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Minor cleanup of protocol definitions (bsc#1192606).
- commit 9179120
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Additional compression structures (bsc#1192606).
- commit fe495f9
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Add new compression flags (bsc#1192606).
- commit 5fd5331
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smb2pdu.h: Replace zero-length array with flexible-array
  member (bsc#1192606).
- commit f748972
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: clear PF_MEMALLOC before exiting demultiplex thread
  (bsc#1192606).
- commit 33f8f3c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: cifspdu.h: Replace zero-length array with flexible-array
  member (bsc#1192606).
- commit 54c058d
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Warn less noisily on default mount (bsc#1192606).
- commit a036f2e
* Fri Nov 26 2021 ematsumiya@suse.de
- fs/cifs: fix gcc warning in sid_to_id (bsc#1192606).
- commit 9fe6f6a
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: allow unlock flock and OFD lock across fork (bsc#1192606).
- commit 0278ba9
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: do d_move in rename (bsc#1164565).
- commit ed82a5d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add SMB2_open() arg to return POSIX data (bsc#1164565).
- commit 6b9d249
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: plumb smb2 POSIX dir enumeration (bsc#1164565).
- commit 33c50f7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add smb2 POSIX info level (bsc#1164565).
- commit cca3e07
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: rename posix create rsp (bsc#1164565).
- commit a064158
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: print warning mounting with vers=1.0 (bsc#1164565).
- commit 2ba6d1f
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix performance regression with setting mtime
  (bsc#1164565).
- commit 3668670
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: make use of cap_unix(ses) in cifs_reconnect_tcon()
  (bsc#1164565).
- commit 1a26833
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: use mod_delayed_work() for &server->reconnect if already
  queued (bsc#1164565).
- commit 1ab6a0b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: call wake_up(&server->response_q) inside of
  cifs_reconnect() (bsc#1164565).
- commit 40269bd
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: handle prefix paths in reconnect (bsc#1164565).
- commit 10c4f8a
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: do not ignore the SYNC flags in getattr (bsc#1164565).
- commit 1cff7a8
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: fiemap: do not return EINVAL if get nothing (bsc#1192606).
- commit f71b1ad
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Increment num_remote_opens stats counter even in case
  of smb2_query_dir_first (bsc#1192606).
- commit 16345c6
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: potential unintitliazed error code in cifs_getattr()
  (bsc#1164565).
- commit 55c9aef
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs_atomic_open(): fix double-put on late allocation failure
  (bsc#1192606).
- commit 3d21ff7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Use #define in cifs_dbg (bsc#1164565).
- commit da56dd2
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix rename() by ensuring source handle opened with DELETE
  bit (bsc#1164565).
- commit 33621ff
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add missing mount option to /proc/mounts (bsc#1164565).
- commit 9180deb
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix potential mismatch of UNC paths (bsc#1164565).
- commit 008b33b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: don't leak -EAGAIN for stat() during reconnect
  (bsc#1164565).
- commit bdfa052
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: make sure we do not overflow the max EA buffer size
  (bsc#1164565).
- commit c57bd80
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: enable change notification for SMB2.1 dialect
  (bsc#1164565).
- commit 9752774
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix mode output in debugging statements (bsc#1164565).
- commit 504f756
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix mount option display for sec=krb5i (bsc#1161907).
- commit cb0115f
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: Add defines for new information level, FileIdInformation
  (bsc#1164565).
- commit caf0941
* Fri Nov 26 2021 ematsumiya@suse.de
-  smb3: print warning once if posix context returned on open
  (bsc#1164565).
- commit 4cfe779
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add one more dynamic tracepoint missing from strict
  fsync path (bsc#1164565).
- commit 88bc35f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix mode bits from dir listing when mounted with
  modefromsid (bsc#1164565).
- commit 7a45b49
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix channel signing (bsc#1192606).
- commit 59b8e3d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add SMB3 change notification support (bsc#1164565).
- commit 7130f9d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: make multichannel warning more visible (bsc#1192606).
- commit 5fb729d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix soft mounts hanging in the reconnect code
  (bsc#1164565).
- commit 1f74108
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Add tracepoints for errors on flush or fsync
  (bsc#1164565).
- commit fe49ca1
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: log warning message (once) if out of disk space
  (bsc#1164565).
- commit 1d44a00
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fail i/o on soft mounts if sessionsetup errors out
  (bsc#1164565).
- commit 859352d
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix problem with null cifs super block with previous patch
  (bsc#1164565).
- commit 8ccd7a6
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Backup intent flag missing from some more ops
  (bsc#1164565).
- commit 169d11b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update internal module version number (bsc#1192606).
- commit 2f1471a
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix soft mounts hanging in the reconnect code
  (bsc#1164565).
- commit aa72889
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Fix task struct use-after-free on reconnect (bsc#1164565).
- commit a434312
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: use PTR_ERR_OR_ZERO() to simplify code (bsc#1164565).
- commit e3ec0b0
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add support for fallocate mode 0 for non-sparse files
  (bsc#1164565).
- commit eb8cb0d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix NULL dereference in match_prepath (bsc#1164565).
- commit 6dce4a8
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix default permissions on new files when mounting with
  modefromsid (bsc#1164565).
- commit d99904b
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Add support for setting owner info, dos attributes,
  and create time (bsc#1164565).
- commit ba6078d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove set but not used variable 'server' (bsc#1164565).
- commit 70b1352
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix memory allocation in __smb2_handle_cancelled_cmd()
  (bsc#1164565).
- commit 22830d8
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix mount options set in automount (bsc#1164565).
- commit 945658c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix unitialized variable poential problem with network
  I/O cache lock patch (bsc#1164565).
- commit 406db0c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix return value in __update_cache_entry (bsc#1164565).
- commit 05ed047
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Avoid doing network I/O while holding cache lock
  (bsc#1164565).
- commit 543a9e2
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix potential deadlock when updating vol in
  cifs_reconnect() (bsc#1164565).
- commit a483c39
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Merge is_path_valid() into get_normalized_path()
  (bsc#1164565).
- commit 8a35879
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Introduce helpers for finding TCP connection
  (bsc#1164565).
- commit fa139d5
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Get rid of kstrdup_const()'d paths (bsc#1164565).
- commit 2f2f4a7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Clean up DFS referral cache (bsc#1164565).
- commit 51716b8
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Don't use iov_iter::type directly (bsc#1192606).
- commit 99ff3cb
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: set correct max-buffer-size for smb2_ioctl_init()
  (bsc#1164565).
- commit 36a4575
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: use compounding for open and first query-dir for readdir()
  (bsc#1164565).
- commit 5aa504c
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: create a helper function to parse the query-directory
  response buffer (bsc#1164565).
- commit d4a4c74
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: prepare SMB2_query_directory to be used with compounding
  (bsc#1164565).
- commit c711000
* Fri Nov 26 2021 ematsumiya@suse.de
- fs/cifs/cifssmb.c: use true,false for bool variable
  (bsc#1164565).
- commit b823a48
* Fri Nov 26 2021 ematsumiya@suse.de
- fs/cifs/smb2ops.c: use true,false for bool variable
  (bsc#1164565).
- commit a954e48
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Optimize readdir on reparse points (bsc#1164565).
- commit 1fdbe42
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Adjust indentation in smb2_open_file (bsc#1164565).
- commit b69e620
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Close cached root handle only if it has a lease
  (bsc#1164565).
- commit 205ef7d
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Fix crash in SMB2_open_init due to uninitialized field
  in compounding path (bsc#1164565).
- commit b133190
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix refcount underflow warning on unmount when no
  directory leases (bsc#1164565).
- commit 5f56751
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: improve check for when we send the security descriptor
  context on create (bsc#1164565).
- commit 6279123
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix mode passed in on create for modetosid mount option
  (bsc#1164565).
- commit 1e7da56
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix possible uninitialized access and race on iface_list
  (bsc#1192606).
- commit 0ce4d56
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix lookup of SMB connections on multichannel
  (bsc#1192606).
- commit 1313fae
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: query attributes on file close (bsc#1164565).
- commit fe40478
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: remove unused flag passed into close functions
  (bsc#1164565).
- commit 1e514e4
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove redundant assignment to pointer pneg_ctxt
  (bsc#1164565).
- commit d63715e
* Fri Nov 26 2021 ematsumiya@suse.de
- fs: cifs: Fix atime update check vs mtime (bsc#1164565).
- commit ff2d5e0
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Fix NULL-pointer dereference in smb2_push_mandatory_locks
  (bnc#1151927 5.3.16).
- commit 68282cc
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: fix a white space issue in cifs_get_inode_info()
  (bsc#1164565).
- commit a22deab
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update internal module version number (bsc#1192606).
- commit 58d90ea
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Always update signing key of first channel (bsc#1192606).
- commit 523db5e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix retrieval of DFS referrals in cifs_mount()
  (bsc#1164565).
- commit bf98d60
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix potential softlockups while refreshing DFS cache
  (bsc#1164565).
- commit 496859d
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix lookup of root ses in DFS referral cache
  (bsc#1164565).
- commit c6ec1d6
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix use-after-free bug in cifs_reconnect() (bsc#1164565).
- commit fe9df9f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: dump channel info in DebugData (bsc#1192606).
- commit 109f68a
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: dump in_send and num_waiters stats counters by default
  (bsc#1164565).
- commit ec9651f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: try harder to open new channels (bsc#1192606).
- commit 8f7594a
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Properly process SMB3 lease breaks (bsc#1164565).
- commit 5f1ee05
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: move cifsFileInfo_put logic into a work-queue
  (bsc#1154355).
- commit 4b84358
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: try opening channels after mounting (bsc#1192606).
- commit 7ecaefa
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: refactor cifs_get_inode_info() (bsc#1164565).
- commit 72479e8
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: switch servers depending on binding state (bsc#1192606).
- commit 95bf7f5
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add server param (bsc#1192606).
- commit dcbb33e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add multichannel mount options and data structs
  (bsc#1192606).
- commit ae40994
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: sort interface list by speed (bsc#1192606).
- commit f0d024f
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Fix SMB2 oplock break processing (bsc#1154355 bnc#1151927
  5.3.16).
- commit 654d9b1
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: don't use 'pre:' for MODULE_SOFTDEP (bsc#1164565).
- commit e8d163b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smbd: Return -EAGAIN when transport is reconnecting
  (bsc#1164565).
- commit 28c2c04
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smbd: Only queue work for error recovery on memory
  registration (bsc#1164565).
- commit 0b460af
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add debug messages for closing unmatched open
  (bsc#1164565).
- commit 2aad8aa
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Do not miss cancelled OPEN responses (bsc#1164565).
- commit e35eb8b
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Fix NULL pointer dereference in mid callback
  (bsc#1164565).
- commit 6a3a4b5
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Close open handle after interrupted close (bsc#1164565).
- commit c8dcdd8
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Respect O_SYNC and O_DIRECT flags during reconnect
  (bsc#1164565).
- commit 8009a80
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: remove confusing dmesg when mounting with encryption
  ("seal") (bsc#1164565).
- commit c585be8
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: close the shared root handle on tree disconnect
  (bsc#1164565).
- commit bb6bb3e
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Return directly after a failed build_path_from_dentry()
  in cifs_do_create() (bsc#1164565).
- commit 72b533b
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Use common error handling code in smb2_ioctl_query_info()
  (bsc#1164565).
- commit 0b398b0
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Use memdup_user() rather than duplicating its
  implementation (bsc#1164565).
- commit 8316a15
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smbd: Return -ECONNABORTED when trasnport is not in
  connected state (bsc#1164565).
- commit 5c1a956
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smbd: Add messages on RDMA session destroy and
  reconnection (bsc#1164565).
- commit ce32d46
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smbd: Return -EINVAL when the number of iovs exceeds
  SMBDIRECT_MAX_SGE (bsc#1164565).
- commit 8f155a8
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: smbd: Invalidate and deregister memory registration on
  re-send for direct I/O (bsc#1164565).
- commit 234140e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Don't display RDMA transport on reconnect (bsc#1164565).
- commit 79c3b5f
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: remove set but not used variables 'cinode' and 'netfid'
  (bsc#1164565).
- commit 49cc01f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add support for flock (bsc#1164565).
- commit 4e82f42
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove unused variable 'sid_user' (bsc#1164565).
- commit 127bb53
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: rename a variable in SendReceive() (bsc#1164565).
- commit 1caac54
* Fri Nov 26 2021 ematsumiya@suse.de
- Refresh patches.suse/new-helper-lookup_positive_unlocked.patch.
- commit 1ce8b59
* Fri Nov 26 2021 ematsumiya@suse.de
- SMB3: Fix persistent handles reconnect (bnc#1151927 5.3.11).
- commit 4676d9a
* Fri Nov 26 2021 ematsumiya@suse.de
- fix memory leak in large read decrypt offload (bsc#1164565).
- commit 9bed06e
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix cifsInodeInfo lock_sem deadlock when reconnect occurs
  (bnc#1151927 5.3.10).
- commit ac7c450
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Fix use after free of file info structures (bnc#1151927
  5.3.8).
- commit d1e3c57
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Fix retry mid list corruption on reconnects (bnc#1151927
  5.3.10).
- commit 78aed6f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: Fix missed free operations (bnc#1151927 5.3.8).
- commit 021eb3e
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: avoid using MID 0xFFFF (bnc#1151927 5.3.8).
- commit 89d7e6b
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Force reval dentry if LOOKUP_REVAL flag is set
  (bnc#1151927 5.3.7).
- commit 0986381
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Force revalidate inode when dentry is stale (bnc#1151927
  5.3.7).
- commit de4eccf
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: Fix regression in time handling (bsc#1164565).
- commit af70e1f
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: remove noisy debug message and minor cleanup
  (bsc#1164565).
- commit 44410f6
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Gracefully handle QueryInfo errors during open
  (bnc#1151927 5.3.7).
- commit 8cf17da
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: use cifsInodeInfo->open_file_lock while iterating to
  avoid a panic (bnc#1151927 5.3.7).
- commit 301cd11
* Fri Nov 26 2021 ematsumiya@suse.de
- fs: cifs: mute -Wunused-const-variable message (bnc#1151927
  5.3.9).
- commit 5cc4a16
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: cleanup some recent endian errors spotted by updated
  sparse (bsc#1164565).
- commit 5ac1698
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: Fix oplock handling for SMB 2.1+ protocols (bnc#1151927
  5.3.4).
- commit 54958fe
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: missing ACL related flags (bsc#1164565).
- commit 123c8cb
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: pass mode bits into create calls (bsc#1164565).
- commit 5e8a919
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: Add missing reparse tags (bsc#1164565).
- commit 71d2662
* Fri Nov 26 2021 ematsumiya@suse.de
- CIFS: fix max ea value size (bnc#1151927 5.3.4).
- commit 93132b5
* Fri Nov 26 2021 ematsumiya@suse.de
- fs/cifs/sess.c: Remove set but not used variable 'capabilities'
  (bsc#1164565).
- commit 68a4d1f
* Fri Nov 26 2021 ematsumiya@suse.de
- fs/cifs/smb2pdu.c: Make SMB2_notify_init static (bsc#1164565).
- commit e039394
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix leak in "open on server" perf counter (bnc#1151927
  5.3.4).
- commit 0a489c3
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: allow decryption keys to be dumped by admin for debugging
  (bsc#1164565).
- commit 37fd44f
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: update internal module version number (bsc#1192606).
- commit cb133a9
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: modefromsid: make room for 4 ACE (bsc#1164565).
- commit 0bd807b
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix potential null dereference in decrypt offload
  (bsc#1164565).
- commit 4d9d9ba
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix unmount hang in open_shroot (bnc#1151927 5.3.4).
- commit ba484ab
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: allow disabling requesting leases (bnc#1151927 5.3.4).
- commit be51a36
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: improve handling of share deleted (and share recreated)
  (bsc#1154355).
- commit 4f3941c
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: display max smb3 requests in flight at any one time
  (bsc#1164565).
- commit fa51523
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: only offload decryption of read responses if multiple
  requests (bsc#1164565).
- commit de45f83
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add a helper to find an existing readable handle to a file
  (bsc#1154355).
- commit e6e9bae
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: enable offload of decryption of large reads via mount
  option (bsc#1164565).
- commit 811e003
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: allow parallelizing decryption of reads (bsc#1164565).
- commit acc6de4
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add a debug macro that prints \\server\share for errors
  (bsc#1164565).
- commit 44608d8
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: fix signing verification of large reads (bsc#1154355).
- commit 2edd1f7
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: allow skipping signature verification for perf sensitive
  configurations (bsc#1164565).
- commit 77fb855
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add dynamic tracepoints for flush and close (bsc#1164565).
- commit 5855d7c
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: log warning if CSC policy conflicts with cache mount
  option (bsc#1164565).
- commit e6c8d3b
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add mount option to allow RW caching of share accessed
  by only 1 client (bsc#1164565).
- commit 1a97c9d
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add some more descriptive messages about share when
  mounting cache=ro (bsc#1164565).
- commit a329bf6
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add mount option to allow forced caching of read only
  share (bsc#1164565).
- commit 570c245
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix dereference on ses before it is null checked
  (bsc#1164565).
- commit e681ba1
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add new debugging macro cifs_server_dbg (bsc#1164565).
- commit f81d1da
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: use existing handle for compound_op(OP_SET_INFO) when
  possible (bsc#1154355).
- commit 0670e76
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: create a helper to find a writeable handle by path name
  (bsc#1154355).
- commit 3782e0b
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove set but not used variables (bsc#1164565).
- commit d27b1f6
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: Incorrect size for netname negotiate context
  (bsc#1154355).
- commit 32948a7
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove unused variable (bsc#1164565).
- commit abf35ec
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: remove redundant assignment to variable rc (bsc#1164565).
- commit 2cafd7e
* Fri Nov 26 2021 ematsumiya@suse.de
- smb3: add missing flag definitions (bsc#1164565).
- commit dbb4ef0
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: add passthrough for smb2 setinfo (bsc#1164565).
- commit 1d94923
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: prepare SMB2_Flush to be usable in compounds
  (bsc#1154355).
- commit d232426
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: allow chmod to set mode bits using special sid
  (bsc#1164565).
- commit 6fac0bf
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: get mode bits from special sid on stat (bsc#1164565).
- commit e5063fd
* Fri Nov 26 2021 ematsumiya@suse.de
- fs: cifs: cifsssmb: remove redundant assignment to variable ret
  (bsc#1164565).
- commit 83c42b2
* Fri Nov 26 2021 ematsumiya@suse.de
- cifs: fix a comment for the timeouts when sending echos
  (bsc#1164565).
- commit cad02ec
* Fri Nov 26 2021 ematsumiya@suse.de
- fs: cifs: Initialize filesystem timestamp ranges (bsc#1164565).
- commit ef56e2e
* Fri Nov 26 2021 ematsumiya@suse.de
- Delete patches that are going to be re-backported (bsc#1192606)
  Some of the patches being deleted by this commit might be too
  different and/or change too much context for the upcoming backports.
- commit a49f5dc
* Fri Nov 26 2021 neilb@suse.de
- nfsd: don't alloc under spinlock in rpc_parse_scope_id
  (git-fixes).
- NFSv4: Fix a regression in nfs_set_open_stateid_locked()
  (git-fixes).
- NFS: Fix up commit deadlocks (git-fixes).
- NFS: Fix deadlocks in nfs_scan_commit_list() (git-fixes).
- pnfs/flexfiles: Fix misplaced barrier in
  nfs4_ff_layout_prepare_ds (git-fixes).
- NFS: Don't set NFS_INO_DATA_INVAL_DEFER and NFS_INO_INVALID_DATA
  (git-fixes).
- nfsd4: Handle the NFSv4 READDIR 'dircount' hint being zero
  (git-fixes).
- nfsd: fix error handling of register_pernet_subsys() in
  init_nfsd() (git-fixes).
- md: fix a lock order reversal in md_alloc (git-fixes).
- commit 5402eef
* Thu Nov 25 2021 neilb@suse.de
- blacklist.conf: assorted updates
- commit f4e87cf
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: exynos: Fix GPIO polarity for thr GalaxyS3 CM36651 sensor's bus (git-fixes)
- commit 30d7221
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: renesas: Fix IOMMU device node names (git-fixes)
- commit 7a45d65
* Thu Nov 25 2021 iivanov@suse.de
- ARM: OMAP2+: pm33xx-core: Make am43xx_get_rtc_base_addr static (git-fixes)
- commit 90f607e
* Thu Nov 25 2021 iivanov@suse.de
- ARM: 8974/1: use SPARSMEM_STATIC when SPARSEMEM is enabled (git-fixes)
- commit b68047e
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: bcm: HR2: Fix PPI interrupt types (git-fixes)
- commit 4868ca3
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: bcm2835-rpi-zero-w: Fix led polarity (git-fixes)
- commit cadf9ee
* Thu Nov 25 2021 iivanov@suse.de
- ARM: 8970/1: decompressor: increase tag size (git-fixes).
- commit 5432f4f
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: r8a7740: Add missing extal2 to CPG node (git-fixes)
- commit b947156
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: r7s9210: Remove bogus clock-names from OSTM nodes (git-fixes)
- commit 392503b
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: r8a73a4: Add missing CMT1 interrupts (git-fixes)
- commit f9adba4
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: imx27-phytec-phycard-s-rdk: Fix the I2C1 pinctrl entries (git-fixes)
- commit f034a63
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: imx6dl-yapp4: Fix Ursa board Ethernet connection (git-fixes)
- commit be4c8ea
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: imx6: Use gpc for FEC interrupt controller to fix wake on LAN (git-fixes)
- commit 9915cbc
* Thu Nov 25 2021 msuchanek@suse.de
- powerpc/watchdog: Fix wd_smp_last_reset_tb reporting
  (bsc#1187541 ltc#192129).
- powerpc/watchdog: read TB close to where it is used (bsc#1187541
  ltc#192129).
- powerpc/watchdog: Avoid holding wd_smp_lock over printk and
  smp_send_nmi_ipi (bsc#1187541 ltc#192129).
- powerpc/watchdog: tighten non-atomic read-modify-write access
  (bsc#1187541 ltc#192129).
- powerpc/watchdog: Fix missed watchdog reset due to memory
  ordering race (bsc#1187541 ltc#192129).
- commit 06565ea
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: imx7-colibri: fix muxing of usbc_det pin (git-fixes)
- commit 82fabab
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: imx7-colibri: prepare module device tree for FlexCAN (git-fixes)
- commit c0216c8
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: uniphier: Set SCSSI clock and reset IDs for each channel (git-fixes).
- commit 15a7e62
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: sunxi: Fix DE2 clocks register range (git-fixes)
- commit 183cef6
* Thu Nov 25 2021 iivanov@suse.de
- ARM: at91: pm: use proper master clock register offset (git-fixes)
- commit 5d631c5
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: oxnas: Fix clear-mask property (git-fixes)
- commit a81f0cc
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: N900: fix onenand timings (git-fixes).
- commit 327315a
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: imx6: phycore-som: fix arm and soc minimum voltage (git-fixes)
- commit 2c192e1
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: sun8i: r40: Move AHCI device node based on address order (git-fixes)
- commit 6a2702e
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: sun8i-a83t-tbs-a711: Fix USB OTG mode detection (git-fixes)
- commit 6bbda66
* Thu Nov 25 2021 iivanov@suse.de
- arm: dts: dra76x: Fix mmc3 max-frequency (git-fixes)
- commit 9bd08fd
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: dra7xx-clocks: Fixup IPU1 mux clock parent source (git-fixes)
- commit cdccd6b
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: am437x-idk-evm: Fix incorrect OPP node names (git-fixes)
- commit 1458ce0
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: imx7-colibri: Fix frequency for sd/mmc (git-fixes)
- commit 799550f
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: imx6dl-colibri-eval-v3: fix sram compatible properties (git-fixes).
- commit 6341187
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: ls1021a: Restore MDIO compatible to gianfar (git-fixes)
- commit 0c57682
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: imx7d: fix opp-supported-hw (git-fixes)
- commit fe91a98
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: imx7d: Correct speed grading fuse settings (git-fixes)
- commit bb0fd16
* Thu Nov 25 2021 iivanov@suse.de
- ARM: dts: imx6: phycore-som: fix emmc supply (git-fixes)
- commit cef9cbd
* Wed Nov 24 2021 tbogendoerfer@suse.de
- i40e: Fix display error code in dmesg (git-fixes).
- i40e: Fix creation of first queue by omitting it if is not
  power of two (git-fixes).
- i40e: Fix warning message and call stack during rmmod i40e
  driver (git-fixes).
- i40e: Fix changing previously set num_queue_pairs for PFs
  (git-fixes).
- i40e: Fix NULL ptr dereference on VSI filter sync (git-fixes).
- i40e: Fix correct max_pkt_size on VF RX queue (git-fixes).
- iavf: Fix for the false positive ASQ/ARQ errors while issuing
  VF reset (git-fixes).
- iavf: validate pointers (git-fixes).
- iavf: prevent accidental free of filter structure (git-fixes).
- iavf: Fix failure to exit out from last all-multicast mode
  (git-fixes).
- iavf: free q_vectors before queues in iavf_disable_vf
  (git-fixes).
- iavf: check for null in iavf_fix_features (git-fixes).
- bnxt_en: reject indirect blk offload when hw-tc-offload is off
  (jsc#SLE-8372 bsc#1153275).
- net: bnx2x: fix variable dereferenced before check (git-fixes).
- cxgb4: fix eeprom len when diagnostics not implemented
  (git-fixes).
- bonding: Fix a use-after-free problem when
  bond_sysfs_slave_add() failed (git-fixes).
- net: delete redundant function declaration (git-fixes).
- gve: Track RX buffer allocation failures (bsc#1176940).
- gve: Allow pageflips on larger pages (bsc#1176940).
- gve: Add netif_set_xps_queue call (bsc#1176940).
- gve: Do lazy cleanup in TX path (git-fixes).
- gve: Add rx buffer pagecnt bias (bsc#1176940).
- gve: Switch to use napi_complete_done (git-fixes).
- gve: DQO: avoid unused variable warnings (bsc#1176940).
- ice: Delete always true check of PF pointer (git-fixes).
- commit 9d613c4
* Wed Nov 24 2021 denis.kirjanov@suse.com
- Update config for dwmac-intel network driver
- commit 04c47bf
* Wed Nov 24 2021 neilb@suse.de
- Delete patches.suse/Fix-breakage-of-swap-over-NFS.patch.
  A recent patch:
  patches.suse/NFS-move-generic_write_checks-call-from-nfs_file_dir.patch
  provides a better solution.
- commit 5504e09
* Wed Nov 24 2021 neilb@suse.de
- SUNRPC/xprt: async tasks mustn't block waiting for memory
  (bsc#1191876).
- SUNRPC: remove scheduling boost for "SWAPPER" tasks
  (bsc#1191876).
- SUNRPC: improve 'swap' handling: scheduling and PF_MEMALLOC
  (bsc#1191876).
- SUNRPC/call_alloc: async tasks mustn't block waiting for memory
  (bsc#1191876).
- SUNRPC/auth: async tasks mustn't block waiting for memory
  (bsc#1191876).
- NFS: move generic_write_checks() call from
  nfs_file_direct_write() to nfs_file_write() (bsc#1191876).
- NFS: do not take i_rwsem for swap IO (bsc#1191876).
- MM: reclaim mustn't enter FS for swap-over-NFS (bsc#1191876).
- commit 6bfb39b
* Tue Nov 23 2021 lduncan@suse.com
- scsi: qla2xxx: Turn off target reset during issue_lip
  (git-fixes).
- scsi: qla2xxx: Fix gnl list corruption (git-fixes).
- scsi: qla2xxx: Relogin during fabric disturbance (git-fixes).
- commit 769bef9
* Tue Nov 23 2021 lduncan@suse.com
- Mark commit as not needed (git-fixes)
- commit 50aa08a
* Tue Nov 23 2021 fdmanana@suse.com
- btrfs: fix fsync failure and transaction abort after writes
  to prealloc extents (bsc#1193002).
- btrfs: do not ignore error from btrfs_next_leaf() when inserting
  checksums (bsc#1193002).
- btrfs: make checksum item extension more efficient
  (bsc#1193002).
- commit 6b9cd09
* Tue Nov 23 2021 fdmanana@suse.com
- btrfs: fix lost inode on log replay after mix of fsync, rename
  and inode eviction (bsc#1192998).
- btrfs: fix race causing unnecessary inode logging during link
  and rename (bsc#1192998).
- commit 08101d8
* Tue Nov 23 2021 denis.kirjanov@suse.com
- net: stmmac: add EHL 2.5Gbps PCI info and PCI ID (bsc#1192691).
- commit 3717dbe
* Tue Nov 23 2021 denis.kirjanov@suse.com
- net: stmmac: add EHL PSE0 & PSE1 1Gbps PCI info and PCI ID
  (bsc#1192691).
- commit af3665c
* Tue Nov 23 2021 denis.kirjanov@suse.com
- net: stmmac: create dwmac-intel.c to contain all Intel platform
  (bsc#1192691).
- commit eea520f
* Tue Nov 23 2021 denis.kirjanov@suse.com
- net: stmmac: pci: Add HAPS support using GMAC5 (bsc#1192691).
- commit 5d3261b
* Tue Nov 23 2021 denis.kirjanov@suse.com
- net: stmmac: add EHL RGMII 1Gbps PCI info and PCI ID
  (bsc#1192691).
- commit 61964c0
* Tue Nov 23 2021 denis.kirjanov@suse.com
- net: stmmac: add TGL SGMII 1Gbps PCI info and PCI ID
  (bsc#1192691).
- commit 22bb342
* Tue Nov 23 2021 denis.kirjanov@suse.com
- net: stmmac: add EHL SGMII 1Gbps PCI info and PCI ID
  (bsc#1192691).
- commit a9fc2ef
* Tue Nov 23 2021 oneukum@suse.com
- blacklist.conf: not necessary in our configurations
- commit f07d2c6
* Tue Nov 23 2021 oneukum@suse.com
- net: hso: fix muxed tty registration (git-fixes).
- commit a80f2e2
* Tue Nov 23 2021 oneukum@suse.com
- net: asix: fix uninit value bugs (git-fixes).
- commit 174a7de
* Tue Nov 23 2021 oneukum@suse.com
- net: usb: Merge cpu_to_le32s + memcpy to put_unaligned_le32
  (git-fixes).
- commit 2d685be
* Tue Nov 23 2021 oneukum@suse.com
- net: pegasus: fix uninit-value in get_interrupt_interval
  (git-fixes).
- commit c9a9fec
* Tue Nov 23 2021 pmladek@suse.com
- printk: Remove printk.h inclusion in percpu.h (bsc#1192987).
- commit 99b7e37
* Tue Nov 23 2021 oneukum@suse.com
- net: hso: fix control-request directions (git-fixes).
- commit 8af2026
* Tue Nov 23 2021 msuchanek@suse.de
- kernel-source.spec: install-kernel-tools also required on 15.4
- commit 6cefb55
* Mon Nov 22 2021 mkubecek@suse.cz
- Update kabi files.
- update from second November 2021 maintenance update submission (commit 9a413cc7eb56)
- commit 5dfdd88
* Mon Nov 22 2021 mkubecek@suse.cz
- series.conf: cleanup
- move mainline backports from subsystem sections to sorted section
  - patches.suse/mm-fix-mremap-not-considering-huge-pmd-devmap.patch
  - patches.suse/block-floppy-fix-contended-case-in-floppy_queue_rq.patch
  - patches.suse/PCI-IOV-Mark-VFs-as-not-implementing-PCI_COMMAND_MEM.patch
  No effect on expanded tree.
- commit 32c4263
* Mon Nov 22 2021 mkubecek@suse.cz
- fix patches metadata
- explicitly mark patches not intended for upstreaming
  - patches.kabi/libnvdimm-cover-up-nd_region-changes.patch
  - patches.suse/Input-Fix-memory-leak-in-psxpad_spi_probe.patch
  - patches.suse/Revert-nvme-allow-64-bit-results-in-passthru-command.patch
  - patches.suse/cdrom-turn-off-autoclose-by-default.patch
  - patches.suse/io_uring-ensure-req-submit-is-copied-when-req-is-def.patch
  - patches.suse/pstore_disable_efi_backend_by_default.patch
  - patches.suse/s390-export-symbols-for-crash-kmp.patch
  - patches.suse/supported-flag-modverdir
  - patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
  - patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch
- commit 55eb2b8
* Mon Nov 22 2021 mkubecek@suse.cz
- series.conf: whitespace and comment cleanup
  No effect on expanded tree.
- commit 1a56fa4
* Mon Nov 22 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  - patches.suse/Bluetooth-sco-Fix-lock_sock-blockage-by-memcpy_from_.patch
  - patches.suse/crypto_ccp-fix_resource_leaks_in_ccp_run_aes_gcm_cmd.patch
  - patches.suse/media-firewire-firedtv-avc-fix-a-buffer-overflow-in-.patch
  - patches.suse/scsi-ibmvfc-Fix-invalid-state-machine-BUG_ON.patch
- move "never" patches into subsystem sections:
  - patches.suse/locking-rwsem-Disable-reader-optimistic-spinning.patch
  - patches.suse/sched-fair-Enable-SIS_AVG_CPU-by-default.patch
  No effect on expanded tree.
- commit b5c6c7d
* Mon Nov 22 2021 mbenes@suse.cz
- blacklist.conf: 70a9ac36ffd8 ("f2fs: fix up f2fs_lookup tracepoints")
  CONFIG_F2FS_FS is not set anywhere.
- commit d108418
* Mon Nov 22 2021 mbenes@suse.cz
- tracing/histogram: Do not copy the fixed-size char array field
  over the field size (git-fixes).
- commit 824b1b8
* Mon Nov 22 2021 jgross@suse.com
- xen/privcmd: fix error handling in mmap-resource processing
  (git-fixes).
- commit 2fc8146
* Mon Nov 22 2021 oneukum@suse.com
- crypto: pcrypt - Delay write to padata->info (git-fixes).
- commit 7c0ca4f
* Mon Nov 22 2021 mbenes@suse.cz
- blacklist.conf: 172f7ba9772c ("ftrace: Make ftrace_profile_pages_init static")
  A cosmetic fix.
- commit eabceca
* Mon Nov 22 2021 mbenes@suse.cz
- tracing: use %%ps format string to print symbols (git-fixes).
- commit a21f67c
* Mon Nov 22 2021 jgross@suse.com
- xen/x86: fix PV trap handling on secondary processors
  (git-fixes).
- commit 22a3e31
* Mon Nov 22 2021 oneukum@suse.com
- blacklist.conf: feature, not bugfix and brealks kABI
- commit 1a7a720
* Mon Nov 22 2021 jgross@suse.com
- swiotlb-xen: avoid double free (git-fixes).
- commit 04818d4
* Mon Nov 22 2021 oneukum@suse.com
- r8152: limit the RX buffer size of RTL8153A for USB 2.0
  (git-fixes).
- commit 9e81786
* Mon Nov 22 2021 shung-hsi.yu@suse.com
- config: refresh BPF configs (jsc#SLE-22574)
  The SUSE-commit 9a413cc7eb56 ("config: disable unprivileged BPF by default
  (jsc#SLE-22573)") inherited from SLE15-SP2 puts the BPF config into the wrong
  place due to SLE15-SP3 additionally backported b24abcff918a ("bpf, kconfig: Add
  consolidated menu entry for bpf with core options"), and leads to duplicate
  CONFIG_BPF_UNPRIV_DEFAULT_OFF entires; this commit remove those BPF config.
  Also, disable unprivileged BPF for armv7hl, which did not inherit the config
  change from SLE15-SP2.
- commit c0c727b
* Mon Nov 22 2021 jgross@suse.com
- x86/Xen: swap NX determination and GDT setup on BSP (git-fixes).
- commit a899c9e
* Mon Nov 22 2021 jgross@suse.com
- blacklist.conf: add 40fdea0284bb208, which depends on 8480ed9c2bbd56
- commit b7c2958
* Mon Nov 22 2021 mkubecek@suse.cz
- config: disable unprivileged BPF by default (jsc#SLE-22573)
  Backport of mainline commit 8a03e56b253e ("bpf: Disallow unprivileged bpf
  by default") only changes kconfig default, used e.g. for "make oldconfig"
  when the config option is missing, but does not update our kernel configs
  used for build. Update also these to make sure unprivileged BPF is really
  disabled by default.
- commit 9a413cc
* Mon Nov 22 2021 tiwai@suse.de
- e1000e: Separate TGP board type from SPT (bsc#1192874).
- commit 836207b
* Sun Nov 21 2021 tiwai@suse.de
- Input: elantench - fix misreporting trackpoint coordinates
  (bsc#1192918).
- commit af3fd37
* Fri Nov 19 2021 mkoutny@suse.com
- mm/hugetlb: initialize hugetlb_usage in mm_init (bsc#1192906).
- commit 4bfee1a
* Fri Nov 19 2021 mkoutny@suse.com
- blacklist.conf: Add 04f8ef5643bc cgroup: Fix memory leak caused by missing cgroup_bpf_offline
- commit d046894
* Fri Nov 19 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  - patches.suse/btrfs-fix-memory-ordering-between-normal-and-ordered-work-functions.patch
- commit 7ca7de6
* Fri Nov 19 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  - patches.suse/scsi-core-Fix-spelling-in-a-source-code-comment
  - patches.suse/scsi-csiostor-Uninitialized-data-in-csio_ln_vnp_read_cbfn
  - patches.suse/scsi-dc395-Fix-error-case-unwinding
  - patches.suse/scsi-ufs-ufshcd-pltfrm-Fix-memory-leak-due-to-probe-defer
- commit 2c768e7
* Fri Nov 19 2021 fdmanana@suse.com
- btrfs: update comments for chunk allocation -ENOSPC cases
  (bsc#1192896).
- btrfs: fix deadlock between chunk allocation and chunk btree
  modifications (bsc#1192896).
- btrfs: block-group: Rework documentation of check_system_chunk
  function (bsc#1192896).
- commit 20b2047
* Fri Nov 19 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  - patches.suse/ipv4-make-exception-cache-less-predictible.patch
  - patches.suse/ipv6-make-exception-cache-less-predictible.patch
  - patches.suse/qtnfmac-fix-potential-spectre-vulnerabilities.patch
- commit 5c2e4e8
* Fri Nov 19 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  - patches.suse/edac-sb_edac-fix-top-of-high-memory-value-for-broadwell-haswell.patch
  - patches.suse/x86-sme-use-define-use_early_pgtable_l5-in-mem_encrypt_identity-c.patch
- commit fd7ddeb
* Fri Nov 19 2021 mkoutny@suse.com
- blacklist.conf: Add 8520e224f547 bpf, cgroups: Fix cgroup v2 fallback on v1/v2 mixed mode
- commit 04918fc
* Fri Nov 19 2021 nborisov@suse.com
- btrfs: fix memory ordering between normal and ordered work functions (git-fixes).
- commit 2b13f6d
* Fri Nov 19 2021 shung-hsi.yu@suse.com
- blacklist.conf: 5c9d706f6133 ("bpf: Fix BPF_LSM kconfig symbol dependency")
  Not needed since 30897832d8b9 ("bpf: Allow local storage to be used from LSM
  programs") is not backported.
- commit 22dfc3c
* Thu Nov 18 2021 msuchanek@suse.de
- Eradicate Patch-mainline: No
  The pre-commit check can reject this deprecated tag then.
- Refresh patches.suse/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch.
- Refresh patches.suse/btrfs-provide-super_operations-get_inode_dev.
- Refresh patches.suse/intel_idle-Disable-ACPI-_CST-on-Haswell.patch
- Eradicate Patch-mainline: No
  The pre-commit check can reject this deprecated tag then.
- Refresh patches.suse/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch.
- Refresh patches.suse/btrfs-provide-super_operations-get_inode_dev.
- commit 6fb97e5
* Thu Nov 18 2021 tiwai@suse.de
- ARM: socfpga: Fix crash with CONFIG_FORTIRY_SOURCE
  (bsc#1192473).
- commit b39e9ef
* Thu Nov 18 2021 shung-hsi.yu@suse.com
- Update
  patches.suse/bpf-Remove-MTU-check-in-__bpf_skb_max_len.patch
  (bsc#1155518 bsc#1192045 CVE-2021-0941).
- commit 5daf798
* Thu Nov 18 2021 shung-hsi.yu@suse.com
- Update
  patches.suse/bpf-Remove-MTU-check-in-__bpf_skb_max_len.patch
  (bsc#1155518 bsc#1192045 CVE-2021-0941).
- commit 33fb6b6
* Thu Nov 18 2021 jbohac@suse.cz
- drm: prevent spectre issue in vmw_execbuf_ioctl (bsc#1192802).
- qtnfmac: fix potential Spectre vulnerabilities (bsc#1192802).
- commit 5952a38
* Wed Nov 17 2021 tiwai@suse.de
- drm/i915: Introduce intel_hpd_hotplug_irqs() (bsc#1192758).
- commit 29d7f7a
* Wed Nov 17 2021 shung-hsi.yu@suse.com
- Update config files: pull BPF configs together
- commit 86a3134
* Wed Nov 17 2021 shung-hsi.yu@suse.com
- bpf: Disallow unprivileged bpf by default (jsc#SLE-22573).
- bpf: Add kconfig knob for disabling unpriv bpf
  by default (jsc#SLE-22573)
- Update config files: Add
  CONFIG_BPF_UNPRIV_DEFAULT_OFF is not set
- commit cb7628d
* Wed Nov 17 2021 tiwai@suse.de
- dm ioctl: fix out of bounds array access when no devices
  (CVE-2021-31916 bsc#1192781).
- commit 49351dc
* Wed Nov 17 2021 shung-hsi.yu@suse.com
- bpf: Disallow unprivileged bpf by default (jsc#SLE-22574).
- commit 7b9dddf
* Wed Nov 17 2021 shung-hsi.yu@suse.com
- bpf: Fix BPF_JIT kconfig symbol dependency
  (git-fixes jsc#SLE-22574).
- bpf: Add kconfig knob for disabling unpriv bpf
  by default (jsc#SLE-22574)
- Update config files: Add
  CONFIG_BPF_UNPRIV_DEFAULT_OFF is not set
- bpf, kconfig: Add consolidated menu entry for bpf with core
  options (jsc#SLE-22574).
- commit 5bd323f
* Tue Nov 16 2021 mcgrof@suse.com
- patches.suse/zram-replace-fsync_bdev-with-sync_blockdev.patch: (bsc#1170269).
- commit 75a41c2
* Tue Nov 16 2021 mcgrof@suse.com
- patches.suse/zram-avoid-race-between-zram_remove-and-disksize_sto.patch: (bsc#1170269).
- commit 406dc3d
* Tue Nov 16 2021 mcgrof@suse.com
- patches.suse/zram-don-t-fail-to-remove-zram-during-unloading-modu.patch: (bsc#1170269).
- commit cb34e92
* Tue Nov 16 2021 mcgrof@suse.com
- patches.suse/zram-fix-race-between-zram_reset_device-and-disksize.patch: (bsc#1170269).
- commit 09f1f4d
* Tue Nov 16 2021 mcgrof@suse.com
- patches.suse/zram-replace-fsync_bdev-with-sync_blockdev.patch: (bsc#1170269).
- commit 6a0e897
* Tue Nov 16 2021 mcgrof@suse.com
- patches.suse/zram-avoid-race-between-zram_remove-and-disksize_sto.patch: (bsc#1170269).
- commit 2c18cb4
* Tue Nov 16 2021 mcgrof@suse.com
- patches.suse/zram-don-t-fail-to-remove-zram-during-unloading-modu.patch: (bsc#1170269).
- commit 913e901
* Tue Nov 16 2021 mcgrof@suse.com
- patches.suse/zram-fix-race-between-zram_reset_device-and-disksize.patch: (bsc#1170269).
- commit 173dc9b
* Tue Nov 16 2021 pmladek@suse.com
- blacklist.conf: printk/workqueue: very hard to hit; works well with lockless
  ringuffer; but it might cause wrong timestamps or even lost messages
  on 5.3 where using par-CPU buffers (bsc#1192750)
- commit 63c8c7f
* Tue Nov 16 2021 pmladek@suse.com
- printk/console: Allow to disable console output by using
  console="" or console=null (bsc#1192753).
- commit 4f99186
* Tue Nov 16 2021 pmladek@suse.com
- printk: handle blank console arguments passed in (bsc#1192753).
- commit db08758
* Tue Nov 16 2021 tiwai@suse.de
- ALSA: hda: fix general protection fault in azx_runtime_idle
  (git-fixes).
- ALSA: hda: Free card instance properly at probe errors
  (git-fixes).
- commit 57f0538
* Tue Nov 16 2021 tiwai@suse.de
- ALSA: usb-audio: Fix dB level of Bose Revolve+ SoundLink
  (bsc#1192375).
- ALSA: usb-audio: Add minimal-mute notion in dB mapping table
  (bsc#1192375).
- ALSA: usb-audio: Use int for dB map values (bsc#1192375).
- commit 561c434
* Tue Nov 16 2021 tiwai@suse.de
- Move upstreamed sound fix into sorted section
- commit b52485e
* Tue Nov 16 2021 ykaukab@suse.de
- net: mscc: ocelot: warn when a PTP IRQ is raised for an unknown
  skb (git-fixes).
- gpio: mpc8xxx: Use 'devm_gpiochip_add_data()' to simplify the
  code and avoid a leak (git-fixes).
- stmmac: platform: Fix signedness bug in stmmac_probe_config_dt()
  (git-fixes).
- net: dsa: felix: re-enable TX flow control in
  ocelot_port_flush() (git-fixes).
- net: mscc: ocelot: fix hardware timestamp dequeue logic.
- commit 4fdc3dd
* Tue Nov 16 2021 pmladek@suse.com
- tracing: Increase PERF_MAX_TRACE_SIZE to handle Sentinel1 and
  docker together (bsc#1192745).
- commit bc3e5c2
* Tue Nov 16 2021 ykaukab@suse.de
- blacklist.conf: add mscc driver fixes
- commit 109b7ec
* Tue Nov 16 2021 msuchanek@suse.de
- kernel-*-subpackage: Add dependency on kernel scriptlets (bsc#1192740).
- commit a133bf4
* Tue Nov 16 2021 iivanov@suse.de
- random: fix crash on multiple early calls to add_bootloader_randomness() (bsc#1184924)
- commit d4705fe
* Tue Nov 16 2021 oneukum@suse.com
- blacklist.conf: changes device names, kABI massacre
- commit 68b0003
* Mon Nov 15 2021 lhenriques@suse.de
- fuse: fix page stealing (bsc#1192718).
- commit 5c46aef
* Mon Nov 15 2021 jbohac@suse.cz
- ipv4: make exception cache less predictible (bsc#1191790,
  CVE-2021-20322).
- ipv6: make exception cache less predictible (bsc#1191790,
  CVE-2021-20322).
- ipv4: use siphash instead of Jenkins in fnhe_hashfun()
  (bsc#1191790, CVE-2021-20322).
- ipv6: use siphash in rt6_exception_hash() (bsc#1191790,
  CVE-2021-20322).
- commit 191e9b3
* Mon Nov 15 2021 jgross@suse.com
- Revert "x86/kvm: fix vcpu-id indexed array sizes" (git-fixes).
- commit 918d1fd
* Mon Nov 15 2021 jgross@suse.com
- Delete patches.kabi/kabi-fix-after-kvm-vcpu-id-array-fix.patch, as
  the patch causing its introduction is being reverted.
- commit 2e03b9d
* Mon Nov 15 2021 jgross@suse.com
- x86/xen: Mark cpu_bringup_and_idle() as dead_end_function
  (git-fixes).
- commit bb35029
* Mon Nov 15 2021 jgross@suse.com
- xen-pciback: Fix return in pm_ctrl_init() (git-fixes).
- commit 94628c1
* Mon Nov 15 2021 jgross@suse.com
- xen: Fix implicit type conversion (git-fixes).
- commit 89e345e
* Sun Nov 14 2021 bp@suse.de
- x86/sme: Use #define USE_EARLY_PGTABLE_L5 in
  mem_encrypt_identity.c (bsc#1152489).
- commit 60c8f9c
* Sat Nov 13 2021 lduncan@suse.com
- scsi: ufs: ufshcd-pltfrm: Fix memory leak due to probe defer
  (git-fixes).
- scsi: csiostor: Uninitialized data in csio_ln_vnp_read_cbfn()
  (git-fixes).
- scsi: core: Fix spelling in a source code comment (git-fixes).
- scsi: dc395: Fix error case unwinding (git-fixes).
- scsi: qla2xxx: Fix a memory leak in an error path of
  qla2x00_process_els() (git-fixes).
- scsi: csiostor: Add module softdep on cxgb4 (git-fixes).
- scsi: qedf: Fix error codes in qedf_alloc_global_queues()
  (git-fixes).
- scsi: qedi: Fix error codes in qedi_alloc_global_queues()
  (git-fixes).
- scsi: smartpqi: Fix an error code in pqi_get_raid_map()
  (git-fixes).
- scsi: fdomain: Fix error return code in fdomain_probe()
  (git-fixes).
- scsi: BusLogic: Fix missing pr_cont() use (git-fixes).
- scsi: iscsi: Fix iface sysfs attr detection (git-fixes).
- scsi: be2iscsi: Fix an error handling path in
  beiscsi_dev_probe() (git-fixes).
- scsi: mpt3sas: Fix error return value in _scsih_expander_add()
  (git-fixes).
- scsi: FlashPoint: Rename si_flags field (git-fixes).
- scsi: snic: Fix an error message (git-fixes).
- scsi: libsas: Use _safe() loop in sas_resume_port() (git-fixes).
- scsi: qedf: Add pointer checks in qedf_update_link_speed()
  (git-fixes).
- Revert "scsi: ufs: fix a missing check of
  devm_reset_control_get" (git-fixes).
- scsi: ufs-pci: Add quirk for broken auto-hibernate for Intel
  EHL (git-fixes).
- scsi: qla2xxx: Make sure that aborted commands are freed
  (git-fixes).
- commit c10ecb2
* Fri Nov 12 2021 ykaukab@suse.de
- supported.conf: add pwm-rockchip
  References: jsc#SLE-22615
- commit 1a3be5a
* Fri Nov 12 2021 bp@suse.de
- EDAC/sb_edac: Fix top-of-high-memory value for Broadwell/Haswell
  (bsc#1152489).
- commit e920f56
* Fri Nov 12 2021 ptesarik@suse.cz
- s390/qeth: fix deadlock during failing recovery (git-fixes).
- s390/qeth: Fix deadlock in remove_discipline (git-fixes).
- s390/qeth: fix NULL deref in qeth_clear_working_pool_list()
  (git-fixes).
- commit 8d9df1e
* Fri Nov 12 2021 ptesarik@suse.cz
- s390/pci: fix zpci_zdev_put() on reserve (git-fixes).
- commit 5f2d7a4
* Fri Nov 12 2021 ptesarik@suse.cz
- net/smc: fix 'workqueue leaked lock' in smc_conn_abort_work
  (git-fixes).
- s390/pci: fix use after free of zpci_dev (git-fixes).
- net/smc: Correct smc link connection counter in case of smc
  client (git-fixes).
- s390/dasd: fix use after free in dasd path handling (git-fixes).
- s390/topology: clear thread/group maps for offline cpus
  (git-fixes).
- commit 4287499
* Thu Nov 11 2021 msuchanek@suse.de
- Fix problem with missing installkernel on Tumbleweed.
- commit 2ed6686
* Wed Nov 10 2021 neilb@suse.de
- Update patches.suse/NFS-Do-uncached-readdir-when-we-re-seeking-a-cookie-.patch
  (bsc#1191628 bsc#1192549).
  dir_cookie is a pointer to the cookie in older kernels,
  not the cookie itself.
- commit ee8ec20
* Wed Nov 10 2021 msuchanek@suse.de
- ibmvnic: Process crqs after enabling interrupts (bsc#1192273
  ltc#194629).
- ibmvnic: don't stop queue in xmit (bsc#1192273 ltc#194629).
- commit 99d6daa
* Wed Nov 10 2021 msuchanek@suse.de
- Revert "ibmvnic: check failover_pending in login response"
  (bsc#1190523 ltc#194510).
- ibmvnic: check failover_pending in login response (bsc#1190523
  ltc#194510).
- commit ac4c874
* Wed Nov 10 2021 acho@suse.com
- Bluetooth: cmtp: fix file refcount when cmtp_attach_device fails
  (bsc#1191961 CVE-2021-34981).
- commit a4ff591
* Wed Nov 10 2021 denis.kirjanov@suse.com
- Update kabi files.
- commit 6361848
* Wed Nov 10 2021 oneukum@suse.com
- Revert "r8152: adjust the settings about MAC clock speed down
  for RTL8153" (git-fixes).
- commit 541bc3e
* Wed Nov 10 2021 oneukum@suse.com
- r8152: don't enable U1U2 with USB_SPEED_HIGH for RTL8153B
  (git-fixes).
- commit e20d73d
* Wed Nov 10 2021 oneukum@suse.com
- r8152: Disable PLA MCU clock speed down (git-fixes).
- Refresh patches.suse/r8152-disable-test-IO-for-RTL8153B.patch.
- commit 9b878a2
* Wed Nov 10 2021 oneukum@suse.com
- r8152: disable U2P3 for RTL8153B (git-fixes).
- commit d6c58f7
* Wed Nov 10 2021 oneukum@suse.com
- r8152: reset flow control patch when linking on for RTL8153B
  (git-fixes).
- commit 7f46ee2
* Wed Nov 10 2021 oneukum@suse.com
- r8152: fix runtime resume for linking change (git-fixes).
- commit 0ff2979
* Wed Nov 10 2021 oneukum@suse.com
- r8152: Add macpassthru support for ThinkPad Thunderbolt 3 Dock
  Gen 2 (git-fixes).
- commit d73c455
* Wed Nov 10 2021 oneukum@suse.com
- r8152: add a helper function about setting EEE (git-fixes).
- commit 5f95fd2
* Wed Nov 10 2021 oneukum@suse.com
- r8152: divide the tx and rx bottom functions (git-fixes).
- Refresh
  patches.suse/r8152-Re-order-napi_disable-in-rtl8152_close.patch.
- Refresh
  patches.suse/r8152-avoid-to-call-napi_disable-twice.patch.
- commit 248b976
* Wed Nov 10 2021 oneukum@suse.com
- r8152: saving the settings of EEE (git-fixes).
- commit 7c0dac3
* Wed Nov 10 2021 oneukum@suse.com
- r8152: use alloc_pages for rx buffer (git-fixes).
- commit 3304002
* Wed Nov 10 2021 oneukum@suse.com
- r8152: replace array with linking list for rx information
  (git-fixes).
- commit b5a7bd7
* Wed Nov 10 2021 oneukum@suse.com
- r8152: separate the rx buffer size (git-fixes).
- commit 4176c6f
* Wed Nov 10 2021 oneukum@suse.com
- rndis_host: set proper input size for OID_GEN_PHYSICAL_MEDIUM
  request (git-fixes).
- commit 3af49ca
* Tue Nov  9 2021 oneukum@suse.com
- crypto: qat - disregard spurious PFVF interrupts (git-fixes).
- commit 11f64ca
* Tue Nov  9 2021 oneukum@suse.com
- crypto: qat - detect PFVF collision after ACK (git-fixes).
- commit fa10b1f
* Tue Nov  9 2021 oneukum@suse.com
- crypto: caam - disable pkc for non-E SoCs (git-fixes).
- commit 49a0bf8
* Tue Nov  9 2021 oneukum@suse.com
- blacklist.conf: build warning only
- commit 389a467
* Tue Nov  9 2021 denis.kirjanov@suse.com
- kabi/severities: update kabi list
- commit 5cf2719
* Tue Nov  9 2021 shung-hsi.yu@suse.com
- bpf: Fix potential race in tail call compatibility check
  (git-fixes).
- commit 6fdd9c7
* Tue Nov  9 2021 dbueso@suse.de
- cgroup/cpuset: Change references of cpuset_mutex to cpuset_rwsem (git-fixes).
- commit c3f4c78
* Mon Nov  8 2021 rgoldwyn@suse.com
- exfat: handle wrong stream entry size in exfat_readdir()
  (git-fixes).
- exfat: fix erroneous discard when clear cluster bit
  (git-fixes).
- commit 366e900
* Mon Nov  8 2021 rgoldwyn@suse.com
- exfat: truncate atimes to 2s granularity  (bsc#1192328).
- Refresh
  patches.suse/exfat-fix-use-of-uninitialized-spinlock-on-error-path.patch.
- exfat: properly set s_time_gran  (bsc#1192328).
- commit 832525a
* Mon Nov  8 2021 tiwai@suse.de
- Drop two USB patches that are reverted by stable 5.4.158
  Deleted:
  patches.suse/usb-core-hcd-Add-support-for-deferring-roothub-regis.patch
  patches.suse/xhci-Set-HCD-flag-to-defer-primary-roothub-registrat.patch
  blacklist.conf: updated
- commit 10f1374
* Mon Nov  8 2021 tiwai@suse.de
- serial: xilinx_uartps: Fix race condition causing stuck TX
  (git-fixes).
- serial: 8250_dw: Drop wrong use of ACPI_PTR() (git-fixes).
- staging: rtl8192u: fix control-message timeouts (git-fixes).
- USB: serial: keyspan: fix memleak on probe errors (git-fixes).
- USB: iowarrior: fix control-message timeouts (git-fixes).
- usb: musb: Balance list entry in musb_gadget_queue (git-fixes).
- usb: max-3421: Use driver data instead of maintaining a list
  of bound devices (git-fixes).
- usb: gadget: hid: fix error code in do_config() (git-fixes).
- commit b954450
* Mon Nov  8 2021 tiwai@suse.de
- power: supply: bq27xxx: Fix kernel crash on IRQ handler register
  error (git-fixes).
- power: supply: max17042_battery: Prevent int underflow in
  set_soc_threshold (git-fixes).
- =?UTF-8?q?power:=20supply:=20rt5033=5Fbattery:=20Change?=
  =?UTF-8?q?=20voltage=20values=20to=20=C2=B5V?= (git-fixes).
- power: supply: max17042_battery: use VFSOC for capacity when
  no rsns (git-fixes).
- iio: dac: ad5446: Fix ad5622_write() return value (git-fixes).
- staging: r8712u: fix control-message timeout (git-fixes).
- Revert "platform/x86: i2c-multi-instantiate: Don't create
  platform device for INT3515 ACPI nodes" (git-fixes).
- commit 0f3a4f1
* Mon Nov  8 2021 tiwai@suse.de
- PCI: uniphier: Serialize INTx masking/unmasking and fix the
  bit operation (git-fixes).
- PCI: aardvark: Read all 16-bits from PCIE_MSI_PAYLOAD_REG
  (git-fixes).
- PCI: aardvark: Fix return value of MSI domain .alloc() method
  (git-fixes).
- PCI: pci-bridge-emul: Fix emulation of W1C bits (git-fixes).
- HID: u2fzero: properly handle timeouts in usb_submit_urb
  (git-fixes).
- HID: u2fzero: clarify error check and length calculations
  (git-fixes).
- pinctrl: core: fix possible memory leak in pinctrl_enable()
  (git-fixes).
- video: fbdev: chipsfb: use memset_io() instead of memset()
  (git-fixes).
- ABI: sysfs-kernel-slab: Document some stats (git-fixes).
- commit 92991a1
* Mon Nov  8 2021 tiwai@suse.de
- auxdisplay: ht16k33: Fix frame buffer device blanking
  (git-fixes).
- auxdisplay: ht16k33: Connect backlight to fbdev (git-fixes).
- auxdisplay: img-ascii-lcd: Fix lock-up when displaying empty
  string (git-fixes).
- PCI: aardvark: Fix reporting Data Link Layer Link Active
  (git-fixes).
- PCI: aardvark: Fix checking for link up via LTSSM state
  (git-fixes).
- PCI: aardvark: Do not unmask unused interrupts (git-fixes).
- PCI: aardvark: Do not clear status bits of masked interrupts
  (git-fixes).
- PCI: aardvark: Don't spam about PIO Response Status (git-fixes).
- commit 3e5c258
* Mon Nov  8 2021 tiwai@suse.de
- ALSA: usb-audio: Add Audient iD14 to mixer map quirk table
  (git-fixes).
- ALSA: usb-audio: Add Schiit Hel device to mixer map quirk table
  (git-fixes).
- commit b23c22d
* Mon Nov  8 2021 jack@suse.cz
- ocfs2: do not zero pages beyond i_size (bsc#1190795).
- commit 5f3b3d8
* Mon Nov  8 2021 jack@suse.cz
- ocfs2: fix data corruption on truncate (bsc#1190795).
- commit 4b0d91a
* Mon Nov  8 2021 mbenes@suse.cz
- ftrace: Fix scripts/recordmcount.pl due to new binutils
  (bsc#1192267).
- commit f07ed1b
* Mon Nov  8 2021 jroedel@suse.de
- PCI/ACPI: Check for _OSC support in acpi_pci_osc_control_set()
  (bsc#1169263).
- PCI/ACPI: Move _OSC query checks to separate function
  (bsc#1169263).
- PCI/ACPI: Move supported and control calculations to separate
  functions (bsc#1169263).
- PCI/ACPI: Remove OSC_PCI_SUPPORT_MASKS and OSC_PCI_CONTROL_MASKS
  (bsc#1169263).
- PCI/ACPI: Clarify message about _OSC failure (bsc#1169263).
- PCI/ACPI: Remove unnecessary osc_lock (bsc#1169263).
- commit a38114a
* Sun Nov  7 2021 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort
  - patches.suse/scsi-lpfc-Adjust-bytes-received-vales-during-cmf-tim.patch
  - patches.suse/scsi-lpfc-Allow-PLOGI-retry-if-previous-PLOGI-was-ab.patch
  - patches.suse/scsi-lpfc-Allow-fabric-node-recovery-if-recovery-is-.patch
  - patches.suse/scsi-lpfc-Correct-sysfs-reporting-of-loop-support-af.patch
  - patches.suse/scsi-lpfc-Don-t-release-final-kref-on-Fport-node-whi.patch
  - patches.suse/scsi-lpfc-Don-t-remove-ndlp-on-PRLI-errors-in-P2P-mo.patch
  - patches.suse/scsi-lpfc-Fix-EEH-support-for-NVMe-I-O.patch
  - patches.suse/scsi-lpfc-Fix-FCP-I-O-flush-functionality-for-TMF-ro.patch
  - patches.suse/scsi-lpfc-Fix-I-O-block-after-enabling-managed-conge.patch
  - patches.suse/scsi-lpfc-Fix-NVMe-I-O-failover-to-non-optimized-pat.patch
  - patches.suse/scsi-lpfc-Fix-hang-on-unload-due-to-stuck-fport-node.patch
  - patches.suse/scsi-lpfc-Fix-link-down-processing-to-address-NULL-p.patch
  - patches.suse/scsi-lpfc-Fix-list_add-corruption-in-lpfc_drain_txq.patch
  - patches.suse/scsi-lpfc-Fix-premature-rpi-release-for-unsolicited-.patch
  - patches.suse/scsi-lpfc-Fix-rediscovery-of-tape-device-after-LIP.patch
  - patches.suse/scsi-lpfc-Fix-use-after-free-in-lpfc_unreg_rpi-routi.patch
  - patches.suse/scsi-lpfc-Improve-PBDE-checks-during-SGL-processing.patch
  - patches.suse/scsi-lpfc-Revert-LOG_TRACE_EVENT-back-to-LOG_INIT-pr.patch
  - patches.suse/scsi-lpfc-Update-lpfc-version-to-14.0.0.2.patch
  - patches.suse/scsi-lpfc-Update-lpfc-version-to-14.0.0.3.patch
  - patches.suse/scsi-lpfc-Wait-for-successful-restart-of-SLI3-adapte.patch
  - patches.suse/scsi-lpfc-Zero-CGN-stats-only-during-initial-driver-.patch
  - patches.suse/scsi-qla2xxx-Add-support-for-mailbox-passthru.patch
  - patches.suse/scsi-qla2xxx-Call-process_response_queue-in-Tx-path.patch
  - patches.suse/scsi-qla2xxx-Check-for-firmware-capability-before-cr.patch
  - patches.suse/scsi-qla2xxx-Display-16G-only-as-supported-speeds-fo.patch
  - patches.suse/scsi-qla2xxx-Fix-crash-in-NVMe-abort-path.patch
  - patches.suse/scsi-qla2xxx-Fix-kernel-crash-when-accessing-port_sp.patch
  - patches.suse/scsi-qla2xxx-Fix-use-after-free-in-eh_abort-path.patch
  - patches.suse/scsi-qla2xxx-Move-heartbeat-handling-from-DPC-thread.patch
  - patches.suse/scsi-qla2xxx-Remove-redundant-initialization-of-poin.patch
  - patches.suse/scsi-qla2xxx-Update-version-to-10.02.07.100-k.patch
  - patches.suse/scsi-qla2xxx-edif-Use-link-event-to-wake-up-app.patch
  No effect on expanded tree.
- commit 69f2186
* Fri Nov  5 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/ibmvnic-Consolidate-code-in-replenish_rx_pool.patch.
- Refresh
  patches.suse/ibmvnic-Fix-up-some-comments-and-messages.patch.
- Refresh patches.suse/ibmvnic-Reuse-LTB-when-possible.patch.
- Refresh patches.suse/ibmvnic-Reuse-rx-pools-when-possible.patch.
- Refresh patches.suse/ibmvnic-Reuse-tx-pools-when-possible.patch.
- Refresh patches.suse/ibmvnic-Use-bitmap-for-LTB-map_ids.patch.
- Refresh
  patches.suse/ibmvnic-Use-rename-local-vars-in-init_rx_pools.patch.
- Refresh
  patches.suse/ibmvnic-Use-rename-local-vars-in-init_tx_pools.patch.
- Refresh
  patches.suse/ibmvnic-init_tx_pools-move-loop-invariant-code.patch.
  Metadata update
- commit 62eb415
* Fri Nov  5 2021 jeyu@suse.de
- README.BRANCH: Add Oscar Salvador as SLE15-SP3 maintainer
- commit 8e13353
* Fri Nov  5 2021 tiwai@suse.de
- Update patch reference for ISDN fix (CVE-2021-43389 bsc#1191958)
- commit b343e2f
* Thu Nov  4 2021 bp@suse.de
- EDAC/amd64: Set proper family type for Family 19h Models 20h-2Fh
  (bsc#1192288).
- commit a0f44db
* Thu Nov  4 2021 oneukum@suse.com
- Update
  patches.suse/usb-hso-fix-error-handling-code-of-hso_create_net_de.patch
  (bsc#1188601 CVE-2021-37159).
  Added bsc and CVE numbers
- commit e17f2ff
* Thu Nov  4 2021 jroedel@suse.de
- kABI: Fix kABI after 36950f2da1ea (bsc#1191851).
- commit 659ddc7
* Thu Nov  4 2021 tiwai@suse.de
- ASoC: topology: Fix stub for snd_soc_tplg_component_remove()
  (git-fixes).
- ASoC: SOF: topology: do not power down primary core during
  topology removal (git-fixes).
- ALSA: ua101: fix division by zero at probe (git-fixes).
- ALSA: uapi: Fix a C++ style comment in asound.h (git-fixes).
- ALSA: hda: Use position buffer for SKL+ again (git-fixes).
- ALSA: hda: Reduce udelay() at SKL+ position reporting
  (git-fixes).
- ALSA: hda/realtek: Fix mic mute LED for the HP Spectre x360 14
  (git-fixes).
- commit a82ebfb
* Thu Nov  4 2021 tiwai@suse.de
- memory: fsl_ifc: fix leak of irq and nand_irq in
  fsl_ifc_ctrl_probe (git-fixes).
- ASoC: dt-bindings: cs42l42: Correct description of ts-inv
  (git-fixes).
- ASoC: mediatek: mt8195: Remove unsued irqs_lock (git-fixes).
- ASoC: rockchip: Use generic dmaengine code (git-fixes).
- ASoC: cs42l42: Defer probe if request_threaded_irq() returns
  EPROBE_DEFER (git-fixes).
- ASoC: cs42l42: Don't set defaults for volatile registers
  (git-fixes).
- ASoC: cs42l42: Correct some register default values (git-fixes).
- ALSA: ua101: fix division by zero at probe (git-fixes).
- ALSA: hda: Reduce udelay() at SKL+ position reporting
  (git-fixes).
- platform/x86: thinkpad_acpi: Fix bitwise vs. logical warning
  (git-fixes).
- commit 7e1e84d
* Wed Nov  3 2021 tiwai@suse.de
- Update patch reference for AMDGPU fix (bsc#1180749)
- commit 6ea4cbc
* Wed Nov  3 2021 tiwai@suse.de
- drm/amdgpu/gmc6: fix DMA mask from 44 to 40 bits (git-fixes).
- drm/amdgpu/display: add quirk handling for stutter mode
  (git-fixes).
- drm/msm: uninitialized variable in msm_gem_import() (git-fixes).
- drm/msm: potential error pointer dereference in init()
  (git-fixes).
- drm/ttm: stop calling tt_swapin in vm_access (git-fixes).
- PM: sleep: Do not let "syscore" devices runtime-suspend during
  system transitions (git-fixes).
- iwlwifi: mvm: fix some kerneldoc issues (git-fixes).
- mt76: mt7915: fix muar_idx in mt7915_mcu_alloc_sta_req()
  (git-fixes).
- mt76: mt7915: fix sta_rec_wtbl tag len (git-fixes).
- mt76: mt7915: fix possible infinite loop release semaphore
  (git-fixes).
- mt76: mt7615: fix endianness warning in mt7615_mac_write_txwi
  (git-fixes).
- ath10k: sdio: Add missing BH locking around napi_schdule()
  (git-fixes).
- commit a012b20
* Wed Nov  3 2021 tiwai@suse.de
- regulator: dt-bindings: samsung,s5m8767: correct
  s5m8767,pmic-buck-default-dvs-idx property (git-fixes).
- regulator: s5m8767: do not use reset value as DVS voltage if
  GPIO DVS is disabled (git-fixes).
- mmc: mxs-mmc: disable regulator on error and in the remove
  function (git-fixes).
- memstick: jmb38x_ms: use appropriate free function in
  jmb38x_ms_alloc_host() (git-fixes).
- memstick: avoid out-of-range warning (git-fixes).
- mmc: sdhci-omap: Fix NULL pointer exception if regulator is
  not configured (git-fixes).
- media: ite-cir: IR receiver stop working after receive overflow
  (git-fixes).
- tpm: Check for integer overflow in tpm2_map_response_body()
  (git-fixes).
- commit d39cbe5
* Wed Nov  3 2021 tiwai@suse.de
- media: dvb-frontends: mn88443x: Handle errors of
  clk_prepare_enable() (git-fixes).
- media: em28xx: Don't use ops->suspend if it is NULL (git-fixes).
- media: cedrus: Fix SUNXI tile size calculation (git-fixes).
- media: mxl111sf: change mutex_init() location (git-fixes).
- media: cx23885: Fix snd_card_free call on null card pointer
  (git-fixes).
- media: tm6000: Avoid card name truncation (git-fixes).
- media: si470x: Avoid card name truncation (git-fixes).
- media: radio-wl1273: Avoid card name truncation (git-fixes).
- media: i2c: ths8200 needs V4L2_ASYNC (git-fixes).
- media: mtk-vpu: Fix a resource leak in the error handling path
  of 'mtk_vpu_probe()' (git-fixes).
- commit db843c8
* Wed Nov  3 2021 tiwai@suse.de
- hwrng: mtk - Force runtime pm ops for sleep ops (git-fixes).
- hwmon: (pmbus/lm25066) Let compiler determine outer dimension
  of lm25066_coeff (git-fixes).
- hwmon: (pmbus/lm25066) Add offset coefficients (git-fixes).
- media: TDA1997x: handle short reads of hdmi info frame
  (git-fixes).
- media: v4l2-ioctl: S_CTRL output the right value (git-fixes).
- media: v4l2-ioctl: Fix check_ext_ctrls (git-fixes).
- media: staging/intel-ipu3: css: Fix wrong size comparison
  imgu_css_fw_init (git-fixes).
- media: dvb-usb: fix ununit-value in az6027_rc_query (git-fixes).
- media: cxd2880-spi: Fix a null pointer dereference on error
  handling path (git-fixes).
- media: em28xx: add missing em28xx_close_extension (git-fixes).
- commit cc194ed
* Wed Nov  3 2021 tiwai@suse.de
- virtio-gpu: fix possible memory allocation failure (git-fixes).
- rsi: fix control-message timeout (git-fixes).
- rtl8187: fix control-message timeouts (git-fixes).
- wcn36xx: add proper DMA memory barriers in rx path (git-fixes).
- wcn36xx: Fix HT40 capability for 2Ghz band (git-fixes).
- wcn36xx: Add ability for wcn36xx_smd_dump_cmd_req to pass
  two's complement (git-fixes).
- hwmon: Fix possible memleak in __hwmon_device_register()
  (git-fixes).
- firmware/psci: fix application of sizeof to pointer (git-fixes).
- usbnet: fix error return code in usbnet_probe() (git-fixes).
- usbnet: sanity check for maxpacket (git-fixes).
- commit 4c5043d
* Wed Nov  3 2021 tiwai@suse.de
- mwifiex: fix division by zero in fw download path (git-fixes).
- libertas_tf: Fix possible memory leak in probe and disconnect
  (git-fixes).
- mt76: mt76x02: fix endianness warnings in mt76x02_mac.c
  (git-fixes).
- mwifiex: Send DELBA requests according to spec (git-fixes).
- rsi: stop thread firstly in rsi_91x_init() error handling
  (git-fixes).
- rsi: Fix module dev_oper_mode parameter description (git-fixes).
- mmc: sdhci: Map more voltage level to SDHCI_POWER_330
  (git-fixes).
- commit e68a671
* Wed Nov  3 2021 tiwai@suse.de
- drm/msm: Fix potential NULL dereference in DPU SSPP (git-fixes).
- drm/amdgpu: fix warning for overflow check (git-fixes).
- drm/v3d: fix wait for TMU write combiner flush (git-fixes).
- drm/sun4i: Fix macros in sun8i_csc.h (git-fixes).
- libertas: Fix possible memory leak in probe and disconnect
  (git-fixes).
- b43legacy: fix a lower bounds test (git-fixes).
- Bluetooth: btmtkuart: fix a memleak in mtk_hci_wmt_sync
  (git-fixes).
- Bluetooth: fix init and cleanup of sco_conn.timeout_work
  (git-fixes).
- commit 58db500
* Wed Nov  3 2021 tiwai@suse.de
- ath6kl: fix division by zero in send path (git-fixes).
- ath10k: fix division by zero in send path (git-fixes).
- ath6kl: fix control-message timeout (git-fixes).
- ath10k: fix control-message timeout (git-fixes).
- ath10k: fix max antenna gain unit (git-fixes).
- ath9k: Fix potential interrupt storm on queue reset (git-fixes).
- b43: fix a lower bounds test (git-fixes).
- ath10k: Fix missing frame timestamp for beacon/probe-resp
  (git-fixes).
- ata: sata_mv: Fix the error handling of mv_chip_id()
  (git-fixes).
- commit 276cbd3
* Wed Nov  3 2021 tiwai@suse.de
- Input: i8042 - Add quirk for Fujitsu Lifebook T725
  (bsc#1191980).
- commit 9545e5e
* Wed Nov  3 2021 bp@suse.de
- x86/msi: Force affinity setup before startup (bsc#1152489).
- Refresh
  patches.suse/0002-x86-msi-Only-use-high-bits-of-MSI-address-for-DMAR-u.patch.
- commit a7cad27
* Wed Nov  3 2021 msuchanek@suse.de
- ibmvnic: delay complete() (bsc#1094840 ltc#167098 git-fixes).
- commit f2c4d71
* Tue Nov  2 2021 ailiop@suse.com
- xfs: don't allow log writes if the data device is readonly
  (bsc#1192229).
- commit 67ee0ba
* Tue Nov  2 2021 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  - patches.suse/ibmvnic-Consolidate-code-in-replenish_rx_pool.patch
  - patches.suse/ibmvnic-Fix-up-some-comments-and-messages.patch
  - patches.suse/ibmvnic-Reuse-LTB-when-possible.patch
  - patches.suse/ibmvnic-Reuse-rx-pools-when-possible.patch
  - patches.suse/ibmvnic-Reuse-tx-pools-when-possible.patch
  - patches.suse/ibmvnic-Use-bitmap-for-LTB-map_ids.patch
  - patches.suse/ibmvnic-Use-rename-local-vars-in-init_rx_pools.patch
  - patches.suse/ibmvnic-Use-rename-local-vars-in-init_tx_pools.patch
  - patches.suse/ibmvnic-init_tx_pools-move-loop-invariant-code.patch
- commit 35d2ed0
* Tue Nov  2 2021 mkubecek@suse.cz
- Update kabi files.
- update from November 2021 maintenance update submission (commit fb4a33cb1752)
- commit 24b46c0
* Tue Nov  2 2021 bp@suse.de
- x86/ioapic: Force affinity setup before startup (bsc#1152489).
- commit 305e50a
* Tue Nov  2 2021 bp@suse.de
- genirq: Provide IRQCHIP_AFFINITY_PRE_STARTUP (bsc#1152489).
- commit e709b2b
* Tue Nov  2 2021 ykaukab@suse.de
- gpio/rockchip: fetch deferred output settings on probe
  (bsc#1192217).
- pinctrl/rockchip: add a queue for deferred pin output settings
  on probe (bsc#1192217).
- gpio/rockchip: fix get_direction value handling (bsc#1192217).
- gpio/rockchip: extended debounce support is only available on v2
  (bsc#1192217).
- pinctrl/rockchip: drop the gpio related codes (bsc#1192217).
- gpio/rockchip: drop irq_gc_lock/irq_gc_unlock for irq set type
  (bsc#1192217).
- gpio/rockchip: support next version gpio controller
  (bsc#1192217).
- gpio/rockchip: use struct rockchip_gpio_regs for gpio controller
  (bsc#1192217).
- gpio/rockchip: add driver for rockchip gpio (bsc#1192217).
- pinctrl/rockchip: add pinctrl device to gpio bank struct
  (bsc#1192217).
- pinctrl/rockchip: separate struct rockchip_pin_bank to a head
  file (bsc#1192217).
- pinctrl/rockchip: always enable clock for gpio controller
  (bsc#1192217).
- pinctrl: rockchip: do coding style for mux route struct
  (bsc#1192217).
- pinctrl: rockchip: add support for rk3568 (bsc#1192217).
- pinctrl: rockchip: make driver be tristate module (bsc#1192217).
- pinctrl: rockchip: clear int status when driver probed
  (bsc#1192217).
- pinctrl: rockchip: create irq mapping in gpio_to_irq
  (bsc#1192217).
- pinctrl: rockchip: enable gpio pclk for rockchip_gpio_to_irq
  (bsc#1192217).
- pinctrl: rockchip: Replace HTTP links with HTTPS ones
  (bsc#1192217).
- pinctrl: pinctrl-rockchip: Fix a bunch of kerneldoc
  misdemeanours (bsc#1192217).
- pinctrl: rockchip: return ENOMEM instead of EINVAL if allocation
  fails (bsc#1192217).
- pinctrl: rockchip: add rk3308 SoC support (bsc#1192217).
- commit de4b584
* Tue Nov  2 2021 jroedel@suse.de
- nvme-pci: set min_align_mask (bsc#1191851).
- swiotlb: respect min_align_mask (bsc#1191851).
- swiotlb: don't modify orig_addr in swiotlb_tbl_sync_single
  (bsc#1191851).
- swiotlb: refactor swiotlb_tbl_map_single (bsc#1191851).
- swiotlb: clean up swiotlb_tbl_unmap_single (bsc#1191851).
- swiotlb: factor out a nr_slots helper (bsc#1191851).
- swiotlb: factor out an io_tlb_offset helper (bsc#1191851).
- swiotlb: add a IO_TLB_SIZE define (bsc#1191851).
- commit 63c0e38
* Tue Nov  2 2021 jroedel@suse.de
- driver core: add a min_align_mask field to struct
  device_dma_parameters (bsc#1191851).
- commit cb95969
* Tue Nov  2 2021 acho@suse.com
- KVM: s390: index kvm->arch.idle_mask by vcpu_idx (bsc#1133021).
- KVM: s390: VSIE: correctly handle MVPG when in VSIE
  (bsc#1133021).
- KVM: s390: extend kvm_s390_shadow_fault to return entry pointer
  (bsc#1133021).
- KVM: s390: split kvm_s390_logical_to_effective (bsc#1133021).
- commit ef66201
* Tue Nov  2 2021 mbenes@suse.cz
- blacklist.conf: ed65df63a39a ("tracing: Have all levels of checks prevent recursion")
  It fixes a corner case, which should be rare. The patch changes a public
  header file and even if the API should not be used externally, there is
  always a risk.
- commit 80def7c
* Mon Nov  1 2021 bp@suse.de
- x86/reboot: Limit Dell Optiplex 990 quirk to early BIOS versions
  (bsc#1152489).
- commit 96ee990
* Mon Nov  1 2021 mkubecek@suse.cz
- netfilter: conntrack: collect all entries in one cycle
  (bsc#1173604).
- commit c4117de
* Mon Nov  1 2021 mkubecek@suse.cz
- ipv6/netfilter: Discard first fragment not including all headers
  (bsc#1191241).
- IPv6: reply ICMP error if the first fragment don't include
  all headers (bsc#1191241).
- ICMPv6: Add ICMPv6 Parameter Problem, code 3 definition
  (bsc#1191241).
- net: ipv6: Discard next-hop MTU less than minimum link MTU
  (bsc#1191241).
- commit c74316d
* Mon Nov  1 2021 jroedel@suse.de
- swiotlb: Split size parameter to map/unmap APIs (bsc#1191851).
- Refresh
  patches.suse/dma-direct-exclude-dma_direct_map_resource-from-the-min_low_pfn-check.patch.
- commit 0eae9b5
* Mon Nov  1 2021 msuchanek@suse.de
- KVM: PPC: Book3S HV: Tolerate treclaim. in fake-suspend mode
  changing registers (bsc#1156395).
- KVM: PPC: Fix clearing never mapped TCEs in realmode
  (bsc#1156395).
- KVM: PPC: Book3S HV Nested: Reflect guest PMU in-use to L0
  when guest SPRs are live (bsc#1156395).
- KVM: PPC: Book3S HV Nested: Sanitise H_ENTER_NESTED TM state
  (bsc#1156395).
- KVM: PPC: Fix kvm_arch_vcpu_ioctl vcpu_load leak (bsc#1156395).
- commit 2ce76cc
* Mon Nov  1 2021 msuchanek@suse.de
- powerpc/xive: Discard disabled interrupts in get_irqchip_state()
  (fate#322438 bsc#1085030 git-fixes).
- commit 3106974
* Mon Nov  1 2021 msuchanek@suse.de
- powerpc/64s: Remove irq mask workaround in
  accumulate_stolen_time() (jsc#SLE-9246 git-fixes).
- commit 5f2cf7e
* Mon Nov  1 2021 bp@suse.de
- x86/pat: Pass valid address to sanitize_phys() (bsc#1152489).
- commit 1702f6b
* Mon Nov  1 2021 msuchanek@suse.de
- KVM: PPC: Book3S HV: Save host FSCR in the P7/8 path
  (bsc#1065729).
- commit 4a60f84
* Mon Nov  1 2021 mkubecek@suse.cz
- sctp: add vtag check in sctp_sf_ootb (CVE-2021-3772
  bsc#1190351).
- sctp: add vtag check in sctp_sf_do_8_5_1_E_sa (CVE-2021-3772
  bsc#1190351).
- sctp: add vtag check in sctp_sf_violation (CVE-2021-3772
  bsc#1190351).
- sctp: fix the processing for COOKIE_ECHO chunk (CVE-2021-3772
  bsc#1190351).
- sctp: fix the processing for INIT_ACK chunk (CVE-2021-3772
  bsc#1190351).
- sctp: fix the processing for INIT chunk (CVE-2021-3772
  bsc#1190351).
- sctp: use init_tag from inithdr for ABORT chunk (CVE-2021-3772
  bsc#1190351).
- sctp: check asoc peer.asconf_capable before processing asconf
  (bsc#1190351).
- commit c4ecd47
* Sat Oct 30 2021 tiwai@suse.de
- mmc: vub300: fix control-message timeouts (git-fixes).
- mmc: dw_mmc: exynos: fix the finding clock sample value
  (git-fixes).
- commit 15296ab
* Fri Oct 29 2021 dwagner@suse.de
- scsi: lpfc: Update lpfc version to 14.0.0.3 (bsc#1192145).
- scsi: lpfc: Allow fabric node recovery if recovery is in
  progress before devloss (bsc#1192145).
- scsi: lpfc: Fix link down processing to address NULL pointer
  dereference (bsc#1192145).
- scsi: lpfc: Allow PLOGI retry if previous PLOGI was aborted
  (bsc#1192145).
- scsi: lpfc: Fix use-after-free in lpfc_unreg_rpi() routine
  (bsc#1192145).
- scsi: lpfc: Correct sysfs reporting of loop support after SFP
  status change (bsc#1192145).
- scsi: lpfc: Wait for successful restart of SLI3 adapter during
  host sg_reset (bsc#1192145).
- scsi: lpfc: Revert LOG_TRACE_EVENT back to LOG_INIT prior to
  driver_resource_setup() (bsc#1192145).
- commit ea0ad63
* Fri Oct 29 2021 tiwai@suse.de
- kABI workaround for cfg80211 mgmt_registration_lock changes
  (git-fixes).
- commit 85ca292
* Fri Oct 29 2021 tiwai@suse.de
- cfg80211: correct bridge/4addr mode check (git-fixes).
- cfg80211: fix management registrations locking (git-fixes).
- commit 38a77a6
* Fri Oct 29 2021 tiwai@suse.de
- net: lan78xx: fix division by zero in send path (git-fixes).
- net: batman-adv: fix error handling (git-fixes).
- nfc: port100: fix using -ERRNO as command type mask (git-fixes).
- cfg80211: scan: fix RCU in cfg80211_add_nontrans_list()
  (git-fixes).
- regmap: Fix possible double-free in regcache_rbtree_exit()
  (git-fixes).
- commit 1fb45c2
* Fri Oct 29 2021 tbogendoerfer@suse.de
- ixgbe: Fix NULL pointer dereference in ixgbe_xdp_setup
  (git-fixes).
- commit c406ead
* Fri Oct 29 2021 tbogendoerfer@suse.de
- ice: Add missing E810 device ids (jsc#SLE-7966 bsc#1157177).
- net: hns3: fix vf reset workqueue cannot exit (bsc#1154353).
- mlxsw: thermal: Fix out-of-bounds memory accesses (git-fixes).
- net/mlx5e: Mutually exclude RX-FCS and RX-port-timestamp
  (git-fixes).
- qed: Fix missing error code in qed_slowpath_start() (git-fixes).
- ionic: don't remove netdev->dev_addr when syncing uc list
  (bsc#1167773).
- iavf: fix double unlock of crit_lock (git-fixes).
- i40e: Fix freeing of uninitialized misc IRQ vector (git-fixes).
- i40e: fix endless loop under rtnl (git-fixes).
- gve: report 64bit tx_bytes counter from
  gve_handle_report_stats() (bsc#1176940).
- gve: fix gve_get_stats() (git-fixes).
- gve: Properly handle errors in gve_assign_qpl (bsc#1176940).
- gve: Avoid freeing NULL pointer (git-fixes).
- gve: Correct available tx qpl check (git-fixes).
- net: bridge: use nla_total_size_64bit() in
  br_get_linkxstats_size() (git-fixes).
- ixgbe: Fix NULL pointer dereference in ixgbe_xdp_setup
  (git-fixes).
- net/mlx4_en: Don't allow aRFS for encapsulated packets
  (git-fixes).
- qed: rdma - don't wait for resources under hw error recovery
  flow (git-fixes).
- bnxt_en: Fix TX timeout when TX ring size is set to the smallest
  (git-fixes).
- net/mlx4_en: Resolve bad operstate value (git-fixes).
- qed: Handle management FW error (git-fixes).
- net/af_unix: fix a data-race in unix_dgram_poll (bsc#1154353).
- net/mlx5: FWTrace, cancel work on alloc pd error flow
  (git-fixes).
- net/mlx5: Fix unpublish devlink parameters (jsc#SLE-8464).
- i40e: Fix ATR queue selection (git-fixes).
- mlx5: count all link events (git-fixes).
- commit 64e7f77
* Fri Oct 29 2021 tbogendoerfer@suse.de
- netfilter: xt_IDLETIMER: fix panic that occurs when timer_type
  has garbage value (bsc#1176447).
- ice: fix getting UDP tunnel entry (jsc#SLE-12878).
- net/mlx5: E-Switch, Fix double allocation of acl flow counter
  (jsc#SLE-15172).
- net/mlx5e: IPSEC RX, enable checksum complete (jsc#SLE-15172).
- RDMA/cma: Do not change route.addr.src_addr.ss_family
  (bsc#1181147).
- RDMA/cma: Fix listener leak in rdma_cma_listen_on_all() failure
  (bsc#1181147).
- net: hns3: check queue id range before using (jsc#SLE-14777).
- bnxt_en: make bnxt_free_skbs() safe to call after
  bnxt_free_mem() (jsc#SLE-16649).
- ice: Only lock to update netdev dev_addr (git-fixes).
- net/sched: ets: fix crash when flipping from 'strict' to
  'quantum' (bsc#1176774).
- net/mlx5e: RX, Avoid possible data corruption when relaxed
  ordering and LRO combined (jsc#SLE-15172).
- commit 016bdb7
* Fri Oct 29 2021 mkubecek@suse.cz
- sctp: add param size validation for SCTP_PARAM_SET_PRIMARY
  (CVE-2021-3655 bsc#1188563).
- sctp: validate chunk size in __rcv_asconf_lookup (CVE-2021-3655
  bsc#1188563).
- sctp: add size validation when walking chunks (CVE-2021-3655
  bsc#1188563).
- commit e419503
* Thu Oct 28 2021 mkubecek@suse.cz
- Revert "net: sched: disable TCQ_F_NOLOCK for pfifo_fast (bsc#1183405)"
  This reverts commit 3aa0c01fad38360cc9cd840d49bdfdc565e2e718.
  With the backport of the upstream fix for bsc#1183405 race, this workaround
  is no longer needed.
- commit 282cec9
* Thu Oct 28 2021 mkubecek@suse.cz
- net: sched: add barrier to ensure correct ordering for lockless
  qdisc (bsc#1183405).
- net: sched: avoid unnecessary seqcount operation for lockless
  qdisc (bsc#1183405).
- net: sched: fix tx action reschedule issue with stopped queue
  (bsc#1183405).
- net: sched: fix tx action rescheduling issue during deactivation
  (bsc#1183405).
- net: sched: fix packet stuck problem for lockless qdisc
  (bsc#1183405).
- net: sched: replaced invalid qdisc tree flush helper in
  qdisc_replace (bsc#1183405).
- net: sch_generic: aviod concurrent reset and enqueue op for
  lockless qdisc (bsc#1183405).
- commit 60ecee5
* Thu Oct 28 2021 msuchanek@suse.de
- powerpc/idle: Don't corrupt back chain when going idle
  (bko#206669 bsc#1174585 bsc#1192107 CVE-2021-43056).
- KVM: PPC: Book3S HV: Make idle_kvm_start_guest() return
  0 if it went to guest (bko#206669 bsc#1174585 bsc#1192107
  CVE-2021-43056).
- KVM: PPC: Book3S HV: Fix stack handling in
  idle_kvm_start_guest() (bko#206669 bsc#1174585 bsc#1192107
  CVE-2021-43056).
- powerpc64/idle: Fix SP offsets when saving GPRs (bko#206669
  bsc#1174585 bsc#1192107 CVE-2021-43056).
- commit 90745c9
* Thu Oct 28 2021 tiwai@suse.de
- Update patch reference for ISDN fix (CVE-2021-3896 bsc#1191958)
- commit b1524c3
* Thu Oct 28 2021 dwagner@suse.de
- nvme-pci: fix error unwind in nvme_map_data (bsc#1191934).
- nvme-pci: refactor nvme_unmap_data (bsc#1191934).
- commit fc21d20
* Thu Oct 28 2021 dwagner@suse.de
- nvme-pci: fix error unwind in nvme_map_data (bsc#1191934).
- nvme-pci: refactor nvme_unmap_data (bsc#1191934).
- commit 3a9d8cd
* Thu Oct 28 2021 tiwai@suse.de
- ASoC: DAPM: Fix missing kctl change notifications (git-fixes).
- ALSA: usb-audio: Provide quirk for Sennheiser GSP670 Headset
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Clevo PC50HS (git-fixes).
- Input: snvs_pwrkey - add clk handling (git-fixes).
- isdn: mISDN: Fix sleeping function called from invalid context
  (git-fixes).
- isdn: cpai: check ctr->cnr to avoid array index out of bound
  (git-fixes).
- ALSA: hda: avoid write to STATESTS if controller is in reset
  (git-fixes).
- platform/x86: intel_scu_ipc: Update timeout value in comment
  (git-fixes).
- commit 26182ff
* Wed Oct 27 2021 ailiop@suse.com
- xfs: fix log intent recovery ENOSPC shutdowns when inactivating
  inodes (bsc#1190642).
- commit 4a5d10a
* Wed Oct 27 2021 tiwai@suse.de
- drm/edid: In connector_bad_edid() cap num_of_ext by num_blocks
  read (git-fixes).
- drm/msm: Avoid potential overflow in timeout_to_jiffies()
  (git-fixes).
- ALSA: hda/realtek: Add quirk for TongFang PHxTxX1 (git-fixes).
- ALSA: hda - Enable headphone mic on Dell Latitude laptops with
  ALC3254 (git-fixes).
- ALSA: hda/realtek: Enable 4-speaker output for Dell Precision
  5560 laptop (git-fixes).
- ASoC: SOF: loader: release_firmware() on load failure to avoid
  batching (git-fixes).
- ASoC: SOF: imx: imx8m: Bar index is only valid for IRAM and
  SRAM types (git-fixes).
- ASoC: SOF: imx: imx8: Bar index is only valid for IRAM and
  SRAM types (git-fixes).
- ASoC: fsl_spdif: register platform component before registering
  cpu dai (git-fixes).
- ASoC: Intel: sof_sdw: tag SoundWire BEs as non-atomic
  (git-fixes).
- ASoC: Intel: Skylake: Fix passing loadable flag for module
  (git-fixes).
- ASoC: Intel: Skylake: Fix module configuration for KPB and MIXER
  (git-fixes).
- ASoC: Intel: update sof_pcm512x quirks (git-fixes).
- ASoC: Intel: bytcr_rt5640: Move "Platform Clock" routes to
  the maps for the matching in-/output (git-fixes).
- ASoC: atmel: ATMEL drivers don't need HAS_DMA (git-fixes).
- commit 6765039
* Wed Oct 27 2021 tiwai@suse.de
- e1000e: Fix packet loss on Tiger Lake and later (git-fixes).
- can: peak_usb: pcan_usb_fd_decode_status(): fix back to
  ERROR_ACTIVE state notification (git-fixes).
- can: peak_pci: peak_pci_remove(): fix UAF (git-fixes).
- can: rcar_can: fix suspend/resume (git-fixes).
- lan78xx: select CRC32 (git-fixes).
- ASoC: wm8960: Fix clock configuration on slave mode (git-fixes).
- audit: fix possible null-pointer dereference in
  audit_filter_rules (git-fixes).
- ata: ahci_platform: fix null-ptr-deref in
  ahci_platform_enable_regulators() (git-fixes).
- virtio: write back F_VERSION_1 before validate (git-fixes).
- mei: me: add Ice Lake-N device id (git-fixes).
- iio: adc: aspeed: set driver data when adc probe (git-fixes).
- usb: musb: dsps: Fix the probe error path (git-fixes).
- xhci: guard accesses to ep_state in xhci_endpoint_reset()
  (git-fixes).
- ALSA: usb-audio: Add quirk for VF0770 (git-fixes).
- ALSA: hda/realtek: Fix the mic type detection issue for ASUS
  G551JW (git-fixes).
- ALSA: hda/realtek - ALC236 headset MIC recording issue
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Clevo X170KM-G (git-fixes).
- ALSA: hda/realtek: Complete partial device name to avoid
  ambiguity (git-fixes).
- watchdog: orion: use 0 for unset heartbeat (git-fixes).
- commit 2657409
* Wed Oct 27 2021 jack@suse.cz
- xfs: fix I_DONTCACHE (bsc#1192074).
- commit c29b8dd
* Wed Oct 27 2021 tbogendoerfer@suse.de
- Delete
  patches.suse/e1000e-Do-not-take-care-about-recovery-NVM-checksum.patch.
  Drop patch to avoid regressions until real fix is available (bsc#1191663)
- commit e7e000a
* Wed Oct 27 2021 oneukum@suse.com
- blacklist.conf: irrelevant
- commit 4c2a4eb
* Wed Oct 27 2021 oneukum@suse.com
- USB: xhci: dbc: fix tty registration race (git-fixes).
- commit 8800f76
* Wed Oct 27 2021 oneukum@suse.com
- xhci: guard accesses to ep_state in xhci_endpoint_reset()
  (git-fixes).
- commit 2947d1e
* Wed Oct 27 2021 tiwai@suse.de
- nfc: nci: fix the UAF of rf_conn_info object (CVE-2021-3760
  bsc#1190067).
- commit 9eabc0c
* Wed Oct 27 2021 tiwai@suse.de
- Update patch reference for firewire fix (CVE-2021-42739 CVE-2021-3542 bsc#1184673)
- commit 2adc0e5
* Tue Oct 26 2021 mkubecek@suse.cz
- cipso,calipso: resolve a number of problems with the DOI
  refcounts (CVE-2021-33033 bsc#1186109).
- commit 499c5a0
* Tue Oct 26 2021 lhenriques@suse.de
- ceph: fix handling of "meta" errors (bsc#1192041).
- ceph: skip existing superblocks that are blocklisted or shut
  down when mounting (bsc#1192040).
- commit 329e544
* Tue Oct 26 2021 mkubecek@suse.cz
- kabi: hide return value type change of sctp_af::from_addr_param
  (CVE-2021-3655 bsc#1188563).
- sctp: fix return value check in __sctp_rcv_asconf_lookup
  (CVE-2021-3655 bsc#1188563).
- sctp: validate from_addr_param return (CVE-2021-3655
  bsc#1188563).
- commit 9f59a3f
* Tue Oct 26 2021 mkubecek@suse.cz
- Update
  patches.suse/net_sched-cls_route-remove-the-right-filter-from-has.patch
  references (add CVE-2021-3715 bsc#1190349).
- commit bd39990
* Mon Oct 25 2021 mkoutny@suse.com
- Revert "sched/fair: Add ancestors of unthrottled undecayed cfs_rq"
  The reverted commit is a followup of a7b359fc6a37 ("sched/fair:
  Correctly insert cfs_rq's to list on unthrottle") which is going to be
  reverted as part of short-term solution of bsc#1191343.
  This reverts commit d8d828e03d4f1e436c3580616c7b53db38e38dcb.
- commit c6395e4
* Mon Oct 25 2021 bp@suse.de
- blacklist.conf: 3a1255396b5a x86/alternatives: add missing insn.h include
- commit 9bccba9
* Fri Oct 22 2021 msuchanek@suse.de
- scsi: ibmvfc: Fix up duplicate response detection (bsc#1191867
  ltc#194757).
- commit 38f073b
* Thu Oct 21 2021 lduncan@suse.com
- Added 3 SCSI-iscsi git-fix commits
- commit 2073942
* Thu Oct 21 2021 lduncan@suse.com
- scsi: iscsi: Fix deadlock on recovery path during GFP_IO reclaim
  (git-fixes).
- Refresh
  patches.suse/scsi-iscsi-verify-lengths-on-passthrough-pdus.
- commit 6addc19
* Thu Oct 21 2021 lduncan@suse.com
- scsi: target: Fix the pgr/alua_support_store functions
  (git-fixes).
- commit 5bcb387
* Thu Oct 21 2021 lduncan@suse.com
- scsi: mpi3mr: Fix error return code in mpi3mr_init_ioc() (git-fixes)
  Also refreshed scsi-mpi3mr-Set-up-IRQs-in-resume-path, since this
  commit changed the context.
- commit 0352f63
* Thu Oct 21 2021 oneukum@suse.com
- USB: serial: option: add Quectel EC200S-CN module support
  (git-fixes).
- commit e1df2bf
* Thu Oct 21 2021 oneukum@suse.com
- USB: serial: qcserial: add EM9191 QDL support (git-fixes).
- commit b42181b
* Thu Oct 21 2021 oneukum@suse.com
- USB: serial: option: add prod. id for Quectel EG91 (git-fixes).
- commit cff3cf9
* Thu Oct 21 2021 oneukum@suse.com
- USB: serial: option: add Telit LE910Cx composition 0x1204
  (git-fixes).
- commit 3ccad62
* Thu Oct 21 2021 oneukum@suse.com
- xhci: Enable trust tx length quirk for Fresco FL11 USB
  controller (git-fixes).
- commit 55acfbd
* Thu Oct 21 2021 oneukum@suse.com
- xhci: Fix command ring pointer corruption while aborting a
  command (git-fixes).
- commit bf02a9c
* Thu Oct 21 2021 oneukum@suse.com
- Input: xpad - add support for another USB ID of Nacon GC-100
  (git-fixes).
- commit eba25ff
* Thu Oct 21 2021 lduncan@suse.com
- scsi: mpi3mr: Fix missing unlock on error (git-fixes).
- commit f4b9433
* Wed Oct 20 2021 lduncan@suse.com
- scsi: mpi3mr: Fix error handling in mpi3mr_setup_isr()
  (git-fixes).
- commit 0eebf69
* Wed Oct 20 2021 bp@suse.de
- x86/sev: Return an error on a returned non-zero
  SW_EXITINFO1[31:0] (bsc#1178134).
- commit 3b2a96a
* Wed Oct 20 2021 tiwai@suse.de
- media: firewire: firedtv-avc: fix a buffer overflow in
  avc_ca_pmt() (CVE-2021-3542 bsc#1184673).
- commit fab3d4f
* Wed Oct 20 2021 ohering@suse.de
- net: mana: Fix error handling in mana_create_rxq() (git-fixes,
  bsc#1191800).
- commit 8c6d0b8
* Wed Oct 20 2021 jack@suse.cz
- ocfs2: fix data corruption after conversion from inline format
  (bsc#1190795).
- commit ac3ffc2
* Tue Oct 19 2021 bp@suse.de
- blacklist.conf: 4758fd801f91 x86/platform/olpc: Correct ifdef symbol to intended CONFIG_OLPC_XO15_SCI
- commit c40c7ae
* Tue Oct 19 2021 bp@suse.de
- blacklist.conf: 225bac2dc5d1 x86/Kconfig: Correct reference to MWINCHIP3D
- commit eee3b41
* Tue Oct 19 2021 bp@suse.de
- blacklist.conf: 711885906b5c x86/Kconfig: Do not enable AMD_MEM_ENCRYPT_ACTIVE_BY_DEFAULT automatically
- commit da61791
* Tue Oct 19 2021 tiwai@suse.de
- gpio: pca953x: Improve bias setting (git-fixes).
- spi: spi-nxp-fspi: don't depend on a specific node name erratum
  workaround (git-fixes).
- drm/panel: olimex-lcd-olinuxino: select CRC32 (git-fixes).
- drm/msm/dsi: fix off by one in dsi_bus_clk_enable error handling
  (git-fixes).
- drm/msm/dsi: Fix an error code in msm_dsi_modeset_init()
  (git-fixes).
- drm/msm: Fix null pointer dereference on pointer edp
  (git-fixes).
- mac80211: check return value of rhashtable_init (git-fixes).
- commit c393393
* Tue Oct 19 2021 tiwai@suse.de
- iio: light: opt3001: Fixed timeout error when 0 lux (git-fixes).
- iio: mtk-auxadc: fix case IIO_CHAN_INFO_PROCESSED (git-fixes).
- iio: ssp_sensors: add more range checking in
  ssp_parse_dataframe() (git-fixes).
- iio: ssp_sensors: fix error code in ssp_print_mcu_debug()
  (git-fixes).
- iio: adc128s052: Fix the error handling path of 'adc128_probe()'
  (git-fixes).
- iio: dac: ti-dac5571: fix an error code in probe() (git-fixes).
- drm/amdgpu: fix gart.bo pin_count leak (git-fixes).
- mac80211: Drop frames from invalid MAC address in ad-hoc mode
  (git-fixes).
- HID: wacom: Add new Intuos BT (CTL-4100WL/CTL-6100WL) device
  IDs (git-fixes).
- HID: apple: Fix logical maximum and usage maximum of Magic
  Keyboard JIS (git-fixes).
- commit 372fd90
* Tue Oct 19 2021 tiwai@suse.de
- pata_legacy: fix a couple uninitialized variable bugs
  (git-fixes).
- cb710: avoid NULL pointer subtraction (git-fixes).
- acpi/arm64: fix next_platform_timer() section mismatch error
  (git-fixes).
- ata: sata_dwc_460ex: No need to call phy_exit() befre phy_init()
  (git-fixes).
- ACPI: fix NULL pointer dereference (git-fixes).
- ACPI: bgrt: Fix CFI violation (git-fixes).
- ACPI: Use DEVICE_ATTR_<RW|RO|WO> macros (git-fixes).
- commit 1a13895
* Tue Oct 19 2021 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: move to zstd for the initrd
  Newer distros have capability to decompress zstd, which
  provides a 2-5%% better compression ratio at very similar
  cpu overhead. Plus this tests the zstd codepaths now as well.
- commit 3d53a5b
* Tue Oct 19 2021 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: reduce initrd functionality
  For building in OBS, we always build inside a virtual machine
  that gets a new, freshly created scratch filesystem image. So
  we do not need to handle fscks because that ain't gonna happen,
  as well as not we do not need to handle microcode update in the
  initrd as these only can be run on the host system anyway. We
  can also strip and hardlink as an additional optimisation that
  should not significantly hurt.
- commit c72c6fc
* Tue Oct 19 2021 dwagner@suse.de
- nvme-pci: Fix abort command id (git-fixes).
- nvme: add command id quirk for apple controllers (git-fixes).
- commit 210cebb
* Mon Oct 18 2021 tzimmermann@suse.de
- drm/nouveau: avoid a use-after-free when BO init fails (bsc#1152472)
  Backporting notes:
  * context changes
- commit dbfac3c
* Mon Oct 18 2021 tzimmermann@suse.de
- drm/panfrost: Make sure MMU context lifetime is not bound to (bsc#1152472)
  Backporting notes:
  * context changes in panfrost_job_irq_handler()
- commit 78a582b
* Mon Oct 18 2021 tzimmermann@suse.de
- drm/i915: Fix syncmap memory leak (bsc#1152489)
  Backporting notes:
  * context changes in intel_timeline_fini()
- commit d5e337e
* Mon Oct 18 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/overlay: Fix active retire callback alignment'
- commit c6cc973
* Mon Oct 18 2021 jgross@suse.com
- xen: reset legacy rtc flag for PV domU (git-fixes).
- commit 2ae68ea
* Mon Oct 18 2021 jgross@suse.com
- xen: fix setting of max_pfn in shared_info (git-fixes).
- commit 2d2e1e0
* Mon Oct 18 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  - patches.suse/NFS-Do-uncached-readdir-when-we-re-seeking-a-cookie-.patch
- commit b7dfcc7
* Sun Oct 17 2021 neilb@suse.de
- NFS: Do uncached readdir when we're seeking a cookie in an
  empty page cache (bsc#1191628).
- commit 5ca83d3
* Fri Oct 15 2021 bp@suse.de
- Update patches.suse/bpf-Fix-ringbuf-helper-function-compatibility.patch
  (git-fixes, bsc#1191645, CVE-2021-34866).
  Update references.
- commit 3bcb18d
* Fri Oct 15 2021 tiwai@suse.de
- ALSA: pcm: Workaround for a wrong offset in SYNC_PTR compat
  ioctl (git-fixes).
- ALSA: hda/realtek: Fix for quirk to enable speaker output on
  the Lenovo 13s Gen2 (git-fixes).
- commit f5dfccc
* Fri Oct 15 2021 tiwai@suse.de
- NFC: digital: fix possible memory leak in
  digital_in_send_sdd_req() (git-fixes).
- NFC: digital: fix possible memory leak in
  digital_tg_listen_mdaa() (git-fixes).
- nfc: fix error handling of nfc_proto_register() (git-fixes).
- ALSA: seq: Fix a potential UAF by wrong private_free call order
  (git-fixes).
- commit aada78f
* Fri Oct 15 2021 denis.kirjanov@suse.com
- netfilter: Drop fragmented ndisc packets assembled in netfilter
  (git-fixes).
- commit e526835
* Fri Oct 15 2021 jbohac@suse.cz
- net: ipv6: Discard next-hop MTU less than minimum link MTU
  (bsc#1191241).
- commit ba09279
* Fri Oct 15 2021 dwagner@suse.de
- nvme-fc: remove freeze/unfreeze around update_nr_hw_queues
  (bsc#1185762).
- nvme-fc: avoid race between time out and tear down
  (bsc#1185762).
- nvme-fc: update hardware queues before using them (bsc#1185762).
- commit 4afdc63
* Thu Oct 14 2021 dwagner@suse.de
- scsi: lpfc: Fix memory overwrite during FC-GS I/O abort handling
  (bsc#1191349).
- commit c7eb218
* Thu Oct 14 2021 tiwai@suse.de
- acpi/arm64: fix next_platform_timer() section mismatch error
  (git-fixes).
- platform/x86: intel_scu_ipc: Fix busy loop expiry time
  (git-fixes).
- platform/mellanox: mlxreg-io: Fix read access of n-bytes size
  attributes (git-fixes).
- drm/nouveau/kms/nv50-: fix file release memory leak (git-fixes).
- drm/nouveau/kms/tu102-: delay enabling cursor until after
  assign_windows (git-fixes).
- drm/sun4i: dw-hdmi: Fix HDMI PHY clock setup (git-fixes).
- iwlwifi: pcie: add configuration of a Wi-Fi adapter on Dell
  XPS 15 (git-fixes).
- ACPI: NFIT: Use fallback node id when numa info in NFIT table
  is incorrect (git-fixes).
- ACPI: fix NULL pointer dereference (git-fixes).
- commit 0673e50
* Thu Oct 14 2021 tiwai@suse.de
- net: hso: fix NULL-deref on disconnect regression (git-fixes).
- commit 901c621
* Thu Oct 14 2021 tiwai@suse.de
- platform/mellanox: mlxreg-io: Fix argument base in kstrtou32()
  call (git-fixes).
- i2c: acpi: fix resource leak in reconfiguration device addition
  (git-fixes).
- mmc: meson-gx: do not use memcpy_to/fromio for dram-access-quirk
  (git-fixes).
- drm/nouveau/debugfs: fix file release memory leak (git-fixes).
- video: fbdev: gbefb: Only instantiate device when built for IP32
  (git-fixes).
- soc: qcom: mdt_loader: Drop PT_LOAD check on hash segment
  (git-fixes).
- ptp_pch: Load module automatically if ID matches (git-fixes).
- phy: mdio: fix memory leak (git-fixes).
- libata: Add ATA_HORKAGE_NO_NCQ_ON_ATI for Samsung 860 and 870
  SSD (git-fixes).
- ptp_pch: Restore dependency on PCI (git-fixes).
- net: cdc_eem: fix tx fixup skb leak (git-fixes).
- net: hso: fix null-ptr-deref during tty device unregistration
  (git-fixes).
- net: cdc_ncm: correct overhead in delayed_ndp_size (git-fixes).
- net: usb: Fix uninit-was-stored issue in asix_read_phy_addr()
  (git-fixes).
- commit 4915e73
* Thu Oct 14 2021 dwagner@suse.de
- pseries/eeh: Fix the kdump kernel crash during eeh_pseries_init
  (git-fixes).
- commit aaf0697
* Thu Oct 14 2021 dwagner@suse.de
- scsi: qla2xxx: Remove redundant initialization of pointer req
  (bsc#1190941).
- scsi: qla2xxx: Update version to 10.02.07.100-k (bsc#1190941).
- scsi: qla2xxx: Fix use after free in eh_abort path
  (bsc#1190941).
- scsi: qla2xxx: Move heartbeat handling from DPC thread to
  workqueue (bsc#1190941).
- scsi: qla2xxx: Call process_response_queue() in Tx path
  (bsc#1190941).
- scsi: qla2xxx: Fix kernel crash when accessing port_speed
  sysfs file (bsc#1190941).
- scsi: qla2xxx: edif: Use link event to wake up app
  (bsc#1190941).
- scsi: qla2xxx: Fix crash in NVMe abort path (bsc#1190941).
- scsi: qla2xxx: Check for firmware capability before creating
  QPair (bsc#1190941).
- scsi: qla2xxx: Display 16G only as supported speeds for 3830c
  card (bsc#1190941).
- scsi: qla2xxx: Add support for mailbox passthru (bsc#1190941).
- scsi: qla2xxx: Fix excessive messages during device logout
  (bsc#1190941).
- scsi: qla2xxx: Restore initiator in dual mode (bsc#1190941).
- scsi: qla2xxx: Open-code qla2xxx_eh_device_reset()
  (bsc#1190941).
- scsi: qla2xxx: Open-code qla2xxx_eh_target_reset()
  (bsc#1190941).
- scsi: qla2xxx: Do not call fc_block_scsi_eh() during bus reset
  (bsc#1190941).
- scsi: qla2xxx: Update version to 10.02.06.200-k (bsc#1190941).
- scsi: qla2xxx: edif: Fix returnvar.cocci warnings (bsc#1190941).
- scsi: qla2xxx: Fix NVMe session down detection (bsc#1190941).
- scsi: qla2xxx: Fix NVMe retry (bsc#1190941).
- scsi: qla2xxx: Fix hang on NVMe command timeouts (bsc#1190941).
- scsi: qla2xxx: Fix NVMe | FCP personality change (bsc#1190941).
- scsi: qla2xxx: edif: Do secure PLOGI when auth app is present
  (bsc#1190941).
- scsi: qla2xxx: edif: Add N2N support for EDIF (bsc#1190941).
- scsi: qla2xxx: Fix hang during NVMe session tear down
  (bsc#1190941).
- scsi: qla2xxx: edif: Fix EDIF enable flag (bsc#1190941).
- scsi: qla2xxx: edif: Reject AUTH ELS on session down
  (bsc#1190941).
- scsi: qla2xxx: edif: Fix stale session (bsc#1190941).
- scsi: qla2xxx: Update version to 10.02.06.100-k (bsc#1190941).
- scsi: qla2xxx: Sync queue idx with queue_pair_map idx
  (bsc#1190941).
- scsi: qla2xxx: Changes to support kdump kernel for NVMe BFS
  (bsc#1190941).
- scsi: qla2xxx: Changes to support kdump kernel (bsc#1190941).
- scsi: qla2xxx: Suppress unnecessary log messages during login
  (bsc#1190941).
- scsi: qla2xxx: Fix NPIV create erroneous error (bsc#1190941).
- scsi: qla2xxx: Fix unsafe removal from linked list
  (bsc#1190941).
- scsi: qla2xxx: Fix port type info (bsc#1190941).
- scsi: qla2xxx: Add debug print of 64G link speed (bsc#1190941).
- scsi: qla2xxx: Show OS name and version in FDMI-1 (bsc#1190941).
- scsi: qla2xxx: Changes to support FCP2 Target (bsc#1190941).
- scsi: qla2xxx: Adjust request/response queue size for 28xx
  (bsc#1190941).
- scsi: qla2xxx: Add host attribute to trigger MPI hang
  (bsc#1190941).
- scsi: qla2xxx: Use scsi_cmd_to_rq() instead of scsi_cmnd.request
  (bsc#1190941).
- commit c17f95e
* Wed Oct 13 2021 msuchanek@suse.de
- kernel-spec-macros: Since rpm 4.17 %%verbose is unusable (bsc#1191229).
  The semantic changed in an incompatible way so invoking the macro now
  causes a build failure.
- commit 3e55f55
* Wed Oct 13 2021 msuchanek@suse.de
- powerpc/feature-fixups: use a semicolon rather than a comma
  (bsc#1188983 CVE-2021-34556 bsc#1188985 CVE-2021-35477).
- commit c85e1c6
* Wed Oct 13 2021 msuchanek@suse.de
- powerpc/lib/feature-fixups: Use PPC_RAW_xxx() macros
  (bsc#1188983 CVE-2021-34556 bsc#1188985 CVE-2021-35477).
- Refresh patches.suse/powerpc-Don-t-use-struct-ppc_inst-to-reference-instr.patch.
- powerpc/ppc-opcode: Add PPC_RAW_MFSPR() (bsc#1188983
  CVE-2021-34556 bsc#1188985 CVE-2021-35477).
- commit 5a3ede4
* Wed Oct 13 2021 msuchanek@suse.de
- powerpc/opcodes: Add shorter macros for registers for use
  with PPC_RAW_xx() (bsc#1188983 CVE-2021-34556 bsc#1188985
  CVE-2021-35477).
- commit 6a14724
* Wed Oct 13 2021 msuchanek@suse.de
- powerpc/signal: Use PPC_RAW_xx() macros (bsc#1188983
  CVE-2021-34556 bsc#1188985 CVE-2021-35477).
- powerpc/asm: Add some opcodes in asm/ppc-opcode.h for PPC32 eBPF
  (bsc#1188983 CVE-2021-34556 bsc#1188985 CVE-2021-35477).
- commit 66c500d
* Wed Oct 13 2021 denis.kirjanov@suse.com
- ipv6/netfilter: Discard first fragment not including all headers
  (bsc#1191241).
- commit 040f020
* Wed Oct 13 2021 denis.kirjanov@suse.com
- IPv6: reply ICMP error if the first fragment don't include
  all headers (bsc#1191241).
- commit abf80f6
* Wed Oct 13 2021 denis.kirjanov@suse.com
- ICMPv6: Add ICMPv6 Parameter Problem, code 3 definition
  (bsc#1191241).
- commit b3ab292
* Wed Oct 13 2021 msuchanek@suse.de
- powerpc: Don't use 'struct ppc_inst' to reference instruction
  location (jsc#SLE-13847 git-fixes).
- powerpc/lib/code-patching: Don't use struct 'ppc_inst' for
  runnable code in tests (jsc#SLE-13847 git-fixes).
- powerpc/lib/code-patching: Make instr_is_branch_to_addr()
  static (jsc#SLE-13847 git-fixes).
- powerpc: Do not dereference code as 'struct ppc_inst' (uprobe,
  code-patching, feature-fixups) (jsc#SLE-13847 git-fixes).
- powerpc/64s: Fix stf mitigation patching w/strict RWX & hash
  (jsc#SLE-13847 git-fixes).
- powerpc/64s: Fix entry flush patching w/strict RWX & hash (jsc#SLE-13847 git-fixes).
- powerpc/uprobes: Validation for prefixed instruction
  (jsc#SLE-13847 git-fixes).
- commit 5729394
* Wed Oct 13 2021 msuchanek@suse.de
- powerpc/bpf: Emit stf barrier instruction sequences
  for BPF_NOSPEC (bsc#1188983 CVE-2021-34556 bsc#1188985
  CVE-2021-35477).
- powerpc/security: Add a helper to query stf_barrier type
  (bsc#1188983 CVE-2021-34556 bsc#1188985 CVE-2021-35477).
- powerpc/bpf: Validate branch ranges (bsc#1188983 CVE-2021-34556
  bsc#1188985 CVE-2021-35477).
- powerpc/lib: Add helper to check if offset is within
  conditional branch range (bsc#1188983 CVE-2021-34556 bsc#1188985
  CVE-2021-35477).
- powerpc/bpf: Emit stf barrier instruction sequences
  for BPF_NOSPEC (bsc#1188983 CVE-2021-34556 bsc#1188985
  CVE-2021-35477).
- powerpc/security: Add a helper to query stf_barrier type
  (bsc#1188983 CVE-2021-34556 bsc#1188985 CVE-2021-35477).
- powerpc/bpf: Fix BPF_SUB when imm == 0x80000000 (bsc#1065729).
- powerpc/bpf: Fix BPF_MOD when imm == 1 (bsc#1065729).
- powerpc/bpf: Validate branch ranges (bsc#1188983 CVE-2021-34556
  bsc#1188985 CVE-2021-35477).
- powerpc/lib: Add helper to check if offset is within
  conditional branch range (bsc#1188983 CVE-2021-34556 bsc#1188985
  CVE-2021-35477).
- powerpc/bpf: Use bctrl for making function calls (bsc#1065729).
- powerpc/bpf: Fix BPF_SUB when imm == 0x80000000 (bsc#1065729).
- powerpc/bpf: Fix BPF_MOD when imm == 1 (bsc#1065729).
- powerpc/bpf: Use bctrl for making function calls (bsc#1065729).
- powerpc/lib: Fix emulate_step() std test (bsc#1065729).
- commit 3f6738b
* Wed Oct 13 2021 shung-hsi.yu@suse.com
- bpf: Fix OOB read when printing XDP link fdinfo (git-fixes).
- commit 09be9b3
* Wed Oct 13 2021 shung-hsi.yu@suse.com
- bpf: Fix a typo of reuseport map in bpf.h (git-fixes).
- bpf: Add bpf_patch_call_args prototype to include/linux/bpf.h
  (git-fixes).
- bpf: Fix up bpf_skb_adjust_room helper's skb csum setting
  (git-fixes).
- commit b5d0357
* Wed Oct 13 2021 oneukum@suse.com
- platform/x86: dell-smbios-wmi: Add missing kfree in error-exit
  from run_smbios_call (git-fixes).
- commit a539d65
* Wed Oct 13 2021 bp@suse.de
- x86/resctrl: Free the ctrlval arrays when
  domain_setup_mon_state() fails (bsc#1152489).
- commit dba5675
* Wed Oct 13 2021 oneukum@suse.com
- can: xilinx_can: handle failure cases of pm_runtime_get_sync
  (git-fixes).
- commit 82f6db6
* Wed Oct 13 2021 oneukum@suse.com
- blacklist.conf: feature, not a fix
- commit fd65896
* Tue Oct 12 2021 oneukum@suse.com
- net: can: ems_usb: fix use-after-free in ems_usb_disconnect()
  (git-fixes).
- commit 5487063
* Tue Oct 12 2021 oneukum@suse.com
- can: peak_usb: fix use after free bugs (git-fixes).
- commit 3ad9b4d
* Tue Oct 12 2021 oneukum@suse.com
- can: dev: can_restart: fix use after free bug (git-fixes).
- commit 0943ca2
* Tue Oct 12 2021 oneukum@suse.com
- can: ti_hecc: ti_hecc_probe(): add missed
  clk_disable_unprepare() in error path (git-fixes).
- commit 2fec0e3
* Tue Oct 12 2021 tiwai@suse.de
- Update patch reference for soc fix (CVE-2021-42252 bsc#1190479)
- commit f05067d
* Tue Oct 12 2021 oneukum@suse.com
- blacklist.conf: requires newer USB PD version than we have
- commit a8bbe8f
* Tue Oct 12 2021 oneukum@suse.com
- blacklist.conf: needs newer USB PD than we have
- commit d0d6a50
* Tue Oct 12 2021 denis.kirjanov@suse.com
- Update kabi files.
- commit a156da7
* Mon Oct 11 2021 oneukum@suse.com
- USB: cdc-acm: fix minor-number release (git-fixes).
- commit 477b833
* Mon Oct 11 2021 oneukum@suse.com
- USB: cdc-acm: clean up probe error labels (git-fixes).
- commit 576c313
* Mon Oct 11 2021 bp@suse.de
- blacklist.conf: 4758fd801f91 x86/platform/olpc: Correct ifdef symbol to intended CONFIG_OLPC_XO15_SCI
- commit fab5572
* Mon Oct 11 2021 bp@suse.de
- blacklist.conf: 225bac2dc5d1 x86/Kconfig: Correct reference to MWINCHIP3D
- commit 08dc820
* Mon Oct 11 2021 jack@suse.cz
- kabi: block: Fix kabi of blk_mq_sched_try_insert_merge()
  (bsc#1191456).
- commit 7832c25
* Mon Oct 11 2021 oneukum@suse.com
- usb: chipidea: ci_hdrc_imx: Also search for 'phys' phandle
  (git-fixes).
- commit b332e18
* Mon Oct 11 2021 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix copy_tofrom_guest routines
  (jsc#SLE-12936 git-fixes).
- commit 825316d
* Mon Oct 11 2021 msuchanek@suse.de
- tpm: ibmvtpm: Avoid error message when process gets signal
  while waiting (bsc#1065729).
- commit 1910f07
* Mon Oct 11 2021 msuchanek@suse.de
- powerpc/numa: Update cpu_cpu_map on CPU online/offline
  (jsc#SLE-13615 bsc#1180100 ltc#190257 git-fixes).
- powerpc/smp: Enable CACHE domain for shared processor
  (jsc#SLE-13615 bsc#1180100 ltc#190257 git-fixes).
- powerpc/smp: Update cpu_core_map on all PowerPc systems
  (jsc#SLE-13615 bsc#1180100 ltc#190257 git-fixes).
- powerpc/smp: Fix a crash while booting kvm guest with nr_cpus=2
  (jsc#SLE-13615 bsc#1180100 ltc#190257 git-fixes).
- powerpc/smp: Set numa node before updating mask (jsc#SLE-13615
  bsc#1180100 ltc#190257 git-fixes).
- powerpc/smp: Cache CPU to chip lookup (jsc#SLE-13615 bsc#1180100
  ltc#190257 git-fixes).
- Refresh patches.suse/powerpc-cacheinfo-Lookup-cache-by-dt-node-and-thread.patch.
- Revert "powerpc/topology: Update topology_core_cpumask"
  (jsc#SLE-13615 bsc#1180100 ltc#190257 git-fixes).
- powerpc/smp: Fold cpu_die() into its only caller (jsc#SLE-13615
  bsc#1180100 ltc#190257 git-fixes).
- Refresh patches.suse/powerpc-cacheinfo-Lookup-cache-by-dt-node-and-thread.patch
- powerpc: Move arch_cpu_idle_dead() into smp.c (jsc#SLE-13615
  bsc#1180100 ltc#190257 git-fixes).
- commit 6f6565a
* Mon Oct 11 2021 msuchanek@suse.de
- powerpc/pseries: Fix build error when NUMA=n (bsc#1190620
  ltc#194498 git-fixes).
- commit 6c29f54
* Mon Oct 11 2021 msuchanek@suse.de
- cpuidle: pseries: Mark pseries_idle_proble() as __init
  (jsc#SLE-13614 bsc#1176914 ltc#186394 git-fixes).
- commit 319f0f3
* Sun Oct 10 2021 ailiop@suse.com
- xfs: fix up non-directory creation in SGID directories
  (bsc#1190006 CVE-2018-13405).
- commit f5a61c4
* Sun Oct 10 2021 ailiop@suse.com
- xfs: remove the icdinode di_uid/di_gid members (bsc#1190006).
- commit 7385144
* Sun Oct 10 2021 ailiop@suse.com
- xfs: ensure that the inode uid/gid match values match the
  icdinode ones (bsc#1190006).
- commit 0ddcc0f
* Sun Oct 10 2021 ailiop@suse.com
- xfs: merge the projid fields in struct xfs_icdinode
  (bsc#1190006).
- commit 3a30ff3
* Thu Oct  7 2021 lduncan@suse.com
- Configure mpi3mr as currently unsupported (jsc#SLE-18120)
- commit aede7cc
* Thu Oct  7 2021 mkoutny@suse.com
- Revert "sched/fair: Correctly insert cfs_rq's to list on unthrottle
  (git-fixes)" (bsc#1191343, bsc#1191238)
  The commit a7b359fc6a37 ("sched/fair: Correctly insert cfs_rq's to list
  on unthrottle") causes more severe problems than the problem it aims to
  solve (corrupting cfs_rq leaf list vs insufficient fairness). While both
  need to be solved eventually, revert the commit until non-breaking
  solution is found.
  Blacklist the commit as well, to prevent a regression via git-fixes.
  This reverts commit 1732b9ba91b4b7a0822e98bd910feefbcb5424dc.
- commit b8c1ddd
* Thu Oct  7 2021 mkoutny@suse.com
- Revert "sched/fair: Ensure that the CFS parent is added after unthrottling (git-fixes)."
  The reverted commit is a followup of a7b359fc6a37 ("sched/fair:
  Correctly insert cfs_rq's to list on unthrottle") which is going to be
  reverted as part of short-term solution of bsc#1191343.
  This reverts commit f3a38fbebab3f88070c129511f99a896f5532f7e.
- commit 4f925fc
* Thu Oct  7 2021 lduncan@suse.com
- scsi: mpi3mr: Set up IRQs in resume path (jsc#SLE-18120).
- scsi: mpi3mr: Use the proper SCSI midlayer interfaces for PI
  (jsc#SLE-18120).
- scsi: mpi3mr: Use scsi_cmd_to_rq() instead of scsi_cmnd.request
  (jsc#SLE-18120).
- commit fc7fb17
* Thu Oct  7 2021 jack@suse.cz
- fscrypt: add fscrypt_symlink_getattr() for computing st_size
  (bsc#1191449).
- commit 549a3d8
* Thu Oct  7 2021 lduncan@suse.com
- scsi: mpi3mr: Add event handling debug prints (jsc#SLE-18120).
- scsi: mpi3mr: Add EEDP DIF DIX support (jsc#SLE-18120).
- scsi: mpi3mr: Add support for DSN secure firmware check
  (jsc#SLE-18120).
- scsi: mpi3mr: Add support for PM suspend and resume
  (jsc#SLE-18120).
- scsi: mpi3mr: Wait for pending I/O completions upon detection
  of VD I/O timeout (jsc#SLE-18120).
- scsi: mpi3mr: Print pending host I/Os for debugging
  (jsc#SLE-18120).
- scsi: mpi3mr: Complete support for soft reset (jsc#SLE-18120).
- scsi: mpi3mr: Add support for threaded ISR (jsc#SLE-18120).
- scsi: mpi3mr: Hardware workaround for UNMAP commands to NVMe
  drives (jsc#SLE-18120).
- scsi: mpi3mr: Allow certain commands during pci-remove hook
  (jsc#SLE-18120).
- scsi: mpi3mr: Add change queue depth support (jsc#SLE-18120).
- scsi: mpi3mr: Implement SCSI error handler hooks
  (jsc#SLE-18120).
- scsi: mpi3mr: Add bios_param SCSI host template hook
  (jsc#SLE-18120).
- scsi: mpi3mr: Print IOC info for debugging (jsc#SLE-18120).
- scsi: mpi3mr: Add support for timestamp sync with firmware
  (jsc#SLE-18120).
- scsi: mpi3mr: Add support for recovering controller
  (jsc#SLE-18120).
- scsi: mpi3mr: Additional event handling (jsc#SLE-18120).
- scsi: mpi3mr: Add support for PCIe device event handling
  (jsc#SLE-18120).
- scsi: mpi3mr: Add support for device add/remove event handling
  (jsc#SLE-18120).
- scsi: mpi3mr: Add support for internal watchdog thread
  (jsc#SLE-18120).
- scsi: mpi3mr: Add support for queue command processing
  (jsc#SLE-18120).
- scsi: mpi3mr: Create operational request and reply queue pair
  (jsc#SLE-18120).
- commit 259660e
* Thu Oct  7 2021 jack@suse.cz
- blk: Fix lock inversion between ioc lock and bfqd lock
  (bsc#1191456).
- commit adb5e59
* Thu Oct  7 2021 jack@suse.cz
- bfq: Remove merged request already in bfq_requests_merged()
  (bsc#1191456).
- commit 0d474e5
* Thu Oct  7 2021 jack@suse.cz
- fs, mm: fix race in unlinking swapfile (bsc#1191455).
- commit cd60ce3
* Thu Oct  7 2021 jack@suse.cz
- blacklist.conf: Blacklist 889c05cc5834
- commit ea30b1a
* Thu Oct  7 2021 lduncan@suse.com
- scsi: mpi3mr: Base driver code (jsc#SLE-18120).
- Update config files (enabling tthe driver as a module)
- commit 3c0fd36
* Thu Oct  7 2021 jack@suse.cz
- blacklist.conf: Blacklist 6961fed42014
- commit b6fb7af
* Thu Oct  7 2021 jack@suse.cz
- blktrace: Fix uaf in blk_trace access after removing by sysfs
  (bsc#1191452).
- commit a4f24d0
* Thu Oct  7 2021 jack@suse.cz
- block: bfq: fix bfq_set_next_ioprio_data() (bsc#1191451).
- commit 34735be
* Thu Oct  7 2021 jack@suse.cz
- ext4: fix reserved space counter leakage (bsc#1191450).
- commit 449ab75
* Thu Oct  7 2021 jack@suse.cz
- ext4: report correct st_size for encrypted symlinks
  (bsc#1191449).
- commit 3669a7f
* Thu Oct  7 2021 shung-hsi.yu@suse.com
- bpf: Fix integer overflow in prealloc_elems_and_freelist()
  (bsc#1191317, CVE-2021-41864).
- commit d4466f5
* Thu Oct  7 2021 tiwai@suse.de
- kABI workaround for HD-audio probe retry changes (bsc#1190801).
- ALSA: hda: intel: Allow repeatedly probing on codec
  configuration errors (bsc#1190801).
- commit 27f79df
* Thu Oct  7 2021 tiwai@suse.de
- drm/amdgpu: correct initial cp_hqd_quantum for gfx9 (git-fixes).
- ALSA: hda/realtek: Quirks to enable speaker output for Lenovo
  Legion 7i 15IMHG05, Yoga 7i 14ITL5/15ITL5, and 13s Gen2 laptops
  (git-fixes).
- ASoC: dapm: use component prefix when checking widget names
  (git-fixes).
- commit 9bf3e05
* Thu Oct  7 2021 tiwai@suse.de
- Add cherry-picked commit id to the usb hso fix (git-fixes)
- commit a4c3be7
* Thu Oct  7 2021 tiwai@suse.de
- drm/amd/display: Pass PCI deviceid into DC (git-fixes).
- e100: fix buffer overrun in e100_get_regs (git-fixes).
- e100: fix length calculation in e100_get_regs_len (git-fixes).
- HID: u2fzero: ignore incomplete packets without data
  (git-fixes).
- HID: betop: fix slab-out-of-bounds Write in betop_probe
  (git-fixes).
- net: hso: add failure handler for add_net_device (git-fixes).
- HID: usbhid: free raw_report buffers in usbhid_stop (git-fixes).
- usb: hso: remove the bailout parameter (git-fixes).
- usb: hso: fix error handling code of hso_create_net_device
  (git-fixes).
- e100: handle eeprom as little endian (git-fixes).
- hso: fix bailout in error case of probe (git-fixes).
- PCI: Fix pci_host_bridge struct device release/free handling
  (git-fixes).
- commit 51aaf55
* Wed Oct  6 2021 lduncan@suse.com
- scsi: mpi3mr: Add mpi30 Rev-R headers and Kconfig
  (jsc#SLE-18120).
- Update config files.
- commit 54f9bad
* Wed Oct  6 2021 ykaukab@suse.de
- PM / devfreq: rk3399_dmc: Remove unneeded semicolon (git-fixes).
- PM / devfreq: rk3399_dmc: Fix kernel oops when rockchip,pmu
  is absent (git-fixes).
- PM / devfreq: rk3399_dmc: Disable devfreq-event device when
  fails (git-fixes).
- PM / devfreq: rk3399_dmc: Add missing of_node_put() (git-fixes).
- PM / devfreq: rk3399_dmc: Fix spelling typo (git-fixes).
- commit b4b8a3b
* Tue Oct  5 2021 mkubecek@suse.cz
- Update kabi files.
- update from October 2021 maintenance update submission (commit c909dd500033)
- commit d500b18
* Tue Oct  5 2021 ludwig.nussel@suse.de
- rpm: use _rpmmacrodir (boo#1191384)
- commit e350c14
* Tue Oct  5 2021 tiwai@suse.de
- net: 6pack: fix slab-out-of-bounds in decode_data
  (CVE-2021-42008 bsc#1191315).
- commit b0db75a
* Mon Oct  4 2021 trenn@suse.com
- x86/cpu: Fix core name for Sapphire Rapids (jsc#SLE-15289).
- powercap: intel_rapl: add support for Sapphire Rapids
  (jsc#SLE-15289).
- commit 053c38b
* Mon Oct  4 2021 mkubecek@suse.cz
- series.conf: cleanup
- move a kabi workaround into correct section:
  patches.kabi/ipvs-Fix-up-kabi-for-expire_nodest_conn_work-additio.patch
- commit bc02214
* Mon Oct  4 2021 mkoutny@suse.com
- sched/fair: Add ancestors of unthrottled undecayed cfs_rq
  (bsc#1191292).
- commit d8d828e
* Mon Oct  4 2021 tonyj@suse.de
- blacklist.conf: Update for 51e1bb9eeaf7
- commit fe28675
* Mon Oct  4 2021 bp@suse.de
- x86/alternatives: Teach text_poke_bp() to emulate instructions
  (bsc#1185302).
- Refresh
  patches.suse/x86-alternatives-sync-bp_patching-update-for-avoiding-null-pointer-exception.patch.
- commit ef191ae
* Mon Oct  4 2021 dwagner@suse.de
- blk-mq: kABI fixes for blk_mq_queue_map (bsc#1185762).
- blk-mq: don't deactivate hctx if managed irq isn't used
  (bsc#1185762).
- blk-mq: mark if one queue map uses managed irq (bsc#1185762).
- genirq: add device_has_managed_msi_irq (bsc#1185762).
- commit 71f9eaf
* Mon Oct  4 2021 dwagner@suse.de
- blk-mq: kABI fixes for blk_mq_queue_map (bsc#1185762).
- blk-mq: don't deactivate hctx if managed irq isn't used
  (bsc#1185762).
- blk-mq: mark if one queue map uses managed irq (bsc#1185762).
- genirq: add device_has_managed_msi_irq (bsc#1185762).
- commit 57a6cb7
* Mon Oct  4 2021 bp@suse.de
- blacklist.conf: 3a1255396b5a x86/alternatives: add missing insn.h include
- commit 53a5b9c
* Mon Oct  4 2021 tiwai@suse.de
- hwmon: (tmp421) fix rounding for negative values (git-fixes).
- hwmon: (tmp421) report /PVLD condition as fault (git-fixes).
- hwmon: (mlxreg-fan) Return non-zero value when fan current
  state is enforced from sysfs (git-fixes).
- commit 2560193
* Mon Oct  4 2021 mkoutny@suse.com
- ipc: remove memcg accounting for sops objects in do_semtimedop()
  (bsc#1190115).
- Delete
  patches.suse/ipc-remove-memcg-accounting-for-sops-objects.patch.
  Refreshing patch with upstream metadata.
- commit 2d6ef2e
* Mon Oct  4 2021 msuchanek@suse.de
- powerpc/perf/hv-gpci: Fix counter value parsing (bsc#1065729).
- commit 628c3ee
* Mon Oct  4 2021 msuchanek@suse.de
- powerpc/pseries/dlpar: use rtas_get_sensor() (bsc#1065729).
- commit 466f31b
* Mon Oct  4 2021 msuchanek@suse.de
- powerpc/powernv: Fix machine check reporting of async store
  errors (bsc#1065729).
- commit 0b715ae
* Mon Oct  4 2021 msuchanek@suse.de
- powerpc/perf: Fix the check for SIAR value (bsc#1065729).
- powerpc/perf: Drop the case of returning 0 as instruction
  pointer (bsc#1065729).
- powerpc/perf: Use stack siar instead of mfspr (bsc#1065729).
- powerpc/perf: Fix crash in perf_instruction_pointer() when
  ppmu is not set (bsc#1065729).
- powerpc/perf: Use regs->nip when SIAR is zero (bsc#1065729).
- powerpc/perf: Use the address from SIAR register to set cpumode
  flags (bsc#1065729).
- commit f3110f1
* Mon Oct  4 2021 tiwai@suse.de
- drm/i915/rkl: Remove require_force_probe protection
  (bsc#1189257).
- commit 94530db
* Fri Oct  1 2021 tiwai@suse.de
- apparmor: remove duplicate macro list_entry_is_head()
  (git-fixes).
- commit 514b75b
* Fri Oct  1 2021 tiwai@suse.de
- xhci: Set HCD flag to defer primary roothub registration
  (git-fixes).
- commit 8f4e75e
* Fri Oct  1 2021 tiwai@suse.de
- USB: serial: option: add device id for Foxconn T99W265
  (git-fixes).
- USB: serial: cp210x: add ID for GW Instek GDM-834x Digital
  Multimeter (git-fixes).
- USB: serial: option: add Telit LN920 compositions (git-fixes).
- usb-storage: Add quirk for ScanLogic SL11R-IDE older than 2.6c
  (git-fixes).
- usb: core: hcd: Add support for deferring roothub registration
  (git-fixes).
- commit 0a6378c
* Fri Oct  1 2021 tiwai@suse.de
- mac80211: fix use-after-free in CCMP/GCMP RX (git-fixes).
- mac80211-hwsim: fix late beacon hrtimer handling (git-fixes).
- mac80211: mesh: fix potentially unaligned access (git-fixes).
- mac80211: limit injected vht mcs/nss in
  ieee80211_parse_tx_radiotap (git-fixes).
- Re-enable UAS for LaCie Rugged USB3-FW with fk quirk
  (git-fixes).
- usb: dwc2: gadget: Fix ISOC flow for BDMA and Slave (git-fixes).
- spi: Fix tegra20 build with CONFIG_PM=n (git-fixes).
- tty: synclink_gt, drop unneeded forward declarations
  (git-fixes).
- commit dbd9f90
* Fri Oct  1 2021 tiwai@suse.de
- mac80211: Fix ieee80211_amsdu_aggregate frag_tail bug
  (git-fixes).
- ALSA: firewire-motu: fix truncated bytes in message tracepoints
  (git-fixes).
- ASoC: SOF: Fix DSP oops stack dump output contents (git-fixes).
- ASoC: fsl_micfil: register platform component before registering
  cpu dai (git-fixes).
- ASoC: mediatek: common: handle NULL case in suspend/resume
  function (git-fixes).
- media: cedrus: Fix SUNXI tile size calculation (git-fixes).
- watchdog/sb_watchdog: fix compilation problem due to
  COMPILE_TEST (git-fixes).
- dmaengine: xilinx_dma: Set DMA mask for coherent APIs
  (git-fixes).
- dmaengine: ioat: depends on !UML (git-fixes).
- console: consume APC, DM, DCS (git-fixes).
- commit 71b860e
* Fri Oct  1 2021 tiwai@suse.de
- thermal/core: Potential buffer overflow in
  thermal_build_list_of_policies() (git-fixes).
- rtc: rx8010: select REGMAP_I2C (git-fixes).
- pwm: stm32-lp: Don't modify HW state in .remove() callback
  (git-fixes).
- pwm: rockchip: Don't modify HW state in .remove() callback
  (git-fixes).
- pwm: img: Don't modify HW state in .remove() callback
  (git-fixes).
- dmaengine: sprd: Add missing MODULE_DEVICE_TABLE (git-fixes).
- PCI: pci-bridge-emul: Add PCIe Root Capabilities Register
  (git-fixes).
- PCI: pci-bridge-emul: Fix array overruns, improve safety
  (git-fixes).
- PCI: pci-bridge-emul: Fix big-endian support (git-fixes).
- commit a8d4022
* Fri Oct  1 2021 tiwai@suse.de
- fpga: machxo2-spi: Fix missing error code in
  machxo2_write_complete() (git-fixes).
- fpga: machxo2-spi: Return an error on failure (git-fixes).
- serial: mvebu-uart: fix driver's tx_empty callback (git-fixes).
- USB: serial: option: remove duplicate USB device ID (git-fixes).
- usb: dwc2: gadget: Fix ISOC transfer complete handling for DDMA
  (git-fixes).
- usb: gadget: r8a66597: fix a loop in set_feature() (git-fixes).
- gpio: uniphier: Fix void functions to remove return value
  (git-fixes).
- ASoC: rockchip: i2s: Fixup config for DAIFMT_DSP_A/B
  (git-fixes).
- ASoC: rockchip: i2s: Fix regmap_ops hang (git-fixes).
- commit 79aec8d
* Fri Oct  1 2021 tiwai@suse.de
- clk: at91: clk-generated: pass the id of changeable parent at
  registration (git-fixes).
- Refresh
  patches.suse/clk-at91-clk-generated-Limit-the-requested-rate-to-o.patch.
- commit 39cefdd
* Fri Oct  1 2021 tiwai@suse.de
- drm/amd/amdgpu: Update debugfs link_settings output link_rate
  field in hex (git-fixes).
- drm: avoid blocking in drm_clients_info's rcu section
  (git-fixes).
- drm/gma500: Fix end of loop tests for list_for_each_entry
  (git-fixes).
- drm/amdgpu: Fix BUG_ON assert (git-fixes).
- staging: board: Fix uninitialized spinlock when attaching genpd
  (git-fixes).
- ath9k: fix sleeping in atomic context (git-fixes).
- ath9k: fix OOB read ar9300_eeprom_restore_internal (git-fixes).
- Bluetooth: skip invalid hci_sync_conn_complete_evt (git-fixes).
- include/linux/list.h: add a macro to test if entry is pointing
  to the head (git-fixes).
- commit 60017cf
* Fri Oct  1 2021 tiwai@suse.de
- drm/panfrost: Clamp lock region to Bifrost minimum (git-fixes).
- gpu: drm: amd: amdgpu: amdgpu_i2c: fix
  possible uninitialized-variable access in
  amdgpu_i2c_router_select_ddc_port() (git-fixes).
- drm/amd/display: Fix timer_per_pixel unit error (git-fixes).
- media: TDA1997x: fix tda1997x_query_dv_timings() return value
  (git-fixes).
- media: v4l2-dv-timings.c: fix wrong condition in two for-loops
  (git-fixes).
- media: imx258: Limit the max analogue gain to 480 (git-fixes).
- iio: dac: ad5624r: Fix incorrect handling of an optional
  regulator (git-fixes).
- staging: ks7010: Fix the initialization of the 'sleep_status'
  structure (git-fixes).
- iwlwifi: mvm: fix a memory leak in
  iwl_mvm_mac_ctxt_beacon_changed (git-fixes).
- drivers: gpu: amd: Initialize amdgpu_dm_backlight_caps object
  to 0 in amdgpu_dm_update_backlight_caps (git-fixes).
- commit 4c6f48f
* Fri Oct  1 2021 tiwai@suse.de
- PCI: Add AMD GPU multi-function power dependencies (git-fixes).
- mfd: Don't use irq_create_mapping() to resolve a mapping
  (git-fixes).
- media: imx258: Rectify mismatch of VTS value (git-fixes).
- media: rc-loopback: return number of emitters rather than error
  (git-fixes).
- media: uvc: don't do DMA on stack (git-fixes).
- media: dib8000: rewrite the init prbs logic (git-fixes).
- parport: remove non-zero check on count (git-fixes).
- mmc: core: Return correct emmc response in case of ioctl error
  (git-fixes).
- mmc: rtsx_pci: Fix long reads when clock is prescaled
  (git-fixes).
- mmc: sdhci-of-arasan: Check return value of non-void funtions
  (git-fixes).
- commit 9209c5a
* Fri Oct  1 2021 tiwai@suse.de
- PCI: aardvark: Fix masking and unmasking legacy INTx interrupts
  (git-fixes).
- PCI: aardvark: Increase polling delay to 1.5s while waiting
  for PIO response (git-fixes).
- PCI: aardvark: Fix checking for PIO status (git-fixes).
- PM: base: power: don't try to use non-existing RTC for storing
  data (git-fixes).
- PCI: Add ACS quirks for Cavium multi-function devices
  (git-fixes).
- PCI: Add ACS quirks for NXP LX2xx0 and LX2xx2 platforms
  (git-fixes).
- PCI: ibmphp: Fix double unmap of io_mem (git-fixes).
- PCI: Restrict ASMedia ASM1062 SATA Max Payload Size Supported
  (git-fixes).
- PCI: Use pci_update_current_state() in pci_enable_device_flags()
  (git-fixes).
- commit 61f24a4
* Fri Oct  1 2021 tiwai@suse.de
- rtc: tps65910: Correct driver module alias (git-fixes).
- USB: EHCI: ehci-mv: improve error handling in mv_ehci_enable()
  (git-fixes).
- usb: gadget: u_ether: fix a potential null pointer dereference
  (git-fixes).
- usb: host: fotg210: fix the actual_length of an iso packet
  (git-fixes).
- serial: sh-sci: fix break handling for sysrq (git-fixes).
- serial: 8250_pci: make setup_port() parameters explicitly
  unsigned (git-fixes).
- serial: 8250: Define RX trigger levels for OxSemi 950 devices
  (git-fixes).
- tty: serial: jsm: hold port lock when reporting modem line
  changes (git-fixes).
- staging: rts5208: Fix get_ms_information() heap buffer size
  (git-fixes).
- commit f3797b6
* Fri Oct  1 2021 tiwai@suse.de
- drm/nouveau/nvkm: Replace -ENOSYS with -ENODEV (git-fixes).
- video: fbdev: riva: Error out if 'pixclock' equals zero
  (git-fixes).
- video: fbdev: kyro: Error out if 'pixclock' equals zero
  (git-fixes).
- video: fbdev: asiliantfb: Error out if 'pixclock' equals zero
  (git-fixes).
- video: fbdev: kyro: fix a DoS bug by restricting user input
  (git-fixes).
- usbip:vhci_hcd USB port can get stuck in the disabled state
  (git-fixes).
- usbip: give back URBs for unsent unlink requests during cleanup
  (git-fixes).
- usb: musb: musb_dsps: request_irq() after initializing musb
  (git-fixes).
- usb: host: fotg210: fix the endpoint's transactional
  opportunities calculation (git-fixes).
- commit f1407f0
* Fri Oct  1 2021 tiwai@suse.de
- kabi/severities: skip kABI check for ath9k-local symbols (CVE-2020-3702 bsc#1191193)
  ath9k modules have some exported symbols for the common helpers
  and the recent fixes broke kABI of those.  They are specific to
  ath9k's own usages, so safe to ignore.
- commit 7579b4b
* Fri Oct  1 2021 tiwai@suse.de
- kABI compatibility for ath_key_delete() changes (CVE-2020-3702
  bsc#1191193).
- commit bc02804
* Fri Oct  1 2021 tiwai@suse.de
- ath9k: Postpone key cache entry deletion for TXQ frames
  reference it (CVE-2020-3702 bsc#1191193).
- ath: Modify ath_key_delete() to not need full key entry
  (CVE-2020-3702 bsc#1191193).
- ath: Export ath_hw_keysetmac() (CVE-2020-3702 bsc#1191193).
- commit 5fe383f
* Fri Oct  1 2021 denis.kirjanov@suse.com
- Refresh
  patches.kabi/scsi-fc-kABI-fixes-for-new-ELS_RDP-definition.patch.
- commit 7f69543
* Fri Oct  1 2021 neilb@suse.de
- Update patches.kabi/NFS-pass-cred-explicitly-for-access-tests.patch
  (bsc#1190746 bsc#1191172).
  cache.group_info (aka cache.cred) was not properly initialized when
  - >access() was called.
- commit 9ff84db
* Thu Sep 30 2021 dbueso@suse.de
- ipc: replace costly bailout check in sysvipc_find_ipc()
  (bsc#1159886 bsc#1188986 CVE-2021-3669).
- ipc/util.c: use binary search for max_idx (bsc#1159886).
- commit af97833
* Thu Sep 30 2021 denis.kirjanov@suse.com
- scsi/fc: kABI fixes for new ELS_EDC, ELS_RDP definition
  (bsc#1171688 bsc#1174003 bsc#1190576).
- commit 3952cc0
* Thu Sep 30 2021 denis.kirjanov@suse.com
- Update config files.
- commit 48075c9
* Wed Sep 29 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  - patches.suse/net-mana-Fix-a-memory-leak-in-an-error-handling-path.patch
- commit 12cbf84
* Wed Sep 29 2021 mkubecek@suse.cz
- series.conf: cleanup
- move submitted patches to "almost mainline" section:
  - patches.suse/NFS-change-nfs_access_get_cached-to-only-report-the-.patch
  - patches.suse/NFS-pass-cred-explicitly-for-access-tests.patch
  - patches.suse/NFS-don-t-store-struct-cred-in-struct-nfs_access_ent.patch
- commit a3b4285
* Wed Sep 29 2021 nborisov@suse.com
- btrfs: prevent rename2 from exchanging a subvol with a directory from different parents (bsc#1190626).
- commit b88ab2e
* Wed Sep 29 2021 oneukum@suse.com
- blacklist.conf: too intrusive, gone in through SP3
- commit a81e8d3
* Wed Sep 29 2021 oneukum@suse.com
- blacklist.conf: too intrusive, gone in through SP3
- commit 4bedee6
* Wed Sep 29 2021 oneukum@suse.com
- blacklist.conf: too intrusive, gone in through SP3
- commit 0474866
* Wed Sep 29 2021 oneukum@suse.com
- blacklist.conf: kABI
- commit e8337cf
* Wed Sep 29 2021 msuchanek@suse.de
- cpuidle: pseries: Do not cap the CEDE0 latency in
  fixup_cede0_latency() (bsc#1185550 ltc#192610 git-fixes
  jsc#SLE-18128).
- commit cfe4b84
* Tue Sep 28 2021 bp@suse.de
- x86/mm: Fix kern_addr_valid() to cope with existing but not
  present entries (bsc#1152489).
- commit 1efaf04
* Tue Sep 28 2021 bp@suse.de
- x86/asm: Fix SETZ size enqcmds() build failure (bsc#1178134).
- commit 54b59b3
* Tue Sep 28 2021 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amd-display-Initialize-attribute-for-hdcp_srm-sy.patch.
  Added Alt-commit for duplicate
- commit 86167e7
* Tue Sep 28 2021 pjakobsson@suse.de
- drm/ast: Fix missing conversions to managed API (git-fixes).
- commit cab6852
* Tue Sep 28 2021 pjakobsson@suse.de
- Refresh patches.suse/drm-i915-Fix-crash-in-auto_retire.patch.
  Added Alt-commit for duplicate
- commit 334db42
* Tue Sep 28 2021 pjakobsson@suse.de
- drm/ingenic: Switch IPU plane to type OVERLAY (git-fixes).
- commit ed3952b
* Tue Sep 28 2021 pjakobsson@suse.de
- drm/pl111: depend on CONFIG_VEXPRESS_CONFIG (git-fixes).
- commit 4e7e865
* Tue Sep 28 2021 ohering@suse.de
- net: mana: Prefer struct_size over open coded arithmetic (jsc#SLE-18779, bsc#1185726).
- net: mana: Add WARN_ON_ONCE in case of CQE read overflow (jsc#SLE-18779, bsc#1185726).
- net: mana: Add support for EQ sharing (jsc#SLE-18779, bsc#1185726).
- net: mana: Move NAPI from EQ to CQ (jsc#SLE-18779, bsc#1185726).
- net: mana: Use struct_size() in kzalloc() (jsc#SLE-18779, bsc#1185726).
- hv_netvsc: Make netvsc/VF binding check both MAC and serial number (jsc#SLE-18779, bsc#1185726).
- net: mana: Fix a memory leak in an error handling path in (jsc#SLE-18779, bsc#1185726).
- hv: mana: remove netdev_lockdep_set_classes usage (jsc#SLE-18779, bsc#1185726).
- net: mana: Use int to check the return value of mana_gd_poll_cq() (jsc#SLE-18779, bsc#1185726).
- net: mana: fix PCI_HYPERV dependency (jsc#SLE-18779, bsc#1185726).
- net: mana: remove redundant initialization of variable err (jsc#SLE-18779, bsc#1185726).
- net: mana: Add a driver for Microsoft Azure Network Adapter (MANA) (jsc#SLE-18779, bsc#1185726).
- commit 44e26ca
* Tue Sep 28 2021 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amdgpu-Init-GFX10_ADDR_CONFIG-for-VCN-v3-in-DPG-.patch.
  Added Alt-commit for duplicate
- commit fa028bf
* Tue Sep 28 2021 dwagner@suse.de
- nvme: avoid race in shutdown namespace removal (bsc#1188067).
- commit bac299d
* Tue Sep 28 2021 dwagner@suse.de
- nvme: fix refcounting imbalance when all paths are down
  (bsc#1188067).
- Refresh
  patches.suse/nvme-only-call-synchronize_srcu-when-clearing-curren.patch.
- commit 44b2d54
* Tue Sep 28 2021 dwagner@suse.de
- series: Update meta data and resort
  Refresh the metad data and sort into correct position:
  patches.suse/scsi-lpfc-Fix-CPU-to-from-endian-warnings-introduced.patch
  patches.suse/scsi-lpfc-Fix-compilation-errors-on-kernels-with-no-.patch
  patches.suse/scsi-lpfc-Fix-gcc-Wstringop-overread-warning-again.patch
  patches.suse/scsi-lpfc-Fix-sprintf-overflow-in-lpfc_display_fpin_.patch
  patches.suse/scsi-lpfc-Remove-unneeded-variable.patch
  patches.suse/scsi-lpfc-Use-correct-scnprintf-limit.patch
- commit 12f1564
* Tue Sep 28 2021 acho@suse.com
- Update
  patches.suse/Bluetooth-check-for-zapped-sk-before-connecting.patch
  (CVE-2021-3752 bsc#1190023).
- commit 6b966b4
* Tue Sep 28 2021 acho@suse.com
- Update
  patches.suse/Bluetooth-check-for-zapped-sk-before-connecting.patch
  (CVE-2021-3752 bsc#1190023).
- commit 65458cc
* Tue Sep 28 2021 pjakobsson@suse.de
- drm/mgag200: Select clock in PLL update functions (git-fixes).
- commit 8e058be
* Tue Sep 28 2021 neilb@suse.de
- Restore kabi after NFS: pass cred explicitly for access tests
  (bsc#1190746).
- NFS: don't store 'struct cred *' in struct nfs_access_entry
  (bsc#1190746).
- NFS: pass cred explicitly for access tests (bsc#1190746).
- NFS: change nfs_access_get_cached to only report the mask
  (bsc#1190746).
- commit 907996a
* Mon Sep 27 2021 pjakobsson@suse.de
- dma-buf: DMABUF_MOVE_NOTIFY should depend on DMA_SHARED_BUFFER
  (git-fixes).
- commit 931b672
* Mon Sep 27 2021 oneukum@suse.com
- usb: musb: tusb6010: uninitialized data in
  tusb_fifo_write_unaligned() (git-fixes).
- commit 11a541f
* Mon Sep 27 2021 pjakobsson@suse.de
- drm/rockchip: cdn-dp-core: Make cdn_dp_core_resume
  __maybe_unused (git-fixes).
- commit 6bec20e
* Mon Sep 27 2021 pjakobsson@suse.de
- drm/i915: Allow the sysadmin to override security mitigations
  (git-fixes).
- commit c1eb827
* Mon Sep 27 2021 mbenes@suse.cz
- erofs: fix up erofs_lookup tracepoint (git-fixes).
- commit 3009743
* Mon Sep 27 2021 bp@suse.de
- EDAC/synopsys: Fix wrong value type assignment for edac_mode
  (bsc#1152489).
- commit 15eb225
* Mon Sep 27 2021 msuchanek@suse.de
- kernel-binary.spec: Do not sign kernel when no key provided
  (bsc#1187167 bsc#1191240 ltc#194716).
- kernel-binary.spec: Do not sign kernel when no key provided
  (bsc#1187167).
- commit c909dd5
* Mon Sep 27 2021 ykaukab@suse.de
- enetc: Fix uninitialized struct dim_sample field usage
  (git-fixes).
- PCI: of: Don't fail devm_pci_alloc_host_bridge() on missing
  'ranges' (git-fixes).
- mmc: sdhci: Fix issue with uninitialized dma_slave_config
  (git-fixes).
- net: ethernet: ti: cpsw: fix min eth packet size for non-switch
  use-cases (git-fixes).
- optee: Fix memory leak when failing to register shm pages
  (git-fixes).
- commit 1758b20
* Sat Sep 25 2021 msuchanek@suse.de
- powerpc: fix function annotations to avoid section mismatch
  warnings with gcc-10 (bsc#1148868).
- commit 9e9276f
* Sat Sep 25 2021 msuchanek@suse.de
- powerpc/drmem: Make LMB walk a bit more flexible (bsc#1190543
  ltc#194523).
- Refresh patches.suse/pseries-drmem-update-LMBs-after-LPM.patch
- commit e17894e
* Thu Sep 23 2021 mkubecek@suse.cz
- Revert "rpm: Abolish scritplet templating (bsc#1189841)." (bsc#1190598)
  This reverts commit e98096d5cf85dbe90f74a930eb1f0e3fe4a70c7f.
  These changes depend on a suse-module-tools update which has not reached
  SLE15-SP2/3 and Leap 15.2/3 yet, causing both build failures and
  unsatisfiable dependency of resulting binary packages.
  Revert the commit temporarily until suse-module-tools is updated.
- commit 7d43568
* Thu Sep 23 2021 msuchanek@suse.de
- pseries/drmem: update LMBs after LPM (bsc#1190543 ltc#194523).
- commit 9763078
* Thu Sep 23 2021 msuchanek@suse.de
- powerpc/pseries: Prevent free CPU ids being reused on another
  node (bsc#1190620 ltc#194498).
- commit 7097b6c
* Thu Sep 23 2021 tbogendoerfer@suse.de
- net: sched: sch_teql: fix null-pointer dereference
  (bsc#1190717).
- commit 0a89f09
* Wed Sep 22 2021 bp@suse.de
- x86/alternatives: Teach text_poke_bp() to emulate instructions
  (bsc#1190561).
- Refresh
  patches.suse/x86-alternatives-sync-bp_patching-update-for-avoiding-null-pointer-exception.patch.
- commit 1c9f1df
* Wed Sep 22 2021 msuchanek@suse.de
- kernel-binary.spec: suse-kernel-rpm-scriptlets required for uninstall as
  well.
  Fixes: e98096d5cf85 ("rpm: Abolish scritplet templating (bsc#1189841).")
- commit e082fbf
* Wed Sep 22 2021 ailiop@suse.com
- mm/swap: consider max pages in iomap_swapfile_add_extent
  (bsc#1190785).
- commit afb626e
* Wed Sep 22 2021 ailiop@suse.com
- iomap: Fix negative assignment to unsigned sis->pages in
  iomap_swapfile_activate (bsc#1190784).
- commit 7126cba
* Wed Sep 22 2021 dwagner@suse.de
- scsi: lpfc: Fix gcc -Wstringop-overread warning, again
  (bsc#1190576).
- scsi: lpfc: Use correct scnprintf() limit (bsc#1190576).
- scsi: lpfc: Fix sprintf() overflow in lpfc_display_fpin_wwpn()
  (bsc#1190576).
- scsi: lpfc: Update lpfc version to 14.0.0.2 (bsc#1190576).
- scsi: lpfc: Improve PBDE checks during SGL processing
  (bsc#1190576).
- scsi: lpfc: Zero CGN stats only during initial driver load
  and stat reset (bsc#1190576).
- scsi: lpfc: Fix I/O block after enabling managed congestion mode
  (bsc#1190576).
- scsi: lpfc: Adjust bytes received vales during cmf timer
  interval (bsc#1190576).
- scsi: lpfc: Fix EEH support for NVMe I/O (bsc#1190576).
- scsi: lpfc: Fix FCP I/O flush functionality for TMF routines
  (bsc#1190576).
- scsi: lpfc: Fix NVMe I/O failover to non-optimized path
  (bsc#1190576).
- scsi: lpfc: Don't remove ndlp on PRLI errors in P2P mode
  (bsc#1190576).
- scsi: lpfc: Fix rediscovery of tape device after LIP
  (bsc#1190576).
- scsi: lpfc: Fix hang on unload due to stuck fport node
  (bsc#1190576).
- scsi: lpfc: Fix premature rpi release for unsolicited TPLS
  and LS_RJT (bsc#1190576).
- scsi: lpfc: Don't release final kref on Fport node while ABTS
  outstanding (bsc#1190576).
- scsi: lpfc: Fix list_add() corruption in lpfc_drain_txq()
  (bsc#1190576).
- scsi: lpfc: Remove unneeded variable (bsc#1190576).
- scsi: lpfc: Fix compilation errors on kernels with no
  CONFIG_DEBUG_FS (bsc#1190576).
- scsi: lpfc: Fix CPU to/from endian warnings introduced by ELS
  processing (bsc#1190576).
- commit 1435c13
* Wed Sep 22 2021 oneukum@suse.com
- blacklist.conf: kABI
- commit 3cb18d9
* Wed Sep 22 2021 oneukum@suse.com
- blacklist.conf: kABI
- commit dcb25ee
* Wed Sep 22 2021 oneukum@suse.com
- blacklist.conf: kABI
- commit d400b4c
* Wed Sep 22 2021 oneukum@suse.com
- docs: Fix infiniband uverbs minor number (git-fixes).
- commit 0fb9cd2
* Wed Sep 22 2021 oneukum@suse.com
- usb: dwc2: Avoid leaving the error_debugfs label unused
  (git-fixes).
- commit fb08350
* Wed Sep 22 2021 msuchanek@suse.de
- ibmvnic: Reuse tx pools when possible (bsc#1190758 ltc#191943).
- ibmvnic: Reuse rx pools when possible (bsc#1190758 ltc#191943).
- ibmvnic: Reuse LTB when possible (bsc#1190758 ltc#191943).
- ibmvnic: Use bitmap for LTB map_ids (bsc#1190758 ltc#191943).
- ibmvnic: init_tx_pools move loop-invariant code (bsc#1190758
  ltc#191943).
- ibmvnic: Use/rename local vars in init_tx_pools (bsc#1190758
  ltc#191943).
- ibmvnic: Use/rename local vars in init_rx_pools (bsc#1190758
  ltc#191943).
- ibmvnic: Fix up some comments and messages (bsc#1190758
  ltc#191943).
- ibmvnic: Consolidate code in replenish_rx_pool() (bsc#1190758
  ltc#191943).
- commit dea5bd2
* Tue Sep 21 2021 bp@suse.de
- x86/resctrl: Fix a maybe-uninitialized build warning treated
  as error (bsc#1152489).
- x86/resctrl: Fix default monitoring groups reporting
  (bsc#1152489).
- commit 450cdb2
* Tue Sep 21 2021 denis.kirjanov@suse.com
- vmxnet3: update to version 6 (bsc#1190406).
- commit 8d3dc67
* Tue Sep 21 2021 denis.kirjanov@suse.com
- vmxnet3: increase maximum configurable mtu to 9190
  (bsc#1190406).
- commit bd5109d
* Tue Sep 21 2021 denis.kirjanov@suse.com
- vmxnet3: set correct hash type based on rss information
  (bsc#1190406).
- commit e1e474b
* Tue Sep 21 2021 denis.kirjanov@suse.com
- vmxnet3: add support for ESP IPv6 RSS (bsc#1190406).
- commit 1687646
* Tue Sep 21 2021 denis.kirjanov@suse.com
- vmxnet3: remove power of 2 limitation on the queues
  (bsc#1190406).
- commit f3834f6
* Tue Sep 21 2021 denis.kirjanov@suse.com
- vmxnet3: add support for 32 Tx/Rx queues (bsc#1190406).
- commit fbdf2fe
* Tue Sep 21 2021 denis.kirjanov@suse.com
- vmxnet3: prepare for version 6 changes (bsc#1190406).
- commit 7e0fe82
* Tue Sep 21 2021 lhenriques@suse.de
- fuse: truncate pagecache on atomic_o_trunc (bsc#1190705).
- commit 73351a3
* Tue Sep 21 2021 ailiop@suse.com
- xfs: sync lazy sb accounting on quiesce of read-only mounts
  (bsc#1190679).
- commit 668fdef
* Tue Sep 21 2021 bp@suse.de
- blacklist.conf: 3bff147b187d x86/mce: Defer processing of early errors
- commit 7e0dc1d
* Mon Sep 20 2021 mbenes@suse.cz
- s390/unwind: use current_frame_address() to unwind current task
  (bsc#1185677).
- commit 92c31e7
* Mon Sep 20 2021 dwagner@suse.de
- scsi: lpfc: Use the proper SCSI midlayer interfaces for PI
  (bsc#1190576).
- scsi: lpfc: Copyright updates for 14.0.0.1 patches
  (bsc#1190576).
- scsi: lpfc: Update lpfc version to 14.0.0.1 (bsc#1190576).
- scsi: lpfc: Add bsg support for retrieving adapter cmf data
  (bsc#1190576).
- scsi: lpfc: Add cmf_info sysfs entry (bsc#1190576).
- scsi: lpfc: Add debugfs support for cm framework buffers
  (bsc#1190576).
- scsi: lpfc: Add support for maintaining the cm statistics buffer
  (bsc#1190576).
- scsi: lpfc: Add rx monitoring statistics (bsc#1190576).
- scsi: lpfc: Add support for the CM framework (bsc#1190576).
- scsi: lpfc: Add cmfsync WQE support (bsc#1190576).
- scsi: lpfc: Add support for cm enablement buffer (bsc#1190576).
- scsi: lpfc: Add cm statistics buffer support (bsc#1190576).
- scsi: lpfc: Add EDC ELS support (bsc#1190576).
- scsi: lpfc: Expand FPIN and RDF receive logging (bsc#1190576).
- scsi: lpfc: Add MIB feature enablement support (bsc#1190576).
- scsi: lpfc: Add SET_HOST_DATA mbox cmd to pass date/time info
  to firmware (bsc#1190576).
- scsi: fc: Add EDC ELS definition (bsc#1190576).
  Refresh and update:
  - patches.kabi/scsi-fc-kABI-fixes-for-new-ELS_RDP-definition.patch
- scsi: core: Add helper to return number of logical blocks in
  a request (bsc#1190576).
- scsi: lpfc: Use scsi_cmd_to_rq() instead of scsi_cmnd.request
  (bsc#1190576).
- scsi: core: Introduce the scsi_cmd_to_rq() function
  (bsc#1190576).
- scsi: fc: Update formal FPIN descriptor definitions
  (bsc#1190576).
- commit e13d431
* Mon Sep 20 2021 msuchanek@suse.de
- Refresh patches.suse/msft-hv-2119-irqdomain-treewide-Keep-firmware-node-unconditionall.patch.
  Add else braces.
- commit f230c58
* Sun Sep 19 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  - patches.suse/ibmvnic-check-failover_pending-in-login-response.patch
- commit 2b5f056
* Fri Sep 17 2021 msuchanek@suse.de
- kernel-binary.spec: Check for no kernel signing certificates.
  Also remove unused variable.
- commit bdc323e
* Fri Sep 17 2021 msuchanek@suse.de
- Revert "rpm/kernel-binary.spec: Use only non-empty certificates."
  This reverts commit 30360abfb58aec2c9ee7b6a27edebe875c90029d.
- commit 413e05b
* Fri Sep 17 2021 lhenriques@suse.de
- fuse: flush extending writes (bsc#1190595).
- cuse: fix broken release (bsc#1190596).
- commit 232b4ea
* Fri Sep 17 2021 msuchanek@suse.de
- rpm/kernel-binary.spec: Use only non-empty certificates.
- commit 30360ab
* Thu Sep 16 2021 tabraham@suse.com
- ipvs: Fix up kabi for expire_nodest_conn_work addition
  (bsc#1190467).
- ipvs: queue delayed work to expire no destination connections
  if expire_nodest_conn=1 (bsc#1190467).
- ipvs: allow connection reuse for unconfirmed conntrack
  (bsc#1190467).
- ipvs: avoid expiring many connections from timer (bsc#1190467).
- commit e0da213
* Thu Sep 16 2021 jack@suse.cz
- ext4: fix race writing to an inline_data file while its xattrs
  are changing (bsc#1190159 CVE-2021-40490).
- commit 4fadd7d
* Thu Sep 16 2021 bp@suse.de
- crypto: ccp - fix resource leaks in ccp_run_aes_gcm_cmd()
  (bsc#1189884 CVE-2021-3744 bsc#1190534 CVE-2021-3764).
- commit 4ee91a7
* Thu Sep 16 2021 ailiop@suse.com
- xfs: allow mount/remount when stripe width alignment is zero
  (bsc#1188651).
- commit e701c22
* Thu Sep 16 2021 tbogendoerfer@suse.de
- bnxt_en: Fix asic.rev in devlink dev info command
  (jsc#SLE-16649).
- bnxt_en: fix stored FW_PSID version masks (jsc#SLE-16649).
- RDMA/hns: Fix QP's resp incomplete assignment (jsc#SLE-14777).
- RDMA/rtrs: Remove a useless kfree() (jsc#SLE-15176).
- RDMA/mlx5: Delete not-available udata check (jsc#SLE-15175).
- IB/hfi1: Indicate DMA wait when txq is queued for wakeup
  (jsc#SLE-13208).
- devlink: Clear whole devlink_flash_notify struct (bsc#1176447).
- net/mlx5: Fix missing return value in
  mlx5_devlink_eswitch_inline_mode_set() (jsc#SLE-15172).
- ionic: cleanly release devlink instance (bsc#1167773).
- ionic: drop useless check of PCI driver data validity
  (bsc#1167773).
- i40e: improve locking of mac_filter_hash (jsc#SLE-13701).
- igc: Use num_tx_queues when iterating over tx_ring queue
  (jsc#SLE-13533).
- ice: do not abort devlink info if board identifier can't be
  found (jsc#SLE-12878).
- sch_cake: fix srchost/dsthost hashing mode (bsc#1176447).
- ice: don't remove netdev->dev_addr from uc sync list
  (git-fixes).
- bareudp: Fix invalid read beyond skb's linear data
  (jsc#SLE-15172).
- RDMA/mlx5: Delay emptying a cache entry when a new MR is added
  to it recently (jsc#SLE-15175).
- commit 3dc7052
* Thu Sep 16 2021 tbogendoerfer@suse.de
- qlcnic: Remove redundant unlock in qlcnic_pinit_from_rom
  (git-fixes).
- debugfs: Return error during {full/open}_proxy_open() on rmmod
  (bsc#1173746).
- devlink: Break parameter notification sequence to be
  before/after unload/load driver (bsc#1154353).
- net/mlx5e: Prohibit inner indir TIRs in IPoIB (git-fixes).
- ionic: cleanly release devlink instance (bsc#1167773).
- gve: fix the wrong AdminQ buffer overflow check (bsc#1176940).
- cxgb4: dont touch blocked freelist bitmap after free
  (git-fixes).
- e1000e: Do not take care about recovery NVM checksum
  (jsc#SLE-8100).
- e1000e: Fix the max snoop/no-snoop latency for 10M (git-fixes).
- xgene-v2: Fix a resource leak in the error handling path of
  'xge_probe()' (git-fixes).
- RDMA/bnxt_re: Remove unpaired rtnl unlock in bnxt_re_dev_init()
  (bsc#1170774).
- iavf: Fix ping is lost after untrusted VF had tried to change
  MAC (jsc#SLE-7940).
- net: qlcnic: add missed unlock in qlcnic_83xx_flash_read32
  (git-fixes).
- bnxt_en: Add missing DMA memory barriers (git-fixes).
- bnxt_en: Disable aRFS if running on 212 firmware (git-fixes).
- bnxt: count Tx drops (git-fixes).
- bnxt: make sure xmit_more + errors does not miss doorbells
  (git-fixes).
- bnxt: disable napi before canceling DIM (git-fixes).
- bnxt: don't lock the tx queue from napi poll (git-fixes).
- net/mlx5: Fix return value from tracer initialization
  (git-fixes).
- net/mlx5e: Avoid creating tunnel headers for local route
  (git-fixes).
- iavf: Set RSS LUT and key in reset handle path (git-fixes).
- ice: Prevent probing virtual functions (git-fixes).
- bnx2x: fix an error code in bnx2x_nic_load() (git-fixes).
- nfp: update ethtool reporting of pauseframe control (git-fixes).
- net/mlx5e: Fix nullptr in mlx5e_hairpin_get_mdev() (git-fixes).
- net/mlx5: Unload device upon firmware fatal error (git-fixes).
- net/mlx5: E-Switch, handle devcom events only for ports on
  the same device (git-fixes).
- net/mlx5: Fix flow table chaining (git-fixes).
- mlx4: Fix missing error code in mlx4_load_one() (git-fixes).
- ionic: count csum_none when offload enabled (bsc#1167773).
- i40e: Fix log TC creation failure when max num of queues is
  exceeded (git-fixes).
- i40e: Fix queue-to-TC mapping on Tx (git-fixes).
- i40e: Add additional info to PHY type error (git-fixes).
- i40e: Fix firmware LLDP agent related warning (git-fixes).
- i40e: Fix logic of disabling queues (git-fixes).
- bnxt_en: Do not enable legacy TX push on older firmware
  (git-fixes).
- bnxt_en: Store the running firmware version code (git-fixes).
- commit f97144d
* Thu Sep 16 2021 msuchanek@suse.de
- powerpc/numa: Consider the max NUMA node for migratable LPAR
  (bsc#1190544 ltc#194520).
- commit ea0d9bb
* Thu Sep 16 2021 tiwai@suse.de
- iwlwifi Add support for ax201 in Samsung Galaxy Book Flex2 Alpha
  (git-fixes).
- drm/msm/mdp4: move HW revision detection to earlier phase
  (git-fixes).
- drm/msm/mdp4: refactor HW revision detection into
  read_mdp_hw_revision (git-fixes).
- ASoC: rt5682: Remove unused variable in rt5682_i2c_remove()
  (git-fixes).
- ASoC: rt5682: Properly turn off regulators if wrong device ID
  (git-fixes).
- ASoC: Intel: Fix platform ID matching (git-fixes).
- ASoC: rt5682: Implement remove callback (git-fixes).
- commit 6612614
* Thu Sep 16 2021 tiwai@suse.de
- fbmem: don't allow too huge resolutions (git-fixes).
- backlight: pwm_bl: Improve bootloader/kernel device handover
  (git-fixes).
- media: coda: fix frame_mem_ctrl for YUV420 and YVU420 formats
  (git-fixes).
- tty: Fix data race between tiocsti() and flush_to_ldisc()
  (git-fixes).
- PM: EM: Increase energy calculation precision (git-fixes).
- libata: fix ata_host_start() (git-fixes).
- power: supply: max17042_battery: fix typo in MAx17042_TOFF
  (git-fixes).
- power: supply: axp288_fuel_gauge: Report register-address on
  readb / writeb errors (git-fixes).
- regmap: fix the offset of register error log (git-fixes).
- regmap: fix page selection for noinc writes (git-fixes).
- regmap: fix page selection for noinc reads (git-fixes).
- commit 0c36126
* Wed Sep 15 2021 dbueso@suse.de
- time: Handle negative seconds correctly in timespec64_to_ns()
  (git-fixes).
- mm: always have io_remap_pfn_range() set pgprot_decrypted()
  (git-fixes).
- commit b2d42ef
* Wed Sep 15 2021 msuchanek@suse.de
- ibmvnic: check failover_pending in login response (bsc#1190523
  ltc#194510).
- commit 9f9cec0
* Wed Sep 15 2021 vliaskovitis@suse.com
- x86/apic/msi: Plug non-maskable MSI affinity race (bsc#1184439).
- Refresh
  patches.suse/0002-x86-msi-Only-use-high-bits-of-MSI-address-for-DMAR-u.patch.
- Refresh
  patches.suse/0004-x86-apic-Support-15-bits-of-APIC-ID-in-IOAPIC-MSI-wh.patch.
- Refresh
  patches.suse/msft-hv-2119-irqdomain-treewide-Keep-firmware-node-unconditionall.patch.
- commit a89813f
* Tue Sep 14 2021 bp@suse.de
- EDAC/i10nm: Fix NVDIMM detection (bsc#1152489).
- commit 9def092
* Tue Sep 14 2021 martin.wilck@suse.com
- scsi: scsi_devinfo: Add blacklist entry for HPE OPEN-V
  (bsc#1189297).
- commit 913942c
* Tue Sep 14 2021 tabraham@suse.com
- netfilter: conntrack: do not renew entry stuck in tcp SYN_SENT
  state (bsc#1190062).
- commit e5272e8
* Tue Sep 14 2021 oneukum@suse.com
- clk: at91: clk-generated: Limit the requested rate to our range
  (git-fixes).
- commit c432b6b
* Tue Sep 14 2021 dwagner@suse.de
- nvme: only call synchronize_srcu when clearing current path
  (bsc#1188067).
- nvme-tcp: Do not reset transport on data digest errors
  (bsc#1188418).
- nvme-multipath: revalidate paths during rescan (bsc#1187211).
- commit 359f763
* Tue Sep 14 2021 ykaukab@suse.de
- phy: tegra: xusb: Fix dangling pointer on probe failure
  (git-fixes).
- misc: sram: Only map reserved areas in Tegra SYSRAM (git-fixes).
- misc: sram: use devm_platform_ioremap_resource_wc() (git-fixes).
- commit b7afa19
* Tue Sep 14 2021 nmoreychaisemartin@suse.com
- blacklist.conf: add efa non backportable patch
- commit ebbcbd1
* Tue Sep 14 2021 shung-hsi.yu@suse.com
- selftests/bpf: Fix bpf-iter-tcp4 test to print correctly the
  dest IP (git-fixes).
- bpf, samples: Add missing mprog-disable to xdp_redirect_cpu's
  optstring (git-fixes).
- libbpf: Fix removal of inner map in bpf_object__create_map
  (git-fixes).
- libbpf: Fix the possible memory leak on error (git-fixes).
- bpf: Fix ringbuf helper function compatibility (git-fixes).
- tools: bpf: Fix error in 'make -C tools/ bpf_install'
  (git-fixes).
- selftests/bpf: Whitelist test_progs.h from .gitignore
  (git-fixes).
- bpftool: Add sock_release help info for cgroup attach/prog
  load command (bsc#1177028).
- selftests/bpf: Define string const as global for
  test_sysctl_prog.c (git-fixes).
- selftests/bpf: Fix test_sysctl_loop{1, 2} failure due to clang
  change (git-fixes).
- commit 37bd48e
* Mon Sep 13 2021 mkoutny@suse.com
- ipc: remove memcg accounting for sops objects in do_semtimedop()
  (bsc#1190115).
- memcg: enable accounting of ipc resources (bsc#1190115
  CVE-2021-3759).
- commit 84a3538
* Mon Sep 13 2021 oneukum@suse.com
- usb: dwc2: Add missing cleanups when usb_add_gadget_udc()
  fails (git-fixes).
- commit bc5a062
* Mon Sep 13 2021 mkoutny@suse.com
- ipc: remove memcg accounting for sops objects in do_semtimedop()
  (bsc#1190115).
- commit 561fbd8
* Mon Sep 13 2021 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  - patches.suse/nvme-multipath-revalidate-paths-during-rescan.patch
  - patches.suse/nvme-only-call-synchronize_srcu-when-clearing-curren.patch
  - patches.suse/nvme-tcp-Do-not-reset-transport-on-data-digest-error.patch
- commit ebb6bcb
* Mon Sep 13 2021 martin.wilck@suse.com
- fixup "rpm: support gz and zst compression methods" once more
  (bsc#1190428, bsc#1190358)
  Fixes: 3b8c4d9bcc24 ("rpm: support gz and zst compression methods")
  Fixes: 23510fce36ec ("fixup "rpm: support gz and zst compression methods"")
- commit 165378a
* Mon Sep 13 2021 tiwai@suse.de
- PM: sleep: core: Avoid setting power.must_resume to false
  (git-fixes).
- drm/panfrost: Use u64 for size in lock_region (git-fixes).
- dmaengine: idxd: clear block on fault flag when clear wq
  (git-fixes).
- dmaengine: idxd: fix wq slot allocation index check (git-fixes).
- commit b255b0e
* Mon Sep 13 2021 tiwai@suse.de
- PCI: xilinx-nwl: Enable the clock through CCF (git-fixes).
- PCI: iproc: Fix BCMA probe resource handling (git-fixes).
- usb: dwc2: Fix error path in gadget registration (git-fixes).
- commit 59e7328
* Mon Sep 13 2021 tiwai@suse.de
- thermal/drivers/exynos: Fix an error code in exynos_tmu_probe()
  (git-fixes).
- drm/panfrost: Simplify lock_region calculation (git-fixes).
- dmaengine: acpi: Avoid comparison GSI with Linux vIRQ
  (git-fixes).
- mfd: lpc_sch: Rename GPIOBASE to prevent build error
  (git-fixes).
- mfd: tqmx86: Clear GPIO IRQ resource when no IRQ is set
  (git-fixes).
- mfd: axp20x: Update AXP288 volatile ranges (git-fixes).
- gpio: mpc8xxx: Fix a resources leak in the error handling path
  of 'mpc8xxx_probe()' (git-fixes).
- commit 75d69a6
* Mon Sep 13 2021 tiwai@suse.de
- pwm: lpc32xx: Don't modify HW state in .probe() after the PWM
  chip was registered (git-fixes).
- ALSA: usb-audio: Add registration quirk for JBL Quantum 800
  (git-fixes).
- PCI: Fix pci_dev_str_match_path() alloc while atomic bug
  (git-fixes).
- PCI/portdrv: Enable Bandwidth Notification only if port supports
  it (git-fixes).
- PCI: Return ~0 data on pciconfig_read() CAP_SYS_ADMIN failure
  (git-fixes).
- PCI: Call Max Payload Size-related fixup quirks early
  (git-fixes).
- ALSA: hda/realtek: Workaround for conflicting SSID on ASUS
  ROG Strix G17 (git-fixes).
- reset: reset-zynqmp: Fixed the argument data type (git-fixes).
- gpu: ipu-v3: Fix i.MX IPU-v3 offset calculations for
  (semi)planar U/V formats (git-fixes).
- commit f395ad9
* Sun Sep 12 2021 tiwai@suse.de
- Drop two intel_int0002_vgpio patches that cause Oops (bsc#1190412)
  Deleted and blacklisted:
  patches.suse/platform-x86-intel_int0002_vgpio-Only-call-enable_ir.patch
  patches.suse/platform-x86-intel_int0002_vgpio-Pass-irqchip-when-a.patch
- commit bebba41
* Sun Sep 12 2021 martin.wilck@suse.com
- fixup "rpm: support gz and zst compression methods" once more
  Fixes: 3b8c4d9bcc24 ("rpm: support gz and zst compression methods")
  Fixes: 23510fce36ec ("fixup "rpm: support gz and zst compression methods"")
- commit 34e68f4
* Sun Sep 12 2021 jeffm@suse.com
- Avoid double printing SUSE specific flags in mod->taint (bsc#1190413).
- commit 297a1a6
* Sat Sep 11 2021 martin.wilck@suse.com
- fixup "rpm: support gz and zst compression methods" (bsc#1190358, bsc#1190428).
  Fixes: 3b8c4d9bcc24 ("rpm: support gz and zst compression methods")
- fixup "rpm: support gz and zst compression methods"
  Fixes: 3b8c4d9bcc24 ("rpm: support gz and zst compression methods")
- commit 6c262f9
* Fri Sep 10 2021 msuchanek@suse.de
- kernel-cert-subpackage: Fix certificate location in scriptlets
  (bsc#1189841).
  Fixes: d9a1357edd73 ("rpm: Define $certs as rpm macro (bsc#1189841).")
- commit 8684de8
* Fri Sep 10 2021 msuchanek@suse.de
- kernel-binary.spec.in Stop templating the scriptlets for subpackages
  (bsc#1190358).
  The script part for base package case is completely separate from the
  part for subpackages. Remove the part for subpackages from the base
  package script and use the KMP scripts for subpackages instead.
- commit 5d1f677
* Fri Sep 10 2021 msuchanek@suse.de
- kernel-binary.spec: Do not fail silently when KMP is empty
  (bsc#1190358).
  Copy the code from kernel-module-subpackage that deals with empty KMPs.
- commit d7d2e6e
* Fri Sep 10 2021 vbabka@suse.cz
- mm/vmscan: fix infinite loop in drop_slab_node (VM
  Functionality, bsc#1189301).
- commit 016e8e0
* Fri Sep 10 2021 neilb@suse.de
- blacklist.conf: blacklist an unwanted commit
- commit 910824e
* Fri Sep 10 2021 neilb@suse.de
- SUNRPC: Simplify socket shutdown when not reusing TCP ports
  (git-fixes).
- SUNRPC: Fix potential memory corruption (git-fixes).
- NFSv4/pNFS: Fix a layoutget livelock loop (git-fixes).
- nfsd4: Fix forced-expiry locking (git-fixes).
- lockd: Fix invalid lockowner cast after vfs_test_lock
  (git-fixes).
- commit 59642ba
* Thu Sep  9 2021 lduncan@suse.com
- scsi: mpt3sas: Fix ReplyPostFree pool allocation (bsc#1181006).
- commit 8c2fa8c
* Thu Sep  9 2021 lduncan@suse.com
- scsi: mpt3sas: Fix ReplyPostFree pool allocation (bsc#1181006).
- commit a70a19d
* Thu Sep  9 2021 msuchanek@suse.de
- Sort nvme patches into linux-block.
- commit 090f7ef
* Thu Sep  9 2021 msuchanek@suse.de
- Refresh patches.suse/cpuidle-pseries-Fixup-CEDE0-latency-only-for-POWER10.patch
  Update patch metadata.
- commit cbfec2a
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: rip out btrfs_space_info::total_bytes_pinned (bsc#1135481).
- Delete
  patches.suse/btrfs-dump_space_info-when-encountering-total_bytes_pinned-0-at-umount.patch.
- commit bfb1107
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: rip the first_ticket_bytes logic from fail_all_tickets (bsc#1135481).
- commit 9722825
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: remove FLUSH_DELAYED_REFS from data ENOSPC flushing (bsc#1135481).
- commit 350aa4f
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: rip out may_commit_transaction (bsc#1135481).
- commit 4606638
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: add a trace class for dumping the current ENOSPC state (bsc#1135481).
- commit 631f16e
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: adjust the flush trace point to include the source (bsc#1135481).
- commit e32ea57
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: implement space clamping for preemptive flushing (bsc#1135481).
- commit ca710c1
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: simplify the logic in need_preemptive_flushing (bsc#1135481).
- commit 4b02073
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: rework btrfs_calc_reclaim_metadata_size (bsc#1135481).
- commit 7205c9f
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: fix btrfs_calc_reclaim_metadata_size calculation (bsc#1135481).
- Refresh
  patches.suse/btrfs-account-ticket-size-at-add-delete-time.patch.
- commit bcb2da5
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: check reclaim_size in need_preemptive_reclaim (bsc#1135481).
- commit fba4763
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: rename need_do_async_reclaim (bsc#1135481).
- commit f764126
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: improve preemptive background space flushing (bsc#1135481).
- commit 874aca2
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: introduce a FORCE_COMMIT_TRANS flush operation (bsc#1135481).
- commit 7ec1638
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: tracepoints: convert flush states to using EM macros (bsc#1135481).
- commit c78869d
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: tracepoints: fix btrfs_trigger_flush symbolic string for flags (bsc#1135481).
- commit c805821
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: add a trace point for reserve tickets (bsc#1135481).
- commit ed22c30
* Thu Sep  9 2021 nborisov@suse.com
- btrfs: make flush_space take a enum btrfs_flush_state instead of int (bsc#1135481).
- commit f6a0397
* Thu Sep  9 2021 tiwai@suse.de
- ALSA: hda/realtek: Quirk for HP Spectre x360 14 amp setup
  (git-fixes).
- ALSA: hda/realtek: Workaround for conflicting SSID on ASUS
  ROG Strix G17 (git-fixes).
- gpu: ipu-v3: Fix i.MX IPU-v3 offset calculations for
  (semi)planar U/V formats (git-fixes).
- commit 6335a8b
* Thu Sep  9 2021 neilb@suse.de
- SUNRPC: improve error response to over-size gss credential
  (bsc#1190022).
- commit 0678bd3
* Wed Sep  8 2021 lduncan@suse.com
- scsi: sg: add sg_remove_request in sg_write (bsc#1171420
  CVE2020-12770).
- commit 59a4a94
* Wed Sep  8 2021 tiwai@suse.de
- Bluetooth: schedule SCO timeouts with delayed_work
  (CVE-2021-3640 bsc#1188172).
- Refresh
  patches.suse/Bluetooth-fix-repeated-calls-to-sco_sock_kill.patch.
- Refresh patches.suse/Bluetooth-switch-to-lock_sock-in-SCO.patch.
- commit 69c5b94
* Wed Sep  8 2021 varad.gautam@suse.com
- sched/fair: Ensure that the CFS parent is added after unthrottling (git-fixes).
- commit f3a38fb
* Wed Sep  8 2021 jslaby@suse.cz
- rpm/kernel-source.spec.in: do some more for vanilla_only
  Make sure:
  * sources are NOT executable
  * env is not used as interpreter
  * timestamps are correct
  We do all this for normal kernel builds, but not for vanilla_only
  kernels (linux-next and vanilla).
- commit b41e4fd
* Wed Sep  8 2021 mkoutny@suse.com
- Revert "memcg: enable accounting for file lock caches (bsc#1190115)."
  This reverts commit 78b761616bfb31a0d54806624e7c8db23fbeda9c.
  It's effectively upstream commit
  3754707bcc3e190e5dadc978d172b61e809cb3bd applied to kernel-source (to
  avoid proliferation of patches). Make a note in blacklist.conf too.
- commit eba498f
* Wed Sep  8 2021 mkubecek@suse.cz
- Update kabi files.
- update from September 2021 maintenance update submission (commit 21030bc7f9be)
- commit 63b67d5
* Tue Sep  7 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  - patches.suse/mm-vmscan-guarantee-drop_slab_node-termination.patch
- commit bddec27
* Tue Sep  7 2021 oneukum@suse.com
- blacklist.conf: kABI
- commit 2b1e710
* Tue Sep  7 2021 vbabka@suse.cz
- mm, vmscan: guarantee drop_slab_node() termination (VM
  Functionality, bsc#1189301).
- commit 56cc71b
* Tue Sep  7 2021 denis.kirjanov@suse.com
- Delete patches.kabi/cpuidle-cpuidle_state-kABI-fix.patch.
  we don't have the field in sle15-sp3
- commit 0e3f58a
* Tue Sep  7 2021 oneukum@suse.com
- blacklist.conf: cosmetic fix
- commit c872ce5
* Tue Sep  7 2021 bp@suse.de
- EDAC/mce_amd: Do not load edac_mce_amd module on guests
  (bsc#1190138).
- commit 2d1891d
* Tue Sep  7 2021 mbenes@suse.cz
- blacklist.conf: 33cba859220b ("fscache: Fix fscache_cookie_put() to not deref after dec")
  Needs prerequisites to backport which could be problematic.
- commit 648a5e5
* Tue Sep  7 2021 oneukum@suse.com
- usb: dwc3: core: Properly default unspecified speed (git-fixes).
- commit 714137e
* Tue Sep  7 2021 tiwai@suse.de
- libata: add ATA_HORKAGE_NO_NCQ_TRIM for Samsung 860 and 870 SSDs
  (git-fixes).
- commit 5a2ecd2
* Tue Sep  7 2021 shung-hsi.yu@suse.com
- kABI: revert change in struct bpf_insn_aux_data (bsc#1188983,
  bsc#1188985, CVE-2021-34556, CVE-2021-35477).
- commit 425bbd2
* Mon Sep  6 2021 mkoutny@suse.com
- memcg: enable accounting of ipc resources (bsc#1190115
  CVE-2021-3759).
- memcg: enable accounting for file lock caches (bsc#1190115).
- commit 925e30c
* Mon Sep  6 2021 jroedel@suse.de
- Refresh
  patches.suse/KVM-nSVM-avoid-picking-up-unsupported-bits-from-L2-i.patch.
- commit f3cba28
* Mon Sep  6 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  - patches.suse/powerpc-stacktrace-Include-linux-delay.h.patch
- commit 0d42678
* Mon Sep  6 2021 mkubecek@suse.cz
- update nvme patch references and move them out of sorted section
  Within a few days, nvme repository was not only rebased again but the
  patches has been also reordered. To avoid further spurious git-sort errors,
  move the nvme patches out of sorted section until they reach mainline or
  some better behaving subsystem repository.
- update Git-commit and move out of sorted section:
  - patches.suse/nvme-multipath-revalidate-paths-during-rescan.patch
  - patches.suse/nvme-only-call-synchronize_srcu-when-clearing-curren.patch
  - patches.suse/nvme-tcp-Do-not-reset-transport-on-data-digest-error.patch
- commit 95e9f8b
* Mon Sep  6 2021 osalvador@suse.de
- mm: fix memory_failure() handling of dax-namespace metadata
  (bsc#1189872).
- commit e915313
* Mon Sep  6 2021 msuchanek@suse.de
- rpm: Fold kernel-devel and kernel-source scriptlets into spec files
  (bsc#1189841).
  These are unchanged since 2011 when they were introduced. No need to
  track them separately.
- commit 692d38b
* Mon Sep  6 2021 msuchanek@suse.de
- rpm: Abolish image suffix (bsc#1189841).
  This is used only with vanilla kernel which is not supported in any way.
  The only effect is has is that the image and initrd symlinks are created
  with this suffix.
  These symlinks are not used except on s390 where the unsuffixed symlinks
  are used by zipl.
  There is no reason why a vanilla kernel could not be used with zipl as
  well as it's quite unexpected to not be able to boot when only a vanilla
  kernel is installed.
  Finally we now have a backup zipl kernel so if the vanilla kernel is
  indeed unsuitable the backup kernel can be used.
- commit e2f37db
* Mon Sep  6 2021 msuchanek@suse.de
- kernel-binary.spec: Define $image as rpm macro (bsc#1189841).
- commit e602b0f
* Mon Sep  6 2021 msuchanek@suse.de
- rpm: Define $certs as rpm macro (bsc#1189841).
  Also pass around only the shortened hash rather than full filename.
  As has been discussed in bsc#1124431 comment 51
  https://bugzilla.suse.com/show_bug.cgi?id=1124431#c51 the placement of
  the certificates is an API which cannot be changed unless we can ensure
  that no two kernels that use different certificate location can be built
  with the same certificate.
- commit d9a1357
* Mon Sep  6 2021 tiwai@suse.de
- HID: input: do not report stylus battery state as "full"
  (git-fixes).
- HID: i2c-hid: Fix Elan touchpad regression (git-fixes).
- pinctrl: samsung: Fix pinctrl bank pin count (git-fixes).
- pinctrl: stmfx: Fix hazardous u8[] to unsigned long cast
  (git-fixes).
- pinctrl: single: Fix error return code in
  pcs_parse_bits_in_pinctrl_entry() (git-fixes).
- clk: kirkwood: Fix a clocking boot regression (git-fixes).
- mailbox: sti: quieten kernel-doc warnings (git-fixes).
- overflow: Correct check_shl_overflow() comment (git-fixes).
- commit 835ad7d
* Mon Sep  6 2021 tiwai@suse.de
- ASoC: rt5682: Adjust headset volume button threshold again
  (git-fixes).
- commit 662b23e
* Mon Sep  6 2021 tiwai@suse.de
- drm/nouveau/kms/nv50: workaround EFI GOP window channel format
  differences (git-fixes).
- iwlwifi: pnvm: accept multiple HW-type TLVs (git-fixes).
- ASoC: component: Remove misplaced prefix handling in pin
  control functions (git-fixes).
- ASoC: rt5682: Adjust headset volume button threshold
  (git-fixes).
- commit db055cd
* Mon Sep  6 2021 tiwai@suse.de
- mtd: rawnand: cafe: Fix a resource leak in the error handling
  path of 'cafe_nand_probe()' (git-fixes).
- USB: serial: option: add new VID/PID to support Fibocom FG150
  (git-fixes).
- drm/nouveau/disp: power down unused DP links during init
  (git-fixes).
- drm: Copy drm_wait_vblank to user before returning (git-fixes).
- virtio_pci: Support surprise removal of virtio pci device
  (git-fixes).
- commit ce46f13
* Mon Sep  6 2021 ghe@suse.com
- ocfs2: ocfs2_downconvert_lock failure results in deadlock
  (bsc#1188439).
- commit d85d8fa
* Fri Sep  3 2021 mkoutny@suse.com
- cgroup1: fix leaked context root causing sporadic NULL deref
  in LTP (bsc#1190181).
- commit d57aed6
* Fri Sep  3 2021 msuchanek@suse.de
- Refresh patches.suse/powerpc-stacktrace-Include-linux-delay.h.patch.
- commit aec8493
* Fri Sep  3 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  - patches.suse/scsi-core-Add-scsi_prot_ref_tag-helper.patch
  - patches.suse/scsi-ibmvfc-Do-not-wait-for-initial-device-scan.patch
  - patches.suse/scsi-lpfc-Add-256-Gb-link-speed-support.patch
  - patches.suse/scsi-lpfc-Add-PCI-ID-support-for-LPe37000-LPe38000-s.patch
  - patches.suse/scsi-lpfc-Call-discovery-state-machine-when-handling.patch
  - patches.suse/scsi-lpfc-Clear-outstanding-active-mailbox-during-PC.patch
  - patches.suse/scsi-lpfc-Copyright-updates-for-12.8.0.11-patches.patch
  - patches.suse/scsi-lpfc-Copyright-updates-for-14.0.0.0-patches.patch
  - patches.suse/scsi-lpfc-Delay-unregistering-from-transport-until-G.patch
  - patches.suse/scsi-lpfc-Discovery-state-machine-fixes-for-LOGO-han.patch
  - patches.suse/scsi-lpfc-Enable-adisc-discovery-after-RSCN-by-defau.patch
  - patches.suse/scsi-lpfc-Fix-KASAN-slab-out-of-bounds-in-lpfc_unreg.patch
  - patches.suse/scsi-lpfc-Fix-NULL-ptr-dereference-with-NPIV-ports-f.patch
  - patches.suse/scsi-lpfc-Fix-NVMe-support-reporting-in-log-message.patch
  - patches.suse/scsi-lpfc-Fix-cq_id-truncation-in-rq-create.patch
  - patches.suse/scsi-lpfc-Fix-function-description-comments-for-vmid.patch
  - patches.suse/scsi-lpfc-Fix-memory-leaks-in-error-paths-while-issu.patch
  - patches.suse/scsi-lpfc-Fix-possible-ABBA-deadlock-in-nvmet_xri_ab.patch
  - patches.suse/scsi-lpfc-Fix-target-reset-handler-from-falsely-retu.patch
  - patches.suse/scsi-lpfc-Improve-firmware-download-logging.patch
  - patches.suse/scsi-lpfc-Keep-NDLP-reference-until-after-freeing-th.patch
  - patches.suse/scsi-lpfc-Remove-REG_LOGIN-check-requirement-to-issu.patch
  - patches.suse/scsi-lpfc-Remove-redundant-assignment-to-pointer-pcm.patch
  - patches.suse/scsi-lpfc-Remove-use-of-kmalloc-in-trace-event-loggi.patch
  - patches.suse/scsi-lpfc-Revise-Topology-and-RAS-support-checks-for.patch
  - patches.suse/scsi-lpfc-Skip-issuing-ADISC-when-node-is-in-NPR-sta.patch
  - patches.suse/scsi-lpfc-Skip-reg_vpi-when-link-is-down-for-SLI3-in.patch
  - patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.11.patch
  - patches.suse/scsi-lpfc-Update-lpfc-version-to-14.0.0.0.patch
  - patches.suse/scsi-lpfc-Use-PBDE-feature-enabled-bit-to-determine-.patch
  - patches.suse/scsi-qla2xxx-Fix-spelling-mistakes-allloc-alloc.patch
  - patches.suse/scsi-qla2xxx-Fix-use-after-free-in-debug-code.patch
  - patches.suse/scsi-qla2xxx-Remove-redundant-continue-statement-in-.patch
  - patches.suse/scsi-qla2xxx-Remove-redundant-initialization-of-vari.patch
  - patches.suse/scsi-qla2xxx-Remove-unused-variable-status.patch
  - patches.suse/scsi-qla2xxx-Update-version-to-10.02.00.107-k.patch
  - patches.suse/scsi-qla2xxx-Use-the-proper-SCSI-midlayer-interfaces.patch
  - patches.suse/scsi-qla2xxx-edif-Add-authentication-pass-fail-bsgs.patch
  - patches.suse/scsi-qla2xxx-edif-Add-detection-of-secure-device.patch
  - patches.suse/scsi-qla2xxx-edif-Add-doorbell-notification-for-app.patch
  - patches.suse/scsi-qla2xxx-edif-Add-encryption-to-I-O-path.patch
  - patches.suse/scsi-qla2xxx-edif-Add-extraction-of-auth_els-from-th.patch
  - patches.suse/scsi-qla2xxx-edif-Add-getfcinfo-and-statistic-bsgs.patch
  - patches.suse/scsi-qla2xxx-edif-Add-key-update.patch
  - patches.suse/scsi-qla2xxx-edif-Add-send-receive-and-accept-for-au.patch
  - patches.suse/scsi-qla2xxx-edif-Add-start-stop-bsgs.patch
  - patches.suse/scsi-qla2xxx-edif-Increment-command-and-completion-c.patch
- commit 9a3c219
* Thu Sep  2 2021 mkubecek@suse.cz
- update patches metadata
  Once again, the nvme repository branch has been rebased so that patches
  from it must have their Git-commit tags updated to avoid git-sort errors.
- commit cca729c
* Thu Sep  2 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/NFS-Correct-size-calculation-for-create-reply-length.patch
- commit fbde034
* Thu Sep  2 2021 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  - patches.suse/nvme-code-command_id-with-a-genctr-for-use-after-fre.patch
  - patches.suse/nvme-pci-limit-maximum-queue-depth-to-4095.patch
  - patches.suse/nvme-tcp-don-t-check-blk_mq_tag_to_rq-when-receiving.patch
  - patches.suse/params-lift-param_set_uint_minmax-to-common-code.patch
- commit 5b98a5d
* Thu Sep  2 2021 mkoutny@suse.com
- cgroup: verify that source is a string (bsc#1190131).
- commit b8204f1
* Thu Sep  2 2021 mkoutny@suse.com
- blacklist.conf: Add 2ca11b0e043b cgroup: Fix kernel-doc
- commit 0b9195b
* Thu Sep  2 2021 tiwai@suse.de
- Update patch reference for virtio_console fix (CVE-2021-38160 bsc#1190117)
- commit c8baed7
* Thu Sep  2 2021 tiwai@suse.de
- rpm/config.sh: correct OBS_PROJECT to SUSE:SLE-15-SP3:Update
  SP3 has been released long time ago
- commit c0223dc
* Thu Sep  2 2021 dwagner@suse.de
- scsi: libfc: Fix array index out of bound exception
  (bsc#1188616).
- commit de260d1
* Thu Sep  2 2021 dwagner@suse.de
- nvme-tcp: Do not reset transport on data digest errors
  (bsc#1188418).
- nvme: only call synchronize_srcu when clearing current path
  (bsc#1188067).
- commit bbe789f
* Thu Sep  2 2021 tiwai@suse.de
- drm/msm: Fix error return code in msm_drm_init() (git-fixes).
- drm/dp_mst: Fix return code on sideband message failure
  (git-fixes).
- drm/prime: fix comment on PRIME Helpers (git-fixes).
- drm/of: free the iterator object on failure (git-fixes).
- drm/of: free the right object (git-fixes).
- ASoC: Intel: Skylake: Fix module resource and format selection
  (git-fixes).
- ASoC: Intel: kbl_da7219_max98927: Fix format selection for
  max98373 (git-fixes).
- ASoC: mediatek: mt8183: Fix Unbalanced pm_runtime_enable in
  mt8183_afe_pcm_dev_probe (git-fixes).
- commit a00572a
* Thu Sep  2 2021 tiwai@suse.de
- VMCI: fix NULL pointer dereference when unmapping queue pair
  (git-fixes).
- commit 45162f9
* Thu Sep  2 2021 tiwai@suse.de
- usb: host: xhci-rcar: Don't reload firmware after the completion
  (git-fixes).
- usb: bdc: Fix an error handling path in 'bdc_probe()' when no
  suitable DMA config is available (git-fixes).
- usb: ehci-orion: Handle errors of clk_prepare_enable() in probe
  (git-fixes).
- usb: gadget: mv_u3d: request_irq() after initializing UDC
  (git-fixes).
- usb: phy: tahvo: add IRQ check (git-fixes).
- usb: host: ohci-tmio: add IRQ check (git-fixes).
- usb: gadget: udc: renesas_usb3: Fix soc_device_match() abuse
  (git-fixes).
- usb: mtu3: fix the wrong HS mult value (git-fixes).
- usb: mtu3: use @mult for HS isoc or intr (git-fixes).
- usb: phy: twl6030: add IRQ checks (git-fixes).
- commit 2b2a9dc
* Thu Sep  2 2021 tiwai@suse.de
- soc: qcom: smsm: Fix missed interrupts if state changes while
  masked (git-fixes).
- soc: qcom: rpmhpd: Use corner in power_off (git-fixes).
- soc: aspeed: p2a-ctrl: Fix boundary check for mmap (git-fixes).
- soc: aspeed: lpc-ctrl: Fix boundary check for mmap (git-fixes).
- usb: phy: fsl-usb: add IRQ check (git-fixes).
- usb: gadget: udc: at91: add IRQ check (git-fixes).
- usb: dwc3: meson-g12a: add IRQ check (git-fixes).
- tty: serial: fsl_lpuart: fix the wrong mapbase value
  (git-fixes).
- staging: rtl8192u: Fix bitwise vs logical operator in
  TranslateRxSignalStuff819xUsb() (git-fixes).
- commit 7e7cd62
* Thu Sep  2 2021 tiwai@suse.de
- media: venus: venc: Fix potential null pointer dereference on
  pointer fmt (git-fixes).
- media: em28xx-input: fix refcount bug in em28xx_usb_disconnect
  (git-fixes).
- media: stkwebcam: fix memory leak in stk_camera_probe
  (git-fixes).
- media: go7007: remove redundant initialization (git-fixes).
- media: go7007: fix memory leak in go7007_usb_probe (git-fixes).
- media: dvb-usb: Fix error handling in dvb_usb_i2c_init
  (git-fixes).
- media: dvb-usb: fix uninit-value in vp702x_read_mac_addr
  (git-fixes).
- media: dvb-usb: fix uninit-value in dvb_usb_adapter_dvb_init
  (git-fixes).
- media: cxd2880-spi: Fix an error handling path (git-fixes).
- commit c67010c
* Thu Sep  2 2021 tiwai@suse.de
- drm/msi/mdp4: populate priv->kms in mdp4_kms_init (git-fixes).
- drm/msm/dsi: Fix some reference counted resource leaks
  (git-fixes).
- drm/msm/dpu: make dpu_hw_ctl_clear_all_blendstages clear
  necessary LMs (git-fixes).
- drm/amdgpu/acp: Make PM domain really work (git-fixes).
- drm/panfrost: Fix missing clk_disable_unprepare() on error in
  panfrost_clk_init() (git-fixes).
- media: TDA1997x: enable EDID support (git-fixes).
- fpga: zynqmp-fpga: Address warning about unused variable
  (git-fixes).
- fpga: xiilnx-spi: Address warning about unused variable
  (git-fixes).
- fpga: altera-freeze-bridge: Address warning about unused
  variable (git-fixes).
- commit 6aaa769
* Thu Sep  2 2021 tiwai@suse.de
- dmaengine: imx-sdma: remove duplicated sdma_load_context
  (git-fixes).
- Revert "dmaengine: imx-sdma: refine to load context only once"
  (git-fixes).
- ASoC: wcd9335: Disable irq on slave ports in the remove function
  (git-fixes).
- ASoC: wcd9335: Fix a memory leak in the error handling path
  of the probe function (git-fixes).
- ASoC: wcd9335: Fix a double irq free in the remove function
  (git-fixes).
- ASoC: Intel: Skylake: Leave data as is when invoking TLV IPCs
  (git-fixes).
- ASoC: ti: delete some dead code in omap_abe_probe() (git-fixes).
- ALSA: pcm: fix divide error in snd_pcm_lib_ioctl (git-fixes).
- ALSA: usb-audio: Fix regression on Sony WALKMAN NW-A45 DAC
  (git-fixes).
- commit bdcb5b3
* Thu Sep  2 2021 tbogendoerfer@suse.de
- xprtrdma: Pad optimization, revisited (bsc#1189760).
- commit 0acbfd0
* Thu Sep  2 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/btrfs-fix-NULL-pointer-dereference-when-deleting-dev.patch.
- commit fa03a78
* Thu Sep  2 2021 wqu@suse.com
- Refresh
  patches.suse/btrfs-fix-NULL-pointer-dereference-when-deleting-dev.patch.
- commit 2264bac
* Wed Sep  1 2021 tiwai@suse.de
- iwlwifi: skip first element in the WTAS ACPI table (git-fixes).
- Bluetooth: btusb: check conditions before enabling USB ALT 3
  for WBS (git-fixes).
- Bluetooth: mgmt: Fix wrong opcode in the response for add_adv
  cmd (git-fixes).
- Bluetooth: btusb: Fix a unspported condition to set available
  debug features (git-fixes).
- commit 084b82e
* Wed Sep  1 2021 tiwai@suse.de
- Bluetooth: sco: Fix lock_sock() blockage by memcpy_from_msg()
  (CVE-2021-3640 bsc#1188172).
- commit a21f4da
* Wed Sep  1 2021 tiwai@suse.de
- Move upstreamed BT fixes into sorted section
- commit 0de160e
* Wed Sep  1 2021 tiwai@suse.de
- brcmfmac: pcie: fix oops on failure to resume and reprobe
  (git-fixes).
- bcma: Fix memory leak for internally-handled cores (git-fixes).
- ath6kl: wmi: fix an error code in ath6kl_wmi_sync_point()
  (git-fixes).
- rsi: fix an error code in rsi_probe() (git-fixes).
- rsi: fix error code in rsi_load_9116_firmware() (git-fixes).
- mac80211: Fix insufficient headroom issue for AMSDU (git-fixes).
- Bluetooth: add timeout sanity check to hci_inquiry (git-fixes).
- Bluetooth: fix repeated calls to sco_sock_kill (git-fixes).
- Bluetooth: increase BTNAMSIZ to 21 chars to fix potential
  buffer overflow (git-fixes).
- Bluetooth: sco: prevent information leak in
  sco_conn_defer_accept() (git-fixes).
- leds: trigger: audio: Add an activate callback to ensure the
  initial brightness is set (git-fixes).
- i2c: mt65xx: fix IRQ check (git-fixes).
- i2c: s3c2410: fix IRQ check (git-fixes).
- i2c: iop3xx: fix deferred probing (git-fixes).
- i2c: highlander: add IRQ check (git-fixes).
- mmc: moxart: Fix issue with uninitialized dma_slave_config
  (git-fixes).
- mmc: dw_mmc: Fix issue with uninitialized dma_slave_config
  (git-fixes).
- PCI: PM: Enable PME if it can be signaled from D3cold
  (git-fixes).
- PCI: PM: Avoid forcing PCI_D0 for wakeup reasons inconsistently
  (git-fixes).
- commit 9a711f4
* Wed Sep  1 2021 tiwai@suse.de
- Add alt-commit for a BT fix patch (git-fixes)
- commit 3dbcbb3
* Wed Sep  1 2021 dwagner@suse.de
- nvme-multipath: revalidate paths during rescan (bsc#1187211)
- commit b61f128
* Wed Sep  1 2021 oneukum@suse.com
- usb: dwc3: Add support for DWC_usb32 IP (git-fixes).
- Refresh
  patches.suse/usb-dwc3-gadget-Enable-suspend-events.patch.
- commit 8846c72
* Wed Sep  1 2021 colyli@suse.de
- md: revert io stats accounting (git-fixes).
- device-dax: Fix default return code of range_parse()
  (git-fixes).
- commit b8e948b
* Wed Sep  1 2021 jslaby@suse.cz
- vt_kdsetmode: extend console locking (bsc#1190025
  CVE-2021-3753).
- commit 025c5d0
* Wed Sep  1 2021 colyli@suse.de
- nbd: Aovid double completion of a request (git-fixes).
- commit 7a1bece
* Wed Sep  1 2021 colyli@suse.de
- nbd: Fix NULL pointer in flush_workqueue (git-fixes).
- dm rq: fix double free of blk_mq_tag_set in dev remove after
  table load fails (git-fixes).
- dm integrity: fix missing goto in bitmap_flush_interval error
  handling (git-fixes).
- drivers/block/null_blk/main: Fix a double free in null_init
  (git-fixes).
- dm verity: fix DM_VERITY_OPTS_MAX value (git-fixes).
- nbd: don't update block size after device is started
  (git-fixes).
- commit 6df7d5d
* Wed Sep  1 2021 colyli@suse.de
- blacklist.conf: add following commit IDs,
- 27ba3e8ff3ab86449e63d38a8d623053591e65fa
- 0ebcdd702f49aeb0ad2e2d894f8c124a0acc6e23
- 854f32648b8a5e424d682953b1a9f3b7c3322701
- a4c8dd9c2d0987cf542a2a0c42684c9c6d78a04e
- 24f6b6036c9eec21191646930ad42808e6180510
- 5b0fab508992c2e120971da658ce80027acbc405
- commit eb9efeb
* Tue Aug 31 2021 msuchanek@suse.de
- rpm: Abolish scritplet templating (bsc#1189841).
  Outsource kernel-binary and KMP scriptlets to suse-module-tools.
  This allows fixing bugs in the scriptlets as well as defining initrd
  regeneration policy independent of the kernel packages.
- commit 940cfb4
* Tue Aug 31 2021 oneukum@suse.com
- usb: dwc2: Postponed gadget registration to the udc class driver
  (git-fixes).
- commit e55ae9a
* Tue Aug 31 2021 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Use kmod-zstd provide.
  This makes it possible to use kmod with ZSTD support on non-Tumbleweed.
- commit 357f09a
* Tue Aug 31 2021 tiwai@suse.de
- crypto: qat - use proper type for vf_mask (git-fixes).
- lib/mpi: use kcalloc in mpi_resize (git-fixes).
- power: supply: max17042: handle fails of reading status register
  (git-fixes).
- spi: sprd: Fix the wrong WDG_LOAD_VAL (git-fixes).
- spi: spi-pic32: Fix issue with uninitialized dma_slave_config
  (git-fixes).
- spi: spi-fsl-dspi: Fix issue with uninitialized dma_slave_config
  (git-fixes).
- regulator: vctrl: Avoid lockdep warning in enable/disable ops
  (git-fixes).
- regulator: vctrl: Use locked regulator_get_voltage in probe path
  (git-fixes).
- PCI/MSI: Skip masking MSI-X on Xen PV (git-fixes).
- commit d2a4523
* Tue Aug 31 2021 jlee@suse.com
- mm: swap: properly update readahead statistics in
  unuse_pte_range() (bsc#1187619).
- commit 6ceb471
* Tue Aug 31 2021 neilb@suse.de
- NFS: Correct size calculation for create reply length
  (bsc#1189870).
- commit 7843408
* Mon Aug 30 2021 tiwai@suse.de
- iommu/amd: Move Stoney Ridge check to detect_ivrs()
  (bsc#1189762).
- commit d8747d6
* Mon Aug 30 2021 iivanov@suse.de
- blacklist.conf: Don't revert SDHCI_QUIRK_CAP_CLOCK_BASE_BROKEN on BCM2711
  This revert fix which breaks the ACPI based RPi's.
  We support only DT based RPi's.
- commit c076733
* Mon Aug 30 2021 fweisbecker@suse.de
- sched/rt: Fix RT utilization tracking during policy change (git-fixes)
- commit 8fc8b7f
* Mon Aug 30 2021 fweisbecker@suse.de
- sched/fair: Correctly insert cfs_rq's to list on unthrottle (git-fixes)
- commit 1732b9b
* Mon Aug 30 2021 ludwig.nussel@suse.de
- rpm/kernel-binary.spec.in: avoid conflicting suse-release
  suse-release has arbitrary values in staging, we can't use it for
  dependencies. The filesystem one has to be enough (boo#1184804).
- commit 56f2cba
* Mon Aug 30 2021 jgross@suse.com
- kABI: Fix kABI after fixing vcpu-id indexed arrays (git-fixes).
- commit 53f17d6
* Sun Aug 29 2021 tiwai@suse.de
- drm/amd/display: use GFP_ATOMIC in amdgpu_dm_irq_schedule_work
  (git-fixes).
- drm/amd/display: Remove invalid assert for ODM + MPC case
  (git-fixes).
- drm/amdgpu: don't enable baco on boco platforms in runpm
  (git-fixes).
- drm/amd/display: workaround for hard hang on HPD on native DP
  (git-fixes).
- drm/amd/display: Fix Dynamic bpp issue with 8K30 with Navi 1X
  (git-fixes).
- drm/amdgpu: fix the doorbell missing when in CGPG issue for
  renoir (git-fixes).
- commit fa96b1f
* Sun Aug 29 2021 tiwai@suse.de
- usb: dwc3: gadget: Stop EP0 transfers during pullup disable
  (git-fixes).
- usb: dwc3: gadget: Fix dwc3_calc_trbs_left() (git-fixes).
- Revert "USB: serial: ch341: fix character loss at high transfer
  rates" (git-fixes).
- can: usb: esd_usb2: esd_usb2_rx_event(): fix the interchange
  of the CAN RX and TX error counters (git-fixes).
- dmaengine: of-dma: router_xlate to return -EPROBE_DEFER if
  controller is not yet available (git-fixes).
- dmaengine: usb-dmac: Fix PM reference leak in usb_dmac_probe()
  (git-fixes).
- usb: dwc3: gadget: Properly track pending and queued SG
  (git-fixes).
- ath9k: Clear key cache explicitly on disabling hardware
  (git-fixes).
- ath: Use safer key clearing with key cache entries (git-fixes).
- Bluetooth: hidp: use correct wait queue when removing ctrl_wait
  (git-fixes).
- commit 6ee1085
* Sun Aug 29 2021 tiwai@suse.de
- Revert "mmc: sdhci-iproc: Set SDHCI_QUIRK_CAP_CLOCK_BASE_BROKEN
  on BCM2711" (git-fixes).
- PCI: Increase D3 delay for AMD Renoir/Cezanne XHCI (git-fixes).
- mmc: dw_mmc: Fix hang on data CRC error (git-fixes).
- dmaengine: xilinx_dma: Fix read-after-free bug when terminating
  transfers (git-fixes).
- USB: core: Avoid WARNings for 0-length descriptor requests
  (git-fixes).
- media: drivers/media/usb: fix memory leak in zr364xx_probe
  (git-fixes).
- media: zr364xx: fix memory leaks in probe() (git-fixes).
- media: zr364xx: propagate errors from zr364xx_start_readpipe()
  (git-fixes).
- commit de359d6
* Sun Aug 29 2021 lma@suse.com
- cpuidle: Consolidate disabled state checks (bsc#1175543)
  patches.suse/cpuidle-Poll-for-a-minimum-of-30ns-and-poll-for-a-tick-if-lower-c-states-are-disabled.patch
  was refreshed as well by this patch for code adjustment.
- commit 486ca9f
* Sat Aug 28 2021 lma@suse.com
- cpuidle: cpuidle_state kABI fix (bsc#1175543)
  The patch bsc1175543-cpuidle-Drop-disabled-field-from-struct-cpuidle_stat.patch
  Dropped the 'disabled' field in struct cpuidle_state because no drivers
  use it, They use the state flag instead.
  Fix kABI to avoid offset changes.
- commit aa615e8
* Sat Aug 28 2021 lma@suse.com
- intel_idle: Disable ACPI _CST on Haswell (bsc#1175543, bsc#1177399, bsc#1180347, bsc#1180141)
- commit da07134
* Sat Aug 28 2021 lma@suse.com
- intel_idle: Fix max_cstate for processor models without C-state tables (bsc#1175543)
- commit 81641db
* Sat Aug 28 2021 lma@suse.com
- intel_idle: Ignore _CST if control cannot be taken from the platform (bsc#1175543)
- commit b93fbf1
* Sat Aug 28 2021 lma@suse.com
- cpuidle: Fix cpuidle_driver_state_disabled() (bsc#1175543)
- commit d669a61
* Sat Aug 28 2021 lma@suse.com
- cpuidle: Introduce cpuidle_driver_state_disabled() for driver quirks (bsc#1175543)
- commit 8d2d96f
* Sat Aug 28 2021 lma@suse.com
- intel_idle: Customize IceLake server support (bsc#1175543)
- commit 25d205d
* Sat Aug 28 2021 lma@suse.com
- intel_idle: Annotate init time data structures (bsc#1175543)
  The patches.suse/intel_idle-Customize-IceLake-server-support.patch was
  refreshed as well by this patch for code adjustment.
- commit 2ed77d7
* Sat Aug 28 2021 lma@suse.com
- Documentation: admin-guide: PM: Add intel_idle document (bsc#1175543)
- commit 65d3c96
* Sat Aug 28 2021 lma@suse.com
- intel_idle: Use ACPI _CST on server systems (bsc#1175543)
  Below 2 patches were refreshed as well by this patch for code
  adjustment:
  patches.suse/intel_idle-convert-to-new-x86-cpu-match-macros.patch
  patches.suse/intel_idle-Customize-IceLake-server-support.patch
- commit f10f8c4
* Sat Aug 28 2021 lma@suse.com
- intel_idle: Add module parameter to prevent ACPI _CST from being used (bsc#1175543)
- commit 79ec477
* Sat Aug 28 2021 lma@suse.com
- intel_idle: Allow ACPI _CST to be used for selected known processors (bsc#1175543)
- commit ecacb28
* Sat Aug 28 2021 lma@suse.com
- cpuidle: Allow idle states to be disabled by default (bsc#1175543)
- commit 48a3541
* Sat Aug 28 2021 lma@suse.com
- intel_idle: Use ACPI _CST for processor models without C-state tables (bsc#1175543)
- commit 9dbf3f1
* Sat Aug 28 2021 lma@suse.com
- intel_idle: Refactor intel_idle_cpuidle_driver_init() (bsc#1175543)
- commit 462302a
* Sat Aug 28 2021 lma@suse.com
- ACPI: processor: Export acpi_processor_evaluate_cst() (bsc#1175543)
- commit 70c6258
* Sat Aug 28 2021 lma@suse.com
- ACPI: processor: Make ACPI_PROCESSOR_CSTATE depend on ACPI_PROCESSOR (bsc#1175543)
- commit c99fda3
* Sat Aug 28 2021 lma@suse.com
- ACPI: processor: Clean up acpi_processor_evaluate_cst() (bsc#1175543)
- commit 9eb9d8c
* Sat Aug 28 2021 lma@suse.com
- ACPI: processor: Introduce acpi_processor_evaluate_cst() (bsc#1175543)
- commit c0d7249
* Sat Aug 28 2021 lma@suse.com
- ACPI: processor: Export function to claim _CST control (bsc#1175543)
- commit 66eadb0
* Sat Aug 28 2021 lma@suse.com
- cpuidle: Drop disabled field from struct cpuidle_state (bsc#1175543)
- commit c479621
* Fri Aug 27 2021 tiwai@suse.de
- net: qrtr: fix another OOB Read in qrtr_endpoint_post
  (CVE-2021-3743 bsc#1189883).
- net: qrtr: fix OOB Read in qrtr_endpoint_post (CVE-2021-3743
  bsc#1189883).
- commit 78ff8ba
* Fri Aug 27 2021 ludwig.nussel@suse.de
- rpm: fix kmp install path
- commit 22ec560
* Fri Aug 27 2021 jgross@suse.com
- x86/kvm: fix vcpu-id indexed array sizes (git-fixes).
- commit 3288077
* Fri Aug 27 2021 wqu@suse.com
- btrfs: fix NULL pointer dereference when deleting device by
  invalid id (bsc#1189832 CVE-2021-3739).
- commit 6bfce07
* Fri Aug 27 2021 wqu@suse.com
- btrfs: fix NULL pointer dereference when deleting device by
  invalid id (bsc#1189832 CVE-2021-3739).
- commit 0c26345
* Fri Aug 27 2021 jgross@suse.com
- xen/events: Fix race in set_evtchn_to_irq (git-fixes).
- commit cfb3b9b
* Thu Aug 26 2021 dwagner@suse.de
- nvme: code command_id with a genctr for use-after-free
  validation (bsc#1181972).
- nvme-tcp: don't check blk_mq_tag_to_rq when receiving pdu data
  (bsc#1181972).
- nvme-pci: limit maximum queue depth to 4095 (bsc#1181972).
- params: lift param_set_uint_minmax to common code (bsc#1181972).
- nvme: avoid possible double fetch in handling CQE (bsc#1181972).
- nvme-pci: fix NULL req in completion handler (bsc#1181972).
- nvme-pci: Use u32 for nvme_dev.q_depth and nvme_queue.q_depth
  (bsc#1181972).
- nvme-pci: use unsigned for io queue depth (bsc#1181972).
- commit 01de302
* Thu Aug 26 2021 ludwig.nussel@suse.de
- post.sh: detect /usr mountpoint too
- commit c7b3d74
* Thu Aug 26 2021 colyli@suse.de
- md/raid10: properly indicate failure when ending a failed
  write request (git-fixes).
- Refresh for the above change,
  patches.suse/md-display-timeout-error.patch.
- commit 2088aff
* Thu Aug 26 2021 tiwai@suse.de
- kernel, fs: Introduce and use set_restart_fn() and
  arch_set_restart_data() (bsc#1189153).
- commit 8bf2f14
* Wed Aug 25 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/blk-mq-sched-Fix-blk_mq_sched_alloc_tags-error-handl.patch.
- commit 6f36e1b
* Wed Aug 25 2021 jroedel@suse.de
- perf/x86/amd: Don't touch the AMD64_EVENTSEL_HOSTONLY bit inside the guest (bsc#1189225).
- commit 8f47b8e
* Wed Aug 25 2021 oneukum@suse.com
- kABI fix of usb_dcd_config_params (git-fixes).
- commit 8726268
* Tue Aug 24 2021 bp@suse.de
- x86/fpu: Limit xstate copy size in xstateregs_set()
  (bsc#1152489).
- commit 33182b7
* Tue Aug 24 2021 bp@suse.de
- blacklist.conf: 9625895011d1 x86/fpu: Fix copy_xstate_to_kernel() gap handling
- commit 50f6bfa
* Tue Aug 24 2021 iivanov@suse.de
- net: usb: lan78xx: don't modify phy_device state concurrently (bsc#1188270)
- commit 4e61642
* Tue Aug 24 2021 martin.wilck@suse.com
- scsi: ibmvfc: Do not wait for initial device scan (bsc#1127650).
- commit 41aa06c
* Tue Aug 24 2021 oneukum@suse.com
- usb: gadget: Export recommended BESL values (git-fixes).
- commit 96bbeda
* Mon Aug 23 2021 ddiss@suse.de
- ovl: prevent private clone if bind mount is not allowed
  (bsc#1189706, CVE-2021-3732).
- commit d40514b
* Mon Aug 23 2021 mbenes@suse.cz
- blacklist.conf: 6c34df6f350d ("tracing: Apply trace filters on all output channels")
  Requires at least commit 8cfcf15503f6 ("tracing: kprobes: Output kprobe
  event to printk buffer") too. Let's wait if there is an actual problem
  for someone.
- commit ef40598
* Mon Aug 23 2021 martin.wilck@suse.com
- kernel-binary.spec.in: make sure zstd is supported by kmod if used
- commit f36412b
* Mon Aug 23 2021 martin.wilck@suse.com
- kernel-binary.spec.in: add zstd to BuildRequires if used
- commit aa61dba
* Mon Aug 23 2021 mbenes@suse.cz
- tracing / histogram: Fix NULL pointer dereference on strcmp()
  on NULL event name (git-fixes).
- commit bf4be33
* Mon Aug 23 2021 jroedel@suse.de
- x86/sev: Use "SEV: " prefix for messages from sev.c (jsc#SLE-14337).
- x86/sev: Split up runtime #VC handler for correct state tracking (jsc#SLE-14337).
- x86/sev: Make sure IRQs are disabled while GHCB is active (jsc#SLE-14337).
- commit 33b49b0
* Mon Aug 23 2021 nmoreychaisemartin@suse.com
- net/mlx5e: Add missing capability check for uplink follow (bsc#1188412)
- commit db9b0eb
* Mon Aug 23 2021 nmoreychaisemartin@suse.com
- net/mlx5: Add ts_cqe_to_dest_cqn related bits (bsc#1188412)
- commit 0a67f96
* Mon Aug 23 2021 bp@suse.de
- x86/signal: Detect and prevent an alternate signal stack
  overflow (bsc#1152489).
- commit 72c8a0d
* Mon Aug 23 2021 tiwai@suse.de
- slimbus: ngd: reset dma setup during runtime pm (git-fixes).
- slimbus: messaging: check for valid transaction id (git-fixes).
- slimbus: messaging: start transaction ids from 1 instead of zero
  (git-fixes).
- mmc: sdhci-iproc: Set SDHCI_QUIRK_CAP_CLOCK_BASE_BROKEN on
  BCM2711 (git-fixes).
- mmc: sdhci-iproc: Cap min clock frequency on BCM2711
  (git-fixes).
- commit cc02968
* Mon Aug 23 2021 neilb@suse.de
- Fix breakage of swap over NFS (bsc#1188924).
- commit 9f3f2ef
* Mon Aug 23 2021 jeffm@suse.com
- Update Patch-mainline tags for patches that landed in 5.14-rc7.
- commit 118111d
* Sun Aug 22 2021 tiwai@suse.de
- ALSA: hda/realtek: Limit mic boost on HP ProBook 445 G8
  (git-fixes).
- commit 7a5c94a
* Sun Aug 22 2021 tiwai@suse.de
- ASoC: intel: atom: Fix breakage for PCM buffer address setup
  (git-fixes).
- commit 0bed191
* Sun Aug 22 2021 tiwai@suse.de
- Update config files: disable CONFIG_SND_SOC_INTEL_BYT_CHT_NOCODEC_MACH (bsc#1189696)
  This option is only for special purpose, and rather harmful for the
  usual operations.
- commit 1e546ed
* Fri Aug 20 2021 martin.wilck@suse.com
- rpm: support gz and zst compression methods
  Extend commit 18fcdff43a00 ("rpm: support compressed modules") for
  compression methods other than xz.
- commit 3b8c4d9
* Fri Aug 20 2021 tiwai@suse.de
- ALSA: hda/hdmi: Add quirk to force pin connectivity on NUC10
  (git-fixes).
- ALSA: hda/realtek: fix mute led of the HP Pavilion 15-eh1xxx
  series (git-fixes).
- ALSA: hda/realtek - Add ALC285 HP init procedure (git-fixes).
- ALSA: hda/realtek - Add type for ALC287 (git-fixes).
- ALSA: hda/realtek: Change device names for quirks to barebone
  names (git-fixes).
- ALSA: hda/hdmi: fix max DP-MST dev_num for Intel TGL+ platforms
  (git-fixes).
- ALSA: hda/hdmi: let new platforms assign the pcm slot
  dynamically (git-fixes).
- commit a13877e
* Thu Aug 19 2021 neilb@suse.de
- SUNRPC: 'Directory with parent 'rpc_clnt' already
  present!' (bsc#1168202 bsc#1188924).
- SUNRPC: fix use-after-free in rpc_free_client_work()
  (bsc#1168202 bsc#1188924).
- kabi fix for SUNRPC: defer slow parts of rpc_free_client()
  to a workqueue (bsc#1168202 bsc#1188924).
- SUNRPC: defer slow parts of rpc_free_client() to a workqueue
  (bsc#1168202 bsc#1188924).
- commit a690151
* Thu Aug 19 2021 tiwai@suse.de
- ALSA: hda: Fix hang during shutdown due to link reset
  (git-fixes).
- ALSA: hda: Release controller display power during
  shutdown/reboot (git-fixes).
- commit 62c768e
* Thu Aug 19 2021 tiwai@suse.de
- PCI/MSI: Use msi_mask_irq() in pci_msi_shutdown() (git-fixes).
- PCI/MSI: Correct misleading comments (git-fixes).
- PCI/MSI: Enforce MSI[X] entry updates to be visible (git-fixes).
- PCI/MSI: Enforce that MSI-X table entry is masked for update
  (git-fixes).
- PCI/MSI: Mask all unused MSI-X entries (git-fixes).
- i2c: dev: zero out array used for i2c reads from userspace
  (git-fixes).
- commit 4d62c8f
* Thu Aug 19 2021 tiwai@suse.de
- ALSA: hda/via: Apply runtime PM workaround for ASUS B23E
  (git-fixes).
- ALSA: hda/realtek: Enable 4-speaker output for Dell XPS 15
  9510 laptop (git-fixes).
- ALSA: hda - fix the 'Capture Switch' value change notifications
  (git-fixes).
- commit bb87ddf
* Thu Aug 19 2021 msuchanek@suse.de
- s390/boot: fix use of expolines in the DMA code (bsc#1188878
  ltc#193771).
- commit 46381a6
* Thu Aug 19 2021 mkubecek@suse.cz
- series.conf: cleanup
- move mainline backports to sorted section:
  - patches.suse/KVM-nSVM-avoid-picking-up-unsupported-bits-from-L2-i.patch
  - patches.suse/KVM-nSVM-always-intercept-VMLOAD-VMSAVE-when-nested.patch
- commit 30636ef
* Wed Aug 18 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/x86-fpu-make-init_fpstate-correct-with-optimized-xsave.patch.
- commit 20ad695
* Wed Aug 18 2021 msuchanek@suse.de
- Refresh patches.suse/x86-fpu-make-init_fpstate-correct-with-optimized-xsave.patch.
- commit 9deb044
* Wed Aug 18 2021 jack@suse.cz
- Fix kabi of prepare_to_wait_exclusive() (bsc#1189575).
- commit da7e3ca
* Wed Aug 18 2021 msuchanek@suse.de
- powerpc/smp: Use existing L2 cache_map cpumask to find L3
  cache siblings (jsc#SLE-13615 bsc#1180100 ltc#190257 git-fixes).
- powerpc/cacheinfo: Remove the redundant get_shared_cpu_map()
  (jsc#SLE-13615 bsc#1180100 ltc#190257 git-fixes).
- powerpc/cacheinfo: Lookup cache by dt node and thread-group id
  (jsc#SLE-13615 bsc#1180100 ltc#190257 git-fixes).
- powerpc/smp: Make some symbols static (jsc#SLE-13615 bsc#1180100
  ltc#190257 git-fixes).
- powerpc/cacheinfo: Improve diagnostics about malformed cache
  lists (jsc#SLE-13615 bsc#1180100 ltc#190257 git-fixes).
- powerpc/cacheinfo: Use name@unit instead of full DT path in
  debug messages (jsc#SLE-13615 bsc#1180100 ltc#190257 git-fixes).
- commit f7e0183
* Wed Aug 18 2021 jack@suse.cz
- ubifs: Set/Clear I_LINKABLE under i_lock for whiteout inode
  (bsc#1189587).
- commit ae93a20
* Wed Aug 18 2021 jack@suse.cz
- ubifs: journal: Fix error return code in ubifs_jnl_write_inode()
  (bsc#1189586).
- commit 50b39b2
* Wed Aug 18 2021 jack@suse.cz
- ubifs: Only check replay with inode type to judge if inode
  linked (bsc#1187455).
- commit 3cfd5e7
* Wed Aug 18 2021 jack@suse.cz
- ubifs: Fix error return code in alloc_wbufs() (bsc#1189585).
- blacklist.conf:
- commit d0fe9df
* Wed Aug 18 2021 jack@suse.cz
- ubifs: Fix memleak in ubifs_init_authentication (bsc#1189583).
- commit abd23d2
* Wed Aug 18 2021 jack@suse.cz
- ocfs2: issue zeroout to EOF blocks (bsc#1189582).
- commit 7960ad8
* Wed Aug 18 2021 jack@suse.cz
- ocfs2: fix snprintf() checking (bsc#1189581).
- commit ca894bd
* Wed Aug 18 2021 jack@suse.cz
- ocfs2: fix zero out valid data (bsc#1189579).
- commit 42e68bc
* Wed Aug 18 2021 jack@suse.cz
- writeback: fix obtain a reference to a freeing memcg css
  (bsc#1189577).
- commit b318f10
* Wed Aug 18 2021 jack@suse.cz
- ext4: fix potential htree corruption when growing large_dir
  directories (bsc#1189576).
- commit 13d68f1
* Wed Aug 18 2021 jack@suse.cz
- rq-qos: fix missed wake-ups in rq_qos_throttle try two
  (bsc#1189575).
- commit edbcd21
* Wed Aug 18 2021 jack@suse.cz
- fanotify: fix copy_event_to_user() fid error clean up
  (bsc#1189574).
- commit a8937b5
* Wed Aug 18 2021 jack@suse.cz
- bdi: Do not use freezable workqueue (bsc#1189573).
- commit 60e4174
* Wed Aug 18 2021 jack@suse.cz
- mm/thp: unmap_mapping_page() to fix THP truncate_cleanup_page()
  (bsc#1189569).
- commit 1b1dfcf
* Wed Aug 18 2021 jack@suse.cz
- ext4: cleanup in-core orphan list if ext4_truncate() failed
  to get a transaction handle (bsc#1189568).
- commit 0ace36d
* Wed Aug 18 2021 jack@suse.cz
- ext4: use ext4_grp_locked_error in mb_find_extent (bsc#1189567).
- commit 4329025
* Wed Aug 18 2021 jack@suse.cz
- ext4: fix avefreec in find_group_orlov (bsc#1189566).
- commit d7bfbbd
* Wed Aug 18 2021 jack@suse.cz
- ext4: remove check for zero nr_to_scan in ext4_es_scan()
  (bsc#1189565).
- commit 3ca5f18
* Wed Aug 18 2021 jack@suse.cz
- ext4: correct the cache_nr in tracepoint ext4_es_shrink_exit
  (bsc#1189564).
- commit cd60859
* Wed Aug 18 2021 jack@suse.cz
- ext4: return error code when ext4_fill_flex_info() fails
  (bsc#1189563).
- commit 200d004
* Wed Aug 18 2021 jack@suse.cz
- ext4: fix kernel infoleak via ext4_extent_header (bsc#1189562).
- commit fd9a225
* Wed Aug 18 2021 martin.wilck@suse.com
- blacklist.conf: add Kconfig patch for BLK_DEV_INITRD
  Add 481083ec0bfc ("initramfs: Remove redundant dependency of RD_ZSTD
  on BLK_DEV_INITRD") to blacklist. We don't have be1859bdc660 ("initramfs:
  remove redundant dependency on BLK_DEV_INITRD"), on which this one is based,
  either.
- commit 598e95d
* Wed Aug 18 2021 dwagner@suse.de
- scsi: lpfc: Move initialization of phba->poll_list earlier to
  avoid crash (git-fixes).
- commit 92c63a5
* Wed Aug 18 2021 jroedel@suse.de
- KVM: nSVM: avoid picking up unsupported bits from L2 in int_ctl
  (bsc#1189399, CVE-2021-3653).
- KVM: nSVM: always intercept VMLOAD/VMSAVE when nested
  (bsc#1189400, CVE-2021-3656).
- KVM: X86: MMU: Use the correct inherited permissions to get
  shadow page (CVE-2021-38198 bsc#1189262).
- commit 7902615
* Wed Aug 18 2021 oneukum@suse.com
- usb: dwc3: gadget: Handle ZLP for sg requests (git-fixes).
- commit 2a94579
* Wed Aug 18 2021 varad.gautam@suse.com
- Revert "xfrm: policy: Read seqcount outside of rcu-read side
  in xfrm_policy_lookup_bytype" (bsc#1185675).
  This revert was initially applied to SLE15-SP2-RT (70e4d04b75f). Since
  the reverted commit went into SLE15-SP2 (96f285dfa8b), the revert needs
  to move from SLE15-SP2-RT to SLE15-SP2.
- commit f32a28c
* Wed Aug 18 2021 msuchanek@suse.de
- Update
  patches.suse/ibmvnic-Allow-device-probe-if-the-device-is-not-read.patch
  (bsc#1167032 ltc#184087 bsc#1184114 ltc#192237).
- commit 8a87839
* Wed Aug 18 2021 tiwai@suse.de
- blacklist.conf: add an entry for the reverted iTCO_wdt
- commit 4c97ae2
* Tue Aug 17 2021 oneukum@suse.com
- usb: dwc3: gadget: Fix handling ZLP (git-fixes).
- commit 5e0eec9
* Tue Aug 17 2021 mbenes@suse.cz
- tracing: Reject string operand in the histogram expression
  (git-fixes).
- commit edab067
* Tue Aug 17 2021 mbenes@suse.cz
- tracing / histogram: Give calculation hist_fields a size
  (git-fixes).
- commit 49985ee
* Tue Aug 17 2021 mbenes@suse.cz
- blacklist.conf: 1e3bac71c505 ("tracing/histogram: Rename "cpu" to "common_cpu"")
  Better not to backport the commit as it changes the semantics of an
  existing field.
- commit 00d0183
* Tue Aug 17 2021 mbenes@suse.cz
- blacklist.conf: 6c881ca0b304 ("afs: Fix tracepoint string placement with built-in AFS")
  CONFIG_AFS_FS is not set on SLE15-SP2. It is on SLE15-SP3 but only as a
  module, not built-in. No need to backport the commit.
- commit 43483b1
* Tue Aug 17 2021 shung-hsi.yu@suse.com
- bpf: Fix leakage due to insufficient speculative store
  bypass mitigation (bsc#1188983, bsc#1188985, CVE-2021-34556,
  CVE-2021-35477).
- bpf: Introduce BPF nospec instruction for mitigating Spectre v4
  (bsc#1188983, bsc#1188985, CVE-2021-34556, CVE-2021-35477).
- commit f87c7ce
* Tue Aug 17 2021 jack@suse.cz
- blk-iolatency: error out if blk_get_queue() failed in
  iolatency_set_limit() (bsc#1189507).
- commit b15ef07
* Tue Aug 17 2021 jack@suse.cz
- blk-mq-sched: Fix blk_mq_sched_alloc_tags() error handling
  (bsc#1189506).
- commit 7fe32f7
* Tue Aug 17 2021 jack@suse.cz
- block: fix trace completion for chained bio (bsc#1189505).
- commit 47344da
* Tue Aug 17 2021 jack@suse.cz
- blk-wbt: make sure throttle is enabled properly (bsc#1189504).
- commit 7b07185
* Tue Aug 17 2021 jack@suse.cz
- blk-wbt: introduce a new disable state to prevent false positive
  by rwb_enabled() (bsc#1189503).
- commit 798c57a
* Tue Aug 17 2021 tiwai@suse.de
- misc: rtsx: do not setting OC_POWER_DOWN reg in
  rtsx_pci_init_ocp() (git-fixes).
- misc: atmel-ssc: lock with mutex instead of spinlock
  (git-fixes).
- commit 55d9570
* Tue Aug 17 2021 tiwai@suse.de
- gpio: eic-sprd: break loop when getting NULL device resource
  (git-fixes).
- Revert "gpio: eic-sprd: Use devm_platform_ioremap_resource()"
  (git-fixes).
- commit 990b695
* Tue Aug 17 2021 tiwai@suse.de
- Revert a BT patch that was reverted on stable trees (git-fixes)
  Delete patches.suse/Bluetooth-Shutdown-controller-after-workqueues-are-f.patch
- commit 127d54b
* Tue Aug 17 2021 tiwai@suse.de
- mtd: cfi_cmdset_0002: fix crash when erasing/writing AMD cards
  (git-fixes).
- commit 0a223c6
* Mon Aug 16 2021 bp@suse.de
- x86/fpu: Make init_fpstate correct with optimized XSAVE
  (bsc#1152489).
- commit 603fc19
* Mon Aug 16 2021 msuchanek@suse.de
- kernel-binary.spec: Require dwarves for kernel-binary-devel when BTF is
  enabled (jsc#SLE-17288).
  About the pahole version: v1.18 should be bare mnimum, v1.22 should be
  fully functional, for now we ship git snapshot with fixes on top of
  v1.21.
- commit 8ba3382
* Mon Aug 16 2021 bp@suse.de
- x86/fpu: Reset state for all signal restore failures
  (bsc#1152489).
- commit f42aa15
* Mon Aug 16 2021 dkirjanov@suse.com
- blacklist.conf: blacklist davicom legacy ethernet driver
- commit 78e9c10
* Mon Aug 16 2021 oneukum@suse.com
- usb: dwc3: gadget: Check MPS of the request length (git-fixes).
- commit 0d1e1fe
* Mon Aug 16 2021 tiwai@suse.de
- Drop watchdog iTCO_wdt patch that causes incompatible behavior (bsc#1189449)
  Also blacklisted
- commit e5dd4ab
* Mon Aug 16 2021 denis.kirjanov@suse.com
- Update config files.
- commit 565c68c
* Mon Aug 16 2021 msuchanek@suse.de
- s390/ap: Fix hanging ioctl caused by wrong msg counter
  (bsc#1188982 LTC#193817).
- commit 7e146ac
* Mon Aug 16 2021 msuchanek@suse.de
- s390/ap: Fix hanging ioctl caused by wrong msg counter
  (bsc#1188982 LTC#193817).
- commit 0297522
* Mon Aug 16 2021 tiwai@suse.de
- Bluetooth: switch to lock_sock in SCO (CVE-2021-3640
  bsc#1188172).
- Bluetooth: avoid circular locks in sco_sock_connect
  (CVE-2021-3640 bsc#1188172).
- commit f2d375d
* Mon Aug 16 2021 tiwai@suse.de
- Update patch reference for a BT fix (CVE-2021-3640 bsc#1188172)
- commit 98aa089
* Mon Aug 16 2021 msuchanek@suse.de
- powerpc/pseries: Fix update of LPAR security flavor after LPM
  (bsc#1188885 ltc#193722 git-fixes).
- commit fbccd6a
* Mon Aug 16 2021 tiwai@suse.de
- pinctrl: tigerlake: Fix GPIO mapping for newer version of
  software (git-fixes).
- commit 3483c38
* Mon Aug 16 2021 tiwai@suse.de
- usb: dwc3: gadget: Clear DEP flags after stop transfers in ep
  disable (git-fixes).
- commit 5733c23
* Mon Aug 16 2021 tiwai@suse.de
- usb: dwc3: gadget: Disable gadget IRQ during pullup disable
  (git-fixes).
- usb: dwc3: gadget: Prevent EP queuing while stopping transfers
  (git-fixes).
- commit 124c915
* Mon Aug 16 2021 tiwai@suse.de
- PCI/MSI: Do not set invalid bits in MSI mask (git-fixes).
- PCI/MSI: Enable and mask MSI-X early (git-fixes).
- ACPI: NFIT: Fix support for virtual SPA ranges (git-fixes).
- iio: adc: Fix incorrect exit of for-loop (git-fixes).
- iio: humidity: hdc100x: Add margin to the conversion time
  (git-fixes).
- iio: adc: ti-ads7950: Ensure CS is deasserted after reading
  channels (git-fixes).
- USB:ehci:fix Kunpeng920 ehci hardware problem (git-fixes).
- usb: dwc3: gadget: Restart DWC3 gadget when enabling pullup
  (git-fixes).
- usb: dwc3: Stop active transfers before halting the controller
  (git-fixes).
- commit 627b67a
* Fri Aug 13 2021 mkubecek@suse.cz
- config: refresh
- commit a299bb8
* Fri Aug 13 2021 tonyj@suse.de
- bpf: Fix integer overflow involving bucket_size (bsc#1189233,
  CVE#CVE-2021-38166).
- commit f4fe434
* Fri Aug 13 2021 msuchanek@suse.de
- Update patches.suse/s390-dasd-add-missing-discipline-function
  (bsc#1188130 ltc#193581).
- commit 0a58311
* Fri Aug 13 2021 lhenriques@suse.de
- ceph: take snap_empty_lock atomically with snaprealm refcount
  change (bsc#1189427).
- ceph: reduce contention in ceph_check_delayed_caps()
  (bsc#1187468).
- commit 93c7440
* Fri Aug 13 2021 dwagner@suse.de
- blacklist.conf: Add 'fix poly1305_core_setkey() declaration'
  Commit 8d195e7a8ada ("crypto: poly1305 - fix poly1305_core_setkey()
  declaration") is a cleanup which breaks kABI.
- commit 37e4183
* Fri Aug 13 2021 dwagner@suse.de
- scsi: blkcg: Fix application ID config options (bsc#1189385
  jsc#SLE-18970).
- Update config files.
- commit 1317caa
* Fri Aug 13 2021 dwagner@suse.de
- crypto: x86/curve25519 - fix cpu feature checking logic in
  mod_exit (git-fixes).
- wireguard: allowedips: free empty intermediate nodes when
  removing single node (git-fixes).
- wireguard: allowedips: allocate nodes in kmem_cache (git-fixes).
- wireguard: allowedips: remove nodes in O(1) (git-fixes).
- commit 6aa0bda
* Fri Aug 13 2021 tiwai@suse.de
- USB: serial: ftdi_sio: add device ID for Auto-M3 OP-COM v2
  (git-fixes).
- USB: serial: option: add Telit FD980 composition 0x1056
  (git-fixes).
- USB: serial: ch341: fix character loss at high transfer rates
  (git-fixes).
- usb: gadget: f_hid: idle uses the highest byte for duration
  (git-fixes).
- usb: gadget: f_hid: added GET_IDLE and SET_IDLE handlers
  (git-fixes).
- usb: gadget: f_hid: fixed NULL pointer dereference (git-fixes).
- commit f089244
* Fri Aug 13 2021 tiwai@suse.de
- drm/meson: fix colour distortion from HDR set during vendor
  u-boot (git-fixes).
- drm/i915: Only access SFC_DONE when media domain is not fused
  off (git-fixes).
- ASoC: SOF: Intel: hda-ipc: fix reply size checking (git-fixes).
- drm/amdgpu/display: fix DMUB firmware version info (git-fixes).
- drm/amdgpu/display: only enable aux backlight control for OLED
  panels (git-fixes).
- commit 8d4d06f
* Fri Aug 13 2021 tiwai@suse.de
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 650
  G8 Notebook PC (git-fixes).
- commit 71d7dbd
* Fri Aug 13 2021 tiwai@suse.de
- ALSA: pcm: Fix mmap breakage without explicit buffer setup
  (git-fixes).
- ASoC: amd: Fix reference to PCM buffer address (git-fixes).
- ASoC: uniphier: Fix reference to PCM buffer address (git-fixes).
- commit 8f53414
* Fri Aug 13 2021 tiwai@suse.de
- ALSA: hda: Add quirk for ASUS Flow x13 (git-fixes).
- ASoC: xilinx: Fix reference to PCM buffer address (git-fixes).
- ASoC: intel: atom: Fix reference to PCM buffer address
  (git-fixes).
- ASoC: tlv320aic31xx: Fix jack detection after suspend
  (git-fixes).
- spi: imx: mx51-ecspi: Fix CONFIGREG delay comment (git-fixes).
- virt_wifi: fix error on connect (git-fixes).
- commit 690710b
* Fri Aug 13 2021 tiwai@suse.de
- staging: rtl8712: get rid of flush_scheduled_work (git-fixes).
- staging: rtl8723bs: Fix a resource leak in sd_int_dpc
  (git-fixes).
- serial: 8250_mtk: fix uart corruption issue when rx power off
  (git-fixes).
- soc: ixp4xx/qmgr: fix invalid __iomem access (git-fixes).
- soc: ixp4xx: fix printing resources (git-fixes).
- spi: imx: mx51-ecspi: Fix low-speed CONFIGREG delay calculation
  (git-fixes).
- spi: meson-spicc: fix memory leak in meson_spicc_remove
  (git-fixes).
- pcmcia: i82092: fix a null pointer dereference bug (git-fixes).
- libata: fix ata_pio_sector for CONFIG_HIGHMEM (git-fixes).
- spi: imx: mx51-ecspi: Reinstate low-speed CONFIGREG delay
  (git-fixes).
- commit 24af025
* Fri Aug 13 2021 tiwai@suse.de
- ASoC: cs42l42: Fix LRCLK frame start edge (git-fixes).
- ASoC: cs42l42: Remove duplicate control for WNF filter frequency
  (git-fixes).
- ASoC: cs42l42: Fix inversion of ADC Notch Switch control
  (git-fixes).
- ASoC: cs42l42: Don't allow SND_SOC_DAIFMT_LEFT_J (git-fixes).
- ASoC: cs42l42: Correct definition of ADC Volume control
  (git-fixes).
- firmware_loader: use -ETIMEDOUT instead of -EAGAIN in
  fw_load_sysfs_fallback (git-fixes).
- Revert "ACPICA: Fix memory leak caused by _CID repair function"
  (git-fixes).
- dmaengine: imx-dma: configure the generic DMA type to make it
  work (git-fixes).
- ALSA: usb-audio: fix incorrect clock source setting (git-fixes).
- commit 20c4d69
* Thu Aug 12 2021 aabdallah@suse.de
- KVM: nVMX: Handle split-lock #AC exceptions that happen in L2
  (bsc#1187959).
- KVM: VMX: Extend VMXs #AC interceptor to handle split lock
  [#]AC in guest (bsc#1187959).
- KVM: x86: Emulate split-lock access as a write in emulator
  (bsc#1187959).
- commit 93dd7c1
* Thu Aug 12 2021 aabdallah@suse.de
- x86/split_lock: Provide handle_guest_split_lock() (bsc#1187959).
- Refresh
  patches.suse/x86-resctrl-query-llc-monitoring-properties-once-during-boot.patch.
  patches.suse/x86-split_lock-don-t-write-msr_test_ctrl-on-cpus-that-aren-t-whitelisted.patch.
- commit b9759ab
* Thu Aug 12 2021 dwagner@suse.de
- scsi: qla2xxx: Remove redundant initialization of variable
  num_cnt (bsc#1189392).
- scsi: qla2xxx: Fix use after free in debug code (bsc#1189392).
- scsi: qla2xxx: Fix spelling mistakes "allloc" -> "alloc"
  (bsc#1189392).
- scsi: qla2xxx: Update version to 10.02.00.107-k (bsc#1189392).
- scsi: qla2xxx: edif: Increment command and completion counts
  (bsc#1189392).
- scsi: qla2xxx: edif: Add encryption to I/O path (bsc#1189392).
- scsi: qla2xxx: edif: Add doorbell notification for app
  (bsc#1189392).
- scsi: qla2xxx: edif: Add detection of secure device
  (bsc#1189392).
- scsi: qla2xxx: edif: Add authentication pass + fail bsgs
  (bsc#1189392).
- scsi: qla2xxx: edif: Add key update (bsc#1189392).
- scsi: qla2xxx: edif: Add extraction of auth_els from the wire
  (bsc#1189392).
- scsi: qla2xxx: edif: Add send, receive, and accept for auth_els
  (bsc#1189392).
- scsi: qla2xxx: edif: Add getfcinfo and statistic bsgs
  (bsc#1189392).
- scsi: qla2xxx: edif: Add start + stop bsgs (bsc#1189392).
- scsi: qla2xxx: Remove unused variable 'status' (bsc#1189392).
- scsi: qla2xxx: Use the proper SCSI midlayer interfaces for PI
  (bsc#1189392).
- scsi: core: Add scsi_prot_ref_tag() helper (bsc#1189392).
- scsi: qla2xxx: Remove redundant continue statement in a for-loop
  (bsc#1189392).
- scsi: qla2xxx: Add heartbeat check (bsc#1189392).
- scsi: qla2xxx: Use list_move_tail() instead of
  list_del()/list_add_tail() (bsc#1189392).
- scsi: qla2xxx: Remove duplicate declarations (bsc#1189392).
- scsi: qla2xxx: Log PCI address in
  qla_nvme_unregister_remote_port() (bsc#1189392).
- scsi: qla2xxx: Remove redundant assignment to rval
  (bsc#1189392).
- scsi: target: qla2xxx: Wait for stop_phase1 at WWN removal
  (bsc#1189392).
- scsi: qla2xxx: Fix error return code in
  qla82xx_write_flash_dword() (bsc#1189392).
- commit 4f97d8a
* Thu Aug 12 2021 tiwai@suse.de
- Update patch reference for a netfilter fix (CVE-2021-38209 bsc#1189393)
- commit 26cdeeb
* Thu Aug 12 2021 dwagner@suse.de
- scsi: lpfc: Fix possible ABBA deadlock in nvmet_xri_aborted()
  (bsc#1189385).
- scsi: lpfc: Remove redundant assignment to pointer pcmd
  (bsc#1189385).
- scsi: lpfc: Copyright updates for 14.0.0.0 patches
  (bsc#1189385).
- scsi: lpfc: Update lpfc version to 14.0.0.0 (bsc#1189385).
- scsi: lpfc: Add 256 Gb link speed support (bsc#1189385).
- scsi: lpfc: Revise Topology and RAS support checks for new
  adapters (bsc#1189385).
- scsi: lpfc: Fix cq_id truncation in rq create (bsc#1189385).
- scsi: lpfc: Add PCI ID support for LPe37000/LPe38000 series
  adapters (bsc#1189385).
- scsi: lpfc: Copyright updates for 12.8.0.11 patches
  (bsc#1189385).
- scsi: lpfc: Update lpfc version to 12.8.0.11 (bsc#1189385).
- scsi: lpfc: Skip issuing ADISC when node is in NPR state
  (bsc#1189385).
- scsi: lpfc: Skip reg_vpi when link is down for SLI3 in ADISC
  cmpl path (bsc#1189385).
- scsi: lpfc: Call discovery state machine when handling
  PLOGI/ADISC completions (bsc#1189385).
- scsi: lpfc: Delay unregistering from transport until GIDFT or
  ADISC completes (bsc#1189385).
- scsi: lpfc: Enable adisc discovery after RSCN by default
  (bsc#1189385).
- scsi: lpfc: Use PBDE feature enabled bit to determine PBDE
  support (bsc#1189385).
- scsi: lpfc: Clear outstanding active mailbox during PCI function
  reset (bsc#1189385).
- scsi: lpfc: Fix KASAN slab-out-of-bounds in lpfc_unreg_rpi()
  routine (bsc#1189385).
- scsi: lpfc: Remove REG_LOGIN check requirement to issue an
  ELS RDF (bsc#1189385).
- scsi: lpfc: Fix memory leaks in error paths while issuing ELS
  RDF/SCR request (bsc#1189385).
- scsi: lpfc: Fix NULL ptr dereference with NPIV ports for RDF
  handling (bsc#1189385).
- scsi: lpfc: Keep NDLP reference until after freeing the IOCB
  after ELS handling (bsc#1189385).
- scsi: lpfc: Fix target reset handler from falsely returning
  FAILURE (bsc#1189385).
- scsi: lpfc: Discovery state machine fixes for LOGO handling
  (bsc#1189385).
- scsi: lpfc: Fix function description comments for vmid routines
  (bsc#1189385).
- scsi: lpfc: Improve firmware download logging (bsc#1189385).
- scsi: lpfc: Remove use of kmalloc() in trace event logging
  (bsc#1189385).
- scsi: lpfc: Fix NVMe support reporting in log message
  (bsc#1189385).
- scsi: lpfc: Fix build error in lpfc_scsi.c (bsc#1189385).
- scsi: lpfc: Use list_move_tail() instead of
  list_del()/list_add_tail() (bsc#1189385).
- scsi: lpfc: vmid: Introduce VMID in I/O path (bsc#1189385 jsc#SLE-18970).
- scsi: lpfc: vmid: Add QFPA and VMID timeout check in worker
  thread (bsc#1189385 jsc#SLE-18970).
- scsi: lpfc: vmid: Timeout implementation for VMID (bsc#1189385 jsc#SLE-18970).
- scsi: lpfc: vmid: Append the VMID to the wqe before sending
  (bsc#1189385 jsc#SLE-18970).
- scsi: lpfc: vmid: Implement CT commands for appid (bsc#1189385 jsc#SLE-18970).
- scsi: lpfc: vmid: Functions to manage VMIDs (bsc#1189385 jsc#SLE-18970).
- scsi: lpfc: vmid: Implement ELS commands for appid
  (bsc#1189385 jsc#SLE-18970).
- scsi: lpfc: vmid: Add support for VMID in mailbox command
  (bsc#1189385 jsc#SLE-18970).
- scsi: lpfc: vmid: VMID parameter initialization (bsc#1189385 jsc#SLE-18970).
- scsi: lpfc: vmid: Add datastructure for supporting VMID in lpfc
  (bsc#1189385 jsc#SLE-18970).
- scsi: blkcg: Add app identifier support for blkcg (bsc#1189385 jsc#SLE-18970).
- Update config files
  Add kABI fixup patch
- patches.kabi/blk-cgroup-kABI-fixes-for-new-fc_app_id-definition.patch
- scsi: cgroup: Add cgroup_get_from_id() (bsc#1189385 jsc#SLE-18970).
- scsi: lpfc: Remove redundant assignment to pointer temp_hdr
  (bsc#1189385).
- commit e47f569
* Thu Aug 12 2021 dwagner@suse.de
- nvmet: use NVMET_MAX_NAMESPACES to set nn value (bsc#1189384).
- commit da8a2b6
* Wed Aug 11 2021 msuchanek@suse.de
- README: Modernize build instructions.
- commit 8cc5c28
* Wed Aug 11 2021 ddiss@suse.de
- ovl: allow upperdir inside lowerdir (bsc#1189323).
- ovl: fix missing revert_creds() on error path (bsc#1189323).
- ovl: skip getxattr of security labels (bsc#1189323).
- ovl: perform vfs_getxattr() with mounter creds (bsc#1189323).
- ovl: expand warning in ovl_d_real() (bsc#1189323).
- commit d2a0c13
* Wed Aug 11 2021 jslaby@suse.cz
- rpm/kernel-obs-build.spec.in: make builds reproducible (bsc#1189305)
- commit 7f9ade7
* Wed Aug 11 2021 tiwai@suse.de
- platform/x86: pcengines-apuv2: Add missing terminating entries
  to gpio-lookup tables (git-fixes).
- commit e6925d8
* Tue Aug 10 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  - patches.suse/NFSv4-Initialise-connection-to-the-server-in-nfs4_al.patch
  - patches.suse/NFSv4-pNFS-Don-t-call-_nfs4_pnfs_v3_ds_connect-multi.patch
  - patches.suse/SUNRPC-Fix-the-batch-tasks-count-wraparound.patch
  - patches.suse/SUNRPC-Should-wake-up-the-privileged-task-firstly.patch
  - patches.suse/nfs-fix-acl-memory-leak-of-posix_acl_create.patch
- commit bd541fa
* Tue Aug 10 2021 tiwai@suse.de
- net: ll_temac: Fix TX BD buffer overwrite (CVE-2021-38207
  bsc#1189298).
- commit 64dedf9
* Tue Aug 10 2021 tiwai@suse.de
- mac80211: Fix NULL ptr deref for injected rate info
  (CVE-2021-38206 bsc#1189296).
- commit a4dbb10
* Tue Aug 10 2021 martin.wilck@suse.com
- scsi: zfcp: Report port fc_security as unknown early during
  remote cable pull (git-fixes).
- commit 071c9e5
* Tue Aug 10 2021 tiwai@suse.de
- net: xilinx_emaclite: Do not print real IOMEM pointer
  (CVE-2021-38205 bsc#1189292).
- commit 1e538f8
* Tue Aug 10 2021 tiwai@suse.de
- Update patch reference for a USB max3421 HCD fix (CVE-2021-38204 bsc#1189291)
- commit 68d7672
* Tue Aug 10 2021 martin.wilck@suse.com
- scsi: scsi_transport_srp: Don't block target in SRP_PORT_LOST
  state (bsc#1184180).
- commit 435d2bf
* Tue Aug 10 2021 tiwai@suse.de
- drm/i915/gen9_bc: Add W/A for missing STRAP config on TGP PCH +
  CML combos (bsc#1188700).
- drm/i915/gen9_bc: Introduce HPD pin mappings for TGP PCH +
  CML combos (bsc#1188700).
- drm/i915/gen9_bc: Introduce TGP PCH DDC pin mappings
  (bsc#1188700).
- drm/i915/gen9_bc: Recognize TGP PCH + CML combos (bsc#1188700).
- drm/i915/rkl: new rkl ddc map for different PCH (bsc#1188700).
- drm/i915/dg1: provide port/phy mapping for vbt (bsc#1188700).
- drm/i915/dg1: gmbus pin mapping (bsc#1188700).
- drm/i915: Introduce HPD_PORT_TC<n> (bsc#1188700).
- drm/i915: Move hpd_pin setup to encoder init (bsc#1188700).
- drm/i915: Configure GEN11_{TBT,TC}_HOTPLUG_CTL for ports TC5/6
  (bsc#1188700).
- drm/i915: Nuke the redundant TC/TBT HPD bit defines
  (bsc#1188700).
- drm/i915: Add VBT AUX CH H and I (bsc#1188700).
- drm/i915: Add VBT DVO ports H and I (bsc#1188700).
- drm/i915: Add more AUX CHs to the enum (bsc#1188700).
- commit 3f49445
* Tue Aug 10 2021 oneukum@suse.com
- usb: dwc3: gadget: Don't setup more than requested (git-fixes).
- commit d278880
* Tue Aug 10 2021 oneukum@suse.com
- usb: dwc3: meson-g12a: check return of dwc3_meson_g12a_usb_init
  (git-fixes).
- commit bc358f9
* Tue Aug 10 2021 ghe@suse.com
- ocfs2: initialize ip_next_orphan (bsc#1186731).
- commit fd80e8c
* Tue Aug 10 2021 neilb@suse.de
- NFSv4/pNFS: Don't call _nfs4_pnfs_v3_ds_connect multiple times
  (git-fixes).
- SUNRPC: Should wake up the privileged task firstly (git-fixes).
- SUNRPC: Fix the batch tasks count wraparound (git-fixes).
- nfs: fix acl memory leak of posix_acl_create() (git-fixes).
- commit 1bdda2d
* Tue Aug 10 2021 neilb@suse.de
- NFSv4: Initialise connection to the server in
  nfs4_alloc_client() (bsc#1040364).
- Delete
  patches.suse/0001-NFSv4-don-t-let-hanging-mounts-block-other-mounts.patch.
  Upstream now has a fix for this bug, so use their version instead of ours.
- commit 350271e
* Mon Aug  9 2021 oneukum@suse.com
- usb: dwc3: gadget: Give back staled requests (git-fixes).
- commit c4cb23f
* Mon Aug  9 2021 oneukum@suse.com
- usb: dwc3: support continuous runtime PM with dual role
  (git-fixes).
- commit f340e0b
* Mon Aug  9 2021 jroedel@suse.de
- iommu/vt-d: Global devTLB flush when present context entry
  changed (bsc#1189220).
- iommu/dma: Fix compile warning in 32-bit builds (bsc#1189229).
- iommu/dma: Fix IOVA reserve dma ranges (bsc#1189214).
- iommu/amd: Fix extended features logging (bsc#1189213).
- iommu/vt-d: Define counter explicitly as unsigned int
  (bsc#1189216).
- iommu/arm-smmu-v3: Decrease the queue size of evtq and priq
  (bsc#1189210).
- crypto: ccp - Annotate SEV Firmware file names (bsc#1189212).
- iommu/vt-d: Fix sysfs leak in alloc_iommu() (bsc#1189218).
- iommu/vt-d: Check for allocation failure in aux_detach_device()
  (bsc#1189215).
- iommu/vt-d: Force to flush iotlb before creating superpage
  (bsc#1189219).
- iommu/vt-d: Invalidate PASID cache when root/context entry
  changed (bsc#1189221).
- iommu/vt-d: Don't set then clear private data in
  prq_event_thread() (bsc#1189217).
- iommu/vt-d: Reject unsupported page request modes (bsc#1189222).
- iommu/arm-smmu-v3: add bit field SFM into GERROR_ERR_MASK
  (bsc#1189209).
- commit f116a8f
* Mon Aug  9 2021 jroedel@suse.de
- blacklist.conf: Add two IOMMU fixes
  b9abb19fa5fd iommu: Check dev->iommu in iommu_dev_xxx functions
  474dd1c65064 iommu/vt-d: Fix clearing real DMA device's scalable-mode context entries
- commit 2db8dfc
* Mon Aug  9 2021 msuchanek@suse.de
- powerpc/papr_scm: Make 'perf_stats' invisible if perf-stats
  unavailable (bsc#1175052 jsc#SLE-13823 bsc#1174969 jsc#SLE-12769
  git-fixes).
- commit c109f3e
* Mon Aug  9 2021 ludwig.nussel@suse.de
- Fix filesystem requirement and suse-release requires
  Reduce filesystem conflict to anything less than 16 to allow pulling the
  change into the next major stable version.
  Don't require suse-release as that's not technically required. Conflict
  with a too old one instead.
- commit 913f755
* Mon Aug  9 2021 oneukum@suse.com
- iwlwifi: rs-fw: don't support stbc for HE 160 (git-fixes).
- commit 981ddc7
* Mon Aug  9 2021 oneukum@suse.com
- blacklist.conf: obsoleted by 8d396bb0a5b62b326f6be7594d8bd46b088296bd
- commit d9ae913
* Mon Aug  9 2021 oneukum@suse.com
- USB: usbtmc: Fix RCU stall warning (git-fixes).
- commit 8c8f7df
* Mon Aug  9 2021 msuchanek@suse.de
- powerpc: Fix is_kvm_guest() / kvm_para_available() (bsc#1181148
  ltc#190702 git-fixes).
- commit 8c2e999
* Mon Aug  9 2021 oneukum@suse.com
- fpga: dfl: fme: Fix cpu hotplug issue in performance reporting
  (git-fixes).
- commit 1278281
* Mon Aug  9 2021 msuchanek@suse.de
- powerpc/pseries: Fix regression while building external modules
  (bsc#1160010 ltc#183046 git-fixes).
  This changes a GPL symbol to general symbol which is kABI change but not
  kABI break.
- commit 5db0ce9
* Mon Aug  9 2021 msuchanek@suse.de
- powerpc/papr_scm: Reduce error severity if nvdimm stats
  inaccessible (bsc#1189197 ltc#193906).
- commit 9021659
* Mon Aug  9 2021 tiwai@suse.de
- fpga: dfl: fme: Fix cpu hotplug issue in performance reporting
  (git-fixes).
- staging: rtl8723bs: Fix a resource leak in sd_int_dpc
  (git-fixes).
- serial: 8250_pci: Avoid irq sharing for MSI(-X) interrupts
  (git-fixes).
- serial: 8250_pci: Enumerate Elkhart Lake UARTs via dedicated
  driver (git-fixes).
- soc: ixp4xx/qmgr: fix invalid __iomem access (git-fixes).
- soc: ixp4xx: fix printing resources (git-fixes).
- dmaengine: imx-dma: configure the generic DMA type to make it
  work (git-fixes).
- dmaengine: idxd: fix setup sequence for MSIXPERM table
  (git-fixes).
- drm/i915: Correct SFC_DONE register offset (git-fixes).
- ASoC: ti: j721e-evm: Check for not initialized parent_clk_id
  (git-fixes).
- ASoC: ti: j721e-evm: Fix unbalanced domain activity tracking
  during startup (git-fixes).
- ASoC: rt5682: Fix the issue of garbled recording after
  powerd_dbus_suspend (git-fixes).
- drm/amd/display: Fix max vstartup calculation for modes with
  borders (git-fixes).
- drm/amd/display: Fix comparison error in dcn21 DML (git-fixes).
- commit b4ad8ce
* Mon Aug  9 2021 tiwai@suse.de
- firmware_loader: fix use-after-free in firmware_fallback_sysfs
  (git-fixes).
- serial: tegra: Only print FIFO error message when an error
  occurs (git-fixes).
- serial: 8250: Mask out floating 16/32-bit bus bits (git-fixes).
- spi: mediatek: Fix fifo transfer (git-fixes).
- ASoC: tlv320aic31xx: fix reversed bclk/wclk master bits
  (git-fixes).
- spi: stm32h7: fix full duplex irq handler handling (git-fixes).
- regulator: rt5033: Fix n_voltages settings for BUCK and LDO
  (git-fixes).
- commit 8f575e8
* Sun Aug  8 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  - patches.suse/ALSA-hda-realtek-Fix-headset-mic-for-Acer-SWIFT-SF31.patch
  - patches.suse/ALSA-hda-realtek-add-mic-quirk-for-Acer-SF314-42.patch
  - patches.suse/ALSA-seq-Fix-racy-deletion-of-subscriber.patch
  - patches.suse/ALSA-usb-audio-Add-registration-quirk-for-JBL-Quantu-4b0556b96e1f.patch
  - patches.suse/ALSA-usb-audio-Fix-superfluous-autosuspend-recovery.patch
- commit 486a747
* Sat Aug  7 2021 tiwai@suse.de
- Move upstreamed patch into sorted section
- commit a779693
* Sat Aug  7 2021 tiwai@suse.de
- ALSA: usb-audio: Avoid unnecessary or invalid connector
  selection at resume (git-fixes).
- commit a52bb92
* Sat Aug  7 2021 tiwai@suse.de
- ALSA: seq: Fix racy deletion of subscriber (git-fixes).
- ALSA: hda/realtek: add mic quirk for Acer SF314-42 (git-fixes).
- ALSA: usb-audio: Add registration quirk for JBL Quantum 600
  (git-fixes).
- ALSA: hda/realtek: Fix headset mic for Acer SWIFT SF314-56
  (ALC256) (git-fixes).
- ALSA: usb-audio: Fix superfluous autosuspend recovery
  (git-fixes).
- commit 57d9208
* Fri Aug  6 2021 jeyu@suse.de
- Update kabi files.
- Update from August 2021 maintenance update submission (commit 055c4fd5f13c)
- commit 0b9f7b1
* Fri Aug  6 2021 denis.kirjanov@suse.com
- net: dsa: mv88e6xxx: also read STU state in
  mv88e6250_g1_vtu_getnext (git-fixes).
- commit 4d3a9e0
* Fri Aug  6 2021 tiwai@suse.de
- Bluetooth: defer cleanup of resources in hci_unregister_dev()
  (git-fixes).
- commit 38ad73f
* Thu Aug  5 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  - patches.suse/NFSv4.1-Don-t-rebind-to-the-same-source-port-when-re.patch
  - patches.suse/SUNRPC-prevent-port-reuse-on-transports-which-don-t-.patch
- commit 5e54e89
* Thu Aug  5 2021 jziviani@suse.de
- blacklist.conf: kABI changes due to kvm_mmu_rule struct.
- commit f3e0e69
* Thu Aug  5 2021 tiwai@suse.de
- Refresh patches.suse/Input-ili210x-add-missing-negation-for-touch-indicat.patch
  Fix missing parentheses in the input backport patch.
- commit 0913716
* Thu Aug  5 2021 jslaby@suse.cz
- rpm/kernel-source.rpmlintrc: ignore new include/config files
  In 5.13, since 0e0345b77ac4, config files have no longer .h suffix.
  Adapt the zero-length check.
  Based on Martin Liska's change.
- commit b6f021b
* Thu Aug  5 2021 tiwai@suse.de
- Revert "gpio: mpc8xxx: change the gpio interrupt
  flags." (git-fixes).
- drm/amd/display: ensure dentist display clock update finished
  in DCN20 (git-fixes).
- commit 3d2a7da
* Thu Aug  5 2021 tiwai@suse.de
- gpio: tqmx86: really make IRQ optional (git-fixes).
- media: videobuf2-core: dequeue if start_streaming fails
  (git-fixes).
- media: rtl28xxu: fix zero-length control request (git-fixes).
- clk: fix leak on devm_clk_bulk_get_all() unwind (git-fixes).
- clk: stm32f4: fix post divisor setup for I2S/SAI PLLs
  (git-fixes).
- cfg80211: Fix possible memory leak in function
  cfg80211_bss_update (git-fixes).
- commit 7dd3f8c
* Thu Aug  5 2021 neilb@suse.de
- SUNRPC: prevent port reuse on transports which don't request it
  (bnc#1186264 bnc#1189021).
- commit a89b568
* Thu Aug  5 2021 neilb@suse.de
- kabi fix for NFSv4.1: Don't rebind to the same source port when
  reconnecting to the server
  (bnc#1186264 bnc#1189021)
- commit 844eb4c
* Thu Aug  5 2021 neilb@suse.de
- NFSv4.1: Don't rebind to the same source port when
  (bnc#1186264 bnc#1189021)
- commit 4b89a40
* Wed Aug  4 2021 tbogendoerfer@suse.de
- ionic: fix up dim accounting for tx and rx (jsc#SLE-16649).
- ionic: remove intr coalesce update from napi (jsc#SLE-16649).
- ionic: make all rx_mode work threadsafe (jsc#SLE-16649).
- RDMA/bnxt_re: Fix stats counters (bsc#1188231).
- bnxt_en: Validate vlan protocol ID on RX packets
  (jsc#SLE-15075).
- ionic: add handling of larger descriptors (jsc#SLE-16649).
- ionic: add new queue features to interface (jsc#SLE-16649).
- ionic: fix sizeof usage (jsc#SLE-16649).
- ionic: protect adminq from early destroy (jsc#SLE-16649).
- ionic: stop watchdog when in broken state (jsc#SLE-16649).
- ionic: block actions during fw reset (jsc#SLE-16649).
- ionic: fix unchecked reference (jsc#SLE-16649).
- ionic: simplify the intr_index use in txq_init (jsc#SLE-16649).
- ionic: code cleanup details (jsc#SLE-16649).
- ionic: aggregate Tx byte counting calls (jsc#SLE-16649).
- ionic: simplify tx clean (jsc#SLE-16649).
- ionic: generic tx skb mapping (jsc#SLE-16649).
- ionic: simplify TSO descriptor mapping (jsc#SLE-16649).
- ionic: simplify use of completion types (jsc#SLE-16649).
- ionic: rebuild debugfs on qcq swap (jsc#SLE-16649).
- ionic: simplify rx skb alloc (jsc#SLE-16649).
- ionic: optimize fastpath struct usage (jsc#SLE-16649).
- ionic: implement Rx page reuse (jsc#SLE-16649).
- ionic: move rx_page_alloc and free (jsc#SLE-16649).
- ionic: change mtu after queues are stopped (jsc#SLE-16649).
- ionic: remove some unnecessary oom messages (jsc#SLE-16649).
- ionic: useful names for booleans (jsc#SLE-16649).
- ionic: check for link after netdev registration (jsc#SLE-16649).
- ionic: start queues before announcing link up (jsc#SLE-16649).
- commit 55ca0a7
* Wed Aug  4 2021 fdmanana@suse.com
- btrfs: rework chunk allocation to avoid exhaustion of the
  system chunk array (bsc#1189077).
- btrfs: fix deadlock with concurrent chunk allocations involving
  system chunks (bsc#1189077).
- btrfs: move the chunk_mutex in btrfs_read_chunk_tree
  (bsc#1189077).
- btrfs: Rename __btrfs_alloc_chunk to btrfs_alloc_chunk
  (bsc#1189077).
- btrfs: parameterize dev_extent_min for chunk allocation
  (bsc#1189077).
- btrfs: factor out create_chunk() (bsc#1189077).
- btrfs: factor out decide_stripe_size() (bsc#1189077).
- btrfs: factor out gather_device_info() (bsc#1189077).
- btrfs: factor out init_alloc_chunk_ctl (bsc#1189077).
- btrfs: introduce alloc_chunk_ctl (bsc#1189077).
- btrfs: refactor find_free_dev_extent_start() (bsc#1189077).
- btrfs: introduce chunk allocation policy (bsc#1189077).
- btrfs: handle invalid profile in chunk allocation (bsc#1189077).
- commit 707ed65
* Wed Aug  4 2021 pmladek@suse.com
- tracing: Fix bug in rb_per_cpu_empty() that might cause deadloop
  (CVE-2021-3679 bsc#1189057).
- commit 49b5ebf
* Wed Aug  4 2021 denis.kirjanov@suse.com
- net/mlx5: Properly convey driver version to firmware
  (git-fixes).
- commit 44d8f42
* Wed Aug  4 2021 denis.kirjanov@suse.com
- net: stmmac: free tx skb buffer in stmmac_resume() (git-fixes).
- commit ac61742
* Wed Aug  4 2021 denis.kirjanov@suse.com
- can: ti_hecc: Fix memleak in ti_hecc_probe (git-fixes).
- commit 75096f3
* Wed Aug  4 2021 denis.kirjanov@suse.com
- net: dsa: mv88e6xxx: Avoid VTU corruption on 6097 (git-fixes).
- commit 524d35f
* Tue Aug  3 2021 mkubecek@suse.cz
- Update kabi files.
- update from August 2021 maintenance update submission (commit a13100d5f167)
- commit 75dc981
* Tue Aug  3 2021 denis.kirjanov@suse.com
- blacklist.conf: add macsonic driver
- commit 688a554
* Mon Aug  2 2021 palcantara@suse.de
- cifs: do not share tcp sessions of dfs connections
  (bsc#1185902).
- commit 78eb685
* Mon Aug  2 2021 palcantara@suse.de
- cifs: prevent NULL deref in cifs_compose_mount_options()
  (bsc#1185902).
- commit a798607
* Mon Aug  2 2021 palcantara@suse.de
- cifs: missing null pointer check in cifs_mount (bsc#1185902).
- commit 17b0494
* Mon Aug  2 2021 palcantara@suse.de
- cifs: fix check of dfs interlinks (bsc#1185902).
- commit 1db4f4d
* Mon Aug  2 2021 palcantara@suse.de
- cifs: avoid starvation when refreshing dfs cache (bsc#1185902).
- commit 064a32d
* Mon Aug  2 2021 palcantara@suse.de
- cifs: do not share tcp servers with dfs mounts (bsc#1185902).
- commit 65332c5
* Mon Aug  2 2021 palcantara@suse.de
- cifs: set a minimum of 2 minutes for refreshing dfs cache
  (bsc#1185902).
- commit 1a16c86
* Mon Aug  2 2021 palcantara@suse.de
- cifs: fix path comparison and hash calc (bsc#1185902).
- commit 9ae40ff
* Mon Aug  2 2021 palcantara@suse.de
- cifs: handle different charsets in dfs cache (bsc#1185902).
- commit 7b185cd
* Mon Aug  2 2021 palcantara@suse.de
- cifs: keep referral server sessions alive (bsc#1185902).
- commit a6fba08
* Mon Aug  2 2021 pmladek@suse.com
- workqueue: fix UAF in pwq_unbound_release_workfn()
  (bsc#1188973).
- commit b02980f
* Mon Aug  2 2021 tiwai@suse.de
- ALSA: pcm - fix mmap capability check for the snd-dummy driver
  (git-fixes).
- commit b68f7e6
* Mon Aug  2 2021 tiwai@suse.de
- ACPI: DPTF: Fix reading of attributes (git-fixes).
- drm/msm/dpu: Fix sm8250_mdp register length (git-fixes).
- commit da4d5f8
* Mon Aug  2 2021 tiwai@suse.de
- can: esd_usb2: fix memory leak (git-fixes).
- can: ems_usb: fix memory leak (git-fixes).
- can: usb_8dev: fix memory leak (git-fixes).
- can: mcba_usb_start(): add missing urb->transfer_dma
  initialization (git-fixes).
- can: hi311x: fix a signedness bug in hi3110_cmd() (git-fixes).
- nfc: nfcsim: fix use after free during module unload
  (git-fixes).
- can: raw: raw_setsockopt(): fix raw_rcv panic for sock UAF
  (git-fixes).
- Revert "ACPI: resources: Add checks for ACPI IRQ override"
  (git-fixes).
- firmware: arm_scmi: Fix range check for the maximum number of
  pending messages (git-fixes).
- firmware: arm_scmi: Fix possible scmi_linux_errmap buffer
  overflow (git-fixes).
- commit 7ff2c84
* Sun Aug  1 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/xfrm-xfrm_state_mtu-should-return-at-least-1280-for-.patch
- commit e52bdda
* Fri Jul 30 2021 tbogendoerfer@suse.de
- ixgbe: Fix packet corruption due to missing DMA sync
  (git-fixes).
- bnxt_en: Check abort error state in bnxt_half_open_nic()
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add missing check for BNXT_STATE_ABORT_ERR in
  bnxt_fw_rset_task() (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refresh RoCE capabilities in bnxt_ulp_probe()
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: don't disable an already disabled PCI device
  (git-fixes).
- cxgb4: fix IRQ free race during driver unload (git-fixes).
- igb: Fix position of assignment to *ring (git-fixes).
- igb: Check if num of q_vectors is smaller than max before
  array access (git-fixes).
- iavf: Fix an error handling path in 'iavf_probe()' (git-fixes).
- e1000e: Fix an error handling path in 'e1000_probe()'
  (git-fixes).
- igb: Fix an error handling path in 'igb_probe()' (git-fixes).
- igc: Fix an error handling path in 'igc_probe()' (git-fixes).
- ixgbe: Fix an error handling path in 'ixgbe_probe()'
  (git-fixes).
- igc: change default return of igc_read_phy_reg() (git-fixes).
- igb: Fix use-after-free error during reset (git-fixes).
- igc: Fix use-after-free error during reset (git-fixes).
- virtio_net: move tx vq operation under tx queue lock
  (git-fixes).
- Revert "be2net: disable bh with spin_lock in be_process_mcc"
  (git-fixes).
- e1000e: Check the PCIm state (git-fixes).
- i40e: Fix autoneg disabling for non-10GBaseT links (git-fixes).
- i40e: Fix error handling in i40e_vsi_open (git-fixes).
- vxlan: add missing rcu_read_lock() in neigh_reduce()
  (git-fixes).
- mvpp2: suppress warning (git-fixes).
- net: mvpp2: Put fwnode in error case during ->probe()
  (git-fixes).
- net/mlx5e: Block offload of outer header csum for GRE tunnel
  (git-fixes).
- commit 3de5d62
* Fri Jul 30 2021 jlee@suse.com
- Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
  (bsc#1187591, bsc#1188694)
- Return EFI_UNSUPPORTED when accessing EFI_RNG_PROTOCOL failed.
- Improved the warning message.
- commit 6f32319
* Thu Jul 29 2021 msuchanek@suse.de
- powerpc/security: Fix link stack flush instruction (bsc#1188885
  ltc#193722).
- commit 6d617e8
* Thu Jul 29 2021 palcantara@suse.de
- cifs: get rid of @noreq param in __dfs_cache_find()
  (bsc#1185902).
- commit 7f4ff26
* Thu Jul 29 2021 palcantara@suse.de
- cifs: do not send tree disconnect to ipc shares (bsc#1185902).
- commit 96ce669
* Thu Jul 29 2021 palcantara@suse.de
- cifs: Remove unused inline function is_sysvol_or_netlogon()
  (bsc#1185902).
- commit 7d7b6d5
* Thu Jul 29 2021 jeffm@suse.com
- Update Patch-mainline tags for patches that landed in 5.14-rc3.
- commit 48a135a
* Thu Jul 29 2021 msuchanek@suse.de
- powerpc/64s: Move branch cache flushing bcctr variant to
  ppc-ops.h (bsc#1188885 ltc#193722).
- commit 837e7fa
* Thu Jul 29 2021 msuchanek@suse.de
- powerpc/security: Allow for processors that flush the link
  stack using the special bcctr (bsc#1188885 ltc#193722).
- powerpc/security: split branch cache flush toggle from code
  patching (bsc#1188885 ltc#193722).
- powerpc/security: make display of branch cache flush more
  consistent (bsc#1188885 ltc#193722).
- powerpc/security: change link stack flush state to the flush
  type enum (bsc#1188885 ltc#193722).
- Delete patches.suse/powerpc-add-link-stack-flush-mitigation-in-debugfs.patch
- replaced with upstream security mitigation cleanup
- powerpc/security: re-name count cache flush to branch cache
  flush (bsc#1188885 ltc#193722).
- commit e35bcce
* Thu Jul 29 2021 msuchanek@suse.de
- powerpc/pesries: Get STF barrier requirement from
  H_GET_CPU_CHARACTERISTICS (bsc#1188885 ltc#193722).
- powerpc/security: Add a security feature for STF barrier
  (bsc#1188885 ltc#193722).
- powerpc/pseries: Get entry and uaccess flush required bits
  from H_GET_CPU_CHARACTERISTICS (bsc#1188885 ltc#193722).
- powerpc/pseries: export LPAR security flavor in lparcfg
  (bsc#1188885 ltc#193722).
- powerpc/64s: rename pnv|pseries_setup_rfi_flush to
  _setup_security_mitigations (bsc#1188885 ltc#193722).
- Refresh patches.suse/powerpc-pseries-mobility-notify-network-peers-after-.patch.
- powerpc/pseries: add new branch prediction security bits for
  link stack (bsc#1188885 ltc#193722).
- commit 3f019e2
* Thu Jul 29 2021 tiwai@suse.de
- kABI workaround for btintel symbol changes (bsc#1188893).
- commit a0378fb
* Thu Jul 29 2021 tiwai@suse.de
- Bluetooth: btusb: Fix failing to init controllers with operation
  firmware (bsc#1188893).
- Bluetooth: btintel: Skip reading firmware file version while
  in bootloader mode (bsc#1188893).
- Bluetooth: btintel: Collect tlv based active firmware build
  info in FW mode (bsc#1188893).
- Bluetooth: btintel: Reorganized bootloader mode tlv checks in
  intel_version_tlv parsing (bsc#1188893).
- Bluetooth: btusb: Consolidate code for waiting firmware download
  (bsc#1188893).
- Bluetooth: btintel: Consolidate intel_version parsing
  (bsc#1188893).
- Bluetooth: btintel: Consolidate intel_version_tlv parsing
  (bsc#1188893).
- commit 5d9b049
* Thu Jul 29 2021 tiwai@suse.de
- Bluetooth: btintel: Move operational checks after version check
  (bsc#1188893).
- Bluetooth: btintel: Check firmware version before download
  (bsc#1188893).
- Bluetooth: btintel: Fix offset calculation boot address
  parameter (bsc#1188893).
- Bluetooth: btusb: print firmware file name on error loading
  firmware (bsc#1188893).
- commit 02eefaa
* Thu Jul 29 2021 tiwai@suse.de
- Bluetooth: btusb: Add support for GarfieldPeak controller
  (bsc#1188893).
- Revert "Bluetooth: btintel: Fix endianness issue for TLV
  version information" (bsc#1188893).
- Bluetooth: btusb: Enable MSFT extension for Intel controllers
  (bsc#1188893).
- Bluetooth: btusb: Map Typhoon peak controller to
  BTUSB_INTEL_NEWGEN (bsc#1188893).
- commit 8c5bc15
* Thu Jul 29 2021 tiwai@suse.de
- Bluetooth: btusb: Helper function to download firmware to
  Intel adapters (bsc#1188893).
- Bluetooth: btusb: Define a function to construct firmware
  filename (bsc#1188893).
- Bluetooth: btusb: Add *setup* function for new generation
  Intel controllers (bsc#1188893).
- Bluetooth: btintel: Fix endianness issue for TLV version
  information (bsc#1188893).
- commit 051ab9c
* Thu Jul 29 2021 tiwai@suse.de
- Bluetooth: btintel: Replace zero-length array with
  flexible-array member (bsc#1188893).
- Bluetooth: btintel: Functions to send firmware header / payload
  (bsc#1188893).
- Bluetooth: btintel: Add infrastructure to read controller
  information (bsc#1188893).
- Bluetooth: btintel: Refactor firmware download function
  (bsc#1188893).
- Bluetooth: hci_intel: enable on new platform (bsc#1188893).
- Bluetooth: hci_intel: switch to list_for_each_entry()
  (bsc#1188893).
- Bluetooth: hci_intel: drop strange le16_to_cpu() against u8
  values (bsc#1188893).
- Bluetooth: btusb: Update boot parameter specific to SKU
  (bsc#1188893).
- commit 29e3766
* Thu Jul 29 2021 aabdallah@suse.de
- Update patch-mainline and git-commit tags
  Refresh:
  - patches.suse/0001-netfilter-conntrack-add-new-sysctl-to-disable-RST-ch.patch
  - patches.suse/0001-netfilter-conntrack-improve-RST-handling-when-tuple-.patch
- commit 758ec5c
* Thu Jul 29 2021 tiwai@suse.de
- Move upstreamed patches to sorted section
- commit e174d5e
* Thu Jul 29 2021 msuchanek@suse.de
- Refresh patches.suse/efi-tpm-Differentiate-missing-and-invalid-final-even.patch.
  Update upstream status.
- commit 871e8d7
* Thu Jul 29 2021 msuchanek@suse.de
- scsi: ibmvfc: Fix command state accounting and stale response
  detection (jsc#SLE-15442 bsc#1180814 ltc#187461 git-fixes).
- commit e0dfe90
* Thu Jul 29 2021 tiwai@suse.de
- net: mac802154: Fix general protection fault (CVE-2021-3659
  bsc#1188876).
- commit 61caeac
* Thu Jul 29 2021 ohering@suse.de
- bonding: fix build issue (git-fixes).
- commit ba9e531
* Thu Jul 29 2021 tiwai@suse.de
- ALSA: pcm: Fix mmap capability check (git-fixes).
- ALSA: hda/realtek: Fix pop noise and 2 Front Mic issues on a
  machine (git-fixes).
- drm/amdgpu: update golden setting for sienna_cichlid
  (git-fixes).
- iwlwifi: Fix softirq/hardirq disabling in
  iwl_pcie_gen2_enqueue_hcmd() (git-fixes).
- iwlwifi: Fix softirq/hardirq disabling in
  iwl_pcie_enqueue_hcmd() (git-fixes).
- commit aefa679
* Thu Jul 29 2021 tiwai@suse.de
- USB: serial: cp210x: add ID for CEL EM3588 USB ZigBee stick
  (git-fixes).
- USB: serial: option: add support for u-blox LARA-R6 family
  (git-fixes).
- USB: usb-storage: Add LaCie Rugged USB3-FW to IGNORE_UAS
  (git-fixes).
- usb: hub: Disable USB 3 device initiated lpm if exit latency
  is too high (git-fixes).
- usb: hub: Fix link power management max exit latency (MEL)
  calculations (git-fixes).
- xhci: Fix lost USB 2 remote wake (git-fixes).
- spi: imx: add a check for speed_hz before calculating the clock
  (git-fixes).
- commit cbaa23f
* Thu Jul 29 2021 tiwai@suse.de
- firmware/efi: Tell memblock about EFI iomem reservations
  (git-fixes).
- ALSA: usb-audio: Add registration quirk for JBL Quantum headsets
  (git-fixes).
- ASoC: rt5631: Fix regcache sync errors on resume (git-fixes).
- ALSA: hdmi: Expose all pins on MSI MS-7C94 board (git-fixes).
- ALSA: sb: Fix potential ABBA deadlock in CSP driver (git-fixes).
- drm: Return -ENOTTY for non-drm ioctls (git-fixes).
- regulator: hi6421: Fix getting wrong drvdata (git-fixes).
- regulator: hi6421: Use correct variable type for regmap api
  val argument (git-fixes).
- iio: accel: bma180: Use explicit member assignment (git-fixes).
- commit 4603b01
* Wed Jul 28 2021 jbohac@suse.cz
- xfrm: xfrm_state_mtu should return at least 1280 for ipv6
  (bsc#1185377).
- commit c3c4cb5
* Wed Jul 28 2021 mkubecek@suse.cz
- use 3.0 SPDX identifier in rpm License tags
  As requested by Maintenance, change rpm License tags from "GPL-2.0"
  (SPDX 2.0) to "GPL-2.0-only" (SPDX 3.0) so that their scripts do not have
  to adjust the tags with each maintenance update submission.
- commit f888e0b
* Wed Jul 28 2021 oneukum@suse.com
- platform/x86: intel_int0002_vgpio: Only call enable_irq_wake()
  when using s2idle (git-fixes).
- commit 28541e7
* Wed Jul 28 2021 oneukum@suse.com
- platform/x86: dell-smbios-wmi: Fix oops on rmmod dell_smbios
  (git-fixes).
- commit ffedcc6
* Wed Jul 28 2021 oneukum@suse.com
- platform/x86: intel_int0002_vgpio: Remove dev_err() usage
  after platform_get_irq() (git-fixes).
- commit 4131c57
* Wed Jul 28 2021 oneukum@suse.com
- platform/x86: intel_int0002_vgpio: Pass irqchip when adding
  gpiochip (git-fixes).
- commit 88a6182
* Wed Jul 28 2021 msuchanek@suse.de
- KVM: PPC: Book3S: Fix H_RTAS rets buffer overflow (bsc#1188838
  CVE-2021-37576).
- commit 0162dcd
* Wed Jul 28 2021 oneukum@suse.com
- platform/x86: intel_int0002_vgpio: Use device_init_wakeup
  (git-fixes).
- commit 017d588
* Wed Jul 28 2021 oneukum@suse.com
- platform/chrome: cros_ec_lightbar: Reduce ligthbar get version
  command (git-fixes).
- commit a8f01e1
* Wed Jul 28 2021 oneukum@suse.com
- Input: ili210x - add missing negation for touch indication on
  ili210x (git-fixes).
- commit 0575cf5
* Tue Jul 27 2021 jziviani@suse.de
- KVM: x86: bit 8 of non-leaf PDPEs is not reserved (bsc#1188790).
- commit 81b4c99
* Tue Jul 27 2021 jziviani@suse.de
- KVM: VMX: Explicitly clear RFLAGS.CF and RFLAGS.ZF in VM-Exit
  RSB path (bsc#1188788).
- commit f2e225f
* Tue Jul 27 2021 jziviani@suse.de
- KVM: VMX: Enable machine check support for 32bit targets
  (bsc#1188787).
- commit 388d3fb
* Tue Jul 27 2021 jziviani@suse.de
- KVM: VMX: Drop guest CPUID check for VMXE in vmx_set_cr4()
  (bsc#1188786).
- commit c5de014
* Tue Jul 27 2021 jziviani@suse.de
- KVM: nVMX: Truncate bits 63:32 of VMCS field on nested check
  in !64-bit (bsc#1188784).
- commit 08b2951
* Tue Jul 27 2021 jziviani@suse.de
- KVM: nVMX: Sync unsync'd vmcs02 state to vmcs12 on migration
  (bsc#1188783).
- commit 5f8f317
* Tue Jul 27 2021 jziviani@suse.de
- KVM: nVMX: Skip IBPB when switching between vmcs01 and vmcs02
  (bsc#1188782).
- commit ef7bd2d
* Tue Jul 27 2021 jziviani@suse.de
- KVM: nVMX: Reset the segment cache when stuffing guest segs
  (bsc#1188781).
- commit 8984ecb
* Tue Jul 27 2021 jziviani@suse.de
- KVM: nVMX: Really make emulated nested preemption timer pinned
  (bsc#1188780).
- commit 597c5f3
* Tue Jul 27 2021 jziviani@suse.de
- KVM: nVMX: Preserve exception priority irrespective of exiting
  behavior (bsc#1188777).
- commit 9024fbf
* Tue Jul 27 2021 jziviani@suse.de
- KVM: nVMX: Ensure 64-bit shift when checking VMFUNC bitmap
  (bsc#1188774).
- commit 7334e84
* Tue Jul 27 2021 jziviani@suse.de
- KVM: nVMX: Consult only the "basic" exit reason when routing
  nested exit (bsc#1188773).
- commit f7ab15a
* Tue Jul 27 2021 jziviani@suse.de
- kvm: LAPIC: Restore guard to prevent illegal APIC register
  access (bsc#1188772).
- commit 8a9a1d5
* Tue Jul 27 2021 jziviani@suse.de
- KVM: LAPIC: Prevent setting the tscdeadline timer if the lapic
  is hw disabled (bsc#1188771).
- commit 7610884
* Tue Jul 27 2021 jziviani@suse.de
- kvm: i8254: remove redundant assignment to pointer s
  (bsc#1188770).
- commit f768a8a
* Tue Jul 27 2021 lduncan@suse.com
- prctl: PR_{G,S}ET_IO_FLUSHER to support controlling memory
  reclaim (bsc#1188752).
- commit 80a0f40
* Tue Jul 27 2021 tiwai@suse.de
- iwlwifi: pcie: make iwl_pcie_txq_update_byte_cnt_tbl bus
  independent (bsc#1187495).
- Refresh
  patches.suse/iwlwifi-pcie-free-IML-DMA-memory-allocation.patch.
- commit 55531dc
* Tue Jul 27 2021 oneukum@suse.com
- blacklist.conf: kABI
- commit c1f6ea9
* Tue Jul 27 2021 lhenriques@suse.de
- ceph: don't WARN if we're still opening a session to an MDS
  (bsc#1188748).
- rbd: don't hold lock_rwsem while running_list is being drained
  (bsc#1188747).
- rbd: always kick acquire on "acquired" and "released"
  notifications (bsc#1188746).
- commit 5813020
* Tue Jul 27 2021 jeyu@suse.de
- Update patches.suse/x86-intel-aggregate-microserver-naming.patch.
  This was a search-and-replace patch - there were one _X -> _D
  replacement missing in tools/power/x86/turbostat/turbostat.c
  Update the patch to cover the missing replacement.
- commit 63c708b
* Tue Jul 27 2021 oneukum@suse.com
- mt76: set dma-done flag for flushed descriptors (git-fixes).
- commit aaa3cb6
* Tue Jul 27 2021 oneukum@suse.com
- mt76: mt7615: fix endianness in mt7615_mcu_set_eeprom
  (git-fixes).
- commit 43e0b14
* Tue Jul 27 2021 oneukum@suse.com
- mt76: mt7615: increase MCU command timeout (git-fixes).
- commit 1ca559f
* Tue Jul 27 2021 oneukum@suse.com
- mt76: mt7603: set 0 as min coverage_class value (git-fixes).
- commit 606bd07
* Tue Jul 27 2021 msuchanek@suse.de
- ibmvnic: retry reset if there are no other resets (bsc#1184350
  ltc#191533).
- commit fccec64
* Tue Jul 27 2021 tiwai@suse.de
- drm/radeon: Call radeon_suspend_kms() in radeon_pci_shutdown()
  for Loongson64 (git-fixes).
- drm/amdgpu: enable sdma0 tmz for Raven/Renoir(V2) (git-fixes).
- drm/amdkfd: Fix circular lock in nocpsch path (git-fixes).
- drm/amdkfd: fix circular locking on get_wave_state (git-fixes).
- drm/amdkfd: use allowed domain for vmbo validation (git-fixes).
- drm/amd/display: Fix off-by-one error in DML (git-fixes).
- drm/amd/display: Release MST resources on switch from MST to
  SST (git-fixes).
- drm/amd/display: Fix DCN 3.01 DSCCLK validation (git-fixes).
- commit 0be6a2a
* Tue Jul 27 2021 tiwai@suse.de
- drm/amdgpu: remove unsafe optimization to drop preamble ib
  (git-fixes).
- drm/amd/display: Avoid HDCP over-read and corruption
  (git-fixes).
- drm: rockchip: add missing registers for RK3066 (git-fixes).
- drm: rockchip: add missing registers for RK3188 (git-fixes).
- drm/vc4: hdmi: Fix PM reference leak in
  vc4_hdmi_encoder_pre_crtc_co() (git-fixes).
- drm/vc4: Fix clock source for VEC PixelValve on BCM2711
  (git-fixes).
- drm/amd/display: fix HDCP reset sequence on reinitialize
  (git-fixes).
- drm/scheduler: Fix hang when sched_entity released (git-fixes).
- drm/nouveau: Don't set allow_fb_modifiers explicitly
  (git-fixes).
- drm/bridge: nwl-dsi: Force a full modeset when
  crtc_state->active is changed to be true (git-fixes).
- commit 0856190
* Mon Jul 26 2021 palcantara@suse.de
- cifs: do not fail __smb_send_rqst if non-fatal signals are
  pending (git-fixes).
- commit 80eef04
* Mon Jul 26 2021 palcantara@suse.de
- cifs: fix interrupted close commands (git-fixes).
- commit 9eae08a
* Mon Jul 26 2021 palcantara@suse.de
- cifs: Fix preauth hash corruption (git-fixes).
- commit a2ac7b0
* Mon Jul 26 2021 palcantara@suse.de
- cifs: Return correct error code from smb2_get_enc_key
  (git-fixes).
- commit ffe15e7
* Mon Jul 26 2021 palcantara@suse.de
- cifs: fix memory leak in smb2_copychunk_range (git-fixes).
- commit f974156
* Mon Jul 26 2021 msuchanek@suse.de
- uuid: Add inline helpers to import / export UUIDs (FATE#326628,
  bsc#1113295, git-fixes).
- commit 5ef7dcb
* Mon Jul 26 2021 tiwai@suse.de
- Drop media rtl28xxu fix patch (bsc#1188683)
  The recent backport of
  patches.suse/media-rtl28xxu-fix-zero-length-control-request.patch
  caused a regression on Astrometa DVB-T2.
  Revert and blacklist it for now.
- commit 1ae8d64
* Mon Jul 26 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  - patches.suse/r8152-Fix-a-deadlock-by-doubly-PM-resume.patch
  - patches.suse/r8152-Fix-potential-PM-refcount-imbalance.patch
- commit 425c935
* Mon Jul 26 2021 msuchanek@suse.de
- powerpc/stacktrace: Include linux/delay.h (bsc#1156395).
- commit fb8c7fc
* Mon Jul 26 2021 lhenriques@suse.de
- ceph: clean up and optimize ceph_check_delayed_caps()
  (bsc#1187468).
- commit 33a74a3
* Mon Jul 26 2021 denis.kirjanov@suse.com
- sfp: Fix error handing in sfp_probe() (git-fixes).
- commit 3f0aed6
* Mon Jul 26 2021 denis.kirjanov@suse.com
- cadence: force nonlinear buffers to be cloned (git-fixes).
- commit 4b76907
* Mon Jul 26 2021 denis.kirjanov@suse.com
- gtp: fix an use-before-init in gtp_newlink() (git-fixes).
- commit 6e609d3
* Mon Jul 26 2021 denis.kirjanov@suse.com
- ravb: Fix bit fields checking in ravb_hwtstamp_get()
  (git-fixes).
- commit ed39fda
* Mon Jul 26 2021 denis.kirjanov@suse.com
- net: hns3: Clear the CMDQ registers before unmapping BAR region
  (git-fixes).
- commit 57704e2
* Mon Jul 26 2021 oneukum@suse.com
- wilc1000: write value to WILC_INTR2_ENABLE register (git-fixes).
- commit 23af1ba
* Mon Jul 26 2021 oneukum@suse.com
- net: wilc1000: clean up resource in error path of init mon
  interface (git-fixes).
- commit aa75b92
* Mon Jul 26 2021 msuchanek@suse.de
- Update patches.suse/ibmvnic-account-for-bufs-already-saved-in-indir_buf.patch
  (jsc#SLE-17268 jsc#SLE-17043 bsc#1179243 ltc#189290 bsc#1188620
  ltc#192221).
- Update patches.suse/ibmvnic-free-tx_pool-if-tso_pool-alloc-fails.patch
  (bsc#1085224 ltc#164363 bsc#1188620 ltc#192221).
- Update patches.suse/ibmvnic-parenthesize-a-check.patch
  (bsc#1184114 ltc#192237 bsc#1183871 ltc#192139 git-fixes
  bsc#1188620 ltc#192221).
- Update patches.suse/ibmvnic-set-ltb-buff-to-NULL-after-freeing.patch
  (bsc#1094840 ltc#167098 bsc#1188620 ltc#192221).
- commit 8147958
* Mon Jul 26 2021 msuchanek@suse.de
- ibmvnic: Remove the proper scrq flush (bsc#1188504 ltc#192075).
- commit 8bf9d02
* Mon Jul 26 2021 oneukum@suse.com
- blacklist.conf: kABI
- commit 7c940a5
* Mon Jul 26 2021 oneukum@suse.com
- blacklist.conf: cosmetic cleanup
- commit 29705c7
* Mon Jul 26 2021 oneukum@suse.com
- blacklist.conf: kABI
- commit 839f900
* Mon Jul 26 2021 jeyu@suse.de
- Update patches.suse/x86-intel-aggregate-big-core-mobile-naming.patch.
  This was a search-and-replace patch - there were a handful of _ULT -> _L
  and _MOBILE -> _L replacements missing in tools/power/x86/turbostat/turbostat.c
  Update the patch to cover the missing replacements.
- Refresh patches.suse/x86-intel-aggregate-big-core-graphics-naming.patch.
- commit efd5300
* Mon Jul 26 2021 jeyu@suse.de
- Update patches.suse/iommu-vt-d-do-not-use-flush-queue-when-caching-mode-is-on.
  The definition of domain_use_flush_queue() was tucked inside
  an #ifdef CONFIG_INTEL_IOMMU_SVM, whereas the function can be called
  outside of that #ifdef. It does not affect SLE15-SP3 directly since our
  configs always enable CONFIG_INTEL_IOMMU_SVM, but it's in the incorrect
  place in general. Move it outside of the ifdef to match upstream behavior.
- commit e39afe2
* Mon Jul 26 2021 fweisbecker@suse.de
- timers: Fix get_next_timer_interrupt() with no timers pending (git-fixes)
- commit 1045d0d
* Mon Jul 26 2021 varad.gautam@suse.com
- docs: virt/kvm: close inline string literal (bsc#1188703).
- commit e83521c
* Mon Jul 26 2021 varad.gautam@suse.com
- KVM: SVM: document KVM_MEM_ENCRYPT_OP, let userspace detect
  if SEV is available (bsc#1188703).
- commit 0f91585
* Mon Jul 26 2021 jlee@suse.com
- integrity: use arch_ima_get_secureboot instead of checking
  EFI_SECURE_BOOT when loading MokListRT (bsc#1188366).
- Update config files.
  Add CONFIG_IMA_ARCH_POLICY=y and CONFIG_IMA_SECURE_AND_OR_TRUSTED_BOOT=y
  in x86_64/default.
- commit 8567c4b
* Mon Jul 26 2021 shung-hsi.yu@suse.com
- i40e: Fix missing rtnl locking when setting up pf switch
  (jsc#SLE-13701).
- commit 27422dd
* Mon Jul 26 2021 tiwai@suse.de
- rtc: max77686: Do not enforce (incorrect) interrupt trigger type
  (git-fixes).
- rtc: mxc_v2: add missing MODULE_DEVICE_TABLE (git-fixes).
- thermal/core: Correct function name
  thermal_zone_device_unregister() (git-fixes).
- reset: ti-syscon: fix to_ti_syscon_reset_data macro (git-fixes).
- soc/tegra: fuse: Fix Tegra234-only builds (git-fixes).
- commit c39f899
* Sun Jul 25 2021 tiwai@suse.de
- USB: serial: cp210x: fix comments for GE CS1000 (git-fixes).
- Revert "USB: quirks: ignore remote wake-up on Fibocom L850-GL
  LTE modem" (git-fixes).
- usb: dwc2: gadget: Fix sending zero length packet in DDMA mode
  (git-fixes).
- usb: renesas_usbhs: Fix superfluous irqs happen after
  usb_pkt_pop() (git-fixes).
- usb: max-3421: Prevent corruption of freed memory (git-fixes).
- commit c637f14
* Sun Jul 25 2021 tiwai@suse.de
- ASoC: rt5682: Fix a problem with error handling in the io init
  function of the soundwire (git-fixes).
- Refresh
  patches.suse/ASoC-rt5682-sdw-set-regcache_cache_only-false-before.patch.
- commit c833aa0
* Sun Jul 25 2021 tiwai@suse.de
- ASoC: wm_adsp: Correct wm_coeff_tlv_get handling (git-fixes).
- ALSA: hda: intel-dsp-cfg: add missing ElkhartLake PCI ID
  (git-fixes).
- ALSA: usb-audio: Add missing proc text entry for BESPOKEN type
  (git-fixes).
- ASoC: Intel: sof_sdw: add SOF_RT715_DAI_ID_FIX for AlderLake
  (git-fixes).
- ASoC: rt5682-sdw: set regcache_cache_only false before reading
  RT5682_DEVICE_ID (git-fixes).
- Bluetooth: btqca: Don't modify firmware contents in-place
  (git-fixes).
- ASoC: rt5682: fix getting the wrong device id when the
  suspend_stress_test (git-fixes).
- commit 2fb44db
* Sun Jul 25 2021 tiwai@suse.de
- ALSA: pcm: Call substream ack() method upon compat mmap commit
  (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 630 G8
  (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 445 G8
  (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 450 G8
  (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP EliteBook 830
  G8 Notebook PC (git-fixes).
- ALSA: hda/realtek: Apply LED fixup for HP Dragonfly G1, too
  (git-fixes).
- ALSA: hda/realtek: Improve fixup for HP Spectre x360 15-df0xxx
  (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP EliteBook x360
  830 G8 (git-fixes).
- ACPI: PM / fan: Put fan device IDs into separate header file
  (git-fixes).
- commit 10136ed
* Fri Jul 23 2021 denis.kirjanov@suse.com
- net: ethernet: ti: Remove TI_CPTS_MOD workaround (git-fixes).
- commit 2c19bb5
* Fri Jul 23 2021 dwagner@suse.de
- scsi: fc: Add 256GBit speed setting to SCSI FC transport
  (bsc#1188101).
- commit 62c8708
* Fri Jul 23 2021 tiwai@suse.de
- r8152: Fix a deadlock by doubly PM resume (bsc#1186194).
- r8152: Fix potential PM refcount imbalance (bsc#1186194).
- commit 539ea44
* Fri Jul 23 2021 tiwai@suse.de
- Revert "drm/i915: Propagate errors on awaiting already signaled
  fences" (git-fixes).
- drm/i915/gvt: Clear d3_entered on elsp cmd submission
  (git-fixes).
- commit 258f2b1
* Fri Jul 23 2021 tiwai@suse.de
- drm/panel: raspberrypi-touchscreen: Prevent double-free
  (git-fixes).
- media: ngene: Fix out-of-bounds bug in
  ngene_command_config_free_buf() (git-fixes).
- liquidio: Fix unintentional sign extension issue on left shift
  of u16 (git-fixes).
- spi: cadence: Correct initialisation of runtime PM again
  (git-fixes).
- spi: mediatek: fix fifo rx mode (git-fixes).
- commit 44fe76d
* Fri Jul 23 2021 colyli@suse.de
- bcache: avoid oversized read request in cache missing code path
  (bsc#1184631).
- bcache: remove bcache device self-defined readahead
  (bsc#1184631).
- commit aaf8eb0
* Thu Jul 22 2021 tbogendoerfer@suse.de
- skbuff: Fix build with SKB extensions disabled (jsc#SLE-15172).
- commit c73a425
* Thu Jul 22 2021 jeffm@suse.com
- Update Patch-mainline tags for patches that landed in 5.14-rc2.
- commit 55eeb57
* Thu Jul 22 2021 jziviani@suse.de
- KVM: do not allow mapping valid but non-reference-counted pages
  (bsc#1186482, CVE-2021-22543).
- KVM: Use kvm_pfn_t for local PFN variable in
  hva_to_pfn_remapped() (bsc#1186482, CVE-2021-22543).
- KVM: do not assume PTE is writable after follow_pfn
  (bsc#1186482, CVE-2021-22543).
- commit 3795669
* Thu Jul 22 2021 jgross@suse.com
- xen/events: reset active flag for lateeoi events later
  (git-fixes).
- Refresh patches.suse/xen-events-fix-setting-irq-affinity.patch.
- commit e51ccb0
* Thu Jul 22 2021 jziviani@suse.de
- KVM: do not allow mapping valid but non-reference-counted pages
  (bsc#1186482, CVE-2021-22543).
- KVM: Use kvm_pfn_t for local PFN variable in
  hva_to_pfn_remapped() (bsc#1186482, CVE-2021-22543).
- KVM: do not assume PTE is writable after follow_pfn
  (bsc#1186482, CVE-2021-22543).
- commit 50f4816
* Thu Jul 22 2021 tbogendoerfer@suse.de
- RDMA/cma: Fix incorrect Packet Lifetime calculation
  (jsc#SLE-8449).
- RDMA/cma: Protect RMW with qp_mutex (git-fixes).
- bpf: Fix integer overflow in argument calculation for
  bpf_map_area_alloc (bsc#1154353).
- ice: Re-organizes reqstd/avail {R, T}XQ check/code for
  efficiency (jsc#SLE-7926).
- commit 94fef56
* Thu Jul 22 2021 tbogendoerfer@suse.de
- netfilter: ctnetlink: suspicious RCU usage in
  ctnetlink_dump_helpinfo (bsc#1176447).
- bonding: fix incorrect return value of bond_ipsec_offload_ok()
  (bsc#1176447).
- bonding: fix suspicious RCU usage in bond_ipsec_offload_ok()
  (bsc#1176447).
- bonding: Add struct bond_ipesc to manage SA (bsc#1176447).
- bonding: disallow setting nested bonding + ipsec offload
  (bsc#1176447).
- bonding: fix suspicious RCU usage in bond_ipsec_del_sa()
  (bsc#1176447).
- ixgbevf: use xso.real_dev instead of xso.dev in callback
  functions of struct xfrmdev_ops (bsc#1176447).
- net: netdevsim: use xso.real_dev instead of xso.dev in callback
  functions of struct xfrmdev_ops (bsc#1176447).
- bonding: fix null dereference in bond_ipsec_add_sa()
  (bsc#1176447).
- bonding: fix suspicious RCU usage in bond_ipsec_add_sa()
  (bsc#1176447).
- skbuff: Release nfct refcount on napi stolen or re-used skbs
  (jsc#SLE-15172).
- net/sched: act_ct: remove and free nf_table callbacks
  (jsc#SLE-15172).
- RDMA/rtrs-srv: Set minimal max_send_wr and max_recv_wr
  (jsc#SLE-15176).
- RDMA/rtrs-clt: Fix memory leak of not-freed sess->stats and
  stats->pcpu_stats (jsc#SLE-15176).
- RDMA/rtrs-clt: Check if the queue_depth has changed during a
  reconnection (jsc#SLE-15176).
- RDMA/rtrs-srv: Fix memory leak when having multiple sessions
  (jsc#SLE-15176).
- RDMA/rtrs-srv: Fix memory leak of unfreed rtrs_srv_stats object
  (jsc#SLE-15176).
- RDMA/rtrs: Do not reset hb_missed_max after re-connection
  (jsc#SLE-15176).
- RDMA/rtrs-srv: Replace atomic_t with percpu_ref for ids_inflight
  (jsc#SLE-15176).
- RDMA/rtrs-clt: Check state of the rtrs_clt_sess before reading
  its stats (jsc#SLE-15176).
- RDMA/srp: Fix a recently introduced memory leak (jsc#SLE-15176).
- RDMA/mlx5: Remove unused parameter udata (jsc#SLE-15176).
- RDMA/mlx4: Remove unused parameter udata (jsc#SLE-15176).
- RDMA/hns: Remove unused parameter udata (jsc#SLE-15176).
- i40e: fix PTP on 5Gb links (jsc#SLE-13701).
- xsk: Fix missing validation for skb and unaligned mode
  (jsc#SLE-13706).
- xfrm: Fix xfrm offload fallback fail case (bsc#1176447).
- xfrm: delete xfrm4_output_finish xfrm6_output_finish
  declarations (bsc#1176447).
- commit 2d7a0e6
* Wed Jul 21 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into sorted section:
  - patches.suse/seq_file-Disallow-extremely-large-seq-buffer-allocations.patch
- commit 07df461
* Wed Jul 21 2021 tiwai@suse.de
- kabi/severities: ignore kABI of iwlwifi symbols (bsc#1187495)
  iwlwifi driver consists of several modules and all exported symbols
  are internal uses.  Let's ignore kABI checks of those.
- commit 75aa507
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: pnvm: set the PNVM again if it was already loaded
  (bsc#1187495).
- iwlwifi: mvm: send stored PPAG command instead of local
  (bsc#1187495).
- iwlwifi: mvm: store PPAG enabled/disabled flag properly
  (bsc#1187495).
- iwlwifi: mvm: fix the type we use in the PPAG table validity
  checks (bsc#1187495).
- iwlwifi: mvm: set enabled in the PPAG command properly
  (bsc#1187495).
- iwlwifi: pnvm: don't try to load after failures (bsc#1187495).
- commit 7ff688f
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: increase PNVM load timeout (bsc#1187495).
- iwlwifi: pcie: properly set LTR workarounds on 22000 devices
  (bsc#1187495).
- iwlwifi: fix 11ax disabled bit in the regulatory capability
  flags (bsc#1187495).
- iwlwifi: pnvm: increment the pointer before checking the TLV
  (bsc#1187495).
- iwlwifi: mvm: don't check if CSA event is running before
  removing (bsc#1187495).
- iwlwifi: mvm: assign SAR table revision to the command later
  (bsc#1187495).
- iwlwifi: pcie: don't disable interrupts for reg_lock
  (bsc#1187495).
- iwlwifi: queue: bail out on invalid freeing (bsc#1187495).
- iwlwifi: pnvm: don't skip everything when not reloading
  (bsc#1187495).
- iwlwifi: pcie: avoid potential PNVM leaks (bsc#1187495).
- iwlwifi: dbg: Don't touch the tlv data (bsc#1187495).
- iwlwifi: provide gso_type to GSO packets (bsc#1187495).
- commit 8a657fa
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: bump FW API to 59 for AX devices (bsc#1187495).
- Delete patches.suse/iwlwifi-SLE15-SP3-ucode-fixes.patch.
- commit bcab4a8
* Wed Jul 21 2021 tiwai@suse.de
- Revert "iwlwifi: remove wide_cmd_header field" (bsc#1187495).
- iwlwifi: read and parse PNVM file (bsc#1187495).
- iwlwifi: pcie: implement set_pnvm op (bsc#1187495).
- commit 8166979
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: add trans op to set PNVM (bsc#1187495).
- iwlwifi: move PNVM implementation to common code (bsc#1187495).
- iwlwifi: rs: align to new TLC config command API (bsc#1187495).
- iwlwifi: fix sar geo table initialization (bsc#1187495).
- iwlwifi: stats: add new api fields for statistics cmd/ntfy
  (bsc#1187495).
- iwlwifi: mvm: fix suspicious rcu usage warnings (bsc#1187495).
- iwlwifi: mvm: remove memset of kek_kck command (bsc#1187495).
- iwlwifi: mvm: don't send a CSA command the firmware doesn't know
  (bsc#1187495).
- iwlwifi: pcie: fix the xtal latency value for a few qu devices
  (bsc#1187495).
- commit b1c507d
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: mvm: avoid possible NULL pointer dereference
  (bsc#1187495).
- iwlwifi: mvm: support ADD_STA_CMD_API_S ver 12 (bsc#1187495).
- iwlwifi: mvm: add a get lmac id function (bsc#1187495).
- iwlwifi: mvm: prepare roc_done_wk to work sync (bsc#1187495).
- iwlwifi: mvm: re-enable TX after channel switch (bsc#1187495).
- iwlwifi: mvm: stop claiming NL80211_EXT_FEATURE_SET_SCAN_DWELL
  (bsc#1187495).
- iwlwifi: mvm: ring the doorbell and wait for PNVM load
  completion (bsc#1187495).
- commit 53fae87
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: update prph scratch structure to include PNVM data
  (bsc#1187495).
- iwlwifi: mvm: read and parse SKU ID if available (bsc#1187495).
- iwlwifi: mvm: get number of stations from TLV (bsc#1187495).
- iwlwifi: iwl-drv: Provide descriptions debugfs dentries
  (bsc#1187495).
- iwlwifi: dvm: devices: Fix function documentation formatting
  issues (bsc#1187495).
- iwlwifi: mvm: tx: Demote misuse of kernel-doc headers
  (bsc#1187495).
- iwlwifi: dvm: rxon: Demote non-conformant kernel-doc headers
  (bsc#1187495).
- iwlwifi: dvm: scan: Demote a few nonconformant kernel-doc
  headers (bsc#1187495).
- iwlwifi: mvm: utils: Fix some doc-rot (bsc#1187495).
- iwlwifi: dvm: Demote a couple of nonconformant kernel-doc
  headers (bsc#1187495).
- commit 5ecfaae
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: bump FW API to 57 for AX devices (bsc#1187495).
- Refresh patches.suse/iwlwifi-SLE15-SP3-ucode-fixes.patch.
- commit 35fc6ef
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: mvm: ops: Remove unused static struct
  'iwl_mvm_debug_names' (bsc#1187495).
- iwlwifi: dvm: sta: Demote a bunch of nonconformant kernel-doc
  headers (bsc#1187495).
- iwlwifi: calib: Demote seemingly unintentional kerneldoc header
  (bsc#1187495).
- iwlwifi: dvm: lib: Demote non-compliant kernel-doc headers
  (bsc#1187495).
- iwlwifi: dvm: tx: Demote non-compliant kernel-doc headers
  (bsc#1187495).
- iwlwifi: rs: Demote non-compliant kernel-doc headers
  (bsc#1187495).
- iwlwifi: dvm: Demote non-compliant kernel-doc headers
  (bsc#1187495).
- iwlwifi: yoyo: add support for internal buffer allocation in D3
  (bsc#1187495).
- iwlwifi: api: fix u32 -> __le32 (bsc#1187495).
- commit 8a1ae62
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: use correct group for alive notification (bsc#1187495).
- iwlwifi: support version 5 of the alive notification
  (bsc#1187495).
- iwlwifi: mvm: ignore the scan duration parameter (bsc#1187495).
- iwlwifi: dbg: add debug host notification (DHN) time point
  (bsc#1187495).
- iwlwifi: mvm: clear all scan UIDs (bsc#1187495).
- iwlwifi: mvm: d3: parse wowlan status version 11 (bsc#1187495).
- iwlwifi: align RX status flags with firmware (bsc#1187495).
- iwlwifi: mvm: remove redundant log in iwl_mvm_tvqm_enable_txq()
  (bsc#1187495).
- iwlwifi: phy-ctxt: add new API VER 3 for phy context cmd
  (bsc#1187495).
- commit e6bd24d
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: thermal: support new temperature measurement API
  (bsc#1187495).
- iwlwifi: mvm: add d3 prints (bsc#1187495).
- iwlwifi: mvm: d3: support GCMP ciphers (bsc#1187495).
- iwlwifi: mvm: support more GTK rekeying algorithms
  (bsc#1187495).
- iwlwifi: move all bus-independent TX functions to common code
  (bsc#1187495).
- iwlwifi: mvm: initiator: add option for adding a PASN responder
  (bsc#1187495).
- iwlwifi: mvm: responder: allow to set only the HLTK for an
  associated station (bsc#1187495).
- iwlwifi: mvm: location: set the HLTK when PASN station is added
  (bsc#1187495).
- commit 78b502b
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: acpi: in non acpi compilations remove iwl_sar_geo_init
  (bsc#1187495).
- commit 5e9faaf
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: support version 3 of GEO_TX_POWER_LIMIT (bsc#1187495).
- Refresh
  patches.suse/iwlwifi-follow-the-new-inclusive-terminology.patch.
- commit 18f1fc1
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: acpi: rename geo structs to contain versioning
  (bsc#1187495).
- Refresh
  patches.suse/iwlwifi-follow-the-new-inclusive-terminology.patch.
- commit 2a48685
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: mvm: Add FTM initiator RTT smoothing logic
  (bsc#1187495).
- iwlwifi: mvm: add support for responder dynamic config command
  version 3 (bsc#1187495).
- iwlwifi: mvm: add support for range request command ver 11
  (bsc#1187495).
- iwlwifi: remove wide_cmd_header field (bsc#1187495).
- iwlwifi: fw: add default value for iwl_fw_lookup_cmd_ver
  (bsc#1187495).
- iwlwifi: rs: set RTS protection for all non legacy rates
  (bsc#1187495).
- iwlwifi: mvm: support new KEK KCK api (bsc#1187495).
- commit b111b70
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: support REDUCE_TX_POWER_CMD version 6 (bsc#1187495).
- iwlwifi: acpi: prepare SAR profile selection code for multiple
  sizes (bsc#1187495).
- iwlwifi: add a common struct for all iwl_tx_power_cmd versions
  (bsc#1187495).
- iwlwifi: acpi: remove dummy definition of iwl_sar_set_profile()
  (bsc#1187495).
- iwlwifi: remove iwl_validate_sar_geo_profile() export
  (bsc#1187495).
- iwlwifi: mvm: use CHECKSUM_COMPLETE (bsc#1187495).
- iwlwifi: mvm: remove redundant support_umac_log field
  (bsc#1187495).
- iwlwifi: mvm: add support for new WOWLAN_TSC_RSC_PARAM version
  (bsc#1187495).
- iwlwifi: don't export acpi functions unnecessarily
  (bsc#1187495).
- commit 4e206c7
* Wed Jul 21 2021 tiwai@suse.de
- iwlwifi: mvm: process ba-notifications also when sta rcu is
  invalid (bsc#1187495).
- iwlwifi: mvm: add support for new version of
  WOWLAN_TKIP_SETTING_API_S (bsc#1187495).
- iwlwifi: mvm: Don't install CMAC/GMAC key in AP mode
  (bsc#1187495).
- iwl-trans: move dev_cmd_offs, page_offs to a common trans header
  (bsc#1187495).
- iwlwifi: regulatory: regulatory capabilities api change
  (bsc#1187495).
- iwlwifi: dbg: add dumping special device memory (bsc#1187495).
- iwlwifi: dbg: remove IWL_FW_INI_TIME_POINT_WDG_TIMEOUT
  (bsc#1187495).
- iwlwifi: acpi: support ppag table command v2 (bsc#1187495).
- iwlwifi: move bc_table_dword to a common trans header
  (bsc#1187495).
- iwlwifi: iwl-trans: move tfd to trans layer (bsc#1187495).
- iwlwifi: move bc_pool to a common trans header (bsc#1187495).
- iwlwifi: enable twt by default (bsc#1187495).
- iwlwifi: mvm: add an option to add PASN station (bsc#1187495).
- iwlwifi: fw: move assert descriptor parser to common code
  (bsc#1187495).
- iwlwifi: wowlan: adapt to wowlan status API version 10
  (bsc#1187495).
- iwlwifi: acpi: evaluate dsm to disable 5.8GHz channels
  (bsc#1187495).
- iwlwifi: msix: limit max RX queues for 9000 family
  (bsc#1187495).
- iwlwifi: sta: defer ADDBA transmit in case reclaimed SN !=
  next SN (bsc#1187495).
- iwlwifi: mvm: set PROTECTED_TWT feature if supported by firmware
  (bsc#1187495).
- iwlwifi: mvm: set PROTECTED_TWT in MAC data policy
  (bsc#1187495).
- iwlwifi: mvm: add PROTECTED_TWT firmware API (bsc#1187495).
- iwlwifi: mvm: rs-fw: handle VHT extended NSS capability
  (bsc#1187495).
- net: iwlwifi: Remove in_interrupt() from tracing macro
  (bsc#1187495).
- net: ipw2x00,iwlegacy,iwlwifi: Remove in_interrupt() from
  debug macros (bsc#1187495).
- commit 68d8e8f
* Wed Jul 21 2021 mbrugger@suse.com
- Update
  patches.suse/ARM-ensure-the-signal-page-contains-defined-contents.patch
  (CVE-2021-21781 bsc#1188445).
- commit 47f3aa1
* Wed Jul 21 2021 oneukum@suse.com
- net: fec_ptp: fix issue caused by refactor the fec_devtype
  (git-fixes).
- commit d15e1c0
* Wed Jul 21 2021 tiwai@suse.de
- kABI workaround for intel_th_driver (git-fixes).
- commit c18c5e5
* Wed Jul 21 2021 tiwai@suse.de
- drm/gma500: Add the missed drm_gem_object_put() in
  psb_user_framebuffer_create() (git-fixes).
- intel_th: Wait until port is in reset before programming it
  (git-fixes).
- ASoC: soc-pcm: fix the return value in dpcm_apply_symmetry()
  (git-fixes).
- ASoC: intel/boards: add missing MODULE_DEVICE_TABLE (git-fixes).
- ASoC: Intel: sof_sdw: add mutual exclusion between PCH DMIC
  and RT715 (git-fixes).
- ALSA: firewire-motu: fix detection for S/PDIF source on optical
  interface in v2 protocol (git-fixes).
- ALSA: usx2y: Avoid camelCase (git-fixes).
- commit 2f9e57e
* Wed Jul 21 2021 jeyu@suse.de
- Rename patches to match SLE15-SP2 equivalents to prepare for the next SLE15-SP2->SLE15-SP3 merge
- commit 06bbd81
* Wed Jul 21 2021 tiwai@suse.de
- watchdog: iTCO_wdt: Account for rebooting on second timeout
  (git-fixes).
- watchdog: Fix possible use-after-free by calling
  del_timer_sync() (git-fixes).
- watchdog: sc520_wdt: Fix possible use-after-free in
  wdt_turnoff() (git-fixes).
- watchdog: Fix possible use-after-free in wdt_startup()
  (git-fixes).
- w1: ds2438: fixing bug that would always get page0 (git-fixes).
- commit 0fe04be
* Wed Jul 21 2021 tiwai@suse.de
- virtio_console: Assure used length from device is limited
  (git-fixes).
- pwm: img: Fix PM reference leak in img_pwm_enable() (git-fixes).
- pwm: imx1: Don't disable clocks at device remove time
  (git-fixes).
- pwm: spear: Don't modify HW state in .remove callback
  (git-fixes).
- power: supply: ab8500: add missing MODULE_DEVICE_TABLE
  (git-fixes).
- usb: gadget: hid: fix error return code in hid_bind()
  (git-fixes).
- usb: gadget: f_hid: fix endianness issue with descriptors
  (git-fixes).
- tty: serial: 8250: serial_cs: Fix a memory leak in error
  handling path (git-fixes).
- tty: serial: fsl_lpuart: fix the potential risk of division
  or modulo by zero (git-fixes).
- staging: rtl8723bs: fix macro value for 2.4Ghz only device
  (git-fixes).
- commit 966e79d
* Wed Jul 21 2021 tiwai@suse.de
- PCI: tegra: Add missing MODULE_DEVICE_TABLE (git-fixes).
- power: supply: charger-manager: add missing MODULE_DEVICE_TABLE
  (git-fixes).
- power: reset: gpio-poweroff: add missing MODULE_DEVICE_TABLE
  (git-fixes).
- power: supply: max17042: Do not enforce (incorrect) interrupt
  trigger type (git-fixes).
- power: supply: ab8500: Avoid NULL pointers (git-fixes).
- power: supply: sc2731_charger: Add missing MODULE_DEVICE_TABLE
  (git-fixes).
- power: supply: sc27xx: Add missing MODULE_DEVICE_TABLE
  (git-fixes).
- misc: alcor_pci: fix inverted branch condition (git-fixes).
- net: usb: fix possible use-after-free in smsc75xx_bind
  (git-fixes).
- commit 74628f5
* Wed Jul 21 2021 tiwai@suse.de
- iio: magn: bmc150: Balance runtime pm + use
  pm_runtime_resume_and_get() (git-fixes).
- iio: gyro: fxa21002c: Balance runtime pm + use
  pm_runtime_resume_and_get() (git-fixes).
- misc: alcor_pci: fix null-ptr-deref when there is no PCI bridge
  (git-fixes).
- misc/libmasm/module: Fix two use after free in ibmasm_init_one
  (git-fixes).
- mfd: cpcap: Fix cpcap dmamask not set warnings (git-fixes).
- mfd: da9052/stmpe: Add and modify MODULE_DEVICE_TABLE
  (git-fixes).
- Input: hideep - fix the uninitialized use in hideep_nvm_unlock()
  (git-fixes).
- i2c: core: Disable client irq on reboot/shutdown (git-fixes).
- lib/decompress_unlz4.c: correctly handle zero-padding around
  initrds (git-fixes).
- commit 14f42b7
* Wed Jul 21 2021 tiwai@suse.de
- backlight: lm3630a: Fix return code of .update_status() callback
  (git-fixes).
- dmaengine: fsl-qdma: check dma_set_mask return value
  (git-fixes).
- gpio: pca953x: Add support for the On Semi pca9655 (git-fixes).
- gpio: zynq: Check return value of pm_runtime_get_sync
  (git-fixes).
- ASoC: Intel: kbl_da7219_max98357a: shrink platform_id below
  20 characters (git-fixes).
- ASoC: soc-core: Fix the error return code in
  snd_soc_of_parse_audio_routing() (git-fixes).
- ASoC: img: Fix PM reference leak in img_i2s_in_probe()
  (git-fixes).
- ALSA: usb-audio: scarlett2: Fix 6i6 Gen 2 line out descriptions
  (git-fixes).
- ALSA: hda: Add IRQ check for platform_get_irq() (git-fixes).
- ALSA: usb-audio: scarlett2: Fix scarlett2_*_ctl_put() return
  values (git-fixes).
- commit 006f207
* Wed Jul 21 2021 tiwai@suse.de
- ACPI: video: Add quirk for the Dell Vostro 3350 (git-fixes).
- ACPI: AMBA: Fix resource name in /proc/iomem (git-fixes).
- ALSA: usb-audio: scarlett2: Fix data_mutex lock (git-fixes).
- ALSA: usb-audio: scarlett2: Fix 18i8 Gen 2 PCM Input count
  (git-fixes).
- ALSA: bebob: add support for ToneWeal FW66 (git-fixes).
- ALSA: ppc: fix error return code in snd_pmac_probe()
  (git-fixes).
- ALSA: sb: Fix potential double-free of CSP mixer elements
  (git-fixes).
- ALSA: ac97: fix PM reference leak in ac97_bus_remove()
  (git-fixes).
- ALSA: usx2y: Don't call free_pages_exact() with NULL address
  (git-fixes).
- commit eaa8acd
* Tue Jul 20 2021 mkubecek@suse.cz
- config: refresh
- drop GVE on arm64 and s390x (no longer available due to dependency update)
- commit d6ed2bf
* Tue Jul 20 2021 duwe@suse.de
- crypto: sun4i-ss - initialize need_fallback (git-fixes).
- crypto: sun4i-ss - IV register does not work on A10 and A13
  (git-fixes).
- crypto: sun4i-ss - checking sg length is not sufficient
  (git-fixes).
- crypto: virtio: Fix dest length calculation in
  __virtio_crypto_skcipher_do_req() (git-fixes).
- crypto: virtio: Fix src/dst scatterlist calculation in
  __virtio_crypto_skcipher_do_req() (git-fixes).
- commit 2b4c8a1
* Tue Jul 20 2021 jgross@suse.com
- blacklist.conf: add 4c9c26f1e67648f41f
- commit db6c764
* Tue Jul 20 2021 jgross@suse.com
- blacklist.conf: add dbc03e81586fc33e4945263fd6e09e22eb4b980f
- commit 32c5658
* Tue Jul 20 2021 msuchanek@suse.de
- powerpc/papr_scm: Properly handle UUID types and API
  (FATE#326628, bsc#1113295, git-fixes).
- commit 9bcaa28
* Tue Jul 20 2021 msuchanek@suse.de
- powerpc: Offline CPU in stop_this_cpu() (bsc#1156395).
- commit 01547d1
* Tue Jul 20 2021 msuchanek@suse.de
- powerpc/mm: Fix lockup on kernel exec fault (bsc#1156395).
- commit b063178
* Tue Jul 20 2021 msuchanek@suse.de
- powerpc/stacktrace: Fix spurious "stale" traces in
  raise_backtrace_ipi() (bsc#1156395).
- commit f074894
* Tue Jul 20 2021 tbogendoerfer@suse.de
- gve: Introduce per netdev `enum gve_queue_format` (bsc#1176940).
- Refresh
  patches.suse/gve-Fix-an-error-handling-path-in-gve_probe.patch.
- commit fc90ec1
* Tue Jul 20 2021 tbogendoerfer@suse.de
- gve: DQO: Remove incorrect prefetch (bsc#1176940).
- gve: Simplify code and axe the use of a deprecated API
  (bsc#1176940).
- gve: Propagate error codes to caller (bsc#1176940).
- gve: DQO: Fix off by one in gve_rx_dqo() (bsc#1176940).
- gve: Fix warnings reported for DQO patchset (bsc#1176940).
- gve: DQO: Add RX path (bsc#1176940).
- gve: DQO: Add TX path (bsc#1176940).
- gve: DQO: Configure interrupts on device up (bsc#1176940).
- gve: DQO: Add ring allocation and initialization (bsc#1176940).
- gve: DQO: Add core netdev features (bsc#1176940).
- gve: Update adminq commands to support DQO queues (bsc#1176940).
- gve: Add DQO fields for core data structures (bsc#1176940).
- gve: Add dqo descriptors (bsc#1176940).
- gve: Add support for DQO RX PTYPE map (bsc#1176940).
- gve: adminq: DQO specific device descriptor logic (bsc#1176940).
- gve: Introduce a new model for device options (bsc#1176940).
- gve: Make gve_rx_slot_page_info.page_offset an absolute offset
  (bsc#1176940).
- gve: gve_rx_copy: Move padding to an argument (bsc#1176940).
- gve: Move some static functions to a common file (bsc#1176940).
- gve: Check TX QPL was actually assigned (bsc#1176940).
- net: gve: remove duplicated allowed (bsc#1176940).
- net: gve: convert strlcpy to strscpy (bsc#1176940).
- gve: Add support for raw addressing in the tx path
  (bsc#1176940).
- gve: Rx Buffer Recycling (bsc#1176940).
- gve: Add support for raw addressing to the rx path
  (bsc#1176940).
- gve: Add support for raw addressing device option (bsc#1176940).
- gve: Replace zero-length array with flexible-array member
  (bsc#1176940).
- gve: Enable Link Speed Reporting in the driver (bsc#1176940).
- gve: Use link status register to report link status
  (bsc#1176940).
- gve: Batch AQ commands for creating and destroying queues
  (bsc#1176940).
- gve: NIC stats for report-stats and for ethtool (bsc#1176940).
- gve: Add Gvnic stats AQ command and ethtool show/set-priv-flags
  (bsc#1176940).
- gve: Use dev_info/err instead of netif_info/err (bsc#1176940).
- gve: Add stats for gve (bsc#1176940).
- gve: Get and set Rx copybreak via ethtool (bsc#1176940).
- commit ffc7e3d
* Tue Jul 20 2021 mgorman@suse.de
- cpu/hotplug: Cure the cpusets trainwreck (git fixes
  (sched/hotplug)).
- commit ea5f05d
* Tue Jul 20 2021 oneukum@suse.com
- blacklist.conf: duplication
- commit eff56f7
* Tue Jul 20 2021 oneukum@suse.com
- kprobes: Fix to check probe enabled before
  disarm_kprobe_ftrace() (git-fixes).
- commit 9aba4a6
* Tue Jul 20 2021 oneukum@suse.com
- kprobes: Fix compiler warning for !CONFIG_KPROBES_ON_FTRACE
  (git-fixes).
- commit a579f68
* Tue Jul 20 2021 tiwai@suse.de
- kABI workaround for pci/quirks.c (git-fixes).
- commit 04fb196
* Tue Jul 20 2021 tiwai@suse.de
- drm/panel: nt35510: Do not fail if DSI read fails (git-fixes).
- Bluetooth: mgmt: Fix the command returns garbage parameter value
  (git-fixes).
- Bluetooth: btusb: Add support USB ALT 3 for WBS (git-fixes).
- Bluetooth: L2CAP: Fix invalid access on ECRED Connection
  response (git-fixes).
- Bluetooth: L2CAP: Fix invalid access if ECRED Reconfigure fails
  (git-fixes).
- Bluetooth: Remove spurious error message (git-fixes).
- Bluetooth: Fix alt settings for incoming SCO with transparent
  coding format (git-fixes).
- mac80211_hwsim: add concurrent channels scanning support over
  virtio (git-fixes).
- mac80211: consider per-CPU statistics if present (git-fixes).
- iwlwifi: pcie: fix context info freeing (git-fixes).
- iwlwifi: mvm: fix error print when session protection ends
  (git-fixes).
- mt76: mt7915: fix IEEE80211_HE_PHY_CAP7_MAX_NC for station mode
  (git-fixes).
- mt76: mt7615: fix fixed-rate tx status reporting (git-fixes).
- net: phy: realtek: add delay to fix RXC generation issue
  (git-fixes).
- commit 4680cad
* Tue Jul 20 2021 tiwai@suse.de
- Add a cherry-picked ID for AMDGPU fix patch
- commit ba73832
* Tue Jul 20 2021 tiwai@suse.de
- wl1251: Fix possible buffer overflow in wl1251_cmd_scan
  (git-fixes).
- wlcore/wl12xx: Fix wl12xx get_mac error if device is in ELP
  (git-fixes).
- commit e3971fc
* Tue Jul 20 2021 tiwai@suse.de
- PCI: iproc: Support multi-MSI only on uniprocessor kernel
  (git-fixes).
- PCI: iproc: Fix multi-MSI base vector number allocation
  (git-fixes).
- PCI: aardvark: Implement workaround for the readback value of
  VEND_ID (git-fixes).
- pinctrl: mcp23s08: Fix missing unlock on error in mcp23s08_irq()
  (git-fixes).
- pinctrl: mcp23s08: fix race condition in irq handler
  (git-fixes).
- pinctrl/amd: Add device HID for new AMD GPIO controller
  (git-fixes).
- wireless: wext-spy: Fix out-of-bounds warning (git-fixes).
- rtl8xxxu: Fix device info for RTL8192EU devices (git-fixes).
- r8169: avoid link-up interrupt issue on RTL8106e if user
  enables ASPM (git-fixes).
- qemu_fw_cfg: Make fw_cfg_rev_attr a proper kobj_attribute
  (git-fixes).
- commit 0ca454f
* Tue Jul 20 2021 tiwai@suse.de
- PCI: aardvark: Fix checking for PIO Non-posted Request
  (git-fixes).
- PCI: Leave Apple Thunderbolt controllers on for s2idle or
  standby (git-fixes).
- media, bpf: Do not copy more entries than user space requested
  (git-fixes).
- iwlwifi: pcie: free IML DMA memory allocation (git-fixes).
- iwlwifi: mvm: don't change band on bound PHY contexts
  (git-fixes).
- mISDN: fix possible use-after-free in HFC_cleanup() (git-fixes).
- media: uvcvideo: Fix pixel format change for Elgato Cam Link 4K
  (git-fixes).
- mmc: core: Allow UHS-I voltage switch for SDSC cards if
  supported (git-fixes).
- commit f7d13b4
* Tue Jul 20 2021 tiwai@suse.de
- drm/amdgpu: Update NV SIMD-per-CU to 2 (git-fixes).
- drm/radeon: Add the missed drm_gem_object_put() in
  radeon_user_framebuffer_create() (git-fixes).
- drm/amd/display: fix incorrrect valid irq check (git-fixes).
- drm/amdkfd: Walk through list with dqm lock hold (git-fixes).
- drm/amd/display: Verify Gamma & Degamma LUT sizes in
  amdgpu_dm_atomic_check (git-fixes).
- drm/mediatek: Fix PM reference leak in mtk_crtc_ddp_hw_init()
  (git-fixes).
- drm/amd/display: Set DISPCLK_MAX_ERRDET_CYCLES to 7 (git-fixes).
- drm/amd/display: Update scaling settings on modeset (git-fixes).
- drm/bridge: cdns: Fix PM reference leak in cdns_dsi_transfer()
  (git-fixes).
- drm/amd/display: fix use_max_lb flag for 420 pixel formats
  (git-fixes).
- commit d72cf42
* Tue Jul 20 2021 tiwai@suse.de
- drm/amd/amdgpu/sriov disable all ip hw status by default
  (git-fixes).
- drm/sched: Avoid data corruptions (git-fixes).
- drm/virtio: Fix double free on probe failure (git-fixes).
- drm/msm/mdp4: Fix modifier support enabling (git-fixes).
- drm/arm/malidp: Always list modifiers (git-fixes).
- drm/vc4: fix argument ordering in vc4_crtc_get_margins()
  (git-fixes).
- drm/zte: Don't select DRM_KMS_FB_HELPER (git-fixes).
- drm/mxsfb: Don't select DRM_KMS_FB_HELPER (git-fixes).
- drm/tegra: Don't set allow_fb_modifiers explicitly (git-fixes).
- commit b02b3f8
* Tue Jul 20 2021 tiwai@suse.de
- ASoC: tegra: Set driver_name=tegra for all machine drivers
  (git-fixes).
- clk: tegra: Ensure that PLLU configuration is applied properly
  (git-fixes).
- clk: renesas: r8a77995: Add ZA2 clock (git-fixes).
- Bluetooth: btusb: fix bt fiwmare downloading failure issue
  for qca btsoc (git-fixes).
- Bluetooth: Shutdown controller after workqueues are flushed
  or cancelled (git-fixes).
- Bluetooth: Fix the HCI to MGMT status conversion table
  (git-fixes).
- Bluetooth: btusb: Fixed too many in-token issue for Mediatek
  Chip (git-fixes).
- cw1200: add missing MODULE_DEVICE_TABLE (git-fixes).
- clocksource/arm_arch_timer: Improve Allwinner A64 timer
  workaround (git-fixes).
- commit c7cdd5b
* Tue Jul 20 2021 mbrugger@suse.com
- ARM: ensure the signal page contains defined contents (bsc#1188445).
- commit a1eecda
* Mon Jul 19 2021 oneukum@suse.com
- kprobes: fix kill kprobe which has been marked as gone
  (git-fixes).
- commit ee1820f
* Mon Jul 19 2021 oneukum@suse.com
- kprobes: Fix NULL pointer dereference at kprobe_ftrace_handler
  (git-fixes).
- commit 865421f
* Mon Jul 19 2021 oneukum@suse.com
- kprobes: Do not expose probe addresses to non-CAP_SYSLOG
  (git-fixes).
- commit e2cb2ae
* Mon Jul 19 2021 denis.kirjanov@suse.com
- net: atlantic: fix ip dst and ipv6 address filters (git-fixes).
- commit 4278aab
* Mon Jul 19 2021 msuchanek@suse.de
- Align s390 NVME target options with other architectures
  (bsc#1188404, jsc#SLE-22494).
  CONFIG_NVME_TARGET=m
  CONFIG_NVME_TARGET_PASSTHRU=y
  CONFIG_NVME_TARGET_LOOP=m
  CONFIG_NVME_TARGET_RDMA=m
  CONFIG_NVME_TARGET_FC=m
  CONFIG_NVME_TARGET_FCLOOP=m
  CONFIG_NVME_TARGET_TCP=m
- commit 5b2b9f6
* Mon Jul 19 2021 denis.kirjanov@suse.com
- net/mlx5: Don't fail driver on failure to create debugfs (git-fixes).
- commit c19d4f7
* Mon Jul 19 2021 denis.kirjanov@suse.com
- net: marvell: Fix OF_MDIO config check (git-fixes).
- commit f372318
* Mon Jul 19 2021 denis.kirjanov@suse.com
- net: dp83867: Fix OF_MDIO config check (git-fixes).
- commit c2ac3ff
* Mon Jul 19 2021 denis.kirjanov@suse.com
- net: Make PTP-specific drivers depend on PTP_1588_CLOCK (git-fixes).
- commit 0997bfc
* Mon Jul 19 2021 denis.kirjanov@suse.com
- net: phy: microchip_t1: add lan87xx_phy_init to initialize the lan87xx phy (git-fixes).
- commit 2e479b6
* Mon Jul 19 2021 oneukum@suse.com
- PCI: quirks: fix false kABI positive (git-fixes).
- commit a2a8059
* Mon Jul 19 2021 oneukum@suse.com
- tpm: efi: Use local variable for calculating final log size
  (git-fixes).
- commit 69be865
* Mon Jul 19 2021 mbenes@suse.cz
- tracing: Do not reference char * as a string in histograms
  (git-fixes).
- commit 5ff7921
* Mon Jul 19 2021 oneukum@suse.com
- PCI: iproc: Fix multi-MSI base vector number allocation
  (git-fixes).
- commit 9e70011
* Mon Jul 19 2021 oneukum@suse.com
- PCI: aardvark: Implement workaround for the readback value of
  VEND_ID (git-fixes).
- commit 4bfb1fd
* Mon Jul 19 2021 oneukum@suse.com
- PCI/sysfs: Fix dsm_label_utf16s_to_utf8s() buffer overrun
  (git-fixes).
- commit dbaa5b3
* Mon Jul 19 2021 oneukum@suse.com
- PCI: Leave Apple Thunderbolt controllers on for s2idle or
  standby (git-fixes).
- commit 900ca03
* Mon Jul 19 2021 msuchanek@suse.de
- Update patches.suse/Revert-ibmvnic-remove-duplicate-napi_schedule-call-i.patch
  (bsc#1065729 bsc#1188405 ltc#193509 bsc#1187476 ltc#193646).
- commit f55c672
* Mon Jul 19 2021 lma@suse.com
- blacklist.conf: 36fa06f9 KVM: x86: Add support for RDPID without RDTSCP
- commit db710b8
* Mon Jul 19 2021 lma@suse.com
- blacklist.conf: 8aec21c0 KVM: VMX: Do not advertise RDPID if ENABLE_RDTSCP control is unsupported
- commit 202cd1e
* Sun Jul 18 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline, drop Git-repo:
  patches.suse/bpftool-Properly-close-va_list-ap-by-va_end-on-error.patch
- commit ec7585c
* Sun Jul 18 2021 mkubecek@suse.cz
- Update kabi files.
- update from second July 2021 maintenance update submission (commit 44308a6ad508)
- commit ee121a0
* Sun Jul 18 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/0003-amdgpu-fix-GEM-obj-leak-in-amdgpu_display_user_frame.patch.
  Drop _unlocked
- commit 942b7a3
* Sun Jul 18 2021 tiwai@suse.de
- fbmem: Do not delete the mode that is still in use (git-fixes).
- dma-buf/sync_file: Don't leak fences on merge failure
  (git-fixes).
- fbmem: add margin check to fb_check_caps() (git-fixes).
- commit 1116a4b
* Fri Jul 16 2021 msuchanek@suse.de
- Update patches.suse/Revert-ibmvnic-remove-duplicate-napi_schedule-call-i.patch
  (bsc#1065729 bsc#1188405 ltc#193509).
- Update patches.suse/Revert-ibmvnic-simplify-reset_long_term_buff-functio.patch
  (bsc#1186206 ltc#191041 bsc#1188405 ltc#193509).
- commit 5fcaf8a
* Fri Jul 16 2021 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Do not install usrmerged kernel on Leap
  (boo#1184804).
- commit 5b51131
* Fri Jul 16 2021 glin@suse.com
- bpftool: Properly close va_list 'ap' by va_end() on error
  (bsc#1155518).
- libbpf: Fixes incorrect rx_ring_setup_done (bsc#1155518).
- commit a14bd1d
* Thu Jul 15 2021 martin.wilck@suse.com
- blacklist.conf: add "block: blk-mq.c: fix @at_head kernel-doc warning"
  Also removed a remnant of a merge conflict.
- commit ebd24f1
* Thu Jul 15 2021 denis.kirjanov@suse.com
- netfilter: x_tables: fix compat match/target pad out-of-bound
  write (CVE-2021-22555 bsc#1188116).
- commit 0b62bdb
* Thu Jul 15 2021 mkubecek@suse.cz
- netfilter: x_tables: fix compat match/target pad out-of-bound
  write (CVE-2021-22555 bsc#1188116).
- commit 5d3d4da
* Thu Jul 15 2021 tiwai@suse.de
- vmxnet3: fix cksum offload issues for tunnels with non-default
  udp ports (git-fixes).
- USB: cdc-acm: blacklist Heimann USB Appset device (git-fixes).
- usb: gadget: eem: fix echo command packet response issue
  (git-fixes).
- vfio/pci: Handle concurrent vma faults (git-fixes).
- [xarray] iov_iter_fault_in_readable() should do nothing in
  xarray case (git-fixes).
- ssb: sdio: Don't overwrite const buffer if block_write fails
  (git-fixes).
- commit 76c3ff9
* Thu Jul 15 2021 tiwai@suse.de
- serial_cs: Add Option International GSM-Ready 56K/ISDN modem
  (git-fixes).
- serial_cs: remove wrong GLOBETROTTER.cis entry (git-fixes).
- staging: rtl8712: remove redundant check in r871xu_drv_init
  (git-fixes).
- spi: spi-loopback-test: Fix 'tx_buf' might be 'rx_buf'
  (git-fixes).
- spi: omap-100k: Fix the length judgment problem (git-fixes).
- spi: spi-topcliff-pch: Fix potential double free in
  pch_spi_process_messages() (git-fixes).
- spi: Make of_register_spi_device also set the fwnode
  (git-fixes).
- regulator: da9052: Ensure enough delay time for
  .set_voltage_time_sel (git-fixes).
- regulator: uniphier: Add missing MODULE_DEVICE_TABLE
  (git-fixes).
- commit a2b1a60
* Thu Jul 15 2021 tiwai@suse.de
- platform/x86: toshiba_acpi: Fix missing error code in
  toshiba_acpi_setup_keyboard() (git-fixes).
- random32: Fix implicit truncation warning in
  prandom_seed_state() (git-fixes).
- media: Fix Media Controller API config checks (git-fixes).
- media: imx-csi: Skip first few frames from a BT.656 source
  (git-fixes).
- media: siano: fix device register error path (git-fixes).
- media: dvb_net: avoid speculation from net slot (git-fixes).
- media: dvd_usb: memory leak in cinergyt2_fe_attach (git-fixes).
- mmc: via-sdmmc: add a check against NULL pointer dereference
  (git-fixes).
- mmc: sdhci-sprd: use sdhci_sprd_writew (git-fixes).
- memstick: rtsx_usb_ms: fix UAF (git-fixes).
- commit 0eb2f6b
* Thu Jul 15 2021 tiwai@suse.de
- media: st-hva: Fix potential NULL pointer dereferences
  (git-fixes).
- media: bt8xx: Fix a missing check bug in bt878_probe
  (git-fixes).
- media: v4l2-core: Avoid the dangling pointer in v4l2_fh_release
  (git-fixes).
- media: em28xx: Fix possible memory leak of em28xx struct
  (git-fixes).
- media: imx: imx7_mipi_csis: Fix logging of only error event
  counters (git-fixes).
- media: pvrusb2: fix warning in pvr2_i2c_core_done (git-fixes).
- media: cobalt: fix race condition in setting HPD (git-fixes).
- media: cpia2: fix memory leak in cpia2_usb_probe (git-fixes).
- media: sti: fix obj-$(config) targets (git-fixes).
- media: exynos-gsc: fix pm_runtime_get_sync() usage count
  (git-fixes).
- commit ba1b2bc
* Thu Jul 15 2021 tiwai@suse.de
- iio: adc: at91-sama5d2: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: accel: mxc4005: Fix overread of data and alignment issue
  (git-fixes).
- lib: vsprintf: Fix handling of number field widths in vsscanf
  (git-fixes).
- media: sti/bdisp: fix pm_runtime_get_sync() usage count
  (git-fixes).
- media: s5p-jpeg: fix pm_runtime_get_sync() usage count
  (git-fixes).
- media: mtk-vcodec: fix PM runtime get logic (git-fixes).
- media: sh_vou: fix pm_runtime_get_sync() usage count
  (git-fixes).
- media: mdk-mdp: fix pm_runtime_get_sync() usage count
  (git-fixes).
- iio: at91-sama5d2_adc: remove usage of iio_priv_to_dev() helper
  (git-fixes).
- iio:accel:mxc4005: Drop unnecessary explicit casts in
  regmap_bulk_read calls (git-fixes).
- commit 74c2c06
* Thu Jul 15 2021 tiwai@suse.de
- gve: Fix an error handling path in 'gve_probe()' (git-fixes).
- fm10k: Fix an error handling path in 'fm10k_probe()'
  (git-fixes).
- HID: do not use down_interruptible() when unbinding devices
  (git-fixes).
- HID: wacom: Correct base usage for capacitive ExpressKey status
  bits (git-fixes).
- crypto: omap-sham - Fix PM reference leak in omap sham ops
  (git-fixes).
- crypto: nitrox - fix unchecked variable in
  nitrox_register_interrupts (git-fixes).
- hwrng: exynos - Fix runtime PM imbalance on error (git-fixes).
- hwmon: (max31790) Fix pwmX_enable attributes (git-fixes).
- hwmon: (max31790) Report correct current pwm duty cycles
  (git-fixes).
- commit ac66984
* Thu Jul 15 2021 tiwai@suse.de
- ALSA: usb-audio: scarlett2: Fix wrong resume call (git-fixes).
- ALSA: hda/realtek: Fix bass speaker DAC mapping for Asus UM431D
  (git-fixes).
- ath9k: Fix kernel NULL pointer dereference during
  ath_reset_internal() (git-fixes).
- clocksource: Retry clock read if long delays detected
  (git-fixes).
- crypto: qat - remove unused macro in FW loader (git-fixes).
- crypto: qat - check return code of qat_hal_rd_rel_reg()
  (git-fixes).
- crypto: ccp - Fix a resource leak in an error handling path
  (git-fixes).
- crypto: ux500 - Fix error return code in hash_hw_final()
  (git-fixes).
- crypto: nx - add missing MODULE_DEVICE_TABLE (git-fixes).
- crypto: ixp4xx - dma_unmap the correct address (git-fixes).
- commit fcdd7a0
* Thu Jul 15 2021 tiwai@suse.de
- ALSA: hda/realtek: Add another ALC236 variant support
  (git-fixes).
- ALSA: usb-audio: fix rate on Ozone Z90 USB headset (git-fixes).
- ACPI: bus: Call kobject_put() in acpi_init() error path
  (git-fixes).
- ACPI: EC: Make more Asus laptops use ECDT _GPE (git-fixes).
- ACPI: resources: Add checks for ACPI IRQ override (git-fixes).
- ACPI: processor idle: Fix up C-state latency if not ordered
  (git-fixes).
- ACPICA: Fix memory leak caused by _CID repair function
  (git-fixes).
- commit 930000b
* Wed Jul 14 2021 denis.kirjanov@suse.com
- seq_file: Disallow extremely large seq buffer allocations
  (bsc#1188062, CVE-2021-33909).
- commit fe01024
* Wed Jul 14 2021 tiwai@suse.de
- thermal/drivers/int340x/processor_thermal: Fix tcc setting
  (git-fixes).
- commit c7a1614
* Wed Jul 14 2021 tiwai@suse.de
- serial: fsl_lpuart: remove RTSCTS handling from get_mctrl()
  (git-fixes).
- serial: 8250_pci: Add support for new HPE serial device
  (git-fixes).
- commit bdbeac7
* Wed Jul 14 2021 tiwai@suse.de
- PCI: tegra194: Fix tegra_pcie_ep_raise_msi_irq() ill-defined
  shift (git-fixes).
- PCI: intel-gw: Fix INTx enable (git-fixes).
- rtw88: 8822c: fix lc calibration timing (git-fixes).
- commit 27f2c49
* Wed Jul 14 2021 tiwai@suse.de
- leds: class: The -ENOTSUPP should never be seen by user space
  (git-fixes).
- mac80211: reset profile_periodicity/ema_ap (git-fixes).
- i2c: designware: Adjust bus_freq_hz when refuse high speed
  mode set (git-fixes).
- net: phy: fix save wrong speed and duplex problem if autoneg
  is on (git-fixes).
- net: phy: microchip_t1: add lan87xx_phy_init to initialize
  the lan87xx phy (git-fixes).
- commit 3654173
* Wed Jul 14 2021 denis.kirjanov@suse.com
- blacklist.conf: update blacklist
- commit 36a2250
* Wed Jul 14 2021 denis.kirjanov@suse.com
- usb: dwc3: Fix debugfs creation flow (git-fixes).
- commit dc4de14
* Wed Jul 14 2021 tiwai@suse.de
- Revert "drm: add a locked version of drm_is_current_master"
  (git-fixes).
- commit 299bede
* Wed Jul 14 2021 tiwai@suse.de
- drm/i915/display: Do not zero past infoframes.vsc (git-fixes).
- drm/msm: Fix error return code in msm_drm_init() (git-fixes).
- drm/dp_mst: Do not set proposed vcpi directly (git-fixes).
- drm/vc4: hdmi: Fix error path of hpd-gpios (git-fixes).
- drm/rockchip: cdn-dp: fix sign extension on an int multiply
  for a u64 result (git-fixes).
- drm/rockchip: lvds: Fix an error handling path (git-fixes).
- drm: rockchip: set alpha_en to 0 if it is not used (git-fixes).
- drm/vc4: hdmi: Prevent clock unbalance (git-fixes).
- drm/vc4: crtc: Skip the TXP (git-fixes).
- drm/vc4: txp: Properly set the possible_crtcs mask (git-fixes).
- drm/amd/display: Fix build warnings (git-fixes).
- drm/amd/dc: Fix a missing check bug in dm_dp_mst_detect()
  (git-fixes).
- drm/vmwgfx: Fix cpu updates of coherent multisample surfaces
  (git-fixes).
- drm/vmwgfx: Mark a surface gpu-dirty after the
  SVGA3dCmdDXGenMips command (git-fixes).
- drm: bridge: add missing word in Analogix help text (git-fixes).
- drm/bridge: Fix the stop condition of
  drm_bridge_chain_pre_enable() (git-fixes).
- drm/bridge/sii8620: fix dependency on extcon (git-fixes).
- drm/i915/selftests: use vma_lookup() in __igt_mmap()
  (git-fixes).
- commit 92278ad
* Wed Jul 14 2021 denis.kirjanov@suse.com
- blacklist.conf: update blacklist
- commit 6b0f6b8
* Wed Jul 14 2021 tiwai@suse.de
- clk: imx8mq: remove SYS PLL 1/2 clock gates (git-fixes).
- Bluetooth: hci_qca: fix potential GPF (git-fixes).
- cw1200: Revert unnecessary patches that fix unreal
  use-after-free bugs (git-fixes).
- brcmfmac: Fix a double-free in brcmf_sdio_bus_reset (git-fixes).
- drm/nouveau: fix dma_address check for CPU/GPU sync (git-fixes).
- drm/amdgpu: wait for moving fence after pinning (git-fixes).
- drm: add a locked version of drm_is_current_master (git-fixes).
- commit 41694a6
* Wed Jul 14 2021 tiwai@suse.de
- kABI compatibility fix for max98373_priv struct (git-fixes).
- commit 9bfc21b
* Wed Jul 14 2021 tiwai@suse.de
- ASoC: SOF: loader: Use snd_sof_dsp_block_read() instead
  sof_block_read() (git-fixes).
- ASoC: rk3328: fix missing clk_disable_unprepare() on error in
  rk3328_platform_probe() (git-fixes).
- ASoC: rt5682: Disable irq on shutdown (git-fixes).
- ASoC: fsl_spdif: Fix unexpected interrupt after suspend
  (git-fixes).
- ASoC: fsl_spdif: Fix error handler with pm_runtime_enable
  (git-fixes).
- ASoC: rt715-sdw: use first_hw_init flag on resume (git-fixes).
- ASoC: rt711-sdw: use first_hw_init flag on resume (git-fixes).
- ASoC: rt700-sdw: use first_hw_init flag on resume (git-fixes).
- ASoC: rt5682-sdw: use first_hw_init flag on resume (git-fixes).
- ASoC: rt1308-sdw: use first_hw_init flag on resume (git-fixes).
- ASoC: max98373-sdw: use first_hw_init flag on resume
  (git-fixes).
- ASoC: max98373-sdw: add missing memory allocation check
  (git-fixes).
- commit 5211f08
* Wed Jul 14 2021 tiwai@suse.de
- ALSA: usb-audio: Fix OOB access at proc output (git-fixes).
- ALSA: firewire-motu: fix stream format for MOTU 8pre FireWire
  (git-fixes).
- commit 0a94859
* Wed Jul 14 2021 tiwai@suse.de
- Blacklist already cherry-picked ASoC commits
- commit 5cc6c21
* Wed Jul 14 2021 oneukum@suse.com
- usb: gadget: f_fs: Fix setting of device and driver data
  cross-references (git-fixes).
- commit 8174fed
* Wed Jul 14 2021 oneukum@suse.com
- vfs: Convert functionfs to use the new mount API (git -fixes).
- commit bc4a6d0
* Wed Jul 14 2021 mgorman@suse.de
- mm, futex: fix shared futex pgoff on shmem huge page (git fixes
  (kernel/futex)).
- commit b5af159
* Tue Jul 13 2021 jeffm@suse.com
- Update Patch-mainline tags for patches that landed in 5.14-rc1.
- commit b2d9bab
* Tue Jul 13 2021 oneukum@suse.com
- thunderbolt: Bond lanes only when dual_link_port != NULL in
  alloc_dev_default() (git-fixes).
- commit a8440fd
* Tue Jul 13 2021 oneukum@suse.com
- usb: typec: fusb302: fix "op-sink-microwatt" default that was
  in mW (git-fixes).
- commit dcf2645
* Tue Jul 13 2021 lhenriques@suse.de
- fuse: reject internal errno (bsc#1188269).
- fuse: check connected before queueing on fpq->io (bsc#1188267).
- fuse: ignore PG_workingset after stealing (bsc#1188268).
- commit ad3c8af
* Tue Jul 13 2021 oneukum@suse.com
- kABI: restore struct tcpc_config definition (git-fixes).
- commit af96f3e
* Tue Jul 13 2021 oneukum@suse.com
- media: v4l2-async: Fix trivial documentation typo (git-fixes).
- commit a677fa5
* Mon Jul 12 2021 mbenes@suse.cz
- tracing/histograms: Fix parsing of "sym-offset" modifier
  (git-fixes).
- commit e43cdf6
* Mon Jul 12 2021 oneukum@suse.com
- usb: typec: fusb302: Always provide fwnode for the port
  (git-fixes).
- commit 23df3ab
* Mon Jul 12 2021 ykaukab@suse.de
- math: Export mul_u64_u64_div_u64 (git-fixes).
- commit 3708119
* Mon Jul 12 2021 ykaukab@suse.de
- PCI: tegra194: Fix tegra_pcie_ep_raise_msi_irq() ill-defined
  shift (git-fixes).
- PCI: intel-gw: Fix INTx enable (git-fixes).
- serial: fsl_lpuart: remove RTSCTS handling from get_mctrl()
  (git-fixes).
- coresight: Propagate symlink failure (git-fixes).
- coresight: core: Fix use of uninitialized pointer (git-fixes).
- commit 0c46818
* Mon Jul 12 2021 tiwai@suse.de
- rtc: stm32: Fix unbalanced clk_disable_unprepare() on probe
  error path (git-fixes).
- rtc: fix snprintf() checking in is_rtc_hctosys() (git-fixes).
- thermal/drivers/rcar_gen3_thermal: Fix coefficient calculations
  (git-fixes).
- reset: bail if try_module_get() fails (git-fixes).
- firmware: tegra: Fix error return code in tegra210_bpmp_init()
  (git-fixes).
- memory: fsl_ifc: fix leak of private memory on probe failure
  (git-fixes).
- memory: fsl_ifc: fix leak of IO mapping on probe failure
  (git-fixes).
- memory: pl353: Fix error return code in pl353_smc_probe()
  (git-fixes).
- memory: atmel-ebi: add missing of_node_put for loop iteration
  (git-fixes).
- reset: brcmstb: Add missing MODULE_DEVICE_TABLE (git-fixes).
- reset: a10sr: add missing of_match_table reference (git-fixes).
- ALSA: intel8x0: Fix breakage at ac97 clock measurement
  (git-fixes).
- ALSA: isa: Fix error return code in snd_cmi8330_probe()
  (git-fixes).
- commit 8a2377b
* Mon Jul 12 2021 ykaukab@suse.de
- memory: fsl_ifc: fix leak of private memory on probe failure
  (git-fixes).
- memory: fsl_ifc: fix leak of IO mapping on probe failure
  (git-fixes).
- commit b522bcb
* Mon Jul 12 2021 ykaukab@suse.de
- Refresh patches.suse/rtc-pcf2127-handle-timestamp-interrupts.patch.
  Switched to queued version.
- commit 1b185ef
* Sat Jul 10 2021 lyan@suse.com
- x86/kvm: Unify kvm_pv_guest_cpu_reboot() with kvm_guest_cpu_offline() (bsc#1185308).
- x86/kvm: Disable all PV features on crash (bsc#1185308).
- refresh patches.suse/0001-kvm-Reintroduce-nopvspin-kernel-parameter.patch
- x86/kvm: Unify kvm_pv_guest_cpu_reboot() with kvm_guest_cpu_offline() (bsc#1185308).
- x86/kvm: Disable all PV features on crash (bsc#1185308).
- refresh patches.suse/0001-kvm-Reintroduce-nopvspin-kernel-parameter.patch
- x86/kvm: Disable kvmclock on all CPUs on shutdown (bsc#1185308).
- x86/kvm: Teardown PV features on boot CPU as well (bsc#1185308).
- x86/kvm: Fix pr_info() for async PF setup/teardown
  (bsc#1185308).
- x86/kvm: Disable kvmclock on all CPUs on shutdown (bsc#1185308).
- x86/kvm: Teardown PV features on boot CPU as well (bsc#1185308).
- x86/kvm: Fix pr_info() for async PF setup/teardown
  (bsc#1185308).
- commit 80699a1
* Fri Jul  9 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/tracepoint-Add-tracepoint_probe_register_may_exist-for-BPF-tracing.patch
  patches.suse/tracing-Resize-tgid_map-to-pid_max-not-PID_MAX_DEFAULT.patch
  patches.suse/tracing-Simplify-fix-saved_tgids-logic.patch
- commit fa5e842
* Fri Jul  9 2021 ykaukab@suse.de
- soc: fsl: qbman: Delete useless kfree code (bsc#1188176).
- soc: fsl: qbman: Ensure device cleanup is run for kexec
  (bsc#1188176).
- commit ec1bcd7
* Fri Jul  9 2021 ykaukab@suse.de
- ptp_qoriq: fix overflow in ptp_qoriq_adjfine() u64 calcalation
  (git-fixes).
- commit d17e17c
* Fri Jul  9 2021 ykaukab@suse.de
- dpaa2-eth: fix memory leak in XDP_REDIRECT (git-fixes).
- commit 586c229
* Fri Jul  9 2021 ykaukab@suse.de
- dpaa2-eth: fix memory leak in XDP_REDIRECT (git-fixes).
- commit 3d9e50c
* Fri Jul  9 2021 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Remove zdebug define used only once.
- commit 85a9fc2
* Thu Jul  8 2021 msuchanek@suse.de
- kernel-binary.spec: Exctract s390 decompression code (jsc#SLE-17042).
- commit 7f97df2
* Thu Jul  8 2021 rgoldwyn@suse.com
- seq_file: Disallow extremely large seq buffer allocations (bsc#1188062, CVE-2021-33909).
- commit eb7ef76
* Thu Jul  8 2021 mbenes@suse.cz
- tracing: Resize tgid_map to pid_max, not PID_MAX_DEFAULT
  (git-fixes).
- commit dfc48c9
* Thu Jul  8 2021 mbenes@suse.cz
- tracing: Simplify & fix saved_tgids logic (git-fixes).
- commit c530730
* Thu Jul  8 2021 mbenes@suse.cz
- tracepoint: Add tracepoint_probe_register_may_exist() for BPF
  tracing (git-fixes).
- commit 1ab86c5
* Thu Jul  8 2021 dwagner@suse.de
- nvme: verify MNAN value if ANA is enabled (bsc#1185791).
- commit e620ef1
* Thu Jul  8 2021 ykaukab@suse.de
- spi: spi-nxp-fspi: Implement errata workaround for LS1028A (bsc#1188121).
- spi: spi-nxp-fspi: Add support for IP read only (bsc#1188121).
- spi: spi-nxp-fspi: Add ACPI support (bsc#1188121).
  Refresh:
  patches.suse/spi-spi-nxp-fspi-fix-fspi-panic-by-unexpected-interr.patch
  patches.suse/spi-spi-nxp-fspi-move-the-register-operation-after-t.patch
- spi: spi-nxp-fspi: Fix a NULL vs IS_ERR() check in probe (bsc#1188121).
  Refresh:
  patches.suse/spi-spi-nxp-fspi-fix-fspi-panic-by-unexpected-interr.patch
  patches.suse/spi-spi-nxp-fspi-move-the-register-operation-after-t.patch
- spi: spi-nxp-fspi: Enable the Octal Mode in MCR0 (bsc#1188121).
- spi: fspi: dynamically alloc AHB memory (bsc#1188121).
  Refresh:
  patches.suse/spi-spi-nxp-fspi-fix-fspi-panic-by-unexpected-interr.patch
  patches.suse/spi-spi-nxp-fspi-move-the-register-operation-after-t.patch
- spi: nxp-fspi: Use devm API to fix missed unregistration of controller (bsc#1188121).
- commit 8290109
* Thu Jul  8 2021 dwagner@suse.de
- Fix meta data in lpfc-decouple-port_template-and-vport_template.patch
- commit d9e6471
* Thu Jul  8 2021 dwagner@suse.de
- scsi: qedf: Do not put host in qedf_vport_create()
  unconditionally (bsc#1170511).
- commit 8665594
* Thu Jul  8 2021 msuchanek@suse.de
- efi/tpm: Differentiate missing and invalid final event log table
  (bsc#1188036).
- commit 8616099
* Thu Jul  8 2021 msuchanek@suse.de
- kernel-binary.spec: Fix up usrmerge for non-modular kernels.
- commit d718cd9
* Thu Jul  8 2021 hare@suse.de
- nvme-rdma: introduce nvme_rdma_sgl structure (git-fixes).
- commit 6ccb8a5
* Thu Jul  8 2021 hare@suse.de
- nvme-rdma: fix in-casule data send for chained sgls (git-fixes).
- nvme-tcp: rerun io_work if req_list is not empty (git-fixes).
- commit a286451
* Thu Jul  8 2021 tiwai@suse.de
- watchdog: aspeed: fix hardware timeout calculation (git-fixes).
- watchdog: sp805: Fix kernel doc description (git-fixes).
- gpio: AMD8111 and TQMX86 require HAS_IOPORT_MAP (git-fixes).
- commit 79058fa
* Wed Jul  7 2021 tiwai@suse.de
- extcon: max8997: Add missing modalias string (git-fixes).
- extcon: sm5502: Drop invalid register write in sm5502_reg_data
  (git-fixes).
- char: pcmcia: error out if 'num_bytes_read' is greater than
  4 in set_protocol() (git-fixes).
- backlight: lm3630a_bl: Put fwnode in error case during ->probe()
  (git-fixes).
- commit 6b8c8e1
* Wed Jul  7 2021 tiwai@suse.de
- iio: light: tcs3472: do not free unallocated IRQ (git-fixes).
- iio: prox: isl29501: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: light: vcnl4035: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: magn: rm3100: Fix alignment of buffer in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: adc: ti-ads8688: Fix alignment of buffer in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- staging: gdm724x: check for overflow in gdm_lte_netif_rx()
  (git-fixes).
- staging: gdm724x: check for buffer overflow in
  gdm_lte_multi_sdu_pkt() (git-fixes).
- fpga: machxo2-spi: Address warning about unused variable
  (git-fixes).
- extcon: intel-mrfld: Sync hardware and software state on init
  (git-fixes).
- fpga: stratix10-soc: Add missing fpga_mgr_free() call
  (git-fixes).
- commit b12d968
* Wed Jul  7 2021 tiwai@suse.de
- iio: adc: mxs-lradc: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: adc: hx711: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: ltr501: ltr501_read_ps(): add missing endianness conversion
  (git-fixes).
- iio: ltr501: ltr559: fix initialization of LTR501_ALS_CONTR
  (git-fixes).
- iio: ltr501: mark register holding upper 8 bits of ALS_DATA{0,1}
  and PS_DATA as volatile, too (git-fixes).
- iio: si1133: fix format string warnings (git-fixes).
- iio: potentiostat: lmp91000: Fix alignment of buffer in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: light: tcs3472: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: light: tcs3414: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: light: isl29125: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- commit 2299862
* Wed Jul  7 2021 tiwai@suse.de
- iio: magn: bmc150: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: magn: hmc5843: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: prox: as3935: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: prox: pulsed-light: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: prox: srf08: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: humidity: am2315: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: gyro: bmg160: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: adc: vf610: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: adc: ti-ads1015: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: accel: stk8ba50: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- commit 66bbafb
* Wed Jul  7 2021 tiwai@suse.de
- serial: mvebu-uart: correctly calculate minimal possible
  baudrate (git-fixes).
- serial: mvebu-uart: do not allow changing baudrate when uartclk
  is not available (git-fixes).
- serial: mvebu-uart: fix calculation of clock divisor
  (git-fixes).
- serial: 8250: Actually allow UPF_MAGIC_MULTIPLIER baud rates
  (git-fixes).
- serial: tegra-tcu: Reorder channel initialization (git-fixes).
- staging: rtl8712: fix memory leak in rtl871x_load_fw_cb
  (git-fixes).
- iio: accel: stk8312: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: accel: kxcjk-1013: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: accel: hid: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: accel: bma220: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: accel: bma180: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: adis16400: do not return ints in irq handlers (git-fixes).
- iio: adis_buffer: do not return ints in irq handlers
  (git-fixes).
- mmc: sdhci: Fix warning message when accessing RPMB in HS400
  mode (git-fixes).
- mmc: core: clear flags before allowing to retune (git-fixes).
- Input: hil_kbd - fix error return code in hil_dev_connect()
  (git-fixes).
- Input: usbtouchscreen - fix control-request directions
  (git-fixes).
- mtd: rawnand: marvell: add missing clk_disable_unprepare()
  on error in marvell_nfc_resume() (git-fixes).
- mtd: partitions: redboot: seek fis-index-block in the right node
  (git-fixes).
- commit a219c27
* Wed Jul  7 2021 tiwai@suse.de
- usb: dwc3: Fix debugfs creation flow (git-fixes).
- xhci: solve a double free problem while doing s4 (git-fixes).
- usb: typec: Add the missed altmode_id_remove() in
  typec_register_altmode() (git-fixes).
- usb: dwc2: Don't reset the core after setting turnaround time
  (git-fixes).
- usb: typec: wcove: Fx wrong kernel doc format (git-fixes).
- tty: nozomi: Fix the error handling path of 'nozomi_card_init()'
  (git-fixes).
- tty: nozomi: Fix a resource leak in an error handling function
  (git-fixes).
- soundwire: stream: Fix test for DP prepare complete (git-fixes).
- visorbus: fix error return code in visorchipset_init()
  (git-fixes).
- commit e666eaf
* Wed Jul  7 2021 tiwai@suse.de
- leds: ktd2692: Fix an error handling path (git-fixes).
- leds: as3645a: Fix error return code in as3645a_parse_node()
  (git-fixes).
- leds: lm3532: select regmap I2C API (git-fixes).
- ASoC: mediatek: mtk-btcvsd: Fix an error handling path in
  'mtk_btcvsd_snd_probe()' (git-fixes).
- ASoC: rsnd: tidyup loop on rsnd_adg_clk_query() (git-fixes).
- ASoC: atmel-i2s: Fix usage of capture and playback at the same
  time (git-fixes).
- ASoC: cs42l42: Correct definition of CS42L42_ADC_PDN_MASK
  (git-fixes).
- ALSA: usb-audio: scarlett2: Read mux at init time (git-fixes).
- ALSA: usb-audio: scarlett2: Read mixer volumes at init time
  (git-fixes).
- Revert "ALSA: bebob/oxfw: fix Kconfig entry for Mackie d.2 Pro"
  (git-fixes).
- commit ea3fb69
* Wed Jul  7 2021 tiwai@suse.de
- ASoC: hisilicon: fix missing clk_disable_unprepare() on error
  in hi6210_i2s_startup() (git-fixes).
- mwifiex: re-fix for unaligned accesses (git-fixes).
- lib/decompressors: remove set but not used variabled 'level'
  (git-fixes).
- clk: si5341: Update initialization magic (git-fixes).
- clk: si5341: Avoid divide errors due to bogus register contents
  (git-fixes).
- clk: actions: Fix bisp_factor_table based clocks on Owl S500
  SoC (git-fixes).
- clk: actions: Fix SD clocks factor table on Owl S500 SoC
  (git-fixes).
- clk: actions: Fix UART clock dividers on Owl S500 SoC
  (git-fixes).
- clk: zynqmp: pll: Remove some dead code (git-fixes).
- clk: meson: g12a: fix gp0 and hifi ranges (git-fixes).
- commit b4df049
* Wed Jul  7 2021 tiwai@suse.de
- clk: renesas: rcar-gen3: Update Z clock rate formula in comments
  (git-fixes).
- drm/msm/dpu: Fix error return code in dpu_mdss_init()
  (git-fixes).
- drm: qxl: ensure surf.data is ininitialized (git-fixes).
- drm/rockchip: dsi: remove extra component_del() call
  (git-fixes).
- drm/rockchip: dsi: move all lane config except LCDC mux to
  bind() (git-fixes).
- drm/rockchip: cdn-dp-core: add missing clk_disable_unprepare()
  on error in cdn_dp_grf_write() (git-fixes).
- video: fbdev: imxfb: Fix an error message (git-fixes).
- ath10k: Fix an error code in ath10k_add_interface() (git-fixes).
- commit fc44520
* Wed Jul  7 2021 tiwai@suse.de
- can: peak_pciefd: pucan_handle_status(): fix a potential
  starvation issue in TX path (git-fixes).
- can: gw: synchronize rcu operations before removing gw job entry
  (git-fixes).
- Bluetooth: Fix handling of HCI_LE_Advertising_Set_Terminated
  event (git-fixes).
- Bluetooth: mgmt: Fix slab-out-of-bounds in tlv_data_is_valid
  (git-fixes).
- ath10k: remove unused more_frags variable (git-fixes).
- ath10k: add missing error return code in ath10k_pci_probe()
  (git-fixes).
- ath10k: go to path err_unsupported when chip id is not supported
  (git-fixes).
- brcmsmac: mac80211_if: Fix a resource leak in an error handling
  path (git-fixes).
- brcmfmac: correctly report average RSSI in station info
  (git-fixes).
- brcmfmac: fix setting of station info chains bitmask
  (git-fixes).
- commit d8b0fc2
* Wed Jul  7 2021 tiwai@suse.de
- can: hi311x: hi3110_can_probe(): silence clang warning
  (git-fixes).
- drm/radeon: wait for moving fence after pinning (git-fixes).
- drm/nouveau: wait for moving fence after pinning v2 (git-fixes).
- cfg80211: call cfg80211_leave_ocb when switching away from OCB
  (git-fixes).
- dmaengine: mediatek: use GFP_NOWAIT instead of GFP_ATOMIC in
  prep_dma (git-fixes).
- dmaengine: mediatek: do not issue a new desc if one is still
  current (git-fixes).
- dmaengine: mediatek: free the proper desc in desc_free handler
  (git-fixes).
- dmaengine: rcar-dmac: Fix PM reference leak in rcar_dmac_probe()
  (git-fixes).
- dmaengine: zynqmp_dma: Fix PM reference leak in
  zynqmp_dma_alloc_chan_resourc() (git-fixes).
- commit 8be348d
* Wed Jul  7 2021 tiwai@suse.de
- gve: Fix swapped vars when fetching max queues (git-fixes).
- mac80211: remove iwlwifi specific workaround NDPs of
  null_response (git-fixes).
- mac80211: remove iwlwifi specific workaround that broke sta
  NDP tx (git-fixes).
- mt76: fix possible NULL pointer dereference in mt76_tx
  (git-fixes).
- extcon: extcon-max8997: Fix IRQ freeing at error path
  (git-fixes).
- r8169: Avoid memcpy() over-reading of ETH_SS_STATS (git-fixes).
- r8152: Avoid memcpy() over-reading of ETH_SS_STATS (git-fixes).
- mac80211_hwsim: drop pending frames on stop (git-fixes).
- mac80211: remove warning in ieee80211_get_sband() (git-fixes).
- PCI: Add AMD RS690 quirk to enable 64-bit DMA (git-fixes).
- commit c400726
* Wed Jul  7 2021 tiwai@suse.de
- wcn36xx: Move hal_buf allocation to devm_kmalloc in probe
  (git-fixes).
- wireless: carl9170: fix LEDS build errors & warnings
  (git-fixes).
- rsi: Assign beacon rate settings to the correct rate_info
  descriptor field (git-fixes).
- ssb: Fix error return code in ssb_bus_scan() (git-fixes).
- ACPI: property: Constify stubs for CONFIG_ACPI=n case
  (git-fixes).
- ACPI: APEI: fix synchronous external aborts in user-mode
  (git-fixes).
- ACPI: sysfs: Fix a buffer overrun problem with
  description_show() (git-fixes).
- cpufreq: sc520_freq: add 'fallthrough' to one case (git-fixes).
- ata: ahci_sunxi: Disable DIPM (git-fixes).
- commit 4b20cc3
* Wed Jul  7 2021 tiwai@suse.de
- media: siano: Fix out-of-bounds warnings in
  smscore_load_firmware_family2() (git-fixes).
- media: s5p-g2d: Fix a memory leak on ctx->fh.m2m_ctx
  (git-fixes).
- media: rtl28xxu: fix zero-length control request (git-fixes).
- media: gspca/sunplus: fix zero-length control requests
  (git-fixes).
- media: gspca/gl860: fix zero-length control requests
  (git-fixes).
- media: gspca/sq905: fix control-request direction (git-fixes).
- media: dtv5100: fix control-request directions (git-fixes).
- hwmon: (max31790) Fix fan speed reporting for fan7..12
  (git-fixes).
- hwmon: (max31722) Remove non-standard ACPI device IDs
  (git-fixes).
- commit 655a2af
* Wed Jul  7 2021 tiwai@suse.de
- media: zr364xx: fix memory leak in zr364xx_start_readpipe
  (git-fixes).
- media: tc358743: Fix error return code in tc358743_probe_of()
  (git-fixes).
- media: au0828: fix a NULL vs IS_ERR() check (git-fixes).
- media: exynos4-is: Fix a use after free in isp_video_release
  (git-fixes).
- media: dvb-usb: fix wrong definition (git-fixes).
- media: rc: i2c: Fix an error message (git-fixes).
- media: I2C: change 'RST' to "RSET" to fix multiple build errors
  (git-fixes).
- mmc: sdhci-esdhc-imx: remove unused is_imx6q_usdhc (git-fixes).
- mmc: vub3000: fix control-request direction (git-fixes).
- mmc: usdhi6rol0: fix error return code in usdhi6_probe()
  (git-fixes).
- commit 0231cde
* Wed Jul  7 2021 tiwai@suse.de
- spi: stm32-qspi: Remove unused qspi field of struct
  stm32_qspi_flash (git-fixes).
- spi: tegra114: Fix an error message (git-fixes).
- spi: spi-sun6i: Fix chipselect/clock bug (git-fixes).
- regulator: hi655x: Fix pass wrong pointer to config.driver_data
  (git-fixes).
- mmc: block: Disable CMDQ on the ioctl path (git-fixes).
- pinctrl: stm32: fix the reported number of GPIO lines per bank
  (git-fixes).
- i2c: robotfuzz-osif: fix control-request directions (git-fixes).
- i2c: dev: Add __user annotation (git-fixes).
- commit c37129c
* Wed Jul  7 2021 tiwai@suse.de
- can: bcm: delay release of struct bcm_op after synchronize_rcu()
  (CVE-2021-3609 bsc#1187215).
- commit a57ee2f
* Wed Jul  7 2021 tiwai@suse.de
- Input: joydev - prevent use of not validated data in
  JSIOCSBTNMAP ioctl (CVE-2021-3612 bsc#1187585).
- commit 64519f9
* Wed Jul  7 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vc4: hdmi: Move the HSM clock enable to runtime_pm'
- commit 23b3543
* Wed Jul  7 2021 tzimmermann@suse.de
- drm/vc4: hdmi: Make sure the controller is powered in detect (bsc#1152489)
  Backporting changes:
  * context changes
  * vc4_hdmi -> vc4->hdmi
- commit 84c924f
* Wed Jul  7 2021 tzimmermann@suse.de
- drm/amdgpu: Don't query CE and UE errors (bsc#1152472)
  Backporting changes:
  * unsigned long -> uint32_t
- commit 1637ecb
* Wed Jul  7 2021 tzimmermann@suse.de
- amdgpu: fix GEM obj leak in amdgpu_display_user_framebuffer_create (bsc#1152472)
  Backporting changes:
  * context changes
- commit f40c83c
* Wed Jul  7 2021 tzimmermann@suse.de
- drm/msm: Small msm_gem_purge() fix (bsc#1152489)
  Backporting changes:
  * context changes
  * GEM_WARN_ON() -> WARN_ON()
- commit f02a5b9
* Wed Jul  7 2021 tzimmermann@suse.de
- drm/radeon: Fix a missing check bug in radeon_dp_mst_detect() (bsc#1152489)
  Backporting changes:
  * context changes
- commit fee040e
* Wed Jul  7 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vc4: hdmi: Restore cec physical address on reconnect'
- commit b32f423
* Wed Jul  7 2021 jeyu@suse.de
- Update patch reference for patches.suse/module-limit-enabling-module.sig_enforce.patch
  (git-fixes, CVE-2021-35039, bsc#1188080).
- commit 8d3fd9b
* Wed Jul  7 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vc4: crtc: Reduce PV fifo threshold on hvs4'
- commit 3780e05
* Wed Jul  7 2021 msuchanek@suse.de
- tpm, tpm_tis: Reserve locality in tpm_tis_resume()
  (bsc#1188036).
- tpm, tpm_tis: Extend locality handling to TPM2 in
  tpm_tis_gen_interrupt() (bsc#1188036).
- tpm, tpm_tis: Decorate tpm_tis_gen_interrupt() with
  request_locality() (bsc#1188036).
- tpm, tpm_tis: Decorate tpm_get_timeouts() with
  request_locality() (bsc#1188036).
- commit 2c323b1
* Wed Jul  7 2021 tzimmermann@suse.de
- drm: bridge/panel: Cleanup connector on bridge detach (bsc#1152489)
  Backporting changes:
  * context changes
- commit b16ae28
* Wed Jul  7 2021 tzimmermann@suse.de
- drm/mcde/panel: Inverse misunderstood flag (bsc#1152472)
  Backporting changes:
  * only panel-samsung-s6d16d0.c exists
- commit 83514d0
* Wed Jul  7 2021 tzimmermann@suse.de
- drm/stm: Fix bus_flags handling (bsc#1152472)
- commit eaa7b7a
* Tue Jul  6 2021 oneukum@suse.com
- usb: typec: tcpm: Move
  mod_delayed_work(&port->vdm_state_machine) call into
  tcpm_queue_vdm() (git-fixes).
- Refresh
  patches.suse/usb-typec-tcpm-Refactor-tcpm_handle_vdm_request-payl.patch.
- Refresh
  patches.suse/usb-typec-tcpm-Refactor-tcpm_handle_vdm_request.patch.
- commit 25ab009
* Tue Jul  6 2021 oneukum@suse.com
- usb: typec: tcpm: Error handling for
  tcpm_register_partner_altmodes (git-fixes).
- commit d172a56
* Tue Jul  6 2021 oneukum@suse.com
- usb: typec: tcpm: move to SNK_UNATTACHED if sink removed for
  DRP (git-fixes).
- commit 44e186b
* Tue Jul  6 2021 oneukum@suse.com
- usb: typec: tcpm: set correct data role for non-DRD (git-fixes).
- commit d27b294
* Tue Jul  6 2021 oneukum@suse.com
- usb: typec: tcpm: Remove tcpc_config configuration mechanism
  (git-fixes).
- commit 20564c3
* Tue Jul  6 2021 oneukum@suse.com
- usb: typec: tcpm: Switch to use fwnode_property_count_uXX()
  (git-fixes).
- commit 69ab721
* Tue Jul  6 2021 oneukum@suse.com
- usb: typec: tcpm: Refactor tcpm_handle_vdm_request (git-fixes).
- commit b4b2308
* Tue Jul  6 2021 oneukum@suse.com
- usb: typec: tcpm: Refactor tcpm_handle_vdm_request payload
  handling (git-fixes).
- commit 9417ed4
* Tue Jul  6 2021 oneukum@suse.com
- usb: typec: ucsi: Put fwnode in any case during ->probe()
  (git-fixes).
- commit ec4c8d0
* Tue Jul  6 2021 oneukum@suse.com
- usb: typec: ucsi: Hold con->lock for the entire duration of
  ucsi_register_port() (git-fixes).
- commit 9f0dcac
* Tue Jul  6 2021 oneukum@suse.com
- usb: typec: tcpm: update power supply once partner accepts
  (git-fixes).
- commit 54348d7
* Tue Jul  6 2021 oneukum@suse.com
- docs: admin-guide: update description for kernel.hotplug sysctl
  (git-fixes).
- blacklist.conf: we do ship the kernel sources and the documentation.
  They may just as well be up to date.
- commit 7d1b971
* Tue Jul  6 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/scsi-ibmvfc-Avoid-move-login-if-fast-fail-is-enabled.patch
  patches.suse/scsi-ibmvfc-Handle-move-login-failure.patch
  patches.suse/scsi-ibmvfc-Reinit-target-retries.patch
  patches.suse/scsi-lpfc-Add-a-option-to-enable-interlocked-ABTS-be.patch
  patches.suse/scsi-lpfc-Add-ndlp-kref-accounting-for-resume-RPI-pa.patch
  patches.suse/scsi-lpfc-Fix-Node-recovery-when-driver-is-handling-.patch
  patches.suse/scsi-lpfc-Fix-Unexpected-timeout-error-in-direct-att.patch
  patches.suse/scsi-lpfc-Fix-crash-when-lpfc_sli4_hba_setup-fails-t.patch
  patches.suse/scsi-lpfc-Fix-node-handling-for-Fabric-Controller-an.patch
  patches.suse/scsi-lpfc-Fix-non-optimized-ERSP-handling.patch
  patches.suse/scsi-lpfc-Fix-unreleased-RPIs-when-NPIV-ports-are-cr.patch
  patches.suse/scsi-lpfc-Ignore-GID-FT-response-that-may-be-receive.patch
  patches.suse/scsi-lpfc-Reregister-FPIN-types-if-ELS_RDF-is-receiv.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.10.patch
  patches.suse/scsi-scsi_dh_alua-Retry-RTPG-on-a-different-path-aft.patch
- commit 9a3a833
* Tue Jul  6 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline and move to "almost mainline" section:
  patches.suse/qla2xxx-synchronize-rport-dev_loss_tmo-setting.patch
- commit 81935f9
* Mon Jul  5 2021 bp@suse.de
- blacklist.conf: 1e886090cefe docs: admin-guide: update description for kernel.hotplug sysctl
- commit 1332420
* Mon Jul  5 2021 bp@suse.de
- x86/elf: Use _BITUL() macro in UAPI headers (bsc#1178134).
- commit 5b8c19e
* Mon Jul  5 2021 bp@suse.de
- blacklist.conf: 89f5f8fb5bf4 EDAC/thunderx: Remove irrelevant variable from error messages
- commit 7c3f543
* Fri Jul  2 2021 bp@suse.de
- blacklist.conf: d8778e393afa x86/fpu: Invalidate FPU state after a failed XRSTOR from a user buffer
- commit 07e7bbd
* Fri Jul  2 2021 bp@suse.de
- x86/pkru: Write hardware init value to PKRU when xstate is init
  (bsc#1152489).
- commit 05b202a
* Fri Jul  2 2021 lduncan@suse.com
- scsi: ufs: ufshcd-pltfrm depends on HAS_IOMEM (bsc#1187980).
- commit bc82289
* Fri Jul  2 2021 mkoutny@suse.com
- cgroup1: don't allow '\n' in renaming (bsc#1187972).
- commit 31d330a
* Fri Jul  2 2021 dwagner@suse.de
- qla2xxx: synchronize rport dev_loss_tmo setting (bsc#1182470
  bsc#1185486).
- commit 8249f86
* Fri Jul  2 2021 glin@suse.com
- bpf: Fix integer overflow in argument calculation for
  bpf_map_area_alloc (bsc#1177028).
- bpf: Fix libelf endian handling in resolv_btfids (bsc#1177028).
- commit f52fc7f
* Thu Jul  1 2021 bp@suse.de
- x86/process: Check PF_KTHREAD and not current->mm for kernel
  threads (bsc#1152489).
- commit f14058e
* Thu Jul  1 2021 bp@suse.de
- x86/fpu: Preserve supervisor states in
  sanitize_restored_user_xstate() (bsc#1178134).
- commit 8de1b90
* Thu Jul  1 2021 msuchanek@suse.de
- kernel-binary.spec: Remove obsolete and wrong comment
  mkmakefile is repleced by echo on newer kernel
- commit d9209e7
* Thu Jul  1 2021 lhenriques@suse.de
- ceph: must hold snap_rwsem when filling inode for async create
  (bsc#1187927).
- commit 288e232
* Thu Jul  1 2021 msuchanek@suse.de
- ibmvnic: Use strscpy() instead of strncpy() (bsc#1184114
  ltc#192237).
- ibmvnic: fix send_request_map incompatible argument (bsc#1184114
  ltc#192237).
- ibmvnic: fix kernel build warnings in build_hdr_descs_arr
  (bsc#1184114 ltc#192237).
- ibmvnic: fix kernel build warning (bsc#1184114 ltc#192237).
- ibmvnic: fix kernel build warning in strncpy (bsc#1184114
  ltc#192237).
- ibmvnic: Allow device probe if the device is not ready at boot
  (bsc#1184114 ltc#192237).
- ibmvnic: Use list_for_each_entry() to simplify code in ibmvnic.c
  (bsc#1184114 ltc#192237).
- commit 6f12df4
* Thu Jul  1 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/Revert-ibmvnic-simplify-reset_long_term_buff-functio.patch
- commit dc51831
* Thu Jul  1 2021 tbogendoerfer@suse.de
- Update
  patches.suse/RDMA-ucma-Rework-ucma_migrate_id-to-avoid-races-with.patch
  (bsc#1181147 bsc#1187050 CVE-2020-36385).
  Added CVE reference.
- commit f7b3ebb
* Thu Jul  1 2021 msuchanek@suse.de
- ibmvnic: account for bufs already saved in indir_buf
  (jsc#SLE-17268 jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: clean pending indirect buffs during reset
  (jsc#SLE-17268 jsc#SLE-17043 bsc#1179243 ltc#189290).
- commit 4925dab
* Thu Jul  1 2021 mkubecek@suse.cz
- fix patch metadata
- fix upstream reference:
  patches.suse/bpfilter-Specify-the-log-level-for-the-kmsg-message.patch
- commit 4e6fe72
* Thu Jul  1 2021 msuchanek@suse.de
- ibmvnic: free tx_pool if tso_pool alloc fails (bsc#1085224
  ltc#164363).
- commit badd4e0
* Thu Jul  1 2021 denis.kirjanov@suse.com
- perf/x86/intel/uncore: Fix a kernel WARNING triggered by
  maxcpus=1 (git-fixes).
- commit 9602802
* Thu Jul  1 2021 msuchanek@suse.de
- ibmvnic: parenthesize a check (bsc#1184114 ltc#192237
  bsc#1183871 ltc#192139 git-fixes).
- ibmvnic: set ltb->buff to NULL after freeing (bsc#1094840
  ltc#167098).
- Revert "ibmvnic: remove duplicate napi_schedule call in open
  function" (bsc#1065729).
- commit e5fa23c
* Thu Jul  1 2021 denis.kirjanov@suse.com
- SUNRPC: Handle major timeout in xprt_adjust_timeout()
  (git-fixes).
- Refresh
  patches.suse/0001-ipmi-watchdog-Stop-watchdog-timer-when-the-current-a.patch.
- Refresh
  patches.suse/block-return-the-correct-bvec-when-checking-for-gaps.patch.
- Refresh
  patches.suse/ibmvnic-remove-default-label-from-to_string-switch.patch.
- commit bff6126
* Thu Jul  1 2021 denis.kirjanov@suse.com
- nvmem: rmem: fix undefined reference to memremap (git-fixes).
- commit 420be35
* Thu Jul  1 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/0001-ipmi-watchdog-Stop-watchdog-timer-when-the-current-a.patch
  patches.suse/block-return-the-correct-bvec-when-checking-for-gaps.patch
  patches.suse/ibmvnic-remove-default-label-from-to_string-switch.patch
  patches.suse/xfrm-policy-Read-seqcount-outside-of-rcu-read-side-i.patch
- commit fc2830a
* Thu Jul  1 2021 glin@suse.com
- bpfilter: Specify the log level for the kmsg message
  (bsc#1155518).
- commit a6b5aff
* Wed Jun 30 2021 lduncan@suse.com
- Blacklisted SCSI ufs core patch: way out of context.
- commit 33b89f4
* Wed Jun 30 2021 lduncan@suse.com
- FCOE: fcoe_wwn_from_mac kABI fix (bsc#1187886).
- scsi: fcoe: Fix mismatched fcoe_wwn_from_mac declaration
  (bsc#1187886).
- commit bf3226e
* Wed Jun 30 2021 lduncan@suse.com
- Blacklisted libsas new gfp variant patches
- commit 7d45a44
* Wed Jun 30 2021 lduncan@suse.com
- scsi: core: Fix race between handling STS_RESOURCE and
  completion (bsc#1187883).
- Refresh
  patches.suse/scsi_dh_alua-return-BLK_STS_AGAIN-for-ALUA-transitio.patch.
- commit 1a66f28
* Wed Jun 30 2021 lduncan@suse.com
- Blacklisted scsi commit that should be skipped.
- commit 6c0722b
* Wed Jun 30 2021 pmladek@suse.com
- kthread: prevent deadlock when kthread_mod_delayed_work()
  races with kthread_cancel_delayed_work_sync() (bsc#1187867).
- commit 4323f85
* Wed Jun 30 2021 pmladek@suse.com
- kthread_worker: split code for canceling the delayed work timer
  (bsc#1187867).
- commit f950430
* Wed Jun 30 2021 jack@suse.cz
- dax: fix ENOMEM handling in grab_mapping_entry() (bsc#1184212).
- commit fa16d18
* Wed Jun 30 2021 msuchanek@suse.de
- Revert "ibmvnic: simplify reset_long_term_buff function"
  (bsc#1186206 ltc#191041).
- commit ae5a395
* Tue Jun 29 2021 lduncan@suse.com
- SCSI: ufs: fix ktime_t kabi change (bsc#1187795).
- scsi: ufs: Fix imprecise load calculation in devfreq window
  (bsc#1187795).
- commit 51e8b33
* Tue Jun 29 2021 lduncan@suse.com
- Blacklisted commit already removed, to keep it away
- commit 2ac8cfe
* Tue Jun 29 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/shmem-helpers: vunmap: Don't put pages for dma-buf'
- commit 4f0b109
* Mon Jun 28 2021 mbenes@suse.cz
- s390/stack: fix possible register corruption with stack switch
  helper (bsc#1185677).
- commit d57c991
* Mon Jun 28 2021 msuchanek@suse.de
- powerpc/perf: Fix crash in perf_instruction_pointer() when ppmu
  is not set (jsc#SLE-13513 bsc#1176919 ltc#186162 git-fixes).
- commit 8cc69d2
* Mon Jun 28 2021 tzimmermann@suse.de
- Revert "video: imsttfb: fix potential NULL pointer dereferences" (bsc#1152489)
- commit cb44bac
* Fri Jun 25 2021 msuchanek@suse.de
- Revert "Update config files (bsc#1187167)" (bsc#1187711).
  The key is needed. When a random key is generaeted it is a problem with
  OBS repository setup. OBS should provide a signing key.
- commit b53af95
* Fri Jun 25 2021 ptesarik@suse.cz
- s390/dasd: add missing discipline function (git-fixes).
- commit ea8d00e
* Fri Jun 25 2021 ptesarik@suse.cz
- kernel: kexec_file: fix error return code of
  kexec_calculate_store_digests() (git-fixes).
- commit c886494
* Fri Jun 25 2021 tiwai@suse.de
- drm/vc4: hdmi: Make sure the controller is powered in detect
  (git-fixes).
- drm/vc4: hdmi: Move the HSM clock enable to runtime_pm
  (git-fixes).
- commit 20bb391
* Fri Jun 25 2021 tiwai@suse.de
- blacklist.conf: Add amdgpu entries that have been reverted (git-fixes)
- commit 41610da
* Fri Jun 25 2021 tiwai@suse.de
- mmc: meson-gx: use memcpy_to/fromio for dram-access-quirk
  (git-fixes).
- commit c1d2306
* Thu Jun 24 2021 lduncan@suse.com
- Removed patch that was incorrectly added to SLE15-SP2 (bsc#1186949)
  This patch was suggested as a git-fix for SLE15-SP2, but the
  commits it fixes are not present there.
- commit fc1818c
* Thu Jun 24 2021 tbogendoerfer@suse.de
- bnxt_en: Call bnxt_ethtool_free() in bnxt_init_one() error path
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix TQM fastpath ring backing store computation
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Rediscover PHY capabilities after firmware reset
  (jsc#SLE-8371 bsc#1153274).
- cxgb4: fix wrong shift (git-fixes).
- be2net: Fix an error handling path in 'be_probe()' (git-fixes).
- netxen_nic: Fix an error handling path in 'netxen_nic_probe()'
  (git-fixes).
- qlcnic: Fix an error handling path in 'qlcnic_probe()'
  (git-fixes).
- net/mlx5e: Block offload of outer header csum for UDP tunnels
  (git-fixes).
- net/mlx5: Consider RoCE cap before init RDMA resources
  (git-fixes).
- net/mlx5e: Fix page reclaim for dead peer hairpin (git-fixes).
- net/mlx5e: Remove dependency in IPsec initialization flows
  (git-fixes).
- ice: add ndo_bpf callback for safe mode netdev ops
  (jsc#SLE-7926).
- net/sched: act_ct: handle DNAT tuple collision (bsc#1154353).
- vrf: fix maximum MTU (git-fixes).
- net/mlx5: Fix PBMC register mapping (git-fixes).
- net/mlx5: Fix placement of log_max_flow_counter (git-fixes).
- net/mlx5: Fix sleep while atomic in mlx5_eswitch_get_vepa
  (git-fixes).
- commit 060a647
* Thu Jun 24 2021 tbogendoerfer@suse.de
- net/mlx5: Reset mkey index on creation (jsc#SLE-15172).
- net/mlx5: E-Switch, Allow setting GUID for host PF vport
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Read PF mac address (jsc#SLE-15172).
- cxgb4: fix wrong ethtool n-tuple rule lookup (jsc#SLE-15131).
- ethtool: strset: fix message length calculation (bsc#1176447).
- cxgb4: halt chip before flashing PHY firmware image
  (jsc#SLE-15131).
- cxgb4: fix sleep in atomic when flashing PHY firmware
  (jsc#SLE-15131).
- cxgb4: fix endianness when flashing boot image (jsc#SLE-15131).
- ice: parameterize functions responsible for Tx ring management
  (jsc#SLE-12878).
- mlxsw: reg: Spectrum-3: Enforce lowest max-shaper burst size
  of 11 (bsc#1176774).
- commit 3e01284
* Thu Jun 24 2021 tiwai@suse.de
- drm/sun4i: dw-hdmi: Make HDMI PHY into a platform device
  (git-fixes).
- ASoC: rt5682: Fix the fast discharge for headset unplugging
  in soundwire mode (git-fixes).
- ASoC: tas2562: Fix TDM_CFG0_SAMPRATE values (git-fixes).
- ASoC: fsl-asoc-card: Set .owner attribute when registering card
  (git-fixes).
- commit af36159
* Thu Jun 24 2021 tiwai@suse.de
- PCI: aardvark: Fix kernel panic during PIO transfer (git-fixes).
- commit ce71c77
* Thu Jun 24 2021 tiwai@suse.de
- PCI: aardvark: Don't rely on jiffies while holding spinlock
  (git-fixes).
- commit 1bd7ff7
* Thu Jun 24 2021 tiwai@suse.de
- spi: spi-nxp-fspi: move the register operation after the clock
  enable (git-fixes).
- Revert "PCI: PM: Do not read power state in
  pci_enable_device_flags()" (git-fixes).
- PCI: Add ACS quirk for Broadcom BCM57414 NIC (git-fixes).
- radeon: use memcpy_to/fromio for UVD fw upload (git-fixes).
- spi: stm32-qspi: Always wait BUSY bit to be cleared in
  stm32_qspi_wait_cmd() (git-fixes).
- regulator: bd70528: Fix off-by-one for buck123 .n_voltages
  setting (git-fixes).
- commit 8ac9ce3
* Thu Jun 24 2021 tiwai@suse.de
- cfg80211: make certificate generation more robust (git-fixes).
- PCI: Work around Huawei Intelligent NIC VF FLR erratum
  (git-fixes).
- PCI: Mark some NVIDIA GPUs to avoid bus reset (git-fixes).
- PCI: Mark TI C667X to avoid bus reset (git-fixes).
- ASoC: rt5659: Fix the lost powers for the HDA header
  (git-fixes).
- hwmon: (scpi-hwmon) shows the negative temperature properly
  (git-fixes).
- commit ed194e5
* Wed Jun 23 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/NFS-Fix-a-potential-NULL-dereference-in-nfs_get_clie.patch
  patches.suse/NFS-Fix-use-after-free-in-nfs4_init_client.patch
  patches.suse/NFSv4-Fix-deadlock-between-nfs4_evict_inode-and-nfs4.patch
  patches.suse/SUNRPC-Handle-major-timeout-in-xprt_adjust_timeout.patch
- commit e5e0666
* Wed Jun 23 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/xfrm-policy-Read-seqcount-outside-of-rcu-read-side-i.patch
- commit cafffbc
* Wed Jun 23 2021 tiwai@suse.de
- video: hgafb: correctly handle card detect failure during probe
  (git-fixes).
- commit 55f7ec7
* Wed Jun 23 2021 tiwai@suse.de
- Bluetooth: use correct lock to prevent UAF of hdev object
  (git-fixes).
- video: hgafb: fix potential NULL pointer dereference
  (git-fixes).
- Revert "video: hgafb: fix potential NULL pointer dereference"
  (git-fixes).
- commit 83627e7
* Wed Jun 23 2021 tiwai@suse.de
- dmaengine: fsl-dpaa2-qdma: Fix error return code in two
  functions (git-fixes).
- drm/amd/amdgpu:save psp ring wptr to avoid attack (git-fixes).
- drm/amd/display: Fix potential memory leak in DMUB hw_init
  (git-fixes).
- drm/amdgpu: refine amdgpu_fru_get_product_info (git-fixes).
- Bluetooth: Add a new USB ID for RTL8822CE (git-fixes).
- commit d18513c
* Wed Jun 23 2021 jeyu@suse.de
- module: limit enabling module.sig_enforce (git-fixes).
- commit 7f30f5d
* Wed Jun 23 2021 schwab@suse.de
- Add dtb-microchip
- commit c797107
* Wed Jun 23 2021 acho@suse.com
- Bluetooth: use correct lock to prevent UAF of hdev object
  (bsc#1186666 CVE-2021-3573).
- commit 6781ea8
* Wed Jun 23 2021 neilb@suse.de
- blacklist.conf: Add unwanted commits
- commit 1da6dbc
* Wed Jun 23 2021 neilb@suse.de
- NFSv4: Fix deadlock between nfs4_evict_inode() and
  nfs4_opendata_get_inode() (git-fixes).
- NFS: Fix a potential NULL dereference in nfs_get_client()
  (git-fixes).
- NFS: Fix use-after-free in nfs4_init_client() (git-fixes).
- commit 3478e99
* Tue Jun 22 2021 mwilck@suse.com
- blk-mq: Rerun dispatching in the case of budget contention
  (bsc#1180092).
- blk-mq: Add blk_mq_delay_run_hw_queues() API call (bsc#1180092).
- blk-mq: In blk_mq_dispatch_rq_list() "no budget" is a reason
  to kick (bsc#1180092).
- commit e31a7fc
* Tue Jun 22 2021 mwilck@suse.com
- blk-mq: Put driver tag in blk_mq_dispatch_rq_list() when no
  budget (bsc#1180092).
- commit ccd1ac3
* Tue Jun 22 2021 mwilck@suse.com
- blk-mq: insert flush request to the front of dispatch queue
  (bsc#1180092).
- commit acc744b
* Tue Jun 22 2021 mwilck@suse.com
- blk-mq: insert passthrough request into hctx->dispatch directly
  (bsc#1180092).
- Refresh
  patches.suse/blk-mq-call-commit_rqs-while-list-empty-but-error-ha.patch.
- Refresh
  patches.suse/blk-mq-insert-request-not-through-queue_rq-into-sw-s.patch.
- commit 4ba4b0f
* Tue Jun 22 2021 ohering@suse.de
- lib: vdso: Remove CROSS_COMPILE_COMPAT_VDSO (bsc#1164648,jsc#SLE-11493).
  Reduce delta to mainline
  Refresh patches.suse/lib-vdso-Prepare-for-time-namespace-support.patch.
- commit 7b06299
* Tue Jun 22 2021 tiwai@suse.de
- Update patch reference for net keys fix (CVE-2021-0605 bsc#1187601)
- commit 7bb3e99
* Tue Jun 22 2021 tiwai@suse.de
- Update patch reference for HID security fix (CVE-2021-0512 bsc#1187595)
- commit 0506954
* Tue Jun 22 2021 glin@suse.com
- bpf: Fix leakage under speculation on mispredicted branches
  (bsc#1187554,CVE-2021-33624).
- bpf: Do not mark insn as seen under speculative path
  verification (bsc#1187554,CVE-2021-33624).
- bpf: Inherit expanded/patched seen count from old aux data
  (bsc#1187554,CVE-2021-33624).
- commit 06f1411
* Tue Jun 22 2021 glin@suse.com
- bpf: Fix leakage under speculation on mispredicted branches
  (bsc#1187554,CVE-2021-33624).
- commit 7949a37
* Mon Jun 21 2021 osalvador@suse.de
- patches.suse/0001-x86-sched-Treat-Intel-SNC-topology-as-default-COD-as.patch:
  (bsc#1187263).
- commit 349dc99
* Mon Jun 21 2021 mgorman@suse.de
- Refresh
  patches.suse/scsi-qla2xxx-Reserve-extra-IRQ-vectors.patch.
  Add Signed-off-by tag for author of the patch in the SLE branch to suppress
  error during branch merges. Example error is
  patches.suse/scsi-qla2xxx-Reserve-extra-IRQ-vectors.patch An email
  address with @suse.de, @suse.com, @suse.cz, or @novell.com in the From,
  Signed-off-by, or Acked-by headers is required
- commit acfd671
* Mon Jun 21 2021 bp@suse.de
- blacklist.conf: 28e5e44aa3f4 x86/mm: Avoid truncating memblocks for SGX memory
- commit ea06fd1
* Mon Jun 21 2021 bp@suse.de
- x86/fpu: Prevent state corruption in __fpu__restore_sig()
  (bsc#1178134).
- commit e509690
* Mon Jun 21 2021 mbenes@suse.cz
- tracing: Do no increment trace_clock_global() by one
  (git-fixes).
- commit 17da93e
* Mon Jun 21 2021 mbenes@suse.cz
- tracing: Do not stop recording comms if the trace file is
  being read (git-fixes).
- commit 7d357b1
* Mon Jun 21 2021 oneukum@suse.com
- usb: chipidea: imx: Fix Battery Charger 1.2 CDP detection
  (git-fixes).
- commit 9d5feb1
* Mon Jun 21 2021 mbenes@suse.cz
- tracing: Do not stop recording cmdlines when tracing is off
  (git-fixes).
- commit 3306bfd
* Mon Jun 21 2021 oneukum@suse.com
- HID: usbhid: Fix race between usbhid_close() and usbhid_stop()
  (git-fixes).
- commit c5019d9
* Mon Jun 21 2021 oneukum@suse.com
- dt-bindings: reset: meson8b: fix duplicate reset IDs
  (git-fixes).
- commit cfc2db2
* Mon Jun 21 2021 oneukum@suse.com
- usb: dwc3: core: fix kernel panic when do reboot (git-fixes).
- commit 35719e0
* Mon Jun 21 2021 tiwai@suse.de
- usb: dwc3: core: fix kernel panic when do reboot (git-fixes).
- commit 9306e13
* Mon Jun 21 2021 neilb@suse.de
- SUNRPC: Handle major timeout in xprt_adjust_timeout()
  (git-fixes).
- commit 87fe1f5
* Sun Jun 20 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/xfrm-policy-Read-seqcount-outside-of-rcu-read-side-i.patch
- commit 3bedaae
* Sat Jun 19 2021 tiwai@suse.de
- usb: core: hub: Disable autosuspend for Cypress CY7C65632
  (git-fixes).
- net/x25: Return the correct errno code (git-fixes).
- HID: gt683r: add missing MODULE_DEVICE_TABLE (git-fixes).
- HID: usbhid: fix info leak in hid_submit_ctrl (git-fixes).
- HID: Add BUS_VIRTUAL to hid_connect logging (git-fixes).
- commit be65fa1
* Sat Jun 19 2021 tiwai@suse.de
- cfg80211: avoid double free of PMSR request (git-fixes).
- can: mcba_usb: fix memory leak in mcba_usb (git-fixes).
- alx: Fix an error handling path in 'alx_probe()' (git-fixes).
- batman-adv: Avoid WARN_ON timing related checks (git-fixes).
- drm/tegra: sor: Do not leak runtime PM reference (git-fixes).
- drm/amd/display: Allow bandwidth validation for 0 streams
  (git-fixes).
- HID: hid-sensor-hub: Return error for hid_set_field() failure
  (git-fixes).
- HID: hid-input: add mapping for emoji picker key (git-fixes).
- HID: quirks: Set INCREMENT_USAGE_ON_DUPLICATE for Saitek X65
  (git-fixes).
- commit c7889a3
* Sat Jun 19 2021 tiwai@suse.de
- can: bcm: fix infoleak in struct bcm_msg_head (CVE-2021-34693
  bsc#1187452).
- commit 02583ee
* Fri Jun 18 2021 shung-hsi.yu@suse.com
- net: mvpp2: add mvpp2_phylink_to_port() helper (bsc#1187171).
- commit 9bd57ed
* Thu Jun 17 2021 tiwai@suse.de
- ASoC: Intel: soc-acpi: remove TGL RVP mixed SoundWire/TDM config
  (git-fixes).
- commit 85be7e7
* Thu Jun 17 2021 oneukum@suse.com
- blacklist.conf: the driver has not been converted to new error codes
- commit 5e49259
* Thu Jun 17 2021 ludwig.nussel@suse.de
- UsrMerge the kernel (boo#1184804)
- Move files in /boot to modules dir
  The file names in /boot are included as %%ghost links. The %%post script
  creates symlinks for the kernel, sysctl.conf and System.map in
  /boot for compatibility. Some tools require adjustments before we
  can drop those links. If boot is a separate partition, a copy is
  used instead of a link.
  The logic for /boot/vmlinuz and /boot/initrd doesn't change with
  this patch.
- Use /usr/lib/modules as module dir when usermerge is active in the
  target distro.
- commit 6f5ed04
* Thu Jun 17 2021 jroedel@suse.de
- x86/sev: Check SME/SEV support in CPUID first (jsc#SLE-14337).
- iommu/vt-d: Use user privilege for RID2PASID translation
  (bsc#1187348).
- iommu/virtio: Add missing MODULE_DEVICE_TABLE (bsc#1187345).
- x86/sev-es: Use __put_user()/__get_user() for data accesses
  (bsc#1187351).
- x86/sev-es: Forward page-faults which happen during emulation
  (bsc#1187350).
- x86/sev-es: Don't return NULL from sev_es_get_ghcb()
  (bsc#1187349).
- iommu/vt-d: Remove WO permissions on second-level paging entries
  (bsc#1187346).
- iommu/vt-d: Report right snoop capability when using FL for IOVA
  (bsc#1187347).
- iommu: Fix a boundary issue to avoid performance drop
  (bsc#1187344).
- x86/sev-es: Replace open-coded hlt-loops with sev_es_terminate()
  (jsc#SLE-14337).
- x86/boot/compressed/64: Check SEV encryption in the 32-bit
  boot-path (jsc#SLE-14337).
- x86/boot/compressed/64: Add CPUID sanity check to 32-bit
  boot-path (jsc#SLE-14337).
- x86/boot/compressed/64: Add 32-bit boot #VC handler
  (jsc#SLE-14337).
- x86/boot/compressed/64: Setup IDT in startup_32 boot path
  (jsc#SLE-14337).
- x86/boot/compressed/64: Reload CS in startup_32 (jsc#SLE-14337).
- x86/sev: Do not require Hypervisor CPUID bit for SEV guests
  (jsc#SLE-14337).
- x86/boot/compressed/64: Cleanup exception handling before
  booting kernel (jsc#SLE-14337).
- iommu/amd: Keep track of amd_iommu_irq_remap state
  (https://bugzilla.kernel.org/show_bug.cgi?id=212133).
- x86/sev-es: Do not support MMIO to/from encrypted memory
  (jsc#SLE-14337).
- x86/head/64: Check SEV encryption before switching to kernel
  page-table (jsc#SLE-14337).
- x86/boot/compressed/64: Check SEV encryption in 64-bit boot-path
  (jsc#SLE-14337).
- x86/boot/compressed/64: Sanity-check CPUID results in the
  early #VC handler (jsc#SLE-14337).
- x86/boot/compressed/64: Introduce sev_status (jsc#SLE-14337).
- x86/boot/64: Explicitly map boot_params and command line
  (jsc#SLE-14337).
- x86/head/64: Disable stack protection for head$(BITS).o
  (jsc#SLE-14337).
- commit 9810251
* Thu Jun 17 2021 oneukum@suse.com
- usb: gadget: eem: fix wrong eem header operation (git-fixes).
- commit 88ac26b
* Thu Jun 17 2021 oneukum@suse.com
- usb: fix various gadget panics on 10gbps cabling (git-fixes).
- commit 43c2b75
* Thu Jun 17 2021 oneukum@suse.com
- usb: f_ncm: only first packet of aggregate needs to start timer
  (git-fixes).
- commit 6960da4
* Thu Jun 17 2021 tiwai@suse.de
- dmaengine: idxd: add missing dsa driver unregister (git-fixes).
- ALSA: seq: Fix race of snd_seq_timer_open() (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ZBook Power G8
  (git-fixes).
- ALSA: hda/realtek: headphone and mic don't work on an Acer
  laptop (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP EliteBook 840
  Aero G8 (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP
  EliteBook x360 1040 G8 (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP
  Elite Dragonfly G2 (git-fixes).
- ASoC: amd: fix for pcm_read() error (git-fixes).
- ASoC: max98088: fix ni clock divider calculation (git-fixes).
- commit 4d314e7
* Thu Jun 17 2021 oneukum@suse.com
- usb: gadget: f_fs: Ensure io_completion_wq is idle during unbind
  (git-fixes).
- commit 4b0a18c
* Thu Jun 17 2021 oneukum@suse.com
- USB: serial: ftdi_sio: add NovaTech OrionMX product ID
  (git-fixes).
- commit a61b441
* Thu Jun 17 2021 oneukum@suse.com
- USB: serial: omninet: add device id for Zyxel Omni 56K Plus
  (git-fixes).
- commit f1cf5e2
* Thu Jun 17 2021 tiwai@suse.de
- usb: dwc3: ep0: fix NULL pointer exception (git-fixes).
- usb: gadget: eem: fix wrong eem header operation (git-fixes).
- usb: fix various gadget panics on 10gbps cabling (git-fixes).
- usb: f_ncm: only first packet of aggregate needs to start timer
  (git-fixes).
- USB: serial: ftdi_sio: add NovaTech OrionMX product ID
  (git-fixes).
- commit 6edf7f4
* Thu Jun 17 2021 tiwai@suse.de
- USB: serial: omninet: add device id for Zyxel Omni 56K Plus
  (git-fixes).
- usb: gadget: f_fs: Ensure io_completion_wq is idle during unbind
  (git-fixes).
- drm: Lock pointer access in drm_master_release() (git-fixes).
- isdn: mISDN: netjet: Fix crash in nj_probe: (git-fixes).
- net/nfc/rawsock.c: fix a permission check bug (git-fixes).
- spi: sprd: Add missing MODULE_DEVICE_TABLE (git-fixes).
- i2c: mpc: Make use of i2c_recover_bus() (git-fixes).
- commit 623c00b
* Thu Jun 17 2021 tiwai@suse.de
- dmaengine: stedma40: add missing iounmap() on error in
  d40_probe() (git-fixes).
- dmaengine: QCOM_HIDMA_MGMT depends on HAS_IOMEM (git-fixes).
- dmaengine: ALTERA_MSGDMA depends on HAS_IOMEM (git-fixes).
- dmaengine: pl330: fix wrong usage of spinlock flags in dma_cyclc
  (git-fixes).
- drm: Fix use-after-free read in drm_getunique() (git-fixes).
- ASoC: sti-sas: add missing MODULE_DEVICE_TABLE (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Lenovo Miix 3-830
  tablet (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Glavey TM800A550L
  tablet (git-fixes).
- ASoC: max98088: fix ni clock divider calculation (git-fixes).
- commit 2b181d0
* Wed Jun 16 2021 colyli@suse.de
- bcache: avoid oversized read request in cache missing code path
  (bsc#1187357, bsc#1185570, bsc#1184631).
- bcache: remove bcache device self-defined readahead
  (bsc#1187357, bsc#1185570, bsc#1184631).
- lib: crc64: fix kernel-doc warning (bsc#1187357).
- bcache: fix a regression of code compiling failure in debug.c
  (bsc#1187357).
- bcache: Use 64-bit arithmetic instead of 32-bit (bsc#1187357).
- md: bcache: Trivial typo fixes in the file journal.c
  (bsc#1187357).
- md: bcache: avoid -Wempty-body warnings (bsc#1187357).
- bcache: use NULL instead of using plain integer as pointer
  (bsc#1187357).
- bcache: remove PTR_CACHE (bsc#1187357).
- bcache: reduce redundant code in bch_cached_dev_run()
  (bsc#1187357).
- bcache: don't pass BIOSET_NEED_BVECS for the 'bio_set' embedded
  in 'cache_set' (bsc#1187357).
- bcache: Convert to DEFINE_SHOW_ATTRIBUTE (bsc#1187357).
- bcache: inherit the optimal I/O size (bsc#1187357).
- commit ce1a322
* Wed Jun 16 2021 oneukum@suse.com
- media: mtk-mdp: Fix a refcounting bug on error in init
  (git-fixes).
- commit 1d82c71
* Wed Jun 16 2021 oneukum@suse.com
- media: mtk-mdp: Check return value of of_clk_get (git-fixes).
- commit f37fbe9
* Wed Jun 16 2021 oneukum@suse.com
- media: s5p-g2d: Fix a memory leak in an error handling path in
  'g2d_probe()' (git-fixes).
- commit 08513d7
* Wed Jun 16 2021 oneukum@suse.com
- usb: dwc3: debugfs: Add and remove endpoint dirs dynamically
  (git-fixes).
- commit 08559a5
* Wed Jun 16 2021 jack@suse.cz
- dax: Add a wakeup mode parameter to put_unlocked_entry()
  (bsc#1187411).
- commit 31da646
* Wed Jun 16 2021 jack@suse.cz
- dax: Add an enum for specifying dax wakup mode (bsc#1187411).
- commit 1d4c2a3
* Wed Jun 16 2021 mbenes@suse.cz
- tracing: Correct the length check which causes memory corruption
  (git-fixes).
- commit 0072a4b
* Wed Jun 16 2021 mbenes@suse.cz
- tracing: Restructure trace_clock_global() to never block
  (git-fixes).
- commit 6d6d42d
* Wed Jun 16 2021 mbrugger@suse.com
- Refresh
  patches.suse/brcmfmac-Add-clm_blob-firmware-files-to-modinfo.patch.
- commit f631d93
* Wed Jun 16 2021 mbenes@suse.cz
- ftrace: Free the trampoline when ftrace_startup() fails
  (git-fixes).
- commit 533e192
* Wed Jun 16 2021 mbenes@suse.cz
- blacklist.conf: 75d3e7f4769d ("s390/test_unwind: fix possible memleak in test_unwind()")
  We build test_unwind kernel module out of tree.
- commit abf9977
* Wed Jun 16 2021 mbenes@suse.cz
- ftrace: Do not blindly read the ip address in ftrace_bug()
  (git-fixes).
- commit 31cd567
* Wed Jun 16 2021 jack@suse.cz
- Revert "ecryptfs: replace BUG_ON with error handling code"
  (bsc#1187413).
- commit 7387ee5
* Wed Jun 16 2021 jack@suse.cz
- ocfs2: fix data corruption by fallocate (bsc#1187412).
- commit 684ec92
* Wed Jun 16 2021 jack@suse.cz
- dax: Wake up all waiters after invalidating dax entry
  (bsc#1187411).
- commit 42391aa
* Wed Jun 16 2021 jack@suse.cz
- fs: fix reporting supported extra file attributes for statx()
  (bsc#1187410).
- commit 36f6f1f
* Wed Jun 16 2021 tiwai@suse.de
- Update config files: CONFIG_SND_HDA_INTEL=m for armv7hl, too (bsc#1187334)
  It's used by openQA.
- commit c363e06
* Wed Jun 16 2021 jack@suse.cz
- ext4: fix memory leak in ext4_fill_super (bsc#1187409).
- commit d8152b1
* Wed Jun 16 2021 jack@suse.cz
- ext4: fix bug on in ext4_es_cache_extent as ext4_split_extent_at
  failed (bsc#1187408).
- commit 41eb311
* Wed Jun 16 2021 jack@suse.cz
- ext4: fix error code in ext4_commit_super (bsc#1187407).
- commit 350d1b1
* Wed Jun 16 2021 jack@suse.cz
- ext4: fix check to prevent false positive report of incorrect
  used inodes (bsc#1187404).
- commit 57c9a0a
* Wed Jun 16 2021 jack@suse.cz
- kyber: fix out of bounds access when preempted (bsc#1187403).
- commit 491df1f
* Wed Jun 16 2021 jack@suse.cz
- block: Discard page cache of zone reset target range
  (bsc#1187402).
- commit 74c08d5
* Wed Jun 16 2021 varad.gautam@suse.com
- xfrm: policy: Read seqcount outside of rcu-read side in
  xfrm_policy_lookup_bytype (bsc#1185675).
- commit 372fbf0
* Wed Jun 16 2021 msuchanek@suse.de
- kernel-binary.spec.in: Regenerate makefile when not using mkmakefile.
- commit 6b30fe5
* Wed Jun 16 2021 varad.gautam@suse.com
- xfrm: policy: Read seqcount outside of rcu-read side in xfrm_policy_lookup_bytype (bsc#1185675).
- commit 96f285d
* Wed Jun 16 2021 palcantara@suse.de
- cifs: constify get_normalized_path() properly (bsc#1185902).
- commit f4ccabe
* Wed Jun 16 2021 palcantara@suse.de
- cifs: don't cargo-cult strndup() (bsc#1185902).
- commit 2296da2
* Tue Jun 15 2021 jeffm@suse.com
- Updated patch-mainline tags.
  Also moved the affected patches into the sorted section.
  Change in patch order moved devm_rpi_firmware_put but it aligns with
  mainline.
- commit bb0636f
* Tue Jun 15 2021 lhenriques@suse.de
- fuse: BUG_ON correction in fuse_dev_splice_write()
  (bsc#1187356).
- commit d2e5d40
* Tue Jun 15 2021 martin.wilck@suse.com
- Update config files: enable zstd decompression for initramfs (bsc#1187483, jsc#SLE-18766)
- commit 0fe9f47
* Tue Jun 15 2021 martin.wilck@suse.com
- usr: Add support for zstd compressed initramfs (bsc#1187483, jsc#SLE-18766).
- commit a9bf6b8
* Tue Jun 15 2021 fweisbecker@suse.de
- sched/debug: Fix cgroup_path[] serialization (git-fixes)
- commit 24c7edf
* Tue Jun 15 2021 fweisbecker@suse.de
- blacklist.conf: We don't support uclamp
- commit 0b70e65
* Tue Jun 15 2021 fweisbecker@suse.de
- blacklist.conf: We have CONFIG_JUMP_LABEL
- commit 093a643
* Tue Jun 15 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/mac80211-add-fragment-cache-to-sta_info.patch
  patches.suse/mac80211-assure-all-fragments-are-encrypted.patch
  patches.suse/mac80211-check-defrag-PN-against-current-frame.patch
  patches.suse/mac80211-do-not-accept-forward-invalid-EAPOL-frames.patch
  patches.suse/mac80211-drop-A-MSDUs-on-old-ciphers.patch
  patches.suse/mac80211-extend-protection-against-mixed-key-and-fra.patch
  patches.suse/mac80211-prevent-attacks-on-TKIP-WEP-as-well.patch
  patches.suse/mac80211-prevent-mixed-key-and-fragment-cache-attack.patch
  patches.suse/mac80211-properly-handle-A-MSDUs-that-start-with-an-.patch
  No effect on expanded tree.
- commit 9fdca2b
* Mon Jun 14 2021 mkubecek@suse.cz
- series.conf: cleanup
  Move a SUSE specific patch ("Patch-mainline: Never...") to corresponding
  per-subsystem section.
- commit 811dc9a
* Mon Jun 14 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/RDMA-ucma-Rework-ucma_migrate_id-to-avoid-races-with.patch
- commit c80eef0
* Mon Jun 14 2021 mkubecek@suse.cz
- series.conf: cleanup
  Move a queued patch to "almost mainline" section.
- commit a847492
* Mon Jun 14 2021 martin.wilck@suse.com
- lib: Add zstd support to decompress (bsc#1187483, jsc#SLE-18766).
- commit 8fa709b
* Mon Jun 14 2021 bp@suse.de
- x86/cpufeatures: Force disable X86_FEATURE_ENQCMD and remove
  update_pasid() (bsc#1178134).
- commit 08621e3
* Mon Jun 14 2021 lhenriques@suse.de
- blacklist: add commit 4f06dd92b5d0 ("fuse: fix write deadlock")
  This is an ancient bug (from v2.6.26) which require extra backports.  Not
  worth the risk introducing new regressions.
- commit f0ede60
* Mon Jun 14 2021 tiwai@suse.de
- efi/libstub: prevent read overflow in find_file_option()
  (git-fixes).
- commit 9d1183c
* Mon Jun 14 2021 tiwai@suse.de
- kABI workaround for rtw88 (git-fixes).
- commit 8a7edfc
* Mon Jun 14 2021 tiwai@suse.de
- usb: typec: intel_pmc_mux: Put fwnode in error case during
  - >probe() (git-fixes).
- thunderbolt: usb4: Fix NVM read buffer bounds and offset issue
  (git-fixes).
- rtw88: 8822c: add LC calibration for RTL8822C (git-fixes).
- commit 3f6037a
* Mon Jun 14 2021 tiwai@suse.de
- mmc: sdhci: Clear unused bounce buffer at DMA mmap error path
  (bsc#1187039).
- commit 757ad8a
* Mon Jun 14 2021 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix handling of +arch marker (bsc#1186672)
  The previous commit made a module wrongly into Module.optional.
  Although it didn't influence on the end result, better to fix it.
  Also, add a comment to explain the markers briefly.
- commit 8f79742
* Mon Jun 14 2021 jack@suse.cz
- block: return the correct bvec when checking for gaps
  (bsc#1187144).
- commit 22678f9
* Mon Jun 14 2021 msuchanek@suse.de
- Update patches.suse/scsi-qla2xxx-Reserve-extra-IRQ-vectors.patch
  (bsc#1184436 bsc#1186286).
- commit 3b95648
* Mon Jun 14 2021 fweisbecker@suse.de
- sched/fair: Make sure to update tg contrib for blocked load (git-fixes)
- commit 9eeb58b
* Mon Jun 14 2021 fweisbecker@suse.de
- sched/fair: Keep load_avg and load_sum synced (git-fixes)
- commit 8888330
* Mon Jun 14 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/bpf-Fix-alu32-const-subreg-bound-tracking-on-bitwise.patch.
- Refresh
  patches.suse/bpf-Prevent-writable-memory-mapping-of-read-only-rin.patch.
- Refresh
  patches.suse/bpf-ringbuf-Deny-reserve-of-buffers-larger-than-ring.patch.
- commit da26c78
* Mon Jun 14 2021 tiwai@suse.de
- gpio: wcd934x: Fix shift-out-of-bounds error (git-fixes).
- drm/mcde: Fix off by 10^3 in calculation (git-fixes).
- drm/msm/a6xx: fix incorrectly set uavflagprd_inv field for A650
  (git-fixes).
- drm/msm/a6xx: update/fix CP_PROTECT initialization (git-fixes).
- Revert "ACPI: sleep: Put the FACS table after using it"
  (git-fixes).
- commit e1018b7
* Mon Jun 14 2021 tiwai@suse.de
- USB: serial: cp210x: fix alternate function for CP2102N QFN20
  (git-fixes).
- usb: typec: mux: Fix copy-paste mistake in typec_mux_match
  (git-fixes).
- usb: typec: ucsi: Clear PPM capability data in ucsi_init()
  error path (git-fixes).
- usb: typec: wcove: Use LE to CPU conversion when accessing
  msg->header (git-fixes).
- usb: fix various gadgets null ptr deref on 10gbps cabling
  (git-fixes).
- USB: f_ncm: ncm_bitrate (speed) is unsigned (git-fixes).
- USB: serial: quatech2: fix control-request directions
  (git-fixes).
- usb: pd: Set PD_T_SINK_WAIT_CAP to 310ms (git-fixes).
- usb: musb: fix MUSB_QUIRK_B_DISCONNECT_99 handling (git-fixes).
- staging: rtl8723bs: Fix uninitialized variables (git-fixes).
- commit b524f7e
* Fri Jun 11 2021 tiwai@suse.de
- Add arch-dependent support markers in supported.conf (bsc#1186672)
  We may need to put some modules as supported only on specific archs.
  This extends the supported.conf syntax to allow to put +arch additionally
  after the unsupported marker, then it'll be conditionally supported on
  that arch.
- commit 75113c7
* Fri Jun 11 2021 bwiedemann@suse.de
- Create Symbols.list and ipa-clones.list determistically
  without this patch, filesystem readdir order would influence
  order of entries in these files.
  This patch was done while working on reproducible builds for SLE.
- commit a898b6d
* Fri Jun 11 2021 nmoreychaisemartin@suse.com
- RDMA/ucma: Rework ucma_migrate_id() to avoid races with destroy (bsc#1187050, CVE-2020-36385)
- commit d630126
* Fri Jun 11 2021 acho@suse.com
- Update
  patches.suse/Bluetooth-SMP-Fail-if-remote-and-local-public-keys-a.patch
  (bsc#1186463 CVE-2021-0129 CVE-2020-26558).
- commit 3b40194
* Fri Jun 11 2021 tiwai@suse.de
- Update config files (bsc#1187167)
  Set empty to CONFIG_MODULE_SIG_KEY for reproducible builds
- commit d4c1c78
* Fri Jun 11 2021 tiwai@suse.de
- ALSA: hda: Fix for mute key LED for HP Pavilion 15-CK0xx
  (git-fixes).
- drm/amdgpu/jpeg3: add cancel_delayed_work_sync before power gate
  (git-fixes).
- drm/amdgpu/jpeg2.5: add cancel_delayed_work_sync before power
  gate (git-fixes).
- drm/amdgpu/vcn3: add cancel_delayed_work_sync before power gate
  (git-fixes).
- commit fbebaf6
* Fri Jun 11 2021 tiwai@suse.de
- Bluetooth: fix the erroneous flush_work() order (git-fixes).
- ALSA: timer: Fix master timer notification (git-fixes).
- ALSA: hda: Fix for mute key LED for HP Pavilion 15-CK0xx
  (git-fixes).
- drm/amdgpu: make sure we unpin the UVD BO (git-fixes).
- vfio/platform: fix module_put call in error flow (git-fixes).
- vfio/pci: zap_vma_ptes() needs MMU (git-fixes).
- vfio/pci: Fix error return code in vfio_ecap_init() (git-fixes).
- HID: multitouch: require Finger field to mark Win8 reports as MT
  (git-fixes).
- commit 64bd478
* Thu Jun 10 2021 martin.wilck@suse.com
- scsi: scsi_dh_alua: Retry RTPG on a different path after failure
  (bsc#1174978 bsc#1185701).
- commit 36cc9f2
* Thu Jun 10 2021 martin.wilck@suse.com
- kernel-binary.spec.in: Add Supplements: for -extra package on Leap
  kernel-$flavor-extra should supplement kernel-$flavor on Leap, like
  it does on SLED, and like the kernel-$flavor-optional package does.
- commit c60d87f
* Thu Jun 10 2021 tabraham@suse.com
- perf/x86/intel/uncore: Remove uncore extra PCI dev
  HSWEP_PCI_PCU_3 (bsc#1184685).
- commit 1c4876a
* Thu Jun 10 2021 dwagner@suse.de
- block: return the correct bvec when checking for gaps
  (bsc#1187143).
- commit 1a99a11
* Thu Jun 10 2021 dwagner@suse.de
- series: Resort and update metadata
  Resort series.conf and update meta data:
  patches.suse/scsi-lpfc-Add-a-option-to-enable-interlocked-ABTS-be.patch
  patches.suse/scsi-lpfc-Add-ndlp-kref-accounting-for-resume-RPI-pa.patch
  patches.suse/scsi-lpfc-Fix-Node-recovery-when-driver-is-handling-.patch
  patches.suse/scsi-lpfc-Fix-Unexpected-timeout-error-in-direct-att.patch
  patches.suse/scsi-lpfc-Fix-crash-when-lpfc_sli4_hba_setup-fails-t.patch
  patches.suse/scsi-lpfc-Fix-node-handling-for-Fabric-Controller-an.patch
  patches.suse/scsi-lpfc-Fix-non-optimized-ERSP-handling.patch
  patches.suse/scsi-lpfc-Fix-unreleased-RPIs-when-NPIV-ports-are-cr.patch
  patches.suse/scsi-lpfc-Ignore-GID-FT-response-that-may-be-receive.patch
  patches.suse/scsi-lpfc-Reregister-FPIN-types-if-ELS_RDF-is-receiv.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.10.patch
- commit f894385
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: track ordered bytes instead of just dio ordered bytes (bsc#1135481).
- commit 9c3cf71
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: account for new extents being deleted in total_bytes_pinned (bsc#1135481).
- commit fed2922
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: handle space_info::total_bytes_pinned inside the delayed ref itself (bsc#1135481).
- commit 5426822
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: shrink delalloc pages instead of full inodes (bsc#1135481).
- commit 5e89cd2
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: fix possible infinite loop in data async reclaim (bsc#1135481).
- commit f95f181
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: add a comment explaining the data flush steps (bsc#1135481).
- commit a308556
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: do async reclaim for data reservations (bsc#1135481).
- commit deae828
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: flush delayed refs when trying to reserve data space (bsc#1135481).
- commit d82c207
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: run delayed iputs before committing the transaction for data (bsc#1135481).
- commit 6af13e4
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: don't force commit if we are data (bsc#1135481).
- commit 3380b09
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: drop the commit_cycles stuff for data reservations (bsc#1135481).
- commit c6ed5f3
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: use the same helper for data and metadata reservations (bsc#1135481).
- commit 188e042
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: serialize data reservations if we are flushing (bsc#1135481).
- commit 9a68295
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: use ticketing for data space reservations (bsc#1135481).
- commit 0cad012
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: add btrfs_reserve_data_bytes and use it (bsc#1135481).
- commit 7c494a4
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: add the data transaction commit logic into may_commit_transaction (bsc#1135481).
- commit 9327930
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: add flushing states for handling data reservations (bsc#1135481).
- commit ee0a32c
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: check tickets after waiting on ordered extents (bsc#1135481).
- commit e9723f6
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: use btrfs_start_delalloc_roots in shrink_delalloc (bsc#1135481).
- commit 08a821e
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: use the btrfs_space_info_free_bytes_may_use helper for delalloc (bsc#1135481).
- commit e18060c
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: call btrfs_try_granting_tickets when reserving space (bsc#1135481).
- commit e684a31
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: call btrfs_try_granting_tickets when unpinning anything (bsc#1135481).
- commit df0d484
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: call btrfs_try_granting_tickets when freeing reserved bytes (bsc#1135481).
- commit 4167827
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: make ALLOC_CHUNK use the space info flags (bsc#1135481).
- commit 6287797
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: make shrink_delalloc take space_info as an arg (bsc#1135481).
- commit 1eb212c
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: handle U64_MAX for shrink_delalloc (bsc#1135481).
- commit acedfaf
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: remove orig from shrink_delalloc (bsc#1135481).
- commit 02659bb
* Thu Jun 10 2021 nborisov@suse.com
- btrfs: change nr to u64 in btrfs_start_delalloc_roots (bsc#1135481).
- commit 5b57ee8
* Wed Jun  9 2021 tbogendoerfer@suse.de
- cxgb4: avoid link re-train during TC-MQPRIO configuration
  (jsc#SLE-8389).
- ice: Allow all LLDP packets from PF to Tx (jsc#SLE-7926).
- ice: Fix VFR issues for AVF drivers that expect ATQLEN cleared
  (git-fixes).
- net/mlx5: DR, Create multi-destination flow table with level
  less than 64 (jsc#SLE-8464).
- ixgbe: fix large MTU request from VF (git-fixes).
- cxgb4: avoid accessing registers when clearing filters
  (git-fixes).
- net/mlx5e: Fix multipath lag activation (git-fixes).
- net/mlx5e: Fix nullptr in add_vlan_push_action() (git-fixes).
- net: hns3: put off calling register_netdev() until client
  initialize complete (bsc#1154353).
- gve: Correct SKB queue index validation (git-fixes).
- gve: Upgrade memory barrier in poll routine (git-fixes).
- gve: Add NULL pointer checks when freeing irqs (git-fixes).
- gve: Update mgmt_msix_idx if num_ntfy changes (git-fixes).
- net: bnx2: Fix error return code in bnx2_init_board()
  (git-fixes).
- net/mlx4: Fix EEPROM dump support (git-fixes).
- Revert "net: liquidio: fix a NULL pointer dereference"
  (git-fixes).
- Revert "qlcnic: Avoid potential NULL pointer dereference"
  (git-fixes).
- net: hns3: Limiting the scope of vector_ring_chain variable
  (git-fixes).
- commit 4451268
* Wed Jun  9 2021 rgoldwyn@suse.com
- btrfs: open device without device_list_mutex  (bsc#1176771).
- commit c922550
* Wed Jun  9 2021 oneukum@suse.com
- UCSI fixup of array of PDOs (git-fixes).
- commit 554911b
* Wed Jun  9 2021 oneukum@suse.com
- usb: typec: ucsi: Retrieve all the PDOs instead of just the
  first 4 (git-fixes).
- commit 62a78a2
* Wed Jun  9 2021 oneukum@suse.com
- i2c: imx: fix reference leak when pm_runtime_get_sync fails
  (git-fixes).
- commit 7b525ce
* Wed Jun  9 2021 oneukum@suse.com
- vmlinux.lds.h: Avoid orphan section with !SMP (git-fixes).
- commit 50e12e5
* Wed Jun  9 2021 tbogendoerfer@suse.de
- ice: handle the VF VSI rebuild failure (jsc#SLE-12878).
- ice: Fix allowing VF to request more/less queues via virtchnl
  (jsc#SLE-12878).
- cxgb4: fix regression with HASH tc prio value update
  (jsc#SLE-15131).
- net/mlx5e: Fix incompatible casting (jsc#SLE-15172).
- netfilter: nf_tables: missing error reporting for not selected
  expressions (bsc#1176447).
- net/sched: act_ct: Offload connections with commit action
  (jsc#SLE-15172).
- devlink: Correct VIRTUAL port to not have phys_port attributes
  (jsc#SLE-15172).
- net: zero-initialize tc skb extension on allocation
  (bsc#1176447).
- net/sched: fq_pie: fix OOB access in the traffic path
  (jsc#SLE-15172).
- net/sched: fq_pie: re-factor fix for fq_pie endless loop
  (jsc#SLE-15172).
- net/mlx5: Set term table as an unmanaged flow table
  (jsc#SLE-15172).
- net/mlx5e: Fix error path of updating netdev queues
  (jsc#SLE-15172).
- net/mlx5e: reset XPS on error flow if netdev isn't registered
  yet (jsc#SLE-15172).
- net/mlx5e: Fix null deref accessing lag dev (jsc#SLE-15172).
- net/mlx5: Set reformat action when needed for termination rules
  (jsc#SLE-15172).
- net: hns3: fix incorrect resp_msg issue (jsc#SLE-14777).
- netfilter: nft_set_pipapo_avx2: Add irq_fpu_usable() check,
  fallback to non-AVX2 version (bsc#1176447).
- cxgb4/ch_ktls: Clear resources when pf4 device is removed
  (jsc#SLE-15129).
- chelsio/chtls: unlock on error in chtls_pt_recvmsg()
  (jsc#SLE-15129).
- commit 9e162d7
* Wed Jun  9 2021 tiwai@suse.de
- regulator: max77620: Use device_set_of_node_from_dev()
  (git-fixes).
- regulator: core: resolve supply for boot-on/always-on regulators
  (git-fixes).
- commit a6466ca
* Tue Jun  8 2021 lduncan@suse.com
- scsi: libsas: Reset num_scatter if libata marks qc as NODATA
  (bsc#1187068).
- scsi: be2iscsi: Revert "Fix a theoretical leak in
  beiscsi_create_eqs()" (bsc#1187067).
- scsi: ufs: Make ufshcd_print_trs() consider
  UFSHCD_QUIRK_PRDT_BYTE_GRAN (bsc#1187069).
- scsi: aacraid: Fix an oops in error handling (bsc#1187072).
- commit a34cc53
* Tue Jun  8 2021 jroedel@suse.de
- x86/ioremap: Map efi_mem_reserve() memory as encrypted for SEV (bsc#1186885).
- commit c1bc56f
* Tue Jun  8 2021 jeyu@suse.de
- Update kabi files.
- Update from the June 2021 maintenance update submission (commit eaf040d1bea)
- commit ff2915c
* Tue Jun  8 2021 tiwai@suse.de
- Update patch reference for a BT fix (CVE-2020-36386 bsc#1187038)
- commit 673eac4
* Tue Jun  8 2021 dbueso@suse.de
- locking/mutex: clear MUTEX_FLAGS if wait_list is empty due to
  signal (git-fixes).
- commit 12081a6
* Tue Jun  8 2021 lduncan@suse.com
- scsi: ufs: core: Narrow down fast path in system suspend path
  (bsc#1186996).
- scsi: sni_53c710: Add IRQ check (bsc#1186990).
- scsi: sun3x_esp: Add IRQ check (bsc#1186991).
- scsi: jazz_esp: Add IRQ check (bsc#1186965).
- scsi: hisi_sas: Fix IRQ checks (bsc#1186963).
- scsi: ufs: ufshcd-pltfrm: Fix deferred probing (bsc#1187003).
- scsi: mpt3sas: Fix error return code of mpt3sas_base_attach()
  (bsc#1186978).
- scsi: qedi: Fix error return code of qedi_alloc_global_queues()
  (bsc#1186984).
- scsi: mpt3sas: Do not use GFP_KERNEL in atomic context
  (bsc#1186977).
- scsi: myrs: Fix a double free in myrs_cleanup() (bsc#1186980).
- scsi: sd: Fix Opal support (bsc#1186989).
- scsi: bnx2fc: Fix Kconfig warning & CNIC build errors
  (bsc#1186955).
- scsi: lpfc: Fix ancient double free (bsc#1186969).
- scsi: megaraid_sas: Fix MEGASAS_IOC_FIRMWARE regression
  (bsc#1186973).
- scsi: cxgb4i: Fix TLS dependency (bsc#1186960).
- scsi: fnic: Fix error return code in fnic_probe() (bsc#1186962).
- scsi: pm80xx: Fix error return in pm8001_pci_probe()
  (bsc#1186981).
- scsi: qedi: Fix missing destroy_workqueue() on error in
  __qedi_probe (bsc#1186985).
- scsi: qla4xxx: Remove in_interrupt() (bsc#1186987).
- scsi: hisi_sas: Remove preemptible() (bsc#1186964).
- scsi: megaraid_sas: Check user-provided offsets (bsc#1186970).
- scsi: libfc: Fix enum-conversion warning (bsc#1186966).
- scsi: bnx2i: Requires MMU (bsc#1186956).
- scsi: mpt3sas: Fix ioctl timeout (bsc#1186979).
- scsi: ufs: Fix race between shutdown and runtime resume flow
  (bsc#1186998).
- scsi: bfa: Fix error return in bfad_pci_init() (bsc#1186954).
- scsi: be2iscsi: Fix a theoretical leak in beiscsi_create_eqs()
  (bsc#1186953).
- scsi: aacraid: Remove erroneous fallthrough annotation
  (bsc#1186950).
- scsi: csiostor: Fix wrong return value in csio_hw_prep_fw()
  (bsc#1186957).
- scsi: qla4xxx: Fix an error handling path in
  'qla4xxx_get_host_stats()' (bsc#1186986).
- scsi: ufs: Properly release resources if a task is aborted
  successfully (bsc#1187001).
- scsi: libsas: Fix error path in sas_notify_lldd_dev_found()
  (bsc#1186967).
- scsi: megaraid_sas: Don't call disable_irq from process IRQ poll
  (bsc#1186972).
- scsi: libsas: Set data_dir as DMA_NONE if libata marks qc as
  NODATA (bsc#1186968).
- scsi: mesh: Fix panic after host or bus reset (bsc#1186976).
- scsi: megaraid_sas: Clear affinity hint (bsc#1186971).
- scsi: scsi_debug: Add check for sdebug_max_queue during module
  init (bsc#1186988).
- scsi: eesox: Fix different dev_id between request_irq() and
  free_irq() (bsc#1186961).
- scsi: powertec: Fix different dev_id between request_irq()
  and free_irq() (bsc#1186982).
- scsi: cumana_2: Fix different dev_id between request_irq()
  and free_irq() (bsc#1186958).
- scsi: ufs: Add quirk to fix abnormal ocs fatal error
  (bsc#1186994).
- scsi: ufs: Introduce UFSHCD_QUIRK_PRDT_BYTE_GRAN quirk
  (bsc#1187000).
- scsi: ufs: Add quirk to enable host controller without hce
  (bsc#1186993).
- scsi: ufs: Add quirk to disallow reset of interrupt aggregation
  (bsc#1186992).
- scsi: ufs: Add quirk to fix mishandling utrlclr/utmrlclr
  (bsc#1186995).
- scsi: megaraid_sas: Remove undefined ENABLE_IRQ_POLL macro
  (bsc#1186974).
- scsi: acornscsi: Fix an error handling path in acornscsi_probe()
  (bsc#1186952).
- scsi: ufs: Don't update urgent bkops level when toggling auto
  bkops (bsc#1186997).
- scsi: cxgb3i: Fix some leaks in init_act_open() (bsc#1186959).
- scsi: ufs-qcom: Fix scheduling while atomic issue (bsc#1187002).
- scsi: aacraid: Use memdup_user() as a cleanup (bsc#1186951).
- scsi: qedi: Check for buffer overflow in qedi_set_path()
  (bsc#1186983).
- Revert "scsi: core: run queue if SCSI device queue isn't ready
  and queue is idle" (bsc#1186949).
- scsi: ufshcd: use an enum for quirks (bsc#1186999).
- commit 063da01
* Mon Jun  7 2021 dwagner@suse.de
- scsi: lpfc: Fix failure to transmit ABTS on FC link (git-fixes).
- scsi: qla2xxx: Prevent PRLI in target mode (git-fixes).
- commit df14b8a
* Mon Jun  7 2021 dwagner@suse.de
- blacklist: Add not necessary git-fixes
- commit 203b357
* Mon Jun  7 2021 dwagner@suse.de
- wireguard: allowedips: initialize list head in selftest
  (git-fixes).
- wireguard: peer: allocate in kmem_cache (git-fixes).
- wireguard: use synchronize_net rather than synchronize_rcu
  (git-fixes).
- wireguard: do not use -O3 (git-fixes).
- wireguard: selftests: make sure rp_filter is disabled on vethc
  (git-fixes).
- wireguard: selftests: remove old conntrack kconfig value
  (git-fixes).
- wireguard: queueing: get rid of per-peer ring buffers
  (git-fixes).
- wireguard: peer: put frequently used members above cache lines
  (git-fixes).
- commit f17f786
* Mon Jun  7 2021 bp@suse.de
- pid: take a reference when initializing `cad_pid` (bsc#1152489).
- commit 7fbca02
* Mon Jun  7 2021 msuchanek@suse.de
- rpm/config.sh: Build device trees (boo#1186928).
- commit 0645dbf
* Mon Jun  7 2021 bp@suse.de
- x86/apic: Mark _all_ legacy interrupts when IO/APIC is missing
  (bsc#1152489).
- commit 76a898b
* Mon Jun  7 2021 oneukum@suse.com
- NFC: SUSE specific brutal fix for runtime PM (bsc#1185589).
- commit c32c592
* Mon Jun  7 2021 mbrugger@suse.com
- brcmfmac: Add clm_blob firmware files to modinfo (bsc#1186677).
- commit abced70
* Mon Jun  7 2021 bp@suse.de
- x86/fault: Don't send SIGSEGV twice on SEGV_PKUERR
  (bsc#1152489).
- commit e986350
* Mon Jun  7 2021 msuchanek@suse.de
- powerpc/32: Fix boot failure with CONFIG_STACKPROTECTOR
  (jsc#SLE-13847 git-fixes).
- commit c646236
* Mon Jun  7 2021 msuchanek@suse.de
- powerpc/kprobes: Fix validation of prefixed instructions across
  page boundary (jsc#SLE-13847 git-fixes).
- commit 1cefe80
* Mon Jun  7 2021 msuchanek@suse.de
- Refresh patches.suse/cpuidle-pseries-Fixup-CEDE0-latency-only-for-POWER10.patch.
  Update to v4 submission.
- commit 1222430
* Mon Jun  7 2021 mkubecek@suse.cz
- config: refresh
- drop PCIE_BW (removed by a backported patch)
- commit 8a54d2d
* Mon Jun  7 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/NFS-Deal-correctly-with-attribute-generation-counter.patch
  patches.suse/NFS-Don-t-corrupt-the-value-of-pg_bytes_written-in-n.patch
  patches.suse/NFS-Don-t-discard-pNFS-layout-segments-that-are-mark.patch
  patches.suse/NFS-Don-t-gratuitously-clear-the-inode-cache-when-lo.patch
  patches.suse/NFS-Don-t-revalidate-the-directory-permissions-on-a-.patch
  patches.suse/NFS-Fix-an-Oopsable-condition-in-__nfs_pageio_add_re.patch
  patches.suse/NFS-fix-an-incorrect-limit-in-filelayout_decode_layo.patch
  patches.suse/NFSD-Repair-misuse-of-sv_lock-in-5.10.16-rt30.patch
  patches.suse/NFSv4-Don-t-discard-segments-marked-for-return-in-_p.patch
  patches.suse/NFSv4-Fix-a-NULL-pointer-dereference-in-pnfs_mark_ma.patch
  patches.suse/NFSv4-Fix-v4.0-v4.1-SEEK_DATA-return-ENOTSUPP-when-s.patch
  patches.suse/NFSv4.2-Always-flush-out-writes-in-nfs42_proc_falloc.patch
  patches.suse/NFSv4.2-fix-handling-of-sr_eof-in-SEEK-s-reply.patch
  patches.suse/NFSv4.2-fix-return-value-of-_nfs4_get_security_label.patch
  patches.suse/NFSv42-Copy-offload-should-update-the-file-size-when.patch
  patches.suse/SUNRPC-Move-fault-injection-call-sites.patch
  patches.suse/SUNRPC-Set-memalloc_nofs_save-for-sync-tasks.patch
  patches.suse/fs-nfs-Use-fatal_signal_pending-instead-of-signal_pe.patch
  patches.suse/md-Fix-missing-unused-status-line-of-proc-mdstat.patch
  patches.suse/nfsd-register-pernet-ops-last-unregister-first.patch
  patches.suse/pNFS-NFSv4-Fix-a-layout-segment-leak-in-pnfs_layout_.patch
  patches.suse/pNFS-flexfiles-fix-incorrect-size-check-in-decode_nf.patch
  patches.suse/sunrpc-fix-refcount-leak-for-rpc-auth-modules.patch
  patches.suse/svcrdma-disable-timeouts-on-rdma-backchannel.patch
  patches.suse/x86-fix-seq_file-iteration-for-pat-memtype.c.patch
  patches.suse/xprtrdma-Avoid-Receive-Queue-wrapping.patch
  patches.suse/xprtrdma-rpcrdma_mr_pop-already-does-list_del_init.patch
- commit 08c81db
* Mon Jun  7 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/pm-sleep-add-pm_debug_messages-kernel-command-line-option.patch
- commit 9d4ad2b
* Mon Jun  7 2021 tiwai@suse.de
- kABI workaround for struct lis3lv02d change (git-fixes).
- commit b20df4c
* Mon Jun  7 2021 tiwai@suse.de
- dmaengine: idxd: Use cpu_feature_enabled() (git-fixes).
- ALSA: hda: update the power_state during the direct-complete
  (git-fixes).
- drm/amdgpu: Don't query CE and UE errors (git-fixes).
- drm/i915/selftests: Fix return value check in
  live_breadcrumbs_smoketest() (git-fixes).
- serial: 8250_pci: handle FL_NOIRQ board flag (git-fixes).
- drm/amdgpu/jpeg2.0: add cancel_delayed_work_sync before power
  gate (git-fixes).
- drm/amdgpu/vcn2.5: add cancel_delayed_work_sync before power
  gate (git-fixes).
- drm/amdkfd: correct sienna_cichlid SDMA RLC register offset
  error (git-fixes).
- drm/amdgpu: stop touching sched.ready in the backend
  (git-fixes).
- ASoC: cs43130: handle errors in cs43130_probe() properly
  (git-fixes).
- Revert "ASoC: cs43130: fix a NULL pointer dereference"
  (git-fixes).
- commit f261b0d
* Mon Jun  7 2021 tiwai@suse.de
- drm/amdgpu/vcn2.0: add cancel_delayed_work_sync before power
  gate (git-fixes).
- drm/amdgpu/vcn1: add cancel_delayed_work_sync before power gate
  (git-fixes).
- drm/amd/display: Disconnect non-DP with no EDID (git-fixes).
- commit 9592735
* Mon Jun  7 2021 tiwai@suse.de
- Add No-fix tag to already backported sound fixes
- commit 96fc983
* Mon Jun  7 2021 tiwai@suse.de
- bus: ti-sysc: Fix flakey idling of uarts and stop using
  swsup_sidle_act (git-fixes).
- i2c: qcom-geni: Suspend and resume the bus during
  SYSTEM_SLEEP_PM ops (git-fixes).
- nfc: fix NULL ptr dereference in llcp_sock_getname() after
  failed connect (git-fixes).
- ALSA: hda/cirrus: Set Initial DMIC volume to -26 dB (git-fixes).
- commit 957e0af
* Mon Jun  7 2021 tiwai@suse.de
- thermal/drivers/intel: Initialize RW trip to
  THERMAL_TEMP_INVALID (git-fixes).
- serial: rp2: use 'request_firmware' instead of
  'request_firmware_nowait' (git-fixes).
- USB: serial: pl2303: add device id for ADLINK ND-6530 GC
  (git-fixes).
- USB: serial: ti_usb_3410_5052: add startech.com device id
  (git-fixes).
- USB: serial: option: add Telit LE910-S1 compositions 0x7010,
  0x7011 (git-fixes).
- USB: serial: ftdi_sio: add IDs for IDS GmbH Products
  (git-fixes).
- USB: usbfs: Don't WARN about excessively large memory
  allocations (git-fixes).
- serial: max310x: unregister uart driver in case of failure
  and abort (git-fixes).
- Revert "serial: max310x: pass return value of
  spi_register_driver" (git-fixes).
- usb: core: reduce power-on-good delay time of root hub
  (git-fixes).
- commit 5cd70a0
* Mon Jun  7 2021 tiwai@suse.de
- mei: request autosuspend after sending rx flow control
  (git-fixes).
- platform/x86: touchscreen_dmi: Add info for the Mediacom Winpad
  7.0 W700 tablet (git-fixes).
- platform/x86: intel_punit_ipc: Append MODULE_DEVICE_TABLE for
  ACPI (git-fixes).
- platform/x86: hp-wireless: add AMD's hardware id to the
  supported list (git-fixes).
- platform/x86: hp_accel: Avoid invoking _INI to speed up resume
  (git-fixes).
- media: gspca: properly check for errors in po1030_probe()
  (git-fixes).
- Revert "media: gspca: Check the return value of write_bridge
  for timeout" (git-fixes).
- media: gspca: mt9m111: Check write_bridge for timeout
  (git-fixes).
- Revert "media: gspca: mt9m111: Check write_bridge for timeout"
  (git-fixes).
- media: dvb: Add check on sp8870_readreg return (git-fixes).
- commit c7b5e47
* Mon Jun  7 2021 tiwai@suse.de
- gpio: cadence: Add missing MODULE_DEVICE_TABLE (git-fixes).
- Revert "media: dvb: Add check on sp8870_readreg" (git-fixes).
- libertas: register sysfs groups properly (git-fixes).
- Revert "libertas: add checks for the return value of
  sysfs_create_group" (git-fixes).
- isdn: mISDN: correctly handle ph_info allocation failure in
  hfcsusb_ph_info (git-fixes).
- Revert "isdn: mISDN: Fix potential NULL pointer dereference
  of kzalloc" (git-fixes).
- isdn: mISDNinfineon: check/cleanup ioremap failure correctly
  in setup_io (git-fixes).
- Revert "isdn: mISDNinfineon: fix potential NULL pointer
  dereference" (git-fixes).
- Revert "media: usb: gspca: add a missed check for
  goto_low_power" (git-fixes).
- commit 337d971
* Mon Jun  7 2021 tiwai@suse.de
- cfg80211: mitigate A-MSDU aggregation attacks (CVE-2020-24588
  bsc#1185861).
- drm/amd/amdgpu: fix a potential deadlock in gpu reset
  (git-fixes).
- drm/amdgpu: Fix a use-after-free (git-fixes).
- drm/amd/amdgpu: fix refcount leak (git-fixes).
- drm/amd/display: Disconnect non-DP with no EDID (git-fixes).
- dmaengine: qcom_hidma: comment platform_driver_register call
  (git-fixes).
- Revert "dmaengine: qcom_hidma: Check for driver register
  failure" (git-fixes).
- char: hpet: add checks after calling ioremap (git-fixes).
- Revert "char: hpet: fix a missing check of ioremap" (git-fixes).
- commit 17141be
* Mon Jun  7 2021 tiwai@suse.de
- efi: cper: fix snprintf() use in cper_dimm_err_location()
  (git-fixes).
- efi: Allow EFI_MEMORY_XP and EFI_MEMORY_RO both to be cleared
  (git-fixes).
- ACPICA: Clean up context mutex during object deletion
  (git-fixes).
- hwmon: (dell-smm-hwmon) Fix index values (git-fixes).
- brcmfmac: properly check for bus register errors (git-fixes).
- Revert "brcmfmac: add a check for the status of usb_register"
  (git-fixes).
- ath6kl: return error code in ath6kl_wmi_set_roam_lrssi_cmd()
  (git-fixes).
- Revert "ath6kl: return error code in
  ath6kl_wmi_set_roam_lrssi_cmd()" (git-fixes).
- commit d3cc1eb
* Fri Jun  4 2021 jslaby@suse.cz
- Revert "char: hpet: fix a missing check of ioremap" (git-fixes).
- ttyprintk: Add TTY hangup callback (git-fixes).
- commit dac98b4
* Thu Jun  3 2021 msuchanek@suse.de
- kernel-binary.spec.in: build-id check requires elfutils.
- commit 01569b3
* Thu Jun  3 2021 neilb@suse.de
- NFSv4: Fix a NULL pointer dereference in
  pnfs_mark_matching_lsegs_return() (git-fixes).
- commit 33829e2
* Thu Jun  3 2021 neilb@suse.de
- NFSv4: Fix v4.0/v4.1 SEEK_DATA return -ENOTSUPP when set
  NFS_V4_2 config (git-fixes).
- NFS: Don't corrupt the value of pg_bytes_written in
  nfs_do_recoalesce() (git-fixes).
- NFS: Fix an Oopsable condition in __nfs_pageio_add_request()
  (git-fixes).
- NFS: fix an incorrect limit in filelayout_decode_layout()
  (git-fixes).
- fs/nfs: Use fatal_signal_pending instead of signal_pending
  (git-fixes).
- xprtrdma: rpcrdma_mr_pop() already does list_del_init()
  (git-fixes).
- xprtrdma: Avoid Receive Queue wrapping (git-fixes).
- NFSv4: Don't discard segments marked for return in
  _pnfs_return_layout() (git-fixes).
- NFS: Don't discard pNFS layout segments that are marked for
  return (git-fixes).
- NFSv42: Copy offload should update the file size when
  appropriate (git-fixes).
- SUNRPC: Move fault injection call sites (git-fixes).
- NFSv4.2 fix handling of sr_eof in SEEK's reply (git-fixes).
- pNFS/flexfiles: fix incorrect size check in decode_nfs_fh()
  (git-fixes).
- NFS: Deal correctly with attribute generation counter overflow
  (git-fixes).
- NFSv4.2: Always flush out writes in nfs42_proc_fallocate()
  (git-fixes).
- md: Fix missing unused status line of /proc/mdstat (git-fixes).
- sunrpc: fix refcount leak for rpc auth modules (git-fixes).
- NFSD: Repair misuse of sv_lock in 5.10.16-rt30 (git-fixes).
- svcrdma: disable timeouts on rdma backchannel (git-fixes).
- NFSv4.2: fix return value of _nfs4_get_security_label()
  (git-fixes).
- NFS: Don't gratuitously clear the inode cache when lookup failed
  (git-fixes).
- NFS: Don't revalidate the directory permissions on a lookup
  failure (git-fixes).
- SUNRPC: Set memalloc_nofs_save() for sync tasks (git-fixes).
- x86: fix seq_file iteration for pat.c (git-fixes).
- nfsd: register pernet ops last, unregister first (git-fixes).
- net: fix iteration for sctp transport seq_files (git-fixes).
- pNFS/NFSv4: Fix a layout segment leak in pnfs_layout_process()
  (git-fixes).
- commit 60296fb
* Wed Jun  2 2021 msuchanek@suse.de
- kernel-binary.spec: Only use mkmakefile when it exists
  Linux 5.13 no longer has a mkmakefile script
- commit b453c7b
* Wed Jun  2 2021 lduncan@suse.com
- scsi: smartpqi: Remove unused functions (bsc#1186472).
- scsi: smartpqi: Fix device pointer variable reference static
  checker issue (bsc#1186472).
- scsi: smartpqi: Fix blocks_per_row static checker issue
  (bsc#1186472).
- scsi: smartpqi: Update version to 2.1.8-045 (bsc#1186472).
- scsi: smartpqi: Add new PCI IDs (bsc#1186472).
- scsi: smartpqi: Correct system hangs when resuming from
  hibernation (bsc#1186472).
- scsi: smartpqi: Update enclosure identifier in sysfs
  (bsc#1186472).
- scsi: smartpqi: Add additional logging for LUN resets
  (bsc#1186472).
- scsi: smartpqi: Update SAS initiator_port_protocols and
  target_port_protocols (bsc#1186472).
- scsi: smartpqi: Add phy ID support for the physical drives
  (bsc#1186472).
- scsi: smartpqi: Convert snprintf() to scnprintf() (bsc#1186472).
- scsi: smartpqi: Fix driver synchronization issues (bsc#1186472).
- scsi: smartpqi: Update device scan operations (bsc#1186472).
- scsi: smartpqi: Update OFA management (bsc#1186472).
- scsi: smartpqi: Update RAID bypass handling (bsc#1186472).
- scsi: smartpqi: Update suspend/resume and shutdown
  (bsc#1186472).
- scsi: smartpqi: Synchronize device resets with mutex
  (bsc#1186472).
- scsi: smartpqi: Update soft reset management for OFA
  (bsc#1186472).
- scsi: smartpqi: Update event handler (bsc#1186472).
- scsi: smartpqi: Add support for wwid (bsc#1186472).
- scsi: smartpqi: Remove timeouts from internal cmds
  (bsc#1186472).
- scsi: smartpqi: Disable WRITE SAME for HBA NVMe disks
  (bsc#1186472).
- scsi: smartpqi: Add host level stream detection enable
  (bsc#1186472).
- scsi: smartpqi: Add stream detection (bsc#1186472).
- scsi: smartpqi: Align code with oob driver (bsc#1186472).
- scsi: smartpqi: Add support for long firmware version
  (bsc#1186472).
- scsi: smartpqi: Add support for BMIC sense feature cmd and
  feature bits (bsc#1186472).
- scsi: smartpqi: Add support for RAID1 writes (bsc#1186472).
- scsi: smartpqi: Add support for RAID5 and RAID6 writes
  (bsc#1186472).
- scsi: smartpqi: Refactor scatterlist code (bsc#1186472).
- scsi: smartpqi: Refactor aio submission code (bsc#1186472).
- scsi: smartpqi: Add support for new product ids (bsc#1186472).
- scsi: smartpqi: Correct request leakage during reset operations
  (bsc#1186472).
- scsi: smartpqi: Use host-wide tag space (bsc#1186472).
- commit b561ca9
* Wed Jun  2 2021 jdelvare@suse.de
- PM: sleep: Add pm_debug_messages kernel command line option
  (bsc#1186752).
- commit 735920b
* Wed Jun  2 2021 oneukum@suse.com
- media: dvb: Add check on sp8870_readreg return (git-fixes).
- commit 2133cbd
* Wed Jun  2 2021 oneukum@suse.com
- blacklist.conf: cosmetic fix
- commit ce72d5a
* Wed Jun  2 2021 oneukum@suse.com
- media: gspca: properly check for errors in po1030_probe()
  (git-fixes).
- commit 1750a2e
* Wed Jun  2 2021 oneukum@suse.com
- Revert "media: gspca: Check the return value of write_bridge
  for timeout" (git-fixes).
- commit b97e22b
* Wed Jun  2 2021 oneukum@suse.com
- media: gspca: mt9m111: Check write_bridge for timeout
  (git-fixes).
- commit 7f3a7f1
* Wed Jun  2 2021 oneukum@suse.com
- Revert "media: gspca: mt9m111: Check write_bridge for timeout"
  (git-fixes).
- commit d087481
* Wed Jun  2 2021 oneukum@suse.com
- blacklist.conf: depends on PD 3.0 which we don't have and cannot be
  backported
- commit a396f2f
* Wed Jun  2 2021 mkubecek@suse.cz
- Update kabi files.
- update from June 2021 maitenance update submission (commit f0fe006fa3e1)
- commit 3b5c05b
* Wed Jun  2 2021 tiwai@suse.de
- HID: magicmouse: fix NULL-deref on disconnect (git-fixes).
- HID: i2c-hid: fix format string mismatch (git-fixes).
- HID: pidff: fix error return code in hid_pidff_init()
  (git-fixes).
- HID: i2c-hid: Skip ELAN power-on command after reset
  (git-fixes).
- tpm: fix error return code in tpm2_get_cc_attrs_tbl()
  (git-fixes).
- vsock/vmci: log once the failed queue pair allocation
  (git-fixes).
- commit e5695e4
* Wed Jun  2 2021 ptesarik@suse.cz
- partitions/ibm: fix non-DASD devices (bsc#1185857 LTC#192526).
- commit 0f96f57
* Tue Jun  1 2021 dwagner@suse.de
- Fix patches.suse/nvme-multipath-reset-bdev-to-ns-head-when-failover.patch (bsc#1186681)
  The backport for bsc#1182999 bsc#1178378 introduced a bug.  It's not
  possible to use bdget_disk() in nvme_failover_req() as this can run in
  IRQ context and bdget_disk() can sleep.
  Luckily, we don't need to set bdev via bio_set_dev() as we can set
  bi_disk directly.
- commit cee62aa
* Tue Jun  1 2021 oneukum@suse.com
- Revert "media: dvb: Add check on sp8870_readreg" (git-fixes).
- commit 3655f21
* Tue Jun  1 2021 oneukum@suse.com
- usb: typec: tcpm: Use LE to CPU conversion when accessing
  msg->header (git-fixes).
- commit f61bf4c
* Tue Jun  1 2021 jgross@suse.com
- xen-pciback: redo VF placement in the virtual topology
  (git-fixes).
- commit 323098d
* Tue Jun  1 2021 oneukum@suse.com
- usb: typec: mux: Fix matching with typec_altmode_desc
  (git-fixes).
- commit 2c2aed2
* Tue Jun  1 2021 dwagner@suse.de
- Fix patches.suse/nvme-multipath-reset-bdev-to-ns-head-when-failover.patch (bsc#1186681)
  The backport for bsc#1182999 bsc#1178378 introduced a bug.  It's not
  possible to use bdget_disk() in nvme_failover_req() as this can run in
  IRQ context and bdget_disk() can sleep.
  Luckily, we don't need to set bdev via bio_set_dev() as we can set
  bi_disk directly.
  Refresh:
  - patches.suse/nvme-multipath-retry-commands-for-dying-queues.patch
- commit f0fe006
* Tue Jun  1 2021 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section
  patches.suse/nxp-nci-add-NXP1002-id.patch
- commit d0ca1ba
* Tue Jun  1 2021 msuchanek@suse.de
- Refresh patches.suse/scsi-ibmvfc-Reinit-target-retries.patch.
  Update patch metadata.
- commit e269098
* Tue Jun  1 2021 oneukum@suse.com
- nxp-i2c: restore includes for kABI (bsc#1185589).
- commit 1786af1
* Tue Jun  1 2021 oneukum@suse.com
- nxp-nci: add NXP1002 id (bsc#1185589).
- commit 9d43526
* Tue Jun  1 2021 hare@suse.de
- block/genhd: use atomic_t for disk_event->block (bsc#1185497).
- commit 57427b3
* Tue Jun  1 2021 ptesarik@suse.cz
- s390/ipl: support NVMe IPL kernel parameters (bsc#1185980
  LTC#192679).
- commit 36a59d3
* Tue Jun  1 2021 hare@suse.de
- block/scsi-ioctl: Fix kernel-infoleak in scsi_put_cdrom_generic_arg() (git-fixes).
- dm crypt: document encrypted keyring key option (git-fixes).
- commit 58565f2
* Mon May 31 2021 bp@suse.de
- x86/cpu: Initialize MSR_TSC_AUX if RDTSCP *or* RDPID is
  supported (bsc#1152489).
- commit 1931741
* Mon May 31 2021 tiwai@suse.de
- Update config files: build W1 modules for x86-64, too (bsc#1186672)
  The core w1 and a couple of modules are needed to be in kernel core
  package for Arm (for RPi) while they are put into leap package for
  other archs.
- commit 5ae0be0
* Mon May 31 2021 jgross@suse.com
- xen-pciback: reconfigure also from backend watch handler
  (git-fixes).
- commit 5795686
* Mon May 31 2021 jgross@suse.com
- xen-blkback: fix compatibility bug with single page rings
  (git-fixes).
- commit c1a440a
* Mon May 31 2021 bp@suse.de
- x86/sev-es: Invalidate the GHCB after completing VMGEXIT
  (bsc#1178134).
- commit 2ed6303
* Mon May 31 2021 jgross@suse.com
- xen/evtchn: Change irq_info lock to raw_spinlock_t (git-fixes).
- commit 085f359
* Mon May 31 2021 ykaukab@suse.de
- tty: serial: ucc_uart: replace qe_io{read,write}* wrappers by
  generic io{read,write}* (git-fixes).
- commit 845115a
* Mon May 31 2021 ykaukab@suse.de
- soc: fsl: qe: replace qe_io{read,write}* wrappers by generic
  io{read,write}* (git-fixes).
- commit d4c6a74
* Mon May 31 2021 varad.gautam@suse.com
- series.conf: cleanup
  update upstream references and resort:
  patches.suse/ipc-mqueue-msg-sem-Avoid-relying-on-a-stack-reference.patch
- commit a8331c9
* Mon May 31 2021 hare@suse.de
- nvme: fix deadlock in disconnect during scan_work and/or
  ana_work (git-fixes).
- Refresh
  patches.suse/nvme-fabrics-reject-I-O-to-offline-device.patch.
- commit 4805fdc
* Mon May 31 2021 ykaukab@suse.de
- arm64: vdso32: make vdso32 install conditional (git-fixes).
- commit de92552
* Mon May 31 2021 ykaukab@suse.de
- blacklist.conf: arm64: add fix for unsupported SOC
- commit 7c4e5f6
* Mon May 31 2021 bp@suse.de
- x86/sev-es: Move sev_es_put_ghcb() in prep for follow on patch
  (bsc#1178134).
- commit 61a3120
* Mon May 31 2021 hare@suse.de
- nvme: document nvme controller states (git-fixes).
- commit 495f482
* Mon May 31 2021 hare@suse.de
- nvme-pci: use simple suspend when a HMB is enabled (git-fixes).
- nvme-pci: make sure write/poll_queues less or equal then cpu
  (git-fixes).
- nvme-pci: align io queue count with allocted nvme_queue in
  (git-fixes).
- nvme-pci: remove last_sq_tail (git-fixes).
- nvme-pci: remove volatile cqes (git-fixes).
- nvme-pci: avoid race between nvme_reap_pending_cqes() and
  nvme_poll() (git-fixes).
- nvme-pci: dma read memory barrier for completions (git-fixes).
- nvme-pci: fix "slimmer CQ head update" (git-fixes).
- nvme-pci: Simplify nvme_poll_irqdisable (git-fixes).
- nvme-pci: Remove two-pass completions (git-fixes).
- nvme-pci: Remove tag from process cq (git-fixes).
- nvme-pci: slimmer CQ head update (git-fixes).
- commit dd74a78
* Mon May 31 2021 tiwai@suse.de
- i2c: s3c2410: fix possible NULL pointer deref on read message
  after write (git-fixes).
- i2c: i801: Don't generate an interrupt on bus reset (git-fixes).
- i2c: sh_mobile: Use new clock calculation formulas for RZ/G2E
  (git-fixes).
- iio: adc: ad7793: Add missing error code in ad7793_setup()
  (git-fixes).
- iio: adc: ad7768-1: Fix too small buffer passed to
  iio_push_to_buffers_with_timestamp() (git-fixes).
- iio: gyro: fxas21002c: balance runtime power in error path
  (git-fixes).
- staging: iio: cdc: ad7746: avoid overwrite of num_channels
  (git-fixes).
- iio: adc: ad7124: Fix potential overflow due to non sequential
  channel numbers (git-fixes).
- iio: adc: ad7124: Fix missbalanced regulator enable / disable
  on error (git-fixes).
- staging: emxx_udc: fix loop in _nbu2ss_nuke() (git-fixes).
- serial: sh-sci: Fix off-by-one error in FIFO threshold register
  setting (git-fixes).
- serial: core: fix suspicious security_locked_down() call
  (git-fixes).
- serial: tegra: Fix a mask operation that is always true
  (git-fixes).
- thunderbolt: dma_port: Fix NVM read buffer bounds and offset
  issue (git-fixes).
- usb: gadget: udc: renesas_usb3: Fix a race in usb3_start_pipen()
  (git-fixes).
- USB: trancevibrator: fix control-request direction (git-fixes).
- misc/uss720: fix memory leak in uss720_probe (git-fixes).
- drm/meson: fix shutdown crash when component not probed
  (git-fixes).
- net: usb: fix memory leak in smsc75xx_bind (git-fixes).
- cdrom: gdrom: initialize global variable at init time
  (git-fixes).
- cdrom: gdrom: deallocate struct gdrom_unit fields in
  remove_gdrom (git-fixes).
- Revert "gdrom: fix a memory leak bug" (git-fixes).
- usb: dwc3: gadget: Enable suspend events (git-fixes).
- commit 62c76a6
* Mon May 31 2021 hare@suse.de
- blk-mq: Swap two calls in blk_mq_exit_queue() (git-fixes).
- block: Fix three kernel-doc warnings (git-fixes).
- commit e222970
* Mon May 31 2021 jeyu@suse.de
- Rename duplicate patches to their SLE15-SP2 equivalents.
  This is to prepare for the next SLE15-SP2 -> SLE15-SP3 merge.
- commit e32f455
* Mon May 31 2021 neilb@suse.de
- SUNRPC: More fixes for backlog congestion (bsc#1185428).
- commit c0de1ec
* Sun May 30 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/nvme-fabrics-decode-host-pathing-error-for-connect.patch
  patches.suse/nvme-fc-short-circuit-reconnect-retries.patch
- whitespace cleanup
- commit 03158d3
* Sun May 30 2021 mkubecek@suse.cz
- series.conf: cleanup
- fix Patch-mainline and move unsortable patches out of sorted section
  patches.suse/0001-netfilter-conntrack-improve-RST-handling-when-tuple-.patch
  patches.suse/0001-netfilter-conntrack-add-new-sysctl-to-disable-RST-ch.patch
- commit 9d82526
* Sun May 30 2021 tiwai@suse.de
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP
  Zbook Fury 17 G8 (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP
  Zbook Fury 15 G8 (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP
  Zbook G8 (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 855 G8
  (git-fixes).
- ALSA: hda/realtek: Chain in pop reduction fixup for ThinkStation
  P340 (git-fixes).
- ALSA: hda/realtek: the bass speaker can't output sound on Yoga
  9i (git-fixes).
- commit 7ba5be9
* Sun May 30 2021 tiwai@suse.de
- ASoC: cs35l33: fix an error code in probe() (git-fixes).
- ASoC: cs42l42: Regmap must use_single_read/write (git-fixes).
- ALSA: usb-audio: scarlett2: snd_scarlett_gen2_controls_create()
  can be static (git-fixes).
- commit 72126c6
* Sun May 30 2021 tiwai@suse.de
- ALSA: hda/realtek: Headphone volume is controlled by Front mixer
  (git-fixes).
- ALSA: usb-audio: scarlett2: Improve driver startup messages
  (git-fixes).
- ALSA: usb-audio: scarlett2: Fix device hang with ehci-pci
  (git-fixes).
- ALSA: usb-audio: fix control-request direction (git-fixes).
- commit ad502bc
* Fri May 28 2021 dbueso@suse.de
- futex: Make syscall entry points less convoluted (git-fixes).
- futex: Get rid of the val2 conditional dance (git-fixes).
- futex: Do not apply time namespace adjustment on FUTEX_LOCK_PI
  (bsc#1164648).
- futex: Change utime parameter to be 'const ... *' (git-fixes).
- commit c6c39e0
* Fri May 28 2021 ykaukab@suse.de
- arm64: kdump: update ppos when reading elfcorehdr (git-fixes).
- arm64: kasan: fix page_alloc tagging with DEBUG_VIRTUAL
  (git-fixes).
- arm64/mm: Fix pfn_valid() for ZONE_DEVICE based memory
  (git-fixes).
- arm64: ptrace: Fix seccomp of traced syscall -1 (NO_SYSCALL)
  (git-fixes).
- arm64: Add missing ISB after invalidating TLB in
  __primary_switch (git-fixes).
- arm64: kexec_file: fix memory leakage in create_dtb() when
  fdt_open_into() fails (git-fixes).
- arm64: link with -z norelro for LLD or aarch64-elf (git-fixes).
- arm64: avoid -Woverride-init warning (git-fixes).
- arm64: link with -z norelro regardless of CONFIG_RELOCATABLE
  (git-fixes).
- Revert "arm64: vdso: Fix compilation with clang older than 8"
  (git-fixes).
- ARM64: vdso32: Install vdso32 from vdso_install (git-fixes).
- arm64: ptrace: Use NO_SYSCALL instead of -1 in
  syscall_trace_enter() (git-fixes).
- arm: mm: use __pfn_to_section() to get mem_section (git-fixes).
- commit 4accc73
* Fri May 28 2021 jlee@suse.com
- Hibernation: Fix Hibernate not blocked in Secure Boot with no EFI secret key
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
  (bsc#1186512)
- commit d15957a
* Fri May 28 2021 ykaukab@suse.de
- blacklist.conf: arm64: dts: add fixes
- commit 918cf09
* Fri May 28 2021 aabdallah@suse.de
- netfilter: conntrack: add new sysctl to disable RST check
  (bsc#1183947 bsc#1185950).
- commit 54ae065
* Fri May 28 2021 ykaukab@suse.de
- blacklist.conf: spi: add a cosmetic fix
- commit 67d8fed
* Fri May 28 2021 ykaukab@suse.de
- Revert "soc: fsl: qe: introduce qe_io{read,write}* wrappers"
  (git-fixes).
- commit 25de66e
* Fri May 28 2021 aabdallah@suse.de
- netfilter: conntrack: improve RST handling when tuple is re-used
  (bsc#1183947 bsc#1185950).
- commit 3e0da56
* Fri May 28 2021 aabdallah@suse.de
- netfilter: conntrack: avoid misleading 'invalid' in log message
  (bsc#1183947 bsc#1185950).
- commit 9338bce
* Fri May 28 2021 ykaukab@suse.de
- net: enetc: fix link error again (git-fixes).
- commit 0d4ccc0
* Fri May 28 2021 ykaukab@suse.de
- blacklist.conf: add misc dt-bindings fixes
  References: git-fixes
- commit fc2fb63
* Fri May 28 2021 tiwai@suse.de
- NFC: nci: fix memory leak in nci_allocate_device (git-fixes).
- commit 2bba556
* Fri May 28 2021 dwagner@suse.de
- scsi: libfc: Avoid invoking response handler twice if ep is
  already completed (bsc#1186573).
- commit 679d56e
* Fri May 28 2021 neilb@suse.de
- SUNRPC in case of backlog, hand free slots directly to waiting task (bsc#1185428).
- commit 862f15d
* Fri May 28 2021 glin@suse.com
- bpf: No need to simulate speculative domain for immediates
  (bsc#1186484,CVE-2021-33200).
- bpf: Fix mask direction swap upon off reg sign change
  (bsc#1186484,CVE-2021-33200).
- bpf: Wrap aux data inside bpf_sanitize_info container
  (bsc#1186484,CVE-2021-33200).
- commit fc0b52a
* Thu May 27 2021 msuchanek@suse.de
- Update
  patches.suse/powerpc-64s-Fix-crashes-when-toggling-entry-flush-ba.patch
  (bsc#1177666 git-fixes bsc#1186460 ltc#192531).
- Update
  patches.suse/powerpc-64s-Fix-crashes-when-toggling-stf-barrier.patch
  (bsc#1087082 git-fixes bsc#1186460 ltc#192531).
- commit ce0ebfb
* Thu May 27 2021 lhenriques@suse.de
- ceph: fix inode leak on getattr error in __fh_to_dentry
  (bsc#1186501).
- ceph: only check pool permissions for regular files
  (bsc#1186501).
- ceph: don't clobber i_snap_caps on non-I_NEW inode
  (bsc#1186501).
- ceph: fix up error handling with snapdirs (bsc#1186501).
- commit 7d20748
* Thu May 27 2021 ohering@suse.de
- hv_netvsc: Reset the RSC count if NVSP_STAT_FAIL in
  netvsc_receive() (git-fixes).
- commit 661689a
* Thu May 27 2021 ohering@suse.de
- uio_hv_generic: Fix another memory leak in error handling paths
  (git-fixes).
- uio_hv_generic: Fix a memory leak in error handling paths
  (git-fixes).
- uio: uio_hv_generic: use devm_kzalloc() for private data alloc
  (git-fixes).
- uio_hv_generic: add missed sysfs_remove_bin_file (git-fixes).
- commit 0e1067b
* Thu May 27 2021 lhenriques@suse.de
- ceph: fix inode leak on getattr error in __fh_to_dentry
  (bsc#1186501).
- ceph: only check pool permissions for regular files
  (bsc#1186501).
- ceph: don't clobber i_snap_caps on non-I_NEW inode
  (bsc#1186501).
- ceph: fix up error handling with snapdirs (bsc#1186501).
- commit 7c54637
* Thu May 27 2021 dwagner@suse.de
- nvme-fabrics: decode host pathing error for connect
  (bsc#1179827).
- nvme-fc: short-circuit reconnect retries (bsc#1179827).
- nvme-fc: check sgl supported by target (bsc#1179827).
- commit 97321b0
* Thu May 27 2021 dwagner@suse.de
- scsi: lpfc: Fix bad memory access during VPD DUMP mailbox
  command (bsc#1186451).
- commit 192cba3
* Thu May 27 2021 dwagner@suse.de
- scsi: lpfc: Update lpfc version to 12.8.0.10 (bsc#1186451).
- scsi: lpfc: Reregister FPIN types if ELS_RDF is received from
  fabric controller (bsc#1186451).
- scsi: lpfc: Add a option to enable interlocked ABTS before
  job completion (bsc#1186451).
- scsi: lpfc: Fix crash when lpfc_sli4_hba_setup() fails to
  initialize the SGLs (bsc#1186451).
- scsi: lpfc: Ignore GID-FT response that may be received after
  a link flip (bsc#1186451).
- scsi: lpfc: Fix node handling for Fabric Controller and Domain
  Controller (bsc#1186451).
- scsi: lpfc: Fix Node recovery when driver is handling
  simultaneous PLOGIs (bsc#1186451).
- scsi: lpfc: Add ndlp kref accounting for resume RPI path
  (bsc#1186451).
- scsi: lpfc: Fix "Unexpected timeout" error in direct attach
  topology (bsc#1186451).
- scsi: lpfc: Fix non-optimized ERSP handling (bsc#1186451).
- scsi: lpfc: Fix unreleased RPIs when NPIV ports are created
  (bsc#1186451).
- commit 19dc8b6
* Thu May 27 2021 oneukum@suse.com
- Bluetooth: L2CAP: Fix handling LE modes by L2CAP_OPTIONS
  (git-fixes).
- commit 322fe2d
* Thu May 27 2021 dwagner@suse.de
- nvme-fc: clear q_live at beginning of association teardown
  (bsc#1186479).
- commit 6f0e9b4
* Thu May 27 2021 dwagner@suse.de
- RDMA/core: create ib_cm with WQ_MEM_RECLAIM flag (bsc#1183346).
- RDMA/addr: create addr_wq with WQ_MEM_RECLAIM flag
  (bsc#1183346).
- commit 18a82b0
* Thu May 27 2021 tiwai@suse.de
- drm/amdgpu: update sdma golden setting for Navi12 (git-fixes).
- drm/amdgpu: update gc golden setting for Navi12 (git-fixes).
- drm/amdgpu: Fix GPU TLB update error when PAGE_SIZE >
  AMDGPU_PAGE_SIZE (git-fixes).
- drm/i915/gt: Disable HiZ Raw Stall Optimization on broken gen7
  (git-fixes).
- ALSA: hda/realtek: Add fixup for HP Spectre x360 15-df0xxx
  (git-fixes).
- ALSA: hda: fixup headset for ASUS GU502 laptop (git-fixes).
- commit b2fab88
* Thu May 27 2021 tiwai@suse.de
- drm/amdgpu: disable 3DCGCG on picasso/raven1 to avoid compute
  hang (git-fixes).
- ALSA: line6: Fix racy initialization of LINE6 MIDI (git-fixes).
- ALSA: intel8x0: Don't update period unless prepared (git-fixes).
- ALSA: hda/realtek: Add some CLOVE SSIDs of ALC293 (git-fixes).
- ALSA: usb-audio: Validate MS endpoint descriptors (git-fixes).
- ALSA: hda: fixup headset for ASUS GU502 laptop (git-fixes).
- ALSA: hda/realtek: reset eapd coeff to default value for alc287
  (git-fixes).
- leds: lp5523: check return value of lp5xx_read and jump to
  cleanup code (git-fixes).
- Revert "leds: lp5523: fix a missing check of return value of
  lp55xx_read" (git-fixes).
- Bluetooth: SMP: Fail if remote and local public keys are
  identical (git-fixes).
- commit 57f36e1
* Wed May 26 2021 tbogendoerfer@suse.de
- net/mlx5: Fix health error state handling (bsc#1186467).
- commit d6aa2d3
* Wed May 26 2021 petr.pavlu@suse.com
- ipmi/watchdog: Stop watchdog timer when the current action is
  'none' (bsc#1184855).
- commit 725c479
* Tue May 25 2021 lduncan@suse.com
- scsi: mpt3sas: Only one vSES is present even when IOC has
  multi vSES (bsc#1185954).
- commit e2e5f3a
* Tue May 25 2021 fdmanana@suse.com
- btrfs: fix race between transaction aborts and fsyncs leading
  to use-after-free (bsc#1186441).
- commit fb966c0
* Tue May 25 2021 fdmanana@suse.com
- btrfs: fix race when picking most recent mod log operation
  for an old root (bsc#1186439).
- commit 305123c
* Tue May 25 2021 fdmanana@suse.com
- btrfs: fix race between transaction aborts and fsyncs leading
  to use-after-free (bsc#1186441).
- commit 9be975d
* Tue May 25 2021 fdmanana@suse.com
- btrfs: fix race when picking most recent mod log operation
  for an old root (bsc#1186439).
- commit f318368
* Tue May 25 2021 tiwai@suse.de
- drm/amdgpu/display/dm: add missing parameter documentation
  (git-fixes).
- drm/amdgpu/display: remove redundant continue statement
  (git-fixes).
- Revert "drm/qxl: do not run release if qxl failed to init"
  (git-fixes).
- commit d1874da
* Tue May 25 2021 tiwai@suse.de
- platform/x86: intel_int0002_vgpio: Only call enable_irq_wake()
  when using s2idle (git-fixes).
- usb: typec: ucsi: Put fwnode in any case during ->probe()
  (git-fixes).
- security: keys: trusted: fix TPM2 authorizations (git-fixes).
- tpm: acpi: Check eventlog signature before using it (git-fixes).
- tty: serial: lpuart: fix lpuart32_write usage (git-fixes).
- commit 4ed41e4
* Tue May 25 2021 tiwai@suse.de
- mt76: mt7615: fix entering driver-own state on mt7663
  (git-fixes).
- mt76: mt7915: fix txpower init for TSSI off chips (git-fixes).
- mt76: mt76x0: disable GTK offloading (git-fixes).
- mt76: mt7615: support loading EEPROM for MT7613BE (git-fixes).
- platform/x86: intel_pmt_crashlog: Fix incorrect macros
  (git-fixes).
- pinctrl: qcom: spmi-gpio: fix warning about irq chip reusage
  (git-fixes).
- commit 6b07d97
* Tue May 25 2021 tiwai@suse.de
- KEYS: trusted: Fix memory leak on object td (git-fixes).
- iwlwifi: pcie: make cfg vs. trans_cfg more robust (git-fixes).
- media: saa7146: use sg_dma_len when building pgtable
  (git-fixes).
- media: saa7134: use sg_dma_len when building pgtable
  (git-fixes).
- intel_th: pci: Add Alder Lake-M support (git-fixes).
- intel_th: pci: Add Rocket Lake CPU support (git-fixes).
- KEYS: trusted: Fix TPM reservation for seal/unseal (git-fixes).
- gpu/xen: Fix a use after free in xen_drm_drv_init (git-fixes).
- commit 2d606fa
* Tue May 25 2021 tiwai@suse.de
- drm/i915: Read C0DRB3/C1DRB3 as 16 bits again (git-fixes).
- drm/amdgpu: fix concurrent VM flushes on Vega/Navi v2
  (git-fixes).
- drm/i915/display: fix compiler warning about array overrun
  (git-fixes).
- drm/amdgpu: Add mem sync flag for IB allocated by SA
  (git-fixes).
- drm/amd/display: add handling for hdcp2 rx id list validation
  (git-fixes).
- drm/amd/display: Try YCbCr420 color when YCbCr444 fails
  (git-fixes).
- drm/amd/display: Fix UBSAN: shift-out-of-bounds warning
  (git-fixes).
- fbmem: add margin check to fb_check_caps() (git-fixes).
- commit 1d7d2f2
* Tue May 25 2021 tiwai@suse.de
- drm/amd/display: Fix debugfs link_settings entry (git-fixes).
- drm/amd/display: DCHUB underflow counter increasing in some
  scenarios (git-fixes).
- drm/amd/pm: fix workload mismatch on vega10 (git-fixes).
- drm/amdkfd: Fix UBSAN shift-out-of-bounds warning (git-fixes).
- drm/amdgpu: Fix some unload driver issues (git-fixes).
- drm/amdgpu/display: buffer INTERRUPT_LOW_IRQ_CONTEXT interrupt
  work (git-fixes).
- drm/amd/display: Don't optimize bandwidth before disabling
  planes (git-fixes).
- drm/amd/display: Check for DSC support instead of ASIC revision
  (git-fixes).
- drm/amd/display: changing sr exit latency (git-fixes).
- drm/dp_mst: Set CLEAR_PAYLOAD_ID_TABLE as broadcast (git-fixes).
- commit f3698a5
* Tue May 25 2021 tiwai@suse.de
- dmaengine: idxd: fix cdev setup and free device lifetime issues
  (git-fixes).
- dmaengine: idxd: removal of pcim managed mmio mapping
  (git-fixes).
- dmaengine: idxd: cleanup pci interrupt vector allocation
  management (git-fixes).
- dmaengine: idxd: fix dma device lifetime (git-fixes).
- drm/dp_mst: Revise broadcast msg lct & lcr (git-fixes).
- drm/ast: Fix invalid usage of AST_MAX_HWC_WIDTH in cursor
  atomic_check (git-fixes).
- drm/qxl: do not run release if qxl failed to init (git-fixes).
- drm/amd/display/dc/dce/dce_aux: Remove duplicate line causing
  'field overwritten' issue (git-fixes).
- drm/komeda: Fix bit check to import to value of proper type
  (git-fixes).
- commit 7955989
* Tue May 25 2021 tiwai@suse.de
- ALSA: firewire-lib: fix amdtp_packet tracepoints event for
  packet_index field (git-fixes).
- ALSA: usb-audio: Fix potential out-of-bounce access in MIDI
  EP parser (git-fixes).
- ACPI: PM: Add ACPI ID of Alder Lake Fan (git-fixes).
- ASoC: Intel: sof_sdw: add quirk for new ADL-P Rvp (git-fixes).
- ASoC: rt5670: Add a quirk for the Dell Venue 10 Pro 5055
  (git-fixes).
- ALSA: hda/hdmi: fix race in handling acomp ELD notification
  at resume (git-fixes).
- Bluetooth: btusb: Enable quirk boolean flag for Mediatek Chip
  (git-fixes).
- Bluetooth: Fix incorrect status handling in LE PHY UPDATE event
  (git-fixes).
- commit ea056ec
* Tue May 25 2021 dwagner@suse.de
- scsi: core: Run queue in case of I/O resource contention failure
  (bsc#1186416).
- commit 50bad37
* Tue May 25 2021 tiwai@suse.de
- USB: serial: pl2303: fix line-speed handling on newer chips
  (bsc#1186320).
- USB: serial: pl2303: add support for PL2303HXN (bsc#1186320).
- commit bc4a20a
* Tue May 25 2021 iivanov@suse.de
- mmc: sdhci-iproc: Set SDHCI_QUIRK_CAP_CLOCK_BASE_BROKEN on BCM2711 (bsc#1186009)
- commit 8a9d64a
* Tue May 25 2021 iivanov@suse.de
- mmc: sdhci-iproc: Cap min clock frequency on BCM2711 (bsc#1186009)
- commit 1607e2d
* Tue May 25 2021 ptesarik@suse.cz
- s390/kdump: fix out-of-memory with PCI (bsc#1182257 LTC#191375).
- commit b91dd8c
* Tue May 25 2021 jslaby@suse.cz
- PCI/RCEC: Fix RCiEP device to RCEC association (jsc#SLE-13736
  jsc#SLE-14845 git-fixes).
- commit 6922678
* Tue May 25 2021 jslaby@suse.cz
- Refresh
  patches.suse/PCI-AER-Add-RCEC-AER-error-injection-support.patch.
  Update to upstream version.
- commit deb7805
* Tue May 25 2021 jslaby@suse.cz
- Refresh
  patches.suse/PCI-AER-Add-pcie_walk_rcec-to-RCEC-AER-handling.patch.
  Update to upstream version.
- commit c098a79
* Tue May 25 2021 jslaby@suse.cz
- Delete
  patches.suse/PCI-AER-Apply-Function-Level-Reset-to-RCiEP-on-fatal.patch.
- Delete
  patches.suse/PCI-ERR-Limit-AER-resets-in-pcie_do_recovery.patch.
- Delete
  patches.suse/PCI-RCEC-Add-RCiEP-s-linked-RCEC-to-AER-ERR.patch.
  Replaced in upstream by a175102b0a82 (PCI/ERR: Recover from RCEC AER
  errors).
- commit 716aea9
* Tue May 25 2021 jslaby@suse.cz
- Update to upstream version.
- commit 21cf7c7
* Tue May 25 2021 jslaby@suse.cz
- Refresh
  patches.suse/PCI-AER-Apply-Function-Level-Reset-to-RCiEP-on-fatal.patch.
- Refresh
  patches.suse/PCI-ERR-Avoid-negated-conditional-for-clarity.patch.
- Refresh
  patches.suse/PCI-RCEC-Add-RCiEP-s-linked-RCEC-to-AER-ERR.patch.
- Refresh
  patches.suse/pci-err-add-pci_walk_bridge-to-pcie_do_recovery.
- Refresh patches.suse/pci-err-recover-from-rcec-aer-errors.
- Refresh patches.suse/pci-err-recover-from-rciep-aer-errors.
  Update to upstream version.
- commit 41d7b52
* Tue May 25 2021 tiwai@suse.de
- spi: spi-fsl-dspi: Fix a resource leak in an error handling path
  (git-fixes).
- gpio: xilinx: Correct kernel doc for xgpio_probe() (git-fixes).
- mmc: sdhci-pci-gli: increase 1.8V regulator wait (git-fixes).
- drm/amd/display: Fix two cursor duplication when using overlay
  (git-fixes).
- Input: silead - add workaround for x86 BIOS-es which bring
  the chip up in a stuck state (git-fixes).
- Input: elants_i2c - do not bind to i2c-hid compatible ACPI
  instantiated devices (git-fixes).
- PCI: thunder: Fix compile testing (git-fixes).
- ACPI / hotplug / PCI: Fix reference count leak in enable_slot()
  (git-fixes).
- gpiolib: acpi: Add quirk to ignore EC wakeups on Dell Venue
  10 Pro 5055 (git-fixes).
- dmaengine: dw-edma: Fix crash on loading/unloading driver
  (git-fixes).
- usb: sl811-hcd: improve misleading indentation (git-fixes).
- pinctrl: ingenic: Improve unreachable code generation
  (git-fixes).
- commit 4488c4d
* Tue May 25 2021 tiwai@suse.de
- firmware: arm_scpi: Prevent the ternary sign expansion bug
  (git-fixes).
- ALSA: dice: fix stream format for TC Electronic Konnekt Live
  at high sampling transfer frequency (git-fixes).
- ALSA: firewire-lib: fix calculation for size of IR context
  payload (git-fixes).
- ALSA: firewire-lib: fix check for the size of isochronous
  packet payload (git-fixes).
- ALSA: bebob/oxfw: fix Kconfig entry for Mackie d.2 Pro
  (git-fixes).
- ALSA: dice: fix stream format at middle sampling rate for
  Alesis iO 26 (git-fixes).
- platform/mellanox: mlxbf-tmfifo: Fix a memory barrier issue
  (git-fixes).
- ics932s401: fix broken handling of errors when word reading
  fails (git-fixes).
- ASoC: rt286: Generalize support for ALC3263 codec (git-fixes).
- ASoC: rsnd: call rsnd_ssi_master_clk_start() from
  rsnd_ssi_init() (git-fixes).
- commit 309a9af
* Tue May 25 2021 tiwai@suse.de
- ALSA: hda/conexant: Re-order CX5066 quirk table entries
  (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Chuwi Hi8 tablet
  (git-fixes).
- ASoC: rsnd: core: Check convert rate in rsnd_hw_params
  (git-fixes).
- ASoC: Intel: bytcr_rt5640: Enable jack-detect support on Asus
  T100TAF (git-fixes).
- ASoC: rt286: Make RT286_SET_GPIO_* readable and writable
  (git-fixes).
- ALSA: bebob: enable to deliver MIDI messages for multiple ports
  (git-fixes).
- ALSA: rme9652: don't disable if not enabled (git-fixes).
- ALSA: hdspm: don't disable if not enabled (git-fixes).
- ALSA: hdsp: don't disable if not enabled (git-fixes).
- commit 0897647
* Tue May 25 2021 tiwai@suse.de
- usb: core: hub: fix race condition about TRSMRCY of resume
  (git-fixes).
- usb: xhci: Increase timeout for HC halt (git-fixes).
- usb: dwc3: omap: improve extcon initialization (git-fixes).
- cdc-wdm: untangle a circular dependency between callback and
  softint (git-fixes).
- drm/i915: Avoid div-by-zero on gen2 (git-fixes).
- drm/radeon/dpm: Disable sclk switching on Oland when two 4K
  60Hz monitors are connected (git-fixes).
- pinctrl: samsung: use 'int' for register masks in Exynos
  (git-fixes).
- i2c: Add I2C_AQ_NO_REP_START adapter quirk (git-fixes).
- i2c: bail out early when RDWR parameters are wrong (git-fixes).
- drm/amd/display: fixed divide by zero kernel crash during dsc
  enablement (git-fixes).
- drm/amd/display: Force vsync flip when reconfiguring MPCC
  (git-fixes).
- qtnfmac: Fix possible buffer overflow in
  qtnf_event_handle_external_auth (git-fixes).
- wl3501_cs: Fix out-of-bounds warnings in wl3501_mgmt_join
  (git-fixes).
- wl3501_cs: Fix out-of-bounds warnings in wl3501_send_pkt
  (git-fixes).
- mac80211: clear the beacon's CRC after channel switch
  (git-fixes).
- Bluetooth: check for zapped sk before connecting (git-fixes).
- Bluetooth: initialize skb_queue_head at l2cap_chan_create()
  (git-fixes).
- Bluetooth: Set CONF_NOT_COMPLETE as l2cap_chan default
  (git-fixes).
- commit 6a99610
* Tue May 25 2021 jslaby@suse.cz
- Refresh
  patches.suse/PCI-ERR-Rename-reset_link-to-reset_subordinates.patch.
- Refresh
  patches.suse/pci-err-add-pci_walk_bridge-to-pcie_do_recovery.
- Refresh
  patches.suse/pci-err-retain-status-from-error-notification.
- Refresh
  patches.suse/pci-err-simplify-by-computing-pci_pcie_type-once.
- Refresh
  patches.suse/pci-err-use-bridge-for-clarity-in-pcie_do_recovery.
  Update to upstream version.
- commit b63143d
* Tue May 25 2021 jslaby@suse.cz
- Update to upstream version.
- commit c7b5cb5
* Tue May 25 2021 jslaby@suse.cz
- PCI/ERR: Bind RCEC devices to the Root Port driver
  (jsc#SLE-13736 jsc#SLE-14845).
- Refresh
  patches.suse/pci-err-simplify-by-computing-pci_pcie_type-once.
- Delete
  patches.suse/PCI-RCEC-Add-RCEC-class-code-and-extended-capability.patch.
- Delete
  patches.suse/PCI-RCEC-Bind-RCEC-devices-to-the-Root-Port-driver.patch.
  Update to upstream version. The two were merged into the one.
- commit 746ca90
* Tue May 25 2021 lduncan@suse.com
- scsi: pm80xx: Fix potential infinite loop (bsc#1186354).
- commit f24fca0
* Mon May 24 2021 lduncan@suse.com
- scsi: pm80xx: Increase timeout for pm80xx mpi_uninit_check()
  (bsc#1186355).
- scsi: pm80xx: Fix chip initialization failure (bsc#1186354).
- scsi: target: tcmu: Fix use-after-free of se_cmd->priv
  (bsc#1186356).
- scsi: pm80xx: Do not sleep in atomic context (bsc#1186353).
- scsi: aacraid: Improve compat_ioctl handlers (bsc#1186352).
- scsi: target: tcmu: Fix warning: 'page' may be used
  uninitialized (bsc#1186357).
- commit d9c7184
* Mon May 24 2021 mgorman@suse.de
- Update metadata and move to sorted section
  patches.suse/sched-fair-Clear-SMT-siblings-after-determining-the-core-is-not-idle.patch.
  patches.suse/sched-fair-Fix-wrong-cpu-selecting-from-isolated-dom.patch.
  patches.suse/sched-fair-Minimize-concurrent-LBs-between-domain-level.patch.
  patches.suse/sched-fair-Reduce-busy-load-balance-interval.patch.
  patches.suse/sched-fair-Reduce-minimal-imbalance-threshold.patch.
  patches.suse/sched-fair-Relax-constraint-on-task-s-load-during-load-balance.patch.
  patches.suse/sched-fair-Remove-the-force-parameter-of-update_tg_load_avg.patch.
  patches.suse/sched-fair-Simplify-the-work-when-reweighting-entity.patch.
  patches.suse/sched-rt-Disable-RT_RUNTIME_SHARE-by-default.patch.
- commit 9b005f0
* Mon May 24 2021 mgorman@suse.de
- sched/fair: Fix shift-out-of-bounds in load_balance() (git fixes
  (sched)).
- commit c01b809
* Mon May 24 2021 ptesarik@suse.cz
- s390/dasd: fix hanging DASD driver unbind (bsc#1183932
  LTC#192153).
- commit f5a02db
* Sun May 23 2021 fweisbecker@suse.de
- genirq/irqdomain: Don't try to free an interrupt that has no (git-fixes)
- commit 6059d03
* Sun May 23 2021 fweisbecker@suse.de
- sched/fair: Avoid stale CPU util_est value for schedutil in (git-fixes)
- commit 3ca2554
* Sun May 23 2021 fweisbecker@suse.de
- sched/eas: Don't update misfit status if the task is pinned (git-fixes)
- commit 7849a6f
* Sat May 22 2021 fweisbecker@suse.de
- posix-timers: Preserve return value in clock_adjtime32() (git-fixes)
- commit 637287d
* Sat May 22 2021 fweisbecker@suse.de
- hrtimer: Update softirq_expires_next correctly after (git-fixes)
- commit 123b070
* Fri May 21 2021 fweisbecker@suse.de
- genirq: Disable interrupts for force threaded handlers (git-fixes)
- commit a3b0361
* Fri May 21 2021 msuchanek@suse.de
- blacklist.conf: Remove already backported commits.
- commit d6aafa0
* Fri May 21 2021 fweisbecker@suse.de
- sched/fair: Fix unfairness caused by missing load decay (git-fixes)
- commit 25deacb
* Fri May 21 2021 dwagner@suse.de
- lpfc: Decouple port_template and vport_template (bsc#185032).
- commit 77503a8
* Fri May 21 2021 pmladek@suse.com
- workqueue: Minor follow-ups to the rescuer destruction change
  (bsc#1185911).
- commit 682a642
* Fri May 21 2021 pmladek@suse.com
- workqueue: more destroy_workqueue() fixes (bsc#1185911).
- commit 63656eb
* Fri May 21 2021 tiwai@suse.de
- Re-enable yenta socket driver for x86_64 (bsc#1186349)
  CONFIG_YENTA was mistakenly disabled along with the disablement of
  CONFIG_PCMCIA.  Re-enable the module for keeping the CardBus stuff
  still working, but put it to kernel-*-optional for Leap 15.3.
- commit 1b41019
* Fri May 21 2021 msuchanek@suse.de
- ibmvnic: remove default label from to_string switch (bsc#1152457
  ltc#174432 git-fixes).
- commit 5e94000
* Fri May 21 2021 mkubecek@suse.cz
- series.conf: cleanup
- move submitted patch to "almost mainline" section:
  patches.suse/cpufreq-intel_pstate-Add-Icelake-servers-support-in-.patch
- commit 0ccf9b6
* Thu May 20 2021 dwagner@suse.de
- nvme-fc: return NVME_SC_HOST_ABORTED_CMD when a command has
  been aborted (bsc#1184259).
- nvme-fc: set NVME_REQ_CANCELLED in nvme_fc_terminate_exchange()
  (bsc#1184259).
- nvme: add NVME_REQ_CANCELLED flag in nvme_cancel_request()
  (bsc#1184259).
- nvme: simplify error logic in nvme_validate_ns() (bsc#1184259).
- commit 56bb69c
* Thu May 20 2021 tbogendoerfer@suse.de
- xsk: Respect device's headroom and tailroom on generic xmit path
  (git-fixes).
- commit 7e45682
* Thu May 20 2021 tbogendoerfer@suse.de
- smc: disallow TCP_ULP in smc_setsockopt() (git-fixes).
- ethernet:enic: Fix a use after free bug in enic_hard_start_xmit
  (git-fixes).
- RDMA/srpt: Fix error return code in srpt_cm_req_recv()
  (git-fixes).
- RDMA/hns: Delete redundant abnormal interrupt status
  (git-fixes).
- RDMA/hns: Delete redundant condition judgment related to eq
  (git-fixes).
- net, xdp: Update pkt_type if generic XDP changes unicast MAC
  (git-fixes).
- xsk: Respect device's headroom and tailroom on generic xmit path
  (git-fixes).
- commit 7c9514e
* Thu May 20 2021 ggherdovich@suse.cz
- cpufreq: intel_pstate: Add Icelake servers support in no-HWP
  mode (bsc#1185758).
- commit d0a78d0
* Thu May 20 2021 tbogendoerfer@suse.de
- bnxt_en: Fix RX consumer index logic in the error path
  (git-fixes).
- commit 75ee727
* Thu May 20 2021 tbogendoerfer@suse.de
- i40e: Fix PHY type identifiers for 2.5G and 5G adapters
  (git-fixes).
- i40e: fix the restart auto-negotiation after FEC modified
  (git-fixes).
- i40e: Fix use-after-free in i40e_client_subtask() (git-fixes).
- i40e: fix broken XDP support (git-fixes).
- mlxsw: spectrum_mr: Update egress RIF list before route's action
  (git-fixes).
- net: hns3: disable phy loopback setting in hclge_mac_start_phy
  (git-fixes).
- net: hns3: clear unnecessary reset request in
  hclge_reset_rebuild (git-fixes).
- net: hns3: use netif_tx_disable to stop the transmit queue
  (git-fixes).
- net: hns3: fix for vxlan gpe tx checksum bug (git-fixes).
- net: hns3: add check for HNS3_NIC_STATE_INITED in
  hns3_reset_notify_up_enet() (git-fixes).
- net: hns3: initialize the message content in
  hclge_get_link_mode() (git-fixes).
- net: hns3: fix incorrect configuration for igu_egu_hw_err
  (git-fixes).
- RDMA/qedr: Fix error return code in qedr_iw_connect()
  (jsc#SLE-8215).
- bnxt_en: Fix RX consumer index logic in the error path
  (git-fixes).
- bnxt_en: fix ternary sign extension bug in bnxt_show_temp()
  (git-fixes).
- net: thunderx: Fix unintentional sign extension issue
  (git-fixes).
- cxgb4: Fix unintentional sign extension issues (git-fixes).
- netdevice: Add missing IFF_PHONY_HEADROOM self-definition
  (git-fixes).
- vrf: fix a comment about loopback device (git-fixes).
- net: hns3: Fix for geneve tx checksum bug (git-fixes).
- commit d07ce98
* Thu May 20 2021 tbogendoerfer@suse.de
- ethtool: fix missing NLM_F_MULTI flag when dumping
  (bsc#1176447).
- IB/hfi1: Rework AIP and VNIC dummy netdev usage (jsc#SLE-13208).
- RDMA/rtrs-clt: destroy sysfs after removing session from active
  list (jsc#SLE-15176).
- RDMA/mlx5: Fix drop packet rule in egress table (jsc#SLE-15175).
- net/sched: act_ct: fix wild memory access when clearing
  fragments (bsc#1176447).
- nfp: devlink: initialize the devlink port attribute "lanes"
  (bsc#1176447).
- selftests: mlxsw: Remove a redundant if statement in
  tc_flower_scale test (bsc#1176774).
- net/mlx5: Fix bit-wise and with zero (jsc#SLE-15172).
- netfilter: conntrack: Make global sysctls readonly in non-init
  netns (bsc#1176447).
- commit 3d16f03
* Wed May 19 2021 lduncan@suse.com
- scsi: fnic: Remove bogus ratelimit messages (bsc#1183249).
- commit ad3d189
* Wed May 19 2021 colyli@suse.de
- dm rq: fix double free of blk_mq_tag_set in dev remove after
  table load fails (bsc#1185581).
- commit eec9b2b
* Wed May 19 2021 lyan@suse.com
- Enable CONFIG_PCI_PF_STUB for Nvidia Ampere vGPU support (jsc#SLE-17882
  jsc#ECO-3691)
  Nvidia switched its vGPU mechanism from mdev to SRIOV since Ampere
  architecutre. For the SRIOV implementation, they used pci-pf-stub
  module. We only need to enable CONFIG_PCI_PF_STUB here,
  other dependencies have been enabled already.
- commit 8ab8eb0
* Wed May 19 2021 bp@suse.de
- x86,swiotlb: Adjust SWIOTLB bounce buffer size for SEV guests
  (bsc#1186219).
- commit df8fbad
* Wed May 19 2021 hare@suse.de
- nvme: explicitly update mpath disk capacity on revalidation
  (git-fixes).
- commit 71b6570
* Wed May 19 2021 hare@suse.de
- nvme: retrigger ANA log update if group descriptor isn't found (git-fixes)
- commit d9afd49
* Wed May 19 2021 hare@suse.de
- nvme-tcp: fix misuse of __smp_processor_id with preemption
  (git-fixes).
- dm: avoid filesystem lookup in dm_get_dev_t() (git-fixes).
- nvme: don't intialize hwmon for discovery controllers
  (git-fixes).
- nvme-tcp: Fix warning with CONFIG_DEBUG_PREEMPT (git-fixes).
- nvme-tcp: Fix possible race of io_work and direct send
  (git-fixes).
- nvme-tcp: fix kconfig dependency warning when !CRYPTO
  (git-fixes).
- blk-iocost: ioc_pd_free() shouldn't assume irq disabled
  (git-fixes).
- nvme: fix controller instance leak (git-fixes).
- nvmet: fix a memory leak (git-fixes).
- block: fix get_max_io_size() (git-fixes).
- nvme-tcp: fix possible hang waiting for icresp response
  (bsc#1179519).
- commit 6431b47
* Wed May 19 2021 hare@suse.de
- nvme: fix possible deadlock when I/O is blocked (git-fixes).
- Delete
  patches.suse/nvme-do-not-update-disk-info-for-multipathed-device.patch.
- commit c1000c4
* Wed May 19 2021 hare@suse.de
- nvme: define constants for identification values (git-fixes).
- commit ef03dba
* Tue May 18 2021 msuchanek@suse.de
- powerpc/64s: Fix crashes when toggling entry flush barrier
  (bsc#1177666 git-fixes).
- powerpc/64s: Fix crashes when toggling stf barrier (bsc#1087082
  git-fixes).
- commit f06d724
* Tue May 18 2021 msuchanek@suse.de
- blk-mq: plug request for shared sbitmap (jsc#SLE-15442
  bsc#1180814 ltc#187461 git-fixes).
- commit d041278
* Tue May 18 2021 tiwai@suse.de
- ACPI: PM: s2idle: Drop unused local variables and related code
  (bsc#1185840).
- commit 1fc2033
* Tue May 18 2021 jdelvare@suse.de
- Delete
  patches.suse/hwmon-amd_energy-01-add-driver-to-report-energy-counters.patch.
- Delete
  patches.suse/hwmon-amd_energy-02-missing-platform_driver_unregister-on.patch.
- Delete
  patches.suse/hwmon-amd_energy-03-match-for-supported-models.patch.
- Delete
  patches.suse/hwmon-amd_energy-04-move-label-out-of-accumulation-structure.patch.
- Delete
  patches.suse/hwmon-amd_energy-05-optimize-accumulation-interval.patch.
- Delete
  patches.suse/hwmon-amd_energy-06-improve-the-accumulation-logic.patch.
- Delete
  patches.suse/hwmon-amd_energy-07-modify-the-visibility-of-the-counters.patch.
- Delete
  patches.suse/hwmon-amd_energy-08-add-family-19h-model-01h.patch.
- Delete
  patches.suse/hwmon-amd_energy-09-fix-allocation-of-hwmon_channel_info.patch.
  As agreed with Jeffrey Cheung and Darren Davis, after the amd_energy
  driver has been removed from upstream due to a disagreement between AMD
  and the hwmon subsystem maintainer on how to mitigate a hardware
  security vulnerability, we will not include this driver in SLE15-SP3. In
  other words, features SLE-15432 and SLE-14261 are being rejected for
  SP3. They will be evaluated again for SP4 if the upstream situation
  changes by then.
- commit 30a5d69
* Tue May 18 2021 tiwai@suse.de
- usb: pci-quirks: disable D3cold on xhci suspend for s2idle on
  AMD Renoire (bsc#1185840).
- commit 5bd67ef
* Tue May 18 2021 tiwai@suse.de
- ACPI / idle: override c-state latency when not in conformance
  with s0ix (bsc#1185840).
- commit 00d00d3
* Tue May 18 2021 tiwai@suse.de
- ACPI: PM: s2idle: Add missing LPS0 functions for AMD
  (bsc#1185840).
- commit 77d36ca
* Tue May 18 2021 tiwai@suse.de
- ACPI: PM: s2idle: Move x86-specific code to the x86 directory
  (bsc#1185840).
- ACPI: PM: s2idle: Add AMD support to handle _DSM (bsc#1185840).
- commit 240ac31
* Tue May 18 2021 lhenriques@suse.de
- fuse: fix write deadlock (bsc#1185573).
- commit f65dbea
* Tue May 18 2021 pjakobsson@suse.de
- drm/i915/overlay: Fix active retire callback alignment
  (git-fixes).
- commit 6ca3a83
* Tue May 18 2021 pjakobsson@suse.de
- drm/i915: Wedge the GPU if command parser setup fails
  (git-fixes).
- commit 331f4cc
* Tue May 18 2021 pjakobsson@suse.de
- drm/amdgpu: remove unused variable from struct amdgpu_bo
  (git-fixes).
- commit e3fca29
* Tue May 18 2021 pjakobsson@suse.de
- Refresh
  patches.suse/0001-drm-i915-Fix-overlay-frontbuffer-tracking.patch.
  Add Alt-commit for duplicate
- commit af0c5c1
* Tue May 18 2021 pjakobsson@suse.de
- drm/amd/display: Initialize attribute for hdcp_srm sysfs file
  (git-fixes).
- commit e983a11
* Tue May 18 2021 pjakobsson@suse.de
- drm/i915: Fix crash in auto_retire (git-fixes).
- commit a0ca792
* Tue May 18 2021 pjakobsson@suse.de
- drm/amdgpu: Init GFX10_ADDR_CONFIG for VCN v3 in DPG mode
  (git-fixes).
- commit 1530740
* Tue May 18 2021 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amdgpu-display-restore-AUX_DPHY_TX_CONTROL-for-D.patch.
  Added Alt-commit for duplicate
- commit 9ad673d
* Tue May 18 2021 pjakobsson@suse.de
- blacklist.conf: 12aca1ce9ee3 drm/msm/disp/dpu1: program 3d_merge only if block is attached
- commit 1e8f219
* Tue May 18 2021 martin.wilck@suse.com
- nvmet: use new ana_log_size instead the old one (bsc#1178612,
  bsc#1184259, bsc#1186155).
- nvme-multipath: fix double initialization of ANA state
  (bsc#1178612, bsc#1184259, bsc#1186155).
- commit 0df107a
* Tue May 18 2021 martin.wilck@suse.com
- nvme: add new line after variable declatation (bsc#1184259,
  bsc#1178612, bsc#1186155).
- nvme: don't check nvme_req flags for new req (bsc#1184259,
  bsc#1178612, bsc#1186155).
- nvme: mark nvme_setup_passsthru() inline (bsc#1184259,
  bsc#1178612, bsc#1186155).
- nvme: split init identify into helper (bsc#1184259, bsc#1178612,
  bsc#1186155).
- nvme: rename nvme_init_identify() (bsc#1184259, bsc#1178612,
  bsc#1186155).
- nvme: reduce checks for zero command effects (bsc#1184259,
  bsc#1178612, bsc#1186155).
- nvme: use NVME_CTRL_CMIC_ANA macro (bsc#1184259, bsc#1178612,
  bsc#1186155).
- commit bb55f2e
* Tue May 18 2021 msuchanek@suse.de
- powerpc/pseries: warn if recursing into the hcall tracing code
  (bsc#1185110 ltc#192091).
- powerpc/pseries: use notrace hcall variant for H_CEDE idle
  (bsc#1185110 ltc#192091).
- powerpc/pseries: Don't trace hcall tracing wrapper (bsc#1185110
  ltc#192091).
- powerpc/pseries: Fix hcall tracing recursion in pv queued
  spinlocks (bsc#1185110 ltc#192091).
- commit b5b9cb5
* Tue May 18 2021 mbrugger@suse.com
- supported.conf: mark usb_otg_fsm as supported (bsc#1185010)
- commit d340e77
* Tue May 18 2021 denis.kirjanov@suse.com
- supported.conf: add bsc1185010 dependency
- commit fb8d746
* Mon May 17 2021 pjakobsson@suse.de
- drm/ingenic: Register devm action to cleanup encoders
  (git-fixes).
- commit 675f1fb
* Mon May 17 2021 martin.wilck@suse.com
- nvmet: use new ana_log_size instead the old one (bsc#1184259).
  note: the upstream commit msg is misleading, this is an nvme host fix,
  not nvmet.
- commit 99e6038
* Mon May 17 2021 pjakobsson@suse.de
- drm/ingenic: Fix non-OSD mode (git-fixes).
- commit 6368ef3
* Mon May 17 2021 pjakobsson@suse.de
- drm/mcde/panel: Inverse misunderstood flag (git-fixes).
- commit e3c909b
* Mon May 17 2021 martin.wilck@suse.com
- nvme: don't intialize hwmon for discovery controllers
  (bsc#1184259).
- commit c0f763f
* Mon May 17 2021 tiwai@suse.de
- kABI workaround for hci_chan amp field addition (CVE-2021-33034
  bsc#1186111).
- commit 82f4155
* Mon May 17 2021 tiwai@suse.de
- Bluetooth: verify AMP hci_chan before amp_destroy
  (CVE-2021-33034 bsc#1186111).
- commit f6d837e
* Mon May 17 2021 tiwai@suse.de
- USB: serial: ti_usb_3410_5052: fix TIOCSSERIAL permission check
  (git-fixes).
- tty: moxa: fix TIOCSSERIAL permission check (git-fixes).
- tty: moxa: fix TIOCSSERIAL jiffies conversions (git-fixes).
- tty: amiserial: fix TIOCSSERIAL permission check (git-fixes).
- commit ec86798
* Mon May 17 2021 tiwai@suse.de
- drm/amd/display: Reject non-zero src_y and src_x for video
  planes (git-fixes).
- PCI: Allow VPD access for QLogic ISP2722 (git-fixes).
- cfg80211: scan: drop entry from hidden_list on overflow
  (git-fixes).
- serial: core: return early on unsupported ioctls (git-fixes).
- serial: stm32: fix tx_empty condition (git-fixes).
- serial: stm32: fix incorrect characters on console (git-fixes).
- commit 4d97fe4
* Mon May 17 2021 glin@suse.com
- libbpf: Fix signed overflow in ringbuf_process_ring
  (bsc#1177028).
- selftests/bpf: Fix BPF_CORE_READ_BITFIELD() macro (bsc#1177028).
- libbpf: Initialize the bpf_seq_printf parameters array field
  by field (bsc#1177028).
- selftests/bpf: Fix the ASSERT_ERR_PTR macro (bsc#1177028).
- libbpf: Add explicit padding to btf_dump_emit_type_decl_opts
  (bsc#1177028).
- selftests/bpf: Re-generate vmlinux.h and BPF skeletons if
  bpftool changed (bsc#1177028).
- libbpf: Add explicit padding to bpf_xdp_set_link_opts
  (bsc#1177028).
- commit c874e76
* Mon May 17 2021 ohering@suse.de
- video: hyperv_fb: Add ratelimit on error message (bsc#1185725).
- Drivers: hv: vmbus: Increase wait time for VMbus unload
  (bsc#1185725).
- Drivers: hv: vmbus: Initialize unload_event statically
  (bsc#1185725).
- Drivers: hv: vmbus: Use after free in __vmbus_open()
  (git-fixes).
- drivers: hv: Fix whitespace errors (bsc#1185725).
- Drivers: hv: vmbus: Fix Suspend-to-Idle for Generation-2 VM
  (git-fixes).
- commit ebeaec2
* Mon May 17 2021 tiwai@suse.de
- iio: tsl2583: Fix division by a zero lux_val (git-fixes).
- iio: gyro: mpu3050: Fix reported temperature value (git-fixes).
- iio: proximity: pulsedlight: Fix rumtime PM imbalance on error
  (git-fixes).
- xhci: Do not use GFP_KERNEL in (potentially) atomic context
  (git-fixes).
- usb: fotg210-hcd: Fix an error message (git-fixes).
- usb: dwc3: gadget: Return success always for kick transfer in
  ep queue (git-fixes).
- usb: dwc2: Fix gadget DMA unmap direction (git-fixes).
- usb: dwc3: pci: Enable usb2-gadget-lpm-disable for Intel
  Merrifield (git-fixes).
- commit c94cc71
* Mon May 17 2021 varad.gautam@suse.com
- ipc/mqueue, msg, sem: Avoid relying on a stack reference past
  its expiry (bsc#1185988).
- commit 5e2321a
* Mon May 17 2021 bp@suse.de
- perf/amd/uncore: Fix sysfs type mismatch (bsc#1178134).
- commit 54f1b43
* Mon May 17 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/powerpc-kexec_file-Use-current-CPU-info-while-settin.patch.
- commit b3db5e3
* Fri May 14 2021 tiwai@suse.de
- Correct CVE number for a mac80211 fix (CVE-2020-26139 bsc#1186062)
- commit 16457bf
* Fri May 14 2021 tiwai@suse.de
- net/nfc: fix use-after-free llcp_sock_bind/connect
  (CVE-2021-23134 bsc#1186060).
- commit ffbe2a6
* Fri May 14 2021 pmladek@suse.com
- watchdog/softlockup: Remove obsolete check of last reported task
  (bsc#1185982).
- commit 6d9c3a2
* Fri May 14 2021 dwagner@suse.de
- nvmet: seset ns->file when open fails (bsc#1183873).
- commit ca1c5ff
* Fri May 14 2021 acho@suse.com
- KVM: s390: fix guarded storage control register handling
  (bsc#1133021).
- commit 6757070
* Fri May 14 2021 tiwai@suse.de
- vgacon: Record video mode changes with VT_RESIZEX (git-fixes).
- hwmon: (occ) Fix poll rate limiting (git-fixes).
- PM / devfreq: Use more accurate returned new_freq as resume_freq
  (git-fixes).
- commit 63ad411
* Fri May 14 2021 dwagner@suse.de
- Update meta data patches.suse/nvme-retrigger-ana-log-update-if-group-descriptor-isn-t.patch
  The patch has been added to mainline. Update the meta data and move it
  into the sorted section.
- commit 7250fb0
* Thu May 13 2021 ematsumiya@suse.de
- nvme: remove superfluous else in nvme_ctrl_loss_tmo_store
  (bsc#1182378).
- commit f263745
* Thu May 13 2021 ematsumiya@suse.de
- nvme: Fix NULL dereference for pci nvme controllers
  (bsc#1182378).
- commit cf7170b
* Thu May 13 2021 ematsumiya@suse.de
- nvme: expose reconnect_delay and ctrl_loss_tmo via sysfs
  (bsc#1182378).
- Refresh patches.suse/nvme-add-kato-sysfs-attribute.patch.
  Context adjustment in kato patch.
- commit 7126f4d
* Wed May 12 2021 tiwai@suse.de
- ath10k kABI workaround for CVE-2020-24588 fix (CVE-2020-24588
  bsc#1185861).
- ath10k: Validate first subframe of A-MSDU before processing
  the list (CVE-2020-26141 bsc#1185863).
- ath10k: Fix TKIP Michael MIC verification for PCIe
  (CVE-2020-26141 bsc#1185863).
- ath10k: drop MPDU which has discard flag set by firmware for
  SDIO (CVE-2020-24588 bsc#1185861).
- ath10k: drop fragments with multicast DA for SDIO
  (CVE-2020-26145 bsc#1185860).
- ath10k: drop fragments with multicast DA for PCIe
  (CVE-2020-26145 bsc#1185860).
- ath10k: add CCMP PN replay protection for fragmented frames
  for PCIe (CVE-2020-26145 bsc#1185860).
- kABI workaround for cfg80211 changes (CVE-2020-24586
  bsc#1185859).
- mac80211: extend protection against mixed key and fragment
  cache attacks (CVE-2020-24586 bsc#1185859).
- mac80211: do not accept/forward invalid EAPOL frames
  (CVE-2020-24587 CVE-2020-24586 bsc#1185863 bsc#1185862
  bsc#1185859).
- mac80211: prevent attacks on TKIP/WEP as well (CVE-2020-24586
  bsc#1185859).
- mac80211: check defrag PN against current frame (CVE-2020-24587
  CVE-2020-24586 bsc#1185863 bsc#1185862 bsc#1185859).
- mac80211: add fragment cache to sta_info (CVE-2020-24587
  CVE-2020-24586 bsc#1185863 bsc#1185859).
- mac80211: drop A-MSDUs on old ciphers (CVE-2020-24587
  CVE-2020-24586 bsc#1185863 bsc#1185862 bsc#1185859).
- mac80211: properly handle A-MSDUs that start with an RFC 1042
  header (CVE-2020-24587 CVE-2020-24586 bsc#1185863 bsc#1185862
  bsc#1185859).
- mac80211: prevent mixed key and fragment cache attacks
  (CVE-2020-24587 CVE-2020-24586 bsc#1185863 bsc#1185862
  bsc#1185859).
- mac80211: assure all fragments are encrypted (CVE-2020-26147
  bsc#1185863 bsc#1185859).
- commit 1aa5a24
* Wed May 12 2021 pmladek@suse.com
- watchdog/softlockup: report the overall time of softlockups
  (bsc#1185982).
- commit 88ee1b3
* Wed May 12 2021 pmladek@suse.com
- watchdog: explicitly update timestamp when reporting softlockup
  (bsc#1185982).
- commit e1f93d5
* Wed May 12 2021 pmladek@suse.com
- watchdog: rename __touch_watchdog() to a better descriptive name
  (bsc#1185982).
- commit c09eacd
* Wed May 12 2021 martin.wilck@suse.com
- Update to mainline version and move into sorted section:
  patches.suse/scsi-fnic-Use-scsi_host_busy_iter-to-traverse-commands.patch (bsc#1179851)
- commit 5bb3cbc
* Wed May 12 2021 martin.wilck@suse.com
- scsi: fnic: Kill 'exclude_id' argument to fnic_cleanup_io()
  (bsc#1179851).
  temporarily disable patches.suse/fnic-use-blk_mq_tagset_busy_iter-to-traverse-commands.patch
- commit da3e4e8
* Wed May 12 2021 martin.wilck@suse.com
- Update upstream references and move into sorted section:
  patches.suse/scsi-fnic-do-not-call-scsi_done-for-unhandled-commands.patch
- commit 0dfec7c
* Wed May 12 2021 tiwai@suse.de
- ath10k: Validate first subframe of A-MSDU before processing
  the list (CVE-2020-26141 bsc#1185863 bsc#1185987).
- commit ea14c35
* Wed May 12 2021 tiwai@suse.de
- ath10k: Fix TKIP Michael MIC verification for PCIe
  (CVE-2020-26141 bsc#1185863 bsc#1185987).
- commit 4eb2710
* Wed May 12 2021 martin.wilck@suse.com
- nvme-multipath: fix double initialization of ANA state
  (bsc#1178612, bsc#1184259).
- commit 4aa67c6
* Wed May 12 2021 tiwai@suse.de
- ath10k kABI workaround for CVE-2020-24588 fix (CVE-2020-24588
  bsc#1185861).
- ath10k: drop MPDU which has discard flag set by firmware for
  SDIO (CVE-2020-24588 bsc#1185861).
- ath10k: drop fragments with multicast DA for SDIO
  (CVE-2020-26145 bsc#1185860).
- ath10k: drop fragments with multicast DA for PCIe
  (CVE-2020-26145 bsc#1185860).
- ath10k: add CCMP PN replay protection for fragmented frames
  for PCIe (CVE-2020-26145 bsc#1185860).
- commit e9158ad
* Wed May 12 2021 tiwai@suse.de
- kABI workaround for cfg80211 changes (CVE-2020-24586
  bsc#1185859).
- mac80211: extend protection against mixed key and fragment
  cache attacks (CVE-2020-24586 bsc#1185859).
- mac80211: do not accept/forward invalid EAPOL frames
  (CVE-2020-24587 CVE-2020-24586 bsc#1185863 bsc#1185862
  bsc#1185859).
- mac80211: prevent attacks on TKIP/WEP as well (CVE-2020-24586
  bsc#1185859).
- mac80211: check defrag PN against current frame (CVE-2020-24587
  CVE-2020-24586 bsc#1185863 bsc#1185862 bsc#1185859).
- mac80211: add fragment cache to sta_info (CVE-2020-24587
  CVE-2020-24586 bsc#1185863 bsc#1185859).
- mac80211: drop A-MSDUs on old ciphers (CVE-2020-24587
  CVE-2020-24586 bsc#1185863 bsc#1185862 bsc#1185859).
- mac80211: properly handle A-MSDUs that start with an RFC 1042
  header (CVE-2020-24587 CVE-2020-24586 bsc#1185863 bsc#1185862
  bsc#1185859).
- mac80211: prevent mixed key and fragment cache attacks
  (CVE-2020-24587 CVE-2020-24586 bsc#1185863 bsc#1185862
  bsc#1185859).
- mac80211: assure all fragments are encrypted (CVE-2020-26147
  bsc#1185863 bsc#1185859).
- commit e747a3d
* Wed May 12 2021 mbenes@suse.cz
- ftrace: Handle commands when closing set_ftrace_filter file
  (git-fixes).
- commit 7c0272c
* Wed May 12 2021 mbenes@suse.cz
- tracing: Map all PIDs to command lines (git-fixes).
- commit ed170f4
* Wed May 12 2021 msuchanek@suse.de
- ibmvfc: Reinit target retries (bsc#1185938 ltc#192043).
- ibmvfc: Avoid move login if fast fail is enabled (bsc#1185938
  ltc#192043).
- ibmvfc: Handle move login failure (bsc#1185938 ltc#192043).
- commit 0d8166b
* Wed May 12 2021 tiwai@suse.de
- xhci: fix potential array out of bounds with several
  interrupters (git-fixes).
- xhci: check control context is valid before dereferencing it
  (git-fixes).
- commit c3f83a0
* Wed May 12 2021 tiwai@suse.de
- usb: gadget: dummy_hcd: fix gpf in gadget_setup (git-fixes).
- usb: core: hub: Fix PM reference leak in usb_port_resume()
  (git-fixes).
- usb: musb: fix PM reference leak in musb_irq_work() (git-fixes).
- usb: xhci: Fix port minor revision (git-fixes).
- usb: gadget: f_uac1: validate input parameters (git-fixes).
- usb: gadget: f_uac2: validate input parameters (git-fixes).
- usb: gadget/function/f_fs string table fix for multiple
  languages (git-fixes).
- usb: webcam: Invalid size of Processing Unit Descriptor
  (git-fixes).
- commit 4c3dc8b
* Wed May 12 2021 tiwai@suse.de
- power: supply: s3c_adc_battery: fix possible use-after-free
  in s3c_adc_bat_remove() (git-fixes).
- power: supply: generic-adc-battery: fix possible use-after-free
  in gab_remove() (git-fixes).
- power: supply: Use IRQF_ONESHOT (git-fixes).
- spi: qup: fix PM reference leak in spi_qup_remove() (git-fixes).
- spi: omap-100k: Fix reference leak to master (git-fixes).
- spi: dln2: Fix reference leak to master (git-fixes).
- spi: ath79: remove spi-master setup and cleanup assignment
  (git-fixes).
- spi: ath79: always call chipselect function (git-fixes).
- usb: gadget: uvc: add bInterval checking for HS mode
  (git-fixes).
- tty: fix memory leak in vc_deallocate (git-fixes).
- commit fbbea32
* Wed May 12 2021 tiwai@suse.de
- mmc: block: Update ext_csd.cache_ctrl if it was written
  (git-fixes).
- mmc: sdhci-pci: Fix initialization of some SD cards for Intel
  BYT-based controllers (git-fixes).
- mmc: sdhci-pci: Add PCI IDs for Intel LKF (git-fixes).
- mmc: sdhci: Check for reset prior to DMA address unmap
  (git-fixes).
- mmc: core: Set read only for SD cards with permanent write
  protect bit (git-fixes).
- PCI: PM: Do not read power state in pci_enable_device_flags()
  (git-fixes).
- phy: phy-twl4030-usb: Fix possible use-after-free in
  twl4030_usb_remove() (git-fixes).
- platform/x86: intel_pmc_core: Don't use global pmcdev in quirks
  (git-fixes).
- commit f8dc44d
* Wed May 12 2021 tiwai@suse.de
- mfd: arizona: Fix rumtime PM imbalance on error (git-fixes).
- mmc: core: Do a power cycle when the CMD11 fails (git-fixes).
- media: dvb-usb: fix memory leak in dvb_usb_adapter_init
  (git-fixes).
- media: platform: sti: Fix runtime PM imbalance in regs_show
  (git-fixes).
- media: i2c: adv7842: fix possible use-after-free in
  adv7842_remove() (git-fixes).
- media: i2c: tda1997: Fix possible use-after-free in
  tda1997x_remove() (git-fixes).
- media: i2c: adv7511-v4l2: fix possible use-after-free in
  adv7511_remove() (git-fixes).
- media: adv7604: fix possible use-after-free in adv76xx_remove()
  (git-fixes).
- media: tc358743: fix possible use-after-free in
  tc358743_remove() (git-fixes).
- commit bddb0b7
* Wed May 12 2021 tiwai@suse.de
- media: em28xx: fix memory leak (git-fixes).
- media: gspca/sq905.c: fix uninitialized variable (git-fixes).
- media: media/saa7164: fix saa7164_encoder_register() memory
  leak bugs (git-fixes).
- media: imx: capture: Return -EPIPE from
  __capture_legacy_try_fmt() (git-fixes).
- media: drivers: media: pci: sta2x11: fix Kconfig dependency
  on GPIOLIB (git-fixes).
- media: ite-cir: check for receive overflow (git-fixes).
- commit f5f8b81
* Wed May 12 2021 tiwai@suse.de
- extcon: arizona: Fix various races on driver unbind (git-fixes).
- extcon: arizona: Fix some issues when HPDET IRQ fires after
  the jack has been unplugged (git-fixes).
- drm/msm/mdp5: Do not multiply vclk line count by 100
  (git-fixes).
- drm/msm/mdp5: Configure PP_SYNC_HEIGHT to double the vtotal
  (git-fixes).
- drm/amdgpu: fix NULL pointer dereference (git-fixes).
- drm/amdkfd: Fix cat debugfs hang_hws file causes system crash
  bug (git-fixes).
- drm/vkms: fix misuse of WARN_ON (git-fixes).
- drm/amd/display: fix dml prefetch validation (git-fixes).
- intel_th: Consistency and off-by-one fix (git-fixes).
- fbdev: zero-fill colormap in fbcmap.c (git-fixes).
- commit e59ac4d
* Wed May 12 2021 tiwai@suse.de
- drm/amd/display: Fix UBSAN warning for not a valid value for
  type '_Bool' (git-fixes).
- drm/amdgpu : Fix asic reset regression issue introduce by
  8f211fe8ac7c4f (git-fixes).
- drm/amdgpu: mask the xgmi number of hops reported from psp to
  kfd (git-fixes).
- drm: Added orientation quirk for OneGX1 Pro (git-fixes).
- crypto: stm32/cryp - Fix PM reference leak on stm32-cryp.c
  (git-fixes).
- crypto: stm32/hash - Fix PM reference leak on stm32-hash.c
  (git-fixes).
- crypto: qat - Fix a double free in adf_create_ring (git-fixes).
- crypto: qat - fix error path in adf_isr_resource_alloc()
  (git-fixes).
- commit 4f7d7a0
* Wed May 12 2021 tiwai@suse.de
- clk: socfpga: arria10: Fix memory leak of socfpga_clk on error
  return (git-fixes).
- ata: ahci: Disable SXS for Hisilicon Kunpeng920 (git-fixes).
- amdgpu: avoid incorrect %%hu format string (git-fixes).
- crypto: qat - ADF_STATUS_PF_RUNNING should be set after
  adf_dev_init (git-fixes).
- crypto: qat - don't release uninitialized resources (git-fixes).
- crypto: qat - fix unmap invalid dma address (git-fixes).
- crypto: api - check for ERR pointers in crypto_destroy_tfm()
  (git-fixes).
- crypto: mips/poly1305 - enable for all MIPS processors
  (git-fixes).
- commit e379274
* Wed May 12 2021 tiwai@suse.de
- Move upstreamed media fixes into sorted section
- commit 5bae3a8
* Wed May 12 2021 acho@suse.com
- bluetooth: eliminate the potential race condition when removing
  the HCI controller (bsc#1184611 CVE-2021-32399).
- commit b57a022
* Wed May 12 2021 glin@suse.com
- bpf: Prevent writable memory-mapping of read-only ringbuf pages
  (bsc#1185640 CVE-2021-3489).
- bpf, ringbuf: Deny reserve of buffers larger than ringbuf
  (bsc#1185640 CVE-2021-3489).
- bpf: Fix alu32 const subreg bound tracking on bitwise operations
  (bsc#1185641 CVE-2021-3490).
- commit c0fa121
* Wed May 12 2021 glin@suse.com
- scripts/git_sort/git_sort.py: add bpf git repo
- commit 65979e3
* Tue May 11 2021 ddiss@suse.de
- proc: Avoid mixing integer types in mem_rw() (CVE-2021-3491
  bsc#1185642).
- commit 757f76b
* Tue May 11 2021 mkubecek@suse.cz
- blacklist: add commit b166a20b0738
  Mainline commit b166a20b0738 ("net/sctp: fix race condition in
  sctp_destroy_sock") was found buggy so that it was reverted by commit
  01bfe5e8e428 ("Revert "net/sctp: fix race condition in sctp_destroy_sock"")
  and replaced by a new fix, commit 34e5b0118685 ("sctp: delay auto_asconf
  init until binding the first addr").
- commit 7c2eabc
* Tue May 11 2021 mkubecek@suse.cz
- sctp: delay auto_asconf init until binding the first addr
  (<cover.1620748346.git.mkubecek@suse.cz>).
- commit cb84c72
* Tue May 11 2021 mkubecek@suse.cz
- tcp: fix to update snd_wl1 in bulk receiver fast path
  (<cover.1620748346.git.mkubecek@suse.cz>).
- commit 627e2e2
* Tue May 11 2021 tiwai@suse.de
- Update patch reference for BT fix (CVE-2021-32399 bsc#1185898)
- commit 81179ec
* Mon May 10 2021 dbueso@suse.de
- Revert 337f13046ff0 ("futex: Allow FUTEX_CLOCK_REALTIME with FUTEX_WAIT op") (git-fixes).
- commit 9e8eea0
* Mon May 10 2021 mkubecek@suse.cz
- series.conf: cleanup
- move a submitted patch to "almost mainline" section
  patches.suse/rtc-pcf2127-handle-timestamp-interrupts.patch
- commit baf1232
* Mon May 10 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/fs-epoll-restore-waking-from-ep_done_scan.patch
- commit 220b548
* Mon May 10 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/nvme-multipath-reset-bdev-to-ns-head-when-failover.patch
  patches.suse/scsi-lpfc-Fix-DMA-virtual-address-ptr-assignment-in-.patch
  patches.suse/scsi-lpfc-Fix-illegal-memory-access-on-Abort-IOCBs.patch
- commit a062422
* Mon May 10 2021 tiwai@suse.de
- drm/radeon: Avoid power table parsing memory leaks (git-fixes).
- drm/radeon: Fix off-by-one power_state index heap overwrite
  (git-fixes).
- commit dad28e7
* Mon May 10 2021 glin@suse.com
- bpf: Fix leakage of uninitialized bpf stack under speculation
  (bsc#1155518).
- bpf: Fix masking negation logic upon negative dst register
  (bsc#1155518).
- commit 876c85a
* Mon May 10 2021 glin@suse.com
- bpf: Fix propagation of 32 bit unsigned bounds from 64 bit
  bounds (bsc#1177028).
- commit 26f1fe9
* Sat May  8 2021 tiwai@suse.de
- ALSA: usb-audio: Remove redundant assignment to len (git-fixes).
- ALSA: usb-audio: Generic application of implicit fb to
  Roland/BOSS devices (git-fixes).
- Revert "ALSA: usb-audio: Add support for many Roland
  devices..." (git-fixes).
- ALSA: usb-audio: Re-apply implicit feedback mode to Pioneer
  devices (git-fixes).
- ALSA: usb-audio: Add support for many Roland devices' implicit
  feedback quirks (git-fixes).
- ALSA: usb-audio: Apply implicit feedback mode for BOSS devices
  (git-fixes).
- ALSA: usb-audio: Skip probe of UA-101 devices (git-fixes).
- ALSA: usb-audio: Drop implicit fb quirk entries dubbed for
  capture (git-fixes).
- ALSA: usb-audio: Check connector value on resume (git-fixes).
- ALSA: usb-audio: Carve out connector value checking into a
  helper (git-fixes).
- ALSA: usb-audio: fix Pioneer DJM-850 control label info
  (git-fixes).
- ALSA: usb-audio: Declare Pioneer DJM-850 mixer controls
  (git-fixes).
- ALSA: usb-audio: Add Pioneer DJM-850 to quirks-table
  (git-fixes).
- ALSA: usb-audio: generate midi streaming substream names from
  jack names (git-fixes).
- ALSA: usb-audio: use usb headers rather than define structs
  locally (git-fixes).
- commit 66017db
* Sat May  8 2021 tiwai@suse.de
- ALSA: usb-audio: Add implicit feeback support for the BOSS GT-1
  (git-fixes).
- Refresh
  patches.suse/ALSA-usb-audio-Add-implicit-fb-quirk-for-BOSS-GP-10.patch.
- Refresh
  patches.suse/ALSA-usb-audio-Add-quirk-for-BOSS-AD-10.patch.
- Refresh patches.suse/ALSA-usb-audio-Add-quirk-for-RC-505.patch.
- commit 430c145
* Sat May  8 2021 tiwai@suse.de
- ALSA: hda/realtek: Add fixup for HP OMEN laptop (git-fixes).
- ALSA: hda/realtek: Fix speaker amp on HP Envy AiO 32
  (git-fixes).
- ALSA: hda/realtek: Fix silent headphone output on ASUS UX430UA
  (git-fixes).
- ALSA: usb-audio: Add dB range mapping for Sennheiser
  Communications Headset PC 8 (git-fixes).
- ALSA: hda/realtek: Enable mute/micmute LEDs and limit mic
  boost on EliteBook 845 G8 (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 445 G7
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Lenovo Ideapad S740
  (git-fixes).
- commit 0e8dbae
* Sat May  8 2021 tiwai@suse.de
- ALSA: hda: generic: change the DAC ctl name for LO+SPK or LO+HP
  (git-fixes).
- commit cb198d3
* Sat May  8 2021 tiwai@suse.de
- Revert "i3c master: fix missing destroy_workqueue() on error
  in i3c_master_register" (git-fixes).
- ACPI: GTDT: Don't corrupt interrupt mappings on watchdow probe
  failure (git-fixes).
- ALSA: hda/realtek: ALC285 Thinkpad jack pin quirk is unreachable
  (git-fixes).
- USB: Add reset-resume quirk for WD19's Realtek Hub (git-fixes).
- USB: Add LPM quirk for Lenovo ThinkPad USB-C Dock Gen2 Ethernet
  (git-fixes).
- platform/x86: thinkpad_acpi: Correct thermal sensor allocation
  (git-fixes).
- commit 23adf05
* Fri May  7 2021 dbueso@suse.de
- fs/epoll: restore waking from ep_done_scan() (bsc#1183868).
- commit b803549
* Fri May  7 2021 jroedel@suse.de
- iommu/amd: Add support for map/unmap_resource (jsc#ECO-3482).
- commit 7b9e3ca
* Fri May  7 2021 ptesarik@suse.cz
- s390/pci: fix leak of PCI device structure (git-fixes).
- vfio-pci/zdev: fix possible segmentation fault issue
  (git-fixes).
- s390/zcrypt: return EIO when msg retry limit reached
  (git-fixes).
- commit 5abd9df
* Fri May  7 2021 tiwai@suse.de
- ACPI: custom_method: fix a possible memory leak (git-fixes).
- ACPI: custom_method: fix potential use-after-free issue
  (git-fixes).
- commit 2b51e47
* Thu May  6 2021 msuchanek@suse.de
- kernel-docs.spec.in: Build using an utf-8 locale.
  Sphinx cannot handle UTF-8 input in non-UTF-8 locale.
- commit 0db6da1
* Thu May  6 2021 heming.zhao@suse.com
- md-cluster: fix use-after-free issue when removing rdev
  (bsc#1184082).
- md: split mddev_find (bsc#1184081).
- md: factor out a mddev_find_locked helper from mddev_find
  (bsc#1184081).
- md: md_open returns -EBUSY when entering racing area
  (bsc#1184081).
- md: don't flush workqueue unconditionally in md_open
  (bsc#1184081).
- commit 255ac58
* Thu May  6 2021 msuchanek@suse.de
- genirq: Reduce irqdebug cacheline bouncing (bsc#1185703
  ltc#192641).
- commit 54b345b
* Thu May  6 2021 tiwai@suse.de
- PCI: dwc: Move iATU detection earlier (git-fixes).
- PCI: keystone: Let AM65 use the pci_ops defined in
  pcie-designware-host.c (git-fixes).
- thermal: thermal_of: Fix error return code of
  thermal_of_populate_bind_params() (git-fixes).
- commit 48dc8db
* Thu May  6 2021 tiwai@suse.de
- PCI: iproc: Fix return value of iproc_msi_irq_domain_alloc()
  (git-fixes).
- PCI: endpoint: Fix missing destroy_workqueue() (git-fixes).
- PCI/RCEC: Fix RCiEP device to RCEC association (git-fixes).
- PCI: Release OF node in pci_scan_device()'s error path
  (git-fixes).
- thermal/drivers/ti-soc-thermal/bandgap Remove unused variable
  'val' (git-fixes).
- docs: kernel-parameters: Add gpio_mockup_named_lines
  (git-fixes).
- docs: kernel-parameters: Move gpio-mockup for alphabetic order
  (git-fixes).
- commit 6976ceb
* Wed May  5 2021 ematsumiya@suse.de
- md/raid1: properly indicate failure when ending a failed write
  request (bsc#1185680).
- commit 67fde5a
* Wed May  5 2021 mbenes@suse.cz
- s390/entry: save the caller of psw_idle (bsc#1185677).
- commit d82aadb
* Wed May  5 2021 ykaukab@suse.de
- rtc: pcf2127: handle timestamp interrupts (bsc#1185495).
- commit f74f90f
* Wed May  5 2021 ykaukab@suse.de
- bus: fsl-mc: list more commands as accepted through the ioctl
  (bsc#1185670).
- bus: fsl-mc: add the dpdbg device type (bsc#1185670).
- commit 6325c23
* Wed May  5 2021 msuchanek@suse.de
- Update patches.suse/powerpc-eeh-Fix-EEH-handling-for-hugepages-in-iorema.patch
  (bsc#1156395 bsc#1185645 ltc#192576).
- commit b0c1c70
* Wed May  5 2021 mbrugger@suse.com
- spi: cadence: set cqspi to the driver_data field of struct
  device (git-fixes).
- commit e8779a2
* Wed May  5 2021 mbrugger@suse.com
- i2c: mlxbf: add IRQ check (git-fixes).
- commit 571342e
* Wed May  5 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/mm-memcontrol-fix-cpuhotplug-statistics-flushing.patch
- commit fc7f89c
* Wed May  5 2021 mkubecek@suse.cz
- Update kabi files.
- update from May 2021 maintenance update submission (commit 0a8fae2b39f2)
- commit 8a0c3f3
* Wed May  5 2021 tiwai@suse.de
- dmaengine: idxd: Fix potential null dereference on pointer
  status (git-fixes).
- commit 287f8f1
* Wed May  5 2021 msuchanek@suse.de
- powerpc/kexec_file: Use current CPU info while setting up FDT
  (bsc#1184615 ltc#189835).
- commit 21c8a7e
* Wed May  5 2021 mbrugger@suse.com
- Update config files. (bsc#1185010)
- supported.conf:
- commit 8888052
* Wed May  5 2021 mkubecek@suse.cz
- rpm: drop /usr/bin/env in interpreter specification
  OBS checks don't like /usr/bin/env in script interpreter lines but upstream
  developers tend to use it. A proper solution would be fixing the depedency
  extraction and drop the OBS check error but that's unlikely to happen so
  that we have to work around the problem on our side and rewrite the
  interpreter lines in scripts before collecting files for packages instead.
- commit 45c5c1a
* Wed May  5 2021 lduncan@suse.com
- scsi: smartpqi: Update version to 1.2.16-012 (bsc#1178089).
- scsi: smartpqi: Correct pqi_sas_smp_handler busy condition
  (bsc#1178089).
- scsi: smartpqi: Correct driver removal with HBA disks
  (bsc#1178089).
- commit d9b38b9
* Tue May  4 2021 dwagner@suse.de
- nvme: add 'kato' sysfs attribute (bsc#1179825).
- nvme: sanitize KATO setting (bsc#1179825).
- commit f3a2791
* Tue May  4 2021 oneukum@suse.com
- patches.suse/NFC-nxp-nci-Add-GPIO-ACPI-mapping-table.patch:
  (bsc#1185589).
- commit 4004e31
* Tue May  4 2021 oneukum@suse.com
- patches.suse/NFC-nxp-nci-Convert-to-use-GPIO-descriptor.patch:
  (bsc#1185589).
- commit a3f193f
* Tue May  4 2021 oneukum@suse.com
- patches.suse/NFC-nxp-nci-Get-rid-of-platform-data.patch:
  (bsc#1185589).
- commit 3e24d09
* Tue May  4 2021 tiwai@suse.de
- rtc: ds1307: Fix wday settings for rx8130 (git-fixes).
- mmc: sdhci-of-dwcmshc: fix rpmb access (git-fixes).
- commit d21fbb6
* Tue May  4 2021 oneukum@linux.fritz.box
- patches.suse/NFC-nxp-nci-Add-NXP1001-to-the-ACPI-ID-table.patch:
  (bsc#1185589).
- commit 68d285a
* Tue May  4 2021 mkoutny@suse.com
- mm: memcontrol: fix cpuhotplug statistics flushing
  (bsc#1185606).
- commit 3bba386
* Tue May  4 2021 dwagner@suse.de
- nvme-multipath: reset bdev to ns head when failover (bsc#178378
  bsc#1182999).
  Refresh:
  - patches.suse/nvme-multipath-retry-commands-for-dying-queues.patch
- commit ee2dc7b
* Tue May  4 2021 dwagner@suse.de
- scripts/git_sort/git_sort.py: Update nvme repositories
- commit e849c44
* Tue May  4 2021 msuchanek@suse.de
- blacklist.conf: Add ppc kuap/uaccess fixes not applicable to SP2
- commit 4b4ca8e
* Mon May  3 2021 msuchanek@suse.de
- powerpc/eeh: Fix EEH handling for hugepages in ioremap space
  (bsc#1156395).
- powerpc/time: Enable sched clock for irqtime (bsc#1156395).
- commit 5ee4c93
* Mon May  3 2021 msuchanek@suse.de
- powerpc/perf: Fix PMU constraint check for EBB events
  (bsc#1065729).
- powerpc/64s: Fix pte update for kernel memory on radix
  (bsc#1055117 git-fixes).
- powerpc/asm-offsets: GPR14 is not needed either (bsc#1065729).
- powerpc/prom: Mark identical_pvr_fixup as __init (bsc#1065729).
- powerpc/fadump: Mark fadump_calculate_reserve_size as __init
  (bsc#1065729).
- commit e08fbf4
* Mon May  3 2021 msuchanek@suse.de
- powerpc/perf: Fix the threshold event selection for memory
  events in power10 (jsc#SLE-13513).
- powerpc/perf: Fix sampled instruction type for larx/stcx
  (jsc#SLE-13513).
- powerpc/smp: Reintroduce cpu_core_mask (jsc#SLE-13615
  bsc#1180100 ltc#190257 git-fixes).
- powerpc/xive: Drop check on irq_data in xive_core_debug_show()
  (bsc#1177437 ltc#188522 jsc#SLE-13294 git-fixes).
- powerpc/xmon: Fix build failure for 8xx (jsc#SLE-12936
  git-fixes).
- commit 84bf014
* Mon May  3 2021 msuchanek@suse.de
- KVM: PPC: Book3S HV P9: Restore host CTRL SPR after guest exit
  (bsc#1156395).
- KVM: PPC: Make the VMX instruction emulation routines static
  (bsc#1156395).
- commit 66099c4
* Mon May  3 2021 fdmanana@suse.com
- btrfs: fix race between swap file activation and snapshot
  creation (bsc#1185587).
- btrfs: fix race between writes to swap files and scrub
  (bsc#1185586).
- commit fef5517
* Mon May  3 2021 fdmanana@suse.com
- btrfs: fix race between swap file activation and snapshot
  creation (bsc#1185587).
- btrfs: fix race between writes to swap files and scrub
  (bsc#1185586).
- commit 517921a
* Mon May  3 2021 mkubecek@suse.cz
- series.conf: cleanup
- move into "almost mainline" section
  patches.suse/rtc-fsl-ftm-alarm-add-MODULE_TABLE.patch
- commit 75e25e9
* Mon May  3 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/x86-platform-uv-set-section-block-size-for-hubless-architectures.patch
- commit 5cf9a28
* Mon May  3 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort
  patches.suse/powerpc-mm-Add-cond_resched-while-removing-hpte-mapp.patch
  patches.suse/powerpc-papr_scm-Fix-build-error-due-to-wrong-printf.patch
  patches.suse/powerpc-papr_scm-Implement-support-for-H_SCM_FLUSH-h.patch
  patches.suse/powerpc-pseries-Add-shutdown-to-vio_driver-and-vio_b.patch
  patches.suse/scsi-lpfc-Change-wording-of-invalid-pci-reset-log-me.patch
  patches.suse/scsi-lpfc-Correct-function-header-comments-related-t.patch
  patches.suse/scsi-lpfc-Fix-ADISC-handling-that-never-frees-nodes.patch
  patches.suse/scsi-lpfc-Fix-FLOGI-failure-due-to-accessing-a-freed.patch
  patches.suse/scsi-lpfc-Fix-PLOGI-ACC-to-be-transmit-after-REG_LOG.patch
  patches.suse/scsi-lpfc-Fix-crash-caused-by-switch-reboot.patch
  patches.suse/scsi-lpfc-Fix-dropped-FLOGI-during-pt2pt-discovery-r.patch
  patches.suse/scsi-lpfc-Fix-incorrect-dbde-assignment-when-buildin.patch
  patches.suse/scsi-lpfc-Fix-lpfc_els_retry-possible-null-pointer-d.patch
  patches.suse/scsi-lpfc-Fix-nodeinfo-debugfs-output.patch
  patches.suse/scsi-lpfc-Fix-null-pointer-dereference-in-lpfc_prep_.patch
  patches.suse/scsi-lpfc-Fix-pt2pt-connection-does-not-recover-afte.patch
  patches.suse/scsi-lpfc-Fix-pt2pt-state-transition-causing-rmmod-h.patch
  patches.suse/scsi-lpfc-Fix-reftag-generation-sizing-errors.patch
  patches.suse/scsi-lpfc-Fix-stale-node-accesses-on-stale-RRQ-reque.patch
  patches.suse/scsi-lpfc-Fix-status-returned-in-lpfc_els_retry-erro.patch
  patches.suse/scsi-lpfc-Fix-unnecessary-null-check-in-lpfc_release.patch
  patches.suse/scsi-lpfc-Fix-use-after-free-in-lpfc_els_free_iocb.patch
  patches.suse/scsi-lpfc-Fix-vport-indices-in-lpfc_find_vport_by_vp.patch
  patches.suse/scsi-lpfc-Reduce-LOG_TRACE_EVENT-logging-for-vports.patch
  patches.suse/scsi-lpfc-Update-copyrights-for-12.8.0.7-and-12.8.0..patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.8.patch
  patches.suse/scsi-qla2xxx-Reserve-extra-IRQ-vectors.patch
  patches.suse/selftests-powerpc-Fix-L1D-flushing-tests-for-Power10.patch
- commit e03aa0a
* Mon May  3 2021 msuchanek@suse.de
- ibmvnic: queue reset work in system_long_wq (bsc#1152457
  ltc#174432 git-fixes).
- ibmvnic: improve failover sysfs entry (bsc#1043990 ltc#155681
  git-fixes).
- ibmvnic: print adapter state as a string (bsc#1152457 ltc#174432
  git-fixes).
- ibmvnic: print reset reason as a string (bsc#1152457 ltc#174432
  git-fixes).
- ibmvnic: clean up the remaining debugfs data structures
  (bsc#1065729).
- ibmvnic: remove duplicate napi_schedule call in open function
  (bsc#1065729).
- ibmvnic: remove duplicate napi_schedule call in do_reset
  function (bsc#1065729).
- ibmvnic: avoid calling napi_disable() twice (bsc#1065729).
- commit 5d92f24
* Mon May  3 2021 msuchanek@suse.de
- cpuidle/pseries: Fixup CEDE0 latency only for POWER10 onwards
  (bsc#1185550 ltc#192610).
- commit 19688a8
* Mon May  3 2021 ptesarik@suse.cz
- ima: Free IMA measurement buffer after kexec syscall
  (git-fixes).
- commit 2cf366a
* Mon May  3 2021 lhenriques@suse.de
- virtiofs: fix memory leak in virtio_fs_probe() (bsc#1185558).
- commit bc3eb47
* Mon May  3 2021 wqu@suse.com
- btrfs: fix qgroup data rsv leak caused by falloc failure
  (bsc#1185549).
- commit 210f7a5
* Mon May  3 2021 wqu@suse.com
- btrfs: track qgroup released data in own variable in
  insert_prealloc_file_extent (bsc#1185549).
- commit 4d34a1c
* Sat May  1 2021 tiwai@suse.de
- ALSA: hda/conexant: Re-order CX5066 quirk table entries
  (git-fixes).
- ASoC: rsnd: check all BUSIF status when error (git-fixes).
- ASoC: wm8960: Remove bitclk relax condition in
  wm8960_configure_sysclk (git-fixes).
- ASoC: samsung: snow: remove useless test (git-fixes).
- ASoC: Intel: boards: sof-wm8804: add check for PLL setting
  (git-fixes).
- drm/i915/gt: Clear CACHE_MODE prior to clearing residuals
  (git-fixes).
- commit 18fa88e
* Sat May  1 2021 tiwai@suse.de
- ALSA: hda/realtek: Remove redundant entry for ALC861
  Haier/Uniwill devices (git-fixes).
- ALSA: hda/realtek: Re-order ALC662 quirk table entries
  (git-fixes).
- ALSA: hda/realtek: Re-order remaining ALC269 quirk table entries
  (git-fixes).
- ALSA: hda/realtek: Re-order ALC269 Lenovo quirk table entries
  (git-fixes).
- ALSA: hda/realtek: Re-order ALC269 Sony quirk table entries
  (git-fixes).
- ALSA: hda/realtek: Re-order ALC269 ASUS quirk table entries
  (git-fixes).
- ALSA: hda/realtek: Re-order ALC269 Dell quirk table entries
  (git-fixes).
- ALSA: hda/realtek: Re-order ALC269 Acer quirk table entries
  (git-fixes).
- ALSA: hda/realtek: Re-order ALC269 HP quirk table entries
  (git-fixes).
- ALSA: hda/realtek: Re-order ALC882 Clevo quirk table entries
  (git-fixes).
- ALSA: hda/realtek: Re-order ALC882 Sony quirk table entries
  (git-fixes).
- ALSA: hda/realtek: Re-order ALC882 Acer quirk table entries
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Intel Clevo PCx0Dx (git-fixes).
- ALSA: hda/cirrus: Use CS8409 filter to fix abnormal sounds on
  Bullseye (git-fixes).
- ALSA: hda/cirrus: Set Initial DMIC volume for Bullseye to -26 dB
  (git-fixes).
- ALSA: sb: Fix two use after free in snd_sb_qsound_build
  (git-fixes).
- ASoC: Intel: kbl_da7219_max98927: Fix kabylake_ssp_fixup
  function (git-fixes).
- ALSA: emu8000: Fix a use after free in snd_emu8000_create_mixer
  (git-fixes).
- ALSA: hda/realtek - Headset Mic issue on HP platform
  (git-fixes).
- ALSA: usb-audio: DJM-750: ensure format is set (git-fixes).
- ALSA: hda/realtek: GA503 use same quirks as GA401 (git-fixes).
- ALSA: hda/realtek: fix mic boost on Intel NUC 8 (git-fixes).
- ALSA: usb-audio: Explicitly set up the clock selector
  (git-fixes).
- ALSA: usb-audio: Add MIDI quirk for Vox ToneLab EX (git-fixes).
- ALSA: hda/cirrus: Make CS8409 driver more generic by using
  fixups (git-fixes).
- ALSA: hda/cirrus: Fix CS42L42 Headset Mic volume control name
  (git-fixes).
- ALSA: hda/cirrus: Cleanup patch_cirrus.c code (git-fixes).
- ALSA: hda/cirrus: Add error handling into CS8409 I2C functions
  (git-fixes).
- ALSA: hda/cirrus: Add Headphone and Headset MIC Volume Control
  (git-fixes).
- ALSA: hda/cirrus: Add jack detect interrupt support from
  CS42L42 companion codec (git-fixes).
- ALSA: hda/cirrus: Add support for CS8409 HDA bridge and CS42L42
  companion codec (git-fixes).
- ALSA: usb-audio: Configure Pioneer DJM-850 samplerate
  (git-fixes).
- ALSA: usb-audio: Fix Pioneer DJM devices URB_CONTROL request
  direction to set samplerate (git-fixes).
- ALSA: usb-audio: Add DJM450 to Pioneer format quirk (git-fixes).
- commit 82d06eb
* Sat May  1 2021 tiwai@suse.de
- i2c: sh7760: fix IRQ error path (git-fixes).
- commit e315f49
* Sat May  1 2021 tiwai@suse.de
- pinctrl: core: Fix kernel doc string for pin_get_name()
  (git-fixes).
- pinctrl: Ingenic: Add missing pins to the JZ4770 MAC MII group
  (git-fixes).
- i2c: sh7760: add IRQ check (git-fixes).
- i2c: jz4780: add IRQ check (git-fixes).
- i2c: emev2: add IRQ check (git-fixes).
- commit da2180a
* Sat May  1 2021 tiwai@suse.de
- i2c: cadence: add IRQ check (git-fixes).
- i2c: sprd: fix reference leak when pm_runtime_get_sync fails
  (git-fixes).
- i2c: omap: fix reference leak when pm_runtime_get_sync fails
  (git-fixes).
- i2c: imx-lpi2c: fix reference leak when pm_runtime_get_sync
  fails (git-fixes).
- i2c: img-scb: fix reference leak when pm_runtime_get_sync fails
  (git-fixes).
- HID: plantronics: Workaround for double volume key presses
  (git-fixes).
- ASoC: ak5558: correct reset polarity (git-fixes).
- ASoC: simple-card: fix possible uninitialized single_cpu local
  variable (git-fixes).
- ASoC: ak5558: Fix s/show/slow/ typo (git-fixes).
- ASoC: samsung: tm2_wm5110: check of of_parse return value
  (git-fixes).
- ALSA: hda/realtek: fix static noise on ALC285 Lenovo laptops
  (git-fixes).
- ALSA: usb-audio: Fix implicit sync clearance at stopping stream
  (git-fixes).
- ALSA: usb: midi: don't return -ENOMEM when usb_urb_ep_type_check
  fails (git-fixes).
- ALSA: usb-audio: Add error checks for
  usb_driver_claim_interface() calls (git-fixes).
- ALSA: core: remove redundant spin_lock pair in
  snd_card_disconnect (git-fixes).
- drm/i915/gvt: Fix error code in intel_gvt_init_device()
  (git-fixes).
- commit 2b66742
* Fri Apr 30 2021 tiwai@suse.de
- ath10k: Fix a use after free in ath10k_htc_send_bundle
  (git-fixes).
- mt76: mt7915: fix aggr len debugfs node (git-fixes).
- rtw88: Fix an error code in rtw_debugfs_set_rsvd_page()
  (git-fixes).
- Bluetooth: avoid deadlock between hci_dev->lock and socket lock
  (git-fixes).
- commit 38c8cc4
* Fri Apr 30 2021 tiwai@suse.de
- net: geneve: modify IP header check in geneve6_xmit_skb and
  geneve_xmit_skb (git-fixes).
- commit f8b6668
* Fri Apr 30 2021 tiwai@suse.de
- net:nfc:digital: Fix a double free in digital_tg_recv_dep_req
  (git-fixes).
- net: phy: marvell: fix m88e1111_set_downshift (git-fixes).
- net: phy: marvell: fix m88e1011_set_downshift (git-fixes).
- net: phy: intel-xway: enable integrated led functions
  (git-fixes).
- ath10k: Fix ath10k_wmi_tlv_op_pull_peer_stats_info() unlock
  without lock (git-fixes).
- ath9k: Fix error check in ath9k_hw_read_revisions() for PCI
  devices (git-fixes).
- mac80211: bail out if cipher schemes are invalid (git-fixes).
- rtw88: Fix array overrun in rtw_get_tx_power_params()
  (git-fixes).
- rsi: Use resume_noirq for SDIO (git-fixes).
- ipw2x00: potential buffer overflow in libipw_wx_set_encodeext()
  (git-fixes).
- rtlwifi: 8821ae: upgrade PHY and RF parameters (git-fixes).
- mt7601u: fix always true expression (git-fixes).
- liquidio: Fix unintented sign extension of a left shift of a
  u16 (git-fixes).
- nfc: pn533: prevent potential memory corruption (git-fixes).
- commit 4c3b252
* Fri Apr 30 2021 schwab@suse.de
- rpm/constraints.in: bump disk space to 45GB on riscv64
- commit f8b883f
* Fri Apr 30 2021 dwagner@suse.de
- scsi: qla2xxx: Reuse existing error handling path (bsc#1185491).
- scsi: qla2xxx: Remove unneeded if-null-free check (bsc#1185491).
- scsi: qla2xxx: Update version to 10.02.00.106-k (bsc#1185491).
- scsi: qla2xxx: Do logout even if fabric scan retries got
  exhausted (bsc#1185491).
- scsi: qla2xxx: Update default AER debug mask (bsc#1185491).
- scsi: qla2xxx: Fix mailbox recovery during PCIe error
  (bsc#1185491).
- scsi: qla2xxx: Fix crash in PCIe error handling (bsc#1185491).
- scsi: qla2xxx: Fix RISC RESET completion polling (bsc#1185491).
- scsi: qla2xxx: Fix crash in qla2xxx_mqueuecommand()
  (bsc#1185491).
- scsi: qla2xxx: Fix use after free in bsg (bsc#1185491).
- scsi: qla2xxx: Consolidate zio threshold setting for both FCP &
  NVMe (bsc#1185491).
- scsi: qla2xxx: Fix stuck session (bsc#1185491).
- scsi: qla2xxx: Add H:C:T info in the log message for fc ports
  (bsc#1185491).
- scsi: qla2xxx: Fix IOPS drop seen in some adapters
  (bsc#1185491).
- scsi: qla2xxx: Check kzalloc() return value (bsc#1185491).
- scsi: qla2xxx: Always check the return value of
  qla24xx_get_isp_stats() (bsc#1185491).
- scsi: qla2xxx: Simplify qla8044_minidump_process_control()
  (bsc#1185491).
- scsi: qla2xxx: Suppress Coverity complaints about dseg_r*
  (bsc#1185491).
- scsi: qla2xxx: Fix endianness annotations (bsc#1185491).
- scsi: qla2xxx: Constify struct qla_tgt_func_tmpl (bsc#1185491).
- scsi: qla2xxx: Use dma_pool_zalloc() (bsc#1185491).
- scsi: qla2xxx: Fix a couple of misdocumented functions
  (bsc#1185491).
- scsi: qla2xxx: Fix incorrectly named function
  qla8044_check_temp() (bsc#1185491).
- scsi: qla2xxx: Fix a couple of misnamed functions (bsc#1185491).
- scsi: qla2xxx: Fix some incorrect formatting/spelling issues
  (bsc#1185491).
- scsi: qla2xxx: Replace __qla2x00_marker()'s missing underscores
  (bsc#1185491).
- scsi: qla2xxx: Fix broken #endif placement (bsc#1185491).
- scsi: qla2xxx: Simplify if statement (bsc#1185491).
- scsi: qla2xxx: Simplify the calculation of variables
  (bsc#1185491).
- scsi: qla2xxx: Fix some memory corruption (bsc#1185491).
- scsi: qla2xxx: Remove redundant NULL check (bsc#1185491).
- scsi: qla2xxx: Remove unnecessary NULL check (bsc#1185491).
- scsi: qla2xxx: Assign boolean values to a bool variable
  (bsc#1185491).
- scsi: qla2xxx: fc_remote_port_chkready() returns a SCSI result
  value (bsc#1185491).
- scsi: qla2xxx: Update version to 10.02.00.105-k (bsc#1185491).
- scsi: qla2xxx: Enable NVMe CONF (BIT_7) when enabling SLER
  (bsc#1185491).
- scsi: qla2xxx: Fix mailbox Ch erroneous error (bsc#1185491).
- scsi: qla2xxx: Wait for ABTS response on I/O timeouts for NVMe
  (bsc#1185491).
- scsi: qla2xxx: Move some messages from debug to normal log level
  (bsc#1185491).
- scsi: qla2xxx: Add error counters to debugfs node (bsc#1185491).
- scsi: qla2xxx: Implementation to get and manage host, target
  stats and initiator port (bsc#1185491).
- commit db29123
* Fri Apr 30 2021 dwagner@suse.de
- Remove patches.suse/scsi-qla2xxx-Make-sure-that-aborted-commands-are-fre.patch
  Upstream commit 39c0c8553bfb ("scsi: Revert "qla2xxx: Make sure that
  aborted commands are freed"") reverts the patch.
- commit 311c2c6
* Thu Apr 29 2021 dwagner@suse.de
- scsi: lpfc: Fix DMA virtual address ptr assignment in bsg
  (bsc#1185365).
- scsi: lpfc: Fix illegal memory access on Abort IOCBs
  (bsc#1183203).
- scsi: lpfc: Copyright updates for 12.8.0.9 patches
  (bsc#1185472).
- scsi: lpfc: Update lpfc version to 12.8.0.9 (bsc#1185472).
- scsi: lpfc: Eliminate use of LPFC_DRIVER_NAME in lpfc_attr.c
  (bsc#1185472).
- scsi: lpfc: Standardize discovery object logging format
  (bsc#1185472).
- scsi: lpfc: Fix various trivial errors in comments and log
  messages (bsc#1185472).
- scsi: lpfc: Remove unsupported mbox PORT_CAPABILITIES logic
  (bsc#1185472).
- scsi: lpfc: Fix lpfc_hdw_queue attribute being ignored
  (bsc#1185472).
- scsi: lpfc: Fix missing FDMI registrations after Mgmt Svc login
  (bsc#1185472).
- scsi: lpfc: Fix silent memory allocation failure in
  lpfc_sli4_bsg_link_diag_test() (bsc#1185472).
- scsi: lpfc: Fix use-after-free on unused nodes after port swap
  (bsc#1185472).
- scsi: lpfc: Fix error handling for mailboxes completed in
  MBX_POLL mode (bsc#1185472).
- scsi: lpfc: Fix lack of device removal on port swaps with PRLIs
  (bsc#1185472).
- scsi: lpfc: Fix NMI crash during rmmod due to circular hbalock
  dependency (bsc#1185472).
- scsi: lpfc: Fix reference counting errors in lpfc_cmpl_els_rsp()
  (bsc#1185472).
- scsi: lpfc: Fix crash when a REG_RPI mailbox fails triggering
  a LOGO response (bsc#1185472).
- scsi: lpfc: Fix rmmod crash due to bad ring pointers to
  abort_iotag (bsc#1185472).
- scsi: lpfc: Fix gcc -Wstringop-overread warning (bsc#1185472).
- scsi: lpfc: Fix a typo (bsc#1185472).
- scsi: lpfc: Fix kernel-doc formatting issue (bsc#1185472).
- scsi: lpfc: Fix a few incorrectly named functions (bsc#1185472).
- scsi: lpfc: Fix incorrectly documented function
  lpfc_debugfs_commonxripools_data() (bsc#1185472).
- scsi: lpfc: Fix a bunch of misnamed functions (bsc#1185472).
- scsi: lpfc: Fix a bunch of kernel-doc misdemeanours
  (bsc#1185472).
- scsi: lpfc: Fix incorrect naming of __lpfc_update_fcf_record()
  (bsc#1185472).
- scsi: lpfc: Fix formatting and misspelling issues (bsc#1185472).
- scsi: lpfc: Fix a bunch of kernel-doc issues (bsc#1185472).
- scsi: lpfc: Fix some error codes in debugfs (bsc#1185472).
- commit a4fa91e
* Thu Apr 29 2021 dwagner@suse.de
- series.conf: Resort and update meta data
-  meta data refreshed:
  patches.suse/scsi-lpfc-Change-wording-of-invalid-pci-reset-log-me.patch
  patches.suse/scsi-lpfc-Correct-function-header-comments-related-t.patch
  patches.suse/scsi-lpfc-Fix-ADISC-handling-that-never-frees-nodes.patch
  patches.suse/scsi-lpfc-Fix-FLOGI-failure-due-to-accessing-a-freed.patch
  patches.suse/scsi-lpfc-Fix-PLOGI-ACC-to-be-transmit-after-REG_LOG.patch
  patches.suse/scsi-lpfc-Fix-crash-caused-by-switch-reboot.patch
  patches.suse/scsi-lpfc-Fix-dropped-FLOGI-during-pt2pt-discovery-r.patch
  patches.suse/scsi-lpfc-Fix-incorrect-dbde-assignment-when-buildin.patch
  patches.suse/scsi-lpfc-Fix-lpfc_els_retry-possible-null-pointer-d.patch
  patches.suse/scsi-lpfc-Fix-nodeinfo-debugfs-output.patch
  patches.suse/scsi-lpfc-Fix-null-pointer-dereference-in-lpfc_prep_.patch
  patches.suse/scsi-lpfc-Fix-pt2pt-connection-does-not-recover-afte.patch
  patches.suse/scsi-lpfc-Fix-pt2pt-state-transition-causing-rmmod-h.patch
  patches.suse/scsi-lpfc-Fix-reftag-generation-sizing-errors.patch
  patches.suse/scsi-lpfc-Fix-stale-node-accesses-on-stale-RRQ-reque.patch
  patches.suse/scsi-lpfc-Fix-status-returned-in-lpfc_els_retry-erro.patch
  patches.suse/scsi-lpfc-Fix-unnecessary-null-check-in-lpfc_release.patch
  patches.suse/scsi-lpfc-Fix-use-after-free-in-lpfc_els_free_iocb.patch
  patches.suse/scsi-lpfc-Fix-vport-indices-in-lpfc_find_vport_by_vp.patch
  patches.suse/scsi-lpfc-Reduce-LOG_TRACE_EVENT-logging-for-vports.patch
  patches.suse/scsi-lpfc-Update-copyrights-for-12.8.0.7-and-12.8.0..patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.8.patch
  patches.suse/scsi-qla2xxx-Reserve-extra-IRQ-vectors.patch
- commit 27785f8
* Thu Apr 29 2021 bp@suse.de
- x86/platform/uv: Set section block size for hubless
  architectures (bsc#1152489).
- commit 47e611e
* Thu Apr 29 2021 ykaukab@suse.de
- rtc: fsl-ftm-alarm: add MODULE_TABLE() (bsc#1185454).
- rtc: fsl-ftm-alarm: update acpi device id (bsc#1185454).
- rtc: fsl-ftm-alarm: fix freeze(s2idle) failed to wake
  (bsc#1185454).
- rtc: fsl-ftm-alarm: report alarm to core (bsc#1185454).
- rtc: fsl-ftm-alarm: enable acpi support (bsc#1185454).
- rtc: fsl-ftm-alarm: avoid struct rtc_time conversions
  (bsc#1185454).
- rtc: fsl-ftm-alarm: switch to rtc_time64_to_tm/rtc_tm_to_time64
  (bsc#1185454).
- rtc: fsl-ftm-alarm: switch to ktime_get_real_seconds
  (bsc#1185454).
- commit 10147b2
* Thu Apr 29 2021 oneukum@suse.com
- reintroduce cqhci_suspend for kABI (git-fixes).
- commit eb30081
* Thu Apr 29 2021 msuchanek@suse.de
- blk-mq: set default elevator as deadline in case of hctx shared
  tagset (jsc#SLE-15442 bsc#1180814 ltc#187461 git-fixes).
- commit 55cfd5d
* Thu Apr 29 2021 msuchanek@suse.de
- Refresh sorted section.
- commit b0d2a3b
* Thu Apr 29 2021 tiwai@suse.de
- vfio/mdev: Do not allow a mdev_type to have a NULL parent
  pointer (git-fixes).
- vfio/mdev: Make to_mdev_device() into a static inline
  (git-fixes).
- vfio/pci: Re-order vfio_pci_probe() (git-fixes).
- vfio/pci: Move VGA and VF initialization to functions
  (git-fixes).
- drm/radeon: Fix a missing check bug in radeon_dp_mst_detect()
  (git-fixes).
- drm: xlnx: zynqmp: fix a memset in zynqmp_dp_train()
  (git-fixes).
- drm/probe-helper: Check epoch counter in output_poll_execute()
  (git-fixes).
- drm/amd/display: Fix off by one in hdmi_14_process_transaction()
  (git-fixes).
- drm/panfrost: Don't try to map pages that are already mapped
  (git-fixes).
- drm/panfrost: Clear MMU irqs before handling the fault
  (git-fixes).
- drm/tilcdc: send vblank event when disabling crtc (git-fixes).
- commit fe92c5a
* Thu Apr 29 2021 tiwai@suse.de
- Fix series.conf sorted section
- commit 6795229
* Thu Apr 29 2021 tiwai@suse.de
- media: staging/intel-ipu3: Fix race condition during set_fmt
  (git-fixes).
- commit 7053b04
* Thu Apr 29 2021 tiwai@suse.de
- mmc: mmc_spi: Drop unused NO_IRQ definition (git-fixes).
- mmc: core: Correct descriptions in mmc_of_parse() (git-fixes).
- sata_mv: add IRQ checks (git-fixes).
- pata_ipx4xx_cf: fix IRQ check (git-fixes).
- pata_arasan_cf: fix IRQ check (git-fixes).
- rsxx: remove extraneous 'const' qualifier (git-fixes).
- pinctrl: lewisburg: Update number of pins in community
  (git-fixes).
- net: geneve: check skb is large enough for IPv4/IPv6 header
  (git-fixes).
- commit 8cd08fd
* Thu Apr 29 2021 tiwai@suse.de
- mfd: lpc_sch: Partially revert "Add support for Intel Quark
  X1000" (git-fixes).
- mfd: stm32-timers: Avoid clearing auto reload register
  (git-fixes).
- mmc: uniphier-sd: Fix a resource leak in the remove function
  (git-fixes).
- mmc: uniphier-sd: Fix an error handling path in
  uniphier_sd_probe() (git-fixes).
- media: staging/intel-ipu3: Fix memory leak in imu_fmt
  (git-fixes).
- media: v4l2-ctrls.c: fix race condition in hdl->requests list
  (git-fixes).
- media: staging/intel-ipu3: Fix set_fmt error handling
  (git-fixes).
- media: dvbdev: Fix memory leak in dvb_media_device_free()
  (git-fixes).
- media: m88rs6000t: avoid potential out-of-bounds reads on arrays
  (git-fixes).
- commit e24fcb3
* Thu Apr 29 2021 tiwai@suse.de
- drm/omap: fix misleading indentation in pixinc() (git-fixes).
- drm/amdkfd: fix build error with AMD_IOMMU_V2=m (git-fixes).
- media: mantis: remove orphan mantis_core.c (git-fixes).
- media: platform: sunxi: sun6i-csi: fix error return code of
  sun6i_video_start_streaming() (git-fixes).
- media: omap4iss: return error code when omap4iss_get() failed
  (git-fixes).
- gpio: omap: Save and restore sysconfig (git-fixes).
- HID: wacom: Assign boolean values to a bool variable
  (git-fixes).
- HID: alps: fix error return code in alps_input_configured()
  (git-fixes).
- HID: google: add don USB id (git-fixes).
- commit 20a3b3a
* Thu Apr 29 2021 tiwai@suse.de
- clk: uniphier: Fix potential infinite loop (git-fixes).
- clk: zynqmp: move zynqmp_pll_set_mode out of round_rate callback
  (git-fixes).
- clk: exynos7: Mark aclk_fsys1_200 as critical (git-fixes).
- clk: qcom: a53-pll: Add missing MODULE_DEVICE_TABLE (git-fixes).
- backlight: journada720: Fix Wmisleading-indentation warning
  (git-fixes).
- ata: libahci_platform: fix IRQ check (git-fixes).
- drm/radeon: fix copy of uninitialized variable back to userspace
  (git-fixes).
- commit f116afa
* Wed Apr 28 2021 lduncan@suse.com
- scsi: smartpqi: Update version to 1.2.16-012 (bsc#1178089).
- scsi: smartpqi: Correct pqi_sas_smp_handler busy condition
  (bsc#1178089).
- scsi: smartpqi: Correct driver removal with HBA disks
  (bsc#1178089).
- commit 1fed21d
* Wed Apr 28 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/x86-microcode-check-for-offline-cpus-before-requesting-new-microcode.patch
- commit 86da738
* Wed Apr 28 2021 bp@suse.de
- x86/microcode: Check for offline CPUs before requesting new
  microcode (bsc#1152489).
- commit 720943a
* Wed Apr 28 2021 oneukum@suse.com
- mmc: cqhci: Add cqhci_deactivate() (git-fixes).
- commit e46a789
* Wed Apr 28 2021 oneukum@suse.com
- mmc: sdhci-of-dwcmshc: implement specific set_uhs_signaling
  (git-fixes).
- commit 78a20b1
* Wed Apr 28 2021 oneukum@suse.com
- mmc: sdhci-of-esdhc: make sure delay chain locked for HS400
  (git-fixes).
- commit b9124c1
* Wed Apr 28 2021 oneukum@suse.com
- mmc: sdhci-of-esdhc: set timeout to max before tuning
  (git-fixes).
- commit 3690227
* Wed Apr 28 2021 oneukum@suse.com
- mmc: sdhci: Use Auto CMD Auto Select only when v4_mode is true
  (git-fixes).
- commit 23cd005
* Wed Apr 28 2021 oneukum@suse.com
- mmc: sdhci-pci: Fix SDHCI_RESET_ALL for CQHCI for Intel
  GLK-based controllers (git-fixes).
- Refresh
  patches.suse/mmc-sdhci-pci-Prefer-SDR25-timing-for-High-Speed-mod.patch.
- commit 9dd1a55
* Wed Apr 28 2021 oneukum@suse.com
- blacklist.conf: prerequisites break kABI
- commit 2c4445c
* Wed Apr 28 2021 oneukum@suse.com
- mmc: sdhci-of-arasan: Add missed checks for devm_clk_register()
  (git-fixes).
- commit 72c0b64
* Wed Apr 28 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/perf-x86-intel-uncore-remove-uncore-extra-pci-dev-hswep_pci_pcu_3.patch.
- commit dbaac01
* Wed Apr 28 2021 oneukum@suse.com
- blacklist.conf: fixes a compiler warning only
- commit 2e1acc1
* Wed Apr 28 2021 oneukum@suse.com
- blacklist.conf: fixes a compiler warning only
- commit 0566d04
* Wed Apr 28 2021 jslaby@suse.cz
- rpm/constraints.in: remove aarch64 disk size exception
  obs://Kernel:stable/kernel-default/ARM/aarch64 currrently fails:
  installing package kernel-default-livepatch-devel-5.12.0-3.1.g6208a83.aarch64 needs 3MB more space on the / filesystem
  The stats say:
  Maximal used disk space: 31799 Mbyte
  By default, we require 35G. For aarch64 we had an exception to lower
  this limit to 30G there. Drop this exception as it is obviously no
  longer valid.
- commit ee00b50
* Tue Apr 27 2021 bp@suse.de
- x86/crash: Fix crash_setup_memmap_entries() out-of-bounds access
  (bsc#1152489).
- commit 542e5a3
* Tue Apr 27 2021 ykaukab@suse.de
- mtd: spi-nor: Split mt25qu512a (n25q512a) entry into two
  (bsc#1167260).
- mtd: spi-nor: Rename "n25q512a" to "mt25qu512a (n25q512a)"
  (bsc#1167260).
- commit 2c1a6eb
* Tue Apr 27 2021 ykaukab@suse.de
- spi: fsl-dspi: fix wrong pointer in suspend/resume
  (bsc#1167260).
- spi: spi-fsl-dspi: use XSPI mode instead of DMA for DPAA2 SoCs
  (bsc#1167260).
- spi: spi-fsl-dspi: delete EOQ transfer mode (bsc#1167260).
- spi: spi-fsl-dspi: set ColdFire to DMA mode (bsc#1167260).
- spi: fsl-dspi: fix NULL pointer dereference (bsc#1167260).
- spi: fsl-dspi: fix use-after-free in remove path (bsc#1167260).
- spi: spi-fsl-dspi: Initialize completion before possible
  interrupt (bsc#1167260).
- spi: spi-fsl-dspi: Fix external abort on interrupt in resume
  or exit paths (bsc#1167260).
- spi: spi-fsl-dspi: Fix lockup if device is shutdown during
  SPI transfer (bsc#1167260).
- spi: spi-fsl-dspi: Fix lockup if device is removed during SPI
  transfer (bsc#1167260).
- spi: spi-fsl-dspi: Free DMA memory with matching function
  (bsc#1167260).
- spi: spi-fsl-dspi: fix native data copy (bsc#1167260).
- spi: spi-fsl-dspi: Adding shutdown hook (bsc#1167260).
- spi: spi-fsl-dspi: Add support for LS1028A (bsc#1167260).
- commit e0a1590
* Tue Apr 27 2021 oneukum@suse.com
- blacklist.conf: cosmetic fix
- commit 501d484
* Tue Apr 27 2021 oneukum@suse.com
- blacklist.conf: breaks kABI
- commit 25e087f
* Tue Apr 27 2021 oneukum@suse.com
- blacklist.conf: patch is a kABI cleanup
- commit dc817ec
* Tue Apr 27 2021 oneukum@suse.com
- usb: roles: Call try_module_get() from
  usb_role_switch_find_by_fwnode() (git-fixes).
- commit 1892580
* Tue Apr 27 2021 oneukum@suse.com
- usb: typec: tps6598x: Fix return value check in tps6598x_probe()
  (git-fixes).
- commit aa90e03
* Tue Apr 27 2021 ykaukab@suse.de
- spi: spi-fsl-dspi: Move invariant configs out of
  dspi_transfer_one_message (bsc#1167260).
- spi: spi-fsl-dspi: Fix interrupt-less DMA mode taking an XSPI
  code path (bsc#1167260).
- spi: spi-fsl-dspi: Avoid NULL pointer in dspi_slave_abort for
  non-DMA mode (bsc#1167260).
- spi: spi-fsl-dspi: Replace interruptible wait queue with a
  simple completion (bsc#1167260).
- spi: spi-fsl-dspi: Protect against races on
  dspi->words_in_flight (bsc#1167260).
- spi: spi-fsl-dspi: Avoid reading more data than written in
  EOQ mode (bsc#1167260).
- spi: spi-fsl-dspi: Fix bits-per-word acceleration in DMA mode
  (bsc#1167260).
- spi: spi-fsl-dspi: Fix little endian access to PUSHR CMD and
  TXDATA (bsc#1167260).
- spi: spi-fsl-dspi: Don't access reserved fields in SPI_MCR
  (bsc#1167260).
- spi: spi-fsl-dspi: fix DMA mapping (bsc#1167260).
- spi: spi-fsl-dspi: Take software timestamp in dspi_fifo_write
  (bsc#1167260).
- spi: spi-fsl-dspi: Use EOQ for last word in buffer even for
  XSPI mode (bsc#1167260).
- spi: spi-fsl-dspi: Optimize dspi_setup_accel for lowest
  interrupt count (bsc#1167260).
- spi: spi-fsl-dspi: Accelerate transfers using larger word size
  if possible (bsc#1167260).
- spi: spi-fsl-dspi: Convert TCFQ users to XSPI FIFO mode
  (bsc#1167260).
- spi: spi-fsl-dspi: Implement .max_message_size method for EOQ
  mode (bsc#1167260).
- spi: spi-fsl-dspi: Rename fifo_{read,write} and
  {tx,cmd}_fifo_write (bsc#1167260).
- spi: spi-fsl-dspi: Add comments around dspi_pop_tx and
  dspi_push_rx functions (bsc#1167260).
- spi: spi-fsl-dspi: Don't mask off undefined bits (bsc#1167260).
- spi: spi-fsl-dspi: Remove unused chip->void_write_data
  (bsc#1167260).
- spi: spi-fsl-dspi: Simplify bytes_per_word gymnastics
  (bsc#1167260).
- spi: spi-fsl-dspi: Make bus-num property optional (bsc#1167260).
- spi: spi-fsl-dspi: Convert the instantiations that support it
  to DMA (bsc#1167260).
- commit 7e2481c
* Tue Apr 27 2021 oneukum@suse.com
- USB: CDC-ACM: fix poison/unpoison imbalance (bsc#1184984).
- commit 264efc3
* Tue Apr 27 2021 tiwai@suse.de
- Revert "mtd: spi-nor: macronix: Add support for mx25l51245g"
  (git-fixes).
- firmware: qcom_scm: Fix kernel-doc function names to match
  (git-fixes).
- firmware: qcom_scm: Workaround lack of "is available" call on
  SC7180 (git-fixes).
- firmware: qcom_scm: Reduce locking section for
  __get_convention() (git-fixes).
- firmware: qcom_scm: Make __qcom_scm_is_call_available() return
  bool (git-fixes).
- usb: roles: Call try_module_get() from
  usb_role_switch_find_by_fwnode() (git-fixes).
- usb: typec: tps6598x: Fix return value check in tps6598x_probe()
  (git-fixes).
- usb: xhci-mtk: improve bandwidth scheduling with TT (git-fixes).
- usb: xhci-mtk: remove or operator for setting schedule
  parameters (git-fixes).
- mfd: intel_pmt: Fix nuisance messages and handling of disabled
  capabilities (git-fixes).
- crypto: chelsio - Read rxchannel-id from firmware (git-fixes).
- commit ca30721
* Tue Apr 27 2021 tiwai@suse.de
- usb: dwc2: Fix hibernation between host and device modes
  (git-fixes).
- usb: dwc2: Fix host mode hibernation exit with remote wakeup
  flow (git-fixes).
- USB: serial: fix return value for unsupported ioctls
  (git-fixes).
- USB: serial: usb_wwan: fix TIOCGSERIAL implementation
  (git-fixes).
- USB: serial: usb_wwan: fix unprivileged TIOCCSERIAL (git-fixes).
- USB: serial: usb_wwan: fix TIOCSSERIAL jiffies conversions
  (git-fixes).
- USB: serial: ssu100: fix TIOCGSERIAL implementation (git-fixes).
- commit 4c3112d
* Tue Apr 27 2021 tiwai@suse.de
- USB: serial: quatech2: fix TIOCGSERIAL implementation
  (git-fixes).
- USB: serial: opticon: fix TIOCGSERIAL implementation
  (git-fixes).
- USB: serial: mos7720: fix TIOCGSERIAL implementation
  (git-fixes).
- USB: serial: f81534: fix TIOCGSERIAL implementation (git-fixes).
- USB: serial: f81232: fix TIOCGSERIAL implementation (git-fixes).
- USB: serial: ark3116: fix TIOCGSERIAL implementation
  (git-fixes).
- USB: CDC-ACM: fix poison/unpoison imbalance (git-fixes).
- usb: dwc3: gadget: Fix START_TRANSFER link state check
  (git-fixes).
- usb: gadget: Fix double free of device descriptor pointers
  (git-fixes).
- usb: typec: tcpm: Honour pSnkStdby requirement during
  negotiation (git-fixes).
- commit 5c40ba7
* Tue Apr 27 2021 tiwai@suse.de
- USB: cdc-acm: fix TIOCGSERIAL implementation (git-fixes).
- USB: cdc-acm: fix unprivileged TIOCCSERIAL (git-fixes).
- Revert "USB: cdc-acm: fix rounding error in TIOCSSERIAL"
  (git-fixes).
- usb: gadget: r8a66597: Add missing null check on return from
  platform_get_resource (git-fixes).
- usb: typec: tcpm: Address incorrect values of tcpm psy for
  fixed supply (git-fixes).
- usb: dwc2: Fix session request interrupt handler (git-fixes).
- USB: gadget: udc: fix wrong pointer passed to IS_ERR() and
  PTR_ERR() (git-fixes).
- usb: gadget: aspeed: fix dma map failure (git-fixes).
- usb: gadget: pch_udc: Revert d3cb25a12138 completely
  (git-fixes).
- usb: gadget: pch_udc: Move pch_udc_init() to satisfy kernel doc
  (git-fixes).
- commit fb519e4
* Tue Apr 27 2021 tiwai@suse.de
- spi: fsl-lpspi: Fix PM reference leak in
  lpspi_prepare_xfer_hardware() (git-fixes).
- spi: spi-ti-qspi: Free DMA resources (git-fixes).
- soc: aspeed: fix a ternary sign expansion bug (git-fixes).
- usb: gadget: pch_udc: Check for DMA mapping error (git-fixes).
- usb: gadget: pch_udc: Check if driver is present before calling
  - >setup() (git-fixes).
- usb: gadget: pch_udc: Replace cpu_to_le32() by lower_32_bits()
  (git-fixes).
- usb: typec: tcpci: Check ROLE_CONTROL while interpreting
  CC_STATUS (git-fixes).
- soundwire: stream: fix memory leak in stream config error path
  (git-fixes).
- soundwire: bus: Fix device found flag correctly (git-fixes).
- commit d16f444
* Tue Apr 27 2021 tiwai@suse.de
- regulator: Avoid a double 'of_node_get' in
  'regulator_of_get_init_node()' (git-fixes).
- regmap: set debugfs_name to NULL after it is freed (git-fixes).
- mtd: rawnand: gpmi: Fix a double free in gpmi_nand_init
  (git-fixes).
- PM: runtime: Add documentation for pm_runtime_resume_and_get()
  (git-fixes).
- soc: qcom: mdt_loader: Detect truncated read of segments
  (git-fixes).
- soc: qcom: mdt_loader: Validate that p_filesz < p_memsz
  (git-fixes).
- staging: rtl8192u: Fix potential infinite loop (git-fixes).
- node: fix device cleanups in error handling code (git-fixes).
- phy: marvell: ARMADA375_USBCLUSTER_PHY should not default to y,
  unconditionally (git-fixes).
- platform/x86: pmc_atom: Match all Beckhoff Automation baytrail
  boards with critclk_systems DMI table (git-fixes).
- commit ab0d991
* Tue Apr 27 2021 tiwai@suse.de
- mtd: spinand: core: add missing MODULE_DEVICE_TABLE()
  (git-fixes).
- mtd: rawnand: atmel: Update ecc_stats.corrected counter
  (git-fixes).
- mtd: rawnand: qcom: Return actual error code instead of -ENODEV
  (git-fixes).
- mtd: Handle possible -EPROBE_DEFER from parse_mtd_partitions()
  (git-fixes).
- mtd: rawnand: brcmnand: fix OOB R/W with Hamming ECC
  (git-fixes).
- mtd: rawnand: fsmc: Fix error code in fsmc_nand_probe()
  (git-fixes).
- mtd: require write permissions for locking and badblock ioctls
  (git-fixes).
- misc: vmw_vmci: explicitly initialize vmci_datagram payload
  (git-fixes).
- misc: vmw_vmci: explicitly initialize vmci_notify_bm_set_msg
  struct (git-fixes).
- misc: lis3lv02d: Fix false-positive WARN on various HP models
  (git-fixes).
- commit e422d77
* Tue Apr 27 2021 tiwai@suse.de
- memory: pl353: fix mask of ECC page_size config register
  (git-fixes).
- memory: gpmc: fix out of bounds read and dereference on
  gpmc_cs[] (git-fixes).
- fotg210-udc: Complete OUT requests on short packets (git-fixes).
- fotg210-udc: Don't DMA more than the buffer can take
  (git-fixes).
- staging: fwserial: fix TIOCGSERIAL implementation (git-fixes).
- staging: fwserial: fix TIOCSSERIAL implementation (git-fixes).
- staging: fwserial: fix TIOCSSERIAL permission check (git-fixes).
- staging: fwserial: fix TIOCSSERIAL jiffies conversions
  (git-fixes).
- iio:accel:adis16201: Fix wrong axis assignment that prevents
  loading (git-fixes).
- commit b5d6098
* Tue Apr 27 2021 tiwai@suse.de
- cpufreq: Kconfig: fix documentation links (git-fixes).
- cpufreq: armada-37xx: Fix determining base CPU frequency
  (git-fixes).
- fotg210-udc: Mask GRP2 interrupts we don't handle (git-fixes).
- fotg210-udc: Remove a dubious condition leading to fotg210_done
  (git-fixes).
- fotg210-udc: Fix EP0 IN requests bigger than two packets
  (git-fixes).
- fotg210-udc: Fix DMA on EP0 for length > max packet size
  (git-fixes).
- firmware: qcom-scm: Fix QCOM_SCM configuration (git-fixes).
- crypto: arm/curve25519 - Move '.fpu' after '.arch' (git-fixes).
- crypto: rng - fix crypto_rng_reset() refcounting when
  !CRYPTO_STATS (git-fixes).
- commit 781f7bc
* Tue Apr 27 2021 tiwai@suse.de
- cpufreq: armada-37xx: Fix driver cleanup when registration
  failed (git-fixes).
- clk: mvebu: armada-37xx-periph: Fix workaround for switching
  from L1 to L0 (git-fixes).
- clk: mvebu: armada-37xx-periph: Fix switching CPU freq from
  250 Mhz to 1 GHz (git-fixes).
- cpufreq: armada-37xx: Fix the AVS value for load L1 (git-fixes).
- clk: mvebu: armada-37xx-periph: remove .set_parent method for
  CPU PM clock (git-fixes).
- cpufreq: armada-37xx: Fix setting TBG parent for load levels
  (git-fixes).
- ACPI: CPPC: Replace cppc_attr with kobj_attribute (git-fixes).
- bus: qcom: Put child node before return (git-fixes).
- bluetooth: eliminate the potential race condition when removing
  the HCI controller (git-fixes).
- commit d53d421
* Mon Apr 26 2021 ykaukab@suse.de
- spi: spi-fsl-dspi: LS2080A and LX2160A support XSPI mode
  (bsc#1167260).
- spi: spi-fsl-dspi: Parameterize the FIFO size and DMA buffer
  size (bsc#1167260).
- spi: spi-fsl-dspi: Use specific compatible strings for all
  SoC instantiations (bsc#1167260).
- spi: spi-fsl-dspi: Use dma_request_chan() instead
  dma_request_slave_channel() (bsc#1167260).
- spi: spi-fsl-dspi: Fix 16-bit word order in 32-bit XSPI mode
  (bsc#1167260).
- spi: spi-fsl-dspi: Always use the TCFQ devices in poll mode
  (bsc#1167260).
- spi: Introduce dspi_slave_abort() function for NXP's dspi SPI
  driver (bsc#1167260).
- spi: spi-fsl-dspi: Fix race condition in TCFQ/EOQ interrupt
  (bsc#1167260).
- spi: spi-fsl-dspi: Use poll mode in case the platform IRQ is
  missing (bsc#1167260).
- spi: spi-fsl-dspi: Remove impossible to reach error check
  (bsc#1167260).
- spi: spi-fsl-dspi: Exit the ISR with IRQ_NONE when it's not ours
  (bsc#1167260).
- spi: spi-fsl-dspi: Reduce indentation level in dspi_interrupt
  (bsc#1167260).
- spi: spi-fsl-dspi: Move dspi_interrupt above
  dspi_transfer_one_message (bsc#1167260).
- spi: spi-fsl-dspi: Fix typos (bsc#1167260).
- spi: spi-fsl-dspi: Use reverse Christmas tree declaration order
  (bsc#1167260).
- spi: spi-fsl-dspi: Replace legacy spi_master names with
  spi_controller (bsc#1167260).
- spi: spi-fsl-dspi: Remove pointless assignment of
  master->transfer to NULL (bsc#1167260).
- spi: spi-fsl-dspi: Remove unused initialization of 'ret'
  in dspi_probe (bsc#1167260).
- spi: spi-fsl-dspi: Reduce indentation in dspi_release_dma()
  (bsc#1167260).
- spi: spi-fsl-dspi: Change usage pattern of SPI_MCR_* and
  SPI_CTAR_* macros (bsc#1167260).
- spi: spi-fsl-dspi: Demistify magic value in SPI_SR_CLEAR
  (bsc#1167260).
- spi: spi-fsl-dspi: Use BIT() and GENMASK() macros (bsc#1167260).
- spi: spi-fsl-dspi: Remove unused defines and includes
  (bsc#1167260).
- spi: spi-fsl-dspi: Fix code alignment (bsc#1167260).
- commit 9437971
* Mon Apr 26 2021 ykaukab@suse.de
- spi: spi-fsl-dspi: remove git-fixes
  Remove git-fixes. Prepare to update the driver.
  References: bsc#1167260
- commit 47a4219
* Mon Apr 26 2021 bp@suse.de
- netfilter: x_tables: Use correct memory barriers (bsc#1184208
  CVE-2021-29650).
- commit a2dbe0f
* Mon Apr 26 2021 msuchanek@suse.de
- libnvdimm/region: Fix nvdimm_has_flush() to handle
  ND_REGION_ASYNC (bsc#1184969 git-fixes).
- libnvdimm/label: Return -ENXIO for no slot in __blk_label_update
  (bsc#1185269).
- libnvdimm/namespace: Fix reaping of invalidated
  block-window-namespace labels (bsc#1185269).
- libnvdimm/security: ensure sysfs poll thread woke up and fetch
  updated attr (FATE#325581 git-fixes).
- commit d1f996e
* Mon Apr 26 2021 ykaukab@suse.de
- arm: dts: add imx7d pcf2127 fix to blacklist
- commit d57b89d
* Sun Apr 25 2021 dbueso@suse.de
- locking/qrwlock: Fix ordering in queued_write_lock_slowpath() (bsc#1185041).
- commit 06bc03e
* Sun Apr 25 2021 tiwai@suse.de
- Drop i915 patches that caused a regression on IVB (bsc#1184943)
  Deleted:
  patches.suse/drm-i915-gt-Clear-CACHE_MODE-prior-to-clearing-resid.patch
  patches.suse/drm-i915-gt-Flush-before-changing-register-state.patch
  patches.suse/drm-i915-gt-One-more-flush-for-Baytrail-clear-residu.patch
- commit 0a944a4
* Fri Apr 23 2021 martin.wilck@suse.com
- rpm/macros.kernel-source: fix KMP failure in %%install (bsc#1185244)
- commit 58c17cd
* Fri Apr 23 2021 martin.wilck@suse.com
- Revert "scsi: be2iscsi: Fix a theoretical leak in beiscsi_create_eqs()"
  (bsc#1185038)
  This reverts commit 9b829c278737b522a63301c27e6e947c9ed4accf.
  Reverted upstream.
- commit 73b3872
* Fri Apr 23 2021 denis.kirjanov@suse.com
- net: ll_temac: Handle DMA halt condition caused by buffer
  underrun (git-fixes).
- commit 2c8041a
* Fri Apr 23 2021 denis.kirjanov@suse.com
- net: ll_temac: Fix RX buffer descriptor handling on GFP_ATOMIC
  pressure (git-fixes).
- commit d2da394
* Fri Apr 23 2021 denis.kirjanov@suse.com
- net: ll_temac: Add more error handling of dma_map_single()
  calls (git-fixes).
- commit d046726
* Fri Apr 23 2021 denis.kirjanov@suse.com
- net: ll_temac: Fix race condition causing TX hang (git-fixes).
- commit a6721f5
* Fri Apr 23 2021 denis.kirjanov@suse.com
- net: atlantic: fix out of range usage of active_vlans array
  (git-fixes).
- commit 4472105
* Fri Apr 23 2021 denis.kirjanov@suse.com
- net: atlantic: fix potential error handling (git-fixes).
- commit 972b18c
* Fri Apr 23 2021 denis.kirjanov@suse.com
- net: atlantic: fix use after free kasan warn (git-fixes).
- commit e77e662
* Fri Apr 23 2021 denis.kirjanov@suse.com
- net: stmmac: xgmac: fix missing IFF_MULTICAST checki in
  dwxgmac2_set_filter (git-fixes).
- commit cc72eca
* Fri Apr 23 2021 denis.kirjanov@suse.com
- net: stmmac: fix missing IFF_MULTICAST check in
  dwmac4_set_filter (git-fixes).
- commit 65142f9
* Fri Apr 23 2021 denis.kirjanov@suse.com
- drivers: net: xgene: Fix the order of the arguments of
  'alloc_etherdev_mqs()' (git-fixes).
- commit 96e1f9b
* Fri Apr 23 2021 denis.kirjanov@suse.com
- net: smc911x: Adjust indentation in smc911x_phy_configure
  (git-fixes).
- commit 4801107
* Fri Apr 23 2021 denis.kirjanov@suse.com
- net: tulip: Adjust indentation in {dmfe, uli526x}_init_module
  (git-fixes).
- commit deb82c3
* Fri Apr 23 2021 jroedel@suse.de
- Refresh patches.kabi/0001-kABI-Fix-kABI-after-EDR-backport.patch.
- commit 79c9348
* Fri Apr 23 2021 ykaukab@suse.de
- rtc: pcf2127: properly set flag WD_CD for rtc chips(pcf2129, pca2129) (bsc#1185233).
- irqchip/ls-extirq: add IRQCHIP_SKIP_SET_WAKE to the irqchip flags (bsc#1185233).
- rtc: pcf2127: only use watchdog when explicitly available (bsc#1185233).
- rtc: pcf2127: fix pcf2127_nvmem_read/write() returns (bsc#1185233).
- rtc: pcf2127: move watchdog initialisation to a separate function (bsc#1185233).
- irqchip/ls-extirq: Add LS1043A, LS1088A external interrupt support (bsc#1185233).
- rtc: pcf2127: fix a bug when not specify interrupts property (bsc#1185233).
- rtc: pcf2127: fix alarm handling (bsc#1185233).
- rtc: pcf2127: add alarm support (bsc#1185233).
- rtc: pcf2127: add pca2129 device id (bsc#1185233).
- rtc: pcf2127: watchdog: handle nowayout feature (bsc#1185233).
- rtc: pcf2127: set regmap max_register (bsc#1185233).
- rtc: pcf2127: remove unnecessary #ifdef (bsc#1185233).
- rtc: pcf2127: let the core handle rtc range (bsc#1185233).
- rtc: pcf2127: handle boot-enabled watchdog feature (bsc#1185233).
- irqchip: Add support for Layerscape external interrupt lines (bsc#1185233).
- rtc: pcf2127: bugfix: watchdog build dependency (bsc#1185233).
- rtc: pcf2127: add tamper detection support (bsc#1185233).
- rtc: pcf2127: add watchdog feature support (bsc#1185233).
- rtc: pcf2127: cleanup register and bit defines (bsc#1185233).
- rtc: pcf2127: convert to devm_rtc_allocate_device (bsc#1185233).
- commit cdccb34
* Thu Apr 22 2021 ematsumiya@suse.de
- nvme-fabrics: reject I/O to offline device (bsc#1181161).
- Refresh patches.suse/nvme-fabrics-fix-kato-initialization.patch.
- Refresh
  patches.suse/nvme-fabrics-only-reserve-a-single-tag.patch.
  Context adjustment on the refreshed patches.
- commit a68e30b
* Thu Apr 22 2021 tonyj@suse.de
- perf/x86/intel/uncore: Remove uncore extra PCI dev
  HSWEP_PCI_PCU_3 (bsc#1184685).
- commit 91f11e3
* Thu Apr 22 2021 jack@suse.cz
- blk-settings: align max_sectors on "logical_block_size" boundary
  (bsc#1185195).
- commit e302bd9
* Thu Apr 22 2021 msuchanek@suse.de
- rpm/kernel-obs-build.spec.in: Include essiv with dm-crypt (boo#1183063).
  Previously essiv was part of dm-crypt but now it is separate.
  Include the module in kernel-obs-build when available.
  Fixes: 7cf5b9e26d87 ("rpm/kernel-obs-build.spec.in: add dm-crypt for building with cryptsetup")
- commit bd99014
* Thu Apr 22 2021 msuchanek@suse.de
- powerpc/papr_scm: Fix build error due to wrong printf specifier
  (bsc#1184969).
- commit 546dd4c
* Thu Apr 22 2021 msuchanek@suse.de
- kABI: powerpc/pseries: Add shutdown() to vio_driver and vio_bus
  (bsc#1184209 ltc#190917).
- commit 7b3a736
* Thu Apr 22 2021 bp@suse.de
- x86/mm: Fix NX bit clearing issue in kernel_map_pages_in_pgd
  (bsc#1152489).
- commit 7205cf8
* Thu Apr 22 2021 tbogendoerfer@suse.de
- i40e: Fix sparse errors in i40e_txrx.c (git-fixes).
- igc: reinit_locked() should be called with rtnl_lock
  (git-fixes).
- ice: Account for port VLAN in VF max packet size calculation
  (git-fixes).
- cxgb4/chtls/cxgbit: Keeping the max ofld immediate data size
  same in cxgb4 and ulds (git-fixes).
- commit f18ec94
* Thu Apr 22 2021 tbogendoerfer@suse.de
- net/mlx5e: fix ingress_ifindex check in mlx5e_flower_parse_meta
  (jsc#SLE-8464).
- commit 43af4d2
* Thu Apr 22 2021 tbogendoerfer@suse.de
- i40e: fix the panic when running bpf in xdpdrv mode (git-fixes).
- i40e: Fix sparse warning: missing error code 'err' (git-fixes).
- i40e: Fix sparse errors in i40e_txrx.c (git-fixes).
- net: hns3: clear VF down state bit before request link status
  (git-fixes).
- net: hns3: Remove un-necessary 'else-if' in the
  hclge_reset_event() (git-fixes).
- i40e: Fix display statistics for veb_tc (git-fixes).
- net/mlx5: Don't request more than supported EQs (git-fixes).
- net/mlx5e: Fix ethtool indication of connector type (git-fixes).
- nfp: flower: ignore duplicate merge hints from FW (git-fixes).
- ethernet/netronome/nfp: Fix a use after free in
  nfp_bpf_ctrl_msg_rx (git-fixes).
- ice: Cleanup fltr list in case of allocation issues (git-fixes).
- ice: Fix for dereference of NULL pointer (git-fixes).
- ice: prevent ice_open and ice_stop during reset (git-fixes).
- ice: Increase control queue timeout (git-fixes).
- cxgb4: avoid collecting SGE_QBASE regs during traffic
  (git-fixes).
- i40e: Fix kernel oops when i40e driver removes VF's (git-fixes).
- i40e: Added Asym_Pause to supported link modes (git-fixes).
- net/mlx5e: Fix error path for ethtool set-priv-flag (git-fixes).
- igb: check timestamp validity (git-fixes).
- igb: Fix duplicate include guard (git-fixes).
- e1000e: Fix duplicate include guard (git-fixes).
- net/qlcnic: Fix a use after free in
  qlcnic_83xx_get_minidump_template (git-fixes).
- e1000e: Fix error handling in e1000_set_d0_lplu_state_82571
  (git-fixes).
- e1000e: add rtnl_lock() to e1000_reset_task (git-fixes).
- igc: Fix Supported Pause Frame Link Setting (git-fixes).
- igc: Fix Pause Frame Advertising (git-fixes).
- igc: reinit_locked() should be called with rtnl_lock
  (git-fixes).
- net/mlx5e: Don't match on Geneve options in case option masks
  are all zero (git-fixes).
- macvlan: macvlan_count_rx() needs to be aware of preemption
  (git-fixes).
- veth: Store queue_mapping independently of XDP prog presence
  (git-fixes).
- net/mlx4_en: update moderation when config reset (git-fixes).
- ixgbe: fail to create xfrm offload of IPsec tunnel mode SA
  (git-fixes).
- net: hns3: fix bug when calculating the TCAM table info
  (git-fixes).
- net: hns3: fix query vlan mask value error for flow director
  (git-fixes).
- ice: Account for port VLAN in VF max packet size calculation
  (git-fixes).
- vxlan: move debug check after netdev unregister (git-fixes).
- i40e: Fix endianness conversions (git-fixes).
- i40e: Fix add TC filter for IPv6 (git-fixes).
- i40e: Fix addition of RX filters after enabling FW LLDP agent
  (git-fixes).
- i40e: Fix overwriting flow control settings during driver
  loading (git-fixes).
- i40e: Add zero-initialization of AQ command structures
  (git-fixes).
- i40e: Fix flow for IPv6 next header (extension header)
  (git-fixes).
- net/mlx4_core: Add missed mlx4_free_cmd_mailbox() (git-fixes).
- cxgb4/chtls/cxgbit: Keeping the max ofld immediate data size
  same in cxgb4 and ulds (git-fixes).
- bnxt_en: reverse order of TX disable and carrier off
  (git-fixes).
- commit 1b80b7a
* Thu Apr 22 2021 tbogendoerfer@suse.de
- ch_ktls: do not send snd_una update to TCB in middle
  (jsc#SLE-15131).
- ch_ktls: tcb close causes tls connection failure
  (jsc#SLE-15131).
- ch_ktls: fix device connection close (jsc#SLE-15131).
- ch_ktls: Fix kernel panic (jsc#SLE-15131).
- net/mlx5e: Fix setting of RS FEC mode (jsc#SLE-15172).
- ixgbe: fix unbalanced device enable/disable in suspend/resume
  (jsc#SLE-13706).
- ethtool: pause: make sure we init driver stats (jsc#SLE-15075).
- netfilter: flowtable: fix NAT IPv6 offload mangling
  (bsc#1176447).
- commit a20dac1
* Thu Apr 22 2021 mkubecek@suse.cz
- series.conf: cleanup
- move into correct directory and series.conf section:
  patches.suse/kABI-cover-up-change-in-struct-kvm_arch.patch -> patches.kabi/
- commit 7ead145
* Thu Apr 22 2021 tiwai@suse.de
- Revert "rpm/kernel-binary.spec.in: Fix dependency of kernel-*-devel package (bsc#1184514)"
  This turned out to be a bad idea: the kernel-$flavor-devel package
  must be usable without kernel-$flavor, e.g. at the build of a KMP.
  And this change brought superfluous installation of kernel-preempt
  when a system had kernel-syms (bsc#1185113).
- commit d771304
* Thu Apr 22 2021 mcgrof@suse.com
- patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch: (bsc#865869,bsc#1178418).
  Fix initialization of the the super block for a btrfs specific enhancement
  which we added. The btrfs specific enhancement augmented the super block to
  add support to ustat() and it is only used by btrfs. For that, the super block
  was extended with a new linked list which is only used only in btrfs. The
  initialization of the linked list however was done late, and if any allocation
  fails early on alloc_super() it meant that the WARNING check on free'ing
  it could fail, as the list may be read as not empty. This warning then
  is triggerable when stress testing allocations, and you run out of
  memory. It can happen regardless of the filesystem you use.
  The sget_fc() contention when stress testing with the unshare system
  call reported on bsc#1178418 which leads to a soft lockup is still being
  investigate, however this fixes the kernel warning reproduced when doing
  that stress testing.
- commit 67dd047
* Wed Apr 21 2021 tiwai@suse.de
- r8169: don't advertise pause in jumbo mode (git-fixes).
- iwlwifi: add support for Qu with AX201 device (git-fixes).
- r8169: tweak max read request size for newer chips also in
  jumbo mtu mode (git-fixes).
- commit 8bacd0f
* Wed Apr 21 2021 tiwai@suse.de
- virt_wifi: Return micros for BSS TSF values (git-fixes).
- mac80211: clear sta->fast_rx when STA removed from 4-addr VLAN
  (git-fixes).
- drm/msm: Fix a5xx/a6xx timestamps (git-fixes).
- commit 0abe8be
* Wed Apr 21 2021 tiwai@suse.de
- drm/ast: Add 25MHz refclk support (bsc#1174416).
- drm/ast: Add support for 1152x864 mode (bsc#1174416).
- drm/ast: Add support for AIP200 (bsc#1174416).
- drm/ast: Correct mode table for AST2500 precatch (bsc#1174416).
- drm/ast: AST2500 fixups (bsc#1174416).
- drm/ast: Fix P2A config detection (bsc#1174416).
- drm/ast: Fix register access in non-P2A mode for DP501
  (bsc#1174416).
- drm/ast: drm/ast: Fix boot address for AST2500 (bsc#1174416).
- drm/ast: Disable screen on register init (bsc#1174416).
- drm/ast: Keep MISC fields when enabling VGA (bsc#1174416).
- drm/ast: Disable VGA decoding while driver is active
  (bsc#1174416).
- commit f478032
* Wed Apr 21 2021 msuchanek@suse.de
- powerpc/pseries: Add shutdown() to vio_driver and vio_bus
  (bsc#1184209 ltc#190917).
- commit 218a8c4
* Wed Apr 21 2021 tiwai@suse.de
- drm/ast: Add 25MHz refclk support (bsc#1174416).
- drm/ast: Add support for 1152x864 mode (bsc#1174416).
- drm/ast: Add support for AIP200 (bsc#1174416).
- drm/ast: Correct mode table for AST2500 precatch (bsc#1174416).
- drm/ast: AST2500 fixups (bsc#1174416).
- drm/ast: Fix P2A config detection (bsc#1174416).
- drm/ast: Fix register access in non-P2A mode for DP501
  (bsc#1174416).
- drm/ast: drm/ast: Fix boot address for AST2500 (bsc#1174416).
- drm/ast: Disable screen on register init (bsc#1174416).
- drm/ast: Keep MISC fields when enabling VGA (bsc#1174416).
- drm/ast: Disable VGA decoding while driver is active
  (bsc#1174416).
- commit 4164eea
* Wed Apr 21 2021 jslaby@suse.cz
- rpm/check-for-config-changes: add AS_HAS_* to ignores
  arch/arm64/Kconfig defines a lot of these. So far our current compilers
  seem to support them all. But it can quickly change with SLE later.
- commit a4d8194
* Tue Apr 20 2021 mbrugger@suse.com
- supported.conf: add tcpi and tcpm module to base system (bsc#1185010)
- commit 3fac436
* Tue Apr 20 2021 oneukum@suse.com
- usb: dwc3: core: don't do suspend for device mode if already
  suspended (git-fixes).
- commit 82b18d4
* Tue Apr 20 2021 oneukum@suse.com
- usb: dwc3: gadget: Clear DCTL.ULSTCHNGREQ before set
  (git-fixes).
- commit 072728a
* Tue Apr 20 2021 oneukum@suse.com
- usb: dwc3: gadget: Set link state to RX_Detect on disconnect
  (git-fixes).
- commit 6a1e8b7
* Tue Apr 20 2021 oneukum@suse.com
- usb: dwc3: gadget: Don't send unintended link state change
  (git-fixes).
- commit acdee65
* Tue Apr 20 2021 msuchanek@suse.de
- kABI: cover up change in struct kvm_arch (bsc#1184969).
- commit 3e9476f
* Tue Apr 20 2021 oneukum@suse.com
- usb: dwc3: of-simple: add a shutdown (git-fixes).
- commit 15b84b1
* Tue Apr 20 2021 oneukum@suse.com
- usb: dwc3: debug: Remove newline printout (git-fixes).
- commit 5104cc5
* Tue Apr 20 2021 martin.wilck@suse.com
- scsi: core: Only return started requests from
  scsi_host_find_tag() (bsc#1179851).
- commit 49d7a00
* Tue Apr 20 2021 glin@suse.com
- bpf: Tighten speculative pointer arithmetic mask (bsc#1184942
  CVE-2021-29155).
- bpf: Move sanitize_val_alu out of op switch (bsc#1184942
  CVE-2021-29155).
- bpf: Refactor and streamline bounds check into helper
  (bsc#1184942 CVE-2021-29155).
- bpf: Improve verifier error messages for users (bsc#1184942
  CVE-2021-29155).
- bpf: Rework ptr_limit into alu_limit and add common error path
  (bsc#1184942 CVE-2021-29155).
- bpf: Ensure off_reg has no mixed signed bounds for all types
  (bsc#1184942 CVE-2021-29155).
- bpf: Move off_reg into sanitize_ptr_alu (bsc#1184942
  CVE-2021-29155).
- commit c02423d
* Tue Apr 20 2021 glin@suse.com
- bpf: Tighten speculative pointer arithmetic mask (bsc#1184942
  CVE-2021-29155).
- bpf: Move sanitize_val_alu out of op switch (bsc#1184942
  CVE-2021-29155).
- bpf: Refactor and streamline bounds check into helper
  (bsc#1184942 CVE-2021-29155).
- bpf: Improve verifier error messages for users (bsc#1184942
  CVE-2021-29155).
- bpf: Rework ptr_limit into alu_limit and add common error path
  (bsc#1184942 CVE-2021-29155).
- bpf: Ensure off_reg has no mixed signed bounds for all types
  (bsc#1184942 CVE-2021-29155).
- bpf: Move off_reg into sanitize_ptr_alu (bsc#1184942
  CVE-2021-29155).
- commit bc2237a
* Tue Apr 20 2021 ykaukab@suse.de
- net: enetc: remove bogus write to SIRXIDR from enetc_setup_rxbdr
  (git-fixes).
- net: enetc: take the MDIO lock only once per NAPI poll cycle
  (git-fixes).
- commit 2704809
* Tue Apr 20 2021 dwagner@suse.de
- scsi: qla2xxx: Reserve extra IRQ vectors (bsc#1184436).
- commit bf4edb3
* Tue Apr 20 2021 glin@suse.com
- bpf: Use correct permission flag for mixed signed bounds
  arithmetic (bsc#1184942 CVE-2021-29155).
- commit 4c203f3
* Mon Apr 19 2021 msuchanek@suse.de
- selftests/powerpc: Fix exit status of pkey tests (bsc#1184934
  ltc#191460).
- selftests/powerpc: Add test for pkey siginfo verification
  (bsc#1184934 ltc#191460).
- commit 7ac835e
* Mon Apr 19 2021 mbenes@suse.cz
- ftrace/x86: Tell objtool to ignore nondeterministic ftrace
  stack layout (bsc#1177028).
- commit e3b8b48
* Mon Apr 19 2021 bp@suse.de
- x86/reboot: Force all cpus to exit VMX root if VMX is supported
  (bsc#1152489).
- commit 9520307
* Mon Apr 19 2021 msuchanek@suse.de
- powerpc/papr_scm: Implement support for H_SCM_FLUSH hcall
  (bsc#1184969).
- commit 878daaa
* Mon Apr 19 2021 oneukum@suse.com
- usb: dwc3: Disable phy suspend after power-on reset (git-fixes).
- commit a403162
* Mon Apr 19 2021 oneukum@suse.com
- usb: dwc3: gadget: Workaround Mirosoft's BESL check (git-fixes).
- commit e16e74a
* Mon Apr 19 2021 oneukum@suse.com
- usb: dwc3: gadget: Set BESL config parameter (git-fixes).
- commit b02b13d
* Mon Apr 19 2021 oneukum@suse.com
- usb: dwc3: Separate field holding multiple properties
  (git-fixes).
- commit 1087836
* Mon Apr 19 2021 oneukum@suse.com
- usb: dwc3: st: Add of_dev_put() in probe function (git-fixes).
- commit b4290b9
* Mon Apr 19 2021 oneukum@suse.com
- usb: dwc3: st: Add of_node_put() before return in probe function
  (git-fixes).
- commit a5796ab
* Mon Apr 19 2021 oneukum@suse.com
- usb: dwc3: Use clk_bulk_prepare_enable() (git-fixes).
- commit 638e28a
* Mon Apr 19 2021 oneukum@suse.com
- usb: dwc3: Use devres to get clocks (git-fixes).
- commit e717ac7
* Mon Apr 19 2021 msuchanek@suse.de
- powerpc/mm: Add cond_resched() while removing hpte mappings
  (bsc#1183289 ltc#191637).
- powerepc/book3s64/hash: Align start/end address correctly with
  bolt mapping (bsc#1184957).
- commit 4735c17
* Mon Apr 19 2021 msuchanek@suse.de
- Refresh patches.suse/powerpc-pseries-extract-host-bridge-from-pci_bus-pri.patch.
  Update patch metadata.
- commit 2060b77
* Mon Apr 19 2021 msuchanek@suse.de
- selftests/powerpc: Fix L1D flushing tests for Power10
  (bsc#1184934 ltc#191460).
- selftests/powerpc: refactor entry and rfi_flush tests
  (bsc#1184934 ltc#191460).
- selftests/powerpc: Fix pkey syscall redefinitions (bsc#1184934
  ltc#191460).
- selftests/powerpc: Add wrapper for gettid (bsc#1184934
  ltc#191460).
- selftests/powerpc: Add pkey helpers for rights (bsc#1184934
  ltc#191460).
- selftests/powerpc: Move pkey helpers to headers (bsc#1184934
  ltc#191460).
- selftests/powerpc: Add test for execute-disabled pkeys
  (bsc#1184934 ltc#191460).
- commit c89a30c
* Mon Apr 19 2021 msuchanek@suse.de
- ibmvnic: correctly use dev_consume/free_skb_irq (jsc#SLE-17268
  jsc#SLE-17043 bsc#1179243 ltc#189290 git-fixes).
- commit 93dc507
* Sun Apr 18 2021 mkubecek@suse.cz
- Update kabi files.
- update from April 2021 maintenance update (commit c41a65cc53c7)
- commit 7bc7f17
* Sat Apr 17 2021 tiwai@suse.de
- interconnect: core: fix error return code of icc_link_destroy()
  (git-fixes).
- drm/imx: imx-ldb: fix out of bounds array access warning
  (git-fixes).
- drm/tegra: dc: Don't set PLL clock to 0Hz (git-fixes).
- commit 90bbfcf
* Fri Apr 16 2021 pmladek@suse.com
- workqueue: Move the position of debug_work_activate() in
  __queue_work() (bsc#1184893).
- commit eb68ae8
* Fri Apr 16 2021 jroedel@suse.de
- kABI: Fix kABI caused by fixes for bsc#1174426 (bsc#1174426).
- commit 4ef9359
* Fri Apr 16 2021 jroedel@suse.de
- PCI/AER: Use "aer" variable for capability offset (bsc#1174426).
- Refresh
  patches.kabi/0001-kABI-Fix-kABI-after-EDR-backport.patch.
- commit 2c4de88
* Fri Apr 16 2021 jroedel@suse.de
- PCI/portdrv: Report reset for frozen channel (bsc#1174426).
- PCI/AER: Specify the type of Port that was reset (bsc#1174426).
- PCI/ERR: Retain status from error notification (bsc#1174426).
- PCI/AER: Clear AER status from Root Port when resetting
  Downstream Port (bsc#1174426).
- PCI/ERR: Clear status of the reporting device (bsc#1174426).
- PCI/AER: Add RCEC AER error injection support (bsc#1174426).
- PCI/PME: Add pcie_walk_rcec() to RCEC PME handling
  (bsc#1174426).
- PCI/AER: Add pcie_walk_rcec() to RCEC AER handling
  (bsc#1174426).
- PCI/ERR: Recover from RCiEP AER errors (bsc#1174426).
- PCI/ERR: Add pcie_link_rcec() to associate RCiEPs (bsc#1174426).
- PCI/ERR: Recover from RCEC AER errors (bsc#1174426).
- PCI/ERR: Clear AER status only when we control AER
  (bsc#1174426).
- PCI/ERR: Add pci_walk_bridge() to pcie_do_recovery()
  (bsc#1174426).
- PCI/ERR: Avoid negated conditional for clarity (bsc#1174426).
- PCI/ERR: Use "bridge" for clarity in pcie_do_recovery()
  (bsc#1174426).
- PCI/ERR: Simplify by computing pci_pcie_type() once
  (bsc#1174426).
- PCI/ERR: Simplify by using pci_upstream_bridge() (bsc#1174426).
- PCI/ERR: Rename reset_link() to reset_subordinates()
  (bsc#1174426).
- PCI/ERR: Cache RCEC EA Capability offset in
  pci_init_capabilities() (bsc#1174426).
- PCI/ERR: Bind RCEC devices to the Root Port driver
  (bsc#1174426).
- PCI/AER: Write AER Capability only when we control it
  (bsc#1174426).
- PCI/ERR: Clear PCIe Device Status errors only if OS owns AER
  (bsc#1174426).
- commit cf4418f
* Fri Apr 16 2021 msuchanek@suse.de
- Refresh patches.suse/scsi-ibmvfc-Fix-invalid-state-machine-BUG_ON.patch.
  Add to sorted section.
- commit 2fa18b2
* Fri Apr 16 2021 ykaukab@suse.de
- dpaa_eth: Use random MAC address when none is given
  (bsc#1184811).
- fsl/fman: tolerate missing MAC address in device tree
  (bsc#1184811).
- fsl/fman: reuse set_mac_address() in dtsec init() (bsc#1184811).
- commit 40e0790
* Fri Apr 16 2021 tiwai@suse.de
- gpio: sysfs: Obey valid_mask (git-fixes).
- HID: wacom: set EV_KEY and EV_ABS only for non-HID_GENERIC
  type of devices (git-fixes).
- Input: nspire-keypad - enable interrupts only when opened
  (git-fixes).
- Input: i8042 - fix Pegatron C15B ID entry (git-fixes).
- Input: s6sy761 - fix coordinate read bit shift (git-fixes).
- commit 0ad8d52
* Fri Apr 16 2021 mgorman@suse.de
- Delete
  patches.suse/sched-Fix-up-proc-sched_debug-to-print-only-runnable-tasks-again.patch (bsc#1184769).
- commit cff61a2
* Thu Apr 15 2021 mbenes@suse.cz
- x86/insn: Add some more Intel instructions to the opcode map
  (bsc#1184760).
- commit 1d99542
* Thu Apr 15 2021 mbenes@suse.cz
- x86/insn: Add some Intel instructions to the opcode map
  (bsc#1184760).
- commit 7c194e1
* Thu Apr 15 2021 ykaukab@suse.de
- iopoll: introduce read_poll_timeout macro (git-fixes).
- commit 3398015
* Thu Apr 15 2021 tiwai@suse.de
- dmaengine: idxd: fix wq cleanup of WQCFG registers (git-fixes).
- dmaengine: idxd: clear MSIX permission entry on shutdown
  (git-fixes).
- dmaengine: Fix a double free in dma_async_device_register
  (git-fixes).
- dmaengine: idxd: fix wq size store permission state (git-fixes).
- dmaengine: idxd: fix opcap sysfs attribute output (git-fixes).
- dmaengine: idxd: fix delta_rec and crc size field for completion
  record (git-fixes).
- dmaengine: idxd: Fix clobbering of SWERR overflow bit on
  writeback (git-fixes).
- commit 5a7e9ed
* Thu Apr 15 2021 tiwai@suse.de
- dmaengine: dw: Make it dependent to HAS_IOMEM (git-fixes).
- vfio/pci: Add missing range check in vfio_pci_mmap (git-fixes).
- cfg80211: remove WARN_ON() in cfg80211_sme_connect (git-fixes).
- ASoC: SOF: Intel: HDA: fix core status verification (git-fixes).
- ASoC: SOF: Intel: hda: remove unnecessary parentheses
  (git-fixes).
- commit 9608bf3
* Thu Apr 15 2021 tiwai@suse.de
- Move upstreamed i915 fix into sorted section
- commit c0cf502
* Thu Apr 15 2021 colyli@suse.de
- mm/rmap: fix potential pte_unmap on an not mapped pte
  (git-fixes).
- dm era: only resize metadata in preresume (git-fixes).
- dm era: Use correct value size in equality function of writeset
  tree (git-fixes).
- dm era: Fix bitset memory leaks (git-fixes).
- dm era: Verify the data block size hasn't changed (git-fixes).
- dm era: Reinitialize bitset cache before digesting a new
  writeset (git-fixes).
- dm era: Update in-core bitset after committing the metadata
  (git-fixes).
- dm era: Recover committed writeset after crash (git-fixes).
- Revert "bcache: Kill btree_io_wq" (git-fixes).
- bsg: free the request before return error code (git-fixes).
- dm: eliminate potential source of excessive kernel log noise
  (git-fixes).
- dm zoned: select CONFIG_CRC32 (git-fixes).
- dm raid: fix discard limits for raid1 (git-fixes).
- block: rsxx: select CONFIG_CRC32 (git-fixes).
- scsi: block: Fix a race in the runtime power management code
  (git-fixes).
- dm ioctl: fix error return code in target_message (git-fixes).
- dm: remove invalid sparse __acquires and __releases annotations
  (git-fixes).
- dm writecache: remove BUG() and fail gracefully instead
  (git-fixes).
- dm: fix bug with RCU locking in dm_blk_report_zones (git-fixes).
- Revert "dm cache: fix arm link errors with inline" (git-fixes).
- dm writecache: fix the maximum number of arguments (git-fixes).
- nbd: fix a block_device refcount leak in nbd_release
  (git-fixes).
- dm integrity: fix error reporting in bitmap mode after creation
  (git-fixes).
- dm mpath: fix racey management of PG initialization (git-fixes).
- dm writecache: handle DAX to partitions on persistent memory
  correctly (git-fixes).
- null_blk: fix passing of REQ_FUA flag in null_handle_rq
  (git-fixes).
- blkcg: fix memleak for iolatency (git-fixes).
- commit b8efea4
* Wed Apr 14 2021 oneukum@suse.com
- usb: dwc3: Update soft-reset wait polling rate (git-fixes).
- commit 54f493a
* Wed Apr 14 2021 oneukum@suse.com
- usb: dwc3: keystone: use devm_platform_ioremap_resource()
  to simplify code (git-fixes).
- commit caa2253
* Wed Apr 14 2021 bp@suse.de
- KVM: kvmclock: Fix vCPUs > 64 can't be online/hotpluged
  (bsc#1152489).
- commit d511393
* Wed Apr 14 2021 oneukum@suse.com
- usb: dwc3: meson-g12a: use devm_platform_ioremap_resource()
  to simplify code (git-fixes).
- commit c2f56d9
* Wed Apr 14 2021 jack@suse.cz
- block, bfq: set next_rq to waker_bfqq->next_rq in waker
  injection (bsc#1168838).
  Drop patches.suse/bfq-Fix-check-detecting-whether-waker-queue-should-b.patch
  as the upstream patch replaces is.
- commit bfcf868
* Wed Apr 14 2021 jack@suse.cz
- patches.suse/bfq-Use-only-idle-IO-periods-for-think-time-calculat.patch:
  Update tags
- commit ebb3c4a
* Wed Apr 14 2021 jack@suse.cz
- patches.suse/bfq-Use-ttime-local-variable.patch: Update tags
- commit 83db8f6
* Wed Apr 14 2021 jack@suse.cz
- ext4: find old entry again if failed to rename whiteout
  (bsc#1184742).
- commit 7f9cb02
* Wed Apr 14 2021 jack@suse.cz
- blacklist.conf: Blacklist 163f0ec1df33
- commit 742fb7c
* Wed Apr 14 2021 jack@suse.cz
- isofs: release buffer head before return (bsc#1182613).
- commit eeef088
* Wed Apr 14 2021 jack@suse.cz
- patches.suse/bfq-Avoid-false-bfq-queue-merging.patch: Refresh with
  upstream version
- commit c0f05bc
* Wed Apr 14 2021 jack@suse.cz
- fs/jfs: fix potential integer overflow on shift of a int
  (bsc#1184741).
- commit d0e76e8
* Wed Apr 14 2021 jack@suse.cz
- jffs2: fix use after free in jffs2_sum_write_data()
  (bsc#1184740).
- commit 6b24b69
* Wed Apr 14 2021 jack@suse.cz
- ocfs2: fix a use after free on error (bsc#1184738).
- commit bbc04e0
* Wed Apr 14 2021 jack@suse.cz
- reiserfs: update reiserfs_xattrs_initialized() condition
  (bsc#1184737).
- commit 0099e39
* Wed Apr 14 2021 jack@suse.cz
- fs: direct-io: fix missing sdio->boundary (bsc#1184736).
- commit 4c56c6a
* Wed Apr 14 2021 jack@suse.cz
- ext4: fix potential error in ext4_do_update_inode (bsc#1184731).
- commit 3990053
* Wed Apr 14 2021 jack@suse.cz
- ext4: do not try to set xattr into ea_inode if value is empty
  (bsc#1184730).
- commit b98639e
* Wed Apr 14 2021 jack@suse.cz
- ext4: fix potential htree index checksum corruption
  (bsc#1184728).
- commit 21d8b4d
* Wed Apr 14 2021 oneukum@suse.com
- usb: Remove dev_err() usage after platform_get_irq()
  (git-fixes).
- commit a9d64cb
* Wed Apr 14 2021 oneukum@suse.com
- usb: dwc3: Switch to use device_property_count_u32()
  (git-fixes).
- commit 58512a7
* Wed Apr 14 2021 jack@suse.cz
- block: recalculate segment count for multi-segment discards
  correctly (bsc#1184724).
- commit 7146c5e
* Wed Apr 14 2021 lhenriques@suse.de
- Update patches.suse/fuse-fix-bad-inode.patch (bsc#1184211
  CVE-2020-36322).
  Updated patch metadata to include CVE number.
- commit 89cea51
* Wed Apr 14 2021 lhenriques@suse.de
- Update patches.suse/fuse-fix-bad-inode.patch (bsc#1184211
  CVE-2020-36322).
  Updated patch metadata to include CVE number.
- commit 6ecd48e
* Wed Apr 14 2021 jslaby@suse.cz
- rpm/check-for-config-changes: remove stale comment
  It is stale since 8ab393bf905a committed in 2005 :).
- commit c9f9f5a
* Tue Apr 13 2021 martin.wilck@suse.com
- dm mpath: switch paths in dm_blk_ioctl() code path (bsc#1167574,
  bsc#1175995, bsc#1184485).
- commit 981c2ae
* Tue Apr 13 2021 bp@suse.de
- blacklist.conf: 66c1b6d74cd7 x86: Move TS_COMPAT back to asm/thread_info.h
- commit 3533f06
* Tue Apr 13 2021 mkubecek@suse.cz
- update patch metadata
- update upstream references and move out of sorted section:
  patches.suse/scsi-ibmvfc-Fix-invalid-state-machine-BUG_ON.patch
- commit f170d23
* Tue Apr 13 2021 tiwai@suse.de
- rpm/mkspec: Use tilde instead of dot for version string with rc (bsc#1184650)
- commit f37613f
* Tue Apr 13 2021 lhenriques@suse.de
- Update patches.suse/fuse-fix-live-lock-in-fuse_iget.patch
  (bsc#1184211 CVE-2021-28950).
  Updated patch metadata to include CVE number.
- commit 610fdaf
* Tue Apr 13 2021 lhenriques@suse.de
- Update patches.suse/fuse-fix-live-lock-in-fuse_iget.patch
  (bsc#1184211 CVE-2021-28950).
  Updated patch metadata to include CVE number.
- commit 3370c43
* Tue Apr 13 2021 glin@suse.com
- libbpf: Only create rx and tx XDP rings when necessary
  (bsc#1155518).
- commit 02ec945
* Tue Apr 13 2021 bp@suse.de
- x86: Introduce TS_COMPAT_RESTART to fix get_nr_restart_syscall()
  (bsc#1152489).
- commit 6cf26f2
* Tue Apr 13 2021 tbogendoerfer@suse.de
- i40e: Fix sparse error: 'vsi->netdev' could be null
  (jsc#SLE-8025).
- i40e: Fix parameters in aq_get_phy_register() (jsc#SLE-8025).
- net/mlx5: Fix PPLM register mapping (jsc#SLE-8464).
- net: hns3: Remove the left over redundant check & assignment
  (bsc#1154353).
- ice: remove DCBNL_DEVRESET bit from PF state (jsc#SLE-7926).
- commit 1626bf4
* Tue Apr 13 2021 tbogendoerfer@suse.de
- ice: fix memory leak of aRFS after resuming from suspend
  (jsc#SLE-12878).
- i40e: Fix sparse error: uninitialized symbol 'ring'
  (jsc#SLE-13701).
- ethtool: fix incorrect datatype in set_eee ops (bsc#1176447).
- net: cls_api: Fix uninitialised struct field
  bo->unlocked_driver_cb (bsc#1176447).
- xfrm: Provide private skb extensions for segmented and hw
  offloaded ESP packets (bsc#1176447).
- ice: Use port number instead of PF ID for WoL (jsc#SLE-12878).
- ice: fix memory allocation call (jsc#SLE-12878).
- ice: Continue probe on link/PHY errors (jsc#SLE-12878).
- geneve: do not modify the shared tunnel info when PMTU triggers
  an ICMP reply (bsc#1176447).
- vxlan: do not modify the shared tunnel info when PMTU triggers
  an ICMP reply (bsc#1176447).
- commit e13f3cc
* Tue Apr 13 2021 msuchanek@suse.de
- scsi: ibmvfc: Fix invalid state machine BUG_ON() (bsc#1184647
  ltc#191231).
- commit 069588f
* Tue Apr 13 2021 glin@suse.com
- bpf: link: Refuse non-O_RDWR flags in BPF_OBJ_GET (bsc#1177028).
- bpf: Refcount task stack in bpf_get_task_stack (bsc#1177028).
- bpf: Enforce that struct_ops programs be GPL-only (bsc#1177028).
- libbpf: Fix bail out from 'ringbuf_process_ring()' on error
  (bsc#1177028).
- commit 1bc90a6
* Tue Apr 13 2021 jroedel@suse.de
- iommu/vt-d: Use device numa domain if RHSA is missing (bsc#1184585).
- Refresh patches.suse/iommu-vt-d-fix-ineffective-devtlb-invalidation-for-subdevices.
- commit 6ad821c
* Tue Apr 13 2021 denis.kirjanov@suse.com
- enetc: Fix reporting of h/w packet counters (git-fixes).
- commit 2b6231d
* Tue Apr 13 2021 denis.kirjanov@suse.com
- net: pasemi: fix error return code in pasemi_mac_open() (git-fixes).
- commit 9f74d4a
* Tue Apr 13 2021 denis.kirjanov@suse.com
- atl1e: fix error return code in atl1e_probe() (git-fixes).
- commit 9030b22
* Tue Apr 13 2021 denis.kirjanov@suse.com
- atl1c: fix error return code in atl1c_probe() (git-fixes).
- commit 138f514
* Tue Apr 13 2021 denis.kirjanov@suse.com
- net: atheros: switch from 'pci_' to 'dma_' API (git-fixes).
- commit 9d0c126
* Tue Apr 13 2021 glin@suse.com
- bpf, sockmap: Fix sk->prot unhash op reset (bsc#1155518).
- bpf: Fix verifier jsgt branch analysis on max bound
  (bsc#1155518).
- samples/bpf: Fix possible hang in xdpsock with multiple threads
  (bsc#1155518).
- commit 50946be
* Tue Apr 13 2021 denis.kirjanov@suse.com
- net: b44: fix error return code in b44_init_one() (git-fixes).
- commit 405f041
* Tue Apr 13 2021 denis.kirjanov@suse.com
- net: qualcomm: rmnet: Fix incorrect receive packet handling during cleanup (git-fixes).
- commit 418a7e1
* Tue Apr 13 2021 denis.kirjanov@suse.com
- net: ethernet: ti: cpsw: fix error return code in cpsw_probe() (git-fixes).
- commit bbd1c86
* Tue Apr 13 2021 denis.kirjanov@suse.com
- qlcnic: fix error return code in qlcnic_83xx_restart_hw() (git-fixes).
- commit 4792038
* Tue Apr 13 2021 denis.kirjanov@suse.com
- net: lantiq: Wait for the GPHY firmware to be ready (git-fixes).
- commit d0452d2
* Mon Apr 12 2021 jgross@suse.com
- xen/evtchn: Change irq_info lock to raw_spinlock_t (git-fixes).
  [jeyu: was doing a SLE15-SP3 branch sweep and found this commit wasn't in
  SLE15-SP3 yet for whatever reason, so I cherry-picked it. Probably due to some
  for-Update/for-GM mixups back in April.]
  Conflicts:
  series.conf
- commit cc002cf
* Mon Apr 12 2021 oneukum@suse.com
- Documentation/ABI: sysfs-platform-ideapad-laptop: update device
  attribute paths (git-fixes).
- commit 2559651
* Mon Apr 12 2021 oneukum@suse.com
- thunderbolt: Fix off by one in tb_port_find_retimer()
  (git-fixes).
- commit d93adab
* Mon Apr 12 2021 oneukum@suse.com
- thunderbolt: Fix a leak in tb_retimer_add() (git-fixes).
- commit 158bfab
* Mon Apr 12 2021 jroedel@suse.de
- KVM: SVM: avoid infinite loop on NPF from bad address (CVE-2020-36310 bsc#1184512).
- commit df4914b
* Mon Apr 12 2021 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix dependency of kernel-*-devel package (bsc#1184514)
  The devel package requires the kernel binary package itself for building
  modules externally.
- commit 794be7b
* Mon Apr 12 2021 bp@suse.de
- blacklist.conf: dd926880da8d x86/apic/of: Fix CPU devicetree-node lookups
- commit 92f0632
* Mon Apr 12 2021 bp@suse.de
- RAS/CEC: Correct ce_add_elem()'s returned values (bsc#1152489).
- commit 1be7dba
* Mon Apr 12 2021 jroedel@suse.de
- KVM: fix memory leak in kvm_io_bus_unregister_dev() (CVE-2020-36312 bsc#1184509).
- commit 6a9d1a6
* Mon Apr 12 2021 jroedel@suse.de
- Refresh patches.suse/x86-insn-make-inat-tables-c-suitable-for-pre-decompression-code.
  Bring gen-insn-attr-x86.awk files in sync over the tree to
  fix a build warning.
- commit 2c08948
* Mon Apr 12 2021 msuchanek@suse.de
- ibmvfc: disable MQ channelization by default (bsc#1184570
  ltc#192356).
- commit 500b7bf
* Mon Apr 12 2021 acho@suse.com
- vfio-ccw: Wire in the request callback (bsc#1183225).
- vfio-mdev: Wire in a request handler for mdev parent
  (bsc#1183225).
- commit 1a8b567
* Mon Apr 12 2021 jgross@suse.com
- xen/events: fix setting irq affinity (bsc#1184583 XSA-332
  CVE-2020-27673).
- commit e88a4fe
* Mon Apr 12 2021 glin@suse.com
- bpf, x86: Validate computation of branch displacements for
  x86-32 (bsc#1184391 CVE-2021-29154).
- bpf, x86: Validate computation of branch displacements for
  x86-64 (bsc#1184391 CVE-2021-29154).
- libbpf: Fix INSTALL flag order (bsc#1155518).
- bpf: Remove MTU check in __bpf_skb_max_len (bsc#1155518).
- commit 3cfc764
* Mon Apr 12 2021 jlee@suse.com
- Update config files. (bsc#1181284)
- commit 09b2083
* Sun Apr 11 2021 tiwai@suse.de
- thunderbolt: Fix off by one in tb_port_find_retimer()
  (git-fixes).
- thunderbolt: Fix a leak in tb_retimer_add() (git-fixes).
- geneve: do not modify the shared tunnel info when PMTU triggers
  an ICMP reply (git-fixes).
- drm/vc4: crtc: Reduce PV fifo threshold on hvs4 (git-fixes).
- ACPI: processor: Fix build when CONFIG_ACPI_PROCESSOR=m
  (git-fixes).
- commit 06335ba
* Sun Apr 11 2021 tiwai@suse.de
- clk: fix invalid usage of list cursor in unregister (git-fixes).
- clk: fix invalid usage of list cursor in register (git-fixes).
- clk: socfpga: fix iomem pointer cast on 64-bit (git-fixes).
- mac80211: fix TXQ AC confusion (git-fixes).
- batman-adv: initialize "struct
  batadv_tvlv_tt_vlan_data"->reserved field (git-fixes).
- net: phy: broadcom: Only advertise EEE for supported modes
  (git-fixes).
- gianfar: Handle error code at MAC address change (git-fixes).
- drm/msm: Set drvdata to NULL when msm_drm_init() fails
  (git-fixes).
- bus: ti-sysc: Fix warning on unbind if reset is not deasserted
  (git-fixes).
- drm/msm: Ratelimit invalid-fence message (git-fixes).
- drm/msm/adreno: a5xx_power: Don't apply A540 lm_setup to other
  GPUs (git-fixes).
- mac80211: choose first enabled channel for monitor (git-fixes).
- mISDN: fix crash in fritzpci (git-fixes).
- platform/x86: thinkpad_acpi: Allow the FnLock LED to change
  state (git-fixes).
- platform/x86: intel-hid: Support Lenovo ThinkPad X1 Tablet Gen 2
  (git-fixes).
- commit a1094b1
* Sat Apr 10 2021 tiwai@suse.de
- nfc: Avoid endless loops caused by repeated llcp_sock_connect()
  (CVE-2020-25673 bsc#1178181).
- nfc: fix memory leak in llcp_sock_connect() (CVE-2020-25672
  bsc#1178181).
- nfc: fix refcount leak in llcp_sock_connect() (CVE-2020-25671
  bsc#1178181).
- nfc: fix refcount leak in llcp_sock_bind() (CVE-2020-25670
  bsc#1178181).
- commit ee06cff
* Fri Apr  9 2021 msuchanek@suse.de
- Add obsolete_rebuilds_subpackage (boo#1172073 bsc#1191731).
- commit f037781
* Fri Apr  9 2021 bp@suse.de
- KVM: SVM: Periodically schedule when unregistering regions on
  destroy (bsc#1184511 CVE-2020-36311).
- commit fad3809
* Fri Apr  9 2021 bp@suse.de
- KVM: SVM: Periodically schedule when unregistering regions on
  destroy (bsc#1184511 CVE-2020-36311).
- commit 4a629fb
* Fri Apr  9 2021 msuchanek@suse.de
- rpm/check-for-config-changes: Also ignore AS_VERSION added in 5.12.
- commit bd64cb2
* Fri Apr  9 2021 tbogendoerfer@suse.de
- IB/hfi1: Fix probe time panic when AIP is enabled with a buggy
  BIOS (jsc#SLE-13208).
- RDMA/rtrs-clt: Close rtrs client conn before destroying rtrs
  clt session files (jsc#SLE-15176).
- igb: avoid premature Rx buffer reuse (jsc#SLE-13536).
- igb: avoid transmit queue timeout in xdp path (jsc#SLE-13536).
- igb: use xdp_do_flush (jsc#SLE-13536).
- igb: skb add metasize for xdp (jsc#SLE-13536).
- igb: XDP extack message on error (jsc#SLE-13536).
- igb: take VLAN double header into account (jsc#SLE-13536).
- igb: XDP xmit back fix error code (jsc#SLE-13536).
- commit 205ebec
* Fri Apr  9 2021 tiwai@suse.de
- ASoC: soc-core kABI workaround (git-fixes).
- commit f4e005d
* Fri Apr  9 2021 tiwai@suse.de
- ASoC: soc-core: Prevent warning if no DMI table is present
  (git-fixes).
- commit 862774d
* Fri Apr  9 2021 tiwai@suse.de
- ASoC: max98373: Changed amp shutdown register as volatile
  (git-fixes).
- ASoC: SOF: Intel: HDA: fix core status verification (git-fixes).
- ALSA: hda/conexant: Apply quirk for another HP ZBook G5 model
  (git-fixes).
- commit d6d316d
* Fri Apr  9 2021 tiwai@suse.de
- ALSA: hda/realtek: Fix speaker amp setup on Acer Aspire E1
  (git-fixes).
- ASoC: fsl_esai: Fix TDM slot setup for I2S mode (git-fixes).
- commit cf1864e
* Fri Apr  9 2021 tiwai@suse.de
- ASoC: sunxi: sun4i-codec: fill ASoC card owner (git-fixes).
- ASoC: cygnus: fix for_each_child.cocci warnings (git-fixes).
- ASoC: max98373: Added 30ms turn on/off time delay (git-fixes).
- ASoC: intel: atom: Remove 44100 sample-rate from the media
  and deep-buffer DAI descriptions (git-fixes).
- ASoC: intel: atom: Stop advertising non working S24LE support
  (git-fixes).
- commit c53d82c
* Fri Apr  9 2021 tiwai@suse.de
- ASoC: wm8960: Fix wrong bclk and lrclk with pll enabled for
  some chips (git-fixes).
- ALSA: aloop: Fix initialization of controls (git-fixes).
- commit 71addac
* Fri Apr  9 2021 msuchanek@suse.de
- post.sh: Return an error when module update fails (bsc#1047233 bsc#1184388).
- commit 18f65df
* Fri Apr  9 2021 glin@suse.com
- ftrace: Fix modify_ftrace_direct (bsc#1177028).
- commit f202820
* Thu Apr  8 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/cifs_debug-use-pd-instead-of-messing-with-d_name.patch
- commit 27776f2
* Thu Apr  8 2021 msuchanek@suse.de
- crypto: essiv - fix AEAD capitalization and preposition use
  in help text (bsc#1184134 ltc#192244).
- commit ba310cd
* Thu Apr  8 2021 aaptel@suse.com
- cifs: do not send close in compound create+close requests
  (bsc#1181507).
- commit d97055c
* Thu Apr  8 2021 aaptel@suse.com
- cifs: New optype for session operations (bsc#1181507).
- commit d9ec8fd
* Thu Apr  8 2021 aaptel@suse.com
- smb3: fix crediting for compounding when only one request in
  flight (bsc#1181507).
- commit 598fa94
* Thu Apr  8 2021 aaptel@suse.com
- cifs: Tracepoints and logs for tracing credit changes
  (bsc#1181507).
- commit 1eadfe8
* Thu Apr  8 2021 aaptel@suse.com
- smb3: add dynamic trace point to trace when credits obtained
  (bsc#1181507).
- commit bef40ec
* Thu Apr  8 2021 aaptel@suse.com
- cifs: return proper error code in statfs(2) (bsc#1181507).
- commit c4b8c95
* Thu Apr  8 2021 aaptel@suse.com
- cifs: change noisy error message to FYI (bsc#1181507).
- commit 569c695
* Thu Apr  8 2021 aaptel@suse.com
- cifs: print MIDs in decimal notation (bsc#1181507).
- commit 59ea5c8
* Thu Apr  8 2021 aaptel@suse.com
- cifs_debug: use %%pd instead of messing with ->d_name
  (bsc#1181507).
- commit 11a6a1c
* Thu Apr  8 2021 pjakobsson@suse.de
- drm/shmem-helpers: vunmap: Don't put pages for dma-buf
  (git-fixes).
- commit 5f834c0
* Thu Apr  8 2021 pjakobsson@suse.de
- powerpc: Fix missing declaration ofable_kernel_vsx()
  (git-fixes).
- commit a1121de
* Thu Apr  8 2021 msuchanek@suse.de
- crypto: essiv - create wrapper template for ESSIV generation
  (bsc#1184134 ltc#192244).
  Update config files.
  supported.conf: Add crypto/essiv
- commit 07e8de6
* Thu Apr  8 2021 pjakobsson@suse.de
- blacklist.conf: 862314bc94dd drm/msm/dpu: Allow specifying features and sblk in DSPP_BLK macro
- commit 27ff597
* Thu Apr  8 2021 pjakobsson@suse.de
- Refresh
  patches.suse/drm-amd-display-Revert-Fix-EDID-parsing-after-resume.patch.
  Add Alt-commit for duplicate
- commit d887b41
* Thu Apr  8 2021 pjakobsson@suse.de
- blacklist.conf: 8dc61152dfd2 mfd: iqs62x: Remove superfluous whitespace above fallthroughs
- commit 5583204
* Thu Apr  8 2021 pjakobsson@suse.de
- blacklist.conf: 4a517faa3403 amdgpu: fix clang build warning
  Also add duplicate 00190bc087e795290502dc51c5d32de85cb2c2b8
- commit 4525ce3
* Thu Apr  8 2021 dwagner@suse.de
- nvme-tcp: use cancel tagset helper for tear down (bsc#1183976).
- nvme-tcp: add clean action for failed reconnection
  (bsc#1183976).
- nvme-core: add cancel tagset helpers (bsc#1183976).
- commit 5f7f322
* Thu Apr  8 2021 bp@suse.de
- x86/ioapic: Ignore IRQ2 again (bsc#1152489).
- commit a2a38c4
* Thu Apr  8 2021 pjakobsson@suse.de
- Refresh
  patches.suse/drm-i915-Fix-ICL-MG-PHY-vswing-handling.patch.
  Add Alt-commit for duplicate
- commit a41e20d
* Thu Apr  8 2021 pjakobsson@suse.de
- blacklist.conf: b89bc060b53e sh/intc: Restore devm_ioremap() alignment
- commit da153ff
* Thu Apr  8 2021 tiwai@suse.de
- drivers: video: fbcon: fix NULL dereference in fbcon_cursor()
  (git-fixes).
- drm/amdkfd: dqm fence memory corruption (git-fixes).
- rtw88: coex: 8821c: correct antenna switch function (git-fixes).
- commit ba76fce
* Thu Apr  8 2021 pjakobsson@suse.de
- blacklist.conf: b3bf99daaee9 drm/i915/display: Defer initial modeset until after GGTT is initialised
  Actually blacklist it this time and not just the duplicate (see SUSE commit
  2d3d7c9c5aca141e8660e8671e699509c329d847)
- commit b907ace
* Thu Apr  8 2021 tiwai@suse.de
- thermal/core: Add NULL pointer check before using cooling
  device stats (git-fixes).
- commit 4299a85
* Thu Apr  8 2021 tiwai@suse.de
- soc/fsl: qbman: fix conflicting alignment attributes
  (git-fixes).
- regulator: bd9571mwv: Fix AVS and DVFS voltage range
  (git-fixes).
- drivers: video: fbcon: fix NULL dereference in fbcon_cursor()
  (git-fixes).
- usbip: vhci_hcd fix shift out-of-bounds in vhci_hub_control()
  (git-fixes).
- USB: quirks: ignore remote wake-up on Fibocom L850-GL LTE modem
  (git-fixes).
- USB: cdc-acm: downgrade message to debug (git-fixes).
- USB: cdc-acm: untangle a circular dependency between callback
  and softint (git-fixes).
- PM: runtime: Fix ordering in pm_runtime_get_suppliers()
  (git-fixes).
- drm/amdgpu: check alignment on CPU page for bo map (git-fixes).
- drm/amdgpu: fix offset calculation in
  amdgpu_vm_bo_clear_mappings() (git-fixes).
- staging: comedi: cb_pcidas64: fix request_irq() warn
  (git-fixes).
- staging: comedi: cb_pcidas: fix request_irq() warn (git-fixes).
- net: wan/lmc: unregister device when no matching device is found
  (git-fixes).
- appletalk: Fix skb allocation size in loopback case (git-fixes).
- ath10k: hold RCU lock when calling
  ieee80211_find_sta_by_ifaddr() (git-fixes).
- brcmfmac: clear EAP/association status bits on linkdown events
  (git-fixes).
- commit cb365ba
* Thu Apr  8 2021 bp@suse.de
- blacklist.conf: 04b38d012556 seccomp: Add missing return in non-void function
- commit 0d7b046
* Thu Apr  8 2021 bp@suse.de
- x86/mem_encrypt: Correct physical address calculation in
  __set_clr_pte_enc() (bsc#1152489).
- commit 5c288fb
* Wed Apr  7 2021 msuchanek@suse.de
- kABI: powerpc/pmem: Include pmem prototypes (bsc#1113295
  git-fixes).
- commit c94e7f1
* Wed Apr  7 2021 fdmanana@suse.com
- btrfs: fix exhaustion of the system chunk array due to
  concurrent allocations (bsc#1183386).
- commit 6cb1172
* Wed Apr  7 2021 ykaukab@suse.de
- net: dsa: felix: implement port flushing on
  .phylink_mac_link_down (git-fixes).
- PCI: tegra: Fix ASPM-L1SS advertisement disable code
  (git-fixes).
- PCI: tegra: Move "dbi" accesses to post common DWC
  initialization (git-fixes).
- thermal/drivers/cpufreq_cooling: Update cpufreq_state only if
  state has changed (git-fixes).
- coresight: tmc-etr: Fix barrier packet insertion for perf buffer
  (git-fixes).
- dpaa_eth: copy timestamp fields to new skb in A-050385
  workaround (git-fixes).
- enetc: Let the hardware auto-advance the taprio base-time of 0
  (git-fixes).
- enetc: Workaround for MDIO register access issue (git-fixes).
- dpaa_eth: fix the RX headroom size alignment (git-fixes).
- dpaa_eth: update the buffer layout for non-A050385 erratum
  scenarios (git-fixes).
- PCI: designware-ep: Fix the Header Type check (git-fixes).
- coresight: etm4x: Fix save and restore of TRCVMIDCCTLR1 register
  (git-fixes).
- coresight: etm4x: Fix issues on trcseqevr access (git-fixes).
- dpaa_eth: Remove unnecessary boolean expression in
  dpaa_get_headroom (git-fixes).
- commit 5b9762c
* Wed Apr  7 2021 msuchanek@suse.de
- powerpc/uaccess: Avoid might_fault() when user access is enabled
  (bsc#1156395).
- powerpc/uaccess: Simplify unsafe_put_user() implementation
  (bsc#1156395).
- powerpc/uaccess: Perform barrier_nospec() in KUAP allowance
  helpers (bsc#1156395).
- commit c1e0284
* Wed Apr  7 2021 lhenriques@suse.de
- fuse: fix live lock in fuse_iget() (bsc#1184211).
- fuse: fix bad inode (bsc#1184211).
- commit 58bcd3b
* Wed Apr  7 2021 lhenriques@suse.de
- fuse: fix live lock in fuse_iget() (bsc#1184211).
- fuse: fix bad inode (bsc#1184211).
- commit 8283ce1
* Wed Apr  7 2021 msuchanek@suse.de
- powerpc/kuap: Restore AMR after replaying soft interrupts
  (bsc#1156395).
- commit 3d73cad
* Wed Apr  7 2021 msuchanek@suse.de
- powerpc/sstep: Check instruction validity against ISA version
  before emulation (bsc#1156395).
- commit d427ef6
* Wed Apr  7 2021 msuchanek@suse.de
- powerpc/sstep: Fix darn emulation (bsc#1156395).
- powerpc/sstep: Fix incorrect return from analyze_instr()
  (bsc#1156395).
- powerpc/sstep: Check instruction validity against ISA version
  before emulation (bsc#1156395).
- commit 7671d9d
* Wed Apr  7 2021 msuchanek@suse.de
- powerpc/pmem: Include pmem prototypes (bsc#1113295 git-fixes).
- commit aa380dd
* Wed Apr  7 2021 msuchanek@suse.de
- blacklist.conf: Add c420644c0a8f powerpc: Use mm_context vas_windows
  counter to issue CP_ABORT
- commit c75afe3
* Wed Apr  7 2021 msuchanek@suse.de
- powerpc/sstep: Fix load-store and update emulation
  (bsc#1156395).
- powerpc/64s: Fix instruction encoding for lis in
  ppc_function_entry() (bsc#1065729).
- powerpc/pseries/ras: Remove unused variable 'status'
  (bsc#1065729).
- commit 9c1ced3
* Wed Apr  7 2021 glin@suse.com
- libbpf: Fix error path in bpf_object__elf_init() (bsc#1177028).
- tools/resolve_btfids: Fix build error with older host toolchains
  (bsc#1177028).
- bpf: Fix an unitialized value in bpf_iter (bsc#1177028).
- commit b032d8d
* Tue Apr  6 2021 mkubecek@suse.cz
- Update kabi files.
- update from April 2021 maintenance update submission (commit fe55a5cff456)
- commit c1ea1f7
* Tue Apr  6 2021 dbueso@suse.de
- locking/mutex: Fix non debug version of mutex_lock_io_nested() (git-fixes).
- commit 3bace53
* Tue Apr  6 2021 tiwai@suse.de
- firewire: nosy: Fix a use-after-free bug in nosy_ioctl()
  (CVE-2021-3483 bsc#1184393).
- commit 3abcfe1
* Tue Apr  6 2021 oneukum@suse.com
- media: v4l: ioctl: Fix memory leak in video_usercopy
  (bsc#1184120 CVE-2021-30002).
- commit 968da96
* Tue Apr  6 2021 tiwai@suse.de
- drm/i915: Fix invalid access to ACPI _DSM objects (bsc#1184074).
- commit 7bfde57
* Tue Apr  6 2021 ykaukab@suse.de
- i2c: tegra: Use threaded interrupt (bsc#1184386).
- i2c: tegra: Create i2c_writesl_vi() to use with VI I2C for
  filling TX FIFO (bsc#1184386).
- i2c: tegra: Wait for config load atomically while in ISR
  (bsc#1184386).
- i2c: tegra: Improve driver module description (bsc#1184386).
- i2c: tegra: Clean up whitespaces, newlines and indentation
  (bsc#1184386).
- i2c: tegra: Clean up and improve comments (bsc#1184386).
- i2c: tegra: Clean up printk messages (bsc#1184386).
- i2c: tegra: Clean up variable names (bsc#1184386).
- i2c: tegra: Improve formatting of variables (bsc#1184386).
- i2c: tegra: Check errors for both positive and negative values
  (bsc#1184386).
- i2c: tegra: Factor out hardware initialization into separate
  function (bsc#1184386).
- i2c: tegra: Factor out register polling into separate function
  (bsc#1184386).
- i2c: tegra: Factor out packet header setup from
  tegra_i2c_xfer_msg() (bsc#1184386).
- i2c: tegra: Factor out error recovery from tegra_i2c_xfer_msg()
  (bsc#1184386).
- i2c: tegra: Rename wait/poll functions (bsc#1184386).
- i2c: tegra: Remove "dma" variable from tegra_i2c_xfer_msg()
  (bsc#1184386).
- i2c: tegra: Remove redundant check in
  tegra_i2c_issue_bus_clear() (bsc#1184386).
- i2c: tegra: Remove likely/unlikely from the code (bsc#1184386).
- i2c: tegra: Remove outdated barrier() (bsc#1184386).
- i2c: tegra: Clean up variable types (bsc#1184386).
- i2c: tegra: Reorder location of functions in the code
  (bsc#1184386).
- i2c: tegra: Clean up probe function (bsc#1184386).
- i2c: tegra: Move out all device-tree parsing into
  tegra_i2c_parse_dt() (bsc#1184386).
- i2c: tegra: Use clk-bulk helpers (bsc#1184386).
- i2c: tegra: Use platform_get_irq() (bsc#1184386).
- i2c: tegra: Use devm_platform_get_and_ioremap_resource()
  (bsc#1184386).
- i2c: tegra: Use reset_control_reset() (bsc#1184386).
- i2c: tegra: Remove error message used for devm_request_irq()
  failure (bsc#1184386).
- i2c: tegra: Runtime PM always available on Tegra (bsc#1184386).
- i2c: tegra: Remove i2c_dev.clk_divisor_non_hs_mode member
  (bsc#1184386).
- i2c: tegra: Initialize div-clk rate unconditionally
  (bsc#1184386).
- i2c: tegra: Mask interrupt in tegra_i2c_issue_bus_clear()
  (bsc#1184386).
- i2c: tegra: Handle potential error of tegra_i2c_flush_fifos()
  (bsc#1184386).
- i2c: tegra: Add missing pm_runtime_put() (bsc#1184386).
- i2c: tegra: Make tegra_i2c_flush_fifos() usable in atomic
  transfer (bsc#1184386).
- commit a5dde2d
* Tue Apr  6 2021 ykaukab@suse.de
- tee: optee: remove need_resched() before cond_resched()
  (git-fixes).
- commit ef989ae
* Tue Apr  6 2021 dwagner@suse.de
- Drop patches.suse/nvme-re-read-ana-log-on-ns-changed-aen.patch
  This patch has been replaced by
  patches.suse/nvme-retrigger-ana-log-update-if-group-descriptor-isn-t.patch
- commit b31f4a4
* Tue Apr  6 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/completion-Drop-init_completion-define.patch
- commit 33fba8d
* Tue Apr  6 2021 ykaukab@suse.de
- net: enetc: allow hardware timestamping on TX queues with
  tc-etf enabled (git-fixes).
- net: enetc: don't disable VLAN filtering in IFF_PROMISC mode
  (git-fixes).
- tee: optee: replace might_sleep with cond_resched (git-fixes).
- Revert "drivers: qcom: rpmh-rsc: Use rcuidle tracepoints for
  rpmh" (git-fixes).
- coresight: remove broken __exit annotations (git-fixes).
- gpiolib: Don't free if pin ranges are not defined (git-fixes).
- commit 3b01237
* Tue Apr  6 2021 pjakobsson@suse.de
- blacklist.conf: 717c4c833648 arm64: defconfig: drop unused BACKLIGHT_GENERIC option
- commit 1db5def
* Tue Apr  6 2021 pjakobsson@suse.de
- blacklist.conf: acf689134a66 powerpc/configs: drop unused BACKLIGHT_GENERIC option
- commit e22a83a
* Tue Apr  6 2021 pjakobsson@suse.de
- blacklist.conf: Remove duplicate blacklist entries
- commit 94f95d4
* Tue Apr  6 2021 pjakobsson@suse.de
- blacklist.conf: 0437141b4e22 ARM: configs: drop unused BACKLIGHT_GENERIC option
- commit 59fb916
* Tue Apr  6 2021 msuchanek@suse.de
- ibmvnic: Use 'skb_frag_address()' instead of hand coding it
  (bsc#1184114 ltc#192237).
- commit 52ca26e
* Tue Apr  6 2021 glin@suse.com
- libbpf: Fix BTF dump of pointer-to-array-of-struct
  (bsc#1155518).
- libbpf: Use SOCK_CLOEXEC when opening the netlink socket
  (bsc#1155518).
- selftests/bpf: Set gopt opt_class to 0 if get tunnel opt failed
  (bsc#1155518).
- libbpf: Clear map_info before each bpf_obj_get_info_by_fd
  (bsc#1155518).
- samples, bpf: Add missing munmap in xdpsock (bsc#1155518).
- selftests/bpf: Mask bpf_csum_diff() return value to 16 bits
  in test_verifier (bsc#1155518).
- selftests/bpf: No need to drop the packet when there is no
  geneve opt (bsc#1155518).
- commit 8d0ef1a
* Tue Apr  6 2021 pjakobsson@suse.de
- drm/i915/selftests: Fix some error codes (git-fixes).
- commit 21e8c0f
* Tue Apr  6 2021 pjakobsson@suse.de
- drm: rcar-du: Fix leak of CMM platform device reference
  (git-fixes).
- commit 40608ab
* Tue Apr  6 2021 ohering@suse.de
- video: hyperv_fb: Fix a double free in hvfb_probe (git-fixes).
- commit c457d1d
* Mon Apr  5 2021 dbueso@suse.de
- selinux: fix inode_doinit_with_dentry() LABEL_INVALID error
  handling (git-fixes).
- commit fa2b85d
* Mon Apr  5 2021 dbueso@suse.de
- include/linux/sched/mm.h: use rcu_dereference in in_vfork()
  (git-fixes).
- stop_machine: mark helpers __always_inline (git-fixes).
- selinux: fix error initialization in inode_doinit_with_dentry()
  (git-fixes).
- completion: Drop init_completion define (git-fixes).
- lib/syscall: fix syscall registers retrieval on 32-bit platforms
  (git-fixes).
- selinux: Fix error return code in sel_ib_pkey_sid_slow()
  (git-fixes).
- commit 3909dc1
* Mon Apr  5 2021 tiwai@suse.de
- extcon: Fix error handling in extcon_dev_register (git-fixes).
- extcon: Add stubs for extcon_register_notifier_all() functions
  (git-fixes).
- staging: rtl8192e: Change state information from u16 to u8
  (git-fixes).
- staging: rtl8192e: Fix incorrect source in memcpy() (git-fixes).
- usb: dwc2: Prevent core suspend when port connection flag is 0
  (git-fixes).
- usb: dwc2: Fix HPRT0.PrtSusp bit setting for HiKey 960 board
  (git-fixes).
- usb: musb: Fix suspend with devices connected for a64
  (git-fixes).
- usb: xhci-mtk: fix broken streams issue on 0.96 xHCI
  (git-fixes).
- USB: cdc-acm: fix use-after-free after probe failure
  (git-fixes).
- USB: cdc-acm: fix double free on probe failure (git-fixes).
- cdc-acm: fix BREAK rx code path adding necessary calls
  (git-fixes).
- usb: gadget: udc: amd5536udc_pci fix null-ptr-dereference
  (git-fixes).
- commit 7e1215f
* Sun Apr  4 2021 msuchanek@suse.de
- powerpc/pseries/mobility: handle premature return from H_JOIN
  (bsc#1181674 ltc#189159 git-fixes bsc#1183662 ltc#191922).
- powerpc/pseries/mobility: use struct for shared state
  (bsc#1181674 ltc#189159 git-fixes bsc#1183662 ltc#191922).
- commit e22e432
* Sun Apr  4 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/powerpc-pseries-mobility-handle-premature-return-fro.patch.
- Refresh
  patches.suse/powerpc-pseries-mobility-use-struct-for-shared-state.patch.
  Update metadata
- commit 61adb77
* Sun Apr  4 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/powerpc-pseries-mobility-handle-premature-return-fro.patch.
- Refresh
  patches.suse/powerpc-pseries-mobility-use-struct-for-shared-state.patch.
- commit 0879685
* Sat Apr  3 2021 jkosina@suse.cz
- net: sched: disable TCQ_F_NOLOCK for pfifo_fast (bsc#1183405)
- commit 023c8a4
* Sat Apr  3 2021 jlee@suse.com
- ACPICA: Enable sleep button on ACPI legacy wake (bsc#1181383).
- commit 0d9d4e6
* Sat Apr  3 2021 tiwai@suse.de
- ACPI: processor: Fix CPU0 wakeup in acpi_idle_play_dead()
  (git-fixes).
- PM: runtime: Fix ordering in pm_runtime_get_suppliers()
  (git-fixes).
- drm/tegra: dc: Restore coupling of display controllers
  (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 640 G8
  (git-fixes).
- ALSA: hda: Add missing sanity checks in PM prepare/complete
  callbacks (git-fixes).
- ALSA: hda: Re-add dropped snd_poewr_change_state() calls
  (git-fixes).
- commit 7b7be94
* Sat Apr  3 2021 tiwai@suse.de
- PM: runtime: Fix race getting/putting suppliers at probe
  (git-fixes).
- drm/tegra: sor: Grab runtime PM reference across reset
  (git-fixes).
- commit 064f8f4
* Sat Apr  3 2021 tiwai@suse.de
- ALSA: usb-audio: Apply sample rate quirk to Logitech Connect
  (git-fixes).
- ALSA: hda/realtek: call alc_update_headset_mode() in
  hp_automute_hook (git-fixes).
- ALSA: hda/realtek: fix a determine_headset_type issue for a
  Dell AIO (git-fixes).
- commit e6c8166
* Thu Apr  1 2021 pjakobsson@suse.de
- blacklist.conf: b3bf99daaee9 drm/i915/display: Defer initial modeset until after GGTT is initialised
- commit 2d3d7c9
* Thu Apr  1 2021 pjakobsson@suse.de
- drm/i915: Fix ICL MG PHY vswing handling (git-fixes).
- commit cc5d549
* Thu Apr  1 2021 fdmanana@suse.com
- Update
  patches.suse/btrfs-fix-race-when-cloning-extent-buffer-during-rew.patch
  (bsc#1184193 CVE-2021-28964).
- commit 2c0102a
* Thu Apr  1 2021 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: Get rid of bogus
  nouveau_conn_mode_valid() (git-fixes).
- commit 67c74c9
* Thu Apr  1 2021 pjakobsson@suse.de
- drm/i915: Hold onto an explicit ref to i915_vma_work.pinned
  (git-fixes).
- commit b6ebc10
* Thu Apr  1 2021 jdelvare@suse.de
- Update references of patches.suse/edac-amd64-set-grain-per-dimm.patch
- commit 881829d
* Thu Apr  1 2021 ykaukab@suse.de
- irqchip/ls-extirq: add IRQCHIP_SKIP_SET_WAKE to the irqchip flags (bsc#1184264).
- irqchip/ls-extirq: Add LS1043A, LS1088A external interrupt support (bsc#1184264).
- commit 4dd3d12
* Thu Apr  1 2021 glin@suse.com
- bpf: Don't do bpf_cgroup_storage_set() for kuprobe/tp programs
  (bsc#1155518).
- commit 5d2df4e
* Thu Apr  1 2021 tiwai@suse.de
- pinctrl: rockchip: fix restore error in resume (git-fixes).
- commit 55f3605
* Thu Apr  1 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/mm-numa-fix-bad-pmd-by-atomically-check-for-pmd_trans_huge-when-marking-page-tables-prot_numa.patch
- commit e108d2c
* Thu Apr  1 2021 tonyj@suse.de
- perf/x86/intel: Fix a crash caused by zero PEBS status
  (CVE-2021-28971 bsc#1184196).
- commit fbc79f5
* Wed Mar 31 2021 jgross@suse.com
- xen-blkback: don't leak persistent grants from xen_blkbk_map()
  (bsc#1183646, CVE-2021-28688, XSA-371).
- commit d927391
* Wed Mar 31 2021 jgross@suse.com
- xen-blkback: don't leak persistent grants from xen_blkbk_map()
  (bsc#1183646, CVE-2021-28688, XSA-371).
- commit f0c74da
* Wed Mar 31 2021 msuchanek@suse.de
- blacklist.conf: Add qspinlock commit revert.
- commit fbfdb5d
* Wed Mar 31 2021 fdmanana@suse.com
- btrfs: fix exhaustion of the system chunk array due to
  concurrent allocations (bsc#1183386).
- commit 419a4b8
* Wed Mar 31 2021 fdmanana@suse.com
- btrfs: fix subvolume/snapshot deletion not triggered on mount
  (bsc#1184219).
- btrfs: always pin deleted leaves when there are active tree
  mod log users (bsc#1184224).
- btrfs: fix race when cloning extent buffer during rewind of
  an old root (bsc#1184193).
- btrfs: fix stale data exposure after cloning a hole with
  NO_HOLES enabled (bsc#1184220).
- btrfs: fix extent buffer leak on failure to copy root
  (bsc#1184218).
- btrfs: abort the transaction if we fail to inc ref in
  btrfs_copy_root (bsc#1184217).
- commit ed1e8cf
* Wed Mar 31 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/netsec-restore-phy-power-state-after-controller-rese.patch.
- commit ea9970d
* Wed Mar 31 2021 oneukum@suse.com
- blacklist.conf: breaks kABI
- commit 7450a15
* Wed Mar 31 2021 tiwai@suse.de
- drm/amdgpu: Add additional Sienna Cichlid PCI ID (git-fixes).
- mac80211: Allow HE operation to be longer than expected
  (git-fixes).
- drm/amdgpu: fb BO should be ttm_bo_type_device (git-fixes).
- drm/amd/display: Revert dram_clock_change_latency for DCN2.1
  (git-fixes).
- commit f4fe93c
* Wed Mar 31 2021 oneukum@suse.com
- media: vicodec: add missing v4l2_ctrl_request_hdl_put()
  (git-fixes).
- commit 1714c92
* Wed Mar 31 2021 oneukum@suse.com
- blacklist.conf: cosmetic fix
- commit 1478eb5
* Wed Mar 31 2021 oneukum@suse.com
- media: cros-ec-cec: do not bail on device_init_wakeup failure
  (git-fixes).
- commit 5533664
* Wed Mar 31 2021 tiwai@suse.de
- PM: EM: postpone creating the debugfs dir till fs_initcall
  (git-fixes).
- bus: omap_l3_noc: mark l3 irqs as IRQF_NO_THREAD (git-fixes).
- net: cdc-phonet: fix data-interface release on probe failure
  (git-fixes).
- mac80211: fix double free in ibss_leave (git-fixes).
- mac80211: fix rate mask reset (git-fixes).
- platform/x86: intel-vbtn: Stop reporting SW_DOCK events
  (git-fixes).
- drm/radeon: fix AGP dependency (git-fixes).
- gpiolib: acpi: Add missing IRQF_ONESHOT (git-fixes).
- ACPI: scan: Rearrange memory allocation in acpi_device_add()
  (git-fixes).
- gianfar: Account for Tx PTP timestamp in the skb headroom
  (git-fixes).
- gianfar: Replace skb_realloc_headroom with skb_cow_head for PTP
  (git-fixes).
- net: gianfar: Add of_node_put() before goto statement
  (git-fixes).
- gianfar: Fix TX timestamping with a stacked DSA driver
  (git-fixes).
- commit dbf2451
* Wed Mar 31 2021 oneukum@suse.com
- blacklist.conf: the fix is cosmetic
- commit 5c3f4dc
* Wed Mar 31 2021 glin@suse.com
- bpf: Fix truncation handling for mod32 dst reg wrt zero
  (bsc#1184170 CVE-2021-3444).
- bpf: Fix 32 bit src register truncation on div/mod
  (bsc#1184170).
- commit af158b0
* Wed Mar 31 2021 glin@suse.com
- Update patches.suse/bpf-Fix-truncation-handling-for-mod32-dst-reg-wrt-ze.patch
  Update the tag for bsc#1184170 and CVE-2021-3444.
- commit ad1dd40
* Wed Mar 31 2021 tiwai@suse.de
- Update patch reference for a usbip fix (CVE-2021-29265 bsc#1184167)
- commit 6988aeb
* Wed Mar 31 2021 tiwai@suse.de
- gianfar: fix jumbo packets+napi+rx overrun crash (CVE-2021-29264
  bsc#1184168).
- commit 9ae0342
* Wed Mar 31 2021 tiwai@suse.de
- Update patch reference of a PCI fix (CVE-2021-28972 bsc#1184198)
- commit dc7fd0e
* Wed Mar 31 2021 mgorman@suse.de
- mm, numa: fix bad pmd by atomically check for pmd_trans_huge
  when marking page tables prot_numa (bsc#1168777).
- commit c5a52b2
* Wed Mar 31 2021 tiwai@suse.de
- net: qrtr: fix a kernel-infoleak in qrtr_recvmsg()
  (CVE-2021-29647 bsc#1184192).
- commit f71857e
* Wed Mar 31 2021 tiwai@suse.de
- Update patch reference of a sound fix (CVE-2021-28952 bsc#1184197)
- commit 5223811
* Wed Mar 31 2021 ddiss@suse.de
- ovl: fix dentry leak in ovl_get_redirect (bsc#1184176).
- ovl: fix unneeded call to ovl_change_flags() (bsc#1184176).
- ovl: fix regression with re-formatted lower squashfs
  (bsc#1184176).
- ovl: relax WARN_ON() when decoding lower directory file handle
  (bsc#1184176).
- ovl: initialize error in ovl_copy_xattr (bsc#1184176).
- ovl: fix out of date comment and unreachable code (bsc#1184176).
- ovl: fix value of i_ino for lower hardlink corner case
  (bsc#1184176).
- commit 6ae489b
* Tue Mar 30 2021 tbogendoerfer@suse.de
- ionic: linearize tso skb with too many frags (bsc#1167773).
- igc: Fix igc_ptp_rx_pktstamp() (bsc#1160634).
- commit 3e13df7
* Tue Mar 30 2021 tbogendoerfer@suse.de
- ionic: linearize tso skb with too many frags (bsc#1167773).
- nfp: flower: fix pre_tun mask id allocation (bsc#1154353).
- flow_dissector: fix byteorder of dissected ICMP ID
  (bsc#1154353).
- Revert "net: bonding: fix error return code of
  bond_neigh_init()" (bsc#1154353).
- igc: Fix igc_ptp_rx_pktstamp() (bsc#1160634).
- net/mlx5e: E-switch, Fix rate calculation division
  (jsc#SLE-8464).
- commit dcb0376
* Tue Mar 30 2021 oneukum@suse.com
- thunderbolt: Add support for Intel Tiger Lake-H (bsc#1184129).
- commit a872918
* Tue Mar 30 2021 dwagner@suse.de
- Replace ANA log reread patch
  Replace the fix with a simpler version. The upstream community
  has agreed on the simpler version after the ECN has been ratified.
  deleted:    patches.suse/nvme-re-read-ana-log-on-ns-changed-aen.patch
  new file:   patches.suse/nvme-retrigger-ana-log-update-if-group-descriptor-isn-t.patch
- commit 391a31f
* Tue Mar 30 2021 oneukum@suse.com
- thunderbolt: Introduce tb_switch_is_tiger_lake() (bsc#1184129).
- commit cb3c283
* Tue Mar 30 2021 tbogendoerfer@suse.de
- ch_ktls: fix enum-conversion warning (jsc#SLE-15129).
- net/mlx5e: Offload tuple rewrite for non-CT flows
  (jsc#SLE-15172).
- net/mlx5e: Allow to match on MPLS parameters only for MPLS
  over UDP (jsc#SLE-15172).
- net/mlx5: Add back multicast stats for uplink representor
  (jsc#SLE-15172).
- netfilter: flowtable: Make sure GC works periodically in idle
  system (bsc#1176447).
- netfilter: nftables: allow to update flowtable flags
  (bsc#1176447).
- netfilter: nftables: report EOPNOTSUPP on unsupported flowtable
  flags (bsc#1176447).
- nfp: flower: add ipv6 bit to pre_tunnel control message
  (bsc#1176447).
- net/mlx5e: RX, Mind the MPWQE gaps when calculating offsets
  (jsc#SLE-15172).
- commit bcf4d7a
* Tue Mar 30 2021 dwagner@suse.de
- nvme-fc: fix racing controller reset and create association
  (bsc#1183048).
- commit 69b4441
* Tue Mar 30 2021 dwagner@suse.de
- Move patches.suse/nvme-fc-avoid-calling-_nvme_fc_abort_outstanding_ios-from-interrupt-context.patch
  Move the patch into the sorted section.
- commit d6d55ac
* Tue Mar 30 2021 dwagner@suse.de
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/scsi-lpfc-Change-wording-of-invalid-pci-reset-log-me.patch
  patches.suse/scsi-lpfc-Correct-function-header-comments-related-t.patch
  patches.suse/scsi-lpfc-Fix-ADISC-handling-that-never-frees-nodes.patch
  patches.suse/scsi-lpfc-Fix-FLOGI-failure-due-to-accessing-a-freed.patch
  patches.suse/scsi-lpfc-Fix-PLOGI-ACC-to-be-transmit-after-REG_LOG.patch
  patches.suse/scsi-lpfc-Fix-crash-caused-by-switch-reboot.patch
  patches.suse/scsi-lpfc-Fix-dropped-FLOGI-during-pt2pt-discovery-r.patch
  patches.suse/scsi-lpfc-Fix-incorrect-dbde-assignment-when-buildin.patch
  patches.suse/scsi-lpfc-Fix-lpfc_els_retry-possible-null-pointer-d.patch
  patches.suse/scsi-lpfc-Fix-nodeinfo-debugfs-output.patch
  patches.suse/scsi-lpfc-Fix-null-pointer-dereference-in-lpfc_prep_.patch
  patches.suse/scsi-lpfc-Fix-pt2pt-connection-does-not-recover-afte.patch
  patches.suse/scsi-lpfc-Fix-pt2pt-state-transition-causing-rmmod-h.patch
  patches.suse/scsi-lpfc-Fix-reftag-generation-sizing-errors.patch
  patches.suse/scsi-lpfc-Fix-stale-node-accesses-on-stale-RRQ-reque.patch
  patches.suse/scsi-lpfc-Fix-status-returned-in-lpfc_els_retry-erro.patch
  patches.suse/scsi-lpfc-Fix-unnecessary-null-check-in-lpfc_release.patch
  patches.suse/scsi-lpfc-Fix-use-after-free-in-lpfc_els_free_iocb.patch
  patches.suse/scsi-lpfc-Fix-vport-indices-in-lpfc_find_vport_by_vp.patch
  patches.suse/scsi-lpfc-Reduce-LOG_TRACE_EVENT-logging-for-vports.patch
  patches.suse/scsi-lpfc-Update-copyrights-for-12.8.0.7-and-12.8.0..patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.8.patch
- commit 9b02aba
* Tue Mar 30 2021 colyli@suse.de
- mm/mremap_pages: fix static key devmap_managed_key updates
  (bsc#1181787).
- commit e836b25
* Tue Mar 30 2021 tiwai@suse.de
- iwlwifi: Fix MODULE_FIRMWARE() ucode definitions for SLE15-SP3
  (bsc#1183860).
- commit 8e0bc83
* Tue Mar 30 2021 glin@suse.com
- bpf: Add sanity check for upper ptr_limit (bsc#1183686
  bsc#1183775).
- bpf: Simplify alu_limit masking for pointer arithmetic
  (bsc#1183686 bsc#1183775).
- bpf: Fix off-by-one for area size in creating mask to left
  (bsc#1183775 CVE-2020-27171).
- bpf: Prohibit alu ops for pointer types not defining ptr_limit
  (bsc#1183686 CVE-2020-27170).
- commit d95f56b
* Mon Mar 29 2021 martin.wilck@suse.com
- scsi: target: pscsi: Clean up after failure in pscsi_map_sg()
  (bsc#1183843).
- commit 1af614d
* Mon Mar 29 2021 martin.wilck@suse.com
- scsi: target: pscsi: Avoid OOM in pscsi_map_sg() (bsc#1183843).
- commit 036f522
* Mon Mar 29 2021 msuchanek@suse.de
- powerpc/64s/exception: Clean up a missed SRR specifier
  (jsc#SLE-9246 git-fixes).
- powerpc: Fix inverted SET_FULL_REGS bitop (jsc#SLE-9246
  git-fixes).
- commit 7437426
* Mon Mar 29 2021 msuchanek@suse.de
- blacklist.conf: Add 5ae5fbd21079 powerpc/perf: Fix handling of privilege
  level checks in perf interrupt context
- commit a7c4b4d
* Mon Mar 29 2021 msuchanek@suse.de
- scsi: ibmvfc: Make ibmvfc_wait_for_ops() MQ aware (bsc#1184111
  ltc#192232).
- scsi: ibmvfc: Fix potential race in ibmvfc_wait_for_ops()
  (bsc#1184111 ltc#192232).
- commit ecee0a9
* Mon Mar 29 2021 mbrugger@suse.com
- arm64/crash_core: Export TCR_EL1.T1SZ in vmcoreinfo
  (bsc#1179863).
- crash_core, vmcoreinfo: Append 'MAX_PHYSMEM_BITS' to vmcoreinfo
  (bsc#1179863).
- commit 3277e15
* Mon Mar 29 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/netsec-restore-phy-power-state-after-controller-rese.patch
- commit a6a1fc0
* Sun Mar 28 2021 tiwai@suse.de
- drm/msm: Fix suspend/resume on i.MX5 (git-fixes).
- drm/amdgpu/display: restore AUX_DPHY_TX_CONTROL for DCN2.x
  (git-fixes).
- commit 048049e
* Sun Mar 28 2021 tiwai@suse.de
- can: peak_usb: Revert "can: peak_usb: add forgotten supported
  devices" (git-fixes).
- commit ab32250
* Sun Mar 28 2021 tiwai@suse.de
- ACPI: video: Add missing callback back for Sony VPCEH3U1E
  (git-fixes).
- ACPICA: Always create namespace nodes using
  acpi_ns_create_node() (git-fixes).
- drm/msm: fix shutdown hook in case GPU components failed to bind
  (git-fixes).
- can: m_can: m_can_do_rx_poll(): fix extraneous msg loss warning
  (git-fixes).
- can: c_can: move runtime PM enable/disable to c_can_platform
  (git-fixes).
- can: c_can_pci: c_can_pci_remove(): fix use-after-free
  (git-fixes).
- can: flexcan: flexcan_chip_freeze(): fix chip freeze for
  missing bitrate (git-fixes).
- can: peak_usb: add forgotten supported devices (git-fixes).
- commit 54aa0c3
* Fri Mar 26 2021 ematsumiya@suse.de
- nvme-tcp: fix possible hang when failing to set io queues
  (bsc#1181161).
- commit 7c2d106
* Fri Mar 26 2021 tiwai@suse.de
- r8169: fix DMA being used after buffer free if WoL is enabled
  (git-fixes).
- i915/perf: Start hrtimer only if sampling the OA buffer
  (git-fixes).
- drm/amd/display: Correct algorithm for reversed gamma
  (git-fixes).
- drm/amdgpu/display: use GFP_ATOMIC in
  dcn21_validate_bandwidth_fp() (git-fixes).
- drm/amd/display: turn DPMS off on connector unplug (git-fixes).
- commit 055deb9
* Thu Mar 25 2021 alnovak@suse.cz
- kernel/smp: make csdlock timeout depend on boot parameter
  (bsc#1180846).
  Explanation: this patch is meant to enable customers who encounter "lost
  IPI" issue to adjust the timeout to match their environment. The root
  cause is being investigated and we hope to drop it in the future.
- commit 8e8af38
* Wed Mar 24 2021 acho@suse.com
- s390/vtime: fix increased steal time accounting (bsc#1183859).
- commit 5026f60
* Wed Mar 24 2021 acho@suse.com
- s390/vtime: fix increased steal time accounting (bsc#1183859).
- commit c966973
* Wed Mar 24 2021 tiwai@suse.de
- usb: typec: tcpm: Invoke power_supply_changed for
  tcpm-source-psy- (git-fixes).
- usb-storage: Add quirk to defeat Kindle's automatic unload
  (git-fixes).
- usb: gadget: configfs: Fix KASAN use-after-free (git-fixes).
- USB: replace hardcode maximum usb string length by definition
  (git-fixes).
- commit fe3af72
* Wed Mar 24 2021 tiwai@suse.de
- Revert "PM: runtime: Update device status before letting
  suppliers suspend" (git-fixes).
- commit cc82105
* Tue Mar 23 2021 msuchanek@suse.de
- Refresh patch metadata.
- Refresh patches.suse/PCI-rpadlpar-Fix-potential-drc_name-corruption-in-st.patch.
- Refresh patches.suse/powerpc-pseries-mobility-handle-premature-return-fro.patch.
- Refresh patches.suse/powerpc-pseries-mobility-use-struct-for-shared-state.patch.
- Refresh patches.suse/scsi-ibmvfc-Free-channel_setup_buf-during-device-tea.patch.
- commit 815f258
* Tue Mar 23 2021 dwagner@suse.de
- nvme-fc: return NVME_SC_HOST_ABORTED_CMD when a command has
  been aborted (bsc#1180197).
- nvme-fc: set NVME_REQ_CANCELLED in nvme_fc_terminate_exchange()
  (bsc#1180197).
- nvme: add NVME_REQ_CANCELLED flag in nvme_cancel_request()
  (bsc#1180197).
- nvme: simplify error logic in nvme_validate_ns() (bsc#1180197).
- commit fbf98de
* Tue Mar 23 2021 dwagner@suse.de
- series.conf: cleanup
  - move mainline patches into sorted section
  patches.suse/PCI-rpadlpar-Fix-potential-drc_name-corruption-in-st.patch
  patches.suse/nvme-allocate-the-keep-alive-request-using-BLK_MQ_RE.patch
  patches.suse/nvme-fabrics-only-reserve-a-single-tag.patch
  patches.suse/nvme-merge-nvme_keep_alive-into-nvme_keep_alive_work.patch
  patches.suse/scsi-ibmvfc-Free-channel_setup_buf-during-device-tea.patch
  patches.suse/scsi-lpfc-Change-wording-of-invalid-pci-reset-log-me.patch
  patches.suse/scsi-lpfc-Correct-function-header-comments-related-t.patch
  patches.suse/scsi-lpfc-Fix-ADISC-handling-that-never-frees-nodes.patch
  patches.suse/scsi-lpfc-Fix-FLOGI-failure-due-to-accessing-a-freed.patch
  patches.suse/scsi-lpfc-Fix-PLOGI-ACC-to-be-transmit-after-REG_LOG.patch
  patches.suse/scsi-lpfc-Fix-crash-caused-by-switch-reboot.patch
  patches.suse/scsi-lpfc-Fix-dropped-FLOGI-during-pt2pt-discovery-r.patch
  patches.suse/scsi-lpfc-Fix-incorrect-dbde-assignment-when-buildin.patch
  patches.suse/scsi-lpfc-Fix-lpfc_els_retry-possible-null-pointer-d.patch
  patches.suse/scsi-lpfc-Fix-nodeinfo-debugfs-output.patch
  patches.suse/scsi-lpfc-Fix-null-pointer-dereference-in-lpfc_prep_.patch
  patches.suse/scsi-lpfc-Fix-pt2pt-connection-does-not-recover-afte.patch
  patches.suse/scsi-lpfc-Fix-pt2pt-state-transition-causing-rmmod-h.patch
  patches.suse/scsi-lpfc-Fix-reftag-generation-sizing-errors.patch
  patches.suse/scsi-lpfc-Fix-stale-node-accesses-on-stale-RRQ-reque.patch
  patches.suse/scsi-lpfc-Fix-status-returned-in-lpfc_els_retry-erro.patch
  patches.suse/scsi-lpfc-Fix-unnecessary-null-check-in-lpfc_release.patch
  patches.suse/scsi-lpfc-Fix-use-after-free-in-lpfc_els_free_iocb.patch
  patches.suse/scsi-lpfc-Fix-vport-indices-in-lpfc_find_vport_by_vp.patch
  patches.suse/scsi-lpfc-Reduce-LOG_TRACE_EVENT-logging-for-vports.patch
  patches.suse/scsi-lpfc-Update-copyrights-for-12.8.0.7-and-12.8.0..patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.8.patch
- commit c32363d
* Tue Mar 23 2021 dwagner@suse.de
- Drop patches.suse/nvme-return-an-error-if-nvme_set_queue_count-fails.patch
  Upstream fixed the problem differently than we have done in
  SLE15-SP2. Remove the SLE15-SP2 fix so that we can import then
  upstream fix for SLE15-SP3.
- commit 15d6660
* Tue Mar 23 2021 denis.kirjanov@suse.com
- net: korina: cast KSEG0 address to pointer in kfree (git-fixes).
- commit cfb1933
* Tue Mar 23 2021 tbogendoerfer@suse.de
- Refresh
  patches.suse/net-mlx5e-Fix-CQ-params-of-ICOSQ-and-async-ICOSQ.patch.
  Fixed backport (bsc#1183773)
- commit 9959a4b
* Mon Mar 22 2021 msuchanek@suse.de
- net: core: introduce __netdev_notify_peers (bsc#1183871
  ltc#192139).
- commit 658d714
* Mon Mar 22 2021 bp@suse.de
- EDAC/amd64: Get rid of the ECC disabled long message
  (bsc#1183815).
- commit 47c3bba
* Mon Mar 22 2021 msuchanek@suse.de
- ibmvnic: prefer strscpy over strlcpy (bsc#1183871 ltc#192139).
- ibmvnic: remove unused spinlock_t stats_lock definition
  (bsc#1183871 ltc#192139).
- ibmvnic: add comments for spinlock_t definitions (bsc#1183871
  ltc#192139).
- Refresh patches.suse/ibmvnic-serialize-access-to-work-queue-on-remove.patch
- Refresh patches.suse/net-re-solve-some-conflicts-after-net-net-next-merge.patch
- ibmvnic: fix miscellaneous checks (bsc#1183871 ltc#192139).
- ibmvnic: avoid multiple line dereference (bsc#1183871
  ltc#192139).
- ibmvnic: fix braces (bsc#1183871 ltc#192139).
- ibmvnic: fix block comments (bsc#1183871 ltc#192139).
- Refresh patches.suse/ibmvnic-fix-a-race-between-open-and-reset.patch.
- Refresh patches.suse/ibmvnic-serialize-access-to-work-queue-on-remove.patch.
- Refresh patches.suse/net-re-solve-some-conflicts-after-net-net-next-merge.patch.
- ibmvnic: prefer 'unsigned long' over 'unsigned long int'
  (bsc#1183871 ltc#192139).
- ibmvnic: remove unnecessary rmb() inside ibmvnic_poll
  (bsc#1183871 ltc#192139).
- ibmvnic: rework to ensure SCRQ entry reads are properly ordered
  (bsc#1183871 ltc#192139).
- net: ethernet: ibm: ibmvnic: Fix some kernel-doc misdemeanours
  (bsc#1183871 ltc#192139).
- ibmvnic: merge do_change_param_reset into do_reset (bsc#1183871
  ltc#192139).
- Refresh patches.suse/ibmvnic-fix-a-race-between-open-and-reset.patch
- use __netdev_notify_peers in ibmvnic (bsc#1183871 ltc#192139).
- ibmvnic: prefer strscpy over strlcpy (bsc#1183871 ltc#192139).
- ibmvnic: remove unused spinlock_t stats_lock definition
  (bsc#1183871 ltc#192139).
- ibmvnic: add comments for spinlock_t definitions (bsc#1183871
  ltc#192139).
- Refresh patches.suse/ibmvnic-serialize-access-to-work-queue-on-remove.patch
- Refresh patches.suse/net-re-solve-some-conflicts-after-net-net-next-merge.patch
- ibmvnic: fix miscellaneous checks (bsc#1183871 ltc#192139).
- ibmvnic: avoid multiple line dereference (bsc#1183871
  ltc#192139).
- ibmvnic: fix braces (bsc#1183871 ltc#192139).
- ibmvnic: fix block comments (bsc#1183871 ltc#192139).
- Refresh patches.suse/ibmvnic-fix-a-race-between-open-and-reset.patch.
- Refresh patches.suse/ibmvnic-serialize-access-to-work-queue-on-remove.patch.
- Refresh patches.suse/net-re-solve-some-conflicts-after-net-net-next-merge.patch.
- ibmvnic: prefer 'unsigned long' over 'unsigned long int'
  (bsc#1183871 ltc#192139).
- ibmvnic: remove unnecessary rmb() inside ibmvnic_poll
  (bsc#1183871 ltc#192139).
- ibmvnic: rework to ensure SCRQ entry reads are properly ordered
  (bsc#1183871 ltc#192139).
- net: ethernet: ibm: ibmvnic: Fix some kernel-doc misdemeanours
  (bsc#1183871 ltc#192139).
- ibmvnic: merge do_change_param_reset into do_reset (bsc#1183871
  ltc#192139).
- Refresh patches.suse/ibmvnic-fix-a-race-between-open-and-reset.patch
- use __netdev_notify_peers in ibmvnic (bsc#1183871 ltc#192139).
- commit efd07e6
* Mon Mar 22 2021 bp@suse.de
- EDAC/amd64: Check for memory before fully initializing an
  instance (bsc#1183815).
- commit 6c70428
* Mon Mar 22 2021 bp@suse.de
- EDAC/amd64: Use cached data when checking for ECC (bsc#1183815).
- commit ef0c794
* Mon Mar 22 2021 varad.gautam@suse.com
- squashfs: fix xattr id and id lookup sanity checks (bsc#1183850).
- commit b1827ac
* Mon Mar 22 2021 varad.gautam@suse.com
- squashfs: fix inode lookup sanity checks (bsc#1183850).
- commit 9b5c651
* Mon Mar 22 2021 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patches out of sorted section
  patches.suse/0001-squashfs-fix-inode-lookup-sanity-checks.patch
  patches.suse/0002-squashfs-fix-xattr-id-and-id-lookup-sanity-checks.patch
- commit 1d6e2f2
* Mon Mar 22 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/PCI-rpadlpar-Fix-potential-drc_name-corruption-in-st.patch
  patches.suse/nvme-allocate-the-keep-alive-request-using-BLK_MQ_RE.patch
  patches.suse/nvme-fabrics-only-reserve-a-single-tag.patch
  patches.suse/nvme-merge-nvme_keep_alive-into-nvme_keep_alive_work.patch
- commit 2e4b640
* Mon Mar 22 2021 tiwai@suse.de
- usb: typec: tcpm: Invoke power_supply_changed for
  tcpm-source-psy- (git-fixes).
- usb: typec: Remove vdo[3] part of tps6598x_rx_identity_reg
  struct (git-fixes).
- thunderbolt: Initialize HopID IDAs in tb_switch_alloc()
  (git-fixes).
- drm/i915/gvt: Set SNOOP for PAT3 on BXT/APL to workaround GPU
  BB hang (git-fixes).
- commit 15bf327
* Mon Mar 22 2021 tiwai@suse.de
- iio: gyro: mpu3050: Fix error handling in
  mpu3050_trigger_handler (git-fixes).
- iio: hid-sensor-temperature: Fix issues of timestamp channel
  (git-fixes).
- iio: hid-sensor-humidity: Fix alignment issue of timestamp
  channel (git-fixes).
- iio: adis16400: Fix an error code in adis16400_initial_setup()
  (git-fixes).
- iio: adc: ad7949: fix wrong ADC result due to incorrect bit mask
  (git-fixes).
- iio: hid-sensor-prox: Fix scale not correct issue (git-fixes).
- iio:adc:qcom-spmi-vadc: add default scale to LR_MUX2_BAT_ID
  channel (git-fixes).
- usbip: Fix incorrect double assignment to udc->ud.tcp_rx
  (git-fixes).
- efi: use 32-bit alignment for efi_guid_t literals (git-fixes).
- firmware/efi: Fix a use after bug in efi_mem_reserve_persistent
  (git-fixes).
- commit 5066b61
* Sat Mar 20 2021 tiwai@suse.de
- ALSA: usb-audio: Fix unintentional sign extension issue
  (git-fixes).
- ASoC: rt711: add snd_soc_component remove callback (git-fixes).
- ASoC: qcom: lpass-cpu: Fix lpass dai ids parse (git-fixes).
- ASoC: codecs: wcd934x: add a sanity check in set channel map
  (git-fixes).
- ASoC: qcom: sdm845: Fix array out of range on rx slim channels
  (git-fixes).
- ASoC: qcom: sdm845: Fix array out of bounds access (git-fixes).
- ASoC: SOF: intel: fix wrong poll bits in dsp power down
  (git-fixes).
- ASoC: SOF: Intel: unregister DMIC device on probe error
  (git-fixes).
- ASoC: rt1015: fix i2c communication error (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 850 G8
  (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 440 G8
  (git-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 840 G8
  (git-fixes).
- ALSA: dice: fix null pointer dereference when node is
  disconnected (git-fixes).
- commit 3dfb189
* Sat Mar 20 2021 tiwai@suse.de
- Fix tag of SCSI subsystem patches in sorted section
  Otherwise series_sort doesn't work
- commit a1dd7fa
* Sat Mar 20 2021 tiwai@suse.de
- ASoC: rt5659: Update MCLK rate in set_sysclk() (git-fixes).
- ASoC: simple-card-utils: Do not handle device clock (git-fixes).
- commit f987c3c
* Sat Mar 20 2021 tiwai@suse.de
- ASoC: cs42l42: Always wait at least 3ms after reset (git-fixes).
- ASoC: cs42l42: Don't enable/disable regulator at Bias Level
  (git-fixes).
- ASoC: cs42l42: Fix mixer volume control (git-fixes).
- ASoC: cs42l42: Fix channel width support (git-fixes).
- commit 61d6928
* Sat Mar 20 2021 tiwai@suse.de
- ASoC: cs42l42: Fix Bitclock polarity inversion (git-fixes).
- ASoC: rt5651: Fix dac- and adc- vol-tlv values being off by
  a factor of 10 (git-fixes).
- ASoC: rt5640: Fix dac- and adc- vol-tlv values being off by
  a factor of 10 (git-fixes).
- ASoC: es8316: Simplify adc_pga_gain_tlv table (git-fixes).
- ASoC: sgtl5000: set DAP_AVC_CTRL register to correct default
  value on probe (git-fixes).
- commit 629faf0
* Sat Mar 20 2021 tiwai@suse.de
- ASoC: Intel: bytcr_rt5640: Fix HP Pavilion x2 10-p0XX OVCD
  current threshold (git-fixes).
- ASoC: rt5670: Add emulated 'DAC1 Playback Switch' control
  (git-fixes).
- ASoC: rt5670: Remove ADC vol-ctrl mute bits poking from Sto1
  ADC mixer settings (git-fixes).
- ASoC: rt5670: Remove 'HP Playback Switch' control (git-fixes).
- ASoC: rt5670: Remove 'OUT Channel Switch' control (git-fixes).
- ASoC: ak5558: Add MODULE_DEVICE_TABLE (git-fixes).
- ASoC: ak4458: Add MODULE_DEVICE_TABLE (git-fixes).
- ASoC: fsl_ssi: Fix TDM slot setup for I2S mode (git-fixes).
- commit 01440d8
* Sat Mar 20 2021 tiwai@suse.de
- ALSA: hda/realtek: apply pin quirk for XiaomiNotebook Pro
  (git-fixes).
- ALSA: hda/realtek: Apply headset-mic quirks for Xiaomi Redmibook
  Air (git-fixes).
- ALSA: hda: generic: Fix the micmute led init state (git-fixes).
- commit fc72277
* Sat Mar 20 2021 jbohac@suse.cz
- net: make __dev_alloc_name consider all name nodes when looking
  for (bsc#1180103).
- commit 3400412
* Fri Mar 19 2021 clin@suse.com
- Update
  patches.suse/s390-lock-down-kernel-in-secure-boot-mode.patch
  (bsc#1183746 jsc#SLE-7741).
- commit e9dda35
* Fri Mar 19 2021 pjakobsson@suse.de
- Add Alt-commit for duplicate
  Refresh
  patches.suse/1910-drm-amd-pm-setup-APU-dpm-clock-table-in-SMU-HW-initi.patch.
- commit 58a6d9c
* Fri Mar 19 2021 ptesarik@suse.cz
- s390/qeth: fix notification for pending buffers during teardown
  (git-fixes).
- s390/qeth: schedule TX NAPI on QAOB completion (git-fixes).
- s390/qeth: improve completion of pending TX buffers (git-fixes).
- s390/qeth: fix memory leak after failed TX Buffer allocation
  (git-fixes).
- commit ffdf1ba
* Fri Mar 19 2021 ptesarik@suse.cz
- s390/dasd: fix hanging IO request during DASD driver unbind
  (git-fixes).
- commit 77e1a65
* Fri Mar 19 2021 ptesarik@suse.cz
- s390/cio: return -EFAULT if copy_to_user() fails (git-fixes).
- s390/crypto: return -EFAULT if copy_to_user() fails (git-fixes).
- s390/cio: return -EFAULT if copy_to_user() fails (git-fixes).
- commit 86038a4
* Fri Mar 19 2021 yousaf.kaukab@suse.com
- netsec: restore phy power state after controller reset
  (bsc#1183756).
- commit 45d0550
* Fri Mar 19 2021 varad.gautam@suse.com
- squashfs: fix xattr id and id lookup sanity checks (bsc#1183750).
- commit 8006352
* Fri Mar 19 2021 varad.gautam@suse.com
- squashfs: fix inode lookup sanity checks (bsc#1183750).
- commit cd40a2e
* Fri Mar 19 2021 otto.hollmann@suse.com
- PCI/LINK: Remove bandwidth notification (bsc#1183712).
- commit 56c94c5
* Fri Mar 19 2021 yousaf.kaukab@suse.com
- netsec: restore phy power state after controller reset
  (bsc#1183757).
- commit 05da5bc
* Fri Mar 19 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Add missing BOOTUP_DEFAULT to profile_name[]'
- commit 82b8ebe
* Fri Mar 19 2021 tzimmermann@suse.de
- drm/msm: Fix races managing the OOB state for timestamp vs (bsc#1152489)
  Backporting notes:
  * context changes
- commit 58990b2
* Fri Mar 19 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/msm: Fix race of GPU init vs timestamp power management.'
- commit 5232b67
* Fri Mar 19 2021 tzimmermann@suse.de
- drm/vc4: hdmi: Restore cec physical address on reconnect (bsc#1152472)
  Backporting notes:
  * context changes
  * change vc4_hdmi to vc4->hdmi
  * removed references to encoder->hdmi_monitor
- commit 7cd936b
* Fri Mar 19 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Prevent shift wrapping in amdgpu_read_mask()'
- commit 6048fb7
* Fri Mar 19 2021 tzimmermann@suse.de
- drm/mediatek: Fix aal size config (bsc#1152489)
  Backporting notes:
  * replaced mtk_ddp_write() with writel()
- commit 5d50b21
* Fri Mar 19 2021 tzimmermann@suse.de
- drm/nouveau: bail out of nouveau_channel_new if channel init fails (bsc#1152489)
  Backporting notes:
  * replaces patches.suse/drm-bail-out-of-nouveau_channel_new-if-channel-init-.patch
- commit b88077f
* Fri Mar 19 2021 tzimmermann@suse.de
- drm/sun4i: tcon: fix inverted DCLK polarity (bsc#1152489)
  Backporting notes:
  * context changes
- commit 0c124bb
* Thu Mar 18 2021 pjakobsson@suse.de
- drm/amdgpu/swsmu: add interrupt work handler for smu11 parts
  (git-fixes).
- commit f97424e
* Thu Mar 18 2021 dwagner@suse.de
- nvmet-rdma: Fix list_del corruption on queue establishment
  failure (bsc#1183501).
- commit 8d20dc6
* Thu Mar 18 2021 pjakobsson@suse.de
- drm/amdgpu/swsmu: add interrupt work function (git-fixes).
- commit c8bf617
* Thu Mar 18 2021 pjakobsson@suse.de
- Add Alt-commit for cherry pick
  Refresh
  patches.suse/1910-drm-amd-pm-setup-APU-dpm-clock-table-in-SMU-HW-initi.patch.
- commit 680f414
* Thu Mar 18 2021 msuchanek@suse.de
- powerpc/book3s64/radix: Remove WARN_ON in destroy_context()
  (bsc#1183692 ltc#191963).
- commit 418290b
* Thu Mar 18 2021 dwagner@suse.de
- nvme: allocate the keep alive request using BLK_MQ_REQ_NOWAIT
  (bsc#1182077).
- nvme: merge nvme_keep_alive into nvme_keep_alive_work
  (bsc#1182077).
- nvme-fabrics: only reserve a single tag (bsc#1182077).
- commit c67a454
* Thu Mar 18 2021 tiwai@suse.de
- Update patch reference of x25 fix (CVE-2020-35519 bsc#1183696)
- commit 6cd53a3
* Thu Mar 18 2021 msuchanek@suse.de
- powerpc/pseries/mobility: handle premature return from H_JOIN
  (bsc#1183662 ltc#191922).
- powerpc/pseries/mobility: use struct for shared state
  (bsc#1183662 ltc#191922).
- commit 36f1612
* Thu Mar 18 2021 tiwai@suse.de
- usbip: fix vudc to check for stream socket (git-fixes).
- Refresh
  patches.suse/usbip-fix-vudc-usbip_sockfd_store-races-leading-to-g.patch.
- commit ecca945
* Thu Mar 18 2021 tiwai@suse.de
- xhci: Fix repeated xhci wake after suspend due to uncleared
  internal wake state (git-fixes).
- xhci: Improve detection of device initiated wake signal
  (git-fixes).
- commit 594832e
* Thu Mar 18 2021 tiwai@suse.de
- usbip: fix vhci_hcd to check for stream socket (git-fixes).
- Refresh
  patches.suse/usbip-fix-vhci_hcd-attach_store-races-leading-to-gpf.patch.
- commit a57cde3
* Thu Mar 18 2021 tiwai@suse.de
- usbip: fix stub_dev to check for stream socket (git-fixes).
- Refresh
  patches.suse/usbip-fix-stub_dev-usbip_sockfd_store-races-leading-.patch.
- commit 2ae7114
* Thu Mar 18 2021 tiwai@suse.de
- staging: rtl8712: Fix possible buffer overflow in
  r8712_sitesurvey_cmd (git-fixes).
- usb: xhci: Fix ASMedia ASM1042A and ASM3242 DMA addressing
  (git-fixes).
- USB: serial: ch341: add new Product ID (git-fixes).
- USB: serial: cp210x: add some more GE USB IDs (git-fixes).
- USB: serial: cp210x: add ID for Acuity Brands nLight Air Adapter
  (git-fixes).
- USB: usblp: fix a hang in poll() if disconnected (git-fixes).
- spi: stm32: make spurious and overrun interrupts visible
  (git-fixes).
- commit bc51b9d
* Thu Mar 18 2021 tiwai@suse.de
- staging: rtl8192e: Fix possible buffer overflow in
  _rtl92e_wx_set_scan (git-fixes).
- media: v4l: vsp1: Fix uif null pointer access (git-fixes).
- media: v4l: vsp1: Fix bru null pointer access (git-fixes).
- PCI: xgene-msi: Fix race in installing chained irq handler
  (git-fixes).
- PCI: mediatek: Add missing of_node_put() to fix reference leak
  (git-fixes).
- PCI: Fix pci_register_io_range() memory leak (git-fixes).
- Input: applespi - don't wait for responses to commands
  indefinitely (git-fixes).
- mmc: mxs-mmc: Fix a resource leak in an error handling path in
  'mxs_mmc_probe()' (git-fixes).
- Platform: OLPC: Fix probe error handling (git-fixes).
- commit 3f405a7
* Thu Mar 18 2021 tiwai@suse.de
- Goodix Fingerprint device is not a modem (git-fixes).
- drm/compat: Clear bounce structures (git-fixes).
- ethernet: alx: fix order of calls on resume (git-fixes).
- ath9k: fix transmitting to stations in dynamic SMPS mode
  (git-fixes).
- i2c: rcar: optimize cacheline to minimize HW race condition
  (git-fixes).
- i2c: rcar: faster irq code to minimize HW race condition
  (git-fixes).
- commit 31fcf0f
* Thu Mar 18 2021 tiwai@suse.de
- blacklist.conf: Add capbilities entry that was reverted
- commit dc865b3
* Wed Mar 17 2021 pjakobsson@suse.de
- Add Alt-commit for cherry pick
  Refresh
  patches.suse/drm-amdgpu-Fix-invalid-number-of-character-in-amdgpu.patch.
- commit 82ef447
* Wed Mar 17 2021 tiwai@suse.de
- Update patch reference of r8188eu fix (CVE-2021-28660 bsc#1183593)
- commit fc23dca
* Wed Mar 17 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/ibmvnic-Fix-possibly-uninitialized-old_num_tx_queues.patch.
- Refresh
  patches.suse/ibmvnic-always-store-valid-MAC-address.patch.
- commit b49d041
* Wed Mar 17 2021 aabdallah@suse.de
- fnic: use scsi_host_busy_iter() to traverse commands
  (bsc#1179851).
- scsi: core: add scsi_host_busy_iter() (bsc#1179851).
- commit 583e298
* Wed Mar 17 2021 jack@suse.cz
- Update tags
  patches.suse/ext4-check-journal-inode-extents-more-carefully.patch
  (bsc#1173485 bsc#1183509 CVE-2021-3428).
- commit 41a8fa6
* Wed Mar 17 2021 oneukum@suse.com
- padata: upgrade smp_mb__after_atomic to smp_mb in
  padata_do_serial (bsc#1178648).
- commit f3ee3cb
* Wed Mar 17 2021 jroedel@suse.de
- iommu/qcom: add missing put_device() call in qcom_iommu_of_xlate() (bsc#1183637).
- commit de5577f
* Wed Mar 17 2021 tiwai@suse.de
- drm/lima: fix reference leak in lima_pm_busy (git-fixes).
- drm/tegra: Fix reference leak when pm_runtime_get_sync() fails
  (git-fixes).
- drm: rcar-du: Fix PM reference leak in rcar_cmm_enable()
  (git-fixes).
- commit 2a493b3
* Wed Mar 17 2021 tiwai@suse.de
- amd/amdgpu: Disable VCN DPG mode for Picasso (git-fixes).
- commit f34c818
* Wed Mar 17 2021 tiwai@suse.de
- HSI: Fix PM usage counter unbalance in ssi_hw_init (git-fixes).
- hwmon: (ina3221) Fix PM usage counter unbalance in
  ina3221_write_enable (git-fixes).
- gpio: zynq: fix reference leak in zynq_gpio functions
  (git-fixes).
- net: fec: Fix reference count leak in fec series ops
  (git-fixes).
- commit e27c26d
* Wed Mar 17 2021 tiwai@suse.de
- Update patch reference for fastrpc fix (CVE-2021-28375 bsc#1183596)
- commit 00ee058
* Tue Mar 16 2021 bp@suse.de
- x86/fsgsbase/64: Fix NULL deref in 86_fsgsbase_read_task
  (bsc#1152489).
- commit f996a8c
* Tue Mar 16 2021 bp@suse.de
- blacklist.conf: e504e74cc3a2 x86/unwind/orc: Disable KASAN checking in the ORC unwinder, part 2
- commit 12930ec
* Tue Mar 16 2021 tiwai@suse.de
- ALSA: usb-audio: fix use after free in usb_audio_disconnect
  (bsc#1182552 bsc#1183598).
- ALSA: usb-audio: fix NULL ptr dereference in usb_audio_probe
  (bsc#1182552 bsc#1183598).
- commit 8173e6a
* Tue Mar 16 2021 tiwai@suse.de
- Update bug reference for USB-audio fixes (bsc#1182552 bsc#1183598)
- commit cd602fc
* Tue Mar 16 2021 tiwai@suse.de
- Move upstreamed sound fixes into sorted section
- commit 4b54f4c
* Tue Mar 16 2021 msuchanek@suse.de
- Refresh sorted section.
- commit c4b4430
* Tue Mar 16 2021 msuchanek@suse.de
- rpadlpar: fix potential drc_name corruption in store functions
  (bsc#1183416 ltc#191079).
- commit cfa810c
* Tue Mar 16 2021 denis.kirjanov@suse.com
- net: stmmac: Use rtnl_lock/unlock on
  netif_set_real_num_rx_queues() call (git-fixes).
- commit aa3dcbf
* Tue Mar 16 2021 tzimmermann@suse.de
- drm/panfrost: Remove unused variables in panfrost_job_close() (bsc#1152472)
- commit 1350ad6
* Tue Mar 16 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/panfrost: Move the GPU reset bits outside the timeout handler'
- commit 5140c1f
* Tue Mar 16 2021 dbueso@suse.de
- Delete patches.suse/powerpc-Implement-smp_cond_load_relaxed.patch
  This has been shown to hurt performance at various levels when
  using qspinlocks (bsc#1182161).
- commit 6cec69e
* Mon Mar 15 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/ibmvnic-Fix-possibly-uninitialized-old_num_tx_queues.patch.
- Refresh
  patches.suse/ibmvnic-always-store-valid-MAC-address.patch.
- commit b83f198
* Mon Mar 15 2021 rgoldwyn@suse.com
- binfmt_misc: fix possible deadlock in bm_register_write
  (git-fixes).
- configfs: fix a use-after-free in __configfs_open_file
  (git-fixes).
- mount: fix mounting of detached mounts onto targets that reside
  on shared mounts  (git-fixes).
- mm: hugetlbfs: fix cannot migrate the fallocated HugeTLB page
  (git-fixes).
- epoll: check for events when removing a timed out thread from
  the wait queue  (git-fixes).
- proc: fix lookup in /proc/net subdirectories after setns(2)
  (git-fixes).
- apparmor: check/put label on apparmor_sk_clone_security()
  (git-fixes).
- apparmor: Fix aa_label refcnt leak in policy_update
  (git-fixes).
- exec: Move would_dump into flush_old_exec  (git-fixes).
- fuse: verify write return  (git-fixes).
- commit 55b045e
* Mon Mar 15 2021 ailiop@suse.com
- xfs: group quota should return EDQUOT when prj quota enabled
  (bsc#1180980).
- commit dbe17e3
* Mon Mar 15 2021 msuchanek@suse.de
- Delete patches.suse/sched-Reenable-interrupts-in-do_sched_yield.patch
  (bsc#1183530)
  This patch has been pointed out to break boot on qemu version 3 with
  azure config.
- commit d2d00bd
* Mon Mar 15 2021 jroedel@suse.de
- Refresh patches.suse/x86-sev-es-add-a-runtime-vc-exception-handler.
- Refresh patches.suse/x86-sev-es-handle-db-events.
  Remove lockdep_assert_irqs_disabled() from
  patches.suse/x86-sev-es-add-a-runtime-vc-exception-handler.
  It can't possibly work correctly on a 5.3 kernel because
  there is no NMI-safe hardirq state tracking yet.
- commit 1234b14
* Mon Mar 15 2021 jroedel@suse.de
- blacklist.conf: Add 62441a1fb532 x86/sev-es: Correctly track IRQ states in runtime #VC handler
- commit 1b48e04
* Mon Mar 15 2021 jroedel@suse.de
- x86/sev-es: Use __copy_from_user_inatomic() (bsc#1183553).
- x86/sev-es: Check regs->sp is trusted before adjusting #VC
  IST stack (bsc#1183551).
- x86/sev-es: Introduce ip_within_syscall_gap() helper
  (bsc#1183552).
- commit 8bcc6e7
* Mon Mar 15 2021 aaptel@suse.com
- smb3: Fix out-of-bounds bug in SMB2_negotiate() (bsc#1183540).
- commit 860b1de
* Mon Mar 15 2021 aaptel@suse.com
- cifs: check pointer before freeing (bsc#1183534).
- commit 03b0110
* Mon Mar 15 2021 dwagner@suse.de
- nvme-hwmon: Return error code when registration fails
  (bsc#1177326).
- commit 73e4ae9
* Mon Mar 15 2021 dwagner@suse.de
- nvme-fabrics: fix kato initialization (bsc#1182591).
- commit 4bcdc01
* Mon Mar 15 2021 dwagner@suse.de
- Remove patches.suse/nvme-hwmon-Return-error-code-when-registration-fails.patch
  hwmon_init() has no return value, hence we don't need this patch. The
  patch is only relevant for SLE15-SP3.
- commit b165e35
* Mon Mar 15 2021 denis.kirjanov@suse.com
- bnxt_en: Re-write PCI BARs after PCI fatal error (git-fixes). - Refresh patches.suse/bnxt_en-Fix-AER-recovery.patch.
- commit 05952f2
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: hdlc_raw_eth: Clear the IFF_TX_SKB_SHARING flag after calling ether_setup (git-fixes).
- commit d9b9ce4
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: hdlc: In hdlc_rcv, check to make sure dev is an HDLC device (git-fixes).
- commit 85c34ec
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: fec: Fix phy_device lookup for phy_reset_after_clk_enable() (git-fixes).
- commit 6a3b52e
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: korina: fix kfree of rx/tx descriptor array (git-fixes).
- commit f8b10af
* Mon Mar 15 2021 jgross@suse.com
- xen/events: avoid handling the same event on two cpus at the
  same time (git-fixes).
- commit d3a2816
* Mon Mar 15 2021 jgross@suse.com
- xen/events: don't unmask an event channel when an eoi is pending
  (git-fixes).
- commit 29c2c45
* Mon Mar 15 2021 tiwai@suse.de
- blacklist.conf: Add an inapplicable etnry for rtw88
- commit 65391e2
* Mon Mar 15 2021 jgross@suse.com
- xen/events: reset affinity of 2-level event when tearing it down
  (git-fixes).
- commit 43f9b1d
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: fec: Fix PHY init after phy_reset_after_clk_enable() (git-fixes).
- commit 93f1c3c
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: enic: Cure the enic api locking trainwreck (git-fixes).
- commit ee3b02c
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: dsa: rtl8366rb: Support all 4096 VLANs (git-fixes).
- commit abc3215
* Mon Mar 15 2021 jgross@suse.com
- Update
  patches.suse/Xen-gnttab-handle-p2m-update-errors-on-a-per-slot-ba.patch
  (bsc#1183022 XSA-367 CVE-2021-28038): added CVE number
- Update
  patches.suse/xen-netback-respect-gnttab_map_refs-s-return-value.patch
  (bsc#1183022 XSA-367 CVE-2021-28038): added CVE number
- commit 49dfaa1
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/msm: Fix WARN_ON() splat in _free_object() (bsc#1152489)
  Backporting notes:
  * context changes
- commit f2973f5
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/panfrost: Don't corrupt the queue mutex on open/close (bsc#1152472)
  Backporting notes:
  * context changes
- commit ab54c88
* Mon Mar 15 2021 jgross@suse.com
- Update
  patches.suse/Xen-gnttab-handle-p2m-update-errors-on-a-per-slot-ba.patch
  (bsc#1183022 XSA-367 CVE-2021-28038): added CVE number
- Update
  patches.suse/xen-netback-respect-gnttab_map_refs-s-return-value.patch
  (bsc#1183022 XSA-367 CVE-2021-28038): added CVE number
- commit 91d5751
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: stmmac: use netif_tx_start|stop_all_queues() function (git-fixes).
- commit 2c830e3
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: stmmac: Fix incorrect location to set real_num_rx|tx_queues (git-fixes).
- commit 952bf43
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/msm/gem: Add obj->lock wrappers (bsc#1152489)
  Backporting notes:
  * taken for 9b73bde39cf2 ("drm/msm: Fix use-after-free in msm_gem with carveout")
  * context changes
- commit 37d3ff2
* Mon Mar 15 2021 tbogendoerfer@suse.de
- RDMA/cm: Fix IRQ restore in ib_send_cm_sidr_rep (jsc#SLE-15176).
- commit c9eeebe
* Mon Mar 15 2021 tbogendoerfer@suse.de
- net: bonding: fix error return code of bond_neigh_init()
  (bsc#1154353).
- bnxt_en: reliably allocate IRQ table on reset to avoid crash
  (jsc#SLE-8371 bsc#1153274).
- commit f06fb53
* Mon Mar 15 2021 tzimmermann@suse.de
- drm: rcar-du: Fix crash when using LVDS1 clock for CRTC (bsc#1152489)
  Backporting notes:
  * context changes
- commit 69d2605
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/amd/powerplay: fix spelling mistake "smu_state_memroy_block" -> (bsc#1152489)
  Backporting notes:
  * rename amd/pm to amd/powerplay
  * context changes
- commit 6a3acb4
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/amdkfd: Put ACPI table after using it (bsc#1152489)
  Backporting notes:
  * context changes
- commit c115d9f
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/msm: Fix use-after-free in msm_gem with carveout (bsc#1152489)
  Backporting notes:
  * context changes
- commit 485d7ba
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/panfrost: Fix job timeout handling (bsc#1152472)
  Backporting notes:
  * context changes
- commit ef50c07
* Mon Mar 15 2021 tzimmermann@suse.de
- video: fbdev: acornfb: remove free_unused_pages() (bsc#1152489)
- commit 979bc2a
* Mon Mar 15 2021 tiwai@suse.de
- binfmt_misc: fix possible deadlock in bm_register_write
  (git-fixes).
- misc/pvpanic: Export module FDT device table (git-fixes).
- misc: fastrpc: restrict user apps from sending kernel RPC
  messages (git-fixes).
- staging: rtl8188eu: prevent ->ssid overflow in rtw_wx_set_scan()
  (git-fixes).
- staging: rtl8188eu: fix potential memory corruption in
  rtw_check_beacon_data() (git-fixes).
- staging: rtl8192u: fix ->ssid overflow in r8192_wx_set_scan()
  (git-fixes).
- staging: comedi: pcl818: Fix endian problem for AI command data
  (git-fixes).
- staging: comedi: pcl711: Fix endian problem for AI command data
  (git-fixes).
- staging: comedi: me4000: Fix endian problem for AI command data
  (git-fixes).
- staging: comedi: dmm32at: Fix endian problem for AI command data
  (git-fixes).
- staging: comedi: das800: Fix endian problem for AI command data
  (git-fixes).
- staging: comedi: das6402: Fix endian problem for AI command data
  (git-fixes).
- staging: comedi: adv_pci1710: Fix endian problem for AI command
  data (git-fixes).
- staging: comedi: addi_apci_1500: Fix endian problem for command
  sample (git-fixes).
- staging: comedi: addi_apci_1032: Fix endian problem for COS
  sample (git-fixes).
- staging: ks7010: prevent buffer overflow in ks_wlan_set_scan()
  (git-fixes).
- staging: rtl8712: unterminated string leads to read overflow
  (git-fixes).
- usb: xhci: do not perform Soft Retry for some xHCI hosts
  (git-fixes).
- USB: serial: io_edgeport: fix memory leak in edge_startup
  (git-fixes).
- usbip: fix vudc usbip_sockfd_store races leading to gpf
  (git-fixes).
- usbip: fix vhci_hcd attach_store() races leading to gpf
  (git-fixes).
- usbip: fix stub_dev usbip_sockfd_store() races leading to gpf
  (git-fixes).
- usb: dwc3: qcom: Add missing DWC3 OF node refcount decrement
  (git-fixes).
- usb: renesas_usbhs: Clear PIPECFG for re-enabling pipe with
  other EPNUM (git-fixes).
- usb: dwc3: qcom: Honor wakeup enabled/disabled state
  (git-fixes).
- usb: gadget: f_uac1: stop playback on function disable
  (git-fixes).
- usb: gadget: f_uac2: always increase endpoint max_packet_size
  by one audio slot (git-fixes).
- USB: gadget: u_ether: Fix a configfs return code (git-fixes).
- commit e8f5b15
* Sat Mar 13 2021 tiwai@suse.de
- ALSA: usb-audio: Fix Pioneer DJM devices URB_CONTROL request
  direction to set samplerate (git-fixes).
- ALSA: usb-audio: add mixer quirks for Pioneer DJM-900NXS2
  (git-fixes).
- ALSA: usb-audio: Add DJM750 to Pioneer mixer quirk (git-fixes).
- ALSA: usb-audio: Add DJM-450 to the quirks table (git-fixes).
- ALSA: usb-audio: Add DJM450 to Pioneer format quirk (git-fixes).
- ALSA: usb-audio: Add support for Pioneer DJM-750 (git-fixes).
- ALSA: usb-audio: Convert the last strlcpy() usage (git-fixes).
- ALSA: usb-audio: Convert remaining strlcpy() to strscpy()
  (git-fixes).
- ALSA: Convert strlcpy to strscpy when return value is unused
  (git-fixes).
- commit 8cf6568
* Sat Mar 13 2021 tiwai@suse.de
- ALSA: usb-audio: Fix "RANGE setting not yet supported" errors
  (git-fixes).
- ALSA: usb-audio: Skip the clock selector inquiry for single
  connections (git-fixes).
- ALSA: usb: Use DIV_ROUND_UP() instead of open-coding it
  (git-fixes).
- commit 761b71c
* Sat Mar 13 2021 tiwai@suse.de
- Move upstreamed HD-audio fixes into sorted section
- commit 61816e8
* Sat Mar 13 2021 tiwai@suse.de
- ALSA: hda/ca0132: Add Sound BlasterX AE-5 Plus support
  (git-fixes).
- ALSA: hda/conexant: Add quirk for mute LED control on HP ZBook
  G5 (git-fixes).
- ALSA: hda: ignore invalid NHLT table (git-fixes).
- commit 490714c
* Sat Mar 13 2021 tiwai@suse.de
- block: rsxx: fix error return code of rsxx_pci_probe()
  (git-fixes).
- software node: Fix node registration (git-fixes).
- mmc: cqhci: Fix random crash when remove mmc module/card
  (git-fixes).
- mmc: core: Fix partition switch time for eMMC (git-fixes).
- commit c895b3d
* Sat Mar 13 2021 tiwai@suse.de
- ALSA: hda/hdmi: Cancel pending works before suspend (git-fixes).
- ALSA: hda: Avoid spurious unsol event handling during S3/S4
  (git-fixes).
- ALSA: hda: Drop the BATCH workaround for AMD controllers
  (git-fixes).
- commit dcc7c7c
* Sat Mar 13 2021 tiwai@suse.de
- Move upstreamed sound fixes into sorted section
- commit 8879ec1
* Fri Mar 12 2021 dfaggioli@suse.com
- kABI: repair after "nVMX: Properly handle userspace interrupt window request"
  Restore the signature of member function of kvm_x86_ops, which is kABI.
  The implementation does not use the second argument any longer, so mark
  it as __unused.
- commit ac3267f
* Fri Mar 12 2021 rgoldwyn@suse.com
- jfs: Fix array index bounds check in dbAdjTree  (bsc#1179454 CVE-2020-27815).
- commit 8c97baa
* Fri Mar 12 2021 tiwai@suse.de
- Refresh media fixes to the upstreamed version (bsc#1181104)
  Refreshed:
  patches.suse/media-dvb-usb-Fix-memory-leak-at-error-in-dvb_usb_de.patch
  patches.suse/media-dvb-usb-Fix-use-after-free-access.patch
- commit 0dafc68
* Fri Mar 12 2021 tiwai@suse.de
- Move upstreamed amdgpu patches into sorted section
- commit 7d79443
* Fri Mar 12 2021 dfaggioli@suse.com
- KVM x86: Extend AMD specific guest behavior to Hygon virtual CPUs
  (bsc#1183447).
- commit 07c11e6
* Fri Mar 12 2021 tiwai@suse.de
- ASoC: Intel: sof_sdw: reorganize quirks by generation
  (git-fixes).
- Refresh
  patches.suse/ASoC-Intel-sof-sdw-indent-and-add-quirks-consistentl.patch.
- commit 50ee7a3
* Fri Mar 12 2021 tiwai@suse.de
- drm/amd/display: Fix nested FPU context in
  dcn21_validate_bandwidth() (git-fixes).
- drm/shmem-helper: Don't remove the offset in vm_area_struct
  pgoff (git-fixes).
- drm/shmem-helper: Check for purged buffers in fault handler
  (git-fixes).
- ASoC: Intel: sof_sdw: add quirk for HP Spectre x360 convertible
  (git-fixes).
- Bluetooth: btqca: Add valid le states quirk (git-fixes).
- commit 30958f3
* Fri Mar 12 2021 dfaggioli@suse.com
- KVM: x86: Add helpers to perform CPUID-based guest vendor check
  (bsc#1183445).
  Also refreshes:
  patches.suse/kvm-x86-fix-cpuid-range-checks-for-hypervisor-and-centaur-classes.
- commit e678df6
* Fri Mar 12 2021 tiwai@suse.de
- mwifiex: pcie: skip cancel_work_sync() on reset failure path
  (git-fixes).
- commit c95acf7
* Fri Mar 12 2021 tiwai@suse.de
- drm: meson_drv add shutdown function (git-fixes).
- qxl: Fix uninitialised struct field head.surface_id (git-fixes).
- media: usbtv: Fix deadlock on suspend (git-fixes).
- media: rc: compile rc-cec.c into rc-core (git-fixes).
- drm/msm/a5xx: Remove overwriting A5XX_PC_DBG_ECO_CNTL register
  (git-fixes).
- misc: eeprom_93xx46: Add quirk to support Microchip 93LC46B
  eeprom (git-fixes).
- ACPICA: Fix race in generic_serial_bus (I2C) and GPIO op_region
  parameter handling (git-fixes).
- HID: i2c-hid: Add I2C_HID_QUIRK_NO_IRQ_AFTER_RESET for ITE8568
  EC on Voyo Winpad A15 (git-fixes).
- mmc: sdhci-of-dwcmshc: set SDHCI_QUIRK2_PRESET_VALUE_BROKEN
  (git-fixes).
- HID: mf: add support for 0079:1846 Mayflash/Dragonrise USB
  Gamecube Adapter (git-fixes).
- PCI: Add function 1 DMA alias quirk for Marvell 9215 SATA
  controller (git-fixes).
- ACPI: video: Add DMI quirk for GIGABYTE GB-BXBT-2807
  (git-fixes).
- platform/x86: acer-wmi: Add ACER_CAP_KBD_DOCK quirk for the
  Aspire Switch 10E SW3-016 (git-fixes).
- platform/x86: acer-wmi: Add support for SW_TABLET_MODE on
  Switch devices (git-fixes).
- platform/x86: acer-wmi: Add ACER_CAP_SET_FUNCTION_MODE
  capability flag (git-fixes).
- platform/x86: acer-wmi: Add new force_caps module parameter
  (git-fixes).
- platform/x86: acer-wmi: Cleanup accelerometer device handling
  (git-fixes).
- platform/x86: acer-wmi: Cleanup ACER_CAP_FOO defines
  (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for ARCHOS Cesium 140
  (git-fixes).
- media: cx23885: add more quirks for reset DMA on some AMD IOMMU
  (git-fixes).
- commit f5bb9e4
* Fri Mar 12 2021 msuchanek@suse.de
- gcc-plugins: simplify GCC plugin-dev capability test
  (bsc#1181862).
- update config files
  - GCC_PLUGINS=y
  - GCC_PLUGIN_CYC_COMPLEXITY=n
  - GCC_PLUGIN_LATENT_ENTROPY=n
  - GCC_PLUGIN_RANDSTRUCT=n
  - GCC_PLUGIN_STRUCTLEAK_USER=n
  - GCC_PLUGIN_STRUCTLEAK_BYREF=n
  - GCC_PLUGIN_STRUCTLEAK_BYREF_ALL=n
  - GCC_PLUGIN_STACKLEAK=n
- commit f16b7b9
* Fri Mar 12 2021 msuchanek@suse.de
- ibmvfc: free channel_setup_buf during device tear down
  (bsc#1183440 ltc#191464).
- commit b86b88e
* Fri Mar 12 2021 nmoreychaisemartin@suse.com
- RDMA/srp: Fix support for unpopulated and unbalanced NUMA nodes (bsc#1169709)
- commit 0d2798a
* Fri Mar 12 2021 dfaggioli@suse.com
- KVM: x86: Return -E2BIG when KVM_GET_SUPPORTED_CPUID hits max entries
  (bsc#1183428).
- commit 3773bcc
* Fri Mar 12 2021 dfaggioli@suse.com
- KVM: nVMX: Properly handle userspace interrupt window request
  (bsc#1183427).
- commit 3cc1c3a
* Fri Mar 12 2021 dfaggioli@suse.com
- kvm: svm: Update svm_xsaves_supported (jsc#SLE-13573).
- commit 2e53071
* Fri Mar 12 2021 dfaggioli@suse.com
- KVM: x86: Expose XSAVEERPTR to the guest (jsc#SLE-13573).
- commit 4f9517b
* Fri Mar 12 2021 dfaggioli@suse.com
- kvm: x86: Enumerate support for CLZERO instruction
  (jsc#SLE-13573).
- commit e2e8bf7
* Thu Mar 11 2021 mcgrof@suse.com
- patches.suse/0007-block-add-docs-for-gendisk-request_queue-refcount-he.patch:
  (bsc#1171295, git fixes (block drivers)).
- patches.suse/0008-block-revert-back-to-synchronous-request_queue-remov.patch:
  (bsc#1171295, git fixes (block drivers)).
- patches.suse/0009-blktrace-fix-debugfs-use-after-free.patch:
  (bsc#1171295, git fixes (block drivers)).
  Update patches related to bsc#1171295 which were merged sooner due to
  other reasons.
- commit 2cd1e12
* Thu Mar 11 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/PCI-Add-a-REBAR-size-quirk-for-Sapphire-RX-5600-XT-P.patch
- commit e2c9c81
* Thu Mar 11 2021 mkubecek@suse.cz
- series.conf: cleanup
- move mainline patches into sorted section
  patches.suse/btrfs-unlock-extents-in-btrfs_zero_range-in-case-of-errors.patch
  patches.suse/btrfs-free-correct-amount-of-space-in-btrfs_delayed_inode_reserve_metadata.patch
  patches.suse/btrfs-don-t-flush-from-btrfs_delayed_inode_reserve_metadata.patch
  (no effect on expanded tree)
- commit 00edfef
* Thu Mar 11 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/ibmvnic-Fix-possibly-uninitialized-old_num_tx_queues.patch
  patches.suse/ibmvnic-always-store-valid-MAC-address.patch
  patches.suse/powerpc-pseries-Don-t-enforce-MSI-affinity-with-kdum.patch
- commit 31cb799
* Thu Mar 11 2021 rgoldwyn@suse.com
- Update patches.suse/apparmor-Fix-use-after-free-in-aa_audit_rule_init.patch
  (CVE-2019-18814 bsc#1156256).
- commit 7636680
* Thu Mar 11 2021 dwagner@suse.de
- scsi: lpfc: Update copyrights for 12.8.0.7 and 12.8.0.8 changes
  (bsc#1182574).
- scsi: lpfc: Update lpfc version to 12.8.0.8 (bsc#1182574).
- scsi: lpfc: Correct function header comments related to ndlp
  reference counting (bsc#1182574).
- scsi: lpfc: Reduce LOG_TRACE_EVENT logging for vports
  (bsc#1182574).
- scsi: lpfc: Change wording of invalid pci reset log message
  (bsc#1182574).
- scsi: lpfc: Fix crash caused by switch reboot (bsc#1182574).
- scsi: lpfc: Fix pt2pt state transition causing rmmod hang
  (bsc#1182574).
- scsi: lpfc: Fix nodeinfo debugfs output (bsc#1182574).
- scsi: lpfc: Fix ADISC handling that never frees nodes
  (bsc#1182574).
- scsi: lpfc: Fix PLOGI ACC to be transmit after REG_LOGIN
  (bsc#1182574).
- scsi: lpfc: Fix dropped FLOGI during pt2pt discovery recovery
  (bsc#1182574).
- scsi: lpfc: Fix status returned in lpfc_els_retry() error exit
  path (bsc#1182574).
- scsi: lpfc: Fix use after free in lpfc_els_free_iocb
  (bsc#1182574).
- scsi: lpfc: Fix null pointer dereference in lpfc_prep_els_iocb()
  (bsc#1182574).
- scsi: lpfc: Fix unnecessary null check in lpfc_release_scsi_buf
  (bsc#1182574).
- scsi: lpfc: Fix pt2pt connection does not recover after LOGO
  (bsc#1182574).
- scsi: lpfc: Fix lpfc_els_retry() possible null pointer
  dereference (bsc#1182574).
- scsi: lpfc: Fix FLOGI failure due to accessing a freed node
  (bsc#1182574).
- scsi: lpfc: Fix stale node accesses on stale RRQ request
  (bsc#1182574).
- scsi: lpfc: Fix reftag generation sizing errors (bsc#1182574).
- scsi: lpfc: Fix vport indices in lpfc_find_vport_by_vpid()
  (bsc#1182574).
- scsi: lpfc: Fix incorrect dbde assignment when building target
  abts wqe (bsc#1182574).
- commit 19f4943
* Thu Mar 11 2021 mcgrof@suse.com
- patches.suse/loop-be-paranoid-on-exit-and-prevent-new-additions-r.patch: (bsc#1171295).
- commit e598133
* Thu Mar 11 2021 mcgrof@suse.com
- patches.suse/blktrace-annotate-required-lock-on-do_blk_trace_setu.patch: (bsc#1171295).
- commit b590c4c
* Thu Mar 11 2021 mcgrof@suse.com
- patches.suse/block-clarify-context-for-refcount-increment-helpers.patch: (bsc#1171295).
- commit 252fb3e
* Thu Mar 11 2021 dfaggioli@suse.com
- KVM: x86: do not reset microcode version on INIT or RESET
  (bsc#1183412).
- commit 16ce873
* Thu Mar 11 2021 mcgrof@suse.com
- patches.suse/blktrace-Avoid-sparse-warnings-when-assigning-q-blk_.patch: (bsc#1171295).
- commit fbf1322
* Thu Mar 11 2021 mcgrof@suse.com
- patches.suse/blktrace-break-out-of-blktrace-setup-on-concurrent-c.patch: (bsc#1171295).
- commit 3bfed47
* Thu Mar 11 2021 denis.kirjanov@suse.com
- net: mvneta: fix double free of txq->buf (git-fixes).
- commit 1c0789f
* Thu Mar 11 2021 denis.kirjanov@suse.com
- net: mvneta: make tx buffer array agnostic (git-fixes).
- commit 49c79a4
* Thu Mar 11 2021 denis.kirjanov@suse.com
- net: usb: ax88179_178a: fix missing stop entry in driver_info (git-fixes).
- commit c51e8e9
* Thu Mar 11 2021 denis.kirjanov@suse.com
- mdio: fix mdio-thunder.c dependency & build error (git-fixes).
- commit 89b67ef
* Thu Mar 11 2021 denis.kirjanov@suse.com
- net: ethernet: cavium: octeon_mgmt: use phy_start and phy_stop (git-fixes).
- commit c74de85
* Thu Mar 11 2021 denis.kirjanov@suse.com
- ice: fix memory leak in ice_vsi_setup (git-fixes).
- commit 7c0d558
* Thu Mar 11 2021 denis.kirjanov@suse.com
- ice: fix memory leak if register_netdev_fails (git-fixes).
- commit 8c0fdc3
* Thu Mar 11 2021 dwagner@suse.de
- nvme: remove nvme_identify_ns_list (bsc#1180197).
- nvme: refactor nvme_validate_ns (bsc#1180197).
- nvme: move nvme_validate_ns (bsc#1180197).
- nvme: query namespace identifiers before adding the namespace
  (bsc#1180197).
- nvme: revalidate zone bitmaps in nvme_update_ns_info
  (bsc#1180197).
- nvme: remove nvme_update_formats (bsc#1180197).
- nvme: update the known admin effects (bsc#1180197).
- nvme: set the queue limits in nvme_update_ns_info (bsc#1180197).
- nvme: remove the 0 lba_shift check in nvme_update_ns_info
  (bsc#1180197).
- nvme: clean up the check for too large logic block sizes
  (bsc#1180197).
- nvme: freeze the queue over ->lba_shift updates (bsc#1180197).
- nvme: factor out a nvme_configure_metadata helper (bsc#1180197).
- nvme: call nvme_identify_ns as the first thing in
  nvme_alloc_ns_block (bsc#1180197).
- nvme: lift the check for an unallocated namespace into
  nvme_identify_ns (bsc#1180197).
- nvme: rename __nvme_revalidate_disk (bsc#1180197).
- nvme: rename _nvme_revalidate_disk (bsc#1180197).
- nvme: rename nvme_validate_ns to nvme_validate_or_alloc_ns
  (bsc#1180197).
- nvme: remove the disk argument to nvme_update_zone_info
  (bsc#1180197).
- nvme: fix initialization of the zone bitmaps (bsc#1180197).
- nvme: opencode revalidate_disk in nvme_validate_ns
  (bsc#1180197).
- commit bf92aeb
* Thu Mar 11 2021 jroedel@suse.de
- Refresh
  patches.suse/iommu-vt-d-fix-kernel-null-pointer-dereference-in-find_domain.
- commit fca53e1
* Thu Mar 11 2021 dfaggioli@suse.com
- KVM: x86: list MSR_IA32_UCODE_REV as an emulated MSR
  (bsc#1183369).
- commit 3238faa
* Thu Mar 11 2021 jroedel@suse.de
- PM: runtime: Add pm_runtime_resume_and_get to deal with usage
  counter (bsc#1183366).
- commit a3fe770
* Thu Mar 11 2021 glin@suse.com
- Update bpf-Fix-signed_-sub-add32-_overflows-type-handling.patch
  Add the following tags: bsc#1183077, CVE-2021-20268
- commit 01dcc33
* Thu Mar 11 2021 jeyu@suse.de
- Import kabi reference files from the RC1 submission (commit 52197697dc8)
- commit f143546
* Thu Mar 11 2021 glin@suse.com
- bpf,x64: Pad NOPs to make images converge more easily
  (bsc#1178163).
- commit 9aadbb2
* Thu Mar 11 2021 denis.kirjanov@suse.com
- iavf: Fix incorrect adapter get in iavf_resume (git-fixes).
- commit f71dec5
* Thu Mar 11 2021 denis.kirjanov@suse.com
- iavf: use generic power management (git-fixes).
- commit 23712b8
* Thu Mar 11 2021 denis.kirjanov@suse.com
- net: stmmac: removed enabling eee in EEE set callback (git-fixes).
- commit d783a1f
* Thu Mar 11 2021 clin@suse.com
- s390: lock down kernel in secure boot mode (jsc#SLE-7741).
- Update config files.
- commit 1499b7b
* Wed Mar 10 2021 lduncan@suse.com
- Update
  patches.suse/scsi-iscsi-ensure-sysfs-attributes-are-limited-to-page_size
  (CVE-2021-27365 bsc#1182715).
- Update
  patches.suse/scsi-iscsi-restrict-sessions-and-handles-to-admin-capabilities
  (CVE-2021-27363 CVE-2021-27364 bsc#1182716 bsc#1182717).
- Update
  patches.suse/scsi-iscsi-verify-lengths-on-passthrough-pdus
  (CVE-2021-27365 bsc#1182715).
- commit da2d102
* Wed Mar 10 2021 dwagner@suse.de
- nvme: return an error if nvme_set_queue_count() fails
  (bsc#1180197).
- commit a1a57eb
* Wed Mar 10 2021 jroedel@suse.de
- iommu/vt-d: Avoid panic if iommu init fails in tboot system (bsc#1183315).
- Refresh
  patches.suse/x86-tboot-don-t-disable-swiotlb-when-iommu-is-forced-on.
- commit 457c28f
* Wed Mar 10 2021 rgoldwyn@suse.com
- locks: reinstate locks_delete_block optimization
  (CVE-2019-19769 bsc#1159280).
- locks: fix a potential use-after-free problem when wakeup a
  waiter  (CVE-2019-19769 bsc#1159280).
- commit 4a9973d
* Wed Mar 10 2021 jroedel@suse.de
- iommu/amd: Fix sleeping in atomic in increase_address_space()
  (bsc#1183310).
- iommu/vt-d: Fix status code for Allocate/Free PASID command
  (bsc#1183320).
- iommu/amd: Fix sleeping in atomic in increase_address_space()
  (bsc#1183310).
- vfio/iommu_type1: Populate full dirty when detach non-pinned
  group (bsc#1183326).
- iommu: Switch gather->end to the inclusive end (bsc#1183314).
- memory: mtk-smi: Fix PM usage counter unbalance in mtk_smi ops
  (bsc#1183325).
- KVM: x86: Set so called 'reserved CR3 bits in LM mask' at vCPU
  reset (bsc#1183324).
- KVM: x86: Allow guests to see MSR_IA32_TSX_CTRL even if tsx=off
  (bsc#1183323).
- iommu: Check dev->iommu in dev_iommu_priv_get() before
  dereferencing it (bsc#1183311).
- iommu/vt-d: Do not use flush-queue when caching-mode is on
  (bsc#1183317).
- iommu/vt-d: Correctly check addr alignment in
  qi_flush_dev_iotlb_pasid() (bsc#1183316).
- iommu/vt-d: Fix unaligned addresses for
  intel_flush_svm_range_dev() (bsc#1183321).
- iommu/vt-d: Fix ineffective devTLB invalidation for subdevices
  (bsc#1183319).
- iommu/vt-d: Fix general protection fault in aux_detach_device()
  (bsc#1183318).
- iommu/vt-d: Move intel_iommu info from struct intel_svm to
  struct intel_svm_dev (bsc#1183322).
- iommu/intel: Fix memleak in intel_irq_remapping_alloc
  (bsc#1183312).
- iommu/qcom: add missing put_device() call in
  qcom_iommu_of_xlate() (bsc#1183313).
- commit f8bf292
* Wed Mar 10 2021 msuchanek@suse.de
- Refresh ibmvfc patches to upstream version.
- commit e1a83f9
* Wed Mar 10 2021 tiwai@suse.de
- ALSA: hda/hdmi: Cancel pending works before suspend
  (bsc#1182377).
- ALSA: hda: Avoid spurious unsol event handling during S3/S4
  (bsc#1182377).
- ALSA: hda: Flush pending unsolicited events before suspend
  (bsc#1182377).
- commit de11888
* Wed Mar 10 2021 msuchanek@suse.de
- powerpc/sstep: Fix VSX instruction emulation (jsc#SLE-13847
  bsc#1180581 ltc#190174).
- commit 2216ba0
* Wed Mar 10 2021 msuchanek@suse.de
- ibmvnic: remove excessive irqsave (bsc#1182485 ltc#191591).
- commit 3c13549
* Wed Mar 10 2021 jroedel@suse.de
- KVM: x86: Set so called 'reserved CR3 bits in LM mask' at vCPU reset (bsc#1183288).
- Refresh
  patches.kabi/kABI-Fix-kABI-after-AMD-SEV-PCID-fixes.patch.
- commit cb76db4
* Wed Mar 10 2021 jroedel@suse.de
- iommu/amd: Fix sleeping in atomic in increase_address_space()
  (bsc#1183277).
- KVM: x86: Allow guests to see MSR_IA32_TSX_CTRL even if tsx=off
  (bsc#1183287).
- iommu/vt-d: Do not use flush-queue when caching-mode is on
  (bsc#1183282).
- iommu/vt-d: Correctly check addr alignment in
  qi_flush_dev_iotlb_pasid() (bsc#1183281).
- iommu/vt-d: Fix unaligned addresses for
  intel_flush_svm_range_dev() (bsc#1183285).
- iommu/vt-d: Fix ineffective devTLB invalidation for subdevices
  (bsc#1183284).
- iommu/vt-d: Fix general protection fault in aux_detach_device()
  (bsc#1183283).
- iommu/vt-d: Move intel_iommu info from struct intel_svm to
  struct intel_svm_dev (bsc#1183286).
- iommu/intel: Fix memleak in intel_irq_remapping_alloc
  (bsc#1183278).
- iommu/vt-d: Avoid panic if iommu init fails in tboot system
  (bsc#1183280).
- iommu/vt-d: Add get_domain_info() helper (bsc#1183279).
- commit b6d08d2
* Wed Mar 10 2021 bp@suse.de
- KVM: SVM: Clear the CR4 register on reset (bsc#1183252).
- commit e6e6e8c
* Wed Mar 10 2021 tiwai@suse.de
- r8169: fix r8168fp_adjust_ocp_cmd function (git-fixes).
- gpiolib: acpi: Allow to find GpioInt() resource by name and
  index (git-fixes).
- gpiolib: acpi: Add ACPI_GPIO_QUIRK_ABSOLUTE_NUMBER quirk
  (git-fixes).
- drm/amdgpu:disable VCN for Navi12 SKU (git-fixes).
- ALSA: usb-audio: use Corsair Virtuoso mapping for Corsair
  Virtuoso SE (git-fixes).
- r8169: Add support for another RTL8168FP (git-fixes).
- r8169: improve DASH support (git-fixes).
- drm/amdgpu: enable DCN for navi10 headless SKU (git-fixes).
- drm/amdgpu: rename nv_is_headless_sku() (git-fixes).
- drm/amdgpu: disable DCN and VCN for Navi14 0x7340/C9 SKU
  (git-fixes).
- commit 16a0ee9
* Wed Mar 10 2021 tiwai@suse.de
- netdevsim: init u64 stats for 32bit hardware (git-fixes).
- net: usb: qmi_wwan: allow qmimux add/del with master up
  (git-fixes).
- can: skb: can_skb_set_owner(): fix ref counting if socket was
  closed before setting skb ownership (git-fixes).
- can: flexcan: invoke flexcan_chip_freeze() to enter freeze mode
  (git-fixes).
- can: flexcan: enable RX FIFO after FRZ/HALT valid (git-fixes).
- can: flexcan: assert FRZ bit in flexcan_chip_freeze()
  (git-fixes).
- mt76: dma: do not report truncated frames to mac80211
  (git-fixes).
- gpio: pca953x: Set IRQ type when handle Intel Galileo Gen 2
  (git-fixes).
- drm/amdgpu: fix parameter error of RREG32_PCIE() in
  amdgpu_regs_pcie (git-fixes).
- usbip: tools: fix build error for multiple definition
  (git-fixes).
- commit 15f1b1c
* Wed Mar 10 2021 tiwai@suse.de
- arm64: select CPUMASK_OFFSTACK if NUMA (bsc#1183033,
  bsc#1183030).
- Update config files: CONFIG_CPUMASK_OFFSTACK=y for arm64
- commit 1e2e7ba
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: comment on the list
  To explain what it actually is.
- commit e94bacf
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: define ignores more strictly
  * search for whole words, so make wildcards explicit
  * use ' for quoting
  * prepend CONFIG_ dynamically, so it need not be in the list
- commit f61e954
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: sort the ignores
  They are growing so to make them searchable by humans.
- commit 67c6b55
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: add -mrecord-mcount ignore
  Added by 3b15cdc15956 (tracing: move function tracer options to Kconfig)
  upstream.
- commit 018b013
* Wed Mar 10 2021 lduncan@suse.com
- scsi: iscsi: Verify lengths on passthrough PDUs (CVE-2021-27365
  bsc#1182715).
- scsi: iscsi: Ensure sysfs attributes are limited to PAGE_SIZE
  (CVE-2021-27365 bsc#1182715).
- scsi: iscsi: Restrict sessions and handles to admin capabilities
  (CVE-2021-27363 CVE-2021-27364 bsc#1182716 bsc#1182717).
- commit e5416af
* Tue Mar  9 2021 msuchanek@suse.de
- Refresh patches.suse/powerpc-pseries-Don-t-enforce-MSI-affinity-with-kdum.patch.
  Update patch metadata.
- commit 5b5a037
* Tue Mar  9 2021 oneukum@suse.com
- crypto: qat - replace CRYPTO_AES with CRYPTO_LIB_AES in Kconfig
  (git-fixes).
- commit 79f6b38
* Tue Mar  9 2021 msuchanek@suse.de
- Update config files.
- commit a7710ca
* Tue Mar  9 2021 msuchanek@suse.de
- arm64: make STACKPROTECTOR_PER_TASK configurable (bsc#1181862).
- commit e710608
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net: gemini: Fix another missing clk_disable_unprepare()
  in probe (git-fixes).
- commit 6c94cd0
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: cpsw: fix clean up of vlan mc entries for
  host port (git-fixes).
- commit 05decbb
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net: arc_emac: Fix memleak in arc_mdio_probe (git-fixes).
- commit 5898dda
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net: gemini: Fix missing free_netdev() in error path of
  gemini_ethernet_port_probe() (git-fixes).
- commit a31c30f
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net: qcom/emac: add missed clk_disable_unprepare in error path
  of emac_clks_phase1_init (git-fixes).
- commit 8bcb8c8
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net/mlx5: Delete extra dump stack that gives nothing
  (git-fixes).
- commit 8adc626
* Tue Mar  9 2021 denis.kirjanov@suse.com
- fsl/fman: fix eth hash table allocation (git-fixes).
- commit 888f0c2
* Tue Mar  9 2021 msuchanek@suse.de
- Refresh patches.suse/powerpc-vdso-Replace-vdso_base-by-vdso.patch.
  Fix warnings.
- commit e4e515f
* Tue Mar  9 2021 denis.kirjanov@suse.com
- fsl/fman: check dereferencing null pointer (git-fixes).
- commit 8b2d58f
* Tue Mar  9 2021 denis.kirjanov@suse.com
- fsl/fman: fix unreachable code (git-fixes).
- commit 44dfe0c
* Tue Mar  9 2021 denis.kirjanov@suse.com
- fsl/fman: fix dereference null return value (git-fixes).
- commit 54941fb
* Tue Mar  9 2021 denis.kirjanov@suse.com
- fsl/fman: use 32-bit unsigned integer (git-fixes).
- commit b5edb51
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net: spider_net: Fix the size used in a 'dma_free_coherent()'
  call (git-fixes).
- commit 62d1c07
* Tue Mar  9 2021 glin@suse.com
- bpf: Fix truncation handling for mod32 dst reg wrt zero
  (bsc#1177028).
- selftests/bpf: Convert test_xdp_redirect.sh to bash
  (bsc#1177028).
- commit c084826
* Tue Mar  9 2021 glin@suse.com
- bpf_lru_list: Read double-checked variable once without lock
  (bsc#1155518).
- bpf: Declare __bpf_free_used_maps() unconditionally
  (bsc#1155518).
- bpf: Avoid warning when re-casting __bpf_call_base into
  __bpf_call_base_args (bsc#1155518).
- commit 30d5020
* Tue Mar  9 2021 glin@suse.com
- bpf: Clear subreg_def for global function return values
  (bsc#1177028).
- bpf, devmap: Use GFP_KERNEL for xdp bulk queue allocation
  (bsc#1177028).
- libbpf: Ignore non function pointer member in struct_ops
  (bsc#1177028).
- bpf: Add bpf_patch_call_args prototype to include/linux/bpf.h
  (bsc#1177028).
- bpf: Fix 32 bit src register truncation on div/mod
  (bsc#1177028).
- bpf: Fix verifier jmp32 pruning decision logic (bsc#1177028).
- bpf: Fix verifier jsgt branch analysis on max bound
  (bsc#1177028).
- commit 4d1a1f2
* Tue Mar  9 2021 tiwai@suse.de
- ALSA: usb-audio: fix use after free in usb_audio_disconnect
  (bsc#1182552).
- ALSA: usb-audio: fix NULL ptr dereference in usb_audio_probe
  (bsc#1182552).
- commit e4781c6
* Mon Mar  8 2021 msuchanek@suse.de
- powerpc: Add kABI placeholder to struct pci_controller and
  mm_context_t (bsc#1183030).
- commit d01a093
* Mon Mar  8 2021 lduncan@suse.com
- scsi: iscsi: Verify lengths on passthrough PDUs (CVE-2021-27365
  bsc#182715).
- scsi: iscsi: Ensure sysfs attributes are limited to PAGE_SIZE
  (CVE-2021-27365 bsc#182715).
- scsi: iscsi: Restrict sessions and handles to admin capabilities
  (CVE-2021-27363 CVE-2021-27364 bsc#182716 bsc#182717).
- commit 71d447d
* Mon Mar  8 2021 tiwai@suse.de
- arch/arm64: Add a kABI placeholder for the future TLBI boradcast
  fixes (bsc#1183030).
- commit 7797213
* Mon Mar  8 2021 fweisbecker@suse.de
- blacklist.conf: Blacklist CONFIG_UCLAMP_TASK fixes
  dcd6dffb0a75 sched/core: Fix size of rq::uclamp initialization
  eaf5a92ebde5 sched/core: Fix reset-on-fork from RT with uclamp
  d81ae8aac85c sched/uclamp: Fix initialization of struct uclamp_rq
  46609ce22703 sched/uclamp: Protect uclamp fast path code with static key
- commit 04723ee
* Mon Mar  8 2021 jeyu@suse.de
- Rename duplicate patches to their SLE15-SP2 equivalents.
  This is to prepare for the next SLE15-SP2 -> SLE15-SP3 merge.
- commit 87e9aa1
* Mon Mar  8 2021 denis.kirjanov@suse.com
- net: ethernet: aquantia: Fix wrong return value (git-fixes).
- commit d7e8c64
* Mon Mar  8 2021 denis.kirjanov@suse.com
- net: dsa: rtl8366: Fix VLAN set-up (git-fixes).
- commit 332c76d
* Mon Mar  8 2021 dwagner@suse.de
- nvme-hwmon: Return error code when registration fails
  (bsc#1177326).
- commit 1f91b69
* Mon Mar  8 2021 vbabka@suse.cz
- Refresh
  patches.suse/0003-kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
  Add KABI padding to mm_struct, which is mentioned in the patch description but
  was actually missing.
- commit 17c4dee
* Mon Mar  8 2021 denis.kirjanov@suse.com
- net: dsa: rtl8366: Fix VLAN semantics (git-fixes).
- commit eaed13b
* Mon Mar  8 2021 msuchanek@suse.de
- kbuild: improve cc-option to clean up all temporary files
  (bsc#1178330).
- Refresh patches.suse/livepatch-dump-ipa-clones.patch
- kbuild: use -S instead of -E for precise cc-option test in
  Kconfig (bsc#1178330).
- commit 9b47d75
* Mon Mar  8 2021 wqu@suse.com
- blacklist.conf: blacklist btrfs subpage RW related fixes
  As btrfs in SLE won't support subpage RW until SLE15-SP4.
- commit 74db4da
* Mon Mar  8 2021 tzimmermann@suse.de
- drm/i915/gem: Support parsing of oversize batches (bsc#1152489)
  Backporting notes:
  * context changes
- commit dc05c54
* Mon Mar  8 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Keep rings pinned while the context is active'
  Backporting notes:
  * ac65bdfef14a ("drm/i915: Keep rings pinned while the context is active")
  is in the v5.3 base tree, but got blacklisted with the wrong duplicate-of
  rev. The patch at hand fixes this.
- commit 81ad7e0
* Mon Mar  8 2021 tiwai@suse.de
- ASoC: Intel: sof_sdw: detect DMIC number based on mach params
  (git-fixes).
- ASoC: Intel: sof-sdw: indent and add quirks consistently
  (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add new BYT_RT5640_NO_SPEAKERS
  quirk-flag (git-fixes).
- Bluetooth: Add new HCI_QUIRK_NO_SUSPEND_NOTIFIER quirk
  (git-fixes).
- Bluetooth: btusb: fix memory leak on suspend and resume
  (git-fixes).
- drm/virtio: use kvmalloc for large allocations (git-fixes).
- commit 2f41145
* Mon Mar  8 2021 tiwai@suse.de
- udlfb: Fix memory leak in dlfb_usb_probe (git-fixes).
- vt/consolemap: do font sum unsigned (git-fixes).
- wlcore: Fix command execute failure 19 for wl12xx (git-fixes).
- rsi: Move card interrupt handling to RX thread (git-fixes).
- commit 9236947
* Mon Mar  8 2021 tiwai@suse.de
- net: usb: qmi_wwan: support ZTE P685M modem (git-fixes).
- crypto: tcrypt - avoid signed overflow in byte count
  (git-fixes).
- drm/amd/display: Guard against NULL pointer deref when
  get_i2c_info fails (git-fixes).
- PCI: Add a REBAR size quirk for Sapphire RX 5600 XT Pulse
  (git-fixes).
- drm/amdgpu: Add check to prevent IH overflow (git-fixes).
- drm/hisilicon: Fix use-after-free (git-fixes).
- media: uvcvideo: Allow entities with no pads (git-fixes).
- media: v4l2-ctrls.c: fix shift-out-of-bounds in std_validate
  (git-fixes).
- media: mceusb: sanity check for prescaler value (git-fixes).
- staging: bcm2835-audio: Replace unsafe strcpy() with strscpy()
  (git-fixes).
- staging: most: sound: add sanity check for function argument
  (git-fixes).
- staging: fwserial: Fix error handling in fwserial_create
  (git-fixes).
- brcmfmac: Add DMI nvram filename quirk for Voyo winpad A15
  tablet (git-fixes).
- brcmfmac: Add DMI nvram filename quirk for Predia Basic tablet
  (git-fixes).
- ath10k: fix wmi mgmt tx queue full due to race condition
  (git-fixes).
- Bluetooth: Fix null pointer dereference in
  amp_read_loc_assoc_final_data (git-fixes).
- Bluetooth: hci_h5: Set HCI_QUIRK_SIMULTANEOUS_DISCOVERY for
  btrtl (git-fixes).
- Input: elantech - fix protocol errors for some trackpoints in
  SMBus mode (git-fixes).
- rsi: Fix TX EAPOL packet handling against iwlwifi AP
  (git-fixes).
- commit 2608a34
* Mon Mar  8 2021 tiwai@suse.de
- ASoC: Intel: bytcr_rt5640: Add quirk for the Acer One S1002
  tablet (git-fixes).
- ASoC: Intel: bytcr_rt5651: Add quirk for the Jumper EZpad 7
  tablet (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Voyo Winpad A15
  tablet (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Estar Beauty HD
  MID 7316R tablet (git-fixes).
- ASoC: Intel: Add DMI quirk table to soc_intel_is_byt_cr()
  (git-fixes).
- commit 4e131ac
* Mon Mar  8 2021 nborisov@suse.com
- Refresh patches.suse/btrfs-don-t-flush-from-btrfs_delayed_inode_reserve_metadata.patch.
- Refresh
  patches.suse/btrfs-free-correct-amount-of-space-in-btrfs_delayed_inode_reserve_metadata.patch.
- Refresh
  patches.suse/btrfs-unlock-extents-in-btrfs_zero_range-in-case-of-errors.patch.
- commit bafd254
* Mon Mar  8 2021 jslaby@suse.cz
- kbuild: dummy-tools, support MPROFILE_KERNEL checks for ppc
  (bsc#1181862).
- commit d053b67
* Sat Mar  6 2021 tiwai@suse.de
- ACPI: bus: Constify is_acpi_node() and friends (part 2)
  (git-fixes).
- commit 5937701
* Sat Mar  6 2021 tiwai@suse.de
- rsxx: Return -EFAULT if copy_to_user() fails (git-fixes).
- PM: runtime: Update device status before letting suppliers
  suspend (git-fixes).
- commit e05652b
* Sat Mar  6 2021 tiwai@suse.de
- drm/amd/display: Add a backlight module option (bsc#1180749).
- drm/amdgpu/display: handle aux backlight in
  backlight_get_brightness (bsc#1180749).
- drm/amdgpu/display: don't assert in set backlight function
  (bsc#1180749).
- drm/amdgpu/display: simplify backlight setting (bsc#1180749).
- commit 5a8f9fa
* Sat Mar  6 2021 msuchanek@suse.de
- kbuild: stop filtering out $(GCC_PLUGINS_CFLAGS) from cc-option
  base (bcs#1181862).
- kbuild: include scripts/Makefile.* only when relevant CONFIG
  is enabled (bcs#1181862).
- commit 5819136
* Fri Mar  5 2021 msuchanek@suse.de
- gcc-plugins: drop support for GCC <= 4.7 (bcs#1181862).
- refresh config files (drop PLUGIN_HOSTCC)
- kconfig: introduce m32-flag and m64-flag (bcs#1181862).
- gcc-plugins: make it possible to disable CONFIG_GCC_PLUGINS
  again (bcs#1181862).
- kbuild: change *FLAGS_<basetarget>.o to take the path relative
  to $(obj) (bcs#1181862).
- kbuild: Fail if gold linker is detected (bcs#1181862).
- commit 9094f62
* Fri Mar  5 2021 msuchanek@suse.de
- powerpc/vdso: Retrieve sigtramp offsets at buildtime (bsc#1183002).
- Refresh patches.suse/powerpc-64-signal-Fix-regression-in-__kernel_sigtram.patch.
- powerpc/vdso: Replace vdso_base by vdso (bsc#1183002).
- commit 0f7fda0
* Fri Mar  5 2021 dmueller@suse.com
- ARMv6/v7: Update config files. (bsc#1183009)
  enable CONFIG_ARM_MODULE_PLTS to fix module loading issues
  (cherry picked from commit b3d2cd1b65794d32c02319c8e2376f15360ff8ec)
- commit 5723968
* Fri Mar  5 2021 msuchanek@suse.de
- kbuild: simplify GCC_PLUGINS enablement in dummy-tools/gcc
  (bcs#1181862).
- commit 77ad0cc
* Fri Mar  5 2021 msuchanek@suse.de
- kbuild: add dummy toolchains to enable all cc-option etc. in
  Kconfig (bcs#1181862).
- Delete patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch.
- commit 928cf1d
* Fri Mar  5 2021 dwagner@suse.de
- wireguard: kconfig: use arm chacha even with no neon
  (git-fixes).
- wireguard: device: do not generate ICMP for non-IP packets
  (git-fixes).
- wireguard: selftests: test multiple parallel streams
  (git-fixes).
- crypto: Kconfig - CRYPTO_MANAGER_EXTRA_TESTS requires the
  manager (git-fixes).
- crypto: arm64/poly1305-neon - reorder PAC authentication with
  SP update (git-fixes).
- commit c931ac8
* Fri Mar  5 2021 mbenes@suse.cz
- objtool: Fix ".cold" section suffix check for newer versions
  of GCC (bsc#1169514).
- commit 4b4e63c
* Fri Mar  5 2021 msuchanek@suse.de
- ibmvnic: always store valid MAC address (bsc#1182011 ltc#191844).
- commit 486024a
* Fri Mar  5 2021 jslaby@suse.cz
- rpm/check-for-config-changes: declare sed args as an array
  So that we can reuse it in both seds.
  This also introduces IGNORED_CONFIGS_RE array which can be easily
  extended.
- commit a1976d2
* Fri Mar  5 2021 tiwai@suse.de
- ALSA: hda: intel-nhlt: verify config type (git-fixes).
- commit 4504e76
* Fri Mar  5 2021 tiwai@suse.de
- ALSA: hda/realtek: Apply dual codec quirks for MSI Godlike
  X570 board (git-fixes).
- ALSA: hda/realtek: Add quirk for Intel NUC 10 (git-fixes).
- ALSA: hda/realtek: Add quirk for Clevo NH55RZQ (git-fixes).
- ALSA: hda/realtek: Enable headset mic of Acer SWIFT with ALC256
  (git-fixes).
- commit acba99b
* Fri Mar  5 2021 tiwai@suse.de
- Move upstreamed USB-audio fixes into sorted section
- commit 28c79bd
* Fri Mar  5 2021 tiwai@suse.de
- ALSA: ctxfi: cthw20k2: fix mask on conf to allow 4 bits
  (git-fixes).
- certs: Fix blacklist flag type confusion (git-fixes).
- commit 83ee089
* Fri Mar  5 2021 jgross@suse.com
- xen-netback: respect gnttab_map_refs()'s return value
  (bsc#1183022 XSA-367).
- commit 5a927d9
* Fri Mar  5 2021 jgross@suse.com
- Xen/gnttab: handle p2m update errors on a per-slot basis
  (bsc#1183022 XSA-367).
- commit b394e32
* Fri Mar  5 2021 jgross@suse.com
- xen-netback: respect gnttab_map_refs()'s return value
  (bsc#1183022 XSA-367).
- commit 53b7528
* Fri Mar  5 2021 jgross@suse.com
- Xen/gnttab: handle p2m update errors on a per-slot basis
  (bsc#1183022 XSA-367).
- commit 846e338
* Thu Mar  4 2021 tiwai@suse.de
- drm/amd/display: Remove Assert from dcn10_get_dig_frontend
  (git-fixes).
- drm/amd/display: Add vupdate_no_lock interrupts for DCN2.1
  (git-fixes).
- drm/amdgpu: Set reference clock to 100Mhz on Renoir (v2)
  (git-fixes).
- drm/amdkfd: Fix recursive lock warnings (git-fixes).
- drm/amd/display: Add FPU wrappers to dcn21_validate_bandwidth()
  (git-fixes).
- drm/modes: Switch to 64bit maths to avoid integer overflow
  (git-fixes).
- commit dbc87d2
* Thu Mar  4 2021 tiwai@suse.de
- watchdog: mei_wdt: request stop on unregister (git-fixes).
- commit 1de5431
* Thu Mar  4 2021 tiwai@suse.de
- pwm: rockchip: rockchip_pwm_probe(): Remove superfluous
  clk_unprepare() (git-fixes).
- PCI: qcom: Use PHY_REFCLK_USE_PAD only for ipq8064 (git-fixes).
- PCI: Align checking of syscall user config accessors
  (git-fixes).
- random: fix the RNDRESEEDCRNG ioctl (git-fixes).
- VMCI: Use set_page_dirty_lock() when unregistering guest memory
  (git-fixes).
- staging: rtl8188eu: Add Edimax EW-7811UN V2 to device table
  (git-fixes).
- USB: serial: option: update interface mapping for ZTE P685M
  (git-fixes).
- USB: serial: ftdi_sio: fix FTX sub-integer prescaler
  (git-fixes).
- usb: dwc3: gadget: Fix dep->interval for fullspeed interrupt
  (git-fixes).
- usb: dwc3: gadget: Fix setting of DEPCFG.bInterval_m1
  (git-fixes).
- commit b47408f
* Thu Mar  4 2021 tiwai@suse.de
- PCI: Decline to resize resources if boot config must be
  preserved (git-fixes).
- drivers/misc/vmw_vmci: restrict too big queue size in
  qp_host_alloc_queue (git-fixes).
- misc: rtsx: init of rts522a add OCP power off when no card is
  present (git-fixes).
- Input: i8042 - add ASUS Zenbook Flip to noselftest list
  (git-fixes).
- Input: raydium_ts_i2c - do not send zero length (git-fixes).
- Input: xpad - add support for PowerA Enhanced Wired Controller
  for Xbox Series X|S (git-fixes).
- mmc: sdhci-esdhc-imx: fix kernel panic when remove module
  (git-fixes).
- fbdev: aty: SPARC64 requires FB_ATY_CT (git-fixes).
- media: mceusb: Fix potential out-of-bounds shift (git-fixes).
- staging: gdm724x: Fix DMA from stack (git-fixes).
- commit 837d6c3
* Thu Mar  4 2021 tiwai@suse.de
- drm/msm/mdp5: Fix wait-for-commit for cmd panels (git-fixes).
- drm/msm/dsi: Correct io_start for MSM8994 (20nm PHY)
  (git-fixes).
- crypto: arm64/sha - add missing module aliases (git-fixes).
- crypto: bcm - Rename struct device_private to bcm_device_private
  (git-fixes).
- crypto: aesni - prevent misaligned buffers on the stack
  (git-fixes).
- drm/i915: Reject 446-480MHz HDMI clock on GLK (git-fixes).
- drm/nouveau/kms: handle mDP connectors (git-fixes).
- drm/sched: Cancel and flush all outstanding jobs before finish
  (git-fixes).
- commit d2c4de8
* Thu Mar  4 2021 jslaby@suse.cz
- rpm/check-for-config-changes: ignore more configs
  Specifially, these:
  * CONFIG_CC_HAS_*
  * CONFIG_CC_HAVE_*
  * CONFIG_CC_CAN_*
  * CONFIG_HAVE_[A-Z]*_COMPILER
  * CONFIG_TOOLS_SUPPORT_*
  are compiler specific too. This will allow us to use super configs
  using kernel's dummy-tools.
- commit d12dcbd
* Thu Mar  4 2021 mbenes@suse.cz
- objtool: Fix retpoline detection in asm code (bsc#1169514).
- commit 15a53c5
* Thu Mar  4 2021 msuchanek@suse.de
- ibmvnic: substitute mb() with dma_wmb() for send_*crq* functions
  (bsc#1183023 ltc#191791).
- ibmvnic: simplify reset_long_term_buff function (bsc#1183023
  ltc#191791).
- ibmvnic: substitute mb() with dma_wmb() for send_*crq* functions
  (bsc#1183023 ltc#191791).
- ibmvnic: simplify reset_long_term_buff function (bsc#1183023
  ltc#191791).
- commit 68ed094
* Thu Mar  4 2021 tiwai@suse.de
- dmaengine: move .device_release missing log warning to debug
  level (bsc#1182992).
- dmaengine: ioat: Support in-use unbind (bsc#1182992).
- commit fb94c70
* Thu Mar  4 2021 tiwai@suse.de
- Add kABI placeholders for ASoC (bsc#1179531).
- Add kABI placeholders for HD-audio (bsc#1179531).
- commit 9e31dbc
* Thu Mar  4 2021 pmladek@suse.com
- printk: fix deadlock when kernel panic (bsc#1183018).
- commit 069ec3d
* Thu Mar  4 2021 pmladek@suse.com
- printk: fix deadlock when kernel panic (bsc#1183018).
- commit 5021e3a
* Thu Mar  4 2021 mbenes@suse.cz
- objtool: Fix error handling for STD/CLD warnings (bsc#1169514).
- commit fb7ed7c
* Thu Mar  4 2021 tiwai@suse.de
- ALSA: usb-audio: Apply the control quirk to Plantronics headsets
  (bsc#1182552).
- ALSA: usb-audio: Fix "cannot get freq eq" errors on Dell AE515
  sound bar (bsc#1182552).
- ALSA: usb-audio: Disable USB autosuspend properly in
  setup_disable_autosuspend() (bsc#1182552).
- commit a815647
* Thu Mar  4 2021 yousaf.kaukab@suse.com
- config: net: freescale: change xgmac-mdio to built-in
  References: bsc#1183015,bsc#1182595
- commit b29b589
* Wed Mar  3 2021 msuchanek@suse.de
- Refresh patches.suse/ibmvnic-Fix-possibly-uninitialized-old_num_tx_queues.patch.
  Update patch metadata
- commit d8a9644
* Wed Mar  3 2021 tiwai@suse.de
- ALSA: usb: Add Plantronics C320-M USB ctrl msg delay quirk
  (bsc#1182552).
- commit 0a8c8cf
* Wed Mar  3 2021 tiwai@suse.de
- exfat: add the dummy mount options to be backward compatible
  with staging/exfat (bsc#1182989).
- commit d7a202d
* Wed Mar  3 2021 tiwai@suse.de
- exfat: add missing MODULE_ALIAS_FS() (bsc#1182989).
- commit d9a7a48
* Wed Mar  3 2021 tbogendoerfer@suse.de
- ice: update the number of available RSS queues (jsc#SLE-7926).
- ice: Fix state bits on LLDP mode switch (jsc#SLE-7926).
- net/mlx5: Disable devlink reload for lag devices (jsc#SLE-8464).
- ice: renegotiate link after FW DCB on (jsc#SLE-8464).
- commit 51a1824
* Wed Mar  3 2021 yousaf.kaukab@suse.com
- net: freescale: change xgmac-mdio to built-in
  References: bsc#1182595
- commit b25e0d8
* Wed Mar  3 2021 tbogendoerfer@suse.de
- RDMA/rtrs-srv: Do not pass a valid pointer to PTR_ERR()
  (jsc#SLE-15176).
- commit b3bb6ea
* Wed Mar  3 2021 tbogendoerfer@suse.de
- ice: update the number of available RSS queues (jsc#SLE-7926).
- ice: Fix state bits on LLDP mode switch (jsc#SLE-7926).
- ice: Set trusted VF as default VSI when setting allmulti on
  (jsc#SLE-12878).
- RDMA/rtrs-srv-sysfs: fix missing put_device (jsc#SLE-15176).
- RDMA/rtrs-srv: fix memory leak by missing kobject free
  (jsc#SLE-15176).
- RDMA/rtrs: Only allow addition of path to an already established
  session (jsc#SLE-15176).
- RDMA/rtrs-srv: Fix stack-out-of-bounds (jsc#SLE-15176).
- RDMA/ucma: Fix use-after-free bug in ucma_create_uevent
  (bsc#1181147).
- RDMA/mlx5: Allow creating all QPs even when non RDMA profile
  is used (jsc#SLE-15175).
- RDMA/rtrs: Fix KASAN: stack-out-of-bounds bug (jsc#SLE-15176).
- RDMA/rtrs-srv: Init wr_cnt as 1 (jsc#SLE-15176).
- RDMA/rtrs-srv: Do not signal REG_MR (jsc#SLE-15176).
- RDMA/rtrs-clt: Use bitmask to check sess->flags (jsc#SLE-15176).
- RDMA/rtrs: Do not signal for heatbeat (jsc#SLE-15176).
- RDMA/rtrs-clt: Refactor the failure cases in alloc_clt
  (jsc#SLE-15176).
- RDMA/rtrs-srv: Fix missing wr_cqe (jsc#SLE-15176).
- RDMA/rtrs: Call kobject_put in the failure path (jsc#SLE-15176).
- RDMA/rtrs-srv: Jump to dereg_mr label if allocate iu fails
  (jsc#SLE-15176).
- RDMA/rtrs-clt: Set mininum limit when create QP (jsc#SLE-15176).
- RDMA/rtrs-srv: Use sysfs_remove_file_self for disconnect
  (jsc#SLE-15176).
- RDMA/rtrs-srv: Release lock before call into close_sess
  (jsc#SLE-15176).
- RDMA/rtrs: Extend ibtrs_cq_qp_create (jsc#SLE-15176).
- net/mlx5e: kTLS, Use refcounts to free kTLS RX priv context
  (jsc#SLE-15172).
- net/mlx5e: Fix CQ params of ICOSQ and async ICOSQ
  (jsc#SLE-15172).
- net/mlx5e: Replace synchronize_rcu with synchronize_net
  (jsc#SLE-15172).
- net/mlx5e: Change interrupt moderation channel params also
  when channels are closed (jsc#SLE-15172).
- net/mlx5e: Enable XDP for Connect-X IPsec capable devices
  (jsc#SLE-15172).
- net/mlx5e: Enable striding RQ for Connect-X IPsec capable
  devices (jsc#SLE-15172).
- bnxt_en: Fix devlink info's stored fw.psid version format
  (jsc#SLE-16649).
- ice: log message when trusted VF goes in/out of promisc mode
  (jsc#SLE-12878).
- RDMA/rtrs: Introduce rtrs_post_send (jsc#SLE-15176).
- RDMA/rtrs: Remove unnecessary argument dir of rtrs_iu_free
  (jsc#SLE-15176).
- commit 4eae933
* Wed Mar  3 2021 jslaby@suse.cz
- kbuild: dummy-tools, fix inverted tests for gcc (bcs#1181862).
- commit e90afb3
* Wed Mar  3 2021 tbogendoerfer@suse.de
- ice: report correct max number of TCs (jsc#SLE-7926).
- RDMA/hns: Disable RQ inline by default (jsc#SLE-8449).
- RDMA/hns: Fix type of sq_signal_bits (jsc#SLE-8449).
- net/mlx5: Disallow RoCE on lag device (jsc#SLE-8464).
- net/mlx5: Disallow RoCE on multi port slave device
  (jsc#SLE-8464).
- net/mlx5: Disable devlink reload for multi port slave device
  (jsc#SLE-8464).
- net/mlx5e: E-switch, Fix rate calculation for overflow
  (jsc#SLE-8464).
- commit 5c94309
* Wed Mar  3 2021 tiwai@suse.de
- ALSA: usb-audio: Drop bogus dB range in too low level
  (bsc#1182552).
- ALSA: usb-audio: Don't abort even if the clock rate differs
  (bsc#1182552).
- ALSA: usb-audio: Allow modifying parameters with succeeding
  hw_params calls (bsc#1182552).
- commit 037cfcf
* Tue Mar  2 2021 dfaggioli@suse.com
- KVM: x86: Add RIP to the kvm_entry, i.e. VM-Enter, tracepoint
  Needed as a dependency of 0b40723a827 ("kvm: tracing: Fix unmatched
  kvm_entry and kvm_exit events", bsc#1182770).
- commit bca7352
* Tue Mar  2 2021 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section
  patches.suse/ibmvnic-Fix-possibly-uninitialized-old_num_tx_queues.patch
- commit be18357
* Tue Mar  2 2021 mkubecek@suse.cz
- Update kabi files.
- update from March 2021 maintenance update submission (commit c35b1245712f)
- commit ebf0b27
* Tue Mar  2 2021 msuchanek@suse.de
- ibmvnic: Fix possibly uninitialized old_num_tx_queues variable
  warning (jsc#SLE-17268).
- commit 2b2d062
* Tue Mar  2 2021 mbenes@suse.cz
- blacklist.conf: c7ff651960a6 ("blktrace: fix blk_rq_issue documentation")
  Cosmetic.
- commit ee4b49c
* Tue Mar  2 2021 mbenes@suse.cz
- blacklist.conf: 179d16007236 ("block: remove superfluous param in blk_fill_rwbs()")
  Cleanup only.
- commit ed3c6d0
* Tue Mar  2 2021 yousaf.kaukab@suse.com
- coresight: etm4x: Modify core-commit to avoid HiSilicon ETM
  overflow (jsc#SLE-14776).
- commit f817d44
* Tue Mar  2 2021 yousaf.kaukab@suse.com
- coresight: etm4x: Skip accessing TRCPDCR in save/restore
  (git-fixes).
- commit 8b8fa95
* Tue Mar  2 2021 jgross@suse.com
- kernel/smp: add more data to CSD lock debugging (bsc#1180846).
- commit 08badc9
* Tue Mar  2 2021 jgross@suse.com
- kernel/smp: prepare more CSD lock debugging (bsc#1180846).
- commit d717867
* Tue Mar  2 2021 jgross@suse.com
- Update config files: activate CONFIG_CSD_LOCK_WAIT_DEBUG for x86 (bsc#1180846).
- commit f88a325
* Tue Mar  2 2021 jgross@suse.com
- kernel/smp: add boot parameter for controlling CSD lock
  debugging (bsc#1180846).
- commit fb4cf71
* Tue Mar  2 2021 jgross@suse.com
- kernel/smp: Provide CSD lock timeout diagnostics (bsc#1180846).
- update config files (CSD_LOCK_WAIT_DEBUG=n)
- commit 59bec34
* Tue Mar  2 2021 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/ibmvnic-fix-a-race-between-open-and-reset.patch
- commit 9ab8f38
* Tue Mar  2 2021 jgross@suse.com
- kABI: Fix kABI after modifying struct __call_single_data
  (bsc#1180846).
- commit 3c0b378
* Tue Mar  2 2021 mkubecek@suse.cz
- series.conf: cleanup
- move submitted patches to appropriate section:
  patches.suse/btrfs-free-correct-amount-of-space-in-btrfs_delayed_inode_reserve_metadata.patch
  patches.suse/btrfs-don-t-flush-from-btrfs_delayed_inode_reserve_metadata.patch
  patches.suse/btrfs-cleanup-try_flush_qgroup.patch
  patches.suse/btrfs-remove-btrfs_inode-from-btrfs_delayed_inode_reserve_metadata.patch
  patches.suse/btrfs-simplify-code-flow-in-btrfs_delayed_inode_reserve_metadata.patch
  patches.suse/btrfs-unlock-extents-in-btrfs_zero_range-in-case-of-errors.patch
  (no effect on expanded tree)
- commit d631784
* Tue Mar  2 2021 jgross@suse.com
- smp: Add source and destination CPUs to __call_single_data
  (bsc#1180846).
- commit 10244d3
* Mon Mar  1 2021 msuchanek@suse.de
- powerpc/numa: Fix build when CONFIG_NUMA=n (bsc#1132477
  ltc#175530).
- commit be6fb41
* Mon Mar  1 2021 msuchanek@suse.de
- pseries/hotplug-memory: hot-add: skip redundant LMB lookup (bsc#1132477 ltc#175530).
- Refresh patches.suse/powerpc-pseries-group-lmb-operation-and-memblock-s.patch.
- commit 8cb9bdd
* Mon Mar  1 2021 msuchanek@suse.de
- powerpc/pseries: Don't enforce MSI affinity with kdump
  (bsc#1181655 ltc#190855).
- commit cfc7153
* Mon Mar  1 2021 msuchanek@suse.de
- pseries/drmem: don't cache node id in drmem_lmb struct (bsc#1132477 ltc#175530).
- Refresh patches.suse/powerpc-pseries-group-lmb-operation-and-memblock-s.patch.
- Refresh patches.suse/powerpc-pseries-update-device-tree-before-ejecting-h.patch.
- commit fe4f641
* Mon Mar  1 2021 palcantara@suse.de
- cifs: fix nodfs mount option (bsc#1181710).
- commit 94844a1
* Mon Mar  1 2021 palcantara@suse.de
- cifs: introduce helper for finding referral server
  (bsc#1181710).
- commit f74681b
* Mon Mar  1 2021 palcantara@suse.de
- cifs: check all path components in resolved dfs target
  (bsc#1181710).
- commit 91cd435
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: gemini: Fix missing clk_disable_unprepare() in error path of gemini_ethernet_port_probe() (git-fixes).
- commit 401e086
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: nixge: fix potential memory leak in nixge_probe() (git-fixes).
- commit cdc643b
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: hns3: fix for VLAN config when reset failed (git-fixes).
- commit 4209fa0
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: hns3: add reset check for VF updating port based VLAN
  (git-fixes).
- commit 9609b2a
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: ethernet: ave: Fix error returns in ave_init (git-fixes).
- commit 166a8fe
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: ag71xx: add missed clk_disable_unprepare in error path
  of probe (git-fixes).
- commit cead210
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: smc91x: Fix possible memory leak in smc_drv_probe()
  (git-fixes).
- commit 342b694
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: macb: fix call to pm_runtime in the suspend/resume
  functions (git-fixes).
- commit e7fb27b
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: macb: mark device wake capable when "magic-packet"
  property present (git-fixes).
- commit 3e9fa11
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: macb: fix wakeup test in runtime suspend/resume routines
  (git-fixes).
- commit 0dfe6dc
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: hns3: fix for mishandle of asserting VF reset fail
  (git-fixes).
- commit 0c2ca01
* Mon Mar  1 2021 denis.kirjanov@suse.com
- smsc95xx: avoid memory leak in smsc95xx_bind (git-fixes).
- commit 11f5fde
* Mon Mar  1 2021 denis.kirjanov@suse.com
- smsc95xx: check return value of smsc95xx_reset (git-fixes).
- commit 02e26ea
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: bcmgenet: use hardware padding of runt frames (git-fixes).
- commit b2f215a
* Mon Mar  1 2021 msuchanek@suse.de
- powerpc/optprobes: Remove unused routine
  patch_imm32_load_insns() (jsc#SLE-13847).
- commit f56b470
* Mon Mar  1 2021 msuchanek@suse.de
- powerpc/pseries/ras: Make init_ras_hotplug_IRQ() static
  (FATE#322022, bsc#1065729. git-fixes).
- powerpc/pseries/eeh: Make pseries_pcibios_bus_add_device()
  static (FATE#324970, bsc#1078720, git-fixes).
- commit 5742f0f
* Mon Mar  1 2021 lhenriques@suse.de
- docs: filesystems: vfs: correct flag name (bsc#1182857).
- commit f89f9ce
* Mon Mar  1 2021 lhenriques@suse.de
- blacklist.conf: d0995b53130e f2fs: add missing documents of reserve_root/resuid/resgid
- commit 63a6155
* Mon Mar  1 2021 lhenriques@suse.de
- docs: filesystems: vfs: correct flag name (bsc#1182856).
- commit 969c3e4
* Mon Mar  1 2021 lhenriques@suse.de
- blacklist.conf: d0995b53130e f2fs: add missing documents of reserve_root/resuid/resgid
- commit 95579b0
* Mon Mar  1 2021 lhenriques@suse.de
- ceph: fix flush_snap logic after putting caps (bsc#1182854).
- commit eacaa0a
* Mon Mar  1 2021 lhenriques@suse.de
- ceph: fix flush_snap logic after putting caps (bsc#1182853).
- commit 9a38be6
* Mon Mar  1 2021 ohering@suse.de
- Drivers: hv: vmbus: Avoid use-after-free in vmbus_onoffer_rescind() (git-fixes).
- commit a24afd4
* Mon Mar  1 2021 mkubecek@suse.cz
- rpm/kernel-source.spec.in: temporary workaround for a build failure
  Upstream c6x architecture removal left a dangling link behind which
  triggers openSUSE post-build check in kernel-source, failing
  kernel-source build.
  A fix deleting the danglink link has been submitted but it did not make
  it into 5.12-rc1. Unfortunately we cannot add it as a patch as patch
  utility does not handle symlink removal. Add a temporary band-aid which
  deletes all dangling symlinks after unpacking the kernel source tarball.
  [jslaby] It's not that temporary as we are dragging this for quite some
  time in master. The reason is that this can happen any time again, so
  let's have this in packaging instead.
- commit 52a1ad7
* Mon Mar  1 2021 tiwai@suse.de
- bus: fsl-mc: Fix test for end of loop (git-fixes).
- commit a7e273c
* Mon Mar  1 2021 tiwai@suse.de
- Move upstreamed fsl patches into sorted section
- commit 6e876b3
* Mon Mar  1 2021 tiwai@suse.de
- i2c: exynos5: Preserve high speed master code (git-fixes).
- pwm: rockchip: rockchip_pwm_probe(): Remove superfluous
  clk_unprepare() (git-fixes).
- drm/panel: kd35t133: allow using non-continuous dsi clock
  (git-fixes).
- drm/rockchip: Require the YTR modifier for AFBC (git-fixes).
- drm/msm: Fix races managing the OOB state for timestamp vs
  timestamps (git-fixes).
- drm/msm: Fix race of GPU init vs timestamp power management
  (git-fixes).
- drm/msm/mdp5: Fix wait-for-commit for cmd panels (git-fixes).
- r8169: fix jumbo packet handling on RTL8168e (git-fixes).
- PCI: rockchip: Make 'ep-gpios' DT property optional (git-fixes).
- PCI: qcom: Use PHY_REFCLK_USE_PAD only for ipq8064 (git-fixes).
- PCI: Align checking of syscall user config accessors
  (git-fixes).
- Bluetooth: btusb: Some Qualcomm Bluetooth adapters stop working
  (git-fixes).
- drm/xlnx: fix kmemleak by sending vblank_event in atomic_disable
  (git-fixes).
- commit ecbb9ac
* Mon Mar  1 2021 tiwai@suse.de
- i2c: brcmstb: Fix brcmstd_send_i2c_cmd condition (git-fixes).
- HID: make arrays usage and value to be the same (git-fixes).
- usb: quirks: add quirk to start video capture on ELMO L-12F
  document camera reliable (git-fixes).
- USB: quirks: sort quirk entries (git-fixes).
- NET: usb: qmi_wwan: Adding support for Cinterion MV31
  (git-fixes).
- commit ae76757
* Sun Feb 28 2021 mkubecek@suse.cz
- misc: eeprom_93xx46: Add module alias to avoid breaking support
  for non device tree users (git-fixes).
- commit 761c100
* Fri Feb 26 2021 colyli@suse.de
- bcache: Avoid comma separated statements (git-fixes).
- bcache: Move journal work to new flush wq (git-fixes).
- bcache: Give btree_io_wq correct semantics again (git-fixes).
- Revert "bcache: Kill btree_io_wq" (git-fixes).
- bcache: Fix register_device_aync typo (git-fixes).
- bcache: consider the fragmentation when update the writeback
  rate (git-fixes).
- bcache: only check feature sets when sb->version >=
  BCACHE_SB_VERSION_CDEV_WITH_FEATURES (git-fixes).
- bcache: set bcache device into read-only mode for
  BCH_FEATURE_INCOMPAT_OBSO_LARGE_BUCKET (git-fixes).
- bcache: introduce BCH_FEATURE_INCOMPAT_LOG_LARGE_BUCKET_SIZE
  for large bucket (git-fixes).
- bcache: check unsupported feature sets for bcache register
  (git-fixes).
- bcache: fix typo from SUUP to SUPP in features.h (git-fixes).
- bcache: set pdev_set_uuid before scond loop iteration
  (git-fixes).
- md/bcache: convert comma to semicolon (git-fixes).
- bcache:remove a superfluous check in register_bcache
  (git-fixes).
- dm: remove unnecessary current->bio_list check when submitting
  split bio (git-fixes).
- bcache: fix race between setting bdev state to none and new
  write request direct to backing (git-fixes).
- dm: fix double RCU unlock in dm_dax_zero_page_range() error path
  (git-fixes).
- dm: fix missing imposition of queue_limits from dm_wq_work()
  thread (git-fixes).
- md: fix the checking of wrong work queue (git-fixes).
- bcache: remove embedded struct cache_sb from struct cache_set
  (git-fixes).
- bcache: check and set sync status on cache's in-memory super
  block (git-fixes).
- bcache: remove can_attach_cache() (git-fixes).
- bcache: don't check seq numbers in register_cache_set()
  (git-fixes).
- bcache: only use bucket_bytes() on struct cache (git-fixes).
- bcache: remove useless bucket_pages() (git-fixes).
- bcache: remove useless alloc_bucket_pages() (git-fixes).
- bcache: only use block_bytes() on struct cache (git-fixes).
- bcache: add set_uuid in struct cache_set (git-fixes).
- bcache: remove for_each_cache() (git-fixes).
- bcache: explicitly make cache_set only have single cache
  (git-fixes).
- bcache: remove 'int n' from parameter list of
  bch_bucket_alloc_set() (git-fixes).
- bcache: check c->root with IS_ERR_OR_NULL() in mca_reserve()
  (git-fixes).
- dm crypt: document new no_workqueue flags (git-fixes).
- commit 89ed52b
* Fri Feb 26 2021 bp@suse.de
- x86/cpufeatures: Add kABI padding (bsc#1179531).
- commit 305ba7d
* Fri Feb 26 2021 dfaggioli@suse.com
- KVM: x86: Gracefully handle __vmalloc() failure during VM allocation
  (bsc#1182801).
- commit 2b89cec
* Fri Feb 26 2021 dfaggioli@suse.com
- KVM: x86: Allocate new rmap and large page tracking when moving memslot
  (bsc#1182800).
- commit 4ea5d1c
* Fri Feb 26 2021 dfaggioli@suse.com
- KVM: VMX: Condition ENCLS-exiting enabling on CPU support for SGX1
  (bsc#1182798).
- commit 41a7998
* Fri Feb 26 2021 yousaf.kaukab@suse.com
- clk: fsl-flexspi: new driver (bsc#1182743).
- dt-bindings: clock: document the fsl-flexspi-clk device
  (bsc#1182743).
- clk: qoriq: provide constants for the type (bsc#1182743).
- commit 2f668c8
* Fri Feb 26 2021 msuchanek@suse.de
- ibmvfc: reinitialize sub-CRQs and perform channel enquiry
  after LPM (bsc#1182632 ltc#191222).
- commit 18964bb
* Fri Feb 26 2021 msuchanek@suse.de
- Refresh ibmvfc patches to v4 submission (bsc#1182632 ltc#191222).
- Refresh patches.suse/ibmvfc-fix-invalid-sub-CRQ-handles-after-hard-reset.patch.
- Refresh patches.suse/ibmvfc-simplify-handling-of-sub-CRQ-initialization.patch.
- Refresh patches.suse/ibmvfc-store-return-code-of-H_FREE_SUB_CRQ-during-cl.patch.
- Refresh patches.suse/ibmvfc-treat-H_CLOSED-as-success-during-sub-CRQ-regi.patch.
- commit 597b27d
* Fri Feb 26 2021 denis.kirjanov@suse.com
- net: phy: marvell10g: fix null pointer dereference (git-fixes).
- commit ba9ce5a
* Fri Feb 26 2021 msuchanek@suse.de
- Refresh patches.suse/ibmvnic-fix-a-race-between-open-and-reset.patch.
  Update patch metadata
- commit 8c08d90
* Fri Feb 26 2021 denis.kirjanov@suse.com
- net: bcmgenet: re-remove bcmgenet_hfb_add_filter (git-fixes).
- commit 46d342e
* Thu Feb 25 2021 msuchanek@suse.de
- Cherry-pick ibmvnic patches from SP3 (jsc#SLE-17268).
- commit fc08b49
* Thu Feb 25 2021 dfaggioli@suse.com
- kvm: tracing: Fix unmatched kvm_entry and kvm_exit events
  (bsc#1182770).
- commit 0b40723
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: dsa: lantiq_gswip: fix and improve the unsupported
  interface error (git-fixes).
- commit 966d874
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: octeon: mgmt: Repair filling of RX ring (git-fixes).
- commit a1726f7
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: dsa: mt7530: set CPU port to fallback mode (git-fixes).
- commit 7c6d69a
* Thu Feb 25 2021 denis.kirjanov@suse.com
- drivers: net: davinci_mdio: fix potential NULL dereference in
  davinci_mdio_probe() (git-fixes).
- commit aad32ea
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: lpc-enet: fix error return code in lpc_mii_init()
  (git-fixes).
- commit 023e4aa
* Thu Feb 25 2021 denis.kirjanov@suse.com
- Revert "net: bcmgenet: remove unused function in bcmgenet.c"
  (git-fixes).
- commit 6e0622b
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: bcmgenet: Fix WoL with password after deep sleep
  (git-fixes).
- commit 8a76658
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: bcmgenet: set Rx mode before starting netif (git-fixes).
- commit 95bbb6f
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: phy: marvell10g: fix temperature sensor on 2110
  (git-fixes).
- commit 80b675a
* Thu Feb 25 2021 yousaf.kaukab@suse.com
- dt-bindings: can: fsl,flexcan.yaml: fix compatible for i.MX35
  and i.MX53 (jsc#SLE-12251).
- dt-bindings: can: fsl,flexcan.yaml: fix fsl,stop-mode
  (jsc#SLE-12251).
- commit c4572f2
* Thu Feb 25 2021 yousaf.kaukab@suse.com
- Refresh patches.suse/PCI-dwc-Support-multiple-ATU-memory-regions.patch.
  Conflicts:
  patches.suse/PCI-dwc-Add-support-to-program-ATU-for-4GB-memory.patch.
- commit 4e15800
* Thu Feb 25 2021 msuchanek@suse.de
- net: re-solve some conflicts after net -> net-next merge
  (bsc#1176855 ltc#187293).
- commit df69724
* Thu Feb 25 2021 msuchanek@suse.de
- ibmvnic: fix a race between open and reset (bsc#1176855
  ltc#187293).
- commit 26c4220
* Thu Feb 25 2021 pvorel@suse.cz
- Fix bug number
- commit 3175ddf
* Thu Feb 25 2021 tiwai@suse.de
- regmap: sdw: use _no_pm functions in regmap_read/write
  (git-fixes).
- soundwire: bus: fix confusion on device used by pm_runtime
  (git-fixes).
- soundwire: export sdw_write/read_no_pm functions (git-fixes).
- soundwire: bus: use sdw_write_no_pm when setting the bus scale
  registers (git-fixes).
- soundwire: bus: use sdw_update_no_pm when initializing a device
  (git-fixes).
- soundwire: cadence: fix ACK/NAK handling (git-fixes).
- soundwire: debugfs: use controller id instead of link_id
  (git-fixes).
- commit f0289e1
* Thu Feb 25 2021 tiwai@suse.de
- phy: rockchip-emmc: emmc_phy_init() always return 0 (git-fixes).
- mei: hbm: call mei_set_devstate() on hbm stop response
  (git-fixes).
- virt: vbox: Do not use wait_event_interruptible when called
  from kernel context (git-fixes).
- misc: eeprom_93xx46: Fix module alias to enable module autoprobe
  (git-fixes).
- commit f380250
* Wed Feb 24 2021 mkoutny@suse.com
- blacklist.conf: Add b4e00444cab4 fork: fix copy_process(CLONE_PARENT) race with the exiting ->real_parent
- commit b1b6d4b
* Wed Feb 24 2021 mbrugger@suse.com
- armv7hl: lpae: Update config files.
  Disable KVM support (bsc#1182697)
- commit 9988ec5
* Wed Feb 24 2021 colyli@suse.de
- dm: fix bio splitting and its bio completion order for regular
  IO (git-fixes).
- bcache: fix overflow in offset_to_stripe() (git-fixes).
- dm crypt: avoid truncating the logical block size (git-fixes).
- include/linux/memremap.h: remove stale comments (git-fixes).
- commit f9b0dc3
* Wed Feb 24 2021 mkoutny@suse.com
- blacklist.conf: Add 8faeb1ffd795 mm: memcg/slab: fix root memcg vmstats
- commit 6424df5
* Wed Feb 24 2021 mkoutny@suse.com
- blacklist:conf: Add 67197a4f28d2 mm, oom_adj: don't loop through tasks in __set_oom_adj when not necessary
- commit c6bc092
* Wed Feb 24 2021 mkoutny@suse.com
- cgroup: fix psi monitor for root cgroup (bsc#1182686).
- commit 248e7d8
* Wed Feb 24 2021 mkoutny@suse.com
- cgroup-v1: add disabled controller check in
  cgroup1_parse_param() (bsc#1182684).
- commit 511e4ac
* Wed Feb 24 2021 mkoutny@suse.com
- cgroup: Fix memory leak when parsing multiple source parameters
  (bsc#1182683).
- commit 6c8979b
* Wed Feb 24 2021 mkoutny@suse.com
- cpuset: fix race between hotplug work and later CPU offline
  (bsc#1182676).
- commit dfdcc97
* Wed Feb 24 2021 msuchanek@suse.de
- macros.kernel-source: Use spec_install_pre for certificate installation (boo#1182672).
  Since rpm 4.16 files installed during build phase are lost.
- commit d0b887e
* Wed Feb 24 2021 msuchanek@suse.de
- Refresh patches.suse/powerpc-Fix-build-error-in-paravirt.h.patch.
  Update patch metadata.
- commit ca12b41
* Wed Feb 24 2021 jack@suse.cz
- quota: Fix memory leak when handling corrupted quota file
  (bsc#1182650).
- commit 2543668
* Wed Feb 24 2021 jeyu@suse.de
- Rename duplicate patches to their SLE15-SP2 equivalents.
  This is to prepare for the next SLE15-SP2 -> SLE15-SP3 merge.
- commit 4208989
* Wed Feb 24 2021 msuchanek@suse.de
- ibmvfc: store return code of H_FREE_SUB_CRQ during cleanup
  (bsc#1182632 ltc#191222).
- ibmvfc: treat H_CLOSED as success during sub-CRQ registration
  (bsc#1182632 ltc#191222).
- ibmvfc: fix invalid sub-CRQ handles after hard reset
  (bsc#1182632 ltc#191222).
- ibmvfc: simplify handling of sub-CRQ initialization (bsc#1182632
  ltc#191222).
- commit f68230e
* Wed Feb 24 2021 tiwai@suse.de
- ALSA: hda/realtek: Quirk for HP Spectre x360 14 amp setup
  (git-fixes).
- commit 8541380
* Wed Feb 24 2021 tiwai@suse.de
- keys: Remove outdated __user annotations (git-fixes).
- dmaengine: idxd: set DMA channel to be private (git-fixes).
- ASoC: qcom: qdsp6: Move frontend AIFs to q6asm-dai (git-fixes).
- ASoC: SOF: sof-pci-dev: add missing Up-Extreme quirk
  (git-fixes).
- ASoC: rt5682: Fix panic in rt5682_jack_detect_handler happening
  during system shutdown (git-fixes).
- ASoC: Intel: sof_sdw: add missing TGL_HDMI quirk for Dell SKU
  0A3E (git-fixes).
- ASoC: Intel: sof_sdw: add missing TGL_HDMI quirk for Dell SKU
  0A32 (git-fixes).
- ASoC: Intel: sof_sdw: add missing TGL_HDMI quirk for Dell SKU
  0A5E (git-fixes).
- ASoC: rt5682-sdw: cancel_work_sync() in .remove and .suspend
  (git-fixes).
- ASoC: rt711-sdw: use cancel_work_sync() for .remove (git-fixes).
- ASoC: rt700-sdw: use cancel_work_sync() in .remove as well as
  .suspend (git-fixes).
- ASoC: codecs: add missing max_register in regmap config
  (git-fixes).
- ASoC: SOF: Intel: hda: cancel D0i3 work during runtime suspend
  (git-fixes).
- ASoC: max98373: Fixes a typo in max98373_feedback_get
  (git-fixes).
- ASoC: siu: Fix build error by a wrong const prefix (git-fixes).
- ALSA: fireface: fix to parse sync status register of latter
  protocol (git-fixes).
- ACPI: property: Make acpi_node_prop_read() static (git-fixes).
- ACPI: property: Remove dead code (git-fixes).
- Bluetooth: btusb: Always fallback to alt 1 for WBS (git-fixes).
- commit 452f177
* Wed Feb 24 2021 ykaukab@suse.de
- dt-bindings: can: fsl,flexcan: add fsl,scu-index property to indicate a resource (jsc#SLE-12251).
- can: flexcan: convert the driver to DT-only (jsc#SLE-12251).
- can: flexcan: flexcan_close(): change order if commands to properly shut down the controller (jsc#SLE-12251).
- can: flexcan: flexcan_open(): completely initialize controller before requesting IRQ (jsc#SLE-12251).
- can: flexcan: flexcan_rx_offload_setup(): factor out mailbox and rx-offload setup into separate function (jsc#SLE-12251).
- can: flexcan: move enabling/disabling of interrupts from flexcan_chip_{start,stop}() to callers (jsc#SLE-12251).
- can: flexcan: factor out enabling and disabling of interrupts into separate function (jsc#SLE-12251).
- can: flexcan: rename macro FLEXCAN_QUIRK_SETUP_STOP_MODE -> FLEXCAN_QUIRK_SETUP_STOP_MODE_GPR (jsc#SLE-12251).
- dt-bindings: firmware: add IMX_SC_R_CAN(x) macro for CAN (jsc#SLE-12251).
- dt-bindings: can: fsl,flexcan: fix fsl,clk-source property (jsc#SLE-12251).
- dt-bindings: can: fsl,flexcan: add uint32 reference to clock-frequency property (jsc#SLE-12251).
- can: flexcan: flexcan_chip_start(): fix erroneous flexcan_transceiver_enable() during bus-off recovery (jsc#SLE-12251).
- can: flexcan: fix failure handling of pm_runtime_get_sync() (jsc#SLE-12251).
- can: flexcan: flexcan_setup_stop_mode(): add missing "req_bit" to stop mode property comment (jsc#SLE-12251).
- can: flexcan: flexcan_remove(): disable wakeup completely (jsc#SLE-12251).
- can: flexcan: add ECC initialization for VF610 (jsc#SLE-12251).
- can: flexcan: add ECC initialization for LX2160A (jsc#SLE-12251).
- can: flexcan: remove FLEXCAN_QUIRK_DISABLE_MECR quirk for LS1021A (jsc#SLE-12251).
- dt-bindings: can: flexcan: convert fsl,*flexcan bindings to yaml (jsc#SLE-12251).
- dt-bindings: can: add can-controller.yaml (jsc#SLE-12251).
- can: flexcan: remove ack_grp and ack_bit handling from driver (jsc#SLE-12251).
- dt-bindings: can: flexcan: remove ack_grp and ack_bit from fsl,stop-mode (jsc#SLE-12251).
- dt-bindings: can: flexcan: list supported processors (jsc#SLE-12251).
- can: flexcan: disable runtime PM if register flexcandev failed (jsc#SLE-12251).
- can: flexcan: add flexcan driver for i.MX8MP (jsc#SLE-12251).
- can: flexcan: initialize all flexcan memory for ECC function (jsc#SLE-12251).
- can: flexcan: add lx2160ar1 support (jsc#SLE-12251).
- can: flexcan: add imx8qm support (jsc#SLE-12251).
- can: flexcan: add Transceiver Delay Compensation support (jsc#SLE-12251).
- can: flexcan: add CAN FD BRS support (jsc#SLE-12251).
- can: flexcan: add ISO CAN FD feature support (jsc#SLE-12251).
- can: flexcan: add CAN-FD mode support (jsc#SLE-12251).
- can: flexcan: use struct canfd_frame for CAN classic frame (jsc#SLE-12251).
- can: flexcan: flexcan_set_bittiming(): move setup of CAN-2.0 bitiming into separate function (jsc#SLE-12251).
- can: flexcan: add LPSR mode support (jsc#SLE-12251).
- can: flexcan: disable clocks during stop mode (jsc#SLE-12251).
- can: flexcan: flexcan_chip_stop(): add error handling and propagate error value (jsc#SLE-12251).
- can: flexcan: add correctable errors correction when HW supports ECC (jsc#SLE-12251).
- can: flexcan: Add check for transceiver maximum bitrate limitation (jsc#SLE-12251).
- can: flexcan: flexcan_probe(): make regulator xceiver optional (jsc#SLE-12251).
- can: flexcan: Ack wakeup interrupt separately (jsc#SLE-12251).
- can: flexcan: quirks: get rid of long lines (jsc#SLE-12251).
- can: flexcan: struct flexcan_regs: document registers not affected by soft reset (jsc#SLE-12251).
- can: flexcan: more register names (jsc#SLE-12251).
- can: flexcan: flexcan_exit_stop_mode(): remove stray empty line (jsc#SLE-12251).
- can: flexcan: sort include files alphabetically (jsc#SLE-12251).
- can: flexcan: fix spelling mistake "reserverd" -> "reserved" (jsc#SLE-12251).
- can: flexcan: poll MCR_LPM_ACK instead of GPR ACK for stop mode acknowledgment (jsc#SLE-12251).
- can: flexcan: add low power enter/exit acknowledgment helper (jsc#SLE-12251).
- can: flexcan: fix possible deadlock and out-of-order reception after wakeup (jsc#SLE-12251).
- can: flexcan: flexcan_mailbox_read() make use of flexcan_write64() to mark the mailbox as read (jsc#SLE-12251).
- can: flexcan: flexcan_irq(): add support for TX mailbox in iflag1 (jsc#SLE-12251).
- can: flexcan: flexcan_read_reg_iflag_rx(): optimize reading (jsc#SLE-12251).
- can: flexcan: introduce struct flexcan_priv::tx_mask and make use of it (jsc#SLE-12251).
- can: flexcan: convert struct flexcan_priv::rx_mask{1,2} to rx_mask (jsc#SLE-12251).
- can: flexcan: remove TX mailbox bit from struct flexcan_priv::rx_mask{1,2} (jsc#SLE-12251).
- can: flexcan: rename struct flexcan_priv::reg_imask{1,2}_default to rx_mask{1,2} (jsc#SLE-12251).
- can: flexcan: flexcan_irq(): rename variable reg_iflag -> reg_iflag_rx (jsc#SLE-12251).
- can: flexcan: rename macro FLEXCAN_IFLAG_MB() -> FLEXCAN_IFLAG2_MB() (jsc#SLE-12251).
- can: flexcan: flexcan_irq_state(): only read timestamp if needed (jsc#SLE-12251).
- can: flexcan: use devm_platform_ioremap_resource() to simplify code (jsc#SLE-12251).
- can: rx-offload: Prepare for CAN FD support (jsc#SLE-12251).
- can: rx-offload: can_rx_offload_reset(): remove no-op function (jsc#SLE-12251).
- can: rx-offload: can_rx_offload_irq_offload_timestamp(): don't use assignment in if condition (jsc#SLE-12251).
- can: rx-offload: can_rx_offload_compare(): fix typo (jsc#SLE-12251).
- can: rx-offload: fix long lines (jsc#SLE-12251).
- can: flexcan: increase error counters if skb enqueueing via can_rx_offload_queue_sorted() fails (jsc#SLE-12251).
- can: flexcan: disable completely the ECC mechanism (jsc#SLE-12251).
- can: flexcan: add support for DT property 'wakeup-source' (jsc#SLE-12251).
- dt-bindings: can: flexcan: add can wakeup property (jsc#SLE-12251).
- can: flexcan: add support for PE clock source select (jsc#SLE-12251).
- dt-bindings: can: flexcan: add PE clock source property to device tree (jsc#SLE-12251).
- can: flexcan: implement can Runtime PM (jsc#SLE-12251).
- commit fabe848
* Wed Feb 24 2021 ykaukab@suse.de
- can: flexcan: remove all fixes
  Prepare for complete driver update.
- commit 1f0c2bd
* Wed Feb 24 2021 tiwai@suse.de
- dmaengine: hsu: disable spurious interrupt (git-fixes).
- dmaengine: owl-dma: Fix a resource leak in the remove function
  (git-fixes).
- dmaengine: fsldma: Fix a resource leak in an error handling
  path of the probe function (git-fixes).
- dmaengine: fsldma: Fix a resource leak in the remove function
  (git-fixes).
- Input: joydev - prevent potential read overflow in ioctl
  (git-fixes).
- Input: elo - fix an error code in elo_connect() (git-fixes).
- Input: sur40 - fix an error code in sur40_probe() (git-fixes).
- HID: core: detect and skip invalid inputs to snto32()
  (git-fixes).
- HID: wacom: Ignore attempts to overwrite the touch_max value
  from HID (git-fixes).
- commit 9e6160a
* Wed Feb 24 2021 nborisov@suse.com
- btrfs: Unlock extents in btrfs_zero_range in case of errors (bsc#1182047).
- commit bd5a9b2
* Wed Feb 24 2021 nborisov@suse.com
- btrfs: Simplify code flow in btrfs_delayed_inode_reserve_metadata (bsc#1182047).
- commit bf6dd14
* Wed Feb 24 2021 nborisov@suse.com
- btrfs: Remove btrfs_inode from btrfs_delayed_inode_reserve_metadata (bsc#1182047).
- commit fb6d272
* Wed Feb 24 2021 nborisov@suse.com
- btrfs: Cleanup try_flush_qgroup (bsc#1182047).
- commit 13881b3
* Wed Feb 24 2021 nborisov@suse.com
- btrfs: Don't flush from btrfs_delayed_inode_reserve_metadata (bsc#1182047).
- commit 942f628
* Wed Feb 24 2021 nborisov@suse.com
- btrfs: Free correct amount of space in btrfs_delayed_inode_reserve_metadata (bsc#1182047).
- commit 22ecef4
* Wed Feb 24 2021 fweisbecker@suse.de
- rcu/nocb: Trigger self-IPI on late deferred wake up before (git-fixes)
- commit 260172d
* Wed Feb 24 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/powerpc-perf-hv-24x7-Dont-create-sysfs-event-files-f.patch
  patches.suse/powerpc-pseries-dlpar-handle-ibm-configure-connector.patch
  patches.suse/scsi-lpfc-Enhancements-to-LOG_TRACE_EVENT-for-better.patch
  patches.suse/scsi-lpfc-Fix-FW-reset-action-if-I-Os-are-outstandin.patch
  patches.suse/scsi-lpfc-Fix-NVMe-recovery-after-mailbox-timeout.patch
  patches.suse/scsi-lpfc-Fix-PLOGI-S_ID-of-0-on-pt2pt-config.patch
  patches.suse/scsi-lpfc-Fix-auto-sli_mode-and-its-effect-on-CONFIG.patch
  patches.suse/scsi-lpfc-Fix-crash-when-a-fabric-node-is-released-p.patch
  patches.suse/scsi-lpfc-Fix-crash-when-nvmet-transport-calls-host_.patch
  patches.suse/scsi-lpfc-Fix-error-log-messages-being-logged-follow.patch
  patches.suse/scsi-lpfc-Fix-target-reset-failing.patch
  patches.suse/scsi-lpfc-Fix-vport-create-logging.patch
  patches.suse/scsi-lpfc-Implement-health-checking-when-aborting-I-.patch
  patches.suse/scsi-lpfc-Prevent-duplicate-requests-to-unregister-w.patch
  patches.suse/scsi-lpfc-Refresh-ndlp-when-a-new-PRLI-is-received-i.patch
  patches.suse/scsi-lpfc-Simplify-bool-comparison.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.7.patch
  patches.suse/scsi-lpfc-Use-the-nvme-fc-transport-supplied-timeout.patch
- commit ff0a90f
* Wed Feb 24 2021 pvorel@suse.cz
- ima: Free IMA measurement buffer after kexec syscall (git fixes
  (IMA)).
- commit 481e98b
* Wed Feb 24 2021 pvorel@suse.cz
- ima: Free IMA measurement buffer on error (git fixes (IMA)).
- commit ac8b38c
* Wed Feb 24 2021 pjakobsson@suse.de
- Add Alt-commit for cherry pick
  Refresh
  patches.suse/1918-drm-amdgpu-fix-NULL-pointer-dereference-for-Renoir.patch.
- commit 84dbff0
* Wed Feb 24 2021 fweisbecker@suse.de
- rcu/nocb: Perform deferred wake up before last idle's (git-fixes)
- commit f0bc502
* Wed Feb 24 2021 fweisbecker@suse.de
- rcu: Pull deferred rcuog wake up to rcu_eqs_enter() callers (git-fixes)
- commit 7a90fca
* Wed Feb 24 2021 pjakobsson@suse.de
- Add Alt-commit for cherry pick
  Refresh
  patches.suse/1909-drm-amd-display-remove-duplicate-call-to-rn_vbios_sm.patch.
- commit 28fa55a
* Tue Feb 23 2021 pjakobsson@suse.de
- Add Alt-commit for cherry-pick
  Refresh
  patches.suse/1906-drm-amdgpu-display-fix-CFLAGS-setup-for-DCN30.patch.
- commit 6c5745f
* Tue Feb 23 2021 fweisbecker@suse.de
- sched: Reenable interrupts in do_sched_yield() (git-fixes)
- commit 579dc67
* Tue Feb 23 2021 pjakobsson@suse.de
- blacklist.conf: bee1abc9cc02 drm/mediatek: reduce clear event
  Requried patches are not backported
- commit a403845
* Tue Feb 23 2021 pjakobsson@suse.de
- Add Alt-commit for cherry pick
  Refresh
  patches.suse/1832-drm-amdgpu-Specify-get_argument-function-for-ci_smu_.patch.
- commit 0bc2e82
* Tue Feb 23 2021 pjakobsson@suse.de
- Add Alt-commit for cherry pick
  Refresh
  patches.suse/1751-drm-amdgpu-Use-the-correct-size-when-allocating-memo.patch.
- commit dd923d9
* Tue Feb 23 2021 pjakobsson@suse.de
- Add Alt-commit for cherry pick
  Refresh
  patches.suse/1700-drm-amd-powerplay-off-by-one-bugs-in-smu_cmn_to_asic.patch.
- commit d58a85c
* Tue Feb 23 2021 pjakobsson@suse.de
- blacklist.conf: b7ccc7858a33 drm/i915/gt: Remove errant assertion in __intel_context_do_pin
  Not needed since we didn't mess up the merge
- commit 5f8e601
* Tue Feb 23 2021 fdmanana@suse.com
- btrfs: run delayed iputs when remounting RO to avoid leaking
  them (bsc#1182626).
- btrfs: add assertion for empty list of transactions at late
  stage of umount (bsc#1182626).
- btrfs: fix race between RO remount and the cleaner task
  (bsc#1182626).
- btrfs: fix transaction leak and crash after cleaning up orphans
  on RO mount (bsc#1182626).
- btrfs: fix transaction leak and crash after RO remount caused
  by qgroup rescan (bsc#1182626).
- btrfs: lift read-write mount setup from mount and remount
  (bsc#1182626).
- commit 2361750
* Tue Feb 23 2021 jdelvare@suse.de
- arm64: Update config file.
  Set CONFIG_WATCHDOG_SYSFS to true (bsc#1182560)
- commit 0c02797
* Tue Feb 23 2021 pmladek@suse.com
- blacklist.conf: printk: not critical; allow to use the full buffer
  when using log dumpers
- commit 4e198dc
* Tue Feb 23 2021 msuchanek@suse.de
- Remove debug patch for boot failure (bsc#1182602 ltc#190924).
  Delete patches.suse/prom_init-enable-varbose-prints-bsc-1178142.patch.
- commit 55e7bdd
* Tue Feb 23 2021 jack@suse.cz
- fs: Handle I_DONTCACHE in iput_final() instead of
  generic_drop_inode() (bsc#1182616).
- commit 8354395
* Tue Feb 23 2021 ddiss@suse.de
- Update upstream reference and move into sorted section:
  patches.suse/target-fix-XCOPY-NAA-identifier-lookup.patch
- commit e8f510f
* Tue Feb 23 2021 ddiss@suse.de
- target: disallow emulate_legacy_capacity with RBD object-map
  (bsc#1177109).
- commit 9e5609a
* Tue Feb 23 2021 msuchanek@suse.de
- Refresh sorted section.
- commit 33e772b
* Tue Feb 23 2021 nstange@suse.de
- supported.conf: mark Wireguard armv7hl dependencies as supported (jsc#SLE-12250)
- commit 661c1ff
* Tue Feb 23 2021 msuchanek@suse.de
- Update config files.
  armv7 is missing CONFIG_KPROBE_EVENTS_ON_NOTRACE=n
- commit c68b5c7
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/coresight-tmc-etr-Assign-boolean-values-to-a-bool-va.patch.
- commit 35a95ac
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/coresight-etb10-Fix-possible-NULL-ptr-dereference-in.patch.
- commit 9d9fb1d
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/coresight-tmc-etf-Fix-NULL-ptr-dereference-in-tmc_en.patch.
- commit 7c2beaf
* Tue Feb 23 2021 msuchanek@suse.de
- powerpc/prom: Fix "ibm,arch-vec-5-platform-support" scan
  (bsc#1182602 ltc#190924).
- commit f6d197a
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/coresight-Remove-unnecessary-THIS_MODULE-of-funnel-a.patch.
- commit 473d7ac
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/coresight-etm4x-Handle-TRCVIPCSSCTLR-accesses.patch.
- commit fcd1419
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/coresight-etm4x-Fix-accesses-to-TRCPROCSELR.patch.
- commit 42fd151
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/coresight-etm4x-Update-TRCIDR3.NUMPROCS-handling-to-.patch.
- commit c3d74e2
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/coresight-etm4x-Fix-accesses-to-TRCCIDCTLR1.patch.
- commit 8a55725
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/coresight-etm4x-Fix-accesses-to-TRCVMIDCTLR1.patch.
- commit e228859
* Tue Feb 23 2021 pmladek@suse.com
- lib/vsprintf: no_hash_pointers prints all addresses as unhashed
  (bsc#1182599).
- commit f0a1f3e
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/coresight-core-Remove-unneeded-semicolon.patch.
- commit 9255eec
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/coresight-cti-Initialize-dynamic-sysfs-attributes.patch.
  blacklist.conf: Remove duplicate entry
- commit bee32f7
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/coresight-Fix-uninitialised-pointer-bug-in-etm_setup.patch.
  blacklist.conf: Remove duplicate entry
- commit 43eb5a5
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/coresight-add-module-license.patch.
  blacklist.conf: Remove duplicate entry
- commit 42b5346
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/phy-tegra-xusb-Fix-usb_phy-device-driver-field.patch.
- commit a87f0e1
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/clk-tegra-bpmp-Clamp-clock-rates-on-requests.patch.
- commit 86bb8a3
* Tue Feb 23 2021 tbogendoerfer@suse.de
- RDMA/bnxt: Do not use ib_umem_page_count() or
  ib_umem_num_pages() (bsc#1175499).
- Refresh
  patches.suse/RDMA-bnxt_re-Fix-sizeof-mismatch-for-allocation-of-p.patch.
- commit 12c2631
* Tue Feb 23 2021 tbogendoerfer@suse.de
- RDMA/bnxt_re: Allow bigger MR creation (bsc#1175499).
- RDMA/bnxt_re: Code refactor while populating user MRs
  (bsc#1175499).
- RDMA/bnxt_re: Use rdma_umem_for_each_dma_block() (bsc#1175499).
- RDMA/umem: Split ib_umem_num_pages() into
  ib_umem_num_dma_blocks() (bsc#1175499).
- RDMA/umem: Add rdma_umem_for_each_dma_block() (bsc#1175499).
- commit 8d37937
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-tegra-Disable-LTSSM-during-L2-entry.patch.
- commit 071b1e3
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-tegra-Check-return-value-of-tegra_pcie_init_cont.patch.
- commit a99e298
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-tegra-Continue-unconfig-sequence-even-if-parts-f.patch.
- commit 37fbae9
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-tegra-Set-DesignWare-IP-version.patch.
- commit f3056ad
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-tegra-Fix-ASPM-L1SS-advertisement-disable-code.patch.
- commit 151b830
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-tegra-Read-dbi-base-address-to-program-in-applic.patch.
- commit c1ce36b
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-tegra-Move-dbi-accesses-to-post-common-DWC-initi.patch.
- commit b8d9f1b
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-Detect-number-of-iATU-windows.patch.
- commit 6869fbb
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-Move-inbound-and-outbound-windows-to-common-.patch.
- commit bf7452a
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-Remove-unnecessary-wrappers-around-dw_pcie_h.patch.
- commit b328586
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-Move-dw_pcie_msi_init-into-core.patch.
- commit 9b591ff
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-Move-link-handling-into-common-code.patch.
- commit db1d380
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-Rework-MSI-initialization.patch.
- commit fc22d7b
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-Move-MSI-interrupt-setup-into-DWC-common-cod.patch.
- commit 85e0e88
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-Drop-the-.set_num_vectors-host-op.patch.
- commit c8a821a
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-dra7xx-Use-the-common-MSI-irq_chip.patch.
- commit 0f8a8d3
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-Ensure-all-outbound-ATU-windows-are-reset.patch.
- commit 5e3c2f6
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-intel-gw-Remove-some-unneeded-function-wrapp.patch.
- commit 42d2190
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-Move-dbi-dbi2-and-addr_space-resource-setup-.patch.
- commit 7a267fa
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-intel-gw-Move-ATU-offset-out-of-driver-match.patch.
- commit fc7f014
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-keystone-Enable-compile-testing-on-ARM.patch.
- commit 674b74f
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-dwc-Add-support-to-program-ATU-for-4GB-memory.patch.
- commit 79897e2
* Tue Feb 23 2021 ykaukab@suse.de
- Refresh patches.suse/PCI-of-Warn-if-non-prefetchable-memory-aperture-size.patch.
- commit 11a2712
* Tue Feb 23 2021 jeyu@suse.de
- Rename duplicate patches to their SLE15-SP2 equivalents.
  This is to prepare for the next SLE15-SP2 -> SLE15-SP3 merge.
- commit d0f44e7
* Tue Feb 23 2021 tiwai@suse.de
- KEYS: trusted: Reserve TPM for seal and unseal operations
  (git-fixes).
- KEYS: trusted: Fix migratable=1 failing (git-fixes).
- KEYS: trusted: Fix incorrect handling of tpm_get_random()
  (git-fixes).
- drm/i915/gt: Correct surface base address for renderclear
  (git-fixes).
- drm/i915/gt: Flush before changing register state (git-fixes).
- drm/amdgpu/display: remove hdcp_srm sysfs on device removal
  (git-fixes).
- mtd: spi-nor: core: Add erase size check for erase command
  initialization (git-fixes).
- mtd: spi-nor: core: Fix erase type discovery for overlaid region
  (git-fixes).
- mtd: spi-nor: sfdp: Fix last erase region marking (git-fixes).
- mtd: spi-nor: sfdp: Fix wrong erase type bitmask for overlaid
  region (git-fixes).
- mtd: spi-nor: hisi-sfc: Put child node np on error path
  (git-fixes).
- mtd: parsers: afs: Fix freeing the part name memory in failure
  (git-fixes).
- mtd: parser: imagetag: fix error codes in
  bcm963xx_parse_imagetag_partitions() (git-fixes).
- pstore: Fix typo in compression option name (git-fixes).
- commit 3d8b82d
* Tue Feb 23 2021 tiwai@suse.de
- drm/amdgpu: cleanup struct amdgpu_ring (git-fixes).
- drm/dp_mst: Don't cache EDIDs for physical ports (git-fixes).
- drm/vc4: hdmi: Update the CEC clock divider on HSM rate change
  (git-fixes).
- drm/vc4: hdmi: Compute the CEC clock divider from the clock rate
  (git-fixes).
- drm/vc4: hdmi: Restore cec physical address on reconnect
  (git-fixes).
- drm/vc4: hdmi: Fix up CEC registers (git-fixes).
- drm/vc4: hdmi: Fix register offset with longer CEC messages
  (git-fixes).
- drm/vc4: hdmi: Move hdmi reset to bind (git-fixes).
- drm/mediatek: Check if fb is null (git-fixes).
- commit 3a8d088
* Tue Feb 23 2021 tiwai@suse.de
- drm/i915/gt: One more flush for Baytrail clear residuals
  (git-fixes).
- drm/amdgpu: toggle on DF Cstate after finishing xgmi injection
  (git-fixes).
- drm/sun4i: tcon: fix inverted DCLK polarity (git-fixes).
- drm/fourcc: fix Amlogic format modifier masks (git-fixes).
- drm/virtio: make sure context is created in gem open
  (git-fixes).
- drm: rcar-du: Fix the return check of of_parse_phandle and
  of_find_device_by_node (git-fixes).
- drm: rcar-du: Fix crash when using LVDS1 clock for CRTC
  (git-fixes).
- commit d709b9b
* Tue Feb 23 2021 tiwai@suse.de
- clocksource/drivers/mxs_timer: Add missing semicolon when
  DEBUG is defined (git-fixes).
- spi: imx: Don't print error on -EPROBEDEFER (git-fixes).
- spi: cadence-quadspi: Abort read if dummy cycles required are
  too many (git-fixes).
- platform/x86: intel_pmt_crashlog: Add dependency on
  MFD_INTEL_PMT (git-fixes).
- platform/x86: intel_pmt_telemetry: Add dependency on
  MFD_INTEL_PMT (git-fixes).
- platform/x86: intel_pmt: Make INTEL_PMT_CLASS
  non-user-selectable (git-fixes).
- watchdog: intel-mid_wdt: Postpone IRQ handler registration
  till SCU is ready (git-fixes).
- drm/vc4: hdmi: Take into account the clock doubling flag in
  atomic_check (git-fixes).
- commit 112de11
* Tue Feb 23 2021 tiwai@suse.de
- drm/amd/display: Fix HDMI deep color output for DCE 6-11
  (git-fixes).
- drm/amd/display: Fix 10/12 bpc setup in DCE output bit depth
  reduction (git-fixes).
- drm/amdgpu: Fix macro name _AMDGPU_TRACE_H_ in preprocessor
  if condition (git-fixes).
- gma500: clean up error handling in init (git-fixes).
- commit af18775
* Tue Feb 23 2021 tiwai@suse.de
- rtc: s5m: select REGMAP_I2C (git-fixes).
- spi: stm32: properly handle 0 byte transfer (git-fixes).
- spi: atmel: Put allocated master before return (git-fixes).
- spi: pxa2xx: Fix the controller numbering for Wildcat Point
  (git-fixes).
- spi: spi-synquacer: fix set_cs handling (git-fixes).
- regulator: core: Avoid debugfs: Directory ... already
  present! error (git-fixes).
- crypto: ecdh_helper - Ensure 'len >= secret.len' in decode_key()
  (git-fixes).
- crypto: talitos - Work around SEC6 ERRATA (AES-CTR mode data
  size error) (git-fixes).
- cpufreq: brcmstb-avs-cpufreq: Fix resource leaks in ->remove()
  (git-fixes).
- cpufreq: brcmstb-avs-cpufreq: Free resources in error path
  (git-fixes).
- commit fbcd516
* Tue Feb 23 2021 tiwai@suse.de
- power: reset: at91-sama5d2_shdwc: fix wkupdbc mask (git-fixes).
- regulator: s5m8767: Drop regulators OF node reference
  (git-fixes).
- regulator: s5m8767: Fix reference count leak (git-fixes).
- regulator: axp20x: Fix reference cout leak (git-fixes).
- mmc: renesas_sdhi_internal_dmac: Fix DMA buffer alignment from
  8 to 128-bytes (git-fixes).
- mmc: usdhi6rol0: Fix a resource leak in the error handling
  path of the probe (git-fixes).
- mmc: sdhci-sprd: Fix some resource leaks in the remove function
  (git-fixes).
- Revert "platform/x86: ideapad-laptop: Switch touchpad attribute
  to be RO" (git-fixes).
- commit 6d58f6a
* Tue Feb 23 2021 tiwai@suse.de
- gpio: pcf857x: Fix missing first interrupt (git-fixes).
- i3c: master: dw: Drop redundant disec call (git-fixes).
- linux/clk.h: use correct kernel-doc notation for 2 functions
  (git-fixes).
- mfd: wm831x-auxadc: Prevent use after free in
  wm831x_auxadc_read_irq() (git-fixes).
- mfd: bd9571mwv: Use devm_mfd_add_devices() (git-fixes).
- i2c: iproc: update slave isr mask (ISR_MASK_SLAVE) (git-fixes).
- i2c: iproc: handle only slave interrupts which are enabled
  (git-fixes).
- drm/fb-helper: Add missed unlocks in setcmap_legacy()
  (git-fixes).
- drm/gma500: Fix error return code in psb_driver_load()
  (git-fixes).
- commit e10cc76
* Tue Feb 23 2021 tiwai@suse.de
- amba: Fix resource leak for drivers without .remove (git-fixes).
- clocksource/drivers/ixp4xx: Select TIMER_OF when needed
  (git-fixes).
- clk: qcom: gcc-msm8998: Fix Alpha PLL type for all GPLLs
  (git-fixes).
- clk: meson: clk-pll: propagate the error from
  meson_clk_pll_set_rate() (git-fixes).
- clk: meson: clk-pll: make "ret" a signed integer (git-fixes).
- clk: meson: clk-pll: fix initializing the old rate (fallback)
  for a PLL (git-fixes).
- clk: sunxi-ng: h6: Fix clock divider range on some clocks
  (git-fixes).
- clk: sunxi-ng: h6: Fix CEC clock (git-fixes).
- auxdisplay: ht16k33: Fix refresh rate handling (git-fixes).
- commit 447d390
* Tue Feb 23 2021 colyli@suse.de
- libnvdimm/dimm: Avoid race between probe and
  available_slots_show() (bsc#1170442).
- Use the above upstream patch to replace the following in-house patch,
  patches.suse/nvdimm-Avoid-race-between-probe-and-reading-device-a.patch.
- commit ef2652a
* Tue Feb 23 2021 colyli@suse.de
- dm thin metadata: Fix use-after-free in dm_bm_set_read_only
  (bsc#1177529).
- dm thin metadata:  Avoid returning cmd->bm wild pointer on error
  (bsc#1177529).
- dm: use noio when sending kobject event (bsc#1177529).
- dm thin metadata: fix lockdep complaint (bsc#1177529).
- dm thin: fix use-after-free in metadata_pre_commit_callback
  (bsc#1177529).
- commit 3e2b6d9
* Tue Feb 23 2021 colyli@suse.de
- blacklist.conf: remove the following lines because it is time to have
  them now,
- a4a8d286586d4b28c8517a51db8d86954aadc74b
- 3918e0667bbac99400b44fa5aef3f8be2eeada4a
- commit e7046a1
* Tue Feb 23 2021 colyli@suse.de
- dm crypt: fix copy and paste bug in crypt_alloc_req_aead
  (jsc#SLE-12226).
- dm crypt: defer decryption to a tasklet if interrupts disabled
  (jsc#SLE-12226).
- dm crypt: do not call bio_endio() from the dm-crypt tasklet
  (jsc#SLE-12226).
- dm crypt: use GFP_ATOMIC when allocating crypto requests from
  softirq (jsc#SLE-12226).
- dm crypt: do not wait for backlogged crypto request completion
  in softirq (jsc#SLE-12226).
- dm crypt: don't use drivers that have
  CRYPTO_ALG_ALLOCATES_MEMORY (jsc#SLE-12226).
- commit e584169
* Tue Feb 23 2021 glin@suse.com
- libbpf: Avoid false unuinitialized variable warning in
  bpf_core_apply_relo (bsc#1177028).
- commit 2ed6283
* Tue Feb 23 2021 dfaggioli@suse.com
- KVM: nVMX: Handle pending #DB when injecting INIT VM-exit.
  Pulling in as a dependency of: "KVM: nVMX: Emulate MTF when performing
  instruction emulation" (bsc#1182380).
- commit df4cbaa
* Mon Feb 22 2021 bp@suse.de
- blacklist.conf: Two sparse fixes
  6ae58d871319 x86/asm: Annotate movdir64b()'s dst argument with __iomem
  5c99720b2838 x86/asm: Add a missing __iomem annotation in enqcmds()
- commit 6dcb1a5
* Mon Feb 22 2021 bp@suse.de
- blacklist.conf: 20bf2b378729 x86/build: Disable CET instrumentation in the kernel
- commit ade903f
* Mon Feb 22 2021 pjakobsson@suse.de
- Add alt-commit for non-blacklisted cherry-picks
- Refresh
  patches.suse/1447-drm-bridge-analogix_dp-Split-bind-into-probe-and-rea.patch.
- Refresh
  patches.suse/1776-drm-i915-Provide-the-perf-pmu.module.patch.
- Refresh
  patches.suse/1777-drm-i915-Copy-default-modparams-to-mock-i915_device.patch.
- Refresh
  patches.suse/1778-drm-i915-display-Check-for-an-LPSP-encoder-before-de.patch.
- Refresh
  patches.suse/1779-drm-i915-Update-bw_buddy-pagemask-table.patch.
- Refresh
  patches.suse/1782-drm-i915-tgl-Make-sure-TC-cold-is-blocked-before-ena.patch.
- Refresh
  patches.suse/1826-drm-i915-Fix-cmd-parser-desc-matching-with-masks.patch.
- Refresh
  patches.suse/1835-drm-i915-display-Ensure-that-ret-is-always-initializ.patch.
- Refresh
  patches.suse/1851-drm-i915-fix-regression-leading-to-display-audio-pro.patch.
- Refresh
  patches.suse/1852-drm-virtio-Revert-drm-virtio-Call-the-right-shmem-he.patch.
- Refresh patches.suse/1857-drm-virtio-fix-unblank.patch.
- Refresh
  patches.suse/1864-drm-virtio-drop-virtio_gpu_output-enabled.patch.
- Refresh
  patches.suse/1881-drm-i915-Be-wary-of-data-races-when-reading-the-acti.patch.
- Refresh
  patches.suse/1921-drm-i915-Stub-out-i915_gpu_coredump_put.patch.
- Refresh
  patches.suse/2072-drm-i915-dp-Disable-Port-sync-mode-correctly-on-tear.patch.
- Refresh
  patches.suse/2077-drm-i915-gt-Skip-trying-to-unbind-in-restore_ggtt_ma.patch.
- Refresh
  patches.suse/drm-i915-Protect-i915_request_await_start-from-early.patch.
- Refresh
  patches.suse/drm-i915-Protect-request-peeking-with-RCU.patch.
- commit 491e3a3
* Mon Feb 22 2021 aaptel@suse.com
- cifs: report error instead of invalid when revalidating a
  dentry fails (bsc#1177440).
- commit 2c3b276
* Mon Feb 22 2021 msuchanek@suse.de
- powerpc/book3s64/hash: Add cond_resched to avoid soft lockup
  warning (bsc#1182571 ltc#191345).
- commit a9f0cef
* Mon Feb 22 2021 tbogendoerfer@suse.de
- RDMA/efa: Use the correct current and new states in modify QP
  (git-fixes).
- commit f2d6e28
* Mon Feb 22 2021 denis.kirjanov@suse.com
- net: rmnet: do not allow to add multiple bridge interfaces
  (git-fixes).
- commit 4f39a57
* Mon Feb 22 2021 denis.kirjanov@suse.com
- net: rmnet: fix lower interface leak (git-fixes).
- commit d007718
* Mon Feb 22 2021 denis.kirjanov@suse.com
- net: rmnet: print error message when command fails (git-fixes).
- commit 9543352
* Mon Feb 22 2021 denis.kirjanov@suse.com
- net: qualcomm: rmnet: Allow configuration updates to existing
  devices (git-fixes).
- commit 8b01fa7
* Mon Feb 22 2021 denis.kirjanov@suse.com
- blacklist.conf: update the blacklist
- commit a0ee69e
* Mon Feb 22 2021 bp@suse.de
- x86/alternatives: Sync bp_patching update for avoiding NULL
  pointer exception (bsc#1152489).
- commit 8753fb5
* Mon Feb 22 2021 msuchanek@suse.de
- ibmvnic: Set to CLOSED state even on error (bsc#1084610
  ltc#165122 git-fixes).
- commit 7047a5a
* Mon Feb 22 2021 msuchanek@suse.de
- ibmvnic: serialize access to work queue on remove (bsc#1065729).
- commit 9671154
* Mon Feb 22 2021 msuchanek@suse.de
- mm: proc: Invalidate TLB after clearing soft-dirty page state
  (bsc#1163776 ltc#183929 git-fixes).
- commit c6ee8b1
* Mon Feb 22 2021 ailiop@suse.com
- xfs: reduce quota reservation when doing a dax unwritten extent
  conversion (git-fixes bsc#1182561).
- commit 229a330
* Mon Feb 22 2021 tbogendoerfer@suse.de
- RDMA/efa: Drop double zeroing for sg_init_table() (bsc#1176248).
- RDMA/efa: Remove redundant udata check from alloc ucontext
  response (bsc#1176248).
- RDMA/efa: Add EFA 0xefa1 PCI ID (bsc#1176248).
- RDMA/efa: User/kernel compatibility handshake mechanism
  (bsc#1176248).
- RDMA/efa: Expose minimum SQ size (bsc#1176248).
- RDMA/efa: Expose maximum TX doorbell batch (bsc#1176248).
- RDMA/efa: Report host information to the device (bsc#1176248).
- RDMA/efa: Fix setting of wrong bit in get/set_feature commands
  (bsc#1176248).
- RDMA/efa: Count admin commands errors (bsc#1176248).
- RDMA/efa: Count mmap failures (bsc#1176248).
- RDMA/efa: Report create CQ error counter (bsc#1176248).
- RDMA/efa: Use in-kernel offsetofend() to check field
  availability (bsc#1176248).
- RDMA/efa: Do not delay freeing of DMA pages (bsc#1176248).
- RDMA/efa: Properly document the interrupt mask register
  (bsc#1176248).
- RDMA/efa: Unified getters/setters for device structs bitmask
  access (bsc#1176248).
- commit f3e9801
* Mon Feb 22 2021 ailiop@suse.com
- xfs: fix an ABBA deadlock in xfs_rename (git-fixes bsc#1182558).
- commit 2a9e635
* Mon Feb 22 2021 mbrugger@suse.com
- arm: Update config files.
  Set CONFIG_WATCHDOG_SYSFS to true (bsc#1182560)
- commit 7ceb879
* Mon Feb 22 2021 tbogendoerfer@suse.de
- vmxnet3: Remove buf_info from device accessible structures
  (bsc#1181671).
- commit 7e4ecda
* Mon Feb 22 2021 nstange@suse.de
- supported.conf: mark Wireguard + dependencies as supported (jsc#SLE-12250)
- commit 1e0196a
* Mon Feb 22 2021 dwagner@suse.de
- nvmet-tcp: Fix NULL dereference when a connect data comes in
  h2cdata pdu (bsc#1182547).
- commit 62bcd4c
* Mon Feb 22 2021 msuchanek@suse.de
- rpm/kernel-subpackage-build: Workaround broken bot
  (https://github.com/openSUSE/openSUSE-release-tools/issues/2439)
- commit b74d860
* Mon Feb 22 2021 mbrugger@suse.com
- drivers/perf: hisi: Fix wrong value for all counters enable
  (SLE-14995 SLE-16234).
- commit 0293acf
* Mon Feb 22 2021 mbrugger@suse.com
- drivers/perf: hisi: Fix typo in events attribute array
  (SLE-14995 SLE-16234).
- commit d024f74
* Mon Feb 22 2021 mbrugger@suse.com
- drivers/perf: hisi: Simplify hisi_read_sccl_and_ccl_id and
  its comment (SLE-14995 SLE-16234).
- Refresh
  patches.suse/drivers-perf-hisi-Permit-modular-builds-of-HiSilicon.patch.
- Refresh
  patches.suse/firmware-arm_sdei-Document-the-motivation-behind-the.patch.
- commit 33b4114
* Mon Feb 22 2021 mbrugger@suse.com
- drivers/perf: hisi: update the sccl_id/ccl_id for certain
  HiSilicon platform (SLE-14995 SLE-16234).
- commit 3cf8137
* Mon Feb 22 2021 nsaenzjulienne@suse.de
- drm/vc4: hdmi: Take into account the clock doubling flag in
  atomic_check (git-fixes).
- commit 0eefa7d
* Mon Feb 22 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/nvme-hwmon-rework-to-avoid-devm-allocation.patch
  patches.suse/perf-x86-intel-uncore-Store-the-logical-die-id-inste.patch
  patches.suse/perf-x86-intel-uncore-With-8-nodes-get-pci-bus-die-i.patch
- commit f696cf9
* Mon Feb 22 2021 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section
  patches.suse/mm-pmem-avoid-inserting-hugepage-pte-entry-with-fsdax-if-hugepage-support-is-disabled.patch
- commit b1cf681
* Mon Feb 22 2021 tiwai@suse.de
- ALSA: usb-audio: Add implicit fb quirk for BOSS GP-10
  (git-fixes).
- ALSA: hda: Add another CometLake-H PCI ID (git-fixes).
- ALSA: hda/hdmi: Drop bogus check at closing a stream
  (git-fixes).
- ALSA: hda/realtek: modify EAPD in the ALC886 (git-fixes).
- commit d3cd0e8
* Mon Feb 22 2021 tiwai@suse.de
- tpm: Remove tpm_dev_wq_lock (git-fixes).
- tpm_tis: Clean up locality release (git-fixes).
- tpm_tis: Fix check_locality for correct locality acquisition
  (git-fixes).
- USB: serial: mos7720: fix error code in mos7720_write()
  (git-fixes).
- USB: serial: mos7840: fix error code in mos7840_write()
  (git-fixes).
- USB: serial: mos7720: improve OOM-handling in read_mos_reg()
  (git-fixes).
- usb: musb: Fix runtime PM race in musb_queue_resume_work
  (git-fixes).
- usb: dwc2: Make "trimming xfer length" a debug message
  (git-fixes).
- usb: dwc2: Abort transaction after errors with unknown reason
  (git-fixes).
- usb: dwc2: Do not update data length if it is 0 on inbound
  transfers (git-fixes).
- usb: gadget: u_audio: Free requests only after callback
  (git-fixes).
- commit 024918e
* Mon Feb 22 2021 tiwai@suse.de
- hwrng: timeriomem - Fix cooldown period calculation (git-fixes).
- media: pxa_camera: declare variable when DEBUG is defined
  (git-fixes).
- media: cx25821: Fix a bug when reallocating some dma memory
  (git-fixes).
- media: qm1d1c0042: fix error return code in qm1d1c0042_init()
  (git-fixes).
- media: lmedm04: Fix misuse of comma (git-fixes).
- media: software_node: Fix refcounts in
  software_node_get_next_child() (git-fixes).
- media: aspeed: fix error return code in
  aspeed_video_setup_video() (git-fixes).
- media: pwc: Use correct device for DMA (bsc#1181133).
- media: tm6000: Fix memleak in tm6000_start_stream (git-fixes).
- media: media/pci: Fix memleak in empress_init (git-fixes).
- media: em28xx: Fix use-after-free in em28xx_alloc_urbs
  (git-fixes).
- media: vsp1: Fix an error handling path in the probe function
  (git-fixes).
- media: camss: missing error code in msm_video_register()
  (git-fixes).
- media: mt9v111: Remove unneeded device-managed puts (git-fixes).
- media: ipu3-cio2: Fix mbus_code processing in
  cio2_subdev_set_fmt() (git-fixes).
- media: i2c: ov5670: Fix PIXEL_RATE minimum value (git-fixes).
- ata: ahci_brcm: Add back regulators management (git-fixes).
- staging: rtl8723bs: wifi_regd.c: Fix incorrect number of
  regulatory rules (git-fixes).
- ata: sata_nv: Fix retrieving of active qcs (git-fixes).
- commit f91a4d1
* Mon Feb 22 2021 tiwai@suse.de
- ASoC: simple-card-utils: Fix device module clock (git-fixes).
- ASoC: cs42l56: fix up error handling in probe (git-fixes).
- ASoC: SOF: debug: Fix a potential issue on string buffer
  termination (git-fixes).
- ASoC: cpcap: fix microphone timeslot mask (git-fixes).
- ALSA: pcm: Don't call sync_stop if it hasn't been stopped
  (git-fixes).
- ALSA: pcm: Assure sync with the pending stop operation at
  suspend (git-fixes).
- ALSA: pcm: Call sync_stop at disconnection (git-fixes).
- ALSA: usb-audio: Don't avoid stopping the stream at
  disconnection (git-fixes).
- ALSA: usb-audio: More strict state change in EP (git-fixes).
- ALSA: usb-audio: Handle invalid running state at releasing EP
  (git-fixes).
- ALSA: usb-audio: Fix PCM buffer allocation in non-vmalloc mode
  (git-fixes).
- ALSA: usb-audio: Correct document for
  snd_usb_endpoint_free_all() (git-fixes).
- ACPI: configfs: add missing check after
  configfs_register_default_group() (git-fixes).
- ACPI: property: Satisfy kernel doc validator (part 2)
  (git-fixes).
- ACPI: property: Satisfy kernel doc validator (part 1)
  (git-fixes).
- ACPI: property: Fix fwnode string properties matching
  (git-fixes).
- ACPICA: Fix exception code class checks (git-fixes).
- commit 858c1eb
* Mon Feb 22 2021 tiwai@suse.de
- Move upstreamed uvcvideo fix into sorted esction
- commit e05eaec
* Mon Feb 22 2021 jgross@suse.com
- xen-blkback: fix error handling in xen_blkbk_map() (XSA-365
  CVE-2021-26930 bsc#1181843).
- commit e27d769
* Mon Feb 22 2021 jgross@suse.com
- xen-scsiback: don't "handle" error by BUG() (XSA-362
  CVE-2021-26931 bsc#1181753).
- commit 0c27363
* Mon Feb 22 2021 jgross@suse.com
- xen-netback: don't "handle" error by BUG() (XSA-362
  CVE-2021-26931 bsc#1181753).
- commit b515e6e
* Mon Feb 22 2021 jgross@suse.com
- xen-blkback: don't "handle" error by BUG() (XSA-362
  CVE-2021-26931 bsc#1181753).
- commit 092d419
* Mon Feb 22 2021 jgross@suse.com
- xen/arm: don't ignore return errors from set_phys_to_machine
  (XSA-361 CVE-2021-26932 bsc#1181747).
- commit 3c70c9d
* Mon Feb 22 2021 jgross@suse.com
- Xen/gntdev: correct error checking in gntdev_map_grant_pages()
  (XSA-361 CVE-2021-26932 bsc#1181747).
- commit ee9fcdf
* Mon Feb 22 2021 jgross@suse.com
- Xen/gntdev: correct dev_bus_addr handling in
  gntdev_map_grant_pages() (XSA-361 CVE-2021-26932 bsc#1181747).
- commit e4d325f
* Mon Feb 22 2021 jgross@suse.com
- Xen/x86: also check kernel mapping in set_foreign_p2m_mapping()
  (XSA-361 CVE-2021-26932 bsc#1181747).
- commit c07de95
* Mon Feb 22 2021 jgross@suse.com
- Xen/x86: don't bail early from clear_foreign_p2m_mapping()
  (XSA-361 CVE-2021-26932 bsc#1181747).
- commit 488df4e
* Mon Feb 22 2021 jgross@suse.com
- xen/netback: fix spurious event detection for common event case
  (bsc#1182175).
- commit 1ecc6fe
* Sun Feb 21 2021 tiwai@suse.de
- ath10k: Fix lockdep assertion warning in ath10k_sta_statistics
  (git-fixes).
- ath10k: Fix suspicious RCU usage warning in
  ath10k_wmi_tlv_parse_peer_stats_info() (git-fixes).
- mt76: mt7915: fix endianness warning in mt7915_mcu_set_radar_th
  (git-fixes).
- Bluetooth: hci_qca: Fix memleak in qca_controller_memdump
  (git-fixes).
- commit a23b170
* Sun Feb 21 2021 tiwai@suse.de
- soc: aspeed: snoop: Add clock control logic (git-fixes).
- memory: ti-aemif: Drop child node when jumping out loop
  (git-fixes).
- reset: hisilicon: correct vendor prefix (git-fixes).
- r8169: fix resuming from suspend on RTL8105e if machine runs
  on battery (git-fixes).
- b43: N-PHY: Fix the update of coef for the PHY revision >=
  3case (git-fixes).
- mac80211: fix potential overflow when multiplying to u32
  integers (git-fixes).
- ath9k: fix data bus crash when setting nf_override via debugfs
  (git-fixes).
- Bluetooth: btusb: Fix memory leak in btusb_mtk_wmt_recv
  (git-fixes).
- Bluetooth: Put HCI device if inquiry procedure interrupts
  (git-fixes).
- Bluetooth: drop HCI device reference before return (git-fixes).
- Bluetooth: Fix initializing response id after clearing struct
  (git-fixes).
- Bluetooth: hci_uart: Fix a race for write_work scheduling
  (git-fixes).
- Bluetooth: btqcomsmd: Fix a resource leak in error handling
  paths in the probe function (git-fixes).
- ath10k: Fix error handling in case of CE pipe init failure
  (git-fixes).
- commit 8d04463
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: dsa: bcm_sf2: Fix overflow checks (git-fixes).
- commit 8931641
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: bcmgenet: keep MAC in reset until PHY is up (git-fixes).
- commit 1bd8cc0
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: mscc: ocelot: properly account for VLAN header length when setting MRU (git-fixes).
- commit 8ecb099
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: fix packet forwarding in rmnet bridge mode (git-fixes).
- commit a6a4d18
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: fix bridge mode bugs (git-fixes).
- commit 6828c73
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: use upper/lower device infrastructure (git-fixes).
- commit 604e5d6
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: do not allow to change mux id if mux id is duplicated (git-fixes).
- commit 358ab29
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: remove rcu_read_lock in rmnet_force_unassociate_device() (git-fixes).
- commit 4387992
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: fix suspicious RCU usage (git-fixes).
- commit 5258625
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: fix NULL pointer dereference in rmnet_changelink() (git-fixes).
- commit 8bdc771
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: fix NULL pointer dereference in rmnet_newlink() (git-fixes).
- commit e563469
* Fri Feb 19 2021 dfaggioli@suse.com
- KVM: x86: allow KVM_STATE_NESTED_MTF_PENDING in kvm_state flags
  (bsc#1182490).
- commit d0034b8
* Fri Feb 19 2021 dfaggioli@suse.com
- KVM: nVMX: don't clear mtf_pending when nested events are blocked
  (bsc#1182489).
- commit c9e5f4e
* Fri Feb 19 2021 msuchanek@suse.de
- ibmvnic: skip send_request_unmap for timeout reset (bsc#1182485
  ltc#191591).
- ibmvnic: add memory barrier to protect long term buffer
  (bsc#1182485 ltc#191591).
- ibmvnic: change IBMVNIC_MAX_IND_DESCS to 16 (bsc#1182485
  ltc#191591).
- ibmvnic: Ensure that CRQ entry read are correctly ordered
  (bsc#1182485 ltc#191591).
- ibmvnic: serialize access to work queue on remove (bsc#1182485
  ltc#191591).
- ibmvnic: skip send_request_unmap for timeout reset (bsc#1182485
  ltc#191591).
- ibmvnic: add memory barrier to protect long term buffer
  (bsc#1182485 ltc#191591).
- ibmvnic: change IBMVNIC_MAX_IND_DESCS to 16 (bsc#1182485
  ltc#191591).
- ibmvnic: Set to CLOSED state even on error (bsc#1182485
  ltc#191591).
- ibmvnic: Ensure that CRQ entry read are correctly ordered
  (bsc#1182485 ltc#191591).
- commit 8ab7740
* Thu Feb 18 2021 dfaggioli@suse.com
- kABI: repair, after "nVMX: Emulate MTF when performinginstruction  emulation"
  kvm_x86_ops is part of kABI as it's used by LTTng. But it's only read
  and never allocated in there, so growing it (without altering existing
  members' offsets) is fine.
- commit d47d125
* Thu Feb 18 2021 jack@suse.cz
- fscrypt: rename DCACHE_ENCRYPTED_NAME to DCACHE_NOKEY_NAME
  (bsc#1182446).
- commit 8620c20
* Thu Feb 18 2021 jack@suse.cz
- fscrypt: add fscrypt_is_nokey_name() (bsc#1182446).
- commit da2337f
* Thu Feb 18 2021 jack@suse.cz
- patches.suse/ext4-Avoid-freeing-inodes-on-dirty-list.patch: Move to
  sorted section, update tags
- commit d9f0c0d
* Thu Feb 18 2021 jack@suse.cz
- fs: fix lazytime expiration handling in
  __writeback_single_inode() (bsc#1182466).
- commit a4f4504
* Thu Feb 18 2021 jack@suse.cz
- ext4: fix superblock checksum failure when setting password salt
  (bsc#1182465).
- commit 1201ea7
* Thu Feb 18 2021 jack@suse.cz
- ext4: don't remount read-only with errors=continue on reboot
  (bsc#1182464).
- commit d554ce9
* Thu Feb 18 2021 jack@suse.cz
- ext4: fix deadlock with fs freezing and EA inodes (bsc#1182463).
- commit 2354cfd
* Thu Feb 18 2021 jack@suse.cz
- reiserfs: add check for an invalid ih_entry_count (bsc#1182462).
- commit 2c4183a
* Thu Feb 18 2021 jack@suse.cz
- quota: Sanity-check quota file headers on load (bsc#1182461).
- commit 5a95e11
* Thu Feb 18 2021 jack@suse.cz
- writeback: Drop I_DIRTY_TIME_EXPIRE (bsc#1182460).
- commit 6f11bc3
* Thu Feb 18 2021 jack@suse.cz
- ubifs: Fix error return code in ubifs_init_authentication()
  (bsc#1182459).
- commit 97d2ec0
* Thu Feb 18 2021 jack@suse.cz
- ubifs: wbuf: Don't leak kernel memory to flash (bsc#1182458).
- commit bce8f1a
* Thu Feb 18 2021 jack@suse.cz
- ubifs: prevent creating duplicate encrypted filenames
  (bsc#1182457).
- commit 80e0969
* Thu Feb 18 2021 jack@suse.cz
- ubifs: ubifs_add_orphan: Fix a memory leak bug (bsc#1182456).
- commit bf8f1af
* Thu Feb 18 2021 jack@suse.cz
- ubifs: ubifs_jnl_write_inode: Fix a memory leak bug
  (bsc#1182455).
  patches.suse/ubifs-xattr-Fix-some-potential-memory-leaks-while-it.patch:
  Refresh and add now relevant bits.
- commit 0b538c3
* Thu Feb 18 2021 jack@suse.cz
- ubifs: Fix ubifs_tnc_lookup() usage in do_kill_orphans()
  (bsc#1182454).
- commit fdbb549
* Thu Feb 18 2021 jack@suse.cz
- ext4: fix bug for rename with RENAME_WHITEOUT (bsc#1182449).
- commit 5f81ca3
* Thu Feb 18 2021 jack@suse.cz
- ext4: fix a memory leak of ext4_free_data (bsc#1182447).
- commit 798e94c
* Thu Feb 18 2021 msuchanek@suse.de
- mm: thp: kABI: move the added flag to the end of enum
  (bsc#1181896 ltc#191273).
- commit 5a6cff9
* Thu Feb 18 2021 jack@suse.cz
- ext4: prevent creating duplicate encrypted filenames
  (bsc#1182446).
- commit ebbed3b
* Thu Feb 18 2021 jack@suse.cz
- block: fix inflight statistics of part0 (bsc#1182445).
- commit 3645427
* Thu Feb 18 2021 jack@suse.cz
- blk-mq: move cancel of hctx->run_work to the front of
  blk_exit_queue (bsc#1182444).
- commit 25d39da
* Thu Feb 18 2021 jack@suse.cz
- blk-mq: insert request not through ->queue_rq into sw/scheduler
  queue (bsc#1182443).
- commit a0c44a1
* Thu Feb 18 2021 jack@suse.cz
- blk-mq: call commit_rqs while list empty but error happen
  (bsc#1182442).
- commit bc0709b
* Thu Feb 18 2021 jack@suse.cz
- block: respect queue limit of max discard segment (bsc#1182441).
- commit 78f8ad6
* Thu Feb 18 2021 jack@suse.cz
- block: virtio_blk: fix handling single range discard request
  (bsc#1182439).
- commit a829826
* Thu Feb 18 2021 ailiop@suse.com
- xfs: fix the forward progress assertion in
  xfs_iwalk_run_callbacks (git-fixes bsc#1182430).
- commit 251c330
* Thu Feb 18 2021 tiwai@suse.de
- drm/i915/tgl+: Make sure TypeC FIA is powered up when
  initializing it (git-fixes).
- Revert "drm/amd/display: Update NV1x SR latency values"
  (git-fixes).
- drm/amd/display: Release DSC before acquiring (git-fixes).
- drm/amd/display: Add more Clock Sources to DCN2.1 (git-fixes).
- drm/amd/display: Fix DPCD translation for LTTPR AUX_RD_INTERVAL
  (git-fixes).
- drm/i915/gt: Define guc firmware blob for older Cometlakes
  (git-fixes).
- commit 50eabd2
* Thu Feb 18 2021 tiwai@suse.de
- drm/amd/display: Decrement refcount of dc_sink before
  reassignment (git-fixes).
- drm/amd/display: Free atomic state after drm_atomic_commit
  (git-fixes).
- drm/amd/display: Fix dc_sink kref count in emulated_link_detect
  (git-fixes).
- commit 0a02ed8
* Thu Feb 18 2021 tiwai@suse.de
- clk: sunxi-ng: mp: fix parent rate change flag check
  (git-fixes).
- firmware_loader: align .builtin_fw to 8 (git-fixes).
- platform/x86: hp-wmi: Disable tablet-mode reporting by default
  (git-fixes).
- commit 3ec7f46
* Thu Feb 18 2021 dfaggioli@suse.com
- KVM: nVMX: Emulate MTF when performing instruction emulation
  (bsc#1182380).
- commit d82f9c0
* Thu Feb 18 2021 mbenes@suse.cz
- tracing: Check length before giving out the filter buffer
  (git-fixes).
- commit d3dfea0
* Thu Feb 18 2021 mbenes@suse.cz
- tracing: Do not count ftrace events in top level enable output
  (git-fixes).
- commit 9eb30ee
* Thu Feb 18 2021 mbenes@suse.cz
- tracing/kprobe: Fix to support kretprobe events on unloaded
  modules (git-fixes).
- commit 19d30cc
* Thu Feb 18 2021 dfaggioli@suse.com
- KVM: x86: remove stale comment from struct x86_emulate_ctxt
  (bsc#1182406).
- commit 0a00f86
* Thu Feb 18 2021 msuchanek@suse.de
- mm/pmem: avoid inserting hugepage PTE entry with fsdax if
  hugepage support is disabled (bsc#1181896 ltc#191273).
- commit 5527d63
* Thu Feb 18 2021 mbenes@suse.cz
- fgraph: Initialize tracing_graph_pause at task creation
  (git-fixes).
- commit ac6ab62
* Thu Feb 18 2021 nmoreychaisemartin@suse.com
- RDMA/srp: Fix support for unpopulated and unbalanced NUMA nodes (bsc#1169709)
- commit f19dffe
* Wed Feb 17 2021 dfaggioli@suse.com
- KVM: x86: clear stale x86_emulate_ctxt->intercept value
  (bsc#1182381).
- commit ffa8b86
* Wed Feb 17 2021 mkubecek@suse.cz
- net/tls: Except bond interface from some TLS checks
  (bsc#1181719).
- net/tls: Device offload to use lowest netdevice in chain
  (bsc#1181719).
- net/bonding: Declare TLS RX device offload support
  (bsc#1181719).
- net/bonding: Implement TLS TX device offload (bsc#1181719).
- net/bonding: Take update_features call out of XFRM funciton
  (bsc#1181719).
- net/bonding: Implement ndo_sk_get_lower_dev (bsc#1181719).
- net/bonding: Take IP hash logic into a helper (bsc#1181719).
- net: netdevice: Add operation ndo_sk_get_lower_dev
  (bsc#1181719).
- commit 3880919
* Wed Feb 17 2021 tiwai@suse.de
- drm/i915/guc: Update to use firmware v49.0.1 (CVE-2020-12362
  CVE-2020-12363 CVE-2020-12364 CVE-2020-12373 bsc#1181720
  bsc#1181735 bsc#1181736 bsc#1181738).
- commit d2373bb
* Wed Feb 17 2021 dfaggioli@suse.com
- KVM: x86: don't notify userspace IOAPIC on edge-triggered interrupt EOI
  (bsc#1182374).
- commit c629183
* Wed Feb 17 2021 mbenes@suse.cz
- tracing/kprobes: Do the notrace functions check without kprobes
  on ftrace (git-fixes).
- Update config files.
- commit dd6e75e
* Wed Feb 17 2021 tiwai@suse.de
- drm/i915/guc: Update to use firmware v49.0.1 (CVE-2020-12362
  CVE-2020-12363 CVE-2020-12364 CVE-2020-12373 bsc#1181720
  bsc#1181735 bsc#1181736 bsc#1181738).
- drm/i915: Update TGL and RKL HuC firmware versions
  (CVE-2020-12362 CVE-2020-12363 CVE-2020-12364 CVE-2020-12373
  bsc#1181720 bsc#1181735 bsc#1181736 bsc#1181738).
- commit 44f462f
* Wed Feb 17 2021 ptesarik@suse.cz
- vfio-pci/zdev: Add zPCI capabilities to VFIO_DEVICE_GET_INFO
  (jsc#SLE-13841).
- s390/default: Set CONFIG_VFIO_PCI_ZDEV=y.
- vfio: Introduce capability definitions for VFIO_DEVICE_GET_INFO
  (jsc#SLE-13841).
- s390/pci: track whether util_str is valid in the zpci_dev
  (jsc#SLE-13841).
- s390/pci: stash version in the zpci_dev (jsc#SLE-13841).
- commit 0136f7b
* Wed Feb 17 2021 nsaenzjulienne@suse.de
- Update config files: Set reset-raspberrypi as builtin (bsc#1180336)
  This driver is needed in order to boot through USB. Ideally the kernel
  module should be selected by dracut, but it's not. So make it builtin
  until the relevant dracut fixes are available.
- commit b773757
* Wed Feb 17 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0003-caif-no-need-to-check-return-value-of-debugfs_create.patch
- commit f7a521f
* Wed Feb 17 2021 tzimmermann@suse.de
- drm/sun4i: dw-hdmi: Fix max. frequency for H6 (bsc#1152472)
- commit acb3f2a
* Wed Feb 17 2021 tzimmermann@suse.de
- drm/sun4i: Fix H6 HDMI PHY configuration (bsc#1152472)
- commit 039ccc9
* Wed Feb 17 2021 tzimmermann@suse.de
- drm/sun4i: dw-hdmi: always set clock rate (bsc#1152472)
- commit 0e99073
* Wed Feb 17 2021 tzimmermann@suse.de
- drm/sun4i: tcon: set sync polarity for tcon1 channel (bsc#1152472)
- commit 03d6bea
* Wed Feb 17 2021 tzimmermann@suse.de
- drm/vc4: hvs: Fix buffer overflow with the dlist handling (bsc#1152489)
- commit b8a95b9
* Wed Feb 17 2021 tzimmermann@suse.de
- drm/meson: Unbind all connectors on module removal (bsc#1152472)
- commit b5e929b
* Wed Feb 17 2021 tzimmermann@suse.de
- matroxfb: avoid -Warray-bounds warning (bsc#1152472)
- commit f5716ba
* Wed Feb 17 2021 tiwai@suse.de
- rpm/config.sh: Enable armv7hl build in an extra project (jsc#SLE-17212)
  The armv7hl is built on OBS openSUSE:Step:15-SP3 project
- commit 8215a31
* Tue Feb 16 2021 tiwai@suse.de
- config.conf: Enable armv7hl build (jsc#SLE-17212)
  The build is still not triggered as it's missing SUSE:* projects
- commit b8c9b59
* Tue Feb 16 2021 nsaenzjulienne@suse.de
- Update config files: Enable UDC useful for arm64 (jsc#SLE-14042)
- supported.conf: Set arm64 UDCs as optional
- commit 4427f1e
* Tue Feb 16 2021 msuchanek@suse.de
- Refresh patches.suse/powerpc-64-signal-Fix-regression-in-__kernel_sigtram.patch
  powerpc/64/signal: Fix regression in fixing regression in
  __kernel_sigtramp_rt64() semantics
  Fixes:
  [    1.424052] systemd[142]: /usr/lib/systemd/system-generators/dracut-rootfs-generator terminated by signal SEGV.
  ...
  /.build/build-vm: line 521:   208 Segmentation fault      $0 "$@"
  [    2.595622] Kernel panic - not syncing: Attempted to kill init!  exitcode=0x0000000b
- commit 031f2c1
* Tue Feb 16 2021 oneukum@suse.com
- Update config files. Enable USB_GADGET(jsc#SLE-14042)
  After discussion what the feature request implied, it was
  decided that gadget mode is also needed on x86_64
- commit 4402673
* Tue Feb 16 2021 ptesarik@suse.cz
- arm64/64kb: Enable 52-bit virtual and 52-bit physical addresses.
  These features have been rejected solely because of their
  dependency on 64k page size.
- commit afe8527
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: dwmac-sunxi: Provide TX and RX fifo sizes
  (git-fixes).
- commit 2c2d766
* Tue Feb 16 2021 ptesarik@suse.cz
- Make a 64kb kernel flavor for arm64 (jsc#SLE-15406)
  Add a kernel flavor with a 64kb PAGE_SIZE. Only the page size has
  been changed explicitly; all other config option changes are caused
  by Kconfig dependencies.
- commit e9424d3
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net/sonic: Add mutual exclusion for accessing shared state
  (git-fixes).
- commit 52ed672
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: Always arm TX Timer at end of transmission start
  (git-fixes).
- commit 6058ba7
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: Fix the TX IOC in xmit path (git-fixes).
- commit 0d8ff7f
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: Enable 16KB buffer size (git-fixes).
- commit c5a734b
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: 16KB buffer must be 16 byte aligned (git-fixes).
- commit c88cefc
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: RX buffer size must be 16 byte aligned (git-fixes).
- commit d10b760
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: xgmac: Clear previous RX buffer size (git-fixes).
- commit 53673df
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: Do not accept invalid MTU values (git-fixes).
- commit ac657b6
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: selftests: Needs to check the number of Multicast
  regs (git-fixes).
- commit 8826854
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: caif: Fix debugfs on 64-bit platforms (git-fixes).
- commit 7a8758b
* Tue Feb 16 2021 denis.kirjanov@suse.com
- caif: no need to check return value of debugfs_create functions
  (git-fixes).
- commit 756b62e
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: axienet: Fix error return code in axienet_probe()
  (git-fixes).
- commit 6ec2abe
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: netsec: Correct dma sync for XDP_TX frames (git-fixes).
- commit 8040572
* Tue Feb 16 2021 tbogendoerfer@suse.de
- net: gro: do not keep too many GRO packets in napi->rx_list
  (bsc#1154353).
- commit 76fde4b
* Mon Feb 15 2021 msuchanek@suse.de
- kernel-binary.spec: Add back initrd and image symlink ghosts to
  filelist (bsc#1182140).
  Fixes: 76a9256314c3 ("rpm/kernel-{source,binary}.spec: do not include ghost symlinks (boo#1179082).")
- commit 606c9d1
* Mon Feb 15 2021 tiwai@suse.de
- ahci: Add support for Dell S140 and later (jsc#SLE-14457).
- commit 7fa1bda
* Mon Feb 15 2021 ailiop@suse.com
- xfs: ratelimit xfs_discard_page messages (bsc#1182283).
- commit 672719e
* Mon Feb 15 2021 ailiop@suse.com
- xfs: scrub should mark a directory corrupt if any entries
  cannot be iget'd (git-fixes bsc#1182278).
- commit 55cdbf1
* Mon Feb 15 2021 tiwai@suse.de
- Drop HID logitech patch that caused a regression (bsc#1182259)
  Delete patches.suse/HID-logitech-dj-add-the-G602-receiver.patch
  blacklist.conf: add the dropped entry
- commit fc205a0
* Mon Feb 15 2021 ailiop@suse.com
- xfs: fix parent pointer scrubber bailing out on unallocated
  inodes (git-fixes bsc#1182276).
- commit 68a744e
* Mon Feb 15 2021 ailiop@suse.com
- xfs: return corresponding errcode if xfs_initialize_perag()
  fail (git-fixes bsc#1182275).
- commit adf2653
* Mon Feb 15 2021 ailiop@suse.com
- xfs: fix the minrecs logic when dealing with inode root child
  blocks (git-fixes bsc#1182273).
- commit 5d5cd17
* Mon Feb 15 2021 ailiop@suse.com
- xfs: ensure inobt record walks always make forward progress
  (git-fixes bsc#1182272).
- commit 5d91094
* Mon Feb 15 2021 bp@suse.de
- x86/apic: Add extra serialization for non-serializing MSRs
  (bsc#1152489).
- commit 52e6a50
* Mon Feb 15 2021 ailiop@suse.com
- xfs: strengthen rmap record flags checking (git-fixes
  bsc#1182271).
- commit 0a8fcac
* Mon Feb 15 2021 ailiop@suse.com
- squashfs: add more sanity checks in xattr id lookup (git-fixes
  bsc#1182268).
- commit f6143c2
* Mon Feb 15 2021 ailiop@suse.com
- squashfs: add more sanity checks in inode lookup (git-fixes
  bsc#1182267).
- commit 81b879a
* Mon Feb 15 2021 ailiop@suse.com
- squashfs: add more sanity checks in id lookup (git-fixes
  bsc#1182266).
- commit a860e79
* Mon Feb 15 2021 ailiop@suse.com
- vfs: Convert squashfs to use the new mount API (git-fixes
  bsc#1182265).
- commit 961749a
* Mon Feb 15 2021 vbabka@suse.cz
- mm: thp: fix MADV_REMOVE deadlock on shmem THP (CVE-2020-29368,
  bsc#1179660.).
- commit 9d15b36
* Mon Feb 15 2021 vbabka@suse.cz
- mm: thp: make the THP mapcount atomic against
  __split_huge_pmd_locked() (CVE-2020-29368, bsc#1179660.).
- commit 842b18f
* Mon Feb 15 2021 tiwai@suse.de
- rpm/post.sh: Avoid purge-kernel for the first installed kernel (bsc#1180058)
- commit c29e77d
* Mon Feb 15 2021 bp@suse.de
- blacklist.conf: 20bf2b378729 x86/build: Disable CET instrumentation in the kernel
- commit ae0a855
* Mon Feb 15 2021 msuchanek@suse.de
- Update config files.
  CONFIG_IRQ_TIME_ACCOUNTING=n on ppc64
  Fixes: ce08519dfa669
- commit 3aeb7fd
* Mon Feb 15 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/mediatek: Remove duplicated include'
- commit ecb87cb
* Mon Feb 15 2021 tzimmermann@suse.de
- drm/dp_mst: Don't report ports connected if nothing is attached to (bsc#1152489)
- commit 00ff66f
* Mon Feb 15 2021 tzimmermann@suse.de
- drm/i915: Fix overlay frontbuffer tracking (bsc#1152489)
- commit 4516e0f
* Mon Feb 15 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gem: Support parsing of oversize batches'
- commit e3b72f7
* Mon Feb 15 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Add missing "Copy GSL groups when committing a new context"'
- commit 5abd636
* Mon Feb 15 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Filter wake_flags passed to default_wake_function'
- commit 0a7430b
* Mon Feb 15 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gem: Reduce context termination list iteration guard to RCU'
- commit 6bbec31
* Mon Feb 15 2021 tzimmermann@suse.de
- drm/i915/gt: Only transfer the virtual context to the new engine if (bsc#1152489)
  Backporting notes:
  * context changes
- commit 3e2a61c
* Mon Feb 15 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/selftests: Avoid passing a random 0 into ilog2'
- commit f3cb566
* Mon Feb 15 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix wrong return value in intel_atomic_check()'
- commit 2ef532e
* Mon Feb 15 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gt: Protect defer_request() from new waiters'
- commit 2230231
* Mon Feb 15 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/mediatek: Fix can't get component for external display plane.'
- commit edafa6b
* Mon Feb 15 2021 jgross@suse.com
- x86/pci: Create PCI/MSI irqdomain after x86_init.pci.arch_init()
  (bsc#1181572).
- commit 7161d5a
* Sun Feb 14 2021 mkubecek@suse.cz
- fix patch metadata
- fix upstream reference:
  patches.suse/net-hns3-add-a-check-for-queue_id-in-hclge_reset_vf_.patch
- commit 33a1a9d
* Sun Feb 14 2021 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section
  patches.suse/powerpc-pseries-extract-host-bridge-from-pci_bus-pri.patch
- commit 05c22a3
* Sun Feb 14 2021 tiwai@suse.de
- drm/sun4i: dw-hdmi: Fix max. frequency for H6 (git-fixes).
- drm/sun4i: Fix H6 HDMI PHY configuration (git-fixes).
- drm/sun4i: dw-hdmi: always set clock rate (git-fixes).
- drm/sun4i: tcon: set sync polarity for tcon1 channel
  (git-fixes).
- drm/dp_mst: Don't report ports connected if nothing is attached
  to them (git-fixes).
- drm/vc4: hvs: Fix buffer overflow with the dlist handling
  (git-fixes).
- drm/i915: Fix overlay frontbuffer tracking (git-fixes).
- drm/nouveau/nvif: fix method count when pushing an array
  (git-fixes).
- commit f9287ec
* Sun Feb 14 2021 tiwai@suse.de
- regulator: Fix lockdep warning resolving supplies (git-fixes).
- commit 83723b8
* Sun Feb 14 2021 tiwai@suse.de
- i2c: stm32f7: fix configuration of the digital filter
  (git-fixes).
- i2c: mediatek: Move suspend and resume handling to NOIRQ phase
  (git-fixes).
- mac80211: 160MHz with extended NSS BW in CSA (git-fixes).
- iwlwifi: mvm: guard against device removal in reprobe
  (git-fixes).
- iwlwifi: mvm: invalidate IDs of internal stations at mvm start
  (git-fixes).
- iwlwifi: pcie: fix context info memory leak (git-fixes).
- iwlwifi: pcie: add a NULL check in iwl_pcie_txq_unmap
  (git-fixes).
- iwlwifi: mvm: take mutex for calling iwl_mvm_get_sync_time()
  (git-fixes).
- iwlwifi: mvm: skip power command when unbinding vif during CSA
  (git-fixes).
- regulator: core: avoid regulator_resolve_supply() race condition
  (git-fixes).
- commit c869ffc
* Sat Feb 13 2021 bp@suse.de
- x86/MCE/AMD, EDAC/mce_amd: Remove struct smca_hwid.xec_bitmap
  (bsc#1182217).
- Refresh
  patches.suse/edac-mce_amd-use-struct-cpuinfo_x86-cpu_die_id-for-amd-nodeid.patch.
- commit bdedc9e
* Sat Feb 13 2021 denis.kirjanov@suse.com
- net: mscc: ocelot: fix address ageing time (again) (git-fixes).
- commit 2561722
* Sat Feb 13 2021 denis.kirjanov@suse.com
- dpaa2-eth: fix return codes used in ndo_setup_tc (git-fixes).
- commit 14e0d91
* Sat Feb 13 2021 denis.kirjanov@suse.com
- qlcnic: fix missing release in qlcnic_83xx_interrupt_test
  (git-fixes).
- commit d3915bd
* Sat Feb 13 2021 denis.kirjanov@suse.com
- net: sun: fix missing release regions in cas_init_one()
  (git-fixes).
- commit 5243443
* Sat Feb 13 2021 denis.kirjanov@suse.com
- net: mscc: ocelot: ANA_AUTOAGE_AGE_PERIOD holds a value in
  seconds, not ms (git-fixes).
- commit 8f77ca6
* Sat Feb 13 2021 denis.kirjanov@suse.com
- net: moxa: Fix a potential double 'free_irq()' (git-fixes).
- commit 6d56ae2
* Sat Feb 13 2021 bp@suse.de
- EDAC/mce_amd: Add new error descriptions for existing types
  (bsc#1182217).
- commit 8e9c253
* Sat Feb 13 2021 bp@suse.de
- x86/mce, EDAC/mce_amd: Print PPIN in machine check records
  (bsc#1182217).
- commit 6faa949
* Sat Feb 13 2021 bp@suse.de
- EDAC/mce_amd: Print !SMCA processor warning only once
  (bsc#1182217).
- commit 3bacba7
* Sat Feb 13 2021 bp@suse.de
- EDAC/amd64: Do not warn when removing instances (bsc#1182217).
- commit d9742d0
* Fri Feb 12 2021 msuchanek@suse.de
- powerpc/pseries: extract host bridge from pci_bus prior to
  bus removal (bsc#1182171 ltc#190900).
- commit 9deaa93
* Fri Feb 12 2021 msuchanek@suse.de
- powerpc/kexec_file: fix FDT size estimation for kdump kernel
  (bsc#1181928 ltc#190572).
- commit de42489
* Fri Feb 12 2021 rgoldwyn@suse.com
- btrfs: Enable autodefrag (bsc#1181785)
  Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit c3b1454
* Fri Feb 12 2021 tiwai@suse.de
- ASoC: codecs: max98373-sdw: align regmap use with other codecs
  (git-fixes).
- Refresh
  patches.suse/ASoC-max98373-don-t-access-volatile-registers-in-bia.patch.
- commit 2986405
* Fri Feb 12 2021 tiwai@suse.de
- ASoC: codecs: rt*.c: remove useless pointer cast (git-fixes).
- ASoC: topology: Add support for WO and RO TLV byte kcontrols
  (git-fixes).
- ASoC: codecs: rt*-sdw: use SDW_SLAVE_ENTRY_EXT (git-fixes).
- ASoC: hdac_hda: allow runtime pm at end of probe (git-fixes).
- commit 51b0ab6
* Fri Feb 12 2021 tbogendoerfer@suse.de
- cxgb4: fix the panic caused by non smac rewrite (git-fixes).
- commit 0f6aca4
* Fri Feb 12 2021 dwagner@suse.de
- nvme-hwmon: rework to avoid devm allocation (bsc#1177326).
- commit bc99792
* Fri Feb 12 2021 tiwai@suse.de
- Update config files: make armv7hl/lpae a fragmented config (jsc#SLE-17212)
  Just for ease of maintenance
- commit 8e88e72
* Fri Feb 12 2021 tiwai@suse.de
- gpio: ep93xx: Fix single irqchip with multi gpiochips
  (git-fixes).
- gpio: ep93xx: fix BUG_ON port F usage (git-fixes).
- commit 4d3d0a7
* Fri Feb 12 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/ibmvnic-Clear-failover_pending-if-unable-to-schedule.patch
- commit f78f850
* Thu Feb 11 2021 msuchanek@suse.de
- arm64: use a common .arch preamble for inline assembly
  (bsc#1182114).
- commit 56aeca4
* Thu Feb 11 2021 msuchanek@suse.de
- 1764c3edc66880778604f5053fe2dda7b3ddd2c1 also fixes binutils 2.36
  (bsc#1182114)
- commit a031455
* Thu Feb 11 2021 msuchanek@suse.de
- powerpc/perf/hv-24x7: Dont create sysfs event files for dummy
  events (bsc#1182118 ltc#190624).
- commit 2178630
* Thu Feb 11 2021 tbogendoerfer@suse.de
- cxgb4/chtls: Fix tid stuck due to wrong update of qid
  (git-fixes).
- chtls: Fix chtls resources release sequence (git-fixes).
- chtls: Added a check to avoid NULL pointer dereference
  (git-fixes).
- chtls: Replace skb_dequeue with skb_peek (git-fixes).
- chtls: Avoid unnecessary freeing of oreq pointer (git-fixes).
- chtls: Fix panic when route to peer not configured (git-fixes).
- chtls: Remove invalid set_tcb call (git-fixes).
- chtls: Fix hardware tid leak (git-fixes).
- i40e: avoid premature Rx buffer reuse (git-fixes).
- net/mlx4_en: Handle TX error CQE (bsc#1181854).
- net/mlx4_en: Avoid scheduling restart task if it is already
  running (bsc#1181854).
- chelsio/chtls: fix a double free in chtls_setkey() (git-fixes).
- chelsio/chtls: fix panic during unload reload chtls (git-fixes).
- commit 6313497
* Thu Feb 11 2021 nsaenzjulienne@suse.de
- Update config files: Set ledtrig-default-on as builtin (bsc#1182128)
- commit 2f7b8ce
* Thu Feb 11 2021 tiwai@suse.de
- supported.conf: Preliminary sort of contents (jsc#SLE-17212)
  Just sorted, no other changes
- commit 5b39bec
* Thu Feb 11 2021 tbogendoerfer@suse.de
- net: hns3: add a check for queue_id in hclge_reset_vf_queue()
  (git-fixes).
- net/mlx5e: Update max_opened_tc also when channels are closed
  (git-fixes).
- net: mvpp2: TCAM entry enable should be written after SRAM data
  (git-fixes).
- igc: check return value of ret_val in
  igc_config_fc_after_link_up (git-fixes).
- igc: set the default return value to -IGC_ERR_NVM in
  igc_write_nvm_srwr (git-fixes).
- igc: Report speed and duplex as unknown when device is runtime
  suspended (git-fixes).
- net/mlx5e: Reduce tc unsupported key print level (git-fixes).
- net/mlx5: Fix memory leak on flow table creation error flow
  (git-fixes).
- igc: fix link speed advertising (git-fixes).
- cxgb4/chtls: Fix tid stuck due to wrong update of qid
  (git-fixes).
- bnxt_en: Improve stats context resource accounting with RDMA
  driver loaded (git-fixes).
- net: mvpp2: Remove Pause and Asym_Pause support (git-fixes).
- mlxsw: core: Increase critical threshold for ASIC thermal zone
  (git-fixes).
- mlxsw: core: Add validation of transceiver temperature
  thresholds (git-fixes).
- net/mlx5e: Fix memleak in mlx5e_create_l2_table_groups
  (git-fixes).
- net/mlx5e: Fix two double free cases (git-fixes).
- net/mlx5: Use port_num 1 instead of 0 when delete a RoCE address
  (git-fixes).
- chtls: Fix chtls resources release sequence (git-fixes).
- chtls: Added a check to avoid NULL pointer dereference
  (git-fixes).
- chtls: Replace skb_dequeue with skb_peek (git-fixes).
- chtls: Fix panic when route to peer not configured (git-fixes).
- chtls: Remove invalid set_tcb call (git-fixes).
- chtls: Fix hardware tid leak (git-fixes).
- net: hns3: fix the number of queues actually used by ARQ
  (git-fixes).
- qed: select CONFIG_CRC32 (git-fixes).
- net: hns: fix return value check in __lb_other_process()
  (git-fixes).
- net: mvpp2: fix pkt coalescing int-threshold configuration
  (git-fixes).
- tun: fix return value when the number of iovs exceeds
  MAX_SKB_FRAGS (git-fixes).
- virtio_net: Fix recursive call to cpus_read_lock() (git-fixes).
- net: mvpp2: Fix GoP port 3 Networking Complex Control
  configurations (git-fixes).
- net: mvpp2: prs: fix PPPoE with ipv6 packet parse (git-fixes).
- net: mvpp2: Add TCAM entry to drop flow control pause frames
  (git-fixes).
- net: mvpp2: disable force link UP during port init procedure
  (git-fixes).
- iavf: fix double-release of rtnl_lock (git-fixes).
- i40e: Fix Error I40E_AQ_RC_EINVAL when removing VFs (git-fixes).
- virtio_net: Fix error code in probe() (git-fixes).
- ixgbe: avoid premature Rx buffer reuse (git-fixes).
- i40e: avoid premature Rx buffer reuse (git-fixes).
- net/mlx4_en: Handle TX error CQE (bsc#1181854).
- net/mlx4_en: Avoid scheduling restart task if it is already
  running (bsc#1181854).
- net/mlx5: Fix wrong address reclaim when command interface is
  down (git-fixes).
- net: mvpp2: Fix error return code in mvpp2_open() (git-fixes).
- chelsio/chtls: fix a double free in chtls_setkey() (git-fixes).
- cxgb3: fix error return code in t3_sge_alloc_qset() (git-fixes).
- net: broadcom CNIC: requires MMU (git-fixes).
- chelsio/chtls: fix panic during unload reload chtls (git-fixes).
- net: ena: set initial DMA width to avoid intel iommu issue
  (git-fixes).
- i40e: Fix removing driver while bare-metal VFs pass traffic
  (git-fixes).
- bnxt_en: Release PCI regions when DMA mask setup fails during
  probe (git-fixes).
- bnxt_en: fix error return code in bnxt_init_board() (git-fixes).
- bnxt_en: fix error return code in bnxt_init_one() (git-fixes).
- net/mlx4_core: Fix init_hca fields offset (git-fixes).
- net/mlx5: Disable QoS when min_rates on all VFs are zero
  (git-fixes).
- net/mlx5: Add handling of port type in rule deletion
  (git-fixes).
- mlxsw: core: Use variable timeout for EMAD retries (git-fixes).
- qed: fix error return code in qed_iwarp_ll2_start() (git-fixes).
- bnxt_en: read EEPROM A2h address using page 0 (git-fixes).
- net/mlx5: Fix deletion of duplicate rules (git-fixes).
- chelsio/chtls: fix always leaking ctrl_skb (git-fixes).
- chelsio/chtls: fix memory leaks caused by a race (git-fixes).
- chelsio/chtls: fix memory leaks in CPL handlers (git-fixes).
- chelsio/chtls: fix deadlock issue (git-fixes).
- cxgb4: set up filter action after rewrites (git-fixes).
- chelsio/chtls: fix tls record info to user (git-fixes).
- chelsio/chtls: correct function return and return type
  (git-fixes).
- chelsio/chtls: correct netdevice for vlan interface (git-fixes).
- chelsio/chtls: fix socket lock (git-fixes).
- commit f8ae7ea
* Thu Feb 11 2021 bp@suse.de
- blacklist.conf: 9ad22e165994 x86/debug: Fix DR6 handling
- commit b5c23b5
* Thu Feb 11 2021 jgross@suse.com
- xen/netback: avoid race in xenvif_rx_ring_slots_available()
  (bsc#1065600).
- commit b061a0d
* Thu Feb 11 2021 jgross@suse.com
- series.conf: cleanup
- update upstream references and move to sorted section:
  patches.suse/x86-xen-avoid-warning-in-Xen-pv-guest-with-CONFIG_AM.patch.
  patches.suse/xen-blkfront-allow-discard-nodes-to-be-optional.patch.
- commit 9ed652c
* Thu Feb 11 2021 oneukum@suse.com
- supported.conf: fix typo "!optoinal" should be "!optional"
- commit 154f90d
* Thu Feb 11 2021 tiwai@suse.de
- dmaengine: idxd: check device state before issue command
  (git-fixes).
- dmaengine: move channel device_node deletion to driver
  (git-fixes).
- dmaengine: idxd: fix misc interrupt completion (git-fixes).
- dmaengine: idxd: Fix list corruption in description completion
  (git-fixes).
- commit 21a74f3
* Thu Feb 11 2021 tiwai@suse.de
- mt76: dma: fix a possible memory leak in mt76_add_fragment()
  (git-fixes).
- commit 8ae7076
* Wed Feb 10 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/0002-x86-msi-Only-use-high-bits-of-MSI-address-for-DMAR-u.patch
  patches.suse/0003-x86-ioapic-Handle-Extended-Destination-ID-field-in-R.patch
  patches.suse/0004-x86-apic-Support-15-bits-of-APIC-ID-in-IOAPIC-MSI-wh.patch
  patches.suse/0005-x86-kvm-Add-KVM_FEATURE_MSI_EXT_DEST_ID.patch
- commit e28768c
* Wed Feb 10 2021 ohering@suse.de
- x86/hyperv: Initialize clockevents after LAPIC is initialized (git-fixes).
- commit 5954028
* Wed Feb 10 2021 tiwai@suse.de
- drm/i915: Fix the MST PBN divider calculation (git-fixes).
- drm/dp/mst: Export drm_dp_get_vc_payload_bw() (git-fixes).
- drm/i915/display: Prevent double YUV range correction on HDR
  planes (git-fixes).
- drm/i915: Power up combo PHY lanes for for HDMI as well
  (git-fixes).
- drm/i915: Extract intel_ddi_power_up_lanes() (git-fixes).
- commit 6a0d54e
* Wed Feb 10 2021 tiwai@suse.de
- USB: serial: option: Adding support for Cinterion MV31
  (git-fixes).
- USB: serial: cp210x: add pid/vid for WSDA-200-USB (git-fixes).
- USB: serial: cp210x: add new VID/PID for supporting Teraoka
  AD2000 (git-fixes).
- USB: usblp: don't call usb_set_interface if there's a single
  alt (git-fixes).
- Input: xpad - sync supported devices with fork on GitHub
  (git-fixes).
- mmc: core: Limit retries when analyse of SDIO tuples fails
  (git-fixes).
- drm/amd/display: Revert "Fix EDID parsing after resume from
  suspend" (git-fixes).
- mac80211: fix station rate table updates on assoc (git-fixes).
- iwlwifi: mvm: don't send RFH_QUEUE_CONFIG_CMD with no queues
  (git-fixes).
- commit 2244f3a
* Tue Feb  9 2021 pjakobsson@suse.de
- supported.conf: Mark habanalabs as supported (jsc#SLE-15232)
- commit c19a913
* Tue Feb  9 2021 dwagner@suse.de
- nvme: re-read ANA log on NS CHANGED AEN (bsc#1179137).
- commit d65941e
* Tue Feb  9 2021 mbrugger@suse.com
- KVM: arm64: Remove S1PTW check from kvm_vcpu_dabt_iswrite()
  (bsc#1181818).
- KVM: arm64: Assume write fault on S1PTW permission fault on
  instruction fetch (bsc#1181818).
- commit 9e58921
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: fix some return value check of
  cpsw_ale_create() (git-fixes).
- commit c1f82b5
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net/mlx5e: Correctly handle changing the number of queues when
  the interface is down (git-fixes).
- commit 2e18a60
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: ale: fix allmulti for nu type ale
  (git-fixes).
- commit 1455e82
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: ale: ensure vlan/mdb deleted when no members
  (git-fixes).
- commit 6a115f1
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: ale: modify vlan/mdb api for switchdev
  (git-fixes).
- Refresh
  patches.suse/0009-net-ethernet-ti-ale-fix-seeing-unreg-mcast-packets-w.patch.
- commit 0cae8d9
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: cpsw: allow untagged traffic on host port
  (git-fixes).
- commit da85a01
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: ale: fix seeing unreg mcast packets with
  promisc and allmulti disabled (git-fixes).
- commit 6a2d8f8
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net/mlx5e: Fix configuration of XPS cpumasks and netdev queues
  in corner cases (git-fixes).
- Refresh
  patches.suse/net-mlx5e-Fix-CPU-mapping-after-function-reload-to-a.patch.
- commit ae37f4a
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net/mlx5e: Use preactivate hook to set the indirection table
  (git-fixes).
- commit a8003a3
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net/mlx5e: Rename hw_modify to preactivate (git-fixes).
- commit d8b9674
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net/mlx5e: Encapsulate updating netdev queues into a function
  (git-fixes).
- commit 0764cbf
* Tue Feb  9 2021 denis.kirjanov@suse.com
- sh_eth: check sh_eth_cpu_data::no_xdfar when dumping registers
  (git-fixes).
- commit ccdc470
* Tue Feb  9 2021 denis.kirjanov@suse.com
- sh_eth: check sh_eth_cpu_data::cexcr when dumping registers
  (git-fixes).
- commit 855923f
* Tue Feb  9 2021 denis.kirjanov@suse.com
- sh_eth: check sh_eth_cpu_data::no_tx_cntrs when dumping
  registers (git-fixes).
- commit 1115b43
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: dsa: mt7530: Change the LINK bit to reflect the link status
  (git-fixes).
- commit 7c5ca65
* Tue Feb  9 2021 msuchanek@suse.de
- powerpc/pseries/dlpar: handle ibm, configure-connector delay
  status (bsc#1181985 ltc#188074).
- commit 418b81d
* Tue Feb  9 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference:
  patches.suse/ibmvnic-Clear-failover_pending-if-unable-to-schedule.patch
- commit 85f2019
* Tue Feb  9 2021 mkubecek@suse.cz
- fix patch metadata
- fix upstream reference:
  patches.suse/io_uring-Fix-current-fs-handling-in-io_sq_wq_submit_.patch
- commit 90ec2ae
* Tue Feb  9 2021 jeyu@suse.de
- Rename duplicate patches to their SLE15-SP2 equivalents.
  This is to prepare for the next SLE15-SP2 -> SLE15-SP3 merge.
- commit a7157b9
* Tue Feb  9 2021 dwagner@suse.de
- scsi: lpfc: Fix EEH encountering oops with NVMe traffic
  (bsc#1181958).
- commit 5afe23b
* Tue Feb  9 2021 tbogendoerfer@suse.de
- net/mlx5e: Release skb in case of failure in tc update skb
  (jsc#SLE-15172).
- net/mlx5: Fix leak upon failure of rule creation
  (jsc#SLE-15172).
- commit 67867c6
* Tue Feb  9 2021 tiwai@suse.de
- supported.conf: Add armv7hl entries (jsc#SLE-17212)
- commit 87b18a9
* Tue Feb  9 2021 glin@suse.com
- selftests/bpf: Fix unused attribute usage in subprogs_unused
  test (bsc#1177028).
- libbpf: Fix potential multiplication overflow (bsc#1177028).
- libbpf: Fix another __u64 cast in printf (bsc#1177028).
- libbpf: Fix compilation warnings for 64-bit printf args
  (bsc#1177028).
- libbpf: Fix type compatibility check copy-paste error
  (bsc#1177028).
- libbpf: Fix libbpf build on compilers missing
  __builtin_mul_overflow (bsc#1177028).
- libbpf: Implement enum value-based CO-RE relocations
  (bsc#1177028).
- commit 76c0289
* Mon Feb  8 2021 msuchanek@suse.de
- powerpc/64/signal: Fix regression in __kernel_sigtramp_rt64()
  semantics (jsc#SLE-9246).
- powerpc/64s: prevent recursive replay_soft_interrupts causing
  superfluous interrupt (jsc#SLE-9246).
- commit 2c2e4e4
* Mon Feb  8 2021 msuchanek@suse.de
- Refresh patches.suse/powerpc-sstep-Fix-array-out-of-bound-warning.patch.
  Update metadata
- commit 8349f78
* Mon Feb  8 2021 msuchanek@suse.de
- powerpc/perf: Exclude kernel samples while counting events in
  user space (bsc#1065729).
- commit 50bd42d
* Mon Feb  8 2021 msuchanek@suse.de
- powerpc: Fix alignment bug within the init sections
  (bsc#1065729).
- commit 7810647
* Mon Feb  8 2021 msuchanek@suse.de
- powerpc/powernv/npu: Do not attempt NPU2 setup on POWER8NVL NPU
  (bsc#1156395).
- powerpc/powernv/memtrace: Fix crashing the kernel when enabling
  concurrently (bsc#1156395).
- powerpc/powernv/memtrace: Don't leak kernel memory to user space
  (bsc#1156395).
- powerpc/fpu: Drop cvt_fd() and cvt_df() (bsc#1156395).
- powerpc/boot: Delete unneeded .globl _zimage_start
  (bsc#1156395).
- commit 735e425
* Mon Feb  8 2021 msuchanek@suse.de
- ibmvnic: device remove has higher precedence over reset
  (bsc#1065729).
- commit 0b8e9f9
* Mon Feb  8 2021 msuchanek@suse.de
- ibmvnic: fix login buffer memory leak (bsc#1081134 ltc#164631).
- commit 5b8c72b
* Mon Feb  8 2021 msuchanek@suse.de
- ibmvnic: Clear failover_pending if unable to schedule
  (bsc#1181960 ltc#190997).
- commit fb1a56e
* Mon Feb  8 2021 tiwai@suse.de
- ACPI: thermal: Do not call acpi_thermal_check() directly
  (git-fixes).
- Refresh patches.suse/acpi_thermal_passive_blacklist.patch.
- commit 1cfdad3
* Mon Feb  8 2021 tiwai@suse.de
- genirq/msi: Activate Multi-MSI early when
  MSI_FLAG_ACTIVATE_EARLY is set (git-fixes).
- drm/amd/display: Fixed corruptions on HPDRX link loss restore
  (git-fixes).
- drm/amd/display: Use hardware sequencer functions for PG control
  (git-fixes).
- drm/amd/display: Allow PSTATE chnage when no displays are
  enabled (git-fixes).
- mac80211: fix incorrect strlen of .write in debugfs (git-fixes).
- drm/amd/display: Update dram_clock_change_latency for DCN2.1
  (git-fixes).
- drm/panfrost: Support cache-coherent integrations (git-fixes).
- commit c563f5a
* Mon Feb  8 2021 tiwai@suse.de
- phy: cpcap-usb: Fix warning for missing regulator_disable
  (git-fixes).
- platform/x86: intel-vbtn: Support for tablet mode on Dell
  Inspiron 7352 (git-fixes).
- platform/x86: touchscreen_dmi: Add swap-x-y quirk for Goodix
  touchscreen on Estar Beauty HD tablet (git-fixes).
- drm/amd/display: Change function decide_dp_link_settings to
  avoid infinite looping (git-fixes).
- mac80211: fix fast-rx encryption check (git-fixes).
- commit 504e3c0
* Mon Feb  8 2021 oneukum@suse.com
- blacklist.conf: kABI extreely hard to work around
- commit e1f9604
* Mon Feb  8 2021 ptesarik@suse.cz
- platform/x86: pmt: Fix a potential Oops on error in probe
  (jsc#SLE-13352, jsc#SLE-13343, jsc#SLE-13363, jsc#SLE-13391).
- commit e21ef02
* Mon Feb  8 2021 ptesarik@suse.cz
- platform/x86: Intel PMT Crashlog capability driver
  (jsc#SLE-13352, jsc#SLE-13343, jsc#SLE-13363, jsc#SLE-13391).
- Update config files: Build PMT Crashlog capability driver.
- supported.conf: Add the PMT Crashlog capability driver.
- commit 0f2da12
* Mon Feb  8 2021 ptesarik@suse.cz
- platform/x86: Intel PMT Telemetry capability driver
  (jsc#SLE-13352, jsc#SLE-13343, jsc#SLE-13363, jsc#SLE-13391).
- Update config files: Build PMT Telemetry capability driver.
- supported.conf: Add the PMT Telemetry capability driver.
- commit e0ffba9
* Mon Feb  8 2021 ptesarik@suse.cz
- platform/x86: Intel PMT class driver (jsc#SLE-13352,
  jsc#SLE-13343, jsc#SLE-13363, jsc#SLE-13391).
- Update config files: Build PMT class driver.
- supported.conf: Add the PMT class driver.
- commit 22095e8
* Mon Feb  8 2021 mbenes@suse.cz
- objtool: Don't fail on missing symbol table (bsc#1169514).
- commit 1518505
* Mon Feb  8 2021 ptesarik@suse.cz
- mfd: Intel Platform Monitoring Technology support
  (jsc#SLE-13352, jsc#SLE-13343, jsc#SLE-13363, jsc#SLE-13391).
- Update config files: Build PMT driver on x86_64.
- supported.conf: Add the PMT driver.
- commit be0482a
* Mon Feb  8 2021 ptesarik@suse.cz
- PCI: Add defines for Designated Vendor-Specific Extended
  Capability (jsc#SLE-13352, jsc#SLE-13343, jsc#SLE-13363,
  jsc#SLE-13391).
- commit 8eb1abf
* Mon Feb  8 2021 nborisov@suse.com
- btrfs: Fix race between extent freeing/allocation when using bitmaps (bsc#1181574).
- commit 98010f2
* Mon Feb  8 2021 glin@suse.com
- libbpf: Don't attempt to load unused subprog as an entry-point
  BPF program (bsc#1177028).
- libbpf: Add multi-prog section support for struct_ops
  (bsc#1177028).
- libbpf: Implement generalized .BTF.ext func/line info adjustment
  (bsc#1177028).
- libbpf: Make RELO_CALL work for multi-prog sections and
  sub-program calls (bsc#1177028).
- libbpf: Support CO-RE relocations for multi-prog sections
  (bsc#1177028).
- libbpf: Parse multi-function sections into multiple BPF programs
  (bsc#1177028).
- libbpf: Ensure ELF symbols table is found before further ELF
  processing (bsc#1177028).
- libbpf: Normalize and improve logging across few functions
  (bsc#1177028).
- libbpf: Skip well-known ELF sections when iterating ELF
  (bsc#1177028).
- libbpf: Factor out common ELF operations and improve logging
  (bsc#1177028).
- libbpf: Implement type-based CO-RE relocations support
  (bsc#1177028).
- libbpf: Centralize poisoning and poison reallocarray()
  (bsc#1177028).
- tools/bpftool: Remove libbpf_internal.h usage in bpftool (bsc#1177028).
  Refresh patches.suse/bpftool-Fix-compilation-failure-for-net.o-with-older.patch
- libbpf: Remove any use of reallocarray() in libbpf
  (bsc#1177028).
- libbpf: Improve relocation ambiguity detection (bsc#1177028).
- libbpf: Clean up and improve CO-RE reloc logging (bsc#1177028).
- libbpf: Improve error logging for mismatched BTF kind cases
  (bsc#1177028).
- libbpf: Detect minimal BTF support and skip BTF loading,
  if missing (bsc#1177028).
- libbpf: Factor out common logic of testing and closing FD
  (bsc#1177028).
- libbpf: Make kernel feature probing lazy (bsc#1177028).
- libbpf: Disable -Wswitch-enum compiler warning (bsc#1177028).
- libbpf: Convert comma to semicolon (bsc#1177028).
- commit dc05c31
* Sun Feb  7 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references of unsortable patches and sort them properly:
  patches.suse/perf-x86-intel-uncore-Store-the-logical-die-id-inste.patch
  patches.suse/perf-x86-intel-uncore-With-8-nodes-get-pci-bus-die-i.patch
- commit b4f0fcb
* Sun Feb  7 2021 mkubecek@suse.cz
- fix patch metadata and move it to correct section
- fix upstream reference of a non-mainline patch and move to correct section:
  patches.suse/net-sctp-filter-remap-copy_from_user-failure-error.patch
- commit fda606d
* Sun Feb  7 2021 tiwai@suse.de
- usb: xhci-mtk: break loop when find the endpoint to drop
  (git-fixes).
- commit bd7c89a
* Sun Feb  7 2021 tiwai@suse.de
- usb: xhci-mtk: skip dropping bandwidth of unchecked endpoints
  (git-fixes).
- commit 1a31126
* Sun Feb  7 2021 tiwai@suse.de
- usb: xhci-mtk: fix unreleased bandwidth data (git-fixes).
- commit 6da0a12
* Sun Feb  7 2021 tiwai@suse.de
- usb: dwc2: Fix endpoint direction check in ep_from_windex
  (git-fixes).
- usb: dwc3: fix clock issue during resume in OTG mode
  (git-fixes).
- xhci: fix bounce buffer usage for non-sg list case (git-fixes).
- usb: renesas_usbhs: Clear pipe running flag in usbhs_pkt_pop()
  (git-fixes).
- USB: gadget: legacy: fix an error code in eth_bind()
  (git-fixes).
- Input: i8042 - unbreak Pegatron C15B (git-fixes).
- commit bcaeec1
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: qca_spi: Move reset_count to struct qcaspi (git-fixes).
- commit 45b7fef
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: qca_spi: fix receive buffer size check (git-fixes).
- commit 5cd7e42
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: stmmac: fix disabling flexible PPS output (git-fixes).
- commit 20dce33
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: stmmac: fix length of PTP clock's name string (git-fixes).
- commit 9f89a73
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: phy: at803x: use operating parameters from PHY-specific
  status (git-fixes).
- commit e91964f
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: phy: extract pause mode (git-fixes).
- commit c81698a
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: phy: extract link partner advertisement reading
  (git-fixes).
- commit 18dc97f
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: phy: read MII_CTRL1000 in genphy_read_status only if needed
  (git-fixes).
- commit d5eb04d
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: stmmac: selftests: Flow Control test can also run with
  ASYM Pause (git-fixes).
- commit 26dfc56
* Sat Feb  6 2021 denis.kirjanov@suse.com
- cirrus: cs89x0: remove set but not used variable 'lp'
  (git-fixes).
- commit 0385a3f
* Sat Feb  6 2021 denis.kirjanov@suse.com
- cirrus: cs89x0: use devm_platform_ioremap_resource() to simplify
  code (git-fixes).
- commit f75aac5
* Sat Feb  6 2021 denis.kirjanov@suse.com
- blacklist.conf: update blacklist
- commit ca67b2c
* Fri Feb  5 2021 tabraham@suse.com
- perf/x86/intel/uncore: With > 8 nodes, get pci bus die id from
  NUMA info (bsc#1180989).
- perf/x86/intel/uncore: Store the logical die id instead of
  the physical die id (bsc#1180989).
- perf/x86/intel/uncore: Generic support for the PCI sub driver
  (bsc#1180989).
- perf/x86/intel/uncore: Factor out uncore_pci_pmu_unregister()
  (bsc#1180989).
- perf/x86/intel/uncore: Factor out uncore_pci_pmu_register()
  (bsc#1180989).
- perf/x86/intel/uncore: Factor out uncore_pci_find_dev_pmu()
  (bsc#1180989).
- perf/x86/intel/uncore: Factor out uncore_pci_get_dev_die_info()
  (bsc#1180989).
- commit 6e81128
* Fri Feb  5 2021 tabraham@suse.com
- perf/x86/intel/uncore: With > 8 nodes, get pci bus die id from
  NUMA info (bsc#1180989).
- perf/x86/intel/uncore: Store the logical die id instead of
  the physical die id (bsc#1180989).
- commit 67d84dd
* Fri Feb  5 2021 tiwai@suse.de
- gpiolib: fix gpio_do_set_config() (bsc#1180682).
- Refresh
  patches.suse/gpiolib-Extract-gpio_set_config_with_argument-for-fu.patch.
- Refresh
  patches.suse/gpiolib-Introduce-gpio_set_debounce_timeout-for-inte.patch.
- Refresh
  patches.suse/gpiolib-use-proper-API-to-pack-pin-configuration-par.patch.
- commit 11e6d6f
* Fri Feb  5 2021 tiwai@suse.de
- gpiolib: acpi: Fix fall-through warnings for Clang
  (bsc#1180682).
- gpiolib: split error path in gpiod_request_commit()
  (bsc#1180682).
- gpiolib: Unify expectations about ->request() returned value
  (bsc#1180682).
- gpiolib: Extract gpiod_not_found() helper (bsc#1180682).
- gpio: just plain warning when nonexisting gpio requested
  (bsc#1180682).
- gpiolib: acpi: Use BIT() macro to increase readability
  (bsc#1180682).
- gpiolib: acpi: Convert pin_index to be u16 (bsc#1180682).
- gpiolib: acpi: Extract acpi_request_own_gpiod() helper
  (bsc#1180682).
- gpiolib: acpi: Make acpi_gpio_to_gpiod_flags() usable for
  GpioInt() (bsc#1180682).
- gpiolib: acpi: Set initial value for output pin based on bias
  and polarity (bsc#1180682).
- gpiolib: acpi: Move acpi_gpio_to_gpiod_flags() upper in the code
  (bsc#1180682).
- gpiolib: acpi: Move non-critical code outside of critical
  section (bsc#1180682).
- gpiolib: acpi: Take into account debounce settings
  (bsc#1180682).
- gpiolib: acpi: Use named item for enum gpiod_flags variable
  (bsc#1180682).
- gpiolib: acpi: Respect bias settings for GpioInt() resource
  (bsc#1180682).
- gpiolib: Introduce gpio_set_debounce_timeout() for internal use
  (bsc#1180682).
- gpiolib: Extract gpio_set_config_with_argument_optional()
  helper (bsc#1180682).
- gpiolib: Extract gpio_set_config_with_argument() for future use
  (bsc#1180682).
- gpiolib: use proper API to pack pin configuration parameters
  (bsc#1180682).
- gpiolib: add missed break statement (bsc#1180682).
- gpiolib: have a single place of calling set_config()
  (bsc#1180682).
- gpiolib: use 'unsigned int' instead of 'unsigned' in
  gpio_set_config() (bsc#1180682).
- commit da451fd
* Fri Feb  5 2021 ykaukab@suse.de
- bus: fsl-mc: add autorescan sysfs (jsc#SLE-12251).
- bus: fsl-mc: add bus rescan attribute (jsc#SLE-12251).
- bus: fsl-mc: add fsl-mc userspace support (jsc#SLE-12251).
- bus: fsl-mc: export mc_cmd_hdr_read_cmdid() to the fsl-mc bus
  (jsc#SLE-12251).
- bus: fsl-mc: move fsl_mc_command struct in a uapi header
  (jsc#SLE-12251).
- bus: fsl-mc: return -EPROBE_DEFER when a device is not yet
  discovered (jsc#SLE-12251).
- bus: fsl-mc: add missing __iomem attribute (jsc#SLE-12251).
- commit 21968ee
* Fri Feb  5 2021 tbogendoerfer@suse.de
- bonding: wait for sysfs kobject destruction before freeing
  struct slave (git-fixes).
- net/mlx5: E-Switch, Use vport metadata matching by default
  (git-fixes).
- cxgb4: fix all-mask IP address comparison (git-fixes).
- cxgb4: fix set but unused variable when DCB is disabled
  (git-fixes).
- commit 8f53029
* Fri Feb  5 2021 ykaukab@suse.de
- Refresh
  patches.suse/coresight-etm4x-Skip-setting-LPOVERRIDE-bit-for-qcom.patch.
- commit 6434185
* Fri Feb  5 2021 ykaukab@suse.de
- Refresh
  patches.suse/spi-fsl-dspi-fix-wrong-pointer-in-suspend-resume.patch.
- commit 78ee3ab
* Fri Feb  5 2021 glin@suse.com
- bpf: Fix a verifier failure with xor (bsc#1177028).
- selftests/bpf: Enable tc verbose mode for test_sk_assign
  (bsc#1177028).
- commit 0e68af0
* Fri Feb  5 2021 glin@suse.com
- bpf, cgroup: Fix problematic bounds check (bsc#1155518).
- bpf, cgroup: Fix optlen WARN_ON_ONCE toctou (bsc#1155518).
- commit 3ab5222
* Fri Feb  5 2021 glin@suse.com
- net, sctp, filter: remap copy_from_user failure error
  (bsc#1181637).
- commit 32551e1
* Thu Feb  4 2021 tbogendoerfer@suse.de
- i40e: Revert "i40e: don't report link up for a VF who hasn't
  enabled queues" (jsc#SLE-8025).
- igc: Fix returning wrong statistics (git-fixes).
- i40e: Fix MAC address setting for a VF via Host/VM (git-fixes).
- mlxsw: core: Fix use-after-free in mlxsw_emad_trans_finish()
  (git-fixes).
- mlxsw: core: Fix memory leak on module removal (git-fixes).
- net/mlx5: Don't call timecounter cyc2time directly from 1PPS
  flow (git-fixes).
- net: ethernet: mlx4: Avoid assigning a value to ring_cons but
  not used it anymore in mlx4_en_xmit() (git-fixes).
- net: team: fix memory leak in __team_options_register
  (git-fixes).
- net/mlx5e: Fix VLAN create flow (git-fixes).
- net/mlx5e: Fix VLAN cleanup flow (git-fixes).
- net/mlx5: Fix request_irqs error flow (git-fixes).
- mlxsw: spectrum_acl: Fix mlxsw_sp_acl_tcam_group_add()'s error
  path (git-fixes).
- team: set dev->needed_headroom in team_setup_by_port()
  (git-fixes).
- bonding: set dev->needed_headroom in bond_setup_by_slave()
  (git-fixes).
- net: qed: RDMA personality shouldn't fail VF load (git-fixes).
- net: thunderx: initialize VF's mailbox mutex before first usage
  (git-fixes).
- net: mvpp2: fix memory leak in mvpp2_rx (git-fixes).
- iavf: Fix updating statistics (git-fixes).
- iavf: fix error return code in iavf_init_get_resources()
  (git-fixes).
- net/mlx5e: vxlan: Use RCU for vxlan table lookup (git-fixes).
- vxlan: fix memleak of fdb (git-fixes).
- net/mlx5e: fix bpf_prog reference count leaks in mlx5e_alloc_rq
  (git-fixes).
- mlxsw: core: Free EMAD transactions using kfree_rcu()
  (git-fixes).
- mlxsw: core: Increase scope of RCU read-side critical section
  (git-fixes).
- net/mlx5: Query PPS pin operational status before registering it
  (git-fixes).
- net/mlx5: Verify Hardware supports requested ptp function on
  a given pin (git-fixes).
- net/mlx5: Fix a bug of using ptp channel index as pin index
  (git-fixes).
- net/mlx5e: Fix error path of device attach (git-fixes).
- net/mlx5: E-switch, Destroy TSAR after reload interface
  (git-fixes).
- net: hns3: fix aRFS FD rules leftover after add a user FD rule
  (git-fixes).
- net: hns3: fix a TX timeout issue (git-fixes).
- net: hns3: fix desc filling bug when skb is expanded or lineared
  (git-fixes).
- qed: Populate nvm-file attributes while reading nvm config
  partition (git-fixes).
- net: hns3: fix use-after-free when doing self test (git-fixes).
- net: hns3: add a missing uninit debugfs when unload driver
  (git-fixes).
- net: cxgb4: fix return error value in t4_prep_fw (git-fixes).
- cxgb4vf: update kernel-doc line comments (git-fixes).
- cxgb4: update kernel-doc line comments (git-fixes).
- cxgb4: move DCB version extern to header file (git-fixes).
- cxgb4: remove cast when saving IPv4 partial checksum
  (git-fixes).
- cxgb4: fix SGE queue dump destination buffer context
  (git-fixes).
- cxgb4: use correct type for all-mask IP address comparison
  (git-fixes).
- cxgb4: fix endian conversions for L4 ports in filters
  (git-fixes).
- cxgb4: parse TC-U32 key values and masks natively (git-fixes).
- cxgb4: use unaligned conversion for fetching timestamp
  (git-fixes).
- cxgb4: move PTP lock and unlock to caller in Tx path
  (git-fixes).
- cxgb4: move handling L2T ARP failures to caller (git-fixes).
- net: qed: fix "maybe uninitialized" warning (git-fixes).
- net: qede: fix use-after-free on recovery and AER handling
  (git-fixes).
- net: qede: fix PTP initialization on recovery (git-fixes).
- net: qed: fix excessive QM ILT lines consumption (git-fixes).
- net: qed: fix NVMe login fails over VFs (git-fixes).
- net: qede: stop adding events on an already destroyed workqueue
  (git-fixes).
- net: qed: fix async event callbacks unregistering (git-fixes).
- iavf: fix speed reporting over virtchnl (git-fixes).
- net/mlx5e: IPoIB, Drop multicast packets that this interface
  sent (git-fixes).
- ixgbe: Fix XDP redirect on archs with PAGE_SIZE above 4K
  (git-fixes).
- veth: Adjust hard_start offset on redirect XDP frames
  (git-fixes).
- net/mlx5e: Set of completion request bit should not clear
  other adjacent bits (git-fixes).
- net/mlx5e: en_accel, Add missing net/geneve.h include
  (git-fixes).
- bonding: Fix reference count leak in bond_sysfs_slave_add
  (git-fixes).
- bnxt_en: Fix accumulation of bp->net_stats_prev (git-fixes).
- net/mlx5: Annotate mutex destroy for root ns (git-fixes).
- net/mlx5: Don't maintain a case of del_sw_func being null
  (git-fixes).
- net/mlx4_core: fix a memory leak bug (git-fixes).
- mlxsw: spectrum: Fix use-after-free of split/unsplit/type_set
  in case reload fails (git-fixes).
- net/mlx5e: Get the latest values from counters in switchdev mode
  (git-fixes).
- net/mlx5e: Don't trigger IRQ multiple times on XSK wakeup to
  avoid WQ overruns (git-fixes).
- net/mlx5: Fix failing fw tracer allocation on s390 (git-fixes).
- net/cxgb4: Check the return from t4_query_params properly
  (git-fixes).
- net: hns3: fix set and get link ksettings issue (git-fixes).
- net: hns3: fix RSS config lost after VF reset (git-fixes).
- qed: Fix race condition between scheduling and destroying the
  slowpath workqueue (git-fixes).
- net/mlx5: E-Switch, Hold mutex when querying drop counter in
  legacy mode (git-fixes).
- net/mlx5: E-Switch, Use vport metadata matching only when
  mandatory (git-fixes).
- net/liquidio: Delete non-working LIQUIDIO_PACKAGE check
  (git-fixes).
- virtio_net: Keep vnet header zeroed if XDP is loaded for small
  buffer (git-fixes).
- net/mlx5: Clear LAG notifier pointer after unregister
  (git-fixes).
- net/mlx5e: Fix endianness handling in pedit mask (git-fixes).
- net/mlx5e: kTLS, Fix wrong value in record tracker enum
  (git-fixes).
- net: hns3: clear port base VLAN when unload PF (git-fixes).
- net: hns3: fix VF VLAN table entries inconsistent issue
  (git-fixes).
- net: hns3: fix "tc qdisc del" failed issue (git-fixes).
- cxgb4: fix checks for max queues to allocate (git-fixes).
- commit a805d8f
* Thu Feb  4 2021 oneukum@suse.com
- Update config files. Switch on DWC3 on x86_64
  (jsc#SLE-14042)
- commit 1a0a5a5
* Thu Feb  4 2021 tiwai@suse.de
- Another fix of the missing merge commit hunk in idxd dma driver (bsc#1181795)
- commit 4b7e5ed
* Thu Feb  4 2021 tiwai@suse.de
- Fix the missing change via the upstream merge commit for idxd dma driver (bsc#1181795)
- commit e5ace2b
* Thu Feb  4 2021 tiwai@suse.de
- dmaengine: idxd: add missing invalid flags field to completion
  (bsc#1181795).
- dmaengine: idxd: fix hw descriptor fields for delta record
  (bsc#1181795).
- commit fb2caf6
* Thu Feb  4 2021 bp@suse.de
- blacklist.conf: Blacklist two 32-bit only fixes
  50fe7ebb6475 bpf, x86_32: Fix clobbering of dst for BPF_JSET
  5ca1ca01fae1 bpf, x86_32: Fix logic error in BPF_LDX zero-extension
- commit 55cadfc
* Thu Feb  4 2021 dwagner@suse.de
- nvme-multipath: Early exit if no path is available
  (bsc#1180964).
- commit 1c96465
* Thu Feb  4 2021 jroedel@suse.de
- kABI: Fix kABI after AMD SEV PCID fixes (bsc#1178995).
- commit bf72ec9
* Thu Feb  4 2021 tiwai@suse.de
- ahci: Add Intel Emmitsburg PCH RAID PCI IDs (jsc#SLE-14457).
- commit a78ee51
* Thu Feb  4 2021 tiwai@suse.de
- iwlwifi: pcie: remove obsolete pre-release support code
  (git-fixes).
- iwlwifi: pcie: add some missing entries for AX210 (git-fixes).
- iwlwifi: support an additional Qu subsystem id (git-fixes).
- iwlwifi: add new card for MA family (git-fixes).
- iwlwifi: iwl-trans: move all txcmd init to trans alloc
  (git-fixes).
- commit 133d60e
* Thu Feb  4 2021 tiwai@suse.de
- iwlwifi: Fix IWL_SUBDEVICE_NO_160 macro to use the correct bit
  (git-fixes).
- iwlwifi: pcie: add rules to match Qu with Hr2 (git-fixes).
- iwlwifi: Add a new card for MA family (git-fixes).
- iwlwifi: follow the new inclusive terminology (git-fixes).
- iwlwifi: pcie: fix xtal latency for 9560 devices (git-fixes).
- iwlwifi: pcie: fix 0x271B and 0x271C trans cfg struct
  (git-fixes).
- iwlwifi: add new cards for MA family (git-fixes).
- iwlwifi: add new cards for AX201 family (git-fixes).
- commit 050b58f
* Thu Feb  4 2021 tiwai@suse.de
- gpio: gpiolib: remove shadowed variable (git-fixes).
- drm/i915/gt: Always try to reserve GGTT address 0x0 (git-fixes).
- iwlwifi: pcie: set LTR on more devices (git-fixes).
- commit d7ad942
* Thu Feb  4 2021 tiwai@suse.de
- mac80211: pause TX while changing interface type (git-fixes).
- wext: fix NULL-ptr-dereference with cfg80211's lack of commit()
  (git-fixes).
- iwlwifi: pcie: reschedule in long-running memory reads
  (git-fixes).
- iwlwifi: pcie: use jiffies for memory read spin time limit
  (git-fixes).
- net: usb: qmi_wwan: added support for Thales Cinterion PLSx3
  modem family (git-fixes).
- drivers: soc: atmel: add null entry at the end of
  at91_soc_allowed_list[] (git-fixes).
- drivers: soc: atmel: Avoid calling at91_soc_init on non AT91
  SoCs (git-fixes).
- commit 023b5c2
* Thu Feb  4 2021 glin@suse.com
- perf: Make struct ring_buffer less ambiguous (bsc#1177028).
  Refresh patches.suse/0001-perf-core-Fix-race-in-the-perf_mmap_close-function.patch.
- commit 5dfb979
* Thu Feb  4 2021 msuchanek@suse.de
- powerpc/mm/pkeys: Make pkey access check work on execute_only_key
  (bsc#1181544 ltc#191080 git-fixes).
- Refresh patches.suse/powerpc-book3s64-pkeys-Fix-pkey_access_permitted-for.patch.
- commit 7508356
* Wed Feb  3 2021 tiwai@suse.de
- rpm/kernel-binary.spec.in: Correct Supplements in optional subpkg (jsc#SLE-11796)
  The product string was changed from openSUSE to Leap.
- commit 3cb7943
* Wed Feb  3 2021 msuchanek@suse.de
- powerpc/pkeys: Check vma before returning key fault error to
  the user (bsc#1181544 ltc#191080).
- powerpc/pkeys: Avoid using lockless page table walk (bsc#1181544
  ltc#191080).
- commit 8cb9fab
* Wed Feb  3 2021 denis.kirjanov@suse.com
- net/mlx5: Fix function calculation for page trees (git-fixes).
- commit 22c3016
* Wed Feb  3 2021 nsaenzjulienne@suse.de
- net: fec: put child node on error path (git-fixes).
- commit cbac658
* Wed Feb  3 2021 nsaenzjulienne@suse.de
- ARM: imx: fix imx8m dependencies (git-fixes).
- soc: imx: select ARM_GIC_V3 for i.MX8M (git-fixes).
- commit adb9b1b
* Wed Feb  3 2021 pjakobsson@suse.de
- Add no-fix tag to drm cherry-picks
  Add a no-fix tag to drm patches that are cherry-picks and are not
  already blacklisted.
- Refresh
  patches.suse/0001-drm-i915-Preload-LUTs-if-the-hw-isn-t-currently-usin.patch.
- Refresh
  patches.suse/0001-drm-i915-Update-drm-i915-bug-filing-URL.patch.
- Refresh
  patches.suse/0001-drm-i915-execlists-Always-force-a-context-reload-whe.patch.
- Refresh
  patches.suse/0001-drm-i915-icl-Fix-hotplug-interrupt-disabling-after-s.patch.
- Refresh
  patches.suse/0003-drm-i915-Correctly-set-SFC-capability-for-video-engi.patch.
- Refresh
  patches.suse/0029-drm-i915-gem-Avoid-implicit-vmap-for-highmem-on-x86-.patch.
- Refresh
  patches.suse/drm-i915-Perform-GGTT-restore-much-earlier-during-re.patch.
- Refresh
  patches.suse/drm-i915-Whitelist-COMMON_SLICE_CHICKEN2.patch.
- Refresh
  patches.suse/drm-i915-pmu-Frequency-is-reported-as-accumulated-cy.patch.
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- Refresh
  patches.suse/drm-i915-update-rawclk-also-on-resume.patch.
- Refresh
  patches.suse/drm-i915-userptr-Never-allow-userptr-into-the-mappab.patch.
- commit 46ba73b
* Wed Feb  3 2021 jroedel@suse.de
- KVM: SVM: Update cr3_lm_rsvd_bits for AMD SEV guests
  (bsc#1178995).
- KVM: x86: Introduce cr3_lm_rsvd_bits in kvm_vcpu_arch
  (bsc#1178995).
- commit 49749c4
* Wed Feb  3 2021 tiwai@suse.de
- r8169: work around RTL8125 UDP hw bug (git-fixes).
- commit db42a5b
* Wed Feb  3 2021 tiwai@suse.de
- r8169: fix WoL on shutdown if CONFIG_DEBUG_SHIRQ is set
  (git-fixes).
- commit ab82b36
* Wed Feb  3 2021 mkubecek@suse.cz
- Update kabi files.
- update from February 2021 maintenance update submission (commit 1e925eb08318)
- commit 97b2a1f
* Tue Feb  2 2021 msuchanek@suse.de
- powerpc: kABI: add back suspend_disable_cpu in machdep_calls
  (bsc#1181674 ltc#189159).
- commit 09376cb
* Tue Feb  2 2021 rgoldwyn@suse.com
- exfat: Avoid allocating upcase table using kcalloc()
  (git-fixes).
- exec: Always set cap_ambient in cap_bprm_set_creds  (git-fixes).
- commit eb2e605
* Tue Feb  2 2021 ptesarik@suse.cz
- s390/dasd: Fix inconsistent kobject removal (jsc#SLE-13767
  bsc#1178420 LTC#185092).
- commit e13d81a
* Tue Feb  2 2021 nstange@suse.de
- io_uring: Fix current->fs handling in io_sq_wq_submit_work()
  (bsc#1179434 CVE-2020-29373).
- commit 3f561ee
* Tue Feb  2 2021 ptesarik@suse.cz
- blacklist.conf: no change to /sys/firmware/uv/query/max_cpus
- commit 737a803
* Tue Feb  2 2021 ptesarik@suse.cz
- s390/vfio-ap: No need to disable IRQ after queue reset
  (git-fixes).
- s390/vfio-ap: clean up vfio_ap resources when KVM pointer
  invalidated (git-fixes).
- commit d91ae22
* Tue Feb  2 2021 msuchanek@suse.de
- powerpc/pseries/mobility: refactor node lookup during DT update
  (bsc#1181674 ltc#189159).
- powerpc/rtas: remove unused rtas_suspend_me_data (bsc#1181674
  ltc#189159).
- powerpc/pseries/hibernation: remove prepare_late() callback
  (bsc#1181674 ltc#189159).
- powerpc/pseries/hibernation: perform post-suspend fixups later
  (bsc#1181674 ltc#189159).
- powerpc/rtas: remove unused rtas_suspend_last_cpu() (bsc#1181674
  ltc#189159).
- powerpc/pseries/hibernation: switch to rtas_ibm_suspend_me()
  (bsc#1181674 ltc#189159).
- powerpc/rtas: remove rtas_suspend_cpu() (bsc#1181674
  ltc#189159).
- powerpc/machdep: remove suspend_disable_cpu() (bsc#1181674
  ltc#189159).
- powerpc/pseries/hibernation: remove pseries_suspend_cpu()
  (bsc#1181674 ltc#189159).
- powerpc/pseries/hibernation: pass stream id via function
  arguments (bsc#1181674 ltc#189159).
- Refresh patches.suse/powerpc-pseries-hibernation-remove-redundant-cachein.patch
- powerpc/pseries/hibernation: drop pseries_suspend_begin()
  from suspend ops (bsc#1181674 ltc#189159).
- powerpc/rtas: remove rtas_ibm_suspend_me_unsafe() (bsc#1181674
  ltc#189159).
- powerpc/rtas: dispatch partition migration requests to pseries
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: retry partition suspend after error
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: signal suspend cancellation to
  platform (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: use stop_machine for join/suspend
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: extract VASI session polling logic
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: use rtas_activate_firmware() on resume
  (bsc#1181674 ltc#189159).
- Refresh patches.suse/powerpc-pseries-mobility-notify-network-peers-after-.patch
- powerpc/pseries/mobility: error message improvements
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: add missing break to default case
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: don't error on absence of ibm,
  update-nodes (bsc#1181674 ltc#189159).
- powerpc/hvcall: add token and codes for H_VASI_SIGNAL
  (bsc#1181674 ltc#189159).
- powerpc/rtas: add rtas_activate_firmware() (bsc#1181674
  ltc#189159).
- powerpc/rtas: add rtas_ibm_suspend_me() (bsc#1181674
  ltc#189159).
- powerpc/rtas: rtas_ibm_suspend_me -> rtas_ibm_suspend_me_unsafe
  (bsc#1181674 ltc#189159).
- powerpc/rtas: complete ibm,suspend-me status codes (bsc#1181674
  ltc#189159).
- powerpc/rtas: prevent suspend-related sys_rtas use on LE
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: Add pr_debug() for device tree changes
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: Set pr_fmt() (bsc#1181674 ltc#189159).
- powerpc/pseries: remove obsolete memory hotplug DT notifier code
  (bsc#1181674 ltc#189159).
- Refresh patches.suse/powerpc-pseries-update-device-tree-before-ejecting-h.patch
- powerpc/pseries: remove dlpar_cpu_readd() (bsc#1181674
  ltc#189159).
- powerpc/pseries: remove memory "re-add" implementation
  (bsc#1181674 ltc#189159).
- powerpc/pseries: remove prrn special case from DT update path
  (bsc#1181674 ltc#189159).
- powerpc/numa: remove arch_update_cpu_topology (bsc#1181674
  ltc#189159).
- powerpc/numa: remove prrn_is_enabled() (bsc#1181674 ltc#189159).
- powerpc/rtasd: simplify handle_rtas_event(), emit message on
  events (bsc#1181674 ltc#189159).
- powerpc/numa: remove start/stop_topology_update() (bsc#1181674
  ltc#189159).
- powerpc/numa: remove timed_topology_update() (bsc#1181674
  ltc#189159).
- powerpc/numa: stub out numa_update_cpu_topology() (bsc#1181674
  ltc#189159).
- powerpc/numa: remove vphn_enabled and prrn_enabled internal
  flags (bsc#1181674 ltc#189159).
- powerpc/numa: remove unreachable topology workqueue code
  (bsc#1181674 ltc#189159).
- powerpc/numa: remove unreachable topology timer code
  (bsc#1181674 ltc#189159).
- powerpc/numa: make vphn_enabled, prrn_enabled flags const
  (bsc#1181674 ltc#189159).
- powerpc/numa: remove unreachable topology update code
  (bsc#1181674 ltc#189159).
- powerpc/numa: remove ability to enable topology updates
  (bsc#1181674 ltc#189159).
- powerpc/numa: Remove late request for home node associativity
  (bsc#1181674 ltc#189159).
- commit 88bd021
* Tue Feb  2 2021 bp@suse.de
- Refresh patches.suse/edac-amd64-set-grain-per-dimm.patch.
  Readd the second hunk which wasn't needed during the original git-fixes
  backport.
- commit 9c3639f
* Tue Feb  2 2021 glin@suse.com
- Update patches.suse/bpf-Fix-modifier-skipping-logic.patch (bsc#1177028).
  Restore the patch to match the upstream commit
- commit a490625
* Mon Feb  1 2021 tbogendoerfer@suse.de
- mlxsw: spectrum_span: Do not overwrite policer configuration
  (bsc#1176774).
- net/mlx5: CT: Fix incorrect removal of tuple_nat_node from
  nat rhashtable (jsc#SLE-15172).
- net/mlx5e: Revert parameters on errors when changing trust
  state without reset (jsc#SLE-15172).
- net/mlx5e: Correctly handle changing the number of queues when
  the interface is down (jsc#SLE-15172).
- net/mlx5e: Fix CT rule + encap slow path offload and deletion
  (jsc#SLE-15172).
- net/mlx5e: Disable hw-tc-offload when MLX5_CLS_ACT config is
  disabled (jsc#SLE-15172).
- net/mlx5: Maintain separate page trees for ECPF and PF functions
  (jsc#SLE-15172).
- net/mlx5e: Fix IPSEC stats (jsc#SLE-15172).
- net/mlx5e: free page before return (jsc#SLE-15172).
- ice: Fix MSI-X vector fallback logic (bsc#1180945).
- ice: Don't allow more channels than LAN MSI-X available
  (bsc#1180945).
- ice: update dev_addr in ice_set_mac_address even if HW filter
  exists (jsc#SLE-12878).
- ice: Implement flow for IPv6 next header (extension header)
  (jsc#SLE-12878).
- ice: fix FDir IPv6 flexbyte (jsc#SLE-12878).
- uapi: fix big endian definition of ipv6_rpl_sr_hdr
  (bsc#1176447).
- commit a3c4fad
* Mon Feb  1 2021 tbogendoerfer@suse.de
- rxrpc: Fix memory leak in rxrpc_lookup_local (bsc#1154353
  bnc#1151927 5.3.9).
- net/mlx5e: E-switch, Fix rate calculation for overflow
  (jsc#SLE-8464).
- i40e: acquire VSI pointer only after VF is initialized
  (jsc#SLE-8025).
- ice: Fix MSI-X vector fallback logic (jsc#SLE-7926).
- ice: Don't allow more channels than LAN MSI-X available
  (jsc#SLE-7926).
- Revert "RDMA/mlx5: Fix devlink deadlock on net namespace
  deletion" (jsc#SLE-8464).
- commit 76b9a3a
* Mon Feb  1 2021 ematsumiya@suse.de
- scsi: qla2xxx: Fix description for parameter
  ql2xenforce_iocb_limit (bsc#1179142).
- commit f3ce867
* Mon Feb  1 2021 jroedel@suse.de
- kABI: Fix kABI for extended APIC-ID support (bsc#1181259,
  jsc#ECO-3191).
- x86/kvm: Add KVM_FEATURE_MSI_EXT_DEST_ID (bsc#1181259,
  jsc#ECO-3191).
- commit 0e40024
* Mon Feb  1 2021 jroedel@suse.de
- x86/apic: Support 15 bits of APIC ID in IOAPIC/MSI where
  available (bsc#1181259, jsc#ECO-3191).
- x86/ioapic: Handle Extended Destination ID field in RTE
  (bsc#1181259, jsc#ECO-3191).
- x86/msi: Only use high bits of MSI address for DMAR unit
  (bsc#1181259, jsc#ECO-3191).
- commit 077256e
* Mon Feb  1 2021 jroedel@suse.de
- x86/kvm: Reserve KVM_FEATURE_MSI_EXT_DEST_ID (bsc#1181259
  jsc#ECO-3191).
- commit 0deae09
* Mon Feb  1 2021 ptesarik@suse.cz
- blacklist.conf: no need to fix code for CONFIG_KEXEC_JUMP
- commit 3abe54d
* Mon Feb  1 2021 bp@suse.de
- blacklist.conf: e45122893a98 x86/fpu: Add kernel_fpu_begin_mask() to selectively initialize state
- commit f36235a
* Mon Feb  1 2021 glin@suse.com
- Refresh patches.suse/bpf-Introduce-bpf_sk_-ancestor_-cgroup_id-helpers.patch.
  The diff for cg_skb_func_proto was wrongly applied to
  tc_cls_act_func_proto.
- commit 6cbb315
* Mon Feb  1 2021 mkubecek@suse.cz
- nbd: freeze the queue while we're adding connections
  (CVE-2021-3348 bsc#1181504).
- commit 78453ee
* Mon Feb  1 2021 tiwai@suse.de
- efi/apple-properties: Reinstate support for boolean properties
  (git-fixes).
- commit c20e373
* Mon Feb  1 2021 tiwai@suse.de
- leds: trigger: fix potential deadlock with libata (git-fixes).
- commit d410ad0
* Mon Feb  1 2021 dbueso@suse.de
-  Update patch References tags for futex fixes (bsc#1181349 CVE-2021-3347)
- commit b3fac23
* Sun Jan 31 2021 tiwai@suse.de
- HID: wacom: Correct NULL dereference on AES pen proximity
  (git-fixes).
- HID: wacom: Fix memory leakage caused by kfifo_alloc
  (git-fixes).
- HID: wacom: Constify attribute_groups (git-fixes).
- HID: wacom: do not call hid_set_drvdata(hdev, NULL) (git-fixes).
- commit c0ccdd7
* Sat Jan 30 2021 tiwai@suse.de
- drm/i915: Always flush the active worker before returning from
  the wait (git-fixes).
- drm/i915/selftest: Fix potential memory leak (git-fixes).
- drm/i915/gt: Clear CACHE_MODE prior to clearing residuals
  (git-fixes).
- drm/vc4: Correct POS1_SCL for hvs5 (git-fixes).
- drm/vc4: Correct lbm size and calculation (git-fixes).
- drm/nouveau/kms/gk104-gp1xx: Fix > 64x64 cursors (git-fixes).
- drivers/nouveau/kms/nv50-: Reject format modifiers for cursor
  planes (git-fixes).
- drm/nouveau/dispnv50: Restore pushing of all data (git-fixes).
- commit ab75656
* Sat Jan 30 2021 tiwai@suse.de
- ACPI/IORT: Do not blindly trust DMA masks from firmware
  (git-fixes).
- PM: hibernate: flush swap writer after marking (git-fixes).
- ACPI: sysfs: Prefer "compatible" modalias (git-fixes).
- drm/i915: Check for all subplatform bits (git-fixes).
- drm/nouveau/svm: fail NOUVEAU_SVM_INIT ioctl on unsupported
  devices (git-fixes).
- commit 274cf96
* Fri Jan 29 2021 ailiop@suse.com
- iomap: fix WARN_ON_ONCE() from unprivileged users (bsc#1181494).
- commit 2958b80
* Fri Jan 29 2021 ptesarik@suse.cz
- net/smc: fix direct access to ib_gid_addr->ndev in
  smc_ib_determine_gid() (git-fixes).
- net/smc: fix valid DMBE buffer sizes (git-fixes).
- net/smc: fix sock refcounting in case of termination
  (git-fixes).
- net/smc: reset sndbuf_desc if freed (git-fixes).
- net/smc: set rx_off for SMCR explicitly (git-fixes).
- net/smc: fix dmb buffer shortage (git-fixes).
- net/smc: remove freed buffer from list (git-fixes).
- net/smc: switch smcd_dev_list spinlock to mutex (git-fixes).
- net/smc: fix sleep bug in smc_pnet_find_roce_resource()
  (git-fixes).
- net/smc: cancel event worker during device removal (git-fixes).
- net/smc: check for valid ib_client_data (git-fixes).
- net/smc: fix cleanup for linkgroup setup failures (git-fixes).
- net/smc: no peer ID in CLC decline for SMCD (git-fixes).
- net/smc: transfer fasync_list in case of fallback (git-fixes).
- commit a9e7337
* Fri Jan 29 2021 mkoutny@suse.com
- mm: memcontrol: fix missing wakeup polling thread (bsc#1181584).
- commit c0272b7
* Fri Jan 29 2021 mkoutny@suse.com
- blacklist.conf: Add 4230e2deaa48 stop_machine, rcu: Mark functions as notrace
- commit 9596511
* Fri Jan 29 2021 mkoutny@suse.com
- blacklist.conf: Add 15ec0fcff6da kernel/sys.c: replace do_brk with do_brk_flags in comment of prctl_set_mm_map()
- commit 7773384
* Fri Jan 29 2021 mkoutny@suse.com
- ptrace: Set PF_SUPERPRIV when checking capability (bsc#1163930).
- ptrace: reintroduce usage of subjective credentials in
  ptrace_has_cap() (bsc#1163930).
- commit 1d6137d
* Fri Jan 29 2021 jeyu@suse.de
- module: delay kobject uevent until after module init call (bsc#1178631).
- Refresh patches.suse/supported-flag
- commit 2796828
* Fri Jan 29 2021 msuchanek@suse.de
- Refresh patches.suse/powerpc-sstep-Fix-array-out-of-bound-warning.patch.
  Update to v2
- commit 6a4b1c5
* Fri Jan 29 2021 ptesarik@suse.cz
- vfio iommu: Add dma available capability (bsc#1179572
  LTC#190110).
- commit 78a5def
* Fri Jan 29 2021 ptesarik@suse.cz
- vfio iommu: Add dma available capability (bsc#1179572
  LTC#190110).
- commit 6544fbc
* Fri Jan 29 2021 jeyu@suse.de
- Batch patch rename with scripts/renamepatches.
  Rename a bunch of patches (mostly drm-related) to match their SLE15-SP2
  equivalents. This will make solving SLE15-SP2 -> SLE15-SP3 conflicts a
  bit easier. This is especially important to make sure drm fixes going
  into SLE15-SP2 conflict with patches already in SLE15-SP3.
- commit 3c1500c
* Fri Jan 29 2021 tiwai@suse.de
- mac80211: pause TX while changing interface type (git-fixes).
- commit c5c081d
* Fri Jan 29 2021 tiwai@suse.de
- HID: multitouch: Remove MT_CLS_WIN_8_DUAL (git-fixes).
- Refresh
  patches.suse/HID-quirks-Always-poll-three-more-Lenovo-PixArt-mice.patch.
- commit bed41ce
* Fri Jan 29 2021 tiwai@suse.de
- can: dev: prevent potential information leak in can_fill_info()
  (git-fixes).
- mt7601u: fix kernel crash unplugging the device (git-fixes).
- mt7601u: fix rx buffer refcounting (git-fixes).
- NFC: fix resource leak when target index is invalid (git-fixes).
- NFC: fix possible resource leak (git-fixes).
- firmware: imx: select SOC_BUS to fix firmware build (git-fixes).
- HID: multitouch: Apply MT_QUIRK_CONFIDENCE quirk for multi-input
  devices (git-fixes).
- media: rc: ensure that uevent can be read directly after rc
  device register (git-fixes).
- HID: multitouch: do not filter mice nodes (git-fixes).
- commit f7694e1
* Fri Jan 29 2021 glin@suse.com
- selftests/bpf: Fix "dubious pointer arithmetic" test
  (bsc#1177028).
- commit eb710d9
* Fri Jan 29 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/0001-futex-Ensure-the-correct-return-value-from-futex_loc.patch
  patches.suse/0002-futex-Replace-pointless-printk-in-fixup_owner.patch
  patches.suse/0003-futex-Provide-and-use-pi_state_update_owner.patch
  patches.suse/0004-rtmutex-Remove-unused-argument-from-rt_mutex_proxy_u.patch
  patches.suse/0005-futex-Use-pi_state_update_owner-in-put_pi_state.patch
  patches.suse/0006-futex-Simplify-fixup_pi_state_owner.patch
  patches.suse/0007-futex-Handle-faults-correctly-for-PI-futexes.patch
- commit 16c5d87
* Fri Jan 29 2021 glin@suse.com
- Refresh patches.suse/bpf-Fix-map-permissions-check.patch.
  The diff was applied to map_delete_elem() mistakenly even though the
  patch indicates the target: map_lookup_and_delete_elem().
  The patch is applied correctly in SLE15-SP2, so this change is only for
  SLE15-SP3.
- commit 223cc56
* Thu Jan 28 2021 tiwai@suse.de
- ASoC: SOF: SND_INTEL_DSP_CONFIG dependency (git-fixes).
- ASoC: SOF: Intel: soundwire: fix select/depend unmet
  dependencies (git-fixes).
- ASoC: Intel: sof_sdw: set proper flags for Dell TGL-H SKU 0A5E
  (git-fixes).
- ASoC: Intel: Skylake: Zero snd_ctl_elem_value (git-fixes).
- ASoC: Intel: Skylake: skl-topology: Fix OOPs ib
  skl_tplg_complete (git-fixes).
- ASoC: mediatek: mt8183-da7219: ignore TDM DAI link by default
  (git-fixes).
- ASoC: mediatek: mt8183-mt6358: ignore TDM DAI link by default
  (git-fixes).
- ASoC: topology: Properly unregister DAI on removal (git-fixes).
- ASoC: topology: Fix memory corruption in
  soc_tplg_denum_create_values() (git-fixes).
- ASoC: AMD Renoir - refine DMI entries for some Lenovo products
  (git-fixes).
- ASoC: wm_adsp: Fix control name parsing for multi-fw
  (git-fixes).
- ALSA: hda: intel-dsp-config: add PCI id for TGL-H (git-fixes).
- commit 959baa2
* Thu Jan 28 2021 tiwai@suse.de
- Move upstreamed sound patches into sorted section
- commit 84af2ff
* Thu Jan 28 2021 tiwai@suse.de
- ALSA: hda/via: Apply the workaround generically for Clevo
  machines (git-fixes).
- ASoC: ak4458: correct reset polarity (git-fixes).
- ALSA: hda/realtek: Enable headset of ASUS B1400CEPE with ALC256
  (git-fixes).
- commit e5943b7
* Thu Jan 28 2021 tiwai@suse.de
- Refresh patches.suse/usb-roles-provide-the-switch-drivers-handle-to-the-switch-in-the-api.patch
  Fix the build on armv7hl config
- commit c7f7007
* Thu Jan 28 2021 tiwai@suse.de
- leds: Add managed API to get a LED from a device driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- leds: Add of_led_get() and led_put() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- thermal: db8500: Depromote debug print (jsc#SLE-16407).
- net: netcp_ethss: Use the PHY time stamping interface
  (bsc#1176447).
- thermal: db8500: Rewrite to be a pure OF sensor (jsc#SLE-16407).
- thermal: db8500: Use dev helper variable (jsc#SLE-16407).
- thermal: db8500: Finalize device tree conversion
  (jsc#SLE-16407).
- commit be80774
* Thu Jan 28 2021 ailiop@suse.com
- xfs: show the proper user quota options (bsc#1181538).
- commit e34397a
* Thu Jan 28 2021 dbueso@suse.de
- futex: Handle faults correctly for PI futexes (bsc#1181349
  bsc#1149032).
- futex: Simplify fixup_pi_state_owner() (bsc#1181349
  bsc#1149032).
- futex: Use pi_state_update_owner() in put_pi_state()
  (bsc#1181349 bsc#1149032).
- rtmutex: Remove unused argument from rt_mutex_proxy_unlock()
  (bsc#1181349 bsc#1149032).
- futex: Provide and use pi_state_update_owner() (bsc#1181349
  bsc#1149032).
- futex: Replace pointless printk in fixup_owner() (bsc#1181349
  bsc#1149032).
- futex: Ensure the correct return value from futex_lock_pi()
  (bsc#1181349 bsc#1149032).
- futex: Remove unused empty compat_exit_robust_list()
  (bsc#1149032).
- futex: Remove needless goto's (bsc#1149032).
- commit 8a00d32
* Thu Jan 28 2021 tiwai@suse.de
- clk: tegra: Add Tegra20/30 EMC clock implementation
  (jsc#SLE-15847).
- Refresh
  patches.suse/clk-tegra-Export-functions-for-EMC-clock-scaling.patch.
- Refresh
  patches.suse/clk-tegra-Implement-Tegra210-EMC-clock.patch.
- Refresh
  patches.suse/clk-tegra-Rename-Tegra124-EMC-clock-source-file.patch.
- commit f80473c
* Thu Jan 28 2021 tiwai@suse.de
- ARM: OMAP2+: omap_device: fix idling of devices during probe
  (bsc#1175713).
- ARM: OMAP2+: Remove redundant assignment to variable ret
  (bsc#1175713).
- OMAP2: fixup doc comments in omap_device (bsc#1175713).
- ARM: OMAP2+: Add pdata for OMAP3 ISP IOMMU (bsc#1175713).
- ARM: OMAP2+: Plug in device_enable/idle ops for IOMMUs
  (bsc#1175713).
- iommu/omap: add pdata ops for omap_device_enable/idle
  (bsc#1175713).
- commit 365ddca
* Thu Jan 28 2021 ohering@suse.de
- x86/hyperv: Fix kexec panic/hang issues (bsc#1176831).
- refresh patches.suse/suse-hv-kabi.patch
- commit 3bdfdcf
* Thu Jan 28 2021 tiwai@suse.de
- Delete patches.suse/1245-drm-remove-drm-specific-kmap_atomic-code.patch
  This broke the build on armv7hl.
- commit 7f90f67
* Thu Jan 28 2021 tiwai@suse.de
- ASoC: meson: aiu: add audio output dt-bindings (jsc#SLE-16518).
- commit 39e8b6e
* Thu Jan 28 2021 fdmanana@suse.com
- btrfs: send: fix invalid clone operations when cloning from
  the same file and root (bsc#1181511).
- commit 090f75a
* Thu Jan 28 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/nfsd4-readdirplus-shouldn-t-return-parent-of-export.patch
- commit 2f3e2e1
* Thu Jan 28 2021 jlee@suse.com
- ACPI/IORT: Fix doc warnings in iort.c (jsc#SLE-16407).
- ACPI, APEI, Fix error return value in apei_map_generic_address()
  (jsc#SLE-16407).
- ACPI: DPTF: Support Alder Lake (jsc#SLE-16407).
- ACPI: Fix whitespace inconsistencies (jsc#SLE-16407).
- ACPI: scan: Fix acpi_dma_configure_id() kerneldoc name
  (jsc#SLE-16407).
- ACPI: button: Drop no longer necessary Acer SW5-012
  lid_init_state quirk (jsc#SLE-16407).
- ACPI: utils: remove unreachable breaks (jsc#SLE-16407).
- ACPI: DPTF: Add ACPI_DPTF Kconfig menu (jsc#SLE-16407).
- Update config files.
- Update supported.conf.
- ACPI: DPTF: Fix participant driver names (jsc#SLE-16407).
- ACPI: processor: remove comment regarding string _UID support
  (jsc#SLE-16407).
- ACPI: reboot: Avoid racing after writing to ACPI RESET_REG
  (jsc#SLE-16407).
- ACPICA: Add missing type casts in GPE register access code
  (jsc#SLE-16407).
- PCI/ACPI: Add Ampere Altra SOC MCFG quirk (jsc#SLE-16407).
- PCI/ACPI: Tone down missing MCFG message (jsc#SLE-16407).
- ACPI / LPSS: Save Cherry Trail PWM ctx registers only once
  (at activation) (jsc#SLE-16407).
- ACPI / LPSS: Resume Cherry Trail PWM controller in no-irq phase
  (jsc#SLE-16407).
- ACPI: Export acpi_get_first_physical_node() to modules
  (jsc#SLE-16407).
- PNP: ACPI: Fix missing-prototypes in acpi_pnp.c (jsc#SLE-16407).
- ACPI: PCI: update kernel-doc line comments (jsc#SLE-16407).
- ACPI: memhotplug: Remove 'state' from struct acpi_memory_device
  (jsc#SLE-16407).
- ACPI: wakeup: Remove dead ACPICA debug code (jsc#SLE-16407).
- ACPI: video: Remove leftover ACPICA debug code (jsc#SLE-16407).
- ACPI: tiny-power-button: Remove dead ACPICA debug code
  (jsc#SLE-16407).
- ACPI: processor: Remove dead ACPICA debug code (jsc#SLE-16407).
- ACPI: proc: Remove dead ACPICA debug code (jsc#SLE-16407).
- ACPI: PCI: Remove unused ACPICA debug code (jsc#SLE-16407).
- ACPI: event: Remove leftover ACPICA debug code (jsc#SLE-16407).
- ACPI: dock: Remove dead ACPICA debug code (jsc#SLE-16407).
- ACPI: debugfs: Remove dead ACPICA debug code (jsc#SLE-16407).
- ACPI: custom_method: Remove dead ACPICA debug code
  (jsc#SLE-16407).
- ACPI: container: Remove leftover ACPICA debug functionality
  (jsc#SLE-16407).
- ACPI: platform: Remove ACPI_MODULE_NAME() (jsc#SLE-16407).
- ACPI: memhotplug: Remove leftover ACPICA debug functionality
  (jsc#SLE-16407).
- ACPI: LPSS: Remove ACPI_MODULE_NAME() (jsc#SLE-16407).
- ACPI: cmos_rtc: Remove leftover ACPI_MODULE_NAME()
  (jsc#SLE-16407).
- node: Add access1 class to represent CPU to memory
  characteristics (jsc#SLE-16407).
- ACPI: Let ACPI know we support Generic Initiator Affinity
  Structures (jsc#SLE-16407).
- ACPI: Support Generic Initiator only domains (jsc#SLE-16407).
- ACPI / NUMA: Add stub function for pxm_to_node()
  (jsc#SLE-16407).
- ACPI: Remove side effect of partly creating a node in
  acpi_get_node() (jsc#SLE-16407).
- ACPI: scan: Replace ACPI_DEBUG_PRINT() with pr_debug()
  (jsc#SLE-16407).
- ACPI: battery: include linux/power_supply.h (jsc#SLE-16407).
- ACPI: APD: Clean up header file include statements
  (jsc#SLE-16407).
- ACPI: APD: Remove unnecessary APD_ADDR() macro stub
  (jsc#SLE-16407).
- ACPI: APD: Remove ACPI_MODULE_NAME() (jsc#SLE-16407).
- ACPI: APD: Remove flags from struct apd_device_desc
  (jsc#SLE-16407).
- ACPI: APD: Add kerneldoc for properties in struct
  apd_device_desc (jsc#SLE-16407).
- ACPI: DPTF: Add PCH FIVR participant driver (jsc#SLE-16407).
- ACPI / PMIC: Move TPS68470 OpRegion driver to drivers/acpi/pmic/
  (jsc#SLE-16407).
- ACPI / PMIC: Split out Kconfig and Makefile specific for ACPI
  PMIC (jsc#SLE-16407).
  Update config files.
- ACPI: NFIT: Use kobj_to_dev() instead (jsc#SLE-16407).
- ACPI: OSL: Make ACPICA use logical addresses of GPE blocks
  (jsc#SLE-16407).
- ACPI: OSL: Change the type of acpi_os_map_generic_address()
  return value (jsc#SLE-16407).
- ACPICA: Add support for using logical addresses of GPE blocks
  (jsc#SLE-16407).
- ACPICA: Introduce special struct type for GPE register addresses
  (jsc#SLE-16407).
- ACPICA: Introduce acpi_hw_gpe_read() and acpi_hw_gpe_write()
  (jsc#SLE-16407).
- ACPICA: Validate GPE blocks at init time (jsc#SLE-16407).
- ACPICA: Update version to 20200925 Version 20200925
  (jsc#SLE-16407).
- ACPICA: Remove unnecessary semicolon (jsc#SLE-16407).
- ACPICA: Debugger: Add a new command: "ALL <NameSeg>"
  (jsc#SLE-16407).
- ACPICA: iASL: Return exceptions for string-to-integer
  conversions (jsc#SLE-16407).
- ACPICA: acpi_help: Update UUID list (jsc#SLE-16407).
- ACPICA: Add predefined names found in the SMBus sepcification
  (jsc#SLE-16407).
- ACPICA: Tree-wide: fix various typos and spelling mistakes
  (jsc#SLE-16407).
- ACPICA: Drop the repeated word "an" in a comment
  (jsc#SLE-16407).
- ACPICA: Add support for 64 bit risc-v compilation
  (jsc#SLE-16407).
- ACPI: processor: Print more information when
  acpi_processor_evaluate_cst() fails (jsc#SLE-16407).
- ACPI/IORT: Remove the unused inline functions (jsc#SLE-16407).
- ACPI/IORT: Drop the unused @ops of iort_add_device_replay()
  (jsc#SLE-16407).
- arm64: permit ACPI core to map kernel memory used for table
  overrides (jsc#SLE-16407).
- arm64/acpi: disallow AML memory opregions to access kernel
  memory (jsc#SLE-16407).
- arm64: acpi: fix UBSAN warning (jsc#SLE-16407).
- commit 5dc32ae
* Thu Jan 28 2021 tiwai@suse.de
- Adjust armv7hl configs for SLE15-SP3 code base (jsc#SLE-17212)
- commit 7df7f95
* Thu Jan 28 2021 tiwai@suse.de
- Copy armv7hl config back from openSUSE-15.2 branch (jsc#SLE-17212)
  vanilla config is skipped as it's dropped on Leap 15.3
- commit a5a45dc
* Thu Jan 28 2021 tiwai@suse.de
- intel_th: pci: Add Alder Lake-P support (git-fixes).
- drm/amd/display: disable dcn10 pipe split by default
  (git-fixes).
- commit 92717d1
* Thu Jan 28 2021 tiwai@suse.de
- xhci: tegra: Delay for disabling LFPS detector (git-fixes).
- xhci: make sure TRB is fully written before giving it to the
  controller (git-fixes).
- USB: ehci: fix an interrupt calltrace error (git-fixes).
- ehci: fix EHCI host controller initialization sequence
  (git-fixes).
- i2c: bpmp-tegra: Ignore unknown I2C_M flags (git-fixes).
- platform/x86: ideapad-laptop: Disable touchpad_switch for
  ELAN0634 (git-fixes).
- drm/nouveau/kms/nv50-: fix case where notifier buffer is at
  offset 0 (git-fixes).
- drm/nouveau/mmu: fix vram heap sizing (git-fixes).
- drm/nouveau/i2c/gm200: increase width of aux semaphore owner
  fields (git-fixes).
- drm/nouveau/privring: ack interrupts the same way as RM
  (git-fixes).
- drm/nouveau/bios: fix issue shadowing expansion ROMs
  (git-fixes).
- drm/amdgpu/psp: fix psp gfx ctrl cmds (git-fixes).
- HID: Ignore battery for Elan touchscreen on ASUS UX550
  (git-fixes).
- HID: logitech-dj: add the G602 receiver (git-fixes).
- HID: multitouch: Enable multi-input for Synaptics
  pointstick/touchpad device (git-fixes).
- commit 6194af6
* Wed Jan 27 2021 neilb@suse.de
- blacklist.conf: unwanted NFS patches
- commit 6f9f1d0
* Wed Jan 27 2021 neilb@suse.de
- nfsd4: readdirplus shouldn't return parent of export
  (git-fixes).
- commit 5e9f700
* Wed Jan 27 2021 ematsumiya@suse.de
- nvme-tcp: avoid request double completion for concurrent
  nvme_tcp_timeout (bsc#1181161).
- nvme-rdma: avoid request double completion for concurrent
  nvme_rdma_timeout (bsc#1181161).
- commit 7760e28
* Wed Jan 27 2021 jgross@suse.com
- x86/xen: avoid warning in Xen pv guest with
  CONFIG_AMD_MEM_ENCRYPT enabled (bsc#1181335).
- commit ada97e4
* Wed Jan 27 2021 jgross@suse.com
- xen-blkfront: allow discard-* nodes to be optional
  (bsc#1181346).
- commit 958c625
* Wed Jan 27 2021 jgross@suse.com
- xen/privcmd: allow fetching resource sizes (bsc#1065600).
- commit 21fc6aa
* Wed Jan 27 2021 msuchanek@suse.de
- scsi: ibmvfc: Fix missing cast of ibmvfc_event pointer to u64 handle
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- Refresh patches.suse/scsi-ibmvfc-Send-commands-down-HW-Sub-CRQ-when-chann.patch.
- Refresh patches.suse/scsi-ibmvfc-Set-and-track-hw-queue-in-ibmvfc_event-s.patch.
- commit 1e02306
* Wed Jan 27 2021 msuchanek@suse.de
- Update ibmvfc patch metadata.
- commit b112c00
* Wed Jan 27 2021 tbogendoerfer@suse.de
- RDMA/ucma: Do not miss ctx destruction steps in some cases
  (bsc#1181147).
- RDMA/cma: Don't overwrite sgid_attr after device is released
  (bsc#1181147).
- RDMA/cma: Fix deadlock on &lock in rdma_cma_listen_on_all()
  error unwind (bsc#1181147).
- RDMA/cma: Add missing error handling of listen_id (bsc#1181147).
- RDMA: Add rdma_connect_locked() (bsc#1181147).
- RDMA/ucma: Fix use after free in destroy id flow (bsc#1181147).
- RDMA/ucma: Rework ucma_migrate_id() to avoid races with destroy
  (bsc#1181147).
- RDMA/cma: Fix use after free race in roce multicast join
  (bsc#1181147).
- RDMA/cma: Consolidate the destruction of a cma_multicast in
  one place (bsc#1181147).
- RDMA/cma: Remove dead code for kernel rdmacm multicast
  (bsc#1181147).
- RDMA/cma: Combine cma_ndev_work with cma_work (bsc#1181147).
- RDMA/cma: Remove cma_comp() (bsc#1181147).
- RDMA/cma: Fix locking for the RDMA_CM_LISTEN state
  (bsc#1181147).
- RDMA/cma: Make the locking for automatic state transition more
  clear (bsc#1181147).
- RDMA/cma: Fix locking for the RDMA_CM_CONNECT state
  (bsc#1181147).
- RDMA/ucma: Fix resource leak on error path (bsc#1181147).
- RDMA/ucma: Remove closing and the close_wq (bsc#1181147).
- RDMA/ucma: Rework how new connections are passed through event
  delivery (bsc#1181147).
- RDMA/ucma: Narrow file->mut in ucma_event_handler()
  (bsc#1181147).
- RDMA/ucma: Change backlog into an atomic (bsc#1181147).
- RDMA/ucma: Fix locking for ctx->events_reported (bsc#1181147).
- RDMA/ucma: Fix the locking of ctx->file (bsc#1181147).
- RDMA/ucma: Do not use file->mut to lock destroying
  (bsc#1181147).
- RDMA/cma: Add missing locking to rdma_accept() (bsc#1181147).
- RDMA/ucma: Remove mc_list and rely on xarray (bsc#1181147).
- RDMA/ucma: Fix error cases around ucma_alloc_ctx()
  (bsc#1181147).
- RDMA/ucma: Consolidate the two destroy flows (bsc#1181147).
- RDMA/ucma: Remove unnecessary locking of file->ctx_list in close
  (bsc#1181147).
- RDMA/ucma: Fix refcount 0 incr in ucma_get_ctx() (bsc#1181147).
- RDMA/core: Move the rdma_show_ib_cm_event() macro (bsc#1181147).
- commit feb2e32
* Wed Jan 27 2021 jlee@suse.com
- efi/libstub: Disable -mbranch-protection (jsc#SLE-16407).
- efi/arm64: libstub: Deal gracefully with EFI_RNG_PROTOCOL
  failure (jsc#SLE-16407).
- efivarfs: Replace invalid slashes with exclamation marks in
  dentries (jsc#SLE-16407).
- efi: Delete deprecated parameter comments (jsc#SLE-16407).
- efi/libstub: Fix missing-prototypes in string.c (jsc#SLE-16407).
- efi: Add definition of EFI_MEMORY_CPU_CRYPTO and ability to
  report it (jsc#SLE-16407).
- efi: mokvar: add missing include of asm/early_ioremap.h
  (jsc#SLE-16407).
- efi: efivars: limit availability to X86 builds (jsc#SLE-16407).
  Update config files.
- efi: remove some false dependencies on CONFIG_EFI_VARS
  (jsc#SLE-16407).
- efi: efivars: un-export efivars_sysfs_init() (jsc#SLE-16407).
- efi: pstore: move workqueue handling out of efivars
  (jsc#SLE-16407).
- efi: pstore: disentangle from deprecated efivars module
  (jsc#SLE-16407).
- efi: mokvar-table: fix some issues in new code (jsc#SLE-16407).
- cper,edac,efi: Memory Error Record: bank group/address and
  chip id (jsc#SLE-16407).
- edac,ghes,cper: Add Row Extension to Memory Error Record
  (jsc#SLE-16407).
- efi/x86: Add a quirk to support command line arguments on Dell
  EFI firmware (jsc#SLE-16407).
- efi/libstub: Add efi_warn and *_once logging helpers
  (jsc#SLE-16407).
- efi: Support for MOK variable config table (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
- efi/printf: remove unneeded semicolon (jsc#SLE-16407).
- efi/libstub: Export efi_low_alloc_above() to other units
  (jsc#SLE-16407).
- efi: Rename arm-init to efi-init common for all arch
  (jsc#SLE-16407).
- commit a426a3c
* Wed Jan 27 2021 msuchanek@suse.de
- scsi: ibmvfc: Set default timeout to avoid crash during
  migration (bsc#1181425 ltc#188252).
- commit 9a4138b
* Wed Jan 27 2021 mkubecek@suse.cz
- series.conf: cleanup
- rename patches to get rid of numeric prefix (for easier resolve of merge conflict)
  patches.suse/0001-drm-rockchip-Avoid-uninitialized-use-of-endpoint-id-.patch -> patches.suse/drm-rockchip-Avoid-uninitialized-use-of-endpoint-id-.patch
  patches.suse/0002-drm-gma500-fix-double-free-of-gma_connector.patch -> patches.suse/drm-gma500-fix-double-free-of-gma_connector.patch
  patches.suse/0003-drm-aspeed-Fix-Kconfig-warning-subsequent-build-erro.patch -> patches.suse/drm-aspeed-Fix-Kconfig-warning-subsequent-build-erro.patch
  patches.suse/0004-drm-dp_aux_dev-check-aux_dev-before-use-in-drm_dp_au.patch -> patches.suse/drm-dp_aux_dev-check-aux_dev-before-use-in-drm_dp_au.patch
  patches.suse/0005-drm-mcde-Fix-handling-of-platform_get_irq-error.patch -> patches.suse/drm-mcde-Fix-handling-of-platform_get_irq-error.patch
  patches.suse/0006-drm-tve200-Fix-handling-of-platform_get_irq-error.patch -> patches.suse/drm-tve200-Fix-handling-of-platform_get_irq-error.patch
  (no effect on expanded tree)
- commit 772573f
* Wed Jan 27 2021 nsaenzjulienne@suse.de
- drm/v3d: Add support for bcm2711 (jsc#SLE-16259).
- Update config
- supported.conf: Enable v3d
- commit 29319ce
* Wed Jan 27 2021 nsaenzjulienne@suse.de
- soc: bcm: bcm2835-pm: Add support for bcm2711 (jsc#SLE-16259).
- commit 8aa7baa
* Wed Jan 27 2021 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section
  patches.suse/floppy-reintroduce-O_NDELAY-fix.patch
- commit 39bee61
* Tue Jan 26 2021 bp@suse.de
- arch/x86/lib/usercopy_64.c: fix __copy_user_flushcache()
  cache writeback (bsc#1152489).
- commit 852fa4b
* Tue Jan 26 2021 bp@suse.de
- blacklist.conf: 035fff1f7aab x86/PCI: Fix intel_mid_pci.c build error when ACPI is not enabled
- commit 7d62c49
* Tue Jan 26 2021 dwagner@suse.de
- scsi: lpfc: Simplify bool comparison (bsc#1180891).
- scsi: lpfc: Update lpfc version to 12.8.0.7 (bsc#1180891).
- scsi: lpfc: Enhancements to LOG_TRACE_EVENT for better
  readability (bsc#1180891).
- scsi: lpfc: Implement health checking when aborting I/O
  (bsc#1180891).
- scsi: lpfc: Fix crash when nvmet transport calls host_release
  (bsc#1180891).
- scsi: lpfc: Fix vport create logging (bsc#1180891).
- scsi: lpfc: Fix NVMe recovery after mailbox timeout
  (bsc#1180891).
- scsi: lpfc: Fix target reset failing (bsc#1180891).
- scsi: lpfc: Fix error log messages being logged following SCSI
  task mgnt (bsc#1180891).
- scsi: lpfc: Prevent duplicate requests to unregister with
  cpuhp framework (bsc#1180891).
- scsi: lpfc: Fix FW reset action if I/Os are outstanding
  (bsc#1180891).
- scsi: lpfc: Use the nvme-fc transport supplied timeout for LS
  requests (bsc#1180891).
- scsi: lpfc: Fix crash when a fabric node is released prematurely
  (bsc#1180891).
- scsi: lpfc: Refresh ndlp when a new PRLI is received in the
  PRLI issue state (bsc#1180891).
- scsi: lpfc: Fix auto sli_mode and its effect on CONFIG_PORT
  for SLI3 (bsc#1180891).
- scsi: lpfc: Fix PLOGI S_ID of 0 on pt2pt config (bsc#1180891).
- commit cdea5d0
* Tue Jan 26 2021 bp@suse.de
- x86/topology: Make __max_die_per_package available
  unconditionally (bsc#1152489).
- commit 0e0c8a8
* Tue Jan 26 2021 jlee@suse.com
- Fix hibernation verification after UEFI subsystem upgraded (jsc#SLE-16407)
- Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- Refresh
  patches.suse/0006-efi-allow-user-to-regenerate-secret-key.patch.
- Delete
  patches.suse/0003-x86-KASLR-public-the-function-for-getting-random-lon.patch.
- Update config files.
- commit d972b09
* Mon Jan 25 2021 bp@suse.de
- x86/cpu/amd: Set __max_die_per_package on AMD (bsc#1152489).
- commit 3044309
* Mon Jan 25 2021 bp@suse.de
- x86/sev: Fix nonistr violation (bsc#1178134).
- commit 47bc3f9
* Mon Jan 25 2021 tiwai@suse.de
- drm/i915/gt: Declare gen9 has 64 mocs entries! (git-fixes).
- drm/etnaviv: always start/stop scheduler in timeout processing
  (git-fixes).
- commit 6ef999c
* Mon Jan 25 2021 tiwai@suse.de
- drm/i915/dsi: Use unconditional msleep for the panel_on_delay
  when there is no reset-deassert MIPI-sequence (git-fixes).
- drm/i915: clear the gpu reloc batch (git-fixes).
- drm/amdgpu: fix a GPU hang issue when remove device (git-fixes).
- drm/i915: Fix mismatch between misplaced vma check and vma
  insert (git-fixes).
- commit cc8174e
* Mon Jan 25 2021 tiwai@suse.de
- drm/amdkfd: Fix leak in dmabuf import (git-fixes).
- drm/msm/dsi_phy_10nm: implement PHY disabling (git-fixes).
- drm/msm/dsi_pll_10nm: restore VCO rate during restore_state
  (git-fixes).
- drm/msm/dpu: Add newline to printks (git-fixes).
- drm/meson: dw-hdmi: Register a callback to disable the regulator
  (git-fixes).
- drm/omap: dmm_tiler: fix return error code in omap_dmm_probe()
  (git-fixes).
- drm/amdgpu: fix build_coefficients() argument (git-fixes).
- drm/amd/display: remove useless if/else (git-fixes).
- drm/tve200: Fix handling of platform_get_irq() error
  (git-fixes).
- drm/mcde: Fix handling of platform_get_irq() error (git-fixes).
- drm/dp_aux_dev: check aux_dev before use in
  drm_dp_aux_dev_get_by_minor() (git-fixes).
- drm/aspeed: Fix Kconfig warning & subsequent build errors
  (git-fixes).
- drm/gma500: fix double free of gma_connector (git-fixes).
- drm/i915/display/dp: Compute the correct slice count for VDSC
  on DP (git-fixes).
- drm/rockchip: Avoid uninitialized use of endpoint id in LVDS
  (git-fixes).
- drm/i915/gt: Program mocs:63 for cache eviction on gen9
  (git-fixes).
- drm/tegra: sor: Disable clocks on error in tegra_sor_init()
  (git-fixes).
- drm/tegra: replace idr_init() by idr_init_base() (git-fixes).
- drm/i915/gt: Free stale request on destroying the virtual engine
  (git-fixes).
- drm/i915/gvt: return error when failing to take the module
  reference (git-fixes).
- drm/i915/gvt: Set ENHANCED_FRAME_CAP bit (git-fixes).
- drm/i915: Handle max_bpc==16 (git-fixes).
- drm/i915: Avoid memory leak with more than 16 workarounds on
  a list (git-fixes).
- drm/amd/display: Add missing pflip irq for dcn2.0 (git-fixes).
- drm/gma500: Fix out-of-bounds access to struct
  drm_device.vblank[] (git-fixes).
- drm/amdgpu: perform srbm soft reset always on SDMA resume
  (git-fixes).
- commit bd76ab9
* Mon Jan 25 2021 tiwai@suse.de
- drm/nouveau/nouveau: fix the start/end range for migration
  (git-fixes).
- drm/vc4: drv: Add error handding for bind (git-fixes).
- drm/sun4i: frontend: Fix the scaler phase on A33 (git-fixes).
- drm/sun4i: frontend: Reuse the ch0 phase for RGB formats
  (git-fixes).
- drm/sun4i: frontend: Rework a bit the phase data (git-fixes).
- drm/amd/display: Don't invoke kgdb_breakpoint() unconditionally
  (git-fixes).
- drm/amdgpu: increase the reserved VM size to 2MB (git-fixes).
- drm/amdgpu: don't map BO in reserved region (git-fixes).
- drm/amdgpu: add DID for navi10 blockchain SKU (git-fixes).
- drm/i915: Drop runtime-pm assert from vgpu io accessors
  (git-fixes).
- drm/i915: Force VT'd workarounds when running as a guest OS
  (git-fixes).
- drm/i915/gt: Delay execlist processing for tgl (git-fixes).
- commit d9edd32
* Mon Jan 25 2021 tiwai@suse.de
- drm/amdkfd: Use same SQ prefetch setting as amdgpu (git-fixes).
- drm/amd/display: Avoid MST manager resource leak (git-fixes).
- drm/amdgpu: correct the gpu reset handling for job != NULL case
  (git-fixes).
- drm/ttm: fix eviction valuable range check (git-fixes).
- drm/amd/display: HDMI remote sink need mode validation for Linux
  (git-fixes).
- drm/amd/display: Increase timeout for DP Disable (git-fixes).
- drm/i915: Break up error capture compression loops with
  cond_resched() (git-fixes).
- drm/msm/a6xx: fix a potential overflow issue (git-fixes).
- drm/panfrost: add amlogic reset quirk callback (git-fixes).
- drm/bridge/synopsys: dsi: add support for non-continuous HS
  clock (git-fixes).
- commit 3790415
* Mon Jan 25 2021 tiwai@suse.de
- drm/brige/megachips: Add checking if ge_b850v3_lvds_init()
  is working correctly (git-fixes).
- drm/nouveau/mem: guard against NULL pointer access in mem_del
  (git-fixes).
- drm/amdgpu: prevent double kfree ttm->sg (git-fixes).
- drm/sun4i: mixer: Extend regmap max_register (git-fixes).
- commit f36768e
* Mon Jan 25 2021 tiwai@suse.de
- drm/i915: Filter wake_flags passed to default_wake_function
  (git-fixes).
- drm/amdgpu/dc: Require primary plane to be enabled whenever
  the CRTC is (git-fixes).
- drm/amd/display: update nv1x stutter latencies (git-fixes).
- drm/amdkfd: fix a memory leak issue (git-fixes).
- drm/tve200: Stabilize enable/disable (git-fixes).
- drm/msm: Disable preemption on all 5xx targets (git-fixes).
- drm/amdgpu: Fix bug in reporting voltage for CIK (git-fixes).
- drm/amd/pm: avoid false alarm due to confusing
  softwareshutdowntemp setting (git-fixes).
- drm/omap: fix incorrect lock state (git-fixes).
- drm/amd/display: Fix memleak in amdgpu_dm_mode_config_init
  (git-fixes).
- drm/amd/display: Retry AUX write when fail occurs (git-fixes).
- drm/amd/display: Reject overlay plane configurations in
  multi-display scenarios (git-fixes).
- drm/msm/a6xx: fix gmu start on newer firmware (git-fixes).
- drm/msm: add shutdown support for display platform_driver
  (git-fixes).
- drm/msm/dpu: Fix scale params in plane validation (git-fixes).
- drm/i915/selftests: Avoid passing a random 0 into ilog2
  (git-fixes).
- drm/amdgpu: Fix bug where DPM is not enabled after hibernate
  and resume (git-fixes).
- drm/amd/display: dchubbub p-state warning during surface planes
  switch (git-fixes).
- commit 64cc324
* Mon Jan 25 2021 tiwai@suse.de
- drm: Added orientation quirk for ASUS tablet model T103HAF
  (git-fixes).
- drm/amdkfd: fix restore worker race condition (git-fixes).
- drm/nouveau/dispnv50: fix runtime pm imbalance on error
  (git-fixes).
- drm/nouveau: fix runtime pm imbalance on error (git-fixes).
- drm/nouveau/debugfs: fix runtime pm imbalance on error
  (git-fixes).
- commit 406e9f7
* Mon Jan 25 2021 tiwai@suse.de
- drm/exynos: dsi: Remove bridge node reference in error handling
  path in probe function (git-fixes).
- drm: rcar-du: Set primary plane zpos immutably at initializing
  (git-fixes).
- drm/amdgpu/sriov add amdgpu_amdkfd_pre_reset in gpu reset
  (git-fixes).
- drm/msm/a5xx: Always set an OPP supported hardware value
  (git-fixes).
- drm/msm: fix leaks if initialization fails (git-fixes).
- drm/amd/display: Stop if retimer is not available (git-fixes).
- drm/amdgpu: increase atombios cmd timeout (git-fixes).
- drm/omap: dss: Cleanup DSS ports on initialisation failure
  (git-fixes).
- commit db34b82
* Mon Jan 25 2021 tiwai@suse.de
- drm/amd/display: dal_ddc_i2c_payloads_create can fail causing
  panic (git-fixes).
- drm/omap: fix possible object reference leak (git-fixes).
- drm/amdgpu: fix calltrace during kmd unload(v3) (git-fixes).
- drm/scheduler: Avoid accessing freed bad job (git-fixes).
- drm/amdgpu/powerplay/smu7: fix AVFS handling with custom
  powerplay table (git-fixes).
- drm/amdgpu/powerplay: fix AVFS handling with custom powerplay
  table (git-fixes).
- drm/amd/display: Free gamma after calculating legacy transfer
  function (git-fixes).
- drm/amd/display: Do not double-buffer DTO adjustments
  (git-fixes).
- commit c18126a
* Mon Jan 25 2021 tiwai@suse.de
- drm/i915/gt: Prevent use of engine->wa_ctx after error
  (git-fixes).
- drm/syncobj: Fix use-after-free (git-fixes).
- drm/atomic: put state on error path (git-fixes).
- commit 4cd1094
* Mon Jan 25 2021 tiwai@suse.de
- drm/i915/hdcp: Update CP property in update_pipe (git-fixes).
- drm/amdgpu: fix DRM_INFO flood if display core is not supported
  (bug 210921) (git-fixes).
- commit 0dca4e9
* Mon Jan 25 2021 tiwai@suse.de
- ACPI: scan: Make acpi_bus_get_device() clear return pointer
  on error (git-fixes).
- cachefiles: Drop superfluous readpages aops NULL check
  (git-fixes).
- ACPI: scan: Harden acpi_device_add() against device ID overflows
  (git-fixes).
- commit 963543c
* Mon Jan 25 2021 bp@suse.de
- x86/sev-es: Handle string port IO to kernel memory properly
  (bsc#1178134).
- commit 3ec7fbe
* Mon Jan 25 2021 mbrugger@suse.com
- i2c: mlxbf: select CONFIG_I2C_SLAVE (jsc#SLE-15271 jsc#SLE-16108
  jsc#SLE-16098 jsc#SLE-13565).
- i2c: mlxbf: I2C_MLXBF should depend on MELLANOX_PLATFORM
  (jsc#SLE-15271 jsc#SLE-16108 jsc#SLE-16098 jsc#SLE-13565).
- commit abb583b
* Mon Jan 25 2021 tbogendoerfer@suse.de
- net: core: devlink: use right genl user_ptr when handling port
  param get/set (bsc#1176447).
- i40e: fix potential NULL pointer dereferencing (jsc#SLE-13701).
- net: fix use-after-free when UDP GRO with shared fraglist
  (bsc#1176447).
- net/mlx5e: In skb build skip setting mark in switchdev mode
  (jsc#SLE-15172).
- nexthop: Bounce NHA_GATEWAY in FDB nexthop groups (bsc#1176447).
- net: bareudp: add missing error handling for
  bareudp_link_config() (jsc#SLE-15172).
- bareudp: Fix use of incorrect min_headroom size (jsc#SLE-15172).
- bareudp: set NETIF_F_LLTX flag (jsc#SLE-15172).
- bnxt_en: Check TQM rings for maximum supported value
  (jsc#SLE-15075).
- bnxt_en: Fix AER recovery (jsc#SLE-15075).
- Revert "e1000e: disable s0ix entry and exit flows for ME
  systems" (jsc#SLE-13532).
- e1000e: Only run S0ix flows if shutdown succeeded
  (jsc#SLE-13532).
- ionic: change set_rx_mode from_ndo to can_sleep (jsc#SLE-16649).
- ionic: flatten calls to ionic_lif_rx_mode (jsc#SLE-16649).
- ice: avoid premature Rx buffer reuse (jsc#SLE-7926).
- net: mlx5e: fix fs_tcp.c build when IPV6 is not enabled
  (jsc#SLE-15172).
- net/mlx5e: Fix IPsec packet drop by mlx5e_tc_update_skb
  (jsc#SLE-15172).
- commit 54582be
* Mon Jan 25 2021 tbogendoerfer@suse.de
- net/mlx5e: ethtool, Fix restriction of autoneg with 56G
  (jsc#SLE-8464).
- net: hns3: fix a phy loopback fail issue (bsc#1154353).
- net: vlan: avoid leaks on register_vlan_dev() failures
  (bsc#1154353).
- bnxt_en: Fix AER recovery (jsc#SLE-8371 bsc#1153274).
- e1000e: bump up timeout to wait when ME un-configures ULP mode
  (jsc#SLE-8100).
- ionic: account for vlan tag len in rx buffer len (bsc#1167773).
- ice, xsk: clear the status bits for the next_to_use descriptor
  (jsc#SLE-7926).
- net: fix proc_fs init handling in af_packet and tls
  (bsc#1154353).
- ice: avoid premature Rx buffer reuse (jsc#SLE-7926).
- net: hns3: remove a misused pragma packed (bsc#1154353).
- commit 465e7d7
* Mon Jan 25 2021 ptesarik@suse.cz
- zlib: move EXPORT_SYMBOL() and MODULE_LICENSE() out of
  dfltcc_syms.c (jsc#SLE-13766).
- commit d62a9cc
* Mon Jan 25 2021 ptesarik@suse.cz
- zlib: export S390 symbols for zlib modules (jsc#SLE-13766).
- KVM: s390: remove diag318 reset code (jsc#SLE-13746).
- s390/pci: fix hot-plug of PCI function missing bus (bsc#1181076
  LTC#190860).
- commit 54be82c
* Mon Jan 25 2021 vbabka@suse.cz
- lib/test_hmm.c: fix an error code in dmirror_allocate_chunk()
  (jsc#SLE-16387).
- commit df77afb
* Mon Jan 25 2021 vbabka@suse.cz
- Refresh
  patches.suse/0041-mm-memremap_pages-support-multiple-ranges-per-invoca.patch.
- add missing hunk for lib/test_hmm.c
- commit f341232
* Mon Jan 25 2021 jslaby@suse.cz
- iommu/amd: Set iommu->int_enabled consistently when interrupts
  are set up (git-fixes).
- commit 0bf82c2
* Mon Jan 25 2021 msuchanek@suse.de
- blacklist.conf: Add 08685be7761d powerpc/64s: fix scv entry fallback flush vs interrupt
  No scv support.
- commit 7e491e5
* Mon Jan 25 2021 jslaby@suse.cz
- selftests: net: fib_tests: remove duplicate log test
  (git-fixes).
- net: mscc: ocelot: allow offloading of bridge on top of LAG
  (git-fixes).
- udp: Prevent reuseport_select_sock from reading uninitialized
  socks (git-fixes).
- pNFS: Mark layout for return if return-on-close was not sent
  (git-fixes).
- commit 87c48df
* Mon Jan 25 2021 bp@suse.de
- blacklist.conf: 78762b0e79bc x86/asm/32: Add ENDs to some functions and relabel with SYM_CODE_*
- commit 1f20d8c
* Mon Jan 25 2021 mkubecek@suse.cz
- series.conf: cleanup
- move kabi workaround into patches.kabi:
  patches.suse/ALSA-pcm-fix-hw_rule-deps-kABI.patch
- commit 3eee3e1
* Mon Jan 25 2021 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/scsi-scsi_transport_srp-Don-t-block-target-in-failfa.patch
  patches.suse/selftests-powerpc-Only-test-lwm-stmw-on-big-endian.patch
- commit 5218f70
* Mon Jan 25 2021 mkubecek@suse.cz
- series.conf: cleanup
- move an unsortable patch out of sorted section
  patches.suse/powerpc-Fix-build-error-in-paravirt.h.patch
- commit 0f64295
* Mon Jan 25 2021 tzimmermann@suse.de
- drm/tve200: Fix handling of platform_get_irq() error (bsc#1152472)
- commit 8541d40
* Mon Jan 25 2021 tzimmermann@suse.de
- drm/mcde: Fix handling of platform_get_irq() error (bsc#1152472)
- commit 60b9525
* Mon Jan 25 2021 tzimmermann@suse.de
- drm/dp_aux_dev: check aux_dev before use in (bsc#1152472)
- commit 21532d2
* Mon Jan 25 2021 tzimmermann@suse.de
- drm/aspeed: Fix Kconfig warning & subsequent build errors (bsc#1152472)
- commit 3d14ba8
* Mon Jan 25 2021 tzimmermann@suse.de
- drm/gma500: fix double free of gma_connector (bsc#1152472)
  Backporting notes:
  * context changes
- commit 2ce14eb
* Mon Jan 25 2021 tzimmermann@suse.de
- drm/rockchip: Avoid uninitialized use of endpoint id in LVDS (bsc#1152472)
- commit 103a121
* Mon Jan 25 2021 tiwai@suse.de
- iio: ad5504: Fix setting power-down state (git-fixes).
- serial: mvebu-uart: fix tx lost characters at power off
  (git-fixes).
- usb: udc: core: Use lock when write to soft_connect (git-fixes).
- usb: gadget: aspeed: fix stop dma register setting (git-fixes).
- commit 4d850d2
* Mon Jan 25 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vc4: gem: Add a managed action to cleanup the job queue'
- commit ce3d22f
* Mon Jan 25 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vc4: bo: Add a managed action to cleanup the cache'
- commit 2cf161b
* Mon Jan 25 2021 glin@suse.com
- bpf: Fix helper bpf_map_peek_elem_proto pointing to wrong
  callback (bsc#1155518).
- bpf: Don't leak memory in bpf getsockopt when optlen == 0
  (bsc#1155518).
- commit 609f544
* Sun Jan 24 2021 tiwai@suse.de
- drm/panel: otm8009a: allow using non-continuous dsi clock
  (git-fixes).
- usb: ohci: Make distrust_firmware param default to false
  (git-fixes).
- commit 7c39cad
* Sun Jan 24 2021 tiwai@suse.de
- i2c: octeon: check correct size of maximum RECV_LEN packet
  (git-fixes).
- commit 54a675e
* Sat Jan 23 2021 tiwai@suse.de
- ALSA: pcm: fix hw_rule deps kABI (bsc#1181014).
- commit 3c80769
* Sat Jan 23 2021 tiwai@suse.de
- ALSA: pcm: One more dependency for hw constraints (bsc#1181014).
- commit d71290f
* Sat Jan 23 2021 tiwai@suse.de
- mmc: core: don't initialize block size from ext_csd if not
  present (git-fixes).
- mmc: sdhci-xenon: fix 1.8v regulator stabilization (git-fixes).
- platform/x86: intel-vbtn: Drop HP Stream x360 Convertible PC
  11 from allow-list (git-fixes).
- platform/x86: i2c-multi-instantiate: Don't create platform
  device for INT3515 ACPI nodes (git-fixes).
- commit 9c2a03f
* Sat Jan 23 2021 dbueso@suse.de
- timers: Use only bucket expiry for base->next_expiry value
  (bsc#1181318).
- timers: Preserve higher bits of expiration on index calculation
  (bsc#1181318).
- commit f60f618
* Fri Jan 22 2021 ptesarik@suse.cz
- s390/cio: fix use-after-free in ccw_device_destroy_console
  (git-fixes).
- commit d3e26e8
* Fri Jan 22 2021 ptesarik@suse.cz
- KVM: s390: pv: Mark mm as protected after the set secure
  parameters and improve cleanup (jsc#SLE-7512 bsc#1165545).
- commit 719d24b
* Fri Jan 22 2021 ptesarik@suse.cz
- net/af_iucv: set correct sk_protocol for child sockets
  (git-fixes).
- net/af_iucv: fix null pointer dereference on shutdown
  (bsc#1179567 LTC#190111).
- commit ddc328b
* Fri Jan 22 2021 ptesarik@suse.cz
- s390/dasd: fix hanging device offline processing (bsc#1181169
  LTC#190914).
- commit 9b7644e
* Fri Jan 22 2021 ptesarik@suse.cz
- net/smc: use memcpy instead of snprintf to avoid out of bounds
  read (jsc#SLE-15862 bsc#1180744 LTC#186340).
- smc: fix out of bound access in smc_nl_get_sys_info()
  (jsc#SLE-15862 bsc#1180744 LTC#186340).
- net/smc: fix access to parent of an ib device (jsc#SLE-15862
  bsc#1180744 LTC#186340).
- commit f7642f8
* Fri Jan 22 2021 ptesarik@suse.cz
- net/smc: Add support for obtaining SMCR device list
  (jsc#SLE-15862 bsc#1180744 LTC#186340).
- net/smc: Add support for obtaining SMCD device list
  (jsc#SLE-15862 bsc#1180744 LTC#186340).
- net/smc: Add SMC-D Linkgroup diagnostic support (jsc#SLE-15862
  bsc#1180744 LTC#186340).
- net/smc: Introduce SMCR get link command (jsc#SLE-15862
  bsc#1180744 LTC#186340).
- net/smc: Introduce SMCR get linkgroup command (jsc#SLE-15862
  bsc#1180744 LTC#186340).
- net/smc: Add support for obtaining system information
  (jsc#SLE-15862 bsc#1180744 LTC#186340).
- net/smc: Introduce generic netlink interface for diagnostic
  purposes (jsc#SLE-15862 bsc#1180744 LTC#186340).
- net/smc: Refactor smc ism v2 capability handling (jsc#SLE-15862
  bsc#1180744 LTC#186340).
- net/smc: Add diagnostic information to link structure
  (jsc#SLE-15862 bsc#1180744 LTC#186340).
- net/smc: Add diagnostic information to smc ib-device
  (jsc#SLE-15862 bsc#1180744 LTC#186340).
- net/smc: Add link counters for IB device ports (jsc#SLE-15862
  bsc#1180744 LTC#186340).
- net/smc: Add connection counters for links (jsc#SLE-15862
  bsc#1180744 LTC#186340).
- net/smc: Use active link of the connection (jsc#SLE-15862
  bsc#1180744 LTC#186340).
- net/smc: use helper smc_conn_abort() in listen processing
  (jsc#SLE-15862 bsc#1180744 LTC#186340).
- commit 064ec88
* Fri Jan 22 2021 nsaenzjulienne@suse.de
- drm/vc4: Unify PCM card's driver_name (git-fixes).
- commit 2a6cd0a
* Fri Jan 22 2021 ykaukab@suse.de
- dpaa2-eth: fix the size of the mapped SGT buffer
  (jsc#SLE-14018).
- soc: fsl: handle RCPM errata A-008646 on SoC LS1021A
  (jsc#SLE-14018).
- soc: fsl: qbman: qman: Remove unused variable 'dequeue_wq'
  (jsc#SLE-14018).
- soc: fsl: qe: qe_common: Fix misnamed function attribute 'addr'
  (jsc#SLE-14018).
- soc: fsl: dpio: qbman-portal: Fix a bunch of kernel-doc
  misdemeanours (jsc#SLE-14018).
- bus: fsl-mc: simplify DPRC version check (jsc#SLE-14018).
- bus: fsl-mc: added missing fields to dprc_rsp_get_obj_region
  structure (jsc#SLE-14018).
- bus: fsl-mc: make sure MC firmware is up and running
  (jsc#SLE-14018).
- bus: fsl-mc: add back accidentally dropped error check
  (jsc#SLE-14018).
- crypto: caam: Replace in_irq() usage (jsc#SLE-14018).
- soc/fsl/qbman: Add an argument to signal if NAPI processing
  is required (jsc#SLE-14018).
- crypto: caam/qi - simplify error path for context allocation
  (jsc#SLE-14018).
- dpaa2-eth: Fix compile error due to missing devlink support
  (jsc#SLE-14018).
- dpaa2-eth: select XGMAC_MDIO for MDIO bus support
  (jsc#SLE-14018).
- soc: fsl: qe: Remove unnessesary check in ucc_set_tdm_rxtx_clk
  (jsc#SLE-14018).
- soc: fsl: qman: convert to use be32_add_cpu() (jsc#SLE-14018).
- soc: fsl: dpio: remove set but not used 'addr_cena'
  (jsc#SLE-14018).
- dpaa2-eth: add support for devlink parser error drop traps
  (jsc#SLE-14018).
- dpaa2-eth: add basic devlink support (jsc#SLE-14018).
- devlink: add .trap_group_action_set() callback (jsc#SLE-14018).
- devlink: add parser error drop packet traps (jsc#SLE-14018).
- dpaa2-eth: install a single steering rule when SHARED_FS is
  enabled (jsc#SLE-14018).
- dpaa2-eth: no need to check link state right after ndo_open
  (jsc#SLE-14018).
- dpaa2-eth: drop double zeroing (jsc#SLE-14018).
- ptp_qoriq: support FIPER3 (jsc#SLE-14018).
- dpaa2-eth: utilize skb->cb for hardware timestamping
  (jsc#SLE-14018).
- dpaa2-eth: invoke dpaa2_eth_enable_tx_tstamp() once in code
  (jsc#SLE-14018).
- dpaa2-eth: define a global ptp_qoriq structure pointer
  (jsc#SLE-14018).
- dpaa2-eth: add APIs of 1588 single step timestamping
  (jsc#SLE-14018).
- dpaa2-eth: Convert to DEFINE_SHOW_ATTRIBUTE (jsc#SLE-14018).
- dpaa2-eth: add a dpaa2_eth_ prefix to all functions in
  dpaa2-eth-dcb.c (jsc#SLE-14018).
- dpaa2-eth: add a dpaa2_eth_ prefix to all functions in
  dpaa2-eth.c (jsc#SLE-14018).
- dpaa2-eth: add a dpaa2_eth_ prefix to all functions in
  dpaa2-ethtool.c (jsc#SLE-14018).
- bus/fsl-mc: Add a new version for dprc_get_obj_region command
  (jsc#SLE-14018).
- bus/fsl-mc: Extend ICID size from 16bit to 32bit
  (jsc#SLE-14018).
- bus/fsl-mc: Export IRQ pool handling functions to be used by
  VFIO (jsc#SLE-14018).
- bus/fsl-mc: Add a container setup function (jsc#SLE-14018).
- bus/fsl-mc: Export a cleanup function for DPRC (jsc#SLE-14018).
- bus/fsl-mc: Export dprc_scan/dprc_remove functions to be used
  by multiple entities (jsc#SLE-14018).
- bus/fsl-mc: Add dprc-reset-container support (jsc#SLE-14018).
- bus/fsl-mc: Cache the DPRC API version (jsc#SLE-14018).
- bus/fsl-mc: Set the QMAN/BMAN region flags (jsc#SLE-14018).
- bus/fsl-mc: add support for 'driver_override' in the mc-bus
  (jsc#SLE-14018).
- bus/fsl-mc: Add a new parameter to dprc_scan_objects function
  (jsc#SLE-14018).
- bus/fsl-mc: Do no longer export the total number of irqs
  outside dprc_scan_objects (jsc#SLE-14018).
- bus: fsl-mc: MC control registers are not always available
  (jsc#SLE-14018).
- bus: fsl-mc: don't assume an iommu is always present
  (jsc#SLE-14018).
- gpio: mpc8xxx: simplify ls1028a/ls1088a support (jsc#SLE-14018).
- ptp_qoriq: output PPS signal on FIPER2 in default
  (jsc#SLE-14018).
- commit 30de820
* Fri Jan 22 2021 jdelvare@suse.de
- hwmon-amd_energy-09-fix-allocation-of-hwmon_channel_info.patch is now
  part of jsc#SLE-14262.
- commit c0fcf0d
* Fri Jan 22 2021 jdelvare@suse.de
- hwmon: (amd_energy) Add AMD family 19h model 01h x86 match
  (jsc#SLE-14262).
- commit 0d38ed6
* Fri Jan 22 2021 tiwai@suse.de
- ALSA: hda: Balance runtime/system PM if direct-complete is
  disabled (git-fixes).
- ASoC: SOF: Intel: fix page fault at probe if i915 init fails
  (git-fixes).
- ASoC: SOF: Intel: hda: Avoid checking jack on system suspend
  (git-fixes).
- ASoC: SOF: Intel: hda: Modify existing helper to disable WAKEEN
  (git-fixes).
- ASoC: SOF: Intel: hda: Resume codec to do jack detection
  (git-fixes).
- ALSA: hda: Add AlderLake-P PCI ID and HDMI codec vid
  (git-fixes).
- commit 4063e56
* Fri Jan 22 2021 tiwai@suse.de
- ALSA: hda: Add Cometlake-R PCI ID (git-fixes).
- ALSA: seq: oss: Fix missing error check in
  snd_seq_oss_synth_make_info() (git-fixes).
- ALSA: hda/via: Add minimum mute flag (git-fixes).
- ALSA: hda/realtek - Limit int mic boost on Acer Aspire E5-575T
  (git-fixes).
- commit 70d9202
* Fri Jan 22 2021 tiwai@suse.de
- Move upstreamed sound patches into sorted section
- commit f5195da
* Thu Jan 21 2021 mbrugger@suse.com
- i2c: mlxbf: Fix the return check of devm_ioremap and ioremap
  (jsc#SLE-15271 jsc#SLE-16108 jsc#SLE-16098 jsc#SLE-13565).
- commit ebaf1be
* Thu Jan 21 2021 mbrugger@suse.com
- i2c: mlxbf: Update author and maintainer email info
  (jsc#SLE-15271 jsc#SLE-16108 jsc#SLE-16098 jsc#SLE-13565).
- commit 248e78f
* Thu Jan 21 2021 mbrugger@suse.com
- i2c: mlxbf: Update reference clock frequency (jsc#SLE-15271
  jsc#SLE-16108 jsc#SLE-16098 jsc#SLE-13565).
- commit 077bf6e
* Thu Jan 21 2021 mbrugger@suse.com
- i2c: mlxbf: Remove unecessary wrapper functions (jsc#SLE-15271
  jsc#SLE-16108 jsc#SLE-16098 jsc#SLE-13565).
- commit a636d51
* Thu Jan 21 2021 mbrugger@suse.com
- i2c: mlxbf: Fix resrticted cast warning of sparse (jsc#SLE-15271
  jsc#SLE-16108 jsc#SLE-16098 jsc#SLE-13565).
- commit 4f74542
* Thu Jan 21 2021 mbrugger@suse.com
- i2c: mlxbf: Add CONFIG_ACPI to guard ACPI function call
  (jsc#SLE-15271 jsc#SLE-16108 jsc#SLE-16098 jsc#SLE-13565).
- commit 8341791
* Thu Jan 21 2021 mbrugger@suse.com
- i2c: mlxbf: I2C SMBus driver for Mellanox BlueField SoC
  (bsc#1119838 jsc#SLE-15271 jsc#SLE-16108 jsc#SLE-16098 jsc#SLE-13565).
- Update config files.
- supported.conf: add i2c-mlxbf
- commit 25f4cd8
* Thu Jan 21 2021 tiwai@suse.de
- blacklist.conf: Add entries for platform/x86/intel-vbtn that are reverted
- commit 5482ef1
* Thu Jan 21 2021 tiwai@suse.de
- platform/x86: intel-vbtn: Fix SW_TABLET_MODE always reporting
  1 on some HP x360 models (git-fixes).
- commit d6ac163
* Thu Jan 21 2021 tiwai@suse.de
- power: vexpress: add suppress_bind_attrs to true (git-fixes).
- commit bb22b7b
* Thu Jan 21 2021 mbrugger@suse.com
- platform/mellanox: mlxbf-pmc: Add Mellanox BlueField PMC
  driver (bsc#1119846 jsc#SLE-15271 jsc#SLE-16108 jsc#SLE-16098
  jsc#SLE-13565).
- Update config files. Enabel MLXBF_PCM as module
- supported.conf: add mlxbf-pmc
- commit af433f3
* Thu Jan 21 2021 tiwai@suse.de
- drm/i915/gt: Restore clear-residual mitigations for Ivybridge,
  Baytrail (git-fixes).
- drm/i915/gt: Limit VFE threads based on GT (git-fixes).
- drm/i915/icl: Fix initing the DSI DSC power refcount during
  HW readout (git-fixes).
- drm/i915/backlight: fix CPU mode backlight takeover on LPT
  (git-fixes).
- drm/i915/dsi: Use unconditional msleep for the panel_on_delay
  when there is no reset-deassert MIPI-sequence (git-fixes).
- drm/msm: Call msm_init_vram before binding the gpu (git-fixes).
- drm/amdgpu: fix potential memory leak during navi12
  deinitialization (git-fixes).
- drm/amdgpu: fix a GPU hang issue when remove device (git-fixes).
- drm/amd/display: fix sysfs amdgpu_current_backlight_pwm NULL
  pointer issue (git-fixes).
- drm/i915/perf: also include Gen11 in OATAILPTR workaround
  (git-fixes).
- drm/amdkfd: Put ACPI table after using it (git-fixes).
- drm/bridge: sii902x: Enable I/O and core VCC supplies if present
  (git-fixes).
- drm/bridge: sii902x: Refactor init code into separate function
  (git-fixes).
- commit 1ac5cc4
* Thu Jan 21 2021 tiwai@suse.de
- blacklist.conf: Add amdgpu patches that are reverted
- commit ac3cc99
* Thu Jan 21 2021 tiwai@suse.de
- spi: imx: Fix freeing of DMA channels if spi_bitbang_start()
  fails (git-fixes).
- Refresh
  patches.suse/spi-imx-fix-runtime-pm-support-for-config_pm.patch.
- commit afbdd20
* Thu Jan 21 2021 tiwai@suse.de
- blacklist.conf: Add rtl8192e patches that are reverted later
- commit 86d1c5b
* Thu Jan 21 2021 tiwai@suse.de
- r8169: fix potential skb double free in an error path
  (git-fixes).
- spi: spi-cadence-quadspi: Fix mapping of buffers for DMA reads
  (git-fixes).
- commit 0cf3ab4
* Thu Jan 21 2021 fdmanana@suse.com
- btrfs: send: fix wrong file path when there is an inode with
  a pending rmdir (bsc#1181237).
- commit be4e71d
* Thu Jan 21 2021 tiwai@suse.de
- tty/sysrq: constify the the sysrq_key_op(s) (git-fixes).
- commit 866ce2a
* Thu Jan 21 2021 tiwai@suse.de
- media: dvb-usb: Fix use-after-free access (bsc#1181104).
- media: dvb-usb: Fix memory leak at error in
  dvb_usb_device_init() (bsc#1181104).
- commit 3a92626
* Thu Jan 21 2021 tiwai@suse.de
- can: vxcan: vxcan_xmit: fix use after free bug (git-fixes).
- mac80211: check if atf has been disabled in
  __ieee80211_schedule_txq (git-fixes).
- mac80211: do not drop tx nulldata packets on encrypted links
  (git-fixes).
- commit dfeeb94
* Thu Jan 21 2021 ptesarik@suse.cz
- Increase PCI_NR_FUNCTIONS to 512 on s390x
  (jsc#SLE-17267, bsc#1180114, LTC#190383).
- Refresh config/s390x/zfcpdump.
- commit 56606d8
* Thu Jan 21 2021 ptesarik@suse.cz
- lib/zlib: fix inflating zlib streams on s390 (bsc#1181070
  LTC#190858).
- commit 5b17a7f
* Thu Jan 21 2021 jroedel@suse.de
- vfio-pci: Use io_remap_pfn_range() for PCI IO memory
  (bsc#1181220).
- iommu/vt-d: Fix a bug for PDP check in prq_event_thread
  (bsc#1181217).
- vfio/pci: Implement ioeventfd thread handler for contended
  memory lock (bsc#1181219).
- KVM: nVMX: Reload vmcs01 if getting vmcs12's pages fails
  (bsc#1181218).
- commit 517d1e9
* Thu Jan 21 2021 nsaenzjulienne@suse.de
- arm64: Remove arm64_dma32_phys_limit and its uses
  (jsc#SLE-17068).
- commit 8ce9631
* Thu Jan 21 2021 glin@suse.com
- bpf: Fix signed_{sub,add32}_overflows type handling
  (bsc#1177028).
- bpf: Support PTR_TO_MEM{,_OR_NULL} register spilling
  (bsc#1177028).
- bpftool: Fix compilation failure for net.o with older glibc
  (bsc#1177028).
- bpf: Save correct stopping point in file seq iteration
  (bsc#1177028).
- selftests/bpf: Clarify build error if no vmlinux (bsc#1177028).
- bpf: Simplify task_file_seq_get_next() (bsc#1177028).
- bpf: Avoid iterating duplicated files for task_file iterator
  (bsc#1177028).
- commit 7d12720
* Thu Jan 21 2021 jroedel@suse.de
- iommu/vt-d: Fix misuse of ALIGN in qi_flush_piotlb()
  (bsc#1181210).
- iommu/amd: Stop irq_remapping_select() matching when remapping
  is disabled (bsc#1181206).
- iommu/vt-d: include conditionally on CONFIG_INTEL_IOMMU_SVM
  (bsc#1181211).
- iommu/vt-d: Don't read VCCAP register unless it exists
  (bsc#1181208).
- x86/tboot: Don't disable swiotlb when iommu is forced on
  (bsc#1181215).
- iommu: Check return of __iommu_attach_device() (bsc#1181207).
- iommu/vt-d: Fix kernel NULL pointer dereference in find_domain()
  (bsc#1181209).
- vfio/type1: fix dirty bitmap calculation in vfio_dma_rw
  (bsc#1181214).
- vfio: fix a missed vfio group put in vfio_pin_pages
  (bsc#1181213).
- vfio: add a singleton check for vfio_group_pin_pages
  (bsc#1181212).
- commit 8c44ec4
* Thu Jan 21 2021 msuchanek@suse.de
- Update patches.suse/selftests-ftrace-Select-an-existing-function-in-kpro.patch (bsc#1181203 ltc#190909).
- commit e5512d0
* Thu Jan 21 2021 tzimmermann@suse.de
- drm/sun4i: dw-hdmi: fix error return code in sun8i_dw_hdmi_bind() (bsc#1152472)
- commit d0d0905
* Thu Jan 21 2021 tzimmermann@suse.de
- drm: bridge: dw-hdmi: Avoid resetting force in the detect function (bsc#1152472)
- commit 9ad528c
* Thu Jan 21 2021 tzimmermann@suse.de
- drm/i915: Correctly set SFC capability for video engines (bsc#1152489)
  Backporting notes:
  * context changes
- commit d15d9b1
* Thu Jan 21 2021 neilb@suse.de
- SUNRPC: xprt_load_transport() needs to support the netid "rdma6"
  (git-fixes).
- commit d5fbee3
* Wed Jan 20 2021 tiwai@suse.de
- ALSA: usb-audio: Fix hw constraints dependencies (bsc#1181014).
- commit 58d7b94
* Wed Jan 20 2021 tiwai@suse.de
- dmabuf: fix use-after-free of dmabuf's file->f_inode
  (git-fixes).
- i2c: imx: Don't generate STOP condition if arbitration has
  been lost (git-fixes).
- i2c: imx: Check for I2SR_IAL after every byte (git-fixes).
- iwlwifi: pcie: set LTR to avoid completion timeout (git-fixes).
- ACPI: EC: PM: Drop ec_no_wakeup check from
  acpi_ec_dispatch_gpe() (git-fixes).
- i2c: imx: Fix reset of I2SR_IAL flag (git-fixes).
- gpio: amd-fch: correct logic of GPIO_LINE_DIRECTION (git-fixes).
- commit 555f1bf
* Wed Jan 20 2021 tiwai@suse.de
- blacklist.conf: Add amdgpu commits that are reverted
- commit 1fba96f
* Wed Jan 20 2021 tiwai@suse.de
- ASoC: AMD Renoir - add DMI entry for Lenovo ThinkPad X395
  (git-fixes).
- ASoC: amd: Replacing MSI with Legacy IRQ model (git-fixes).
- ASoC: AMD Renoir - add DMI entry for Lenovo ThinkPad E14 Gen 2
  (git-fixes).
- ASoC: meson: axg-tdmin: fix axg skew offset (git-fixes).
- ASoC: max98373: don't access volatile registers in bias level
  off (git-fixes).
- ASoC: rt711: mutex between calibration and power state changes
  (git-fixes).
- ASoC: Intel: haswell: Add missing pm_ops (git-fixes).
- ASoC: rsnd: don't call clk_disable_unprepare() if can't use
  (git-fixes).
- ASoC: SOF: Fix spelling mistake in Kconfig "ond" -> "and"
  (git-fixes).
- ASoC: codecs: fix spelling mistake in Kconfig "comunicate" ->
  "communicate" (git-fixes).
- commit 13c6b71
* Wed Jan 20 2021 tiwai@suse.de
- spi: cadence: cache reference clock rate during probe
  (git-fixes).
- r8152: Add Lenovo Powered USB-C Travel Hub (git-fixes).
- usb: typec: Fix copy paste error for NVIDIA alt-mode description
  (git-fixes).
- hwmon: (pwm-fan) Ensure that calculation doesn't discard big
  period values (git-fixes).
- ACPI: scan: add stub acpi_create_platform_device() for
  !CONFIG_ACPI (git-fixes).
- misdn: dsp: select CONFIG_BITREVERSE (git-fixes).
- commit 01db302
* Wed Jan 20 2021 nsaenzjulienne@suse.de
- Update configs: Enable i2c_mux_pinctrl (jsc#SLE-15318)
- supported.conf: Support i2c-mux-pinctrl
- commit 1488fe7
* Wed Jan 20 2021 msuchanek@suse.de
- selftests/ftrace: Select an existing function in
  kprobe_eventname test (bsc#1179396 ltc#185738).
- commit 3e9ea6f
* Wed Jan 20 2021 msuchanek@suse.de
- selftests/powerpc: spectre_v2 test must be built 64-bit
  (bsc#1181158 ltc#190851).
- commit 52f3d6b
* Wed Jan 20 2021 jgross@suse.com
- Update
  patches.suse/0001-xen-events-add-a-proper-barrier-to-2-level-uevent-un.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0002-xen-events-fix-race-in-evtchn_fifo_unmask.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0003-xen-events-add-a-new-late-EOI-evtchn-framework.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0004-xen-blkback-use-lateeoi-irq-binding.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0005-xen-netback-use-lateeoi-irq-binding.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0006-xen-scsiback-use-lateeoi-irq-binding.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0007-xen-pvcallsback-use-lateeoi-irq-binding.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0008-xen-pciback-use-lateeoi-irq-binding.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0009-xen-events-switch-user-event-channels-to-lateeoi-mod.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0010-xen-events-use-a-common-cpu-hotplug-hook-for-event-c.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0011-xen-events-defer-eoi-in-case-of-excessive-number-of-.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0012-xen-events-block-rogue-events-for-some-time.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/xen-events-avoid-removing-an-event-channel-while-han.patch
  (CVE-2020-27675 XSA-331 bsc#1177410).
- Added CVE numbers for above patches.
- commit 3b60580
* Wed Jan 20 2021 msuchanek@suse.de
- selftests/powerpc: Move set_dscr() into rfi_flush.c (bsc#1181158
  ltc#190851).
- selftests/powerpc: Move Hash MMU check to utilities (bsc#1181158
  ltc#190851).
- selftests/powerpc: Add a test of bad (out-of-range) accesses
  (bsc#1181158 ltc#190851).
- Refresh patches.suse/selftests-powerpc-Add-tlbie_test-in-.gitignore.patch.
- selftests/powerpc: Add a test of spectre_v2 mitigations
  (bsc#1181158 ltc#190851).
- Refresh patches.suse/selftests-powerpc-entry-flush-test.patch.
- selftests/powerpc: Ignore generated files (bsc#1181158
  ltc#190851).
- commit f53f10b
* Wed Jan 20 2021 msuchanek@suse.de
- selftests/powerpc: Only test lwm/stmw on big endian (bsc#1180412
  ltc#190579).
- commit 21bd682
* Wed Jan 20 2021 msuchanek@suse.de
- powerpc: Fix build error in paravirt.h (bsc#1181148 ltc#190702).
- commit 251d2f4
* Wed Jan 20 2021 msuchanek@suse.de
- Exclude Symbols.list again.
  Removing the exclude builds vanilla/linux-next builds.
  Fixes: 55877625c800 ("kernel-binary.spec.in: Package the obj_install_dir as explicit filelist.")
- commit a1728f2
* Wed Jan 20 2021 msuchanek@suse.de
- powerpc/paravirt: Use is_kvm_guest() in vcpu_is_preempted()
  (bsc#1181148 ltc#190702).
- powerpc: Reintroduce is_kvm_guest() as a fast-path check
  (bsc#1181148 ltc#190702).
- powerpc: Rename is_kvm_guest() to check_kvm_guest() (bsc#1181148
  ltc#190702).
- powerpc: Refactor is_kvm_guest() declaration to new header
  (bsc#1181148 ltc#190702).
- commit 17fe8f8
* Tue Jan 19 2021 msuchanek@suse.de
- floppy: reintroduce O_NDELAY fix (boo#1181018).
- commit ab10a7d
* Tue Jan 19 2021 denis.kirjanov@suse.com
- Refresh
  patches.suse/scsi-qedi-correct-max-length-of-chap-secret.
- commit ac83a80
* Tue Jan 19 2021 ykaukab@suse.de
- arm64: pgtable: Ensure dirty bit is preserved across
  pte_wrprotect() (bsc#1180130).
- arm64: pgtable: Fix pte_accessible() (bsc#1180130).
- commit 585bbd5
* Tue Jan 19 2021 tiwai@suse.de
- Revive usb-audio Keep Interface mixer (bsc#1181014).
- commit 80020db
* Tue Jan 19 2021 mbrugger@suse.com
- mtd: spi-nor: atmel: fix unlock_all() for AT25FS010/040
  (git-fixes).
- mtd: spi-nor: atmel: remove global protection flag (git-fixes).
- commit c76850f
* Tue Jan 19 2021 mkubecek@suse.cz
- netfilter: ctnetlink: add a range check for l3/l4 protonum
  (CVE-2020-25211 bsc#1176395).
- commit ebf5e43
* Tue Jan 19 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/NFS-nfs_delegation_find_inode_server-must-first-refe.patch
  patches.suse/NFS-nfs_igrab_and_active-must-first-reference-the-su.patch
  patches.suse/NFS-pNFS-Fix-a-leak-of-the-layout-plh_outstanding-co.patch
  patches.suse/NFS-pNFS-Fix-a-typo-in-ff_layout_resend_pnfs_read.patch
  patches.suse/NFS-switch-nfsiod-to-be-an-UNBOUND-workqueue.patch
  patches.suse/NFS4-Fix-use-after-free-in-trace_event_raw_event_nfs.patch
  patches.suse/NFSv4-Fix-the-alignment-of-page-data-in-the-getdevic.patch
  patches.suse/NFSv4.2-condition-READDIR-s-mask-for-security-label-.patch
  patches.suse/Revert-nfsd4-support-change_attr_type-attribute.patch
  patches.suse/SUNRPC-Clean-up-the-handling-of-page-padding-in-rpc_.patch
  patches.suse/SUNRPC-rpc_wake_up-should-wake-up-tasks-in-the-corre.patch
  patches.suse/lockd-don-t-use-interval-based-rebinding-over-TCP.patch
  patches.suse/md-fix-a-warning-caused-by-a-race-between-concurrent.patch
  patches.suse/net-sunrpc-Fix-snprintf-return-value-check-in-do_xpr.patch
  patches.suse/net-sunrpc-interpret-the-return-value-of-kstrtou32-c.patch
  patches.suse/nfs_common-need-lock-during-iterate-through-the-list.patch
  patches.suse/nfsd-Fix-message-level-for-normal-termination.patch
  patches.suse/sunrpc-fix-xs_read_xdr_buf-for-partial-pages-receive.patch
- commit f5dfabc
* Tue Jan 19 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/kprobes-tracing-kprobes-Fix-to-kill-kprobes-on-initmem-after-boot.patch
  patches.suse/mm-vmalloc-Fix-unlock-order-in-s_stop.patch
- commit 8ea9f59
* Tue Jan 19 2021 mhocko@suse.com
- tests: add close_range() tests (jsc#SLE-17337, bsc#1179090).
- arch: wire-up close_range() (jsc#SLE-17337, bsc#1179090).
- open: add close_range() (jsc#SLE-17337, bsc#1179090).
- commit abad1c5
* Tue Jan 19 2021 jslaby@suse.cz
- Refresh
  patches.suse/0011-x86-hpet-Move-MSI-support-into-hpet.c.patch.
- Update
  patches.suse/msft-hv-2119-irqdomain-treewide-Keep-firmware-node-unconditionall.patch
  (git-fixes bsc#1180889).
  Add missing hunks in the e3beca48a45b's backport.
- commit 060c4e5
* Tue Jan 19 2021 tbogendoerfer@suse.de
- Update
  patches.suse/tun-correct-header-offsets-in-napi-frags-mode.patch
  (git-fixes bsc#1180812 CVE-2021-0342).
  Added CVE reference
- commit 0059c1d
* Tue Jan 19 2021 neilb@suse.de
- NFS: nfs_igrab_and_active must first reference the superblock
  (for-next).
- NFS: nfs_delegation_find_inode_server must first reference
  the superblock (for-next).
- NFS/pNFS: Fix a leak of the layout 'plh_outstanding' counter
  (for-next).
- net: sunrpc: interpret the return value of kstrtou32 correctly
  (for-next).
- NFS4: Fix use-after-free in trace_event_raw_event_nfs4_set_lock
  (for-next).
- NFS/pNFS: Fix a typo in ff_layout_resend_pnfs_read() (for-next).
- sunrpc: fix xs_read_xdr_buf for partial pages receive
  (for-next).
- NFS: switch nfsiod to be an UNBOUND workqueue (for-next).
- lockd: don't use interval-based rebinding over TCP (for-next).
- net: sunrpc: Fix 'snprintf' return value check in
  'do_xprt_debugfs' (for-next).
- SUNRPC: Clean up the handling of page padding in
  rpc_prepare_reply_pages() (for-next).
- NFSv4: Fix the alignment of page data in the getdeviceinfo reply
  (for-next).
- NFSv4.2: condition READDIR's mask for security label based on
  LSM state (for-next).
- SUNRPC: rpc_wake_up() should wake up tasks in the correct order
  (for-next).
- md: fix a warning caused by a race between concurrent
  md_ioctl()s (for-next).
- Revert "nfsd4: support change_attr_type attribute" (for-next).
- nfs_common: need lock during iterate through the list
  (for-next).
- nfsd: Fix message level for normal termination (for-next).
- commit 685e8f2
* Mon Jan 18 2021 bp@suse.de
- x86/cpu/amd: Call init_amd_zn() om Family 19h processors too
  (bsc#1181077).
- commit a71f120
* Mon Jan 18 2021 mgorman@suse.de
- blacklist.conf: No in-tree users of the table
- commit 9c6c6be
* Mon Jan 18 2021 mgorman@suse.de
- kprobes: tracing/kprobes: Fix to kill kprobes on initmem after
  boot (git fixes (kernel/kprobe)).
- commit 47f3848
* Mon Jan 18 2021 mgorman@suse.de
- blacklist.conf: UP not enabled in kernel config
- commit c97848a
* Mon Jan 18 2021 mgorman@suse.de
- mm/vmalloc: Fix unlock order in s_stop() (git fixes
  (mm/vmalloc)).
- commit 70dafb3
* Mon Jan 18 2021 mgorman@suse.de
- blacklist.conf: nilfs2 not enabled in kernel config
- commit 409ae2f
* Mon Jan 18 2021 msuchanek@suse.de
- scsi: ibmvfc: Fix spelling mistake "succeded" -> "succeeded"
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- commit a426064
* Mon Jan 18 2021 msuchanek@suse.de
- blk-mq-debugfs: Add decode for BLK_MQ_F_TAG_HCTX_SHARED
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- blk-mq: Facilitate a shared sbitmap per tagset (jsc#SLE-15442
  bsc#1180814 ltc#187461).
- blk-mq: Use pointers for blk_mq_tags bitmap tags (jsc#SLE-15442
  bsc#1180814 ltc#187461).
- blk-mq: Pass flags for tag init/free (jsc#SLE-15442 bsc#1180814
  ltc#187461).
- blk-mq: Free tags in blk_mq_init_tags() upon error
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- commit c2ebad8
* Mon Jan 18 2021 ptesarik@suse.cz
- s390/qeth: fix L2 header access in qeth_l3_osa_features_check()
  (git-fixes).
- s390/qeth: fix locking for discipline setup / removal
  (git-fixes).
- s390/qeth: fix deadlock during recovery (git-fixes).
- s390/dasd: fix list corruption of lcu list (git-fixes).
- s390/dasd: fix list corruption of pavgroup group list
  (git-fixes).
- s390/dasd: prevent inconsistent LCU device data (git-fixes).
- s390/smp: perform initial CPU reset also for SMT siblings
  (git-fixes).
- s390/kexec_file: fix diag308 subcode when loading crash kernel
  (git-fixes).
- s390/qeth: consolidate online/offline code (git-fixes).
- s390/qeth: don't raise NETDEV_REBOOT event from L3 offline path
  (git-fixes).
- commit 22371f9
* Mon Jan 18 2021 mhocko@suse.com
- Update config files (jsc#SLE-17227)
  Enable CMA and DMA_CMA backend. Also enable SPI_BITBANG as requested.
- commit ebe7020
* Mon Jan 18 2021 bp@suse.de
- blacklist.conf: 78762b0e79bc x86/asm/32: Add ENDs to some functions and relabel with SYM_CODE_*
- commit 2b5cd2a
* Mon Jan 18 2021 tiwai@suse.de
- ALSA: usb-audio: Avoid implicit feedback on Pioneer devices
  (bsc#1181014).
- ALSA: usb-audio: Set sample rate for all sharing EPs on UAC1
  (bsc#1181014).
- ALSA: usb-audio: Fix UAC1 rate setup for secondary endpoints
  (bsc#1181014).
- ALSA: usb-audio: Always apply the hw constraints for implicit
  fb sync (bsc#1181014).
- commit b78b9c6
* Mon Jan 18 2021 jlee@suse.com
- Do not backport  30ad8db3a patch because HPE needs uv_bios_call()
  (bsc#1180598)
  Do not backport 30ad8db3a2c2e0121202342c6c2a48fc28937056 x86/platform/uv: Mark
  uv_bios_call() and uv_bios_call_irqsave() because HPE needs
  uv_bios_call() in SLE15-SP3
- blacklist.conf:
- Delete
  patches.suse/x86-platform-uv-Mark-uv_bios_call-and-uv_bios_call_i.patch.
- commit cb1e448
* Sat Jan 16 2021 msuchanek@suse.de
- scsi: scsi_debug: Support host tagset (jsc#SLE-15442 bsc#1180814
  ltc#187461).
- scsi: core: Show nr_hw_queues in sysfs (jsc#SLE-15442
  bsc#1180814 ltc#187461).
- scsi: Add host and host template flag 'host_tagset'
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
  Refresh patches.suse/scsi-add-disable_async_probing-module-argument.patch
- scsi: scsi_debug: Support hostwide tags (jsc#SLE-15442
  bsc#1180814 ltc#187461).
- scsi: core: Refactor scsi_mq_setup_tags function (jsc#SLE-15442
  bsc#1180814 ltc#187461).
- scsi: scsi_debug: Re-arrange parameters alphabetically
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- commit 0e8c445
* Fri Jan 15 2021 msuchanek@suse.de
- scsi: ibmvfc: Provide modules parameters for MQ settings
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Enable MQ and set reasonable defaults
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Purge SCSI channels after transport loss/reset
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Send Cancel MAD down each hw SCSI channel
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Add cancel mad initialization helper
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Register Sub-CRQ handles with VIOS during channel
  setup (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Send commands down HW Sub-CRQ when channelized
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Set and track hw queue in ibmvfc_event struct
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Advertise client support for using hardware
  channels (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Implement channel enquiry and setup commands
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Map/request irq and register Sub-CRQ interrupt
  handler (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Define Sub-CRQ interrupt handler routine
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Add handlers to drain and complete Sub-CRQ
  responses (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Add Sub-CRQ IRQ enable/disable routine
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Add alloc/dealloc routines for SCSI Sub-CRQ
  Channels (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Add Subordinate CRQ definitions (jsc#SLE-15442
  bsc#1180814 ltc#187461).
- scsi: ibmvfc: Define hcall wrapper for registering a Sub-CRQ
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Add size parameter to ibmvfc_init_event_pool()
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Init/free event pool during queue allocation/free
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Move event pool init/free routines (jsc#SLE-15442
  bsc#1180814 ltc#187461).
- scsi: ibmvfc: Add vhost fields and defaults for MQ enablement
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Relax locking around ibmvfc_queuecommand()
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Complete commands outside the host/queue lock
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Define per-queue state/list locks (jsc#SLE-15442
  bsc#1180814 ltc#187461).
- scsi: ibmvfc: Make command event pool queue specific
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Define generic queue structure for CRQs
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Advertise client support for targetWWPN using
  v2 commands (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Add support for target_wwpn field in v2 MADs
  and vfcFrame (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Add FC payload retrieval routines for versioned
  vfcFrames (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Add helper for testing capability flags
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Add new fields for version 2 of several MADs
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Deduplicate common ibmvfc_cmd init code
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Use correlation token to tag commands
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Remove trailing semicolon (jsc#SLE-15442
  bsc#1180814 ltc#187461).
- scsi: ibmvfc: Byte swap login_buf.resp values in attribute
  show functions (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Protect vhost->task_set increment by the host lock
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- scsi: ibmvfc: Interface updates for future FPIN and MQ support
  (jsc#SLE-15442 bsc#1180814 ltc#187461).
- commit fe5294b
* Fri Jan 15 2021 mkubecek@suse.cz
- Revert dwc3 series.
  As of now, this recently merged series fails to build without the kabi
  workaround which would break SLE15-SP3 merge. Drop the patches until the
  build failure is fixed.
- commit a8aaab2
* Fri Jan 15 2021 mbrugger@suse.com
- drivers/perf: Fix kernel panic when rmmod PMU modules during
  perf sampling (bsc#1180848).
- commit 8584e95
* Fri Jan 15 2021 tiwai@suse.de
- Drop incorrectly re-backported radeon patch again (bsc#1180971)
  Also add cherry-picked commit ids in the two relevant patches
- commit bb3221b
* Fri Jan 15 2021 lhenriques@suse.de
- blacklist.conf: 66ab33bf6d43 ("virtiofs fix leak in setup")
  Requires a massive commit, which is quite intrusive in fuse and not worth it.
- commit 2076b1f
* Fri Jan 15 2021 lhenriques@suse.de
- fuse: fix page dereference after free (jsc#SLE-13782).
- virtio_fs: convert to LE accessors (jsc#SLE-13782).
- commit 5376406
* Fri Jan 15 2021 aabdallah@suse.de
- KVM: SVM: Initialize prev_ga_tag before use (bsc#1180809).
- commit 953316b
* Fri Jan 15 2021 lhenriques@suse.de
- blacklist.conf: 0e9fb6f17ad5 ("fuse: BUG_ON correction in fuse_dev_splice_write()")
  Requires intrusive changes in pipe, splice, etc.
- commit eac6f26
* Fri Jan 15 2021 lhenriques@suse.de
- fuse: reject options on reconfigure via fsconfig(2)
  (jsc#SLE-13782).
- fuse: ignore 'data' argument of mount(..., MS_REMOUNT)
  (jsc#SLE-13782).
- fuse: use ->reconfigure() instead of ->remount_fs()
  (jsc#SLE-13782).
- virtiofs: do not use fuse_fill_super_common() for device
  installation (jsc#SLE-13782).
- fuse: invalidate inode attr in writeback cache mode
  (jsc#SLE-13782).
- fuse: Update stale comment in queue_interrupt() (jsc#SLE-13782).
- virtiofs: Add mount option and atime behavior to the doc
  (jsc#SLE-13782).
- virtiofs: schedule blocking async replies in separate worker
  (jsc#SLE-13782).
- commit ac0b54e
* Fri Jan 15 2021 lhenriques@suse.de
- fuse: fix stack use after return (jsc#SLE-13782).
- fuse: Support RENAME_WHITEOUT flag (jsc#SLE-13782).
- fuse: don't overflow LLONG_MAX with end offset (jsc#SLE-13782).
- commit 3a3db69
* Fri Jan 15 2021 lhenriques@suse.de
- fuse: fix fuse_send_readpages() in the syncronous read case
  (jsc#SLE-13782).
- fuse: fix leak of fuse_io_priv (jsc#SLE-13782).
- virtiofs: Use completions while waiting for queue to be drained
  (jsc#SLE-13782).
- virtiofs: Do not send forget request "struct list_head" element
  (jsc#SLE-13782).
- virtiofs: Use a common function to send forget (jsc#SLE-13782).
- fuse: verify write return (jsc#SLE-13782).
- commit a5ee2f4
* Thu Jan 14 2021 bp@suse.de
- blacklist.conf: 035fff1f7aab x86/PCI: Fix intel_mid_pci.c build error when ACPI is not enabled
- commit e52f15d
* Thu Jan 14 2021 bp@suse.de
- x86/kprobes: Restore BTF if the single-stepping is cancelled
  (bsc#1152489).
- commit f89b6b0
* Thu Jan 14 2021 tiwai@suse.de
- hwmon: (amd_energy) fix allocation of hwmon_channel_info config
  (git-fixes).
- dmaengine: idxd: off by one in cleanup code (git-fixes).
- commit 22fcbaa
* Thu Jan 14 2021 lhenriques@suse.de
- fuse: redundant get_fuse_inode() calls in fuse_writepages_fill()
  (jsc#SLE-13782).
- fuse: Add changelog entries for protocols 7.1 - 7.8
  (jsc#SLE-13782).
- virtiofs: Remove set but not used variable 'fc' (jsc#SLE-13782).
- virtiofs: Retry request submission from worker context
  (jsc#SLE-13782).
- virtiofs: Count pending forgets as in_flight forgets
  (jsc#SLE-13782).
- virtiofs: Set FR_SENT flag only after request has been sent
  (jsc#SLE-13782).
- virtiofs: No need to check fpq->connected state (jsc#SLE-13782).
- virtiofs: Do not end request in submission context
  (jsc#SLE-13782).
- fuse: don't advise readdirplus for negative lookup
  (jsc#SLE-13782).
- fuse: don't dereference req->args on finished request
  (jsc#SLE-13782).
- virtio-fs: don't show mount options (jsc#SLE-13782).
- commit ce0c590
* Thu Jan 14 2021 lhenriques@suse.de
- virtio-fs: Change module name to virtiofs.ko (jsc#SLE-13782).
- fuse: Make fuse_args_to_req static (jsc#SLE-13782).
- fuse: unexport fuse_put_request (jsc#SLE-13782).
- fuse: kmemcg account fs data (jsc#SLE-13782).
- fuse: on 64-bit store time in d_fsdata directly (jsc#SLE-13782).
- commit 5c78fc0
* Thu Jan 14 2021 lhenriques@suse.de
- virtio-fs: add virtiofs filesystem (jsc#SLE-13782).
- Refresh
  patches.suse/mac80211_hwsim-add-frame-transmission-support-over-v.patch.
- Update config files:
  CONFIG_VIRTIO_FS=m
- supported.conf: add virtiofs
- commit f56518a
* Thu Jan 14 2021 lhenriques@suse.de
- virtio-fs: add Documentation/filesystems/virtiofs.rst
  (jsc#SLE-13782).
- fuse: reserve values for mapping protocol (jsc#SLE-13782).
- fuse: reserve byteswapped init opcodes (jsc#SLE-13782).
- fuse: allow skipping control interface and forced unmount
  (jsc#SLE-13782).
- fuse: dissociate DESTROY from fuseblk (jsc#SLE-13782).
- fuse: delete dentry if timeout is zero (jsc#SLE-13782).
- fuse: separate fuse device allocation and installation in
  fuse_conn (jsc#SLE-13782).
- fuse: add fuse_iqueue_ops callbacks (jsc#SLE-13782).
- fuse: extract fuse_fill_super_common() (jsc#SLE-13782).
- fuse: export fuse_dequeue_forget() function (jsc#SLE-13782).
- commit ca085b1
* Thu Jan 14 2021 lhenriques@suse.de
- fuse: export fuse_get_unique() (jsc#SLE-13782).
- fuse: export fuse_send_init_request() (jsc#SLE-13782).
- fuse: export fuse_len_args() (jsc#SLE-13782).
- fuse: export fuse_end_request() (jsc#SLE-13782).
- fuse: stop copying pages to fuse_req (jsc#SLE-13782).
- fuse: stop copying args to fuse_req (jsc#SLE-13782).
- fuse: clean up fuse_req (jsc#SLE-13782).
- commit 0d1d5ea
* Thu Jan 14 2021 lhenriques@suse.de
- fuse: simplify request allocation (jsc#SLE-13782).
- Refresh
  patches.suse/fuse-fix-parameter-for-fs_ioc_-get-set-flags.patch.
- commit 7f8dfa3
* Thu Jan 14 2021 lhenriques@suse.de
- fuse: unexport request ops (jsc#SLE-13782).
- fuse: convert retrieve to simple api (jsc#SLE-13782).
- fuse: convert release to simple api (jsc#SLE-13782).
- cuse: convert init to simple api (jsc#SLE-13782).
- fuse: convert init to simple api (jsc#SLE-13782).
- commit 652a991
* Thu Jan 14 2021 lhenriques@suse.de
- fuse: convert writepages to simple api (jsc#SLE-13782).
- Refresh
  patches.suse/fuse-don-t-ignore-errors-from-fuse_writepages_fill.patch.
- commit d1549f6
* Thu Jan 14 2021 lhenriques@suse.de
- fuse: convert readdir to simple api (jsc#SLE-13782).
- fuse: convert readpages to simple api (jsc#SLE-13782).
- commit f65ef7d
* Thu Jan 14 2021 lhenriques@suse.de
- fuse: convert direct_io to simple api (jsc#SLE-13782).
- Refresh
  patches.suse/fix-up-iter-on-short-count-in-fuse_direct_io.patch.
- commit bfbe398
* Thu Jan 14 2021 tbogendoerfer@suse.de
- Update
  patches.suse/netfilter-add-and-use-nf_hook_slow_list.patch
  (bsc#1176447 bsc#1180765 CVE-2021-20177).
  Added CVE number.
- commit 8e9abe5
* Thu Jan 14 2021 lhenriques@suse.de
- fuse: add simple background helper (jsc#SLE-13782).
- fuse: convert sync write to simple api (jsc#SLE-13782).
- fuse: covert readpage to simple api (jsc#SLE-13782).
- fuse: fuse_short_read(): don't take fuse_req as argument
  (jsc#SLE-13782).
- fuse: convert ioctl to simple api (jsc#SLE-13782).
- commit 960efa9
* Thu Jan 14 2021 lhenriques@suse.de
- fuse: move page alloc (jsc#SLE-13782).
- Refresh
  patches.suse/fuse-fix-parameter-for-fs_ioc_-get-set-flags.patch.
- commit ae6a2de
* Thu Jan 14 2021 lhenriques@suse.de
- fuse: convert readlink to simple api (jsc#SLE-13782).
- fuse: add pages to fuse_args (jsc#SLE-13782).
- fuse: convert destroy to simple api (jsc#SLE-13782).
- fuse: add nocreds to fuse_args (jsc#SLE-13782).
- fuse: convert fuse_force_forget() to simple api (jsc#SLE-13782).
- fuse: add noreply to fuse_args (jsc#SLE-13782).
- fuse: convert flush to simple api (jsc#SLE-13782).
- fuse: simplify 'nofail' request (jsc#SLE-13782).
- fuse: rearrange and resize fuse_args fields (jsc#SLE-13782).
- commit 99f9f98
* Thu Jan 14 2021 lhenriques@suse.de
- fuse: flatten 'struct fuse_args' (jsc#SLE-13782).
- Refresh patches.suse/fuse-verify-attributes.patch.
- commit ace7210
* Thu Jan 14 2021 lhenriques@suse.de
- vfs: subtype handling moved to fuse (jsc#SLE-13782).
- fuse: convert to use the new mount API (jsc#SLE-13782).
- cuse: fix broken release (jsc#SLE-13782).
- commit b7625ea
* Thu Jan 14 2021 lhenriques@suse.de
- fuse: cleanup fuse_wait_on_page_writeback (jsc#SLE-13782).
- commit 6d24ff2
* Thu Jan 14 2021 lhenriques@suse.de
- fuse: require /dev/fuse reads to have enough buffer capacity
  (take 2) (jsc#SLE-13782).
- Refresh
  patches.suse/fuse-fix-deadlock-with-aio-poll-and-fuse_iqueue-wait.patch.
- commit acb8ea8
* Thu Jan 14 2021 oneukum@suse.com
- kABI fixup for dwc3 introduction of DWC_usb32 (git-fixes).
- commit 03d1108
* Thu Jan 14 2021 tiwai@suse.de
- ALSA: doc: Fix reference to mixart.rst (git-fixes).
- commit b4c3583
* Thu Jan 14 2021 tiwai@suse.de
- ASoC: meson: axg-tdm-interface: fix loopback (git-fixes).
- ASoC: dapm: remove widget from dirty list on free (git-fixes).
- ASoC: Intel: fix error code cnl_set_dsp_D0() (git-fixes).
- commit 04a1c91
* Thu Jan 14 2021 tiwai@suse.de
- ALSA: hda/hdmi - enable runtime pm for CI AMD display audio
  (git-fixes).
- ALSA: firewire-tascam: Fix integer overflow in midi_port_work()
  (git-fixes).
- ALSA: fireface: Fix integer overflow in transmit_midi_msg()
  (git-fixes).
- ALSA: hda/tegra: fix tegra-hda on tegra30 soc (git-fixes).
- clk: tegra30: Add hda clock default rates to clock driver
  (git-fixes).
- ALSA: usb-audio: Fix implicit feedback sync setup for Pioneer
  devices (git-fixes).
- ALSA: usb-audio: Annotate the endpoint index in audioformat
  (git-fixes).
- ALSA: usb-audio: Avoid unnecessary interface re-setup
  (git-fixes).
- ALSA: usb-audio: Choose audioformat of a counter-part substream
  (git-fixes).
- ALSA: usb-audio: Fix the missing endpoints creations for quirks
  (git-fixes).
- ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for
  HP machines (git-fixes).
- commit db30ae4
* Wed Jan 13 2021 bp@suse.de
- x86/apic: Fix x2apic enablement without interrupt remapping
  (bsc#1152489).
- commit a8a5227
* Wed Jan 13 2021 tbogendoerfer@suse.de
- netfilter: add and use nf_hook_slow_list() (bsc#1180765
  CVE-2021-20177).
- commit 465dae1
* Wed Jan 13 2021 bp@suse.de
- Refresh patches.suse/edac-amd64-add-amd-family-17h-model-60h-pci-ids.patch.
  Complete the backport now that
  5e4c55276ae8 ("EDAC/amd64: Save max number of controllers to family type")
  has been backported too.
- commit f6cb75f
* Wed Jan 13 2021 oneukum@suse.com
- usb: dwc3: Add support for DWC_usb32 IP (git-fixes).
- commit f699093
* Wed Jan 13 2021 tiwai@suse.de
- Input: elantech - fix protocol errors for some trackpoints in
  SMBus mode (bsc#1180870).
- Input: elan_i2c - add new trackpoint report type 0x5F
  (bsc#1180870).
- Input: synaptics - demote non-conformant kernel-doc header
  (bsc#1180870).
- Input: elan_i2c_core - move header inclusion inside
  (bsc#1180870).
- Input: elantech - demote obvious abuse of kernel-doc header
  (bsc#1180870).
- Input: elan_i2c - fix firmware update on newer ICs
  (bsc#1180870).
- Input: synaptics - enable InterTouch for ThinkPad T14 Gen 1
  (bsc#1180870).
- commit d5ab100
* Wed Jan 13 2021 tiwai@suse.de
- Input: synaptics - enable InterTouch for ThinkPad P1/X1E gen 2
  (bsc#1180870).
- Input: synaptics-rmi4 - rename f30_data to gpio_data
  (bsc#1180870).
- Input: elan_i2c - add ic type 0x15 (bsc#1180870).
- Input: elan_i2c - add support for high resolution reports
  (bsc#1180870).
- Input: elan_i2c - do not constantly re-query pattern ID
  (bsc#1180870).
- Input: elan_i2c - add firmware update info for ICs 0x11, 0x13,
  0x14 (bsc#1180870).
- Input: elan_i2c - handle firmware updated on newer ICs
  (bsc#1180870).
- Input: elan_i2c - add support for different firmware page sizes
  (bsc#1180870).
- Input: elan_i2c - fix detecting IAP version on older controllers
  (bsc#1180870).
- Input: elan_i2c - handle devices with patterns above 1
  (bsc#1180870).
- commit 8cfe63d
* Wed Jan 13 2021 tiwai@suse.de
- Input: elan_i2c - make fetching IC type of older controllers
  more robust (bsc#1180870).
- Input: elan_i2c - handle firmware not implementing "get pattern"
  command (bsc#1180870).
- Input: elantech - remove redundant assignments to variable error
  (bsc#1180870).
- Input: introduce input_mt_report_slot_inactive() (bsc#1180870).
- Input: psmouse - drop all unneeded functions from mouse headers
  (bsc#1180870).
- Input: synaptics - fix a typo (bsc#1180870).
- Input: elan_i2c - switch to using devm_add_action_or_reset()
  (bsc#1180870).
- Input: elan_i2c - switch to using devm_device_add_groups()
  (bsc#1180870).
- commit 6509eab
* Wed Jan 13 2021 nsaenzjulienne@suse.de
- nvmem: Add driver to expose reserved memory as nvmem (jsc#SLE-SLE-16616).
- Update config files: Enable nvmem-rmem as module on arm64 & armv7+lpae, disable it otherwise
- supported.conf: Add nvmem-rmem
  This is needed early to get boot-loader configuration working on RPi4;
  an essential feature.
- commit 212522b
* Wed Jan 13 2021 oneukum@suse.com
- usb: dwc3: Update soft-reset wait polling rate (git-fixes).
- commit 227b9e8
* Wed Jan 13 2021 mbrugger@suse.com
- drivers/perf: hisi: Permit modular builds of HiSilicon uncore drivers (bsc#1180848). - Update config files. - supported.conf:
- commit 3ceea3c
* Wed Jan 13 2021 martin.wilck@suse.com
- scsi: scsi_transport_srp: Don't block target in failfast state
  (bsc#1172355).
- commit 4d51a17
* Wed Jan 13 2021 jgross@suse.com
- xen: support having only one event pending per watch
  (bsc#1179508 XSA-349 CVE-2020-29568).
- commit b454020
* Wed Jan 13 2021 jgross@suse.com
- xen: revert Allow watches discard events before queueing
  (bsc#1179508 XSA-349 CVE-2020-29568).
- commit 7a45cd4
* Wed Jan 13 2021 jgross@suse.com
- xen: revert Add 'will_handle' callback support in
  xenbus_watch_path() (bsc#1179508 XSA-349 CVE-2020-29568).
- commit b9e03df
* Wed Jan 13 2021 jgross@suse.com
- xen: revert Support will_handle watch callback (bsc#1179508
  XSA-349 CVE-2020-29568).
- commit 3082598
* Wed Jan 13 2021 jgross@suse.com
- xen: revert Count pending messages for each watch (bsc#1179508
  XSA-349 CVE-2020-29568).
- commit 9d4ca48
* Wed Jan 13 2021 tiwai@suse.de
- video: fbdev: atmel_lcdfb: fix return error code in
  atmel_lcdfb_of_init() (git-fixes).
- video: fbdev: vga16fb: fix setting of pixclock because a
  pass-by-value error (git-fixes).
- video: fbdev: pvr2fb: initialize variables (git-fixes).
- video: fbdev: fix OOB read in vga_8planes_imageblit()
  (git-fixes).
- commit 7cdcf45
* Wed Jan 13 2021 jgross@suse.com
- xen: revert Disallow pending watch messages (bsc#1179508
  XSA-349 CVE-2020-29568).
- commit a948c9f
* Wed Jan 13 2021 tiwai@suse.de
- ntb: idt: fix error check in ntb_hw_idt.c (jsc#SLE-13360).
- commit 93a77b3
* Wed Jan 13 2021 tiwai@suse.de
- usb: gadget: enable super speed plus (git-fixes).
- USB: serial: option: add LongSung M5710 module support
  (git-fixes).
- USB: serial: option: add Quectel EM160R-GL (git-fixes).
- usb: uas: Add PNY USB Portable SSD to unusual_uas (git-fixes).
- usb: gadget: configfs: Fix use-after-free issue with udc_name
  (git-fixes).
- USB: usblp: fix DMA to stack (git-fixes).
- usb: gadget: Fix spinlock lockup on usb_function_deactivate
  (git-fixes).
- usb: gadget: function: printer: Fix a memory leak for interface
  descriptor (git-fixes).
- USB: cdc-wdm: Fix use after free in
  service_outstanding_interrupt() (git-fixes).
- USB: cdc-acm: blacklist another IR Droid device (git-fixes).
- crypto: asym_tpm: correct zero out potential secrets
  (git-fixes).
- net: usb: qmi_wwan: add Quectel EM160R-GL (git-fixes).
- CDC-NCM: remove "connected" log message (git-fixes).
- ethernet: ucc_geth: fix use-after-free in ucc_geth_remove()
  (git-fixes).
- lib/genalloc: fix the overflow when size is too big (git-fixes).
- Bluetooth: revert: hci_h5: close serdev device and free hu in
  h5_close (git-fixes).
- commit 052b915
* Wed Jan 13 2021 tiwai@suse.de
- drm/panfrost: Move the GPU reset bits outside the timeout
  handler (git-fixes).
- drm/panfrost: don't use pfdevfreq.busy_count to know if hw is
  idle (git-fixes).
- commit 173f5a4
* Wed Jan 13 2021 tiwai@suse.de
- drm/panfrost: Remove unused variables in panfrost_job_close()
  (git-fixes).
- commit 11a7e60
* Wed Jan 13 2021 tiwai@suse.de
- drm/panfrost: Don't corrupt the queue mutex on open/close
  (git-fixes).
- commit a5f75e8
* Wed Jan 13 2021 tiwai@suse.de
- drm/i915/dp: Track pm_qos per connector (git-fixes).
- drm/i915: clear the shadow batch (git-fixes).
- drm/i915: Fix mismatch between misplaced vma check and vma
  insert (git-fixes).
- drm/amd/display: updated wm table for Renoir (git-fixes).
- drm/meson: dw-hdmi: Enable the iahb clock early enough
  (git-fixes).
- commit 11d51e1
* Wed Jan 13 2021 tiwai@suse.de
- drm/meson: dw-hdmi: Disable clocks on driver teardown
  (git-fixes).
- drm/edid: fix objtool warning in drm_cvt_modes() (git-fixes).
- drm/amdkfd: Fix leak in dmabuf import (git-fixes).
- drm/amd/display: Prevent bandwidth overflow (git-fixes).
- drm/amdgpu: fix compute queue priority if num_kcq is less than 4
  (git-fixes).
- drm/msm/dsi_phy_10nm: implement PHY disabling (git-fixes).
- drm/msm/dsi_pll_10nm: restore VCO rate during restore_state
  (git-fixes).
- drm/msm/dpu: Add newline to printks (git-fixes).
- drm/mediatek: Use correct aliases name for ovl (git-fixes).
- drm/meson: dw-hdmi: Ensure that clocks are enabled before
  touching the TOP registers (git-fixes).
- commit d189b05
* Wed Jan 13 2021 tiwai@suse.de
- drm/meson: dw-hdmi: Register a callback to disable the regulator
  (git-fixes).
- drm/meson: Unbind all connectors on module removal (git-fixes).
- drm/meson: Free RDMA resources after tearing down DRM
  (git-fixes).
- drm/omap: dmm_tiler: fix return error code in omap_dmm_probe()
  (git-fixes).
- drm/udl: Fix missing error code in udl_handle_damage()
  (git-fixes).
- drm/i915: Avoid mixing integer types during batch copies
  (git-fixes).
- drm/amdgpu: fix build_coefficients() argument (git-fixes).
- drm/amdgpu: fix incorrect enum type (git-fixes).
- drm/amd/display: remove useless if/else (git-fixes).
- commit 714ea88
* Wed Jan 13 2021 tiwai@suse.de
- drm/i915/tgl: Fix Combo PHY DPLL fractional divider for 38.4MHz
  ref clock (git-fixes).
- drm/panel: simple: Add flags to boe_nv133fhm_n61 (git-fixes).
- drm/edid: Fix uninitialized variable in drm_cvt_modes()
  (git-fixes).
- drm/bridge: tpd12s015: Fix irq registering in tpd12s015_probe
  (git-fixes).
- drm/tve200: Fix handling of platform_get_irq() error
  (git-fixes).
- drm/mcde: Fix handling of platform_get_irq() error (git-fixes).
- drm/dp_aux_dev: check aux_dev before use in
  drm_dp_aux_dev_get_by_minor() (git-fixes).
- drm/aspeed: Fix Kconfig warning & subsequent build errors
  (git-fixes).
- drm/panfrost: Fix job timeout handling (git-fixes).
- commit 2743044
* Tue Jan 12 2021 lduncan@suse.com
- scsi: qedi: Correct max length of CHAP secret (bsc#1180221).
- commit 5b6934e
* Tue Jan 12 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/sched-fair-Check-for-idle-core-in-wake_affine.patch
- commit b5830a4
* Tue Jan 12 2021 tiwai@suse.de
- drm/gma500: fix double free of gma_connector (git-fixes).
- drm/i915/gt: Declare gen9 has 64 mocs entries! (git-fixes).
- drm/i915/display/dp: Compute the correct slice count for VDSC
  on DP (git-fixes).
- drm/i915/gt: Cancel the preemption timeout on responding to it
  (git-fixes).
- drm/i915/gt: Ignore repeated attempts to suspend request flow
  across reset (git-fixes).
- drm/i915/gem: Propagate error from cancelled submit due to
  context closure (git-fixes).
- drm/amdgpu: fix sdma instance fw version and feature version
  init (git-fixes).
- drm/amdgpu/disply: set num_crtc earlier (git-fixes).
- drm/omap: sdi: fix bridge enable/disable (git-fixes).
- drm/panel: sony-acx565akm: Fix race condition in probe
  (git-fixes).
- commit cdc5bb1
* Tue Jan 12 2021 tiwai@suse.de
- drm/rockchip: Avoid uninitialized use of endpoint id in LVDS
  (git-fixes).
- drm/amdgpu/vcn3.0: remove old DPG workaround (git-fixes).
- drm/amdgpu/vcn3.0: stall DPG when WPTR/RPTR reset (git-fixes).
- drm/amd/display: Init clock value by current vbios CLKs
  (git-fixes).
- drm/i915/gt: Limit frequency drop to RPe on parking (git-fixes).
- drm/i915/gt: Retain default context state across shrinking
  (git-fixes).
- drm/i915/gt: Program mocs:63 for cache eviction on gen9
  (git-fixes).
- drm/tegra: sor: Disable clocks on error in tegra_sor_init()
  (git-fixes).
- drm/tegra: replace idr_init() by idr_init_base() (git-fixes).
- drm/nouveau: fix relocations applying logic and a double-free
  (git-fixes).
- commit 83684ef
* Tue Jan 12 2021 tiwai@suse.de
- drm/mediatek: dsi: Modify horizontal front/back porch byte
  formula (git-fixes).
- drm/exynos: depend on COMMON_CLK to fix compile tests
  (git-fixes).
- drm/i915/gt: Free stale request on destroying the virtual engine
  (git-fixes).
- drm/i915/perf: workaround register corruption in OATAILPTR
  (git-fixes).
- drm/amdgpu: update golden setting for sienna_cichlid
  (git-fixes).
- drm/amd/display: Avoid HDCP initialization in devices without
  output (git-fixes).
- drm/amdgpu: fix a page fault (git-fixes).
- drm/amdgpu: fix SI UVD firmware validate resume fail
  (git-fixes).
- drm/amd/amdgpu: fix null pointer in runtime pm (git-fixes).
- drm/i915/gt: Fixup tgl mocs for PTE tracking (git-fixes).
- commit 4d0b8ee
* Tue Jan 12 2021 bp@suse.de
- blacklist.conf: 4f8af077a02e docs: Fix reST markup when linking to sections
- commit 28e1ebf
* Tue Jan 12 2021 tiwai@suse.de
- drm/i915/gvt: return error when failing to take the module
  reference (git-fixes).
- drm/i915/gvt: Set ENHANCED_FRAME_CAP bit (git-fixes).
- drm/i915: Handle max_bpc==16 (git-fixes).
- drm/i915/selftests: Fix wrong return value of
  perf_request_latency() (git-fixes).
- drm/i915/selftests: Fix wrong return value of
  perf_series_engines() (git-fixes).
- drm/i915: Avoid memory leak with more than 16 workarounds on
  a list (git-fixes).
- drm/i915/tgl: Fix Media power gate sequence (git-fixes).
- drm/sun4i: dw-hdmi: fix error return code in
  sun8i_dw_hdmi_bind() (git-fixes).
- drm: bridge: dw-hdmi: Avoid resetting force in the detect
  function (git-fixes).
- drm/amd/display: Add missing pflip irq for dcn2.0 (git-fixes).
- commit c514745
* Tue Jan 12 2021 tiwai@suse.de
- drm/amd/display: Add missing pflip irq (git-fixes).
- drm/i915: Correctly set SFC capability for video engines
  (git-fixes).
- drm/gma500: Fix out-of-bounds access to struct
  drm_device.vblank[] (git-fixes).
- drm/panfrost: Fix module unload (git-fixes).
- drm/panfrost: Fix a deadlock between the shrinker and madvise
  path (git-fixes).
- drm/amdgpu: resolved ASD loading issue on sienna (git-fixes).
- drm/amdgpu: update golden setting for sienna_cichlid
  (git-fixes).
- drm/amdgpu: perform srbm soft reset always on SDMA resume
  (git-fixes).
- drm/i915: Fix encoder lookup during PSR atomic check
  (git-fixes).
- drm/i915/gt: Use the local HWSP offset during submission
  (git-fixes).
- commit f811a3d
* Tue Jan 12 2021 tiwai@suse.de
- drm/i915/gvt: Only pin/unpin intel_context along with workload
  (git-fixes).
- drm/imx: parallel-display: remove unused function enc_to_imxpd()
  (git-fixes).
- drm/i915: Reject 90/270 degree rotated initial fbs (git-fixes).
- drm/i915: Restore ILK-M RPS support (git-fixes).
- drm/i915/region: fix max size calculation (git-fixes).
- drm/nouveau/device: fix changing endianess code to work on
  older GPUs (git-fixes).
- drm/nouveau/gem: fix "refcount_t: underflow; use-after-free"
  (git-fixes).
- drm/nouveau/kms/nv50-: Program notifier offset before requesting
  disp caps (git-fixes).
- drm/nouveau/nouveau: fix the start/end range for migration
  (git-fixes).
- drm/shme-helpers: Fix dma_buf_mmap forwarding bug (git-fixes).
- commit f9a03a3
* Tue Jan 12 2021 tiwai@suse.de
- drm/v3d: Fix double free in v3d_submit_cl_ioctl() (git-fixes).
- drm/sun4i: frontend: Fix the scaler phase on A33 (git-fixes).
- drm/sun4i: frontend: Reuse the ch0 phase for RGB formats
  (git-fixes).
- drm/sun4i: frontend: Rework a bit the phase data (git-fixes).
- drm/amd/display: Don't invoke kgdb_breakpoint() unconditionally
  (git-fixes).
- drm/amd/display: Fix kernel panic by dal_gpio_open() error
  (git-fixes).
- drm/amd/display: adding ddc_gpio_vga_reg_list to ddc reg def'ns
  (git-fixes).
- drm/amdgpu: increase the reserved VM size to 2MB (git-fixes).
- drm/amd/display: Fixed panic during seamless boot (git-fixes).
- drm/amdgpu: don't map BO in reserved region (git-fixes).
- commit adc6b7e
* Tue Jan 12 2021 tiwai@suse.de
- drm/amdgpu: add DID for navi10 blockchain SKU (git-fixes).
- drm/amdgpu: disable DCN and VCN for navi10 blockchain SKU(v3)
  (git-fixes).
- drm/i915: Drop runtime-pm assert from vgpu io accessors
  (git-fixes).
- drm/i915: Force VT'd workarounds when running as a guest OS
  (git-fixes).
- drm/i915: Exclude low pages (128KiB) of stolen from use
  (git-fixes).
- drm/i915: Use the active reference on the vma while capturing
  (git-fixes).
- drm/i915/gt: Undo forced context restores after trivial
  preemptions (git-fixes).
- drm/i915/gt: Delay execlist processing for tgl (git-fixes).
- drm/i915: Mark ininitial fb obj as WT on eLLC machines to
  avoid rcu lockup during fbdev init (git-fixes).
- drm/i915/gt: Initialize reserved and unspecified MOCS indices
  (git-fixes).
- commit fdd5a7c
* Tue Jan 12 2021 tiwai@suse.de
- drm/i915/dp: Tweak initial dpcd backlight.enabled value
  (git-fixes).
- drm/amdgpu: correct the cu and rb info for sienna cichlid
  (git-fixes).
- drm/amdkfd: Use same SQ prefetch setting as amdgpu (git-fixes).
- drm/amd/psp: Fix sysfs: cannot create duplicate filename
  (git-fixes).
- drm/amd/display: Avoid MST manager resource leak (git-fixes).
- drm/amdgpu: update golden setting for sienna_cichlid
  (git-fixes).
- drm/amdgpu: correct the gpu reset handling for job != NULL case
  (git-fixes).
- drm/amdgpu: add rlc iram and dram firmware support (git-fixes).
- drm/amdgpu: add function to program pbb mode for sienna cichlid
  (git-fixes).
- drm/ttm: fix eviction valuable range check (git-fixes).
- commit 6b6cb10
* Tue Jan 12 2021 tiwai@suse.de
- drm/i915: Set all unused color plane offsets to ~0xfff again
  (git-fixes).
- drm/i915: Fix TGL DKL PHY DP vswing handling (git-fixes).
- drm/amdgpu: vcn and jpeg ring synchronization (git-fixes).
- drm/amdgpu: Fix invalid number of character '{' in
  amdgpu_acpi_init (git-fixes).
- drm/amd/display: HDMI remote sink need mode validation for Linux
  (git-fixes).
- drm/amd/display: Avoid set zero in the requested clk
  (git-fixes).
- drm/amd/display: Increase timeout for DP Disable (git-fixes).
- drm/amd/display: Fix incorrect backlight register offset for
  DCN (git-fixes).
- drm/i915/gem: Always test execution status on closing the
  context (git-fixes).
- drm/i915/gt: Always send a pulse down the engine after disabling
  heartbeat (git-fixes).
- commit 6c3296a
* Tue Jan 12 2021 tiwai@suse.de
- drm/i915: Cancel outstanding work after disabling heartbeats
  on an engine (git-fixes).
- drm/i915/gem: Serialise debugfs i915_gem_objects with ctx->mutex
  (git-fixes).
- drm/i915: Break up error capture compression loops with
  cond_resched() (git-fixes).
- drm/i915/gem: Prevent using pgprot_writecombine() if PAT is
  not supported (git-fixes).
- drm/i915: Fix state checker hw.active/hw.enable readout
  (git-fixes).
- drm/msm: Fix the a650 hw_apriv check (git-fixes).
- drm/msm/a6xx: fix a potential overflow issue (git-fixes).
- drm/msm/adreno: fix probe without iommu (git-fixes).
- drm/panfrost: add Amlogic GPU integration quirks (git-fixes).
- drm/panfrost: add amlogic reset quirk callback (git-fixes).
- commit dde6379
* Tue Jan 12 2021 tiwai@suse.de
- drm/panfrost: add support for vendor quirk (git-fixes).
- drm: fix double free for gbo in drm_gem_vram_init and
  drm_gem_vram_create (git-fixes).
- drm/xlnx: Use devm_drm_dev_alloc (git-fixes).
- drm/bridge/synopsys: dsi: add support for non-continuous HS
  clock (git-fixes).
- drm/amd/display: Delete duplicated argument to '&&' or '||'
  (git-fixes).
- drm/amdgpu: No sysfs, not an error condition (git-fixes).
- drm/amd/display: Check clock table return (git-fixes).
- drm: panfrost: fix common struct sg_table related issues
  (git-fixes).
- drm: lima: fix common struct sg_table related issues
  (git-fixes).
- commit 0a6baa2
* Tue Jan 12 2021 tiwai@suse.de
- drm: exynos: fix common struct sg_table related issues
  (git-fixes).
- drm/vkms: avoid warning in vkms_get_vblank_timestamp
  (git-fixes).
- drm/amdgpu: fix max_entries calculation v4 (git-fixes).
- drm/amd/display: fix potential integer overflow when shifting
  32 bit variable bl_pwm (git-fixes).
- drm/scheduler: Scheduler priority fixes (v2) (git-fixes).
- drm/amd/display: Screen corruption on dual displays (DP+USB-C)
  (git-fixes).
- drm/amd/display: Disconnect pipe separetely when disable pipe
  split (git-fixes).
- drm/amdgpu: restore ras flags when user resets eeprom(v2)
  (git-fixes).
- Revert "drm/amdgpu: Fix NULL dereference in dpm sysfs handlers"
  (git-fixes).
- drm/amdgpu: Remove redundant NULL check (git-fixes).
- commit cf5d051
* Tue Jan 12 2021 tiwai@suse.de
- drm/bridge_connector: Set default status connected for eDP
  connectors (git-fixes).
- drm/brige/megachips: Add checking if ge_b850v3_lvds_init()
  is working correctly (git-fixes).
- drm/malidp: Use struct drm_gem_object_funcs.get_sg_table
  internally (git-fixes).
- drm/hisilicon: Code refactoring for hibmc_drv_de (git-fixes).
- drm/vkms: add missing platform_device_unregister() in
  vkms_init() (git-fixes).
- drm/vgem: add missing platform_device_unregister() in
  vgem_init() (git-fixes).
- drm/panfrost: perfcnt: fix ref count leak in
  panfrost_perfcnt_enable_locked (git-fixes).
- drm/panfrost: move devfreq_init()/fini() in device (git-fixes).
- drm/panfrost: rename error labels in device_init (git-fixes).
- commit 86204b1
* Tue Jan 12 2021 tiwai@suse.de
- dma-buf/dma-resv: Respect num_fences when initializing the
  shared fence list (git-fixes).
- drm/mediatek: set dpi pin mode to gpio low to avoid leakage
  current (git-fixes).
- drm/i915: Stub out i915_gpu_coredump_put (git-fixes).
- commit 145aef1
* Tue Jan 12 2021 tiwai@suse.de
- Bluetooth: Fix attempting to set RPA timeout when unsupported
  (git-fixes).
- commit d1047e2
* Tue Jan 12 2021 oneukum@suse.com
- usb: dwc3: core: Properly default unspecified speed (git-fixes).
- commit 777b42e
* Mon Jan 11 2021 bp@suse.de
- x86/sev-es: Fix SEV-ES OUT/IN immediate opcode vc handling
  (bsc#1178134).
- commit 0b7cd9d
* Mon Jan 11 2021 bp@suse.de
- x86/resctrl: Don't move a task to the same resource group
  (bsc#1152489).
- commit 8a696c5
* Mon Jan 11 2021 bp@suse.de
- x86/resctrl: Use an IPI instead of task_work_add() to update
  PQR_ASSOC MSR (bsc#1152489).
- commit 309f3cb
* Mon Jan 11 2021 bp@suse.de
- x86/mtrr: Correct the range check before performing MTRR type
  lookups (bsc#1152489).
- commit 41cceca
* Mon Jan 11 2021 bp@suse.de
- x86/mm: Fix leak of pmd ptlock (bsc#1152489).
- commit cb571f0
* Mon Jan 11 2021 fdmanana@suse.com
- btrfs: fix missing delalloc new bit for new delalloc ranges
  (bsc#1180773).
- btrfs: make btrfs_dirty_pages take btrfs_inode (bsc#1180773).
- btrfs: make btrfs_set_extent_delalloc take btrfs_inode
  (bsc#1180773).
- commit fba9b10
* Mon Jan 11 2021 tbogendoerfer@suse.de
- IB/hfi1: Ensure correct mm is used at all times (bsc#1179878
  CVE-2020-27835).
- IB/hfi1: Remove module parameter for KDETH qpns (bsc#1179878).
- IB/hfi1: Remove kobj from hfi1_devdata (bsc#1179878).
- commit 79bac5c
* Mon Jan 11 2021 tiwai@suse.de
- regmap: debugfs: Fix a reversed if statement in
  regmap_debugfs_init() (git-fixes).
- commit 6e1e482
* Mon Jan 11 2021 tiwai@suse.de
- USB: serial: iuu_phoenix: fix DMA from stack (git-fixes).
- usb: gadget: configfs: Preserve function ordering after bind
  failure (git-fixes).
- usb: gadget: select CONFIG_CRC32 (git-fixes).
- usb: usbip: vhci_hcd: protect shift size (git-fixes).
- usb: gadget: f_uac2: reset wMaxPacketSize (git-fixes).
- usb: dwc3: ulpi: Use VStsDone to detect PHY regs access
  completion (git-fixes).
- USB: yurex: fix control-URB timeout handling (git-fixes).
- usb: chipidea: ci_hdrc_imx: add missing put_device() call in
  usbmisc_get_init_data() (git-fixes).
- usb: gadget: u_ether: Fix MTU size mismatch with RX packet size
  (git-fixes).
- USB: gadget: legacy: fix return error code in acm_ms_bind()
  (git-fixes).
- USB: xhci: fix U1/U2 handling for hardware with XHCI_INTEL_HOST
  quirk set (git-fixes).
- staging: mt7621-dma: Fix a resource leak in an error handling
  path (git-fixes).
- dmaengine: xilinx_dma: fix mixed_enum_type coverity warning
  (git-fixes).
- dmaengine: xilinx_dma: fix incompatible param warning in
  _child_probe() (git-fixes).
- dmaengine: xilinx_dma: check dma_async_device_register return
  value (git-fixes).
- dmaengine: dw-edma: Fix use after free in dw_edma_alloc_chunk()
  (git-fixes).
- dmaengine: mediatek: mtk-hsdma: Fix a resource leak in the
  error handling path of the probe function (git-fixes).
- i2c: i801: Fix the i2c-mux gpiod_lookup_table not being properly
  terminated (git-fixes).
- i2c: sprd: use a specific timeout to avoid system hang up issue
  (git-fixes).
- wan: ds26522: select CONFIG_BITREVERSE (git-fixes).
- wil6210: select CONFIG_CRC32 (git-fixes).
- crypto: ecdh - avoid buffer overflow in ecdh_set_secret()
  (git-fixes).
- spi: stm32: FIFO threshold level - fix align packet size
  (git-fixes).
- regmap: debugfs: Fix a memory leak when calling
  regmap_attach_dev (git-fixes).
- dmaengine: at_hdmac: add missing kfree() call in at_dma_xlate()
  (git-fixes).
- dmaengine: at_hdmac: add missing put_device() call in
  at_dma_xlate() (git-fixes).
- dmaengine: at_hdmac: Substitute kzalloc with kmalloc
  (git-fixes).
- commit da0ba2f
* Mon Jan 11 2021 mgorman@suse.de
- sched/fair: Check for idle core in wake_affine (git fixes
  (sched)).
- commit 2caffed
* Mon Jan 11 2021 nsaenzjulienne@suse.de
- arm64: mm: Fix ARCH_LOW_ADDRESS_LIMIT when !CONFIG_ZONE_DMA
  (git-fixes).
- commit 52bc22f
* Mon Jan 11 2021 nsaenzjulienne@suse.de
- blacklist.conf: 2c2b3ad2c4c8 ("spi: spi-fsl-dspi: Use max_native_cs
  instead of num_chipselect to set SPI_MCR")
  Depends on 7d93aecdb58d4 ("spi: Add generic support for unused native cs
  with cs-gpios") which at the moment is not worth back-porting as it'll
  break kABI.
- commit bafcdfd
* Mon Jan 11 2021 jgross@suse.com
- xen-blkback: set ring->xenblkd to NULL after kthread_stop()
  (bsc#1179509 XSA-350 CVE-2020-29569).
- commit 552ca06
* Mon Jan 11 2021 jgross@suse.com
- xenbus/xenbus_backend: Disallow pending watch messages
  (bsc#1179508 XSA-349 CVE-2020-29568).
- commit b293dfc
* Mon Jan 11 2021 jgross@suse.com
- xen/xenbus: Count pending messages for each watch (bsc#1179508
  XSA-349 CVE-2020-29568).
- commit d8a62d9
* Mon Jan 11 2021 jgross@suse.com
- xen/xenbus/xen_bus_type: Support will_handle watch callback
  (bsc#1179508 XSA-349 CVE-2020-29568).
- commit 8be4352
* Mon Jan 11 2021 jgross@suse.com
- xen/xenbus: Add 'will_handle' callback support in
  xenbus_watch_path() (bsc#1179508 XSA-349 CVE-2020-29568).
- commit 4383a8c
* Mon Jan 11 2021 jgross@suse.com
- xen/xenbus: Allow watches discard events before queueing
  (bsc#1179508 XSA-349 CVE-2020-29568).
- commit ec8d064
* Fri Jan  8 2021 tiwai@suse.de
- drm: bail out of nouveau_channel_new if channel init fails
  (CVE-2020-25639 bsc#1176846).
- commit 1ef70aa
* Fri Jan  8 2021 dwagner@suse.de
- nvme-multipath: fix bogus request queue reference put
  (bsc#1175389).
- commit ef51578
* Fri Jan  8 2021 glin@suse.com
- selftests/bpf: Move and extend ASSERT_xxx() testing macros
  (bsc#1177028).
- libbpf: Add __noinline macro to bpf_helpers.h (bsc#1177028).
- commit 630edda
* Fri Jan  8 2021 wqu@suse.com
- Move "btrfs: qgroup: don't try to wait flushing if we're already holding
  a transaction (bsc#1179575)." to sorted section
- commit 464edf7
* Thu Jan  7 2021 msuchanek@suse.de
- Refresh patches.suse/nvdimm-Avoid-race-between-probe-and-reading-device-a.patch.
  Refresh to v2 URL
- commit 82e37f2
* Thu Jan  7 2021 bp@suse.de
- blacklist.conf: 44623b2818f4 crypto: x86/crc32c - fix building with clang ias
- commit 4260c52
* Thu Jan  7 2021 bp@suse.de
- x86/mm/numa: Remove uninitialized_var() usage (bsc#1152489).
- commit ec737c3
* Thu Jan  7 2021 colyli@suse.de
- mm: fix phys_to_target_node() and memory_add_physaddr_to_nid()
  exports (jsc#SLE-14344).
- device-dax/kmem: fix resource release (jsc#SLE-14344).
- device-dax: add a range mapping allocation attribute
  (jsc#SLE-14344).
- dax/hmem: introduce dax_hmem.region_idle parameter
  (jsc#SLE-14344).
- device-dax: add an 'align' attribute (jsc#SLE-14344).
- device-dax: make align a per-device property (jsc#SLE-14344).
- device-dax: introduce 'mapping' devices (jsc#SLE-14344).
- device-dax: add dis-contiguous resource support (jsc#SLE-14344).
- mm/memremap_pages: support multiple ranges per invocation
  (jsc#SLE-14344).
- mm/memremap_pages: convert to 'struct range' (jsc#SLE-14368).
- device-dax: add resize support (jsc#SLE-14344).
- drivers/base: make device_find_child_by_name() compatible with
  sysfs inputs (jsc#SLE-14344).
- device-dax: introduce 'seed' devices (jsc#SLE-14344).
- device-dax: introduce 'struct dev_dax' typed-driver operations
  (jsc#SLE-14344).
- device-dax: add an allocation interface for device-dax instances
  (jsc#SLE-14344).
- device-dax/kmem: replace release_resource() with
  release_mem_region() (jsc#SLE-14344).
- device-dax/kmem: move resource name tracking to drvdata
  (jsc#SLE-14344).
- device-dax/kmem: introduce dax_kmem_range() (jsc#SLE-14344).
- device-dax: make pgmap optional for instance creation
  (jsc#SLE-14344).
- device-dax: move instance creation parameters to 'struct
  dev_dax_data' (jsc#SLE-14344).
- device-dax: drop the dax_region.pfn_flags attribute
  (jsc#SLE-14344).
- ACPI: HMAT: attach a device for each soft-reserved range
  (jsc#SLE-14344).
- mm/memory_hotplug: introduce default phys_to_target_node()
  implementation (jsc#SLE-14344).
- resource: report parent to walk_iomem_res_desc() callback
  (jsc#SLE-14344).
- ACPI: HMAT: refactor hmat_register_target_device to
  hmem_register_device (jsc#SLE-14344).
- efi/fake_mem: arrange for a resource entry per efi_fake_mem
  instance (jsc#SLE-14344).
- x86/numa: add 'nohmat' option (jsc#SLE-14344).
- x86/numa: cleanup configuration dependent command-line options
  (jsc#SLE-14344).
- mm/memory_hotplug: introduce default dummy
  memory_add_physaddr_to_nid() (jsc#SLE-14344).
- device-dax: add memory via add_memory_driver_managed()
  (jsc#SLE-14344).
- commit 5becd55
* Thu Jan  7 2021 colyli@suse.de
- mm/memory_hotplug: introduce add_memory_driver_managed()
  (jsc#SLE-14344).
- Refresh for the above patch,
  patches.suse/0001-mm-don-t-panic-when-links-can-t-be-created-in-sysfs.patch.
- commit 788a9a9
* Thu Jan  7 2021 colyli@suse.de
- device-dax: don't leak kernel memory to user space after
  unloading kmem (jsc#SLE-14344).
- commit b01827a
* Thu Jan  7 2021 colyli@suse.de
- mm/memremap: set caching mode for PCI P2PDMA memory to WC
  (jsc#SLE-14344).
- Refresh for the above patch,
  patches.suse/1933-memremap-rename-MEMORY_DEVICE_DEVDAX-to-MEMORY_DEVIC.patch.
- commit 4730420
* Thu Jan  7 2021 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/ibmvnic-continue-fatal-error-reset-after-passive-ini.patch
- commit c554179
* Thu Jan  7 2021 colyli@suse.de
- mm/memory_hotplug: add pgprot_t to mhp_params (jsc#SLE-14344).
- Refresh for the above patch,
  patches.suse/powerpc-mm-Limit-resize_hpt_for_hotplug-call-to-hash.patch.
- commit 92a2c86
* Thu Jan  7 2021 colyli@suse.de
- powerpc/mm: thread pgprot_t through create_section_mapping()
  (jsc#SLE-14344).
- Refresh for the above patch,
  patches.suse/powerpc-mm-Limit-resize_hpt_for_hotplug-call-to-hash.patch.
  patches.suse/powerpc-mm-radix-Create-separate-mappings-for-hot-pl.patch.
  patches.suse/powerpc-mm-radix-Remove-split_kernel_mapping.patch.
- commit 22697fb
* Thu Jan  7 2021 tiwai@suse.de
- ntb: intel: add Intel NTB LTR vendor support for gen4 NTB
  (jsc#SLE-12710).
- commit 22de07c
* Thu Jan  7 2021 colyli@suse.de
- x86/mm: thread pgprot_t through init_memory_mapping()
  (jsc#SLE-14344).
- Refresh for the above patch,
  patches.suse/x86-platform-uv-Remove-uv-bios-and-efi-code-related-.patch.
- commit 9cc6133
* Thu Jan  7 2021 colyli@suse.de
- mm/memory_hotplug: rename mhp_restrictions to mhp_params
  (jsc#SLE-14368).
- mm/memory_hotplug: drop the flags field from struct
  mhp_restrictions (jsc#SLE-14344).
- dax: Move mandatory ->zero_page_range() check in alloc_dax()
  (jsc#SLE-14344).
- libnvdimm/e820: Retrieve and populate correct 'target_node'
  info (jsc#SLE-14344).
- x86/NUMA: Provide a range-to-target_node lookup facility
  (jsc#SLE-14344).
- x86/mm: Introduce CONFIG_NUMA_KEEP_MEMINFO (jsc#SLE-14344).
- Update following config files for the above patch,
  config/arm64/default
  config/ppc64le/default
  config/s390x/default
  config/x86_64/default
- commit 3d588c7
* Thu Jan  7 2021 colyli@suse.de
- powerpc/papr_scm: Switch to numa_map_to_online_node()
  (jsc#SLE-14344).
- Refresh for the above patch,
  patches.suse/powerpc-papr_scm-Fetch-nvdimm-health-information-fro.patch.
  patches.suse/powerpc-papr_scm-Fetch-nvdimm-performance-stats-from.patch.
- commit 9f14d6c
* Thu Jan  7 2021 colyli@suse.de
- mm/numa: Skip NUMA_NO_NODE and online nodes in
  numa_map_to_online_node() (jsc#SLE-14344).
- commit f7082df
* Thu Jan  7 2021 colyli@suse.de
- mm/memory_hotplug.c: add a bounds check to __add_pages()
  (jsc#SLE-14344).
- dax: Add numa_node to the default device-dax attributes
  (jsc#SLE-14344).
- dax: Simplify root read-only definition for the 'resource'
  attribute (jsc#SLE-14344).
- dax: Create a dax device_type (jsc#SLE-14344).
- dax: Fix alloc_dax_region() compile warning (jsc#SLE-14344).
- commit 4c51fce
* Thu Jan  7 2021 mkubecek@suse.cz
- Update kabi files.
- update from January 2021 maintenance update submission (commit 4ff469b6e1a0)
- commit a9bc2aa
* Thu Jan  7 2021 tiwai@suse.de
- ALSA: usb-audio: Add alias entry for ASUS PRIME TRX40 PRO-S
  (git-fixes).
- ACPI: HMAT: Fix handling of changes from ACPI 6.2 to ACPI 6.3
  (git-fixes).
- ACPI: Add out of bounds and numa_off protections to
  pxm_to_node() (git-fixes).
- ehci-hcd: Move include to keep CRC stable (git-fixes).
- commit 407490e
* Thu Jan  7 2021 tiwai@suse.de
- bus/fsl_mc: Do not rely on caller to provide non NULL mc_io
  (git-fixes).
- commit e4eab60
* Thu Jan  7 2021 tiwai@suse.de
- ALSA: hda/realtek - Modify Dell platform name (git-fixes).
- ALSA: hda/realtek - Supported Dell fixed type headset
  (git-fixes).
- ALSA: hda/realtek: Remove dummy lineout on Acer TravelMate
  P648/P658 (git-fixes).
- commit 5e10442
* Thu Jan  7 2021 tiwai@suse.de
- Move upstreamed sound patch into sorted section
- commit 0c5f21f
* Thu Jan  7 2021 tiwai@suse.de
- r8169: work around power-saving bug on some chip versions
  (git-fixes).
- ALSA: pcm: Clear the full allocated memory at hw_params
  (git-fixes).
- rtc: pl031: fix resource leak in pl031_probe (git-fixes).
- rtc: sun6i: Fix memleak in sun6i_rtc_clk_init (git-fixes).
- i3c master: fix missing destroy_workqueue() on error in
  i3c_master_register (git-fixes).
- misc: vmw_vmci: fix kernel info-leak by initializing dbells
  in vmci_ctx_get_chkpt_doorbells() (git-fixes).
- xhci: Give USB2 ports time to enter U3 in bus suspend
  (git-fixes).
- USB: dummy-hcd: Fix uninitialized array use in init()
  (git-fixes).
- Bluetooth: hci_h5: close serdev device and free hu in h5_close
  (git-fixes).
- media: gp8psk: initialize stats at power control logic
  (git-fixes).
- staging: wlan-ng: fix out of bounds read in
  prism2sta_probe_usb() (git-fixes).
- commit 57824b9
* Thu Jan  7 2021 tiwai@suse.de
- ALSA: hda/via: Fix runtime PM for Clevo W35xSS (git-fixes).
- ALSA: usb-audio: Add quirk for RC-505 (git-fixes).
- ALSA: hda/realtek: Enable mute and micmute LED on HP EliteBook
  850 G7 (git-fixes).
- ALSA: hda/realtek: Add two "Intel Reference board" SSID in
  the ALC256 (git-fixes).
- ALSA: hda/realtek: Add mute LED quirk for more HP laptops
  (git-fixes).
- ALSA: hda/conexant: add a new hda codec CX11970 (git-fixes).
- ALSA: usb-audio: Add quirk for BOSS AD-10 (git-fixes).
- ALSA: usb-audio: Fix UBSAN warnings for MIDI jacks (git-fixes).
- ALSA: hda/realtek - Fix speaker volume control on Lenovo C940
  (git-fixes).
- commit 3b01e24
* Wed Jan  6 2021 msuchanek@suse.de
- powerpc/sstep: Fix array out of bound warning (bsc#1180581
  ltc#190174).
- Delete patches.suse/powerpc-sstep-Add-testcases-for-VSX-vector-paired-lo.patch (bsc#1180581 ltc#190174).
  Drop test for the broken emulation, too.
- commit 346e1c7
* Wed Jan  6 2021 msuchanek@suse.de
- powerpc/test_emulate_step: Add testcases for divde[.] and
  divdeu[.] instructions (bsc#1180581 ltc#190174).
- commit 98eaae4
* Wed Jan  6 2021 msuchanek@suse.de
- powerpc/sstep: Add support for divde[.] and
  divdeu[.] instructions (bsc#1180581 ltc#190174).
- powerpc/ppc-opcode: Add divde and divdeu opcodes (bsc#1180581
  ltc#190174).
- commit 4565dda
* Wed Jan  6 2021 msuchanek@suse.de
- Delete patches.suse/powerpc-sstep-Support-VSX-vector-paired-storage-acce.patch (bsc#1180581 ltc#190174).
  Drop patch causing array overflow.
- commit ee77681
* Wed Jan  6 2021 msuchanek@suse.de
- drivers/base/memory.c: cache memory blocks in xarray to
  accelerate lookup (bsc#1159955 ltc#182993).
- Delete patches.suse/drivers-base-memory.c-cache-blocks-in-radix-tree-to-.patch.
  Refresh to upstream patch.
- commit 7c92ca5
* Wed Jan  6 2021 msuchanek@suse.de
- Refresh patches.suse/nvme-fc-avoid-calling-_nvme_fc_abort_outstanding_ios-from-interrupt-context.patch
  Fix commit hash
- commit fdfd462
* Wed Jan  6 2021 msuchanek@suse.de
- Refresh patches.suse/0001-btrfs-qgroup-don-t-try-to-wait-flushing.patch
  Fix commit hash
- commit 5ec0893
* Wed Jan  6 2021 msuchanek@suse.de
- Refresh patch metadata.
- Refresh patches.suse/ibmvnic-fix-NULL-pointer-dereference.patch.
- commit 45ce7d1
* Wed Jan  6 2021 jlee@suse.com
- ima: Fail rule parsing when asymmetric key measurement isn't
  supportable (jsc#SLE-15209).
- ima: Pre-parse the list of keyrings in a KEY_CHECK rule
  (jsc#SLE-15209).
- ima: Use the common function to detect LSM conditionals in a
  rule (jsc#SLE-15209).
- ima: Move comprehensive rule validation checks out of the
  token parser (jsc#SLE-15209).
- ima: Use correct type for the args_p member of
  ima_rule_entry.lsm elements (jsc#SLE-15209).
- ima: Shallow copy the args_p member of ima_rule_entry.lsm
  elements (jsc#SLE-15209).
- ima: Fail rule parsing when the KEY_CHECK hook is combined
  with an invalid cond (jsc#SLE-15209).
- ima: Fail rule parsing when the KEXEC_CMDLINE hook is combined
  with an invalid cond (jsc#SLE-15209).
- ima: Fail rule parsing when buffer hook functions have an
  invalid action (jsc#SLE-15209).
  Refresh
  patches.suse/ima-Fail-rule-parsing-when-appraise_flag-blacklist-i.patch
- ima: Free the entire rule if it fails to parse (jsc#SLE-15209).
- ima: Free the entire rule when deleting a list of rules
  (jsc#SLE-15209).
- mm: add kvfree_sensitive() for freeing sensitive data objects
  (jsc#SLE-15209).
- IMA: pre-allocate buffer to hold keyrings string
  (jsc#SLE-15209).
  Refresh
  patches.suse/ima-Directly-assign-the-ima_default_policy-pointer-t.patch
- commit d6d4155
* Wed Jan  6 2021 dbueso@suse.de
- lib/string: remove unnecessary #undefs (git-fixes).
- bitmap: remove unused function declaration (git-fixes).
- swiotlb: using SIZE_MAX needs limits.h included (git-fixes).
- swiotlb: fix "x86: Don't panic if can not alloc buffer for
  swiotlb" (git-fixes).
- kdb: Fix pager search for multi-line strings (git-fixes).
- kgdb: Drop malformed kernel doc comment (git-fixes).
- commit 28d99cb
* Wed Jan  6 2021 bp@suse.de
- EDAC/amd64: Fix PCI component registration (bsc#1152489).
- commit 6c4ae9b
* Tue Jan  5 2021 bp@suse.de
- KVM: x86: Expose AVX512_FP16 for supported CPUID
  (jsc#SLE-13413).
- commit a3f980a
* Tue Jan  5 2021 lma@suse.com
- KVM: x86: Expose fast short REP MOV for supported cpuid
  (bsc#1180334).
- x86/asm: Drop unused RDPID macro (bsc#1180334).
- KVM: x86: emulating RDPID failure shall return #UD rather than
  [#]GP (bsc#1180334).
- kvm: x86: Expose RDPID in KVM_GET_SUPPORTED_CPUID (bsc#1180334).
- commit 05fbe0b
* Tue Jan  5 2021 bp@suse.de
- x86: Enumerate AVX512 FP16 CPUID feature flag (jsc#SLE-13413).
- commit fd2814e
* Tue Jan  5 2021 msuchanek@suse.de
- powerpc/sstep: Add testcases for VSX vector paired load/store
  instructions (jsc#SLE-13847 bsc#1180581 ltc#190174).
- powerpc/sstep: Support VSX vector paired storage access
  instructions (jsc#SLE-13847 bsc#1180581 ltc#190174).
- powerpc/watchpoint: Workaround P10 DD1 issue with VSX-32 byte
  instructions (jsc#SLE-12936 bsc#1180581 ltc#190174).
- powerpc/sstep: Add testcases for VSX vector paired load/store
  instructions (jsc#SLE-13847 bsc#1180581 ltc#190174).
- powerpc/ppc-opcode: Add encoding macros for VSX vector paired
  instructions (jsc#SLE-13847 bsc#1180581 ltc#190174).
- powerpc/sstep: Support VSX vector paired storage access
  instructions (jsc#SLE-13847 bsc#1180581 ltc#190174).
- powerpc/ppc-opcode: Fold PPC_INST_* macros into PPC_RAW_*
  macros (jsc#SLE-13847 bsc#1180581 ltc#190174).
- Refresh patches.suse/powerpc-sstep-Add-tests-for-prefixed-floating-point-.patch.
- Refresh patches.suse/powerpc-sstep-Add-tests-for-prefixed-integer-load-st.patch.
- powerpc/ppc-opcode: Reuse raw instruction macros to stringify
  (jsc#SLE-13847 bsc#1180581 ltc#190174).
- powerpc/ppc-opcode: Consolidate powerpc instructions from
  bpf_jit.h (jsc#SLE-13847 bsc#1180581 ltc#190174 bsc#1180567
  ltc#190612).
- powerpc/bpf_jit: Reuse instruction macros from ppc-opcode.h
  (jsc#SLE-13847 bsc#1180581 ltc#190174).
- powerpc/ppc-opcode: Move ppc instruction encoding from
  test_emulate_step (jsc#SLE-13847 bsc#1180581 ltc#190174).
- powerpc/ppc-opcode: Introduce PPC_RAW_* macros for base
  instruction encoding (jsc#SLE-13847 bsc#1180581 ltc#190174).
- powerpc/lib: Fix emulate_step() std test (jsc#SLE-13847
  bsc#1180581 ltc#190174).
- commit 6a6d57b
* Tue Jan  5 2021 ddiss@suse.de
- target: fix XCOPY NAA identifier lookup (CVE-2020-28374,
  bsc#1178372).
- commit 3e5427c
* Tue Jan  5 2021 tiwai@suse.de
- Move upstreamed regmap and pinctrl patches into sorted section
- commit 6d2ef28
* Tue Jan  5 2021 tiwai@suse.de
- ALSA: hda/hdmi: Fix incorrect mutex unlock in
  silent_stream_disable() (bsc#1180543).
- commit a9190f5
* Tue Jan  5 2021 mgorman@suse.de
- intel_idle: Disable ACPI _CST on Haswell (bsc#1177399,
  bsc#1180347, bsc#1180141).
- commit 92491ff
* Tue Jan  5 2021 tiwai@suse.de
- mwifiex: Fix possible buffer overflows in
  mwifiex_cmd_802_11_ad_hoc_start (CVE-2020-36158 bsc#1180559).
- commit 3e80605
* Tue Jan  5 2021 fdmanana@suse.com
- btrfs: do not commit logs and transactions during link and
  rename operations (bsc#1180566).
- btrfs: do not take the log_mutex of the subvolume when pinning
  the log (bsc#1180566).
- btrfs: delete duplicated words + other fixes in comments
  (bsc#1180566).
- commit 916e8ac
* Tue Jan  5 2021 jlee@suse.com
- Replace HTTP links with HTTPS ones: security (jsc#SLE-15209).
- tpm_ftpm_tee: register driver on TEE bus (jsc#SLE-15209).
- tpm: Add support for event log pointer found in TPM2 ACPI table
  (jsc#SLE-15209).
- tpm: Unify the mismatching TPM space buffer sizes
  (jsc#SLE-15209).
- Removed commit id in blacklist.conf
- libnvdimm/security: Fix key lookup permissions (jsc#SLE-15209).
- tpm_tis_spi: Prefer async probe (jsc#SLE-15209).
- tpm/st33zp24: fix spelling mistake "drescription" ->
  "description" (jsc#SLE-15209).
- tpm_tis_spi: Don't send anything during flow control
  (jsc#SLE-15209).
- security: fix the key_permission LSM hook function type
  (jsc#SLE-15209).
- keys: Make the KEY_NEED_* perms an enum rather than a mask
  (jsc#SLE-15209).
- keys: Implement update for the big_key type (jsc#SLE-15209).
- security/keys: rewrite big_key crypto to use library interface
  (jsc#SLE-15209).
  Update config files.
- KEYS: encrypted: use crypto_shash_tfm_digest() (jsc#SLE-15209).
- crypto: hash - introduce crypto_shash_tfm_digest()
  (jsc#SLE-15209).
- tpm: eventlog: Replace zero-length array with flexible-array
  member (jsc#SLE-15209).
- tpm/tpm_ftpm_tee: Use UUID API for exporting the UUID
  (jsc#SLE-15209).
- sysfs: remove redundant __compat_only_sysfs_link_entry_to_kobj
  fn (jsc#SLE-15209).
- KEYS: Avoid false positive ENOMEM error on key read
  (jsc#SLE-15209).
- KEYS: Don't write out to userspace while holding key semaphore
  (jsc#SLE-15209).
- MAINTAINERS: adjust to trusted keys subsystem creation
  (jsc#SLE-15209).
- tpm: tpm_tis_spi_cr50: use new structure for SPI transfer delays
  (jsc#SLE-15209).
- tpm_tis_spi: use new 'delay' structure for SPI transfer delays
  (jsc#SLE-15209).
- tpm: Revert tpm_tis_spi_mod.ko to tpm_tis_spi.ko
  (jsc#SLE-15209).
- IMA: fix measuring asymmetric keys Kconfig (jsc#SLE-15209).
- Refresh
  patches.suse/0002-ima-generalize-x86-EFI-arch-glue-for-other-EFI-archi.patch
  patches.suse/ima-add-a-new-CONFIG-for-loading-arch-specific-polic.patch
- Update config files.
  CONFIG_IMA_MEASURE_ASYMMETRIC_KEYS=y
- IMA: Read keyrings= option from the IMA policy (jsc#SLE-15209).
- IMA: Add support to limit measuring keys (jsc#SLE-15209).
- KEYS: Call the IMA hook to measure keys (jsc#SLE-15209).
- IMA: Define an IMA hook to measure keys (jsc#SLE-15209).
  Refresh
  patches.suse/0002-ima-generalize-x86-EFI-arch-glue-for-other-EFI-archi.patch
- IMA: Add KEY_CHECK func to measure keys (jsc#SLE-15209).
- IMA: Check IMA policy flag (jsc#SLE-15209).
- tpm: Add tpm_version_major sysfs file (jsc#SLE-15209).
- tpm/tpm_ftpm_tee: add shutdown call back (jsc#SLE-15209).
- security: keys: trusted: fix lost handle flush (jsc#SLE-15209).
- KEYS: remove CONFIG_KEYS_COMPAT (jsc#SLE-15209).
  Update config files.
- KEYS: trusted: Remove set but not used variable 'keyhndl'
  (jsc#SLE-15209).
- KEYS: trusted: Move TPM2 trusted keys code (jsc#SLE-15209).
- KEYS: trusted: Create trusted keys subsystem (jsc#SLE-15209).
  Refresh
  patches.suse/1885-kbuild-remove-header-compile-test.patch
  patches.suse/KVM-arm-arm64-Factor-out-hypercall-handling-from-PSC.patch
  patches.suse/crypto-sha-split-sha.h-into-sha1.h-and-sha2.h.patch
- KEYS: Use common tpm_buf for trusted and asymmetric keys
  (jsc#SLE-15209).
- tpm: Move tpm_buf code to include/linux/ (jsc#SLE-15209).
- tpm: use GFP_KERNEL instead of GFP_HIGHMEM for tpm_buf
  (jsc#SLE-15209).
- tpm: tpm_tis_spi: Drop THIS_MODULE usage from driver struct
  (jsc#SLE-15209).
- tpm: tpm_tis_spi: Cleanup includes (jsc#SLE-15209).
- tpm: tpm_tis_spi: Support cr50 devices (jsc#SLE-15209).
  Update config files.
- tpm: tpm_tis_spi: Introduce a flow control callback
  (jsc#SLE-15209).
- tpm: Add a flag to indicate TPM power is managed by firmware
  (jsc#SLE-15209).
- tpm_tis: override durations for STM tpm with firmware 1.2.8.28
  (jsc#SLE-15209).
- tpm: provide a way to override the chip returned durations
  (jsc#SLE-15209).
- tpm: Remove duplicate code from caps_show() in tpm-sysfs.c
  (jsc#SLE-15209).
- tpm/tpm_ftpm_tee: A driver for firmware TPM running inside TEE
  (jsc#SLE-15209).
  Update config files.
- tpm: Remove a deprecated comments about implicit sysfs locking
  (jsc#SLE-15209).
- commit 7e1f0f4
* Tue Jan  5 2021 heming.zhao@suse.com
- md/cluster: fix deadlock when node is doing resync job
  (bsc#1163727).
- md/cluster: block reshape with remote resync job (bsc#1163727).
- md/bitmap: fix memory leak of temporary bitmap (bsc#1163727).
- md/bitmap: md_bitmap_get_counter returns wrong blocks
  (bsc#1163727).
- md/bitmap: md_bitmap_read_sb uses wrong bitmap blocks
  (bsc#1163727).
- md-cluster: fix rmmod issue when md_cluster convert bitmap to
  none (bsc#1163727).
- md-cluster: fix safemode_delay value when converting to
  clustered bitmap (bsc#1163727).
- md-cluster: fix wild pointer of unlock_all_bitmaps()
  (bsc#1163727).
- commit 7522976
* Mon Jan  4 2021 rgoldwyn@suse.com
- mm: validate inode in mapping_set_error()  (git-fixes).
- commit 05b16dc
* Mon Jan  4 2021 rgoldwyn@suse.com
- btrfs: add missing check for nocow and compression inode flags
  (bsc#1178780).
- fs/buffer.c: record blockdev write errors in super_block that
  it backs  (bsc#1172266).
- vfs: track per-sb writeback errors and report them to syncfs
  (bsc#1172266).
- commit 934c84a
* Mon Jan  4 2021 rgoldwyn@suse.com
- btrfs: add missing check for nocow and compression inode flags (bsc#1178780).
- commit 98b0ffc
* Mon Jan  4 2021 lhenriques@suse.de
- Revert "ceph: allow rename operation under different quota
  realms" (bsc#1180541).
- commit 1a2a0a7
* Mon Jan  4 2021 lhenriques@suse.de
- Refresh
  patches.suse/ceph-downgrade-warning-from-mdsmap-decode-to-debug.patch.
- Refresh
  patches.suse/ceph-fix-race-in-concurrent-_ceph_remove_cap-invocations.patch.
  Patches have been merged into mainline; refreshing Git-commit and Path-mainline
  tags in patches.
- commit d338d00
* Mon Jan  4 2021 tbogendoerfer@suse.de
- nfp: move indirect block cleanup to flower app stop callback
  (bsc#1176447).
- ethtool: fix error paths in ethnl_set_channels() (bsc#1176447).
- i40e, xsk: clear the status bits for the next_to_use descriptor
  (jsc#SLE-13701).
- RDMA/mlx5: Fix MR cache memory leak (jsc#SLE-15175).
- RDMA/bnxt_re: Fix max_qp_wrs reported (bsc#1175499).
- RDMA/hns: Bugfix for calculation of extended sge
  (jsc#SLE-14777).
- RDMA/rtrs-srv: Fix typo (jsc#SLE-15176).
- RDMA/rtrs-srv: Don't guard the whole __alloc_srv with srv_mutex
  (jsc#SLE-15176).
- RDMA/rtrs-clt: Missing error from rtrs_rdma_conn_established
  (jsc#SLE-15176).
- RDMA/rtrs-clt: Avoid run destroy_con_cq_qp/create_con_cq_qp
  in parallel (jsc#SLE-15176).
- RDMA/rtrs-clt: Remove outdated comment in create_con_cq_qp
  (jsc#SLE-15176).
- RDMA/rtrs-clt: Remove destroy_con_cq_qp in case route resolving
  failed (jsc#SLE-15176).
- IB/isert: add module param to set sg_tablesize for IO cmd
  (jsc#SLE-15176).
- RDMA/core: Fix error return in _ib_modify_qp() (jsc#SLE-15176).
- RDMA/bnxt_re: Fix entry size during SRQ create (jsc#SLE-15076
  bsc#1175499).
- net/mlx5e: remove unnecessary memset (jsc#SLE-15172).
- net/sched: fix miss init the mru in qdisc_skb_cb (bsc#1176447).
- i40e: remove redundant assignment (jsc#SLE-13701).
- ionic: use mc sync for multicast filters (jsc#SLE-16649).
- net: sched: Fix dump of MPLS_OPT_LSE_LABEL attribute in
  cls_flower (bsc#1176447).
- net: flow_offload: Fix memory leak for indirect flow block
  (jsc#SLE-15075).
- e1000e: fix S0ix flow to allow S0i3.2 subset entry
  (jsc#SLE-13532).
- bonding: fix feature flag setting at init time (bsc#1176447).
- ch_ktls: fix build warning for ipv4-only config (jsc#SLE-15129).
- net/sched: fq_pie: initialize timer earlier in fq_pie_init()
  (jsc#SLE-15172).
- commit feb8216
* Mon Jan  4 2021 msuchanek@suse.de
- powerpc/pci: Remove LSI mappings on device teardown (bsc#1172145
  ltc#184630).
- commit a2fd2d8
* Mon Jan  4 2021 msuchanek@suse.de
- Delete patches.suse/powerpc-pci-unmap-legacy-INTx-interrupts-when-a-PHB-.patch
  (bsc#1172145 ltc#184630).
  To be replaced with new fix merged through SP2.
- commit 8ea9da6
* Mon Jan  4 2021 msuchanek@suse.de
- powerpc/cacheinfo: Print correct cache-sibling map/list for
  L2 cache (jsc#SLE-13615 bsc#1180100 ltc#190257).
- powerpc/smp: Add support detecting thread-groups sharing L2
  cache (jsc#SLE-13615 bsc#1180100 ltc#190257).
- powerpc/smp: Rename init_thread_group_l1_cache_map() to make
  it generic (jsc#SLE-13615 bsc#1180100 ltc#190257).
- powerpc/smp: Rename cpu_l1_cache_map as
  thread_group_l1_cache_map (jsc#SLE-13615 bsc#1180100
  ltc#190257).
- powerpc/smp: Parse ibm,thread-groups with multiple properties
  (jsc#SLE-13615 bsc#1180100 ltc#190257).
- powerpc/smp: Use GFP_ATOMIC while allocating tmp mask
  (jsc#SLE-13615 bsc#1180100 ltc#190257).
- powerpc/smp: Remove unnecessary variable (jsc#SLE-13615
  bsc#1180100 ltc#190257).
- powerpc/smp: Optimize update_coregroup_mask (jsc#SLE-13615
  bsc#1180100 ltc#190257).
- powerpc/smp: Move coregroup mask updation to a new function
  (jsc#SLE-13615 bsc#1180100 ltc#190257).
- powerpc/smp: Optimize update_mask_by_l2 (jsc#SLE-13615
  bsc#1180100 ltc#190257).
- powerpc/smp: Check for duplicate topologies and consolidate
  (jsc#SLE-13615 bsc#1180100 ltc#190257).
- powerpc/smp: Depend on cpu_l1_cache_map when adding CPUs
  (jsc#SLE-13615 bsc#1180100 ltc#190257).
- powerpc/smp: Stop passing mask to update_mask_by_l2
  (jsc#SLE-13615 bsc#1180100 ltc#190257).
- powerpc/smp: Limit CPUs traversed to within a node
  (jsc#SLE-13615 bsc#1180100 ltc#190257).
- powerpc/smp: Optimize remove_cpu_from_masks (jsc#SLE-13615
  bsc#1180100 ltc#190257).
- powerpc/smp: Remove get_physical_package_id (jsc#SLE-13615
  bsc#1180100 ltc#190257).
- powerpc/smp: Stop updating cpu_core_mask (jsc#SLE-13615
  bsc#1180100 ltc#190257).
- powerpc/topology: Update topology_core_cpumask (jsc#SLE-13615
  bsc#1180100 ltc#190257).
- powerpc/topology: Override cpu_smt_mask (jsc#SLE-13615
  bsc#1180100 ltc#190257).
- sched/topology: Allow archs to override cpu_smt_mask
  (jsc#SLE-13615 bsc#1180100 ltc#190257).
- powerpc/cacheinfo: Add per cpu per index shared_cpu_list
  (jsc#SLE-13615 bsc#1180100 ltc#190257).
- powerpc/cacheinfo: Make cpumap_show code reusable (jsc#SLE-13615
  bsc#1180100 ltc#190257).
- powerpc/cacheinfo: Use cpumap_print to print cpumap
  (jsc#SLE-13615 bsc#1180100 ltc#190257).
- powerpc/smp: Use IS_ENABLED() to avoid #ifdef (jsc#SLE-13615
  bsc#1180100 ltc#190257).
- powerpc/smp: Drop superfluous NULL check (jsc#SLE-13615
  bsc#1180100 ltc#190257).
- commit aa22c03
* Mon Jan  4 2021 mbenes@suse.cz
- blacklist.conf: adab66b71abf ("Revert: "ring-buffer: Remove HAVE_64BIT_ALIGNED_ACCESS"")
  We do not support metag and sparc64 archs.
- commit 99ad074
* Mon Jan  4 2021 mbenes@suse.cz
- blacklist.conf: d9a9280a0d0a ("seq_buf: Avoid type mismatch for seq_buf_init")
  It breaks kABI. It is not worth the hassle to backport.
- commit 7c29506
* Mon Jan  4 2021 jeyu@suse.de
- module: delay kobject uevent until after module init call (bsc#1178631).
- Refresh patches.suse/supported-flag.
- commit 9f35554
* Mon Jan  4 2021 mbenes@suse.cz
- bpf: Fix bpf_put_raw_tracepoint()'s use of __module_address()
  (git-fixes).
- commit e888e29
* Mon Jan  4 2021 mbenes@suse.cz
- blacklist.conf: 310e3a4b5a4f ("tracing: Remove WARN_ON in start_thread()")
  CONFIG_HWLAT_TRACER is not set anywhere.
- commit 4f64022
* Mon Jan  4 2021 ghe@suse.com
- ocfs2: fix unbalanced locking (bsc#1180506).
- commit b54b08a
* Mon Jan  4 2021 tiwai@suse.de
- remoteproc: qcom: Fix potential NULL dereference in
  adsp_init_mmio() (git-fixes).
- remoteproc: qcom: fix reference leak in adsp_start (git-fixes).
- remoteproc: q6v5-mss: fix error handling in q6v5_pds_enable
  (git-fixes).
- serial_core: Check for port state when tty is in error state
  (git-fixes).
- usb: gadget: f_fs: Re-use SS descriptors for SuperSpeedPlus
  (git-fixes).
- USB: gadget: f_midi: setup SuperSpeed Plus descriptors
  (git-fixes).
- USB: gadget: f_acm: add support for SuperSpeed Plus (git-fixes).
- USB: gadget: f_rndis: fix bitrate for SuperSpeed and above
  (git-fixes).
- media: gspca: Fix memory leak in probe (git-fixes).
- media: saa7146: fix array overflow in vidioc_s_audio()
  (git-fixes).
- media: max2175: fix max2175_set_csm_mode() error code
  (git-fixes).
- media: imx214: Fix stop streaming (git-fixes).
- media: msi2500: assign SPI bus number dynamically (git-fixes).
- media: siano: fix memory leak of debugfs members in
  smsdvb_hotplug (git-fixes).
- media: sunxi-cir: ensure IR is handled when it is continuous
  (git-fixes).
- media: solo6x10: fix missing snd_card_free in error handling
  case (git-fixes).
- media: ipu3-cio2: Remove traces of returned buffers (git-fixes).
- media: ipu3-cio2: Make the field on subdev format
  V4L2_FIELD_NONE (git-fixes).
- media: ipu3-cio2: Validate mbus format in setting subdev format
  (git-fixes).
- media: ipu3-cio2: Serialise access to pad format (git-fixes).
- media: ipu3-cio2: Return actual subdev format (git-fixes).
- media: mtk-vcodec: add missing put_device() call in
  mtk_vcodec_init_enc_pm() (git-fixes).
- media: mtk-vcodec: add missing put_device() call in
  mtk_vcodec_release_dec_pm() (git-fixes).
- media: mtk-vcodec: add missing put_device() call in
  mtk_vcodec_init_dec_pm() (git-fixes).
- media: tm6000: Fix sizeof() mismatches (git-fixes).
- iwlwifi: pcie: add one missing entry for AX210 (git-fixes).
- commit 1e25d62
* Mon Jan  4 2021 tiwai@suse.de
- gpio: mvebu: update Armada XP per-CPU comment (git-fixes).
- dmaengine: mv_xor_v2: Fix error return code in mv_xor_v2_probe()
  (git-fixes).
- HID: i2c-hid: add Vero K147 to descriptor override (git-fixes).
- iio:imu:bmi160: Fix too large a buffer (git-fixes).
- crypto: atmel-i2c - select CONFIG_BITREVERSE (git-fixes).
- crypto: ecdh - avoid unaligned accesses in ecdh_set_secret()
  (git-fixes).
- crypto: omap-aes - Fix PM disable depth imbalance in
  omap_aes_probe (git-fixes).
- crypto: crypto4xx - Replace bitwise OR with logical OR in
  crypto4xx_build_pd (git-fixes).
- Input: goodix - add upside-down quirk for Teclast X98 Pro tablet
  (git-fixes).
- Input: cros_ec_keyb - send 'scancodes' in addition to key events
  (git-fixes).
- commit 48f3c1f
* Mon Jan  4 2021 tiwai@suse.de
- ALSA/hda: apply jack fixup for the Acer Veriton
  N4640G/N6640G/N2510G (git-fixes).
- ALSA: hda/realtek: Apply jack fixup for Quanta NL3 (git-fixes).
- ALSA: hda/realtek: Add quirk for MSI-GP73 (git-fixes).
- ALSA: pcm: oss: Fix a few more UBSAN fixes (git-fixes).
- ALSA: usb-audio: Disable sample read check if firmware doesn't
  give back (git-fixes).
- ALSA: usb-audio: Add VID to support native DSD reproduction
  on FiiO devices (git-fixes).
- ALSA: core: memalloc: add page alignment for iram (git-fixes).
- ACPI: PNP: compare the string length in the matching_id()
  (git-fixes).
- clocksource/drivers/arm_arch_timer: Correct fault programming
  of CNTKCTL_EL1.EVNTI (git-fixes).
- clocksource/drivers/arm_arch_timer: Use stable count reader
  in erratum sne (git-fixes).
- clocksource/drivers/cadence_ttc: Fix memory leak in
  ttc_setup_clockevent() (git-fixes).
- clocksource/drivers/orion: Add missing clk_disable_unprepare()
  on error path (git-fixes).
- crypto: af_alg - avoid undefined behavior accessing salg_name
  (git-fixes).
- crypto: inside-secure - Fix sizeof() mismatch (git-fixes).
- crypto: talitos - Fix return type of current_desc_hdr()
  (git-fixes).
- crypto: talitos - Endianess in current_desc_hdr() (git-fixes).
- cfg80211: initialize rekey_data (git-fixes).
- commit 57d3bee
* Thu Dec 31 2020 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section:
  patches.suse/ibmvnic-fix-NULL-pointer-dereference.patch
- update upstream reference:
  patches.suse/ibmvnic-continue-fatal-error-reset-after-passive-ini.patch
- commit a0b2ce7
* Wed Dec 30 2020 msuchanek@suse.de
- ibmvnic: fix login buffer memory leak (jsc#SLE-17043 bsc#1179243
  ltc#189290 git-fixes).
- commit 2d2f67f
* Wed Dec 30 2020 msuchanek@suse.de
- ibmvnic: continue fatal error reset after passive init
  (bsc#1171078 ltc#184239 git-fixes).
- commit e6ea824
* Wed Dec 30 2020 msuchanek@suse.de
- Refresh patches.suse/powerpc-perf-Exclude-kernel-samples-while-counting-e.patch.
- commit fc17dca
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/perf: Fix Threshold Event Counter Multiplier width
  for P10 (jsc#SLE-13513 bsc#1180072 ltc#190309).
- commit c1c01ab
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/bitops: Fix possible undefined behaviour with fls()
  and fls64() (bsc#1156395).
- commit e90809a
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc: Fix incorrect stw{, ux, u, x} instructions in
  __set_pte_at (bsc#1065729).
- commit b5cc99b
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/xmon: Change printk() to pr_cont() (bsc#1065729).
- commit 9125964
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/64: Set up a kernel stack for secondaries before
  cpu_restore() (bsc#1065729).
- commit 7bcd26b
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/eeh_cache: Fix a possible debugfs deadlock
  (bsc#1156395).
- commit bfd7479
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/64: Fix an EMIT_BUG_ENTRY in head_64.S (jsc#SLE-9246
  git-fixes).
- powerpc/signal: Move inline functions in signal.h (jsc#SLE-16200
  git-fixes).
- commit d0ddb83
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/sstep: Cover new VSX instructions under CONFIG_VSX
  (jsc#SLE-13847 git-fixes).
- powerpc/sstep: Emulate prefixed instructions only when
  CPU_FTR_ARCH_31 is set (jsc#SLE-13847 git-fixes).
- commit c3ca4ff
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc: Avoid broken GCC __attribute__((optimize))
  (bsc#1156395).
- commit 3d98ea5
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/smp: Add __init to init_big_cores() (bsc#1109695
  ltc#171067 git-fixes).
- commit 88fe3ed
* Wed Dec 30 2020 msuchanek@suse.de
- Refresh patches.suse/powerpc-rtas-fix-typo-of-ibm-open-errinjct-in-rtas-f.patch
  Refresh to upstream version.
- commit f0055e2
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/pseries/hibernation: remove redundant cacheinfo update
  (bsc#1138374 ltc#178199 git-fixes).
- commit e904a78
* Wed Dec 30 2020 msuchanek@suse.de
- Revert "powerpc/pseries/hotplug-cpu: Remove double free in
  error path" (bsc#1065729).
- commit 243e39e
* Wed Dec 30 2020 msuchanek@suse.de
- blacklist.conf: Add e91d8d78237d mm/zsmalloc.c: drop ZSMALLOC_PGTABLE_MAPPING
  The option is not enabled.
- commit 65fee6f
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/64: irq replay remove decrementer overflow check
  (jsc#SLE-9246 git-fixes(stable-5.10)).
- commit 6c37cac
* Wed Dec 30 2020 oneukum@suse.com
- PCI: Fix overflow in command-line resource alignment requests
  (git-fixes).
- commit 1dd80ec
* Wed Dec 30 2020 msuchanek@suse.de
- ibmvnic: fix: NULL pointer dereference (bsc#1044767 ltc#155231
  git-fixes).
- commit 59feb80
* Wed Dec 30 2020 oneukum@suse.com
- Refresh
  patches.suse/powercap-Restrict-energy-meter-to-root-access.patch.
  Now in mainline
- commit 414492a
* Wed Dec 30 2020 oneukum@suse.com
- blacklist.conf: fix already added by other patch
- commit ed48336
* Wed Dec 30 2020 oneukum@suse.com
- blacklist.conf: already gone in by another ID
- commit 7020218
* Wed Dec 30 2020 oneukum@suse.com
- usb: host: ehci-tegra: Fix error handling in tegra_ehci_probe()
  (git-fixes).
- commit 6f94554
* Wed Dec 30 2020 oneukum@suse.com
- blacklist.conf: fix not relevant for our config
- commit 47a12a9
* Tue Dec 29 2020 oneukum@suse.com
- USB: UAS: introduce a quirk to set no_write_same (git-fixes).
- commit bda3ea7
* Tue Dec 29 2020 oneukum@suse.com
- USB: add RESET_RESUME quirk for Snapscan 1212 (git-fixes).
- commit 0912116
* Tue Dec 29 2020 oneukum@suse.com
- crypto: qat - add CRYPTO_AES to Kconfig dependencies
  (git-fixes).
- commit 6dcc047
* Tue Dec 29 2020 dwagner@suse.de
- blk-mq: Remove 'running from the wrong CPU' warning
  (bsc#1174486).
- commit 5a12d1c
* Tue Dec 29 2020 bp@suse.de
- blacklist.conf: 3d51507f29f2 x86/entry/32: Add missing ASM_CLAC to general_protection entry
- commit 794e745
* Tue Dec 29 2020 tiwai@suse.de
- ACPI: NFIT: Fix input validation of bus-family (git-fixes).
- nl80211: validate key indexes for cfg80211_registered_device
  (git-fixes).
- commit d4bf12f
* Tue Dec 29 2020 tiwai@suse.de
- watchdog: coh901327: add COMMON_CLK dependency (git-fixes).
- watchdog: qcom: Avoid context switch in restart handler
  (git-fixes).
- watchdog: Fix potential dereferencing of null pointer
  (git-fixes).
- watchdog: sprd: change to use usleep_range() instead of busy
  loop (git-fixes).
- watchdog: sprd: check busy bit before new loading rather than
  after that (git-fixes).
- watchdog: sprd: remove watchdog disable from resume fail path
  (git-fixes).
- watchdog: sirfsoc: Add missing dependency on HAS_IOMEM
  (git-fixes).
- watchdog: armada_37xx: Add missing dependency on HAS_IOMEM
  (git-fixes).
- commit 705ed83
* Tue Dec 29 2020 tiwai@suse.de
- media: uvcvideo: Accept invalid bFormatIndex and bFrameIndex
  values (bsc#1180117).
- commit 2f3db03
* Tue Dec 29 2020 tiwai@suse.de
- Re-import the upstream uvcvideo fix; one more fix will be added later (bsc#1180117)
- commit 0da5ae4
* Mon Dec 28 2020 mkubecek@suse.cz
- rpm/constraints.in: more disk space for aarch64 binary builds (bsc#1180261)
  Tumbleweed KotD builds already consume ~30 GB of disk space and SLE15-SP3
  builds sometimes exceed even 32 GB, resulting in build failures. Thus the
  exception providing only 30 GB for aarch64 binary builds is no longer
  sustainable and if requiring 35 GB limits the portfolio of available
  builders, we need to address that.
- commit 07b084b
* Mon Dec 28 2020 bp@suse.de
- x86/topology: Set cpu_die_id only if DIE_TYPE found
  (bsc#1152489).
- commit 6e7d005
* Mon Dec 28 2020 bp@suse.de
- EDAC/mce_amd: Use struct cpuinfo_x86.cpu_die_id for AMD NodeId
  (bsc#1152489).
- commit 72ce98e
* Mon Dec 28 2020 bp@suse.de
- x86/CPU/AMD: Remove amd_get_nb_id() (bsc#1152489).
- commit be1bad6
* Mon Dec 28 2020 bp@suse.de
- x86/CPU/AMD: Save AMD NodeId as cpu_die_id (bsc#1152489).
- commit af076e7
* Mon Dec 28 2020 bp@suse.de
- EDAC/amd64: Do not load on family 0x15, model 0x13 (bsc#1179763).
- commit 877e64a
* Mon Dec 28 2020 mkubecek@suse.cz
- rpm: drop /usr/bin/env in interpreter specification
  OBS checks don't like /usr/bin/env in script interpreter lines but upstream
  developers tend to use it. A proper solution would be fixing the depedency
  extraction and drop the OBS check error but that's unlikely to happen so
  that we have to work around the problem on our side and rewrite the
  interpreter lines in scripts before collecting files for packages instead.
- commit 0ec5324
* Thu Dec 24 2020 nsaenzjulienne@suse.de
- reset: raspberrypi: Don't reset USB if already up (bsc#1180336).
- commit 72c8f7f
* Wed Dec 23 2020 mbrugger@suse.com
- blacklist.conf: ignore CRYPTO_SKCIPHER kconfig option
- commit 00dae55
* Wed Dec 23 2020 mbrugger@suse.com
- crypto: hisilicon - Cap block size at 2^31 (jsc#SLE-16507
  jsc#SLE-15835).
- commit 4cc08f7
* Wed Dec 23 2020 tabraham@suse.com
- nvmet-tcp: fix maxh2cdata icresp parameter (bsc#1179892).
- commit 8a7b72b
* Wed Dec 23 2020 mbrugger@suse.com
- crypto: hisilicon - fix driver compatibility issue with
  different versions of devices (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/qm - change debugfs file name from qm_regs
  to regs (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/qm - add DebugFS for xQC and xQE dump
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/zip - add debugfs for Hisilicon ZIP
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/hpre - add debugfs for Hisilicon HPRE
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/sec2 - add debugfs for Hisilicon SEC
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/qm - add debugfs to the QM state machine
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/qm - add debugfs for QM (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon/zip - Use temporary sqe when doing work
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - add device error report through abnormal
  irq (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - remove codes of directly report device
  errors through MSI (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - QM memory management optimization
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - unify initial value assignment into QM
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - remove use_dma_api related codes
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - add FLR support (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon/qm - add state machine for QM (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - refactor module parameter pf_q_num related
  code (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/zip - modify the ZIP probe process
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/hpre - modify the HPRE probe process
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/sec2 - modify the SEC probe process
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/sec2 - constify sec_dfx_regs (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon/zip - constify struct debugfs_reg32
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/hpre - constify struct debugfs_reg32
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/qm - Make qm_controller_reset() static
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/qm - add more ACPI dependencies (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon/qm - fix build failure with ACPI off
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/qm - stop qp by judging sq and cq tail
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/sec2 - add controller reset support for SEC2
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/hpre - add controller reset support for HPRE
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/zip - add controller reset support for zip
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/qm - add controller reset interface
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - add vfs_num module parameter for hpre/sec
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - unify SR-IOV related codes into QM
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - put vfs_num into struct hisi_qm
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/sec2 - Add new create qp process
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/hpre - Optimize finding hpre device process
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/zip - Use hisi_qm_alloc_qps_node() when init
  ctx (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/qm - Put device finding logic into QM
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/sec2 - Add pbuffer mode for SEC driver
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/sec2 - Update IV and MAC operation
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/sec2 - Add iommu status check (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon/sec2 - Add workqueue for SEC driver
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - Use one workqueue per qm instead of per qp
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - remove redundant assignment of pointer ctx
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - Remove module_param uacce_mode
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - Fix duplicate print when qm occur multiple
  errors (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - Unify error detect process into qm
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - Configure zip RAS error type (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - Unify hardware error init/uninit into QM
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - fix spelling mistake "disgest" -> "digest"
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - add branch prediction macro (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - adjust hpre_crt_para_get (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - Fixed some tiny bugs of HPRE (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - Bugfixed tfm leak (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - Add aead support on SEC2 (jsc#SLE-16507
  jsc#SLE-15835).
- Refresh
  patches.suse/crypto-sha-split-sha.h-into-sha1.h-and-sha2.h.patch.
- crypto: hisilicon - redefine skcipher initiation (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - Add branch prediction macro (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - Add callback error check (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - Adjust some inner logic (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - Update QP resources of SEC V2 (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - Update some names on SEC V2 (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - fix print/comment of SEC V2 (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - Update debugfs usage of SEC V2
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - still no need to check return value of
  debugfs_create functions (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - Remove useless MODULE macros (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - Use the offset fields in sqe to avoid need
  to split scatterlists (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - Fix issue with wrong number of sg elements
  after dma map (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon/sec2 - Use atomics instead of __sync
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - fix a NULL vs IS_ERR() bug in
  sec_create_qp_ctx() (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - add DebugFS for HiSilicon SEC (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - add SRIOV for HiSilicon SEC (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - add HiSilicon SEC V2 driver (jsc#SLE-16507
  jsc#SLE-15835).
- Update config files. DEV_HISI_SEC2 as module
- supported.conf: add hisi_sec2
- crypto: hisilicon - no need to check return value of
  debugfs_create functions (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - add vfs_num module param for zip
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - replace #ifdef with IS_ENABLED for
  CONFIG_NUMA (jsc#SLE-16507 jsc#SLE-15835).
- hwrng: hisi - add HiSilicon TRNG driver support (jsc#SLE-16507
  jsc#SLE-15835).
- Update config files. Enable HW_RANDOM_HISI_V2
- support.conf: add hisi-trng-v2
- crypto: hisilicon - fix to return sub-optimal device when best
  device has no qps (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - use sgl API to get sgl dma addr and len
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - fix endianness verification problem of QM
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - fix param should be static when not external
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - Fix using plain integer as NULL pointer
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - tiny fix about QM/ZIP error callback print
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon: Fix misuse of GENMASK macro (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - select NEED_SG_DMA_LENGTH in qm Kconfig
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - Add debugfs for HPRE (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - add SRIOV support for HPRE (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - add HiSilicon HPRE accelerator
  (jsc#SLE-16507 jsc#SLE-15835).
- Update config files. Enable CRYPTO_DEV_HISI_HPRE
- supported.conf: add hisi_hpre
- crypto: hisilicon - misc fix about sgl (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - fix large sgl memory allocation problem
  when disable smmu (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - add sgl_sge_nr module param for zip
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - merge sgl support to hisi_qm module
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - allow compile-testing on x86 (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - avoid unused function warning (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - Fix return value check in
  hisi_zip_acompress() (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - Fix warning on printing %%p with dma_addr_t
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - fix error handle in hisi_zip_create_req_q
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - add missing single_release (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - init curr_sgl_dma to fix compile warning
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - add dependency for CRYPTO_DEV_HISI_ZIP
  (jsc#SLE-16507 jsc#SLE-15835).
- crypto: hisilicon - fix kbuild warnings (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - add debugfs for ZIP and QM (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - add SRIOV support for ZIP (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - add HiSilicon ZIP accelerator support
  (jsc#SLE-16507 jsc#SLE-15835).
- Update config files. Enable CRYPTO_DEV_HISI_ZIP
- supported.conf: add hisi_zip
- crypto: hisilicon - add hardware SGL support (jsc#SLE-16507
  jsc#SLE-15835).
- crypto: hisilicon - add queue management driver for HiSilicon
  QM module (jsc#SLE-16507 jsc#SLE-15835).
- Update config files. Enable CRYPTO_DEV_HISI_QM
- supported.conf: add hisi_qm
- commit 2188cb3
* Wed Dec 23 2020 bp@suse.de
- x86/ima: use correct identifier for SetupMode variable
  (bsc#1152489).
- commit 9b27f4f
* Wed Dec 23 2020 jlee@suse.com
- i2c: Revert incorrect conversion to use generic helper
  (jsc#SLE-16407).
- commit 80898a3
* Tue Dec 22 2020 bp@suse.de
- blacklist.conf: 3d51507f29f2 x86/entry/32: Add missing ASM_CLAC to general_protection entry
- commit 1aa31e3
* Tue Dec 22 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/mm-memory_failure-always-pin-the-page-in-madvise_inj.patch
- commit 4f786fa
* Tue Dec 22 2020 denis.kirjanov@suse.com
- Refresh
  patches.suse/arm64-force-no_block_mappings-if-crashkernel-reservation-is-required.patch.
- Refresh
  patches.suse/arm64-ignore-any-dma-offsets-in-the-max_zone_phys-calculation.patch.
- Refresh
  patches.suse/arm64-mm-move-reserve_crashkernel-into-mem_init.patch.
- Refresh
  patches.suse/arm64-mm-move-zone_dma_bits-initialization-into-zone_sizes_init.patch.
- Refresh
  patches.suse/arm64-mm-set-zone_dma-size-based-on-devicetree-s-dma-ranges.patch.
- Refresh
  patches.suse/arm64-mm-set-zone_dma-size-based-on-early-iort-scan.patch.
- Refresh
  patches.suse/ibmvnic-Clean-up-TX-code-and-TX-buffer-data-structur.patch.
- Refresh
  patches.suse/ibmvnic-Correctly-re-enable-interrupts-in-NAPI-polli.patch.
- Refresh
  patches.suse/ibmvnic-Do-not-replenish-RX-buffers-after-every-poll.patch.
- Refresh
  patches.suse/ibmvnic-Ensure-that-device-queue-memory-is-cache-lin.patch.
- Refresh
  patches.suse/ibmvnic-Introduce-batched-RX-buffer-descriptor-trans.patch.
- Refresh
  patches.suse/ibmvnic-Introduce-indirect-subordinate-Command-Respo.patch.
- Refresh
  patches.suse/ibmvnic-Introduce-xmit_more-support-using-batched-su.patch.
- Refresh patches.suse/ibmvnic-Remove-send_subcrq-function.patch.
- Refresh
  patches.suse/ibmvnic-Use-netdev_alloc_skb-instead-of-alloc_skb-to.patch.
- Refresh
  patches.suse/ibmvnic-fix-rx-buffer-tracking-and-index-management-.patch.
- Refresh patches.suse/net-smc-improve-return-codes-for-smc-dv2.
- Refresh
  patches.suse/of-address-introduce-of_dma_get_max_cpu_address.patch.
- Refresh
  patches.suse/s390-sles15sp3-03-01-s390-cio-Export-information-about-Endpoint-Security-.patch.
- Refresh
  patches.suse/s390-sles15sp3-03-02-s390-cio-Provide-Endpoint-Security-Mode-per-CU.patch.
- Refresh
  patches.suse/s390-sles15sp3-03-03-s390-cio-Add-support-for-FCES-status-notification.patch.
- Refresh
  patches.suse/s390-sles15sp3-03-04-s390-dasd-Remove-unused-parameter-from-dasd_generic_.patch.
- Refresh
  patches.suse/s390-sles15sp3-03-05-s390-dasd-Move-duplicate-code-to-separate-function.patch.
- Refresh
  patches.suse/s390-sles15sp3-03-06-s390-dasd-Store-path-configuration-data-during-path-.patch.
- Refresh
  patches.suse/s390-sles15sp3-03-07-s390-dasd-Fix-operational-path-inconsistency.patch.
- Refresh
  patches.suse/s390-sles15sp3-03-08-s390-dasd-Display-FC-Endpoint-Security-information-v.patch.
- Refresh
  patches.suse/s390-sles15sp3-03-09-s390-dasd-Prepare-for-additional-path-event-handling.patch.
- Refresh
  patches.suse/s390-sles15sp3-03-10-s390-dasd-Process-FCES-path-event-notification.patch.
- Refresh
  patches.suse/scsi-fnic-avoid-looping-in-trans-eth-on-unload.
- Refresh
  patches.suse/scsi-fnic-change-shost_printk-to-fnic_fcs_dbg.
- Refresh
  patches.suse/scsi-fnic-change-shost_printk-to-fnic_main_dbg.
- Refresh
  patches.suse/scsi-fnic-set-scsi_set_resid-only-for-underflow.
- Refresh patches.suse/scsi-fnic-validate-io_req-before-others.
- commit 87eecb7
* Tue Dec 22 2020 glin@suse.com
- selftests/bpf: Print reason when a tester could not run a
  program (bsc#1155518).
- selftests/bpf: Fix invalid use of strncat in test_sockmap
  (bsc#1155518).
- samples: bpf: Refactor test_cgrp2_sock2 program with libbpf
  (bsc#1155518).
- samples/bpf: Remove unused test_ipip.sh (bsc#1155518).
- selftest/bpf: Add missed ip6ip6 test back (bsc#1155518).
- selftests/bpf/test_offload.py: Reset ethtool features after
  failed setting (bsc#1155518).
- commit 82533c7
* Tue Dec 22 2020 tiwai@suse.de
- clk: bcm: dvp: Add MODULE_DEVICE_TABLE() (git-fixes).
- clk: fsl-sai: fix memory leak (git-fixes).
- commit bba80c9
* Tue Dec 22 2020 tiwai@suse.de
- ASoC: wm8994: Fix PM disable depth imbalance on error
  (git-fixes).
- commit e953294
* Tue Dec 22 2020 tiwai@suse.de
- Update commit ids for already cherry-picked pinctrl patches
- commit 5e797b0
* Tue Dec 22 2020 tiwai@suse.de
- dmaengine: idxd: add IAX configuration support in the IDXD
  driver (jsc#SLE-13380).
- dmaengine: idxd: add ATS disable knob for work queues
  (jsc#SLE-13380).
- commit aca8d81
* Tue Dec 22 2020 tiwai@suse.de
- Add cherry-picked dup ID for IDXD patch
- commit 1fde049
* Tue Dec 22 2020 tiwai@suse.de
- Move ASoC patch into sorted section
  The patch was mistakenly put into nirvana because of badly tagged commit id.
- commit df0bd91
* Tue Dec 22 2020 tiwai@suse.de
- Move upstreamed IDXD patches into sorted section
- commit 6ca191c
* Tue Dec 22 2020 tiwai@suse.de
- clk: mvebu: a3700: fix the XTAL MODE pin to MPP1_9 (git-fixes).
- clk: sunxi-ng: Make sure divider tables have sentinel
  (git-fixes).
- clk: s2mps11: Fix a resource leak in error handling paths in
  the probe function (git-fixes).
- clk: ingenic: Fix divider calculation with div tables
  (git-fixes).
- clk: at91: sam9x60: remove atmel,osc-bypass support (git-fixes).
- clk: ti: Fix memleak in ti_fapll_synth_setup (git-fixes).
- clk: mediatek: Make mtk_clk_register_mux() a static function
  (git-fixes).
- clk: tegra: Fix duplicated SE clock entry (git-fixes).
- clk: tegra: Do not return 0 on failure (git-fixes).
- lan743x: fix for potential NULL pointer dereference with bare
  card (git-fixes).
- commit 21d14d2
* Tue Dec 22 2020 firo.yang@suse.com
- drivers/base/memory.c: indicate all memory blocks as removable
  (bsc#1180264).
- commit 64673b1
* Tue Dec 22 2020 bp@suse.de
- x86/cpu: Add a X86_MATCH_INTEL_FAM6_MODEL_STEPPINGS() macro
  (jsc#SLE-13358).
- commit 6c034c0
* Tue Dec 22 2020 bp@suse.de
- EDAC/i10nm: Add Intel Sapphire Rapids server support
  (jsc#SLE-13358).
- commit 991ab76
* Tue Dec 22 2020 bp@suse.de
- EDAC/i10nm: Use readl() to access MMIO registers
  (jsc#SLE-13358).
- commit 0389f79
* Mon Dec 21 2020 bp@suse.de
- EDAC: Add DDR5 new memory type (jsc#SLE-13358).
- commit add2e95
* Mon Dec 21 2020 jlee@suse.com
- ACPI: processor: Fix build for ARCH_APICTIMER_STOPS_ON_C3 unset
  (jsc#SLE-16407).
- ACPI: processor: Use CPUIDLE_FLAG_TIMER_STOP (jsc#SLE-16407).
- ACPI: OSL: Prevent acpi_release_memory() from returning too
  early (jsc#SLE-16407).
- ACPI: ioremap: avoid redundant rounding to OS page size
  (jsc#SLE-16407).
- ACPI: SoC: APD: Check return value of acpi_dev_get_property()
  (jsc#SLE-16407).
- ACPI: APD: Add a fmw property is_raven (jsc#SLE-16407).
- ACPI: APD: Change name from ST to FCH (jsc#SLE-16407).
- i2c: designware: Add device HID for Hygon I2C controller
  (jsc#SLE-16407).
- ACPI: NFIT: Fix ARS zero-sized allocation (jsc#SLE-16407).
- acpi: thermal: Don't call thermal_zone_device_is_enabled()
  (jsc#SLE-16407).
- thermal: Simplify or eliminate unnecessary set_mode() methods
  (jsc#SLE-16407).
- thermal: Use mode helpers in drivers (jsc#SLE-16407).
- thermal: Add mode helpers (jsc#SLE-16407).
- thermal: remove get_mode() operation of drivers (jsc#SLE-16407).
- thermal: Store device mode in struct thermal_zone_device
  (jsc#SLE-16407).
- thermal: Add current mode to thermal zone device
  (jsc#SLE-16407).
- thermal: Store thermal mode in a dedicated enum (jsc#SLE-16407).
  Refresh
  patches.suse/acpi_thermal_passive_blacklist.patch
- acpi: thermal: Fix error handling in the register function
  (jsc#SLE-16407).
- sched,acpi_pad: Convert to sched_set_fifo*() (jsc#SLE-16407).
- ACPI: Replace HTTP links with HTTPS ones (jsc#SLE-16407).
  Refresh
  patches.suse/0017-ACPI-NFIT-Define-runtime-firmware-activation-command.patch
- ACPI: Use valid link to the ACPI specification (jsc#SLE-16407).
- ACPI: Use fallthrough pseudo-keyword (jsc#SLE-16407).
- ACPI: APEI: remove redundant assignment to variable rc
  (jsc#SLE-16407).
- ACPI: NUMA: Remove the useless 'node >= MAX_NUMNODES' check
  (jsc#SLE-16407).
- ACPI: NUMA: Remove the useless sub table pointer check
  (jsc#SLE-16407).
- ACPI: tables: Remove the duplicated checks for
  acpi_parse_entries_array() (jsc#SLE-16407).
- ACPI: tables: avoid relocations for table signature array
  (jsc#SLE-16407).
- ACPI: OSL: Clean up the removal of unused memory mappings
  (jsc#SLE-16407).
- ACPI: OSL: Use deferred unmapping in acpi_os_unmap_iomem()
  (jsc#SLE-16407).
- ACPI: OSL: Use deferred unmapping in
  acpi_os_unmap_generic_address() (jsc#SLE-16407).
- ACPI: OSL: Implement deferred unmapping of ACPI memory
  (jsc#SLE-16407).
- ACPI: property: use cached name in
  acpi_fwnode_get_named_child_node() (jsc#SLE-16407).
- ACPI: EC: add newline when printing 'ec_event_clearing' module
  parameter (jsc#SLE-16407).
- ACPI: PAD: Eliminate usage of uninitialized_var() macro
  (jsc#SLE-16407).
- ACPI: sysfs: add newlines when printing module parameters
  (jsc#SLE-16407).
- ACPI: procfs: Remove last dirs after being marked deprecated
  for a decade (jsc#SLE-16407).
- Remove
  patches.suse/acpi-disable-deprecated-warnings.patch
- Update config files.
  x86_64/default removed CONFIG_ACPI_PROCFS_POWER=y
- ACPICA: Update version to 20200717 (jsc#SLE-16407).
- acpi: Extend TPM2 ACPI table with missing log fields
  (jsc#SLE-16407).
- libnvdimm: Replace guid_copy() with import_guid() where it
  makes sense (jsc#SLE-16407).
- thermal/of: Rename of-thermal.c (jsc#SLE-16407).
- ACPICA: Update version to 20200528 (jsc#SLE-16407).
- PCI: Rename _DSM constants to align with spec (jsc#SLE-16407).
- ACPI: DPTF: Add battery participant driver (jsc#SLE-16407).
  Refresh
  patches.suse/ACPI-DPTF-Add-battery-participant-for-TigerLake.patch
- ACPI: DPTF: Additional sysfs attributes for power participant
  driver (jsc#SLE-16407).
- ACPI / PMIC: Add i2c address for thermal control
  (jsc#SLE-16407).
- ACPI: utils: Add acpi_evaluate_reg() helper (jsc#SLE-16407).
- ACPI: Delete unused proc filename macros (jsc#SLE-16407).
- ACPI: debug: Make two functions static (jsc#SLE-16407).
- ACPI: processor: idle: Allow probing on platforms with one
  ACPI C-state (jsc#SLE-16407).
- ACPI: sleep: Put the FACS table after using it (jsc#SLE-16407).
- ACPI: scan: Put SPCR and STAO table after using it
  (jsc#SLE-16407).
- ACPI: EC: Put the ACPI table after using it (jsc#SLE-16407).
- ACPI: APEI: Put the HEST table for error path (jsc#SLE-16407).
- ACPI: APEI: Put the error record serialization table for error
  path (jsc#SLE-16407).
- ACPI: APEI: Put the error injection table for error path and
  module exit (jsc#SLE-16407).
- ACPI: APEI: Put the boot error record table after parsing
  (jsc#SLE-16407).
- ACPI: watchdog: Put the watchdog action table after parsing
  (jsc#SLE-16407).
- ACPI: LPIT: Put the low power idle table after using it
  (jsc#SLE-16407).
- ACPICA: Update version to 20200430 (jsc#SLE-16407).
- PM: sleep: core: Rename DPM_FLAG_LEAVE_SUSPENDED
  (jsc#SLE-16407).
- PM: sleep: core: Rename dev_pm_smart_suspend_and_suspended()
  (jsc#SLE-16407).
- PM: sleep: core: Rename dev_pm_may_skip_resume()
  (jsc#SLE-16407).
- PM: sleep: core: Rework the power.may_skip_resume handling
  (jsc#SLE-16407).
- PM: sleep: core: Do not skip callbacks in the resume phase
  (jsc#SLE-16407).
- PM: sleep: core: Fold functions into their callers
  (jsc#SLE-16407).
- PM: sleep: core: Simplify the SMART_SUSPEND flag handling
  (jsc#SLE-16407).
- ACPI: PM: s2idle: Print type of wakeup debug messages
  (jsc#SLE-16407).
- ACPI/PCI: pci_link: use extended_irq union member when setting
  ext-irq shareable (jsc#SLE-16407).
- ACPI: button: Drop no longer necessary Asus T200TA
  lid_init_state quirk (jsc#SLE-16407).
- ACPI: EC: Fix up fast path check in acpi_ec_add()
  (jsc#SLE-16407).
- ACPI: NFIT: Replace zero-length array with flexible-array member
  (jsc#SLE-16407).
- ACPI: NUMA: Up-level "map to online node" functionality
  (jsc#SLE-16407).
- ACPICA: Update version 20200326 (jsc#SLE-16407).
- ACPICA: WSMT: Fix typo, no functional change (jsc#SLE-16407).
- ACPICA: Fix IVRS IVHD type 10h reserved field name
  (jsc#SLE-16407).
- ACPICA: Implement IVRS IVHD type 11h parsing (jsc#SLE-16407).
- ACPICA: Fix a typo in a comment field (jsc#SLE-16407).
- x86: ACPI: fix CPU hotplug deadlock (jsc#SLE-16407).
- PM: sleep: core: Drop racy and redundant checks from
  device_prepare() (jsc#SLE-16407).
  Refresh
  patches.suse/0011-PM-sleep-core-Rename-DPM_FLAG_NEVER_SKIP.patch
- PCI/ACPI: Move pcie_to_hpx3_type from stack to static data
  (jsc#SLE-16407).
- acpi: Remove header dependency (jsc#SLE-16407).
- ACPI: PCI: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-16407).
- ACPI: fan: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-16407).
- ACPI: EC: Eliminate EC_FLAGS_QUERY_HANDSHAKE (jsc#SLE-16407).
- ACPI: EC: Do not clear boot_ec_is_ecdt in acpi_ec_add()
  (jsc#SLE-16407).
- blacklist.conf:
  Removed
  65a691f5f8f0bb63d6a82eec7b0ffd193d8d8a5f # ACPI: not for stable, reverted below
  c85a7109f905f7848735ef50d7e63e5534c4e95d # ACPI: stable commit reverting the above
- ACPI: EC: Simplify acpi_ec_ecdt_start() and acpi_ec_init()
  (jsc#SLE-16407).
- ACPI: EC: Consolidate event handler installation code
  (jsc#SLE-16407).
- ACPI: EC: Use fast path in acpi_ec_add() for DSDT boot EC
  (jsc#SLE-16407).
- ACPI: EC: Simplify acpi_ec_add() (jsc#SLE-16407).
- ACPI: EC: Drop AE_NOT_FOUND special case from
  ec_install_handlers() (jsc#SLE-16407).
- ACPI: EC: Avoid passing redundant argument to functions
  (jsc#SLE-16407).
- ACPI: EC: Avoid printing confusing messages in acpi_ec_setup()
  (jsc#SLE-16407).
- ACPI: list_for_each_safe() -> list_for_each_entry_safe()
  (jsc#SLE-16407).
- ACPI: video: remove redundant assignments to variable result
  (jsc#SLE-16407).
- ACPI: OSL: Add missing __acquires/__releases annotations
  (jsc#SLE-16407).
- ACPI / battery: Cleanup Lenovo Ideapad Miix 320 DMI table entry
  (jsc#SLE-16407).
- ACPI / AC: Cleanup DMI quirk table (jsc#SLE-16407).
- ACPI: Add new tiny-power-button driver to directly signal init
  (jsc#SLE-16407).
  Update config files.
  x86_64/default add # CONFIG_ACPI_TINY_POWER_BUTTON is not set
  arm64/default add # CONFIG_ACPI_TINY_POWER_BUTTON is not set
- ACPI: button: move HIDs to acpi/button.h (jsc#SLE-16407).
- ACPICA: Update version to 20200214 (jsc#SLE-16407).
- PM: sleep: core: Use built-in RCU list checking (jsc#SLE-16407).
- i2c: designware: Add ACPI HID for Hisilicon Hip08-Lite I2C
  controller (jsc#SLE-16407).
- ACPI / APD: Add clock frequency for Hisilicon Hip08-Lite I2C
  controller (jsc#SLE-16407).
- ACPI/IORT: Parse SSID property of named component node
  (jsc#SLE-16407).
  Refresh
  patches.suse/ACPI-IORT-Add-an-input-ID-to-acpi_dma_configure.patch
- ACPI: thermal: switch to use <linux/units.h> helpers
  (jsc#SLE-16407).
- ACPI / LPSS: Rename pwm_backlight pwm-lookup to
  pwm_soc_backlight (jsc#SLE-16407).
- ACPI: PPTT: Consistently use unsigned int as parameter type
  (jsc#SLE-16407).
- ACPI: video: Use native backlight on Lenovo E41-25/45
  (jsc#SLE-16407).
- ACPI: video: fix typo in comment (jsc#SLE-16407).
- ACPICA: Update version to 20200110 (jsc#SLE-16407).
- ACPICA: Update version to 20191213 (jsc#SLE-16407).
- ACPICA: acpisrc: add unix line ending support for non-windows
  build (jsc#SLE-16407).
- ACPI: Fix Kconfig indentation (jsc#SLE-16407).
- ACPI: button: Add DMI quirk for Acer Switch 10 SW5-032
  lid-switch (jsc#SLE-16407).
- device property: Add a function to obtain a node's prefix
  (jsc#SLE-16407).
  Refresh
  patches.suse/device-property-export-fwnode_get_name.patch
- ACPI: HMAT: use %%u instead of %%d to print u32 values
  (jsc#SLE-16407).
- ACPI: NUMA: HMAT: fix a section mismatch (jsc#SLE-16407).
- ACPI: HMAT: don't mix pxm and nid when setting memory target
  processor_pxm (jsc#SLE-16407).
- ACPI: NUMA: HMAT: Register "soft reserved" memory as an "hmem"
  device (jsc#SLE-16407).
- ACPI: NUMA: HMAT: Register HMAT at device_initcall level
  (jsc#SLE-16407).
- device-dax: Add a driver for "hmem" devices (jsc#SLE-16407).
- Update config files.
  x86_64/default add CONFIG_DEV_DAX_HMEM=m
  arm64/default add CONFIG_DEV_DAX_HMEM=m
- supported.conf:
  - drivers/dax/dax_hmem
- ACPI: NUMA: Establish a new drivers/acpi/numa/ directory
  (jsc#SLE-16407).
  Update config files.
- ACPI: video: update doc for acpi_video_bus_DOS()
  (jsc#SLE-16407).
- ACPI: platform: Unregister stale platform devices
  (jsc#SLE-16407).
- ACPI / LPSS: Switch to use acpi_dev_hid_uid_match()
  (jsc#SLE-16407).
- ACPI / utils: Describe function parameters in kernel-doc
  (jsc#SLE-16407).
- ACPI: button: Remove unused acpi_lid_notifier_register()
  functions (jsc#SLE-16407).
  Refresh
  patches.suse/ACPI-button-fix-handling-lid-state-changes-when-inpu.patch
- ACPI: button: Add DMI quirk for Asus T200TA (jsc#SLE-16407).
- ACPI: button: Turn lid_blacklst DMI table into a generic quirk
  table (jsc#SLE-16407).
  Refresh
  patches.suse/ACPI-button-Add-DMI-quirk-for-Medion-Akoya-E2215T.patch
- ACPI: button: Allow disabling LID support with the
  lid_init_state module option (jsc#SLE-16407).
- ACPI: button: Refactor lid_init_state module parsing code
  (jsc#SLE-16407).
- ACPI / PMIC: Add Cherry Trail Crystal Cove PMIC OpRegion driver
  (jsc#SLE-16407).
- ACPI / PMIC: Add byt prefix to Crystal Cove PMIC OpRegion driver
  (jsc#SLE-16407).
- ACPI / PMIC: Do not register handlers for unhandled OpRegions
  (jsc#SLE-16407).
- ACPI: EC: add support for hardware-reduced systems
  (jsc#SLE-16407).
- ACPI: EC: tweak naming in preparation for GpioInt support
  (jsc#SLE-16407).
- ACPICA: Update version to 20191018 (jsc#SLE-16407).
- ACPI: OSI: Shoot duplicate word (jsc#SLE-16407).
- ACPI: processor_idle: Skip dummy wait if kernel is in guest
  (jsc#SLE-16407).
- acpi: Use pr_warn instead of pr_warning (jsc#SLE-16407).
  Refresh
  patches.suse/acpi-disable-deprecated-warnings.patch
- ACPI: HMAT: ACPI_HMAT_MEMORY_PD_VALID is deprecated since
  ACPI-6.3 (jsc#SLE-16407).
- PCI/ACPI: Remove unnecessary struct hotplug_program_ops
  (jsc#SLE-16407).
  Refresh
  patches.suse/pci-aer-add-pci_aer_raw_clear_status-to-unconditionally-clear-error-status
- PCI/ACPI: Move _HPP & _HPX functions to pci-acpi.c
  (jsc#SLE-16407).
  Refresh
  patches.suse/pci-aer-add-pci_aer_raw_clear_status-to-unconditionally-clear-error-status
- PCI/ACPI: Rename _HPX structs from hpp_* to hpx_*
  (jsc#SLE-16407).
- PCI: Move ASPM declarations to linux/pci.h (jsc#SLE-16407).
  Refresh
  patches.suse/r8169-improve-rtl_get_coalesce.patch
  patches.suse/mt76-mt76x2e-disable-pcie_aspm-by-default.patch
  patches.suse/mt76-fix-include-in-pci.h.patch
- ACPI: thermal: Remove redundant acpi_has_method() calls
  (jsc#SLE-16407).
- ACPI: SBS: remove unused const variable 'SMBUS_PEC'
  (jsc#SLE-16407).
- ACPI/PCI: Remove surplus parentheses from a return statement
  (jsc#SLE-16407).
- HMAT: Register attributes for memory hot add (jsc#SLE-16407).
  Refresh
  patches.suse/0001-HMAT-Skip-publishing-target-info-for-nodes-with-no-o.patch
- ACPI / APEI: Get rid of NULL_UUID_LE constant (jsc#SLE-16407).
  Refresh
  patches.suse/ACPI-APEI-Kick-the-memory_failure-queue-for-synchron.patch
- ACPICA: Update version to 20190816 (jsc#SLE-16407).
- ACPICA: Macros: remove pointer math on a null pointer
  (jsc#SLE-16407).
- ACPI: PM: Print debug messages on device power state changes
  (jsc#SLE-16407).
- PM: sleep: Drop dpm_noirq_begin() and dpm_noirq_end()
  (jsc#SLE-16407).
- PM: sleep: Integrate suspend-to-idle with generig suspend flow
  (jsc#SLE-16407).
- drivers: Introduce device lookup variants by ACPI_COMPANION
  device (jsc#SLE-16407).
- Refresh
  patches.suse/drivers-base-implement-dev_enable_async_probe.patch
  patches.suse/i2c-acpi-put-device-when-verifying-client-fails.patch
- acpi: Use built-in RCU list checking for acpi_ioremaps list
  (jsc#SLE-16407).
- commit 2e42a5c
* Mon Dec 21 2020 osalvador@suse.de
- mm,memory_failure: always pin the page in madvise_inject_error
  (bsc#1180258).
- commit 7fb306a
* Mon Dec 21 2020 bp@suse.de
- x86/mm/ident_map: Check for errors from ident_pud_init()
  (bsc#1152489).
- commit 37afaed
* Mon Dec 21 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/IB-isert-Fix-unaligned-immediate-data-handling.patch
  patches.suse/IB-mthca-fix-return-value-of-error-branch-in-mthca_i.patch
  patches.suse/IB-rdmavt-Fix-sizeof-mismatch.patch
  patches.suse/IB-srpt-Fix-memory-leak-in-srpt_add_one.patch
  patches.suse/IB-uverbs-Set-IOVA-on-IB-MR-in-uverbs-layer.patch
  patches.suse/RDMA-bnxt_re-Do-not-add-user-qps-to-flushlist.patch
  patches.suse/RDMA-core-Fix-bogus-WARN_ON-during-ib_unregister_dev.patch
  patches.suse/RDMA-core-Fix-reported-speed-and-width.patch
  patches.suse/RDMA-core-Fix-return-error-value-in-_ib_modify_qp-to.patch
  patches.suse/RDMA-core-Free-DIM-memory-in-error-unwind.patch
  patches.suse/RDMA-core-Stop-DIM-before-destroying-CQ.patch
  patches.suse/RDMA-counter-Allow-manually-bind-QPs-with-different-.patch
  patches.suse/RDMA-counter-Only-bind-user-QPs-in-auto-mode.patch
  patches.suse/RDMA-hns-Bugfix-for-memory-window-mtpt-configuration.patch
  patches.suse/RDMA-netlink-Remove-CAP_NET_RAW-check-when-dump-a-ra.patch
  patches.suse/RDMA-pvrdma-Fix-missing-kfree-in-pvrdma_register_dev.patch
  patches.suse/RDMA-qedr-Endianness-warnings-cleanup.patch
  patches.suse/RDMA-qedr-Fix-memory-leak-in-iWARP-CM.patch
  patches.suse/RDMA-qedr-SRQ-s-bug-fixes.patch
  patches.suse/RDMA-rxe-Drop-pointless-checks-in-rxe_init_ports.patch
  patches.suse/RDMA-rxe-Fix-memleak-in-rxe_mem_init_user.patch
  patches.suse/RDMA-rxe-Fix-skb-lifetime-in-rxe_rcv_mcast_pkt.patch
  patches.suse/RDMA-rxe-Fix-the-parent-sysfs-read-when-the-interfac.patch
  patches.suse/RDMA-rxe-Handle-skb_clone-failure-in-rxe_recv.c.patch
  patches.suse/RDMA-rxe-Prevent-access-to-wr-next-ptr-afrer-wr-is-p.patch
  patches.suse/RDMA-rxe-Remove-unused-rxe_mem_map_pages.patch
  patches.suse/RDMA-rxe-Return-void-from-rxe_init_port_param.patch
  patches.suse/RDMA-rxe-Return-void-from-rxe_mem_init_dma.patch
  patches.suse/RDMA-rxe-Skip-dgid-check-in-loopback-mode.patch
  patches.suse/RDMA-srpt-Fix-typo-in-srpt_unregister_mad_agent-docs.patch
- commit 2dad798
* Mon Dec 21 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/scsi-mpt3sas-add-bypass_dirty_port_flag-parameter
  patches.suse/scsi-mpt3sas-add-module-parameter-multipath_on_hba
  patches.suse/scsi-mpt3sas-allocate-memory-for-hba_port-objects
  patches.suse/scsi-mpt3sas-bump-driver-version-to-35-101-00-00
  patches.suse/scsi-mpt3sas-define-hba_port-structure
  patches.suse/scsi-mpt3sas-get-device-objects-using-sas_address-portid
  patches.suse/scsi-mpt3sas-get-sas_device-objects-using-device-s-rphy
  patches.suse/scsi-mpt3sas-handle-vses-vphy-object-during-hba-reset
  patches.suse/scsi-mpt3sas-handling-hba-vses-device
  patches.suse/scsi-mpt3sas-rearrange-scsih_mark_responding_sas_device
  patches.suse/scsi-mpt3sas-rename-transport_del_phy_from_an_existing_port
  patches.suse/scsi-mpt3sas-set-valid-physicalport-in-smppassthrough
  patches.suse/scsi-mpt3sas-update-hba_port-objects-after-host-reset
  patches.suse/scsi-mpt3sas-update-hba_port-s-sas_address-phy_mask
- commit a2950eb
* Mon Dec 21 2020 bp@suse.de
- EDAC/i10nm: Use readl() to access MMIO registers (bsc#1152489).
- commit a3a0100
* Mon Dec 21 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/powerpc-perf-Fix-crash-with-is_sier_available-when-p.patch
- commit adb35a0
* Mon Dec 21 2020 glin@suse.com
- samples/bpf: Fix possible hang in xdpsock with multiple threads
  (bsc#1177028).
- libbpf: Sanitise map names before pinning (bsc#1177028).
- samples: bpf: Refactor hbm program with libbpf (bsc#1177028).
- tools/bpftool: Fix build slowdown (bsc#1177028).
- bpf: Fix propagation of 32-bit signed bounds from 64-bit bounds
  (bsc#1177028).
- selftests/bpf/test_offload.py: Filter bpftool internal map
  when counting maps (bsc#1177028).
- selftests/bpf/test_offload.py: Fix expected case of extack
  messages (bsc#1177028).
- selftests/bpf/test_offload.py: Only check verifier log on
  verification fails (bsc#1177028).
- selftests/bpf/test_offload.py: Remove check for program load
  flags match (bsc#1177028).
- xdp: Remove the xdp_attachment_flags_ok() callback
  (bsc#1177028).
- tools/bpftool: Fix PID fetching with a lot of results
  (bsc#1177028).
- selftests/bpf: Drain ringbuf samples at the end of test
  (bsc#1177028).
- libbpf: Fix ring_buffer__poll() to return number of consumed
  samples (bsc#1177028).
- commit fa84f47
* Mon Dec 21 2020 glin@suse.com
- series.conf: refresh
- update upstream references and resort:
  patches.suse/arm64-force-no_block_mappings-if-crashkernel-reservation-is-required.patch.
  patches.suse/arm64-ignore-any-dma-offsets-in-the-max_zone_phys-calculation.patch.
  patches.suse/arm64-mm-move-reserve_crashkernel-into-mem_init.patch.
  patches.suse/arm64-mm-move-zone_dma_bits-initialization-into-zone_sizes_init.patch.
  patches.suse/arm64-mm-set-zone_dma-size-based-on-devicetree-s-dma-ranges.patch.
  patches.suse/arm64-mm-set-zone_dma-size-based-on-early-iort-scan.patch.
  patches.suse/ibmvnic-Clean-up-TX-code-and-TX-buffer-data-structur.patch.
  patches.suse/ibmvnic-Correctly-re-enable-interrupts-in-NAPI-polli.patch.
  patches.suse/ibmvnic-Do-not-replenish-RX-buffers-after-every-poll.patch.
  patches.suse/ibmvnic-Ensure-that-device-queue-memory-is-cache-lin.patch.
  patches.suse/ibmvnic-Introduce-batched-RX-buffer-descriptor-trans.patch.
  patches.suse/ibmvnic-Introduce-indirect-subordinate-Command-Respo.patch.
  patches.suse/ibmvnic-Introduce-xmit_more-support-using-batched-su.patch.
  patches.suse/ibmvnic-Remove-send_subcrq-function.patch.
  patches.suse/ibmvnic-Use-netdev_alloc_skb-instead-of-alloc_skb-to.patch.
  patches.suse/ibmvnic-fix-rx-buffer-tracking-and-index-management-.patch.
  patches.suse/net-smc-improve-return-codes-for-smc-dv2.
  patches.suse/of-address-introduce-of_dma_get_max_cpu_address.patch.
  patches.suse/powerpc-perf-Add-generic-and-cache-event-list-for-po.patch.
  patches.suse/powerpc-perf-Add-new-power-PMU-flag-PPMU_P10_DD1-for.patch.
  patches.suse/powerpc-perf-Drop-the-check-for-SIAR_VALID.patch.
  patches.suse/powerpc-perf-Fix-crash-with-is_sier_available-when-p.patch.
  patches.suse/powerpc-perf-Fix-the-PMU-group-constraints-for-thres.patch.
  patches.suse/powerpc-perf-Fix-to-update-cache-events-with-l2l3-ev.patch.
  patches.suse/powerpc-perf-Fix-to-update-generic-event-codes-for-p.patch.
  patches.suse/powerpc-perf-Fix-to-update-radix_scope_qual-in-power.patch.
  patches.suse/powerpc-perf-Invoke-per-CPU-variable-access-with-dis.patch.
  patches.suse/powerpc-perf-MMCR0-control-for-PMU-registers-under-P.patch.
  patches.suse/powerpc-perf-Update-the-PMU-group-constraints-for-l2.patch.
  patches.suse/powerpc-perf-Use-regs-nip-when-SIAR-is-zero.patch.
  patches.suse/powerpc-perf-Use-the-address-from-SIAR-register-to-s.patch.
  patches.suse/s390-sles15sp3-03-01-s390-cio-Export-information-about-Endpoint-Security-.patch.
  patches.suse/s390-sles15sp3-03-02-s390-cio-Provide-Endpoint-Security-Mode-per-CU.patch.
  patches.suse/s390-sles15sp3-03-03-s390-cio-Add-support-for-FCES-status-notification.patch.
  patches.suse/s390-sles15sp3-03-04-s390-dasd-Remove-unused-parameter-from-dasd_generic_.patch.
  patches.suse/s390-sles15sp3-03-05-s390-dasd-Move-duplicate-code-to-separate-function.patch.
  patches.suse/s390-sles15sp3-03-06-s390-dasd-Store-path-configuration-data-during-path-.patch.
  patches.suse/s390-sles15sp3-03-07-s390-dasd-Fix-operational-path-inconsistency.patch.
  patches.suse/s390-sles15sp3-03-08-s390-dasd-Display-FC-Endpoint-Security-information-v.patch.
  patches.suse/s390-sles15sp3-03-09-s390-dasd-Prepare-for-additional-path-event-handling.patch.
  patches.suse/s390-sles15sp3-03-10-s390-dasd-Process-FCES-path-event-notification.patch.
  patches.suse/scsi-fnic-avoid-looping-in-trans-eth-on-unload.
  patches.suse/scsi-fnic-change-shost_printk-to-fnic_fcs_dbg.
  patches.suse/scsi-fnic-change-shost_printk-to-fnic_main_dbg.
  patches.suse/scsi-fnic-set-scsi_set_resid-only-for-underflow.
  patches.suse/scsi-fnic-validate-io_req-before-others.
- commit 41ceac4
* Mon Dec 21 2020 tiwai@suse.de
- rtc: pcf2127: fix pcf2127_nvmem_read/write() returns
  (git-fixes).
- commit fe3d756
* Mon Dec 21 2020 tiwai@suse.de
- rtc: ep93xx: Fix NULL pointer dereference in
  ep93xx_rtc_read_time (git-fixes).
- rtc: hym8563: enable wakeup when applicable (git-fixes).
- commit 52e449a
* Sun Dec 20 2020 tiwai@suse.de
- pwm: imx27: Fix overflow for bigger periods (git-fixes).
- firmware: tegra: fix strncpy()/strncat() confusion (git-fixes).
- mtd: spi-nor: ignore errors in spi_nor_unlock_all() (git-fixes).
- mtd: spi-nor: sst: fix BPn bits for the SST25VF064C (git-fixes).
- iwlwifi: sta: set max HE max A-MPDU according to HE capa
  (git-fixes).
- commit 48bc7b1
* Sun Dec 20 2020 tiwai@suse.de
- power: supply: bq24190_charger: fix reference leak (git-fixes).
- power: supply: axp288_charger: Fix HP Pavilion x2 10 DMI
  matching (git-fixes).
- HSI: omap_ssi: Don't jump to free ID in ssi_add_controller()
  (git-fixes).
- pwm: lp3943: Dynamically allocate PWM chip base (git-fixes).
- pwm: zx: Add missing cleanup in error path (git-fixes).
- commit 22a0fb4
* Fri Dec 18 2020 lduncan@suse.com
- Fixed 14 mpt3sas patches, now upstream (jsc#SLE-16914, bsc#1177733)
  Should be no functional change, bu the patches are updated
  with commit ID, and moved to the proper place in series.conf.
- commit eef3811
* Fri Dec 18 2020 martin.wilck@suse.com
- scsi: core: Fix VPD LUN ID designator priorities (bsc#1178049).
- commit efdf30e
* Fri Dec 18 2020 ykaukab@suse.de
- spi: spi-nxp-fspi: fix fspi panic by unexpected interrupts
  (bsc#1180214).
- rtc: pcf2127: fix a bug when not specify interrupts property
  (bsc#1180214).
- rtc: fsl-ftm-alarm: update acpi device id (bsc#1180214).
- ahci: qoriq: enable acpi support in qoriq ahci driver
  (bsc#1180214).
- spi: spi-nxp-fspi: Add ACPI support (bsc#1180214).
- commit 8759723
* Fri Dec 18 2020 oneukum@suse.com
- supported.conf: Declare qat4xxx supported externally by Intel
- commit b7913fb
* Fri Dec 18 2020 lduncan@suse.com
- scsi: mpt3sas: Bump driver version to 35.101.00.00
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Add module parameter multipath_on_hba
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Handle vSES vphy object during HBA reset
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Add bypass_dirty_port_flag parameter
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Handling HBA vSES device (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Set valid PhysicalPort in SMPPassThrough
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Update hba_port objects after host reset
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Get sas_device objects using device's rphy
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Rename transport_del_phy_from_an_existing_port()
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Get device objects using sas_address & portID
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Update hba_port's sas_address & phy_mask
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Rearrange _scsih_mark_responding_sas_device()
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Allocate memory for hba_port objects
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Define hba_port structure (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: A small correction in _base_process_reply_queue
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Fix sync irqs (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Detect tampered Aero and Sea adapters
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Remove pci-dma-compat wrapper API (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Remove superfluous memset() (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Update driver version to 35.100.00.00
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Postprocessing of target and LUN reset
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Add functions to check if any cmd is outstanding
  on Target and LUN (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Rename and export interrupt mask/unmask functions
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Cancel the running work during host reset
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Dump system registers for debugging
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Memset config_cmds.reply buffer with zeros
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Don't call disable_irq from IRQ poll handler
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Fix set but unused variable (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Fix error returns in BRM_status_show
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Fix unlock imbalance (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Fix memset() in non-RDPQ mode (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Fix reply queue count in non RDPQ mode
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Fix double free warnings (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Disable DIF when prot_mask set to zero
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Capture IOC data for debugging purposes
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Use true, false for ioc->use_32bit_dma
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Remove NULL check before freeing function
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Update mpt3sas version to 33.101.00.00
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Handle RDPQ DMA allocation in same 4G region
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Separate out RDPQ allocation to new function
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Rename function name is_MSB_are_same
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Don't change the DMA coherent mask after
  allocations (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: use true,false for bool variables (jsc#SLE-16914,
  bsc#1177733).
- commit 5bf7889
* Thu Dec 17 2020 oneukum@suse.com
- crypto: qat - add capability detection logic in qat_4xxx
  (jsc#SLE-14454).
- commit 83336e3
* Thu Dec 17 2020 oneukum@suse.com
- crypto: qat - add AES-XTS support for QAT GEN4 devices
  (jsc#SLE-14454).
- Refresh patches.suse/QAT-add-suse_kabi_padding.patch.
- commit 3755a1e
* Thu Dec 17 2020 oneukum@suse.com
- crypto: qat - add AES-CTR support for QAT GEN4 devices
  (jsc#SLE-14454).
- commit 5393983
* Thu Dec 17 2020 oneukum@suse.com
- crypto: qat - fix excluded_middle.cocci warnings
  (jsc#SLE-14454).
- commit a62bf18
* Thu Dec 17 2020 mbenes@suse.cz
- tracing: Fix race in trace_open and buffer resize call
  (CVE-2020-27825 bsc#1179960).
- commit c590ed4
* Thu Dec 17 2020 mbenes@suse.cz
- ring-buffer: speed up buffer resets by avoiding synchronize_rcu
  for each CPU (CVE-2020-27825 bsc#1179960).
- commit d308278
* Thu Dec 17 2020 mbenes@suse.cz
- ring-buffer: Make resize disable per cpu buffer instead of
  total buffer (CVE-2020-27825 bsc#1179960).
- commit 95e9004
* Thu Dec 17 2020 oneukum@suse.com
- crypto: qat - add gen4 firmware loader (jsc#SLE-14454).
- commit 9d44e54
* Thu Dec 17 2020 tiwai@suse.de
- Drop a backported uvcvideo patch that caused a regression (bsc#1180117)
  Also blacklisting the commit
- commit b185b93
* Thu Dec 17 2020 pjakobsson@suse.de
- blacklist.conf: Remove temporary drm path blacklist
- commit f037d4c
* Thu Dec 17 2020 oneukum@suse.com
- crypto: qat - add qat_4xxx driver (jsc#SLE-14454).
  Update config files.
- commit 8df8685
* Thu Dec 17 2020 oneukum@suse.com
- crypto: s390/sha1 - prefix the "sha1_" functions
  (jsc#SLE-14454).
- commit aad706f
* Thu Dec 17 2020 oneukum@suse.com
- crypto: qat - add hook to initialize vector routing table
  (jsc#SLE-14454).
- commit 21c4c5c
* Thu Dec 17 2020 bp@suse.de
- x86/resctrl: Fix incorrect local bandwidth when mba_sc is
  enabled (bsc#1152489).
- x86/resctrl: Remove unused struct mbm_state::chunks_bw
  (bsc#1152489).
- commit b4996a1
* Thu Dec 17 2020 oneukum@suse.com
- crypto: powerpc/sha1 - prefix the "sha1_" functions
  (jsc#SLE-14454).
- commit 7a8e9d4
* Thu Dec 17 2020 dwagner@suse.de
- nvmet-fc: fix missing check for no hostport struct
  (bsc#1176942).
- commit 7fab8fc
* Thu Dec 17 2020 dwagner@suse.de
- scsi: qla2xxx: Update version to 10.02.00.104-k (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Fix device loss on 4G and older HBAs (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: If fcport is undergoing deletion complete I/O
  with retry (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Fix the call trace for flush workqueue
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Fix flash update in 28XX adapters on big endian
  machines (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Handle aborts correctly for port undergoing
  deletion (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Fix N2N and NVMe connect retry failure
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Fix FW initialization error on big endian
  machines (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Fix crash during driver load on big endian
  machines (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Fix compilation issue in PPC systems (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Don't check for fw_started while posting NVMe
  command (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Tear down session if FW say it is down
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Limit interrupt vectors to number of CPUs
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Change post del message from debug level to
  log level (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Remove in_interrupt() from qla83xx-specific code
  (bsc#1171688 bsc#1172733).
- scsi: target: tcm_qla2xxx: Remove BUG_ON(in_interrupt())
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Remove in_interrupt() from qla82xx-specific code
  (bsc#1171688 bsc#1172733).
- commit 298833c
* Thu Dec 17 2020 oneukum@suse.com
- crypto: qat - target fw images to specific AEs (jsc#SLE-14454).
- commit e7e8777
* Thu Dec 17 2020 dwagner@suse.de
- scsi: qla2xxx: Move sess cmd list/lock to driver (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Drop TARGET_SCF_LOOKUP_LUN_FROM_TAG (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Return EBUSY on fcport deletion (bsc#1171688
  bsc#1172733).
  Replace patches.suse/qla2xxx-return-ebusy-on-fcport-deletion.patch
  with upstream version.
- scsi: qla2xxx: remove incorrect sparse #ifdef (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Fix return of uninitialized value in rval
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Convert to DEFINE_SHOW_ATTRIBUTE (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Initialize variable in qla8044_poll_reg()
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Do not consume srb greedily (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Handle incorrect entry_type entries (bsc#1171688
  bsc#1172733).
- commit 3c29fc6
* Thu Dec 17 2020 bp@suse.de
- x86/mm/mem_encrypt: Fix definition of PMD_FLAGS_DEC_WP
  (bsc#1152489).
- commit 994c3ae
* Thu Dec 17 2020 dwagner@suse.de
- scsi: qla2xxx: Use constant when it is known (bsc#1171688
  bsc#1172733).
  Refresh:
  - patches.suse/qla2xxx-return-ebusy-on-fcport-deletion.patch
- commit cfc1ae5
* Thu Dec 17 2020 oneukum@suse.com
- crypto: sha - split sha.h into sha1.h and sha2.h
  (jsc#SLE-14454).
- Refresh
  patches.suse/add-product-identifying-information-to-vmcoreinfo.patch.
- commit 8180f5f
* Thu Dec 17 2020 dwagner@suse.de
- scsi: lpfc: Fix fall-through warnings for Clang (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Correct null ndlp reference on routine exit
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Use generic power management (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix variable 'vport' set but not used in
  lpfc_sli4_abts_err_handler() (bsc#1175480 bsc#1176396
  bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix missing prototype for
  lpfc_nvmet_prep_abort_wqe() (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Fix set but unused variables
  in lpfc_dev_loss_tmo_handler() (bsc#1175480 bsc#1176396
  bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix set but not used warnings from Rework remote
  port lock handling (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Fix missing prototype warning for
  lpfc_fdmi_vendor_attr_mi() (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Fix memory leak on lcb_context (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Remove dead code on second !ndlp check (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix pointer defereference before it is null checked
  issue (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Update changed file copyrights for 2020 (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Update lpfc version to 12.8.0.6 (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Convert abort handling to SLI-3 and SLI-4 handlers
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Convert SCSI I/O completions to SLI-3 and SLI-4
  handlers (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Convert SCSI path to use common I/O submission path
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Enable common send_io interface for SCSI and NVMe
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Enable common wqe_template support for both SCSI
  and NVMe (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Refactor WQE structure definitions for common use
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix NPIV Fabric Node reference counting (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix NPIV discovery and Fabric Node detection
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Unsolicited ELS leaves node in incorrect state while
  dropping it (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Remove ndlp when a PLOGI/ADISC/PRLI/REG_RPI
  ultimately fails (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Rework remote port lock handling (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix refcounting around SCSI and NVMe transport APIs
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix removal of SCSI transport device get and put on
  dev structure (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Rework locations of ndlp reference taking
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Rework remote port ref counting and node freeing
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_nvmet: Fix-up some formatting and doc-rot
  issues (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_nvme: Fix some kernel-doc related issues
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_nvme: Remove unused variable 'phba'
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_bsg: Provide correct documentation for a bunch
  of functions (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_debugfs: Fix a couple of function documentation
  issues (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_attr: Fix-up a bunch of kernel-doc
  misdemeanours (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_attr: Demote kernel-doc format for redefined
  functions (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_scsi: Fix a whole host of kernel-doc issues
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Update lpfc version to 12.8.0.5 (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Reject CT request for MIB commands (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Add FDMI Vendor MIB support (bsc#1175480 bsc#1176396
  bsc#1176942 bsc#1177500).
- scsi: lpfc: Enlarge max_sectors in scsi host templates
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix duplicate wq_create_version check (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Removed unused macros in lpfc_attr.c (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Re-fix use after free in lpfc_rq_buf_free()
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix scheduling call while in softirq context
  in lpfc_unreg_rpi (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Fix invalid sleeping context in
  lpfc_sli4_nvmet_alloc() (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: Remove unneeded break statements (bsc#1175480 bsc#1176396
  bsc#1176942 bsc#1177500).
- scsi: lpfc: Remove unneeded variable 'status' in
  lpfc_fcp_cpu_map_store() (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Drop nodelist reference on error in lpfc_gen_req()
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Remove set but not used 'qp' (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix spelling mistake "Cant" -> "Can't" (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix initial FLOGI failure due to BBSCN not supported
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Update lpfc version to 12.8.0.4 (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Extend the RDF FPIN Registration descriptor
  for additional events (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Fix FLOGI/PLOGI receive race condition in pt2pt
  discovery (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- commit 6c7ebde
* Thu Dec 17 2020 tiwai@suse.de
- soc: amlogic: canvas: add missing put_device() call in
  meson_canvas_get() (git-fixes).
- drivers: soc: ti: knav_qmss_queue: Fix error return code in
  knav_queue_probe (git-fixes).
- soc: ti: Fix reference imbalance in knav_dma_probe (git-fixes).
- soc: ti: knav_qmss: fix reference leak in knav_queue_probe
  (git-fixes).
- soc: qcom: smp2p: Safely acquire spinlock without IRQs
  (git-fixes).
- soc: mediatek: Check if power domains can be powered on at
  boot time (git-fixes).
- soc/tegra: fuse: Fix index bug in get_process_id (git-fixes).
- soc: renesas: rmobile-sysc: Fix some leaks in
  rmobile_init_pm_domains() (git-fixes).
- soc: fsl: dpio: Get the cpumask through cpumask_of(cpu)
  (git-fixes).
- spi: spi-nxp-fspi: fix fspi panic by unexpected interrupts
  (git-fixes).
- commit 37de46f
* Thu Dec 17 2020 tiwai@suse.de
- platform/x86: intel-vbtn: Support for tablet mode on HP Pavilion
  13 x360 PC (git-fixes).
- Refresh
  patches.suse/platform-x86-intel-vbtn-Allow-switch-events-on-Acer-.patch.
- commit b789099
* Thu Dec 17 2020 tiwai@suse.de
- pinctrl: falcon: add missing put_device() call in
  pinctrl_falcon_probe() (git-fixes).
- mtd: rawnand: gpmi: Fix the random DMA timeout issue
  (git-fixes).
- mtd: rawnand: meson: Fix a resource leak in init (git-fixes).
- pinctrl: amd: remove debounce filter setting in IRQ type setting
  (git-fixes).
- platform/x86: touchscreen_dmi: Add info for the Irbis TW118
  tablet (git-fixes).
- platform/x86: acer-wmi: add automatic keyboard background
  light toggle key as KEY_LIGHTS_TOGGLE (git-fixes).
- platform/x86: thinkpad_acpi: Add BAT1 is primary battery quirk
  for Thinkpad Yoga 11e 4th gen (git-fixes).
- platform/x86: thinkpad_acpi: Do not report SW_TABLET_MODE on
  Yoga 11e (git-fixes).
- commit 3fd302b
* Thu Dec 17 2020 tiwai@suse.de
- mtd: rawnand: gpmi: fix reference count leak in gpmi ops
  (git-fixes).
- mtd: rawnand: meson: fix meson_nfc_dma_buffer_release()
  arguments (git-fixes).
- mtd: rawnand: qcom: Fix DMA sync on FLASH_STATUS register read
  (git-fixes).
- mtd: spinand: Fix OOB read (git-fixes).
- mfd: rt5033: Fix errorneous defines (git-fixes).
- Input: cm109 - do not stomp on control URB (git-fixes).
- Input: i8042 - add Acer laptops to the i8042 reset list
  (git-fixes).
- iwlwifi: mvm: fix kernel panic in case of assert during CSA
  (git-fixes).
- iwlwifi: pcie: limit memory read spin time (git-fixes).
- commit d3789b9
* Thu Dec 17 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/scsi-fnic-avoid-looping-in-trans-eth-on-unload
  patches.suse/scsi-fnic-change-shost_printk-to-fnic_fcs_dbg
  patches.suse/scsi-fnic-change-shost_printk-to-fnic_main_dbg
  patches.suse/scsi-fnic-set-scsi_set_resid-only-for-underflow
  patches.suse/scsi-fnic-validate-io_req-before-others
- commit 3190615
* Thu Dec 17 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/ibmvnic-add-some-debugs.patch
- commit 5542884
* Wed Dec 16 2020 rgoldwyn@suse.com
- fix regression in "epoll: Keep a reference on files added to the check list"  (bsc#1180031, git-fixes).
- commit 775fe31
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - add support for broadcasting mode (jsc#SLE-14454).
- commit 3eb975b
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - add support for shared ustore (jsc#SLE-14454).
- commit 8208824
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - allow to target specific AEs (jsc#SLE-14454).
- commit 95c0bc6
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - add FCU CSRs to chip info (jsc#SLE-14454).
- commit cced259
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - add CSS3K support (jsc#SLE-14454).
- commit 5745db4
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - use ae_mask (jsc#SLE-14454).
- commit 8f00dce
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - add check for null pointer (jsc#SLE-14454).
- crypto: qat - add misc control CSR to chip info (jsc#SLE-14454).
- crypto: qat - add wake up event to chip info (jsc#SLE-14454).
- commit 5b4f1a7
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - add clock enable CSR to chip info (jsc#SLE-14454).
- commit 0a0ceac
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - add reset CSR and mask to chip info
  (jsc#SLE-14454).
- crypto: qat - add local memory size to chip info
  (jsc#SLE-14454).
- commit 668485e
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - add support for lm2 and lm3 (jsc#SLE-14454).
- commit 7ae2a53
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - add next neighbor to chip_info (jsc#SLE-14454).
- crypto: qat - replace check based on DID (jsc#SLE-14454).
- commit 5d786df
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - introduce chip info structure (jsc#SLE-14454).
- crypto: qat - refactor long expressions (jsc#SLE-14454).
- commit 417a900
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - refactor qat_uclo_set_ae_mode() (jsc#SLE-14454).
- commit a769fdf
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - move defines to header files (jsc#SLE-14454).
- commit 316c7a5
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - remove global CSRs helpers (jsc#SLE-14454).
- commit 4eedc22
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - refactor AE start (jsc#SLE-14454).
- commit 20a1098
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - change micro word data mask (jsc#SLE-14454).
- crypto: qat - change type for ctx_mask (jsc#SLE-14454).
- crypto: qat - add support for relative FW ucode loading
  (jsc#SLE-14454).
- commit d529f37
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - rename qat_uclo_del_uof_obj() (jsc#SLE-14454).
- commit 67574e7
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - introduce additional parenthesis (jsc#SLE-14454).
- commit 755a426
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - remove unnecessary parenthesis (jsc#SLE-14454).
- commit 4966907
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - fix error message (jsc#SLE-14454).
- crypto: qat - fix CSR access (jsc#SLE-14454).
- commit 9206fc3
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - support for mof format in fw loader
  (jsc#SLE-14454).
- crypto: qat - replace pci with PCI in comments (jsc#SLE-14454).
- commit 9c9c3c5
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - remove cast for mailbox CSR (jsc#SLE-14454).
- commit 62896ad
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - remove unneeded semicolon (jsc#SLE-14454).
- commit 9e0b68a
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - extend ae_mask (jsc#SLE-14454).
- commit e36c762
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - allow for instances in different banks
  (jsc#SLE-14454).
- commit d74dd80
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - refactor qat_crypto_dev_config() (jsc#SLE-14454).
- commit 7b787fc
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - refactor qat_crypto_create_instances()
  (jsc#SLE-14454).
- commit d0bcaed
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - change return value in adf_cfg_key_val_get()
  (jsc#SLE-14454).
- commit f698585
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - change return value in
  adf_cfg_add_key_value_param() (jsc#SLE-14454).
- commit 707ca4a
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - remove unnecessary void* casts (jsc#SLE-14454).
- commit 428b2be
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - call functions in adf_sriov if available
  (jsc#SLE-14454).
- commit 56a083b
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - remove hardcoded bank irq clear flag mask
  (jsc#SLE-14454).
- commit 87975f0
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - abstract writes to arbiter enable (jsc#SLE-14454).
- commit c2673fd
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - use BIT_ULL() - 1 pattern for masks
  (jsc#SLE-14454).
- commit 4e50301
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - replace constant masks with GENMASK
  (jsc#SLE-14454).
- commit ace21f7
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - abstract build ring base (jsc#SLE-14454).
- commit 45f06e6
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - enable ring after pair is programmed
  (jsc#SLE-14454).
- commit 876666b
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - register crypto instances based on capability
  (jsc#SLE-14454).
- Refresh patches.suse/QAT-add-suse_kabi_padding.patch.
- commit f62a6a6
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - add support for capability detection
  (jsc#SLE-14454).
- commit f5cb13a
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/srpt: Fix typo in srpt_unregister_mad_agent docstring (bsc#1152489)
- commit b808e1d
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Handle skb_clone() failure in rxe_recv.c (bsc#1152489)
- commit ad662c6
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Endianness warnings cleanup (bsc#1152489)
- commit c3cca6a
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - abstract arbiter access (jsc#SLE-14454).
- commit 8234ef6
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - remove unused macros in arbiter module
  (jsc#SLE-14454).
- commit ace40aa
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - remove writes into WQCFG (jsc#SLE-14454).
- commit 1f08531
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - update constants table (jsc#SLE-14454).
- commit 42213a3
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - use admin mask to send fw constants
  (jsc#SLE-14454).
- commit 82fccc5
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - change admin sequence (jsc#SLE-14454).
- crypto: qat - rename ME in AE (jsc#SLE-14454).
- commit 3b63177
* Wed Dec 16 2020 rgoldwyn@suse.com
- do_epoll_ctl(): clean the failure exits up a bit
  (bsc#1180031,CVE-2020-0466).
- epoll: Keep a reference on files added to the check list
  (bsc#1180031).
- commit 5e9b787
* Wed Dec 16 2020 mbenes@suse.cz
- blacklist.conf: bcee52789588 ("tracing: Fix userstacktrace option for instances")
  The kernel is missing many prerequisities. It is not worth it as it is.
- commit e39f16a
* Wed Dec 16 2020 tiwai@suse.de
- Update patch reference for wireless fix (CVE-2020-27068 bsc#1180086)
- commit 170f743
* Wed Dec 16 2020 tiwai@suse.de
- platform/x86: mlx-platform: Fix item counter assignment for
  MSN2700/ComEx system (git-fixes).
- mmc: sdhci: tegra: fix wrong unit with busy_timeout (git-fixes).
- spi: imx: fix reference leak in two imx operations (git-fixes).
- driver: core: Fix list corruption after device_del()
  (git-fixes).
- iwlwifi: dbg-tlv: fix old length in is_trig_data_contained()
  (git-fixes).
- mt76: mt7615: fix rdd mcu cmd endianness (git-fixes).
- mt76: mt7915: fix endian issues (git-fixes).
- mt76: fix tkip configuration for mt7615/7663 devices
  (git-fixes).
- mt76: fix memory leak if device probing fails (git-fixes).
- mt76: mt7915: fix sparse warning cast from restricted __le16
  (git-fixes).
- mt76: set fops_tx_stats.owner to THIS_MODULE (git-fixes).
- mt76: mt7915: set fops_sta_stats.owner to THIS_MODULE
  (git-fixes).
- mt76: add back the SUPPORTS_REORDERING_BUFFER flag (git-fixes).
- Bluetooth: btusb: Fix detection of some fake CSR controllers
  with a bcdDevice val of 0x0134 (git-fixes).
- Bluetooth: Fix: LL PRivacy BLE device fails to connect
  (git-fixes).
- brcmfmac: fix error return code in brcmf_cfg80211_connect()
  (git-fixes).
- brcmfmac: Fix memory leak for unpaired brcmf_{alloc/free}
  (git-fixes).
- rtw88: remove extraneous 'const' qualifier (git-fixes).
- drm/doc: Document that modifiers are always required for fb
  (git-fixes).
- netdevsim: Add debugfs toggle to reject BPF programs in verifier
  (git-fixes).
- commit 3b2d7b6
* Wed Dec 16 2020 tiwai@suse.de
- platform/x86: mlx-platform: remove an unused variable
  (git-fixes).
- USB: serial: option: add interface-number sanity check to flag
  handling (git-fixes).
- commit bff4f99
* Wed Dec 16 2020 tiwai@suse.de
- USB: serial: mos7720: fix parallel-port state restore
  (git-fixes).
- xhci-pci: Allow host runtime PM as default for Intel Alpine
  Ridge LP (git-fixes).
- commit f265436
* Wed Dec 16 2020 tiwai@suse.de
- USB: serial: digi_acceleport: fix write-wakeup deadlocks
  (git-fixes).
- USB: serial: keyspan_pda: fix write unthrottling (git-fixes).
- USB: serial: keyspan_pda: fix tx-unthrottle use-after-free
  (git-fixes).
- USB: serial: keyspan_pda: fix write-wakeup use-after-free
  (git-fixes).
- USB: serial: keyspan_pda: fix stalled writes (git-fixes).
- USB: serial: keyspan_pda: fix write deadlock (git-fixes).
- USB: serial: keyspan_pda: fix dropped unthrottle interrupts
  (git-fixes).
- usb: oxu210hp-hcd: Fix memory leak in oxu_create (git-fixes).
- usb: ehci-omap: Fix PM disable depth umbalance in
  ehci_hcd_omap_probe (git-fixes).
- usb: mtu3: fix memory corruption in mtu3_debugfs_regset()
  (git-fixes).
- commit 7596d48
* Wed Dec 16 2020 tiwai@suse.de
- spi: atmel-quadspi: Fix AHB memory accesses (git-fixes).
- spi: mt7621: Disable clock in probe error path (git-fixes).
- usb: chipidea: ci_hdrc_imx: Pass DISABLE_DEVICE_STREAMING flag
  to imx6ul (git-fixes).
- usb/max3421: fix return error code in max3421_probe()
  (git-fixes).
- commit 6c576b3
* Wed Dec 16 2020 tiwai@suse.de
- spi: davinci: Fix use-after-free on unbind (git-fixes).
- spi: fix resource leak for drivers without .remove callback
  (git-fixes).
- spi: mxs: fix reference leak in mxs_spi_probe (git-fixes).
- spi: st-ssc4: Fix unbalanced pm_runtime_disable() in probe
  error path (git-fixes).
- spi: pic32: Don't leak DMA channels in probe error path
  (git-fixes).
- spi: synquacer: Disable clock in probe error path (git-fixes).
- wimax: fix duplicate initializer warning (git-fixes).
- commit 51e204b
* Wed Dec 16 2020 tiwai@suse.de
- spi: sprd: fix reference leak in sprd_spi_remove (git-fixes).
- spi: atmel-quadspi: Disable clock in probe error path
  (git-fixes).
- spi: bcm63xx-hsspi: fix missing clk_disable_unprepare() on
  error in bcm63xx_hsspi_resume (git-fixes).
- spi: tegra114: fix reference leak in tegra spi ops (git-fixes).
- spi: tegra20-sflash: fix reference leak in tegra_sflash_resume
  (git-fixes).
- spi: tegra20-slink: fix reference leak in slink ops of tegra20
  (git-fixes).
- spi: mt7621: fix missing clk_disable_unprepare() on error in
  mt7621_spi_probe (git-fixes).
- spi: spi-ti-qspi: fix reference leak in ti_qspi_setup
  (git-fixes).
- spi: stm32: fix reference leak in stm32_spi_resume (git-fixes).
- spi: spi-mem: fix reference leak in spi_mem_access_start
  (git-fixes).
- commit 51236be
* Wed Dec 16 2020 tiwai@suse.de
- soc: qcom: geni: More properly switch to DMA mode (git-fixes).
- spi: spi-mem: Fix passing zero to 'PTR_ERR' warning (git-fixes).
- spi: img-spfi: fix reference leak in img_spfi_resume
  (git-fixes).
- regulator: mcp16502: add linear_min_sel (git-fixes).
- regulator: axp20x: Fix DLDO2 voltage control register mask
  for AXP22x (git-fixes).
- speakup: fix uninitialized flush_lock (git-fixes).
- slimbus: qcom-ngd-ctrl: Avoid sending power requests without
  QMI (git-fixes).
- serial: 8250_omap: Avoid FIFO corruption caused by MDR1 access
  (git-fixes).
- rsi: fix error return code in rsi_reset_card() (git-fixes).
- commit 8a400aa
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - add packed to init admin structures
  (jsc#SLE-14454).
- commit bffc702
* Wed Dec 16 2020 tiwai@suse.de
- PCI: iproc: Fix out-of-bound array accesses (git-fixes).
- platform/x86: mlx-platform: Fix item counter assignment for
  MSN2700, MSN24xx systems (git-fixes).
- platform/x86: dell-smbios-base: Fix error return code in
  dell_smbios_init (git-fixes).
- platform/x86: intel-vbtn: Allow switch events on Acer Switch
  Alpha 12 (git-fixes).
- platform/x86: mlx-platform: Remove PSU EEPROM from MSN274x
  platform configuration (git-fixes).
- platform/x86: mlx-platform: Remove PSU EEPROM from default
  platform configuration (git-fixes).
- Revert "platform/x86: wmi: Destroy on cleanup rather than
  unregister" (git-fixes).
- platform/chrome: cros_ec_spi: Don't overwrite spi::mode
  (git-fixes).
- regmap: Remove duplicate `type` field from regmap
  `regcache_sync` trace event (git-fixes).
- qtnfmac: fix error return code in qtnf_pcie_probe() (git-fixes).
- commit 4690027
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - abstract admin interface (jsc#SLE-14454).
- commit 10773c4
* Wed Dec 16 2020 tiwai@suse.de
- PCI: brcmstb: Initialize "tmp" before use (git-fixes).
- PCI: Fix pci_slot_release() NULL pointer dereference
  (git-fixes).
- memstick: r592: Fix error return in r592_probe() (git-fixes).
- mmc: pxamci: Fix error return code in pxamci_probe (git-fixes).
- memstick: fix a double-free bug in memstick_check (git-fixes).
- staging: olpc_dcon: Do not call platform_device_unregister()
  in dcon_probe() (git-fixes).
- nfc: s3fwrn5: Release the nfc firmware (git-fixes).
- orinoco: Move context allocation after processing the skb
  (git-fixes).
- mwifiex: fix mwifiex_shutdown_sw() causing sw reset failure
  (git-fixes).
- commit e021aed
* Wed Dec 16 2020 tiwai@suse.de
- Input: cyapa_gen6 - fix out-of-bounds stack access (git-fixes).
- Input: omap4-keypad - fix runtime PM error handling (git-fixes).
- Input: ads7846 - fix unaligned access on 7845 (git-fixes).
- Input: ads7846 - fix integer overflow on Rt calculation
  (git-fixes).
- Input: ads7846 - fix race that causes missing releases
  (git-fixes).
- iio: adc: rockchip_saradc: fix missing clk_disable_unprepare()
  on error in rockchip_saradc_resume (git-fixes).
- iio:adc:ti-ads124s08: Fix alignment and data leak issues
  (git-fixes).
- iio:adc:ti-ads124s08: Fix buffer being too long (git-fixes).
- iwlwifi: mvm: hook up missing RX handlers (git-fixes).
- mac80211: don't set set TDLS STA bandwidth wider than possible
  (git-fixes).
- commit 2fd9b35
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - relocate GEN2 CSR access code (jsc#SLE-14454).
- commit aa3be04
* Wed Dec 16 2020 tiwai@suse.de
- cpufreq: vexpress-spc: Add missing MODULE_ALIAS (git-fixes).
- Revert "i2c: i2c-qcom-geni: Fix DMA transfer race" (git-fixes).
- iio:pressure:mpl3115: Force alignment of buffer (git-fixes).
- iio:magnetometer:mag3110: Fix alignment and data leak issues
  (git-fixes).
- iio:light:st_uvis25: Fix timestamp alignment and prevent data
  leak (git-fixes).
- iio:light:rpr0521: Fix timestamp alignment and prevent data leak
  (git-fixes).
- iio: buffer: Fix demux update (git-fixes).
- extcon: max77693: Fix modalias string (git-fixes).
- cw1200: fix missing destroy_workqueue() on error in
  cw1200_init_common (git-fixes).
- commit 59cf4f4
* Wed Dec 16 2020 tiwai@suse.de
- cpufreq: scpi: Add missing MODULE_ALIAS (git-fixes).
- cpufreq: loongson1: Add missing MODULE_ALIAS (git-fixes).
- cpufreq: st: Add missing MODULE_DEVICE_TABLE (git-fixes).
- cpufreq: mediatek: Add missing MODULE_DEVICE_TABLE (git-fixes).
- cpufreq: highbank: Add missing MODULE_DEVICE_TABLE (git-fixes).
- cpufreq: ap806: Add missing MODULE_DEVICE_TABLE (git-fixes).
- staging: comedi: mf6x4: Fix AI end-of-conversion detection
  (git-fixes).
- bus: fsl-mc: fix error return code in fsl_mc_object_allocate()
  (git-fixes).
- commit 172d8d6
* Wed Dec 16 2020 ykaukab@suse.de
- drm/tegra: output: Don't leak OF node on error (jsc#SLE-15847).
- commit 17189d0
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - split transport CSR access logic (jsc#SLE-14454).
- commit a3a10f0
* Wed Dec 16 2020 ykaukab@suse.de
- phy: tegra: xusb: Fix usb_phy device driver field (jsc#SLE-15847).
- clk: tegra: bpmp: Clamp clock rates on requests (jsc#SLE-15847).
- cpufreq: tegra194: Rename tegra194_get_speed_common function (jsc#SLE-15847).
- cpufreq: tegra194: Remove unnecessary frequency calculation (jsc#SLE-15847).
- cpufreq: tegra186: Simplify cluster information lookup (jsc#SLE-15847).
- cpufreq: tegra186: Fix sparse 'incorrect type in assignment' warning (jsc#SLE-15847).
- cpufreq: tegra194: get consistent cpuinfo_cur_freq (jsc#SLE-15847).
- phy: tegra: Don't warn on probe deferral (jsc#SLE-15847).
- drm/tegra: output: Do not put OF node twice (jsc#SLE-15847).
- drm/tegra: sor: Don't warn on probe deferral (jsc#SLE-15847).
- cpufreq: tegra186: Fix get frequency callback (jsc#SLE-15847).
- memory: tegra: Remove GPU from DRM IOMMU group (jsc#SLE-15847).
- drm/tegra: Properly reference count the DDC I2C adapter
  (jsc#SLE-15847).
- iommu/tegra-smmu: Prune IOMMU group when it is released
  (jsc#SLE-15847).
- iommu/tegra-smmu: Balance IOMMU group reference count
  (jsc#SLE-15847).
- iommu/tegra-smmu: Set IOMMU group name (jsc#SLE-15847).
- cpufreq: tegra186: Fix initial frequency (jsc#SLE-15847).
- commit 9e4289a
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - fix configuration of iov threads (jsc#SLE-14454).
- commit 4028436
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - num_rings_per_bank is device dependent
  (jsc#SLE-14454).
- crypto: qat - mask device capabilities with soft straps
  (jsc#SLE-14454).
- commit a55dc52
* Wed Dec 16 2020 tiwai@suse.de
- Bluetooth: btmtksdio: Add the missed release_firmware() in
  mtk_setup_firmware() (git-fixes).
- Bluetooth: btusb: Add the missed release_firmware() in
  btusb_mtk_setup_firmware() (git-fixes).
- Bluetooth: hci_h5: fix memory leak in h5_close (git-fixes).
- Bluetooth: Fix slab-out-of-bounds read in
  hci_le_direct_adv_report_evt() (git-fixes).
- Bluetooth: Fix null pointer dereference in hci_event_packet()
  (git-fixes).
- ath10k: Release some resources in an error handling path
  (git-fixes).
- ath10k: Fix an error handling path (git-fixes).
- ath6kl: fix enum-conversion warning (git-fixes).
- commit 35aef63
* Wed Dec 16 2020 tiwai@suse.de
- ath10k: Fix the parsing error in service available event
  (git-fixes).
- commit ae02c89
* Wed Dec 16 2020 tiwai@suse.de
- Revert "ACPI / resources: Use AE_CTRL_TERMINATE to terminate
  resources walks" (git-fixes).
- commit 2779aa4
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: qcom: common: Fix refcounting in qcom_snd_parse_of()
  (git-fixes).
- commit 4c7929f
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: max98390: Fix error codes in max98390_dsm_init()
  (git-fixes).
- commit 9ec9be4
* Wed Dec 16 2020 tiwai@suse.de
- soundwire: intel: fix another unused-function warning
  (jsc#SLE-16518).
- soundwire: master: use pm_runtime_set_active() on add
  (jsc#SLE-16518).
- soundwire: qcom: Fix build failure when slimbus is module
  (jsc#SLE-16518).
- commit 5c4cbf1
* Wed Dec 16 2020 tiwai@suse.de
- Move upstreamed soundwire patches into sorted section
- commit 9be4676
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- IB/srpt: Fix memory leak in srpt_add_one (bsc#1152489)
- commit da75bee
* Wed Dec 16 2020 tiwai@suse.de
- soundwire: Fix DEBUG_LOCKS_WARN_ON for uninitialized attribute
  (jsc#SLE-16518).
- commit d23ae0b
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/hns: Bugfix for memory window mtpt configuration (bsc#1152489)
- commit 4f3475b
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- IB/mthca: fix return value of error branch in mthca_init_cq() (bsc#1152489)
- commit c98a089
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/pvrdma: Fix missing kfree() in pvrdma_register_device() (bsc#1152489)
- commit baad43e
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: Intel: hda: fix the condition passed to
  sof_dev_dbg_or_err (jsc#SLE-16518).
- ASoC: SOF: modify the SOF_DBG flags (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: remove duplicated status dump
  (jsc#SLE-16518).
- ASoC: SOF: imx: update kernel-doc description (jsc#SLE-16518).
- ASoC: topology: Fix wrong size check (jsc#SLE-16518).
- ASoC: topology: Add missing size check (jsc#SLE-16518).
- ASoC: SOF: Intel: add SoundWire support for ADL-S
  (jsc#SLE-16518).
- ASoC: Intel: common: add ACPI matching tables for Alder Lake
  (jsc#SLE-16518).
- ASoC: Intel: cht_bsw_nau8824: Change SSP2-Codec DAI id to 0
  (jsc#SLE-16518).
- ASoC: Intel: cht_bsw_nau8824: Drop compress-cpu-dai bits
  (jsc#SLE-16518).
- ASoC: intel: sof_rt5682: Add support for tgl_rt1011_rt5682
  (jsc#SLE-16518).
- commit df54797
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix memory leak in iWARP CM (bsc#1152489)
- commit db44ceb
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix skb lifetime in rxe_rcv_mcast_pkt() (bsc#1152489)
- commit 1de4514
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- IB/rdmavt: Fix sizeof mismatch (bsc#1152489)
- commit 677c5ba
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: trace: Add runtime trace filtering mechanism
  (jsc#SLE-16518).
- ASoC: SOF: control: fix cppcheck warning in
  snd_sof_volume_info() (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: add sof_icl_ops for ICL platforms
  (jsc#SLE-16518).
- ASoC: SOF: ops: modify the signature of stall op
  (jsc#SLE-16518).
- ASoC: SOF: ext_manifest: parse cavs extra config data elem
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: define parse_platform_ext_manifest op
  (jsc#SLE-16518).
- ASoC: SOF: ops: add parse_platform_ext_manifest() op
  (jsc#SLE-16518).
- ASoC: SOF: Add `memory_info` file to debugfs (jsc#SLE-16518).
- ASoC: SOF: Change section comment for SOF_IPC_TEST_
  (jsc#SLE-16518).
- ASoC: SOF: Improve code alignment in header.h (jsc#SLE-16518).
- ASoC: SOF: ext_manifest: Parse firmware config dictionary
  (jsc#SLE-16518).
- ASoC: SOF: nocodec: modify DAI link definitions (jsc#SLE-16518).
- ASoC: SOF: IPC: fix implicit type overflow (jsc#SLE-16518).
- commit 478e999
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: Intel: allow for coexistence between SOF and catpt
  drivers (jsc#SLE-16518).
- Update config files.
- commit f7947cd
* Wed Dec 16 2020 tiwai@suse.de
- ALSA: hda: intel-dsp-config: ignore dsp_driver parameter for
  PCI legacy devices (jsc#SLE-16518).
- commit 63ddb05
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: Intel: broadwell: set card and driver name dynamically
  (jsc#SLE-16518).
- ALSA: hda: intel-dsp-config: add Broadwell ACPI DSP driver
  selection (jsc#SLE-16518).
- commit dbb4f88
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: Intel: allow for coexistence between SOF and Atom/SST
  drivers (jsc#SLE-16518).
- Update config files.
- commit 5c50712
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - update IV in software (jsc#SLE-14454).
- Refresh patches.suse/QAT-add-suse_kabi_padding.patch.
- commit 02c439a
* Wed Dec 16 2020 oneukum@suse.com
- crypto: qat - remove unused function (jsc#SLE-14454).
- commit edc1305
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: Intel: Atom: add dynamic selection of DSP driver
  (jsc#SLE-16518).
- commit 7c727eb
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: acpi: add dynamic selection of DSP driver
  (jsc#SLE-16518).
- commit 14933b4
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: Intel: byt/cht: set pm ops dynamically (jsc#SLE-16518).
- commit 5bab293
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: Intel: boards: byt/cht: set card and driver name at run
  time (jsc#SLE-16518).
- commit 8837dc6
* Wed Dec 16 2020 tiwai@suse.de
- ALSA: hda: intel-dsp-config: add helper for ACPI DSP driver
  selection (jsc#SLE-16518).
- commit 18cdfb4
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: Intel: bdw-rt5677: add missing pm_ops (jsc#SLE-16518).
- commit 25029ef
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: Intel: Boards: tgl_max98373: add dpcm_capture flag for
  speaker_smart_amp (jsc#SLE-16518).
- commit d6b111c
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: topology: Simplify remove_widget function (jsc#SLE-16518).
- commit b057eed
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: topology: Remove empty functions (jsc#SLE-16518).
- commit 3f721cb
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: topology: Change allocations to resource managed
  (jsc#SLE-16518).
- commit ea837e4
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: topology: Unify all device references (jsc#SLE-16518).
- commit 10328ad
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: topology: Remove multistep topology loading
  (jsc#SLE-16518).
- commit 364e86e
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: topology: Remove unused functions from topology API
  (jsc#SLE-16518).
- commit 0dc5676
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: soc-acpi: add helper to identify parent driver
  (jsc#SLE-16518).
- commit d308530
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: Intel: broadwell: add missing pm_ops (jsc#SLE-16518).
- commit bab05a6
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: control: override volume info callback
  (jsc#SLE-16518).
- commit 67c8df2
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: Intel: add hw specific PCM constraints
  (jsc#SLE-16518).
- commit 02c0e0b
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: relax PCM period and buffer size constraints
  (jsc#SLE-16518).
- commit ce00821
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: Fix 7/8 spaces indentation in Kconfig (jsc#SLE-16518).
- commit 53e4ae3
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: intel: SND_SOC_INTEL_KEEMBAY should depend on ARCH_KEEMBAY
  (jsc#SLE-16518).
- commit a961770
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: Intel: keembay: use inclusive language for bclk and fsync
  (jsc#SLE-16518).
- commit 726a785
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: Intel: atom: use inclusive language for SSP bclk/fsync
  (jsc#SLE-16518).
- commit 3078a9f
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: use inclusive language for bclk and fsync
  (jsc#SLE-16518).
- commit d738d67
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: topology: use inclusive language for bclk and fsync
  (jsc#SLE-16518).
- commit 3e92b8e
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: Intel: fix Kconfig dependency for
  SND_INTEL_DSP_CONFIG (jsc#SLE-16518).
- commit 65bf32d
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: Intel: fix Kconfig punctuation and wording
  (jsc#SLE-16518).
- commit e2d566a
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: Kconfig: fix Kconfig punctuation and wording
  (jsc#SLE-16518).
- commit 32e6a72
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: imx: fix Kconfig punctuation (jsc#SLE-16518).
- commit f4194f0
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: Intel: sof_sdw: add quirk for new TigerLake-SDCA device
  (jsc#SLE-16518).
- commit 7aadcdd
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: loader: do not warn about unknown firmware headers
  (jsc#SLE-16518).
- commit 1bf0f28
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: intel: sof_rt5682: Add quirk for Dooly (jsc#SLE-16518).
- commit 8100bff
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: intel: sof_rt5682: Add support for cml_rt1015_rt5682
  (jsc#SLE-16518).
- commit bb5fa3d
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: sof-audio: remove goto used for force-nocodec support
  (jsc#SLE-16518).
- commit 81aeb29
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: topology: remove const in sizeof() (jsc#SLE-16518).
- commit 66b10d3
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: control: remove const in sizeof() (jsc#SLE-16518).
- commit 2b84b77
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: Intel: hda: use semicolons rather than commas to
  separate statements (jsc#SLE-16518).
- commit 3f2432e
* Wed Dec 16 2020 jslaby@suse.cz
- inet_ecn: Fix endianness of checksum update when setting ECT(1)
  (git-fixes).
- commit 492cf46
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: Intel: bytcr_rt5651: use semicolons rather than commas
  to separate statements (jsc#SLE-16518).
- commit 6d8047e
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: SOF: Intel: initial support for Alderlake-S
  (jsc#SLE-13489).
- Update config files.
- commit fac4baf
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: amd: support other audio modes for raven (git-fixes).
- ASoC: AMD Renoir - add DMI table to avoid the ACP mic probe
  (broken BIOS) (git-fixes).
- ASoC: AMD Raven/Renoir - fix the PCI probe (PCI revision)
  (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for ARCHOS Cesium 140
  (git-fixes).
- ASoC: Intel: Boards: tgl_max98373: update TDM slot_width
  (git-fixes).
- ASoC: amd: Return -ENODEV for non-existing ACPI call
  (git-fixes).
- ASoC: amd: Downgrade print level for invalid ACP mode
  (git-fixes).
- commit 7df7491
* Wed Dec 16 2020 tiwai@suse.de
- ALSA: hda/ca0132 - Add ZxR surround DAC setup (git-fixes).
- ALSA: hda/ca0132 - Add 8051 PLL write helper functions
  (git-fixes).
- ALSA: hda/ca0132 - Remove now unnecessary DSP setup functions
  (git-fixes).
- ALSA: hda/ca0132 - Ensure DSP is properly setup post-firmware
  download (git-fixes).
- ALSA: hda/ca0132 - Add 8051 exram helper functions (git-fixes).
- ALSA: hda/ca0132 - Add stream port remapping function
  (git-fixes).
- ALSA: hda/ca0132 - Reset codec upon initialization (git-fixes).
- ALSA: hda/hdmi: fix silent stream for first playback to DP
  (git-fixes).
- ALSA: seq: Use bool for snd_seq_queue internal flags
  (git-fixes).
- ALSA: hda/ca0132: Move unsol callback setups to parser
  (git-fixes).
- ALSA: compress: allow pause and resume during draining
  (git-fixes).
- ALSA: hdspm: Fix fall-through warnings for Clang (git-fixes).
- ALSA: remove unneeded break (git-fixes).
- commit 24cbc87
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: amd: change clk_get() to devm_clk_get() and add missed
  checks (git-fixes).
- ASoC: cx2072x: Fix doubly definitions of Playback and Capture
  streams (git-fixes).
- ASoC: meson: fix COMPILE_TEST error (git-fixes).
- ASoC: arizona: Fix a wrong free in wm8997_probe (git-fixes).
- ASoC: wm8998: Fix PM disable depth imbalance on error
  (git-fixes).
- ASoC: pcm: DRAIN support reactivation (git-fixes).
- ASoC: ti: davinci-mcasp: remove always zero of
  davinci_mcasp_get_dt_params (git-fixes).
- ASoC: sun4i-i2s: Fix lrck_period computation for I2S justified
  mode (git-fixes).
- ASoC: tegra20-spdif: remove "default m" (git-fixes).
- ASoC: wm_adsp: remove "ctl" from list on error in
  wm_adsp_create_control() (git-fixes).
- ASoC: jz4740-i2s: add missed checks for clk_get() (git-fixes).
- ASoC: SOF: control: fix size checks for ext_bytes control .get()
  (git-fixes).
- commit 8f99a8a
* Wed Dec 16 2020 tiwai@suse.de
- ALSA: hda/ca0132 - Change Input Source enum strings (git-fixes).
- ALSA: hda/ca0132 - Fix AE-5 rear headphone pincfg (git-fixes).
- commit 4d4db90
* Wed Dec 16 2020 tiwai@suse.de
- ALSA: hda: Fix regressions on clear and reconfig sysfs
  (git-fixes).
- commit f6ae090
* Wed Dec 16 2020 tiwai@suse.de
- ALSA: pcm: oss: Fix potential out-of-bounds shift (git-fixes).
- ALSA: rawmidi: Access runtime->avail always in spinlock
  (git-fixes).
- ALSA: seq: remove useless function (git-fixes).
- commit 87f324b
* Wed Dec 16 2020 tiwai@suse.de
- ALSA: hda/realtek - Add supported for more Lenovo ALC285
  Headset Button (git-fixes).
- ALSA: hda/realtek - Enable headset mic of ASUS Q524UQK with
  ALC255 (git-fixes).
- ALSA: hda/realtek - Enable headset mic of ASUS X430UN with
  ALC256 (git-fixes).
- ALSA: hda/realtek: make bass spk volume adjustable on a yoga
  laptop (git-fixes).
- ALSA: hda/hdmi: packet buffer index must be set before reading
  value (git-fixes).
- ALSA: hda/hdmi: always print pin NIDs as hexadecimal
  (git-fixes).
- ALSA: hda/proc - print DP-MST connections (git-fixes).
- commit b46aa44
* Wed Dec 16 2020 tiwai@suse.de
- ALSA: usb-audio: Fix potential out-of-bounds shift (git-fixes).
- ALSA: usb-audio: Fix control 'access overflow' errors from chmap
  (git-fixes).
- ALSA: usb-audio: Add implicit fb support for Steinberg UR22
  (git-fixes).
- ALSA: usb-audio: Add quirk for Pioneer DJ DDJ-SR2 (git-fixes).
- ALSA: usb-audio: Add support for Pioneer DJ DDJ-RR controller
  (git-fixes).
- commit cbe79ef
* Wed Dec 16 2020 tiwai@suse.de
- Move upstreamed USB-audio patches into sorted section
- commit 6078fcf
* Wed Dec 16 2020 lduncan@suse.com
- scsi: fnic: Validate io_req before others (bsc#1175079).
- scsi: fnic: Set scsi_set_resid() only for underflow
  (bsc#1175079).
- scsi: fnic: Change shost_printk() to FNIC_MAIN_DBG()
  (bsc#1175079).
- scsi: fnic: Avoid looping in TRANS ETH on unload (bsc#1175079).
- scsi: fnic: Change shost_printk() to FNIC_FCS_DBG()
  (bsc#1175079).
- commit 140fd58
* Tue Dec 15 2020 fweisbecker@suse.de
- sched/fair: Fix overutilized update in enqueue_task_fair() (git-fixes)
- commit aad16e5
* Tue Dec 15 2020 fweisbecker@suse.de
- sched: correct SD_flags returned by tl->sd_flags() (git-fixes)
- commit 323fa02
* Tue Dec 15 2020 fweisbecker@suse.de
- sched/fair: Refill bandwidth before scaling (git-fixes)
- commit 6f148d9
* Tue Dec 15 2020 fweisbecker@suse.de
- sched/fair: Fix race between runtime distribution and (git-fixes)
- commit 73cd7f5
* Tue Dec 15 2020 fweisbecker@suse.de
- sched/fair: Fix wrong cpu selecting from isolated domain (git-fixes)
- commit c4c367e
* Tue Dec 15 2020 oneukum@suse.com
- Update
  patches.suse/HID-Fix-slab-out-of-bounds-read-in-hid_field_extract.patch
  (bsc#1180052).
  Identified as security issue. bsc added.
- commit 02607b9
* Tue Dec 15 2020 oneukum@suse.com
- Update
  patches.suse/HID-Fix-slab-out-of-bounds-read-in-hid_field_extract.patch
  (bsc#1180052).
  Patch identified as security issue. bsc added.
- commit 88ee41b
* Tue Dec 15 2020 vbabka@suse.cz
- mm: memcg: fix memcg reclaim soft lockup (VM Functionality,
  bsc#1180056).
- commit 3a73547
* Tue Dec 15 2020 nsaenzjulienne@suse.de
- crypto: caam - fix printing on xts fallback allocation error
  path (git-fixes).
- commit fd68750
* Tue Dec 15 2020 oneukum@suse.com
- crypto: qat - fix status check in qat_hal_put_rel_rd_xfer()
  (git-fixes).
- commit e1943c2
* Tue Dec 15 2020 oneukum@suse.com
- crypto: qat - fix status check in qat_hal_put_rel_rd_xfer()
  (git-fixes).
- commit 9a7e1fb
* Tue Dec 15 2020 jslaby@suse.cz
- iommu/hyper-v: Remove I/O-APIC ID check from
  hyperv_irq_remapping_select() (jsc#SLE-16823).
- iommu/amd: Fix IOMMU interrupt generation in X2APIC mode
  (jsc#SLE-16823).
- iommu/amd: Fix union of bitfields in intcapxt support
  (jsc#SLE-16823).
- x86/ioapic: Correct the PCI/ISA trigger type selection
  (jsc#SLE-16823).
- commit 2f4c498
* Tue Dec 15 2020 jslaby@suse.cz
- x86/ioapic: Use I/O-APIC ID for finding irqdomain, not index
  (jsc#SLE-16823).
- x86/hyperv: Enable 15-bit APIC ID if the hypervisor supports it
  (jsc#SLE-16823).
- x86/kvm: Enable 15-bit extension when
  KVM_FEATURE_MSI_EXT_DEST_ID detected (jsc#SLE-16823).
- iommu/hyper-v: Disable IRQ pseudo-remapping if 15 bit APIC
  IDs are available (jsc#SLE-16823).
- x86/apic: Support 15 bits of APIC ID in MSI where available
  (jsc#SLE-16823).
- x86/ioapic: Handle Extended Destination ID field in RTE
  (jsc#SLE-16823).
- iommu/vt-d: Simplify intel_irq_remapping_select()
  (jsc#SLE-16823).
- x86: Kill all traces of irq_remapping_get_irq_domain()
  (jsc#SLE-16823).
- x86/ioapic: Use irq_find_matching_fwspec() to find remapping
  irqdomain (jsc#SLE-16823).
- x86/hpet: Use irq_find_matching_fwspec() to find remapping
  irqdomain (jsc#SLE-16823).
- iommu/hyper-v: Implement select() method on remapping irqdomain
  (jsc#SLE-16823).
- iommu/vt-d: Implement select() method on remapping irqdomain
  (jsc#SLE-16823).
- iommu/amd: Implement select() method on remapping irqdomain
  (jsc#SLE-16823).
- x86/apic: Add select() method on vector irqdomain
  (jsc#SLE-16823).
- genirq/irqdomain: Implement get_name() method on irqchip fwnodes
  (jsc#SLE-16823).
- x86/ioapic: Generate RTE directly from parent irqchip's MSI
  message (jsc#SLE-16823).
- x86/ioapic: Cleanup IO/APIC route entry structs (jsc#SLE-16823).
- x86/io_apic: Cleanup trigger/polarity helpers (jsc#SLE-16823).
- x86/msi: Remove msidef.h (jsc#SLE-16823).
- x86/pci/xen: Use msi_msg shadow structs (jsc#SLE-16823).
- x86/kvm: Use msi_msg shadow structs (jsc#SLE-16823).
- PCI: vmd: Use msi_msg shadow structs (jsc#SLE-16823).
- iommu/amd: Use msi_msg shadow structs (jsc#SLE-16823).
- iommu/intel: Use msi_msg shadow structs (jsc#SLE-16823).
- x86/msi: Provide msi message shadow structs (jsc#SLE-16823).
- genirq/msi: Allow shadow declarations of msi_msg:: $member
  (jsc#SLE-16823).
- x86/hpet: Move MSI support into hpet.c (jsc#SLE-16823).
- x86/apic: Always provide irq_compose_msi_msg() method for
  vector domain (jsc#SLE-16823).
- x86/apic: Cleanup destination mode (jsc#SLE-16823).
- x86/apic: Get rid of apic:: Dest_logical (jsc#SLE-16823).
- x86/apic: Replace pointless apic:: Dest_logical usage
  (jsc#SLE-16823).
- x86/apic: Cleanup delivery mode defines (jsc#SLE-16823).
- x86/devicetree: Fix the ioapic interrupt type table
  (jsc#SLE-16823).
- x86/apic/uv: Fix inconsistent destination mode (jsc#SLE-16823).
- x86/msi: Only use high bits of MSI address for DMAR unit
  (jsc#SLE-16823).
- x86/apic: Fix x2apic enablement without interrupt remapping
  (jsc#SLE-16823).
- commit e68f7b8
* Tue Dec 15 2020 tiwai@suse.de
- Update patch reference for audit security fix (CVE-2020-0444 bsc#1180027)
- commit 8236de7
* Tue Dec 15 2020 tiwai@suse.de
- Update patch reference for HID security fix (CVE-2020-0465 bsc#1180029)
- commit c0d38cb
* Mon Dec 14 2020 neilb@suse.de
- Update
  patches.suse/SUNRPC-Fix-SUNRPC-Add-len-parameter-to-gss_unwrap.patch
  (git-fixes).
- commit c1a6212
* Mon Dec 14 2020 mpdesouza@suse.com
- btrfs: qgroup: don't try to wait flushing if we're already holding a transaction (bsc#1179575).
- commit 7eae617
* Mon Dec 14 2020 rgoldwyn@suse.com
- supported.conf: Mark exfat as fully supported (bsc#1179882)
  Moves exfat from kernel-default-extra to kernel-default
- commit 619a3f5
* Mon Dec 14 2020 ptesarik@suse.cz
- s390/pci: Mark all VFs as not implementing PCI_COMMAND_MEMORY
  (bsc#1179611 LTC#190155).
- commit 8805bd5
* Mon Dec 14 2020 ptesarik@suse.cz
- s390/pci: adaptation of iommu to multifunction (bsc#1179611
  LTC#190155).
- Refresh patches.suse/s390-pci-create-zpci-bus.
- Refresh patches.suse/s390-pci-handling-multifunctions.
- commit 18ace9e
* Mon Dec 14 2020 ptesarik@suse.cz
- s390/purgatory: do not build purgatory with kcov, kasan and
  friends (bsc#1179603 LTC#190152).
- commit 2fdc981
* Mon Dec 14 2020 ptesarik@suse.cz
- s390/qeth: Remove pnso workaround (bsc#1179565 LTC#190112).
- commit 3eaa0fe
* Mon Dec 14 2020 ptesarik@suse.cz
- net/smc: fix direct access to ib_gid_addr->ndev in
  smc_ib_determine_gid() (bsc#1179205 LTC#189977).
- net/smc: fix matching of existing link groups (bsc#1179205
  LTC#189977).
- commit 0e174e5
* Mon Dec 14 2020 pjakobsson@suse.de
- Update config files.
- Delete
  patches.suse/1842-xen-add-helpers-to-allocate-unpopulated-memory.patch.
  As discussed with Juergen Gross per email, the patch might break xen
  guests and is not strictly required for the DRM backport.
  v2. As mentioned by Jessica, remove CONFIG_XEN_UNPOPULATED_ALLOC as it
  also goes away.
- commit 2d34f4b
* Mon Dec 14 2020 jdelvare@suse.de
- hwmon: (amd_energy) modify the visibility of the counters
  (jsc#SLE-14262 bsc#1178760).
- hwmon: (amd_energy) Improve the accumulation logic
  (jsc#SLE-14262).
- hwmon: (amd_energy) optimize accumulation interval
  (jsc#SLE-14262).
- hwmon: (amd_energy) Move label out of accumulation structure
  (jsc#SLE-14262).
- commit 4692751
* Mon Dec 14 2020 yousaf.kaukab@suse.com
- PCI: tegra: Disable LTSSM during L2 entry (bsc#1179344).
- PCI: tegra: Check return value of tegra_pcie_init_controller()
  (bsc#1179344).
- PCI: tegra: Continue unconfig sequence even if parts fail
  (bsc#1179344).
- PCI: tegra: Set DesignWare IP version (bsc#1179344).
- PCI: tegra: Fix ASPM-L1SS advertisement disable code
  (bsc#1179344).
- commit 9846dd7
* Mon Dec 14 2020 yousaf.kaukab@suse.com
- Delete patches.suse/PCI-dwc-Move-dw_pcie_setup_rc-to-DWC-common-code.patch.
  References: bsc#1179344
- commit bdaf386
* Mon Dec 14 2020 tiwai@suse.de
- blacklist.conf: correct the cherry-picked commit ID
- commit 48385ea
* Mon Dec 14 2020 tiwai@suse.de
- Update patch reference tags for missing CVE entries
- commit 24c7af3
* Mon Dec 14 2020 ptesarik@suse.cz
- s390/pci: fix CPU address in MSI for directed IRQ (git-fixes).
- s390/qeth: fix tear down of async TX buffers (git-fixes).
- s390/qeth: fix af_iucv notification race (git-fixes).
- s390/qeth: delay draining the TX buffers (git-fixes).
- s390: add 3f program exception handler (git-fixes).
- s390/cpuinfo: show processor physical address (git-fixes).
- commit 15840e9
* Mon Dec 14 2020 ptesarik@suse.cz
- s390/qeth: make af_iucv TX notification call more robust
  (bsc#1179604 LTC#190151).
- commit 1d3596d
* Mon Dec 14 2020 jlee@suse.com
- ACPI: EC: PM: Flush EC work unconditionally after wakeup
  (jsc#SLE-16407).
- ACPI: EC: PM: s2idle: Extend GPE dispatching debug message
  (jsc#SLE-16407).
- commit a21778d
* Mon Dec 14 2020 jlee@suse.com
- ACPI: EC: PM: Avoid flushing EC work when EC GPE is inactive
  (jsc#SLE-16407).
- ACPI: PM: s2idle: Fix comment in acpi_s2idle_prepare_late()
  (jsc#SLE-16407).
- commit eb134e5
* Mon Dec 14 2020 shung-hsi.yu@suse.com
- x86/apic/vector: Fix ordering in vector assignment (bsc#1156315).
- genirq/matrix: Deal with the sillyness of for_each_cpu() on UP (bsc#1156315).
- commit 108604c
* Mon Dec 14 2020 jlee@suse.com
- genirq/PM: Always unlock IRQ descriptor in rearm_wake_irq()
  (jsc#SLE-16407).
- ACPI: EC: PM: Avoid premature returns from acpi_s2idle_wake()
  (jsc#SLE-16407).
- platform/x86: intel_int0002_vgpio: Use
  acpi_register_wakeup_handler() (jsc#SLE-16407).
- ACPI: PM: Add acpi_register_wakeup_handler() (jsc#SLE-16407).
- ACPI: PM: s2idle: Refine active GPEs check (jsc#SLE-16407).
- ACPI: EC: Fix flushing of pending work (jsc#SLE-16407).
- platform/x86: intel_int0002_vgpio: Pass irqchip when adding
  gpiochip (jsc#SLE-16407).
- platform/x86: intel_int0002_vgpio: Use device_init_wakeup
  (jsc#SLE-16407).
- commit 7f8bb95
* Mon Dec 14 2020 neilb@suse.de
- SUNRPC: Revert 241b1f419f0e ("SUNRPC: Remove xdr_buf_trim()")
  (git-fixes).
- blacklist.conf:
  Doesn't cause a regression once the previous two patches are included.
- SUNRPC: Fix GSS privacy computation of auth->au_ralign
  (git-fixes).
- SUNRPC: Add "@len" parameter to gss_unwrap() (git-fixes).
- commit de10d89
* Mon Dec 14 2020 neilb@suse.de
- blacklist.conf: two git-fixes that break kabi too much
- commit 7df1e74
* Mon Dec 14 2020 neilb@suse.de
- blacklist.conf: Add a duplicate
- commit 5592171
* Mon Dec 14 2020 jlee@suse.com
- ACPICA: Preserve memory opregion mappings (jsc#SLE-16407).
- ACPICA: Replace one-element array with flexible-array
  (jsc#SLE-16407).
- ACPICA: iASL: add new OperationRegion subtype keyword
  PlatformRtMechanism (jsc#SLE-16407).
- ACPICA: Fix required parameters for _NIG and _NIH
  (jsc#SLE-16407).
- ACPICA: Disassembler: ignore AE_ALREADY_EXISTS status when
  parsing create operators (jsc#SLE-16407).
- ACPICA: Move acpi_gbl_next_cmd_num definition to acglobal.h
  (jsc#SLE-16407).
- ACPICA: Make acpi_protocol_lengths static (jsc#SLE-16407).
- platform/x86: sony-laptop: Make resuming thermal profile safer
  (jsc#SLE-16407).
- platform/x86: sony-laptop: SNC calls should handle BUFFER types
  (jsc#SLE-16407).
- ACPICA: utilities: fix sprintf() (jsc#SLE-16407).
- ACPICA: acpiexec: remove redeclaration of
  acpi_gbl_db_opt_no_region_support (jsc#SLE-16407).
- ACPICA: Change PlatformCommChannel ASL keyword to PCC
  (jsc#SLE-16407).
- ACPICA: Fix a couple of typos (jsc#SLE-16407).
- ACPICA: use acpi_size instead of u32 for prefix_path_length
  (jsc#SLE-16407).
- ACPICA: cast length arguement to acpi_ns_build_normalized_path()
  as u32 (jsc#SLE-16407).
- ACPICA: cast the result of the pointer difference to u32
  (jsc#SLE-16407).
- ACPICA: Table Manager: Update comments in a function header
  (jsc#SLE-16407).
- ACPICA: Enable sleep button on ACPI legacy wake (jsc#SLE-16407).
- ACPICA: Fix a comment "enable" fixed events -> "disable"
  all fixed events (jsc#SLE-16407).
- ACPICA: ASL-ASL+ converter: make root file a parameter for
  cv_init_file_tree (jsc#SLE-16407).
- ACPICA: ASL-ASL+ converter: remove function parameters from
  cv_init_file_tree() (jsc#SLE-16407).
- ACPICA: Allow acpi_any_gpe_status_set() to skip one GPE
  (jsc#SLE-16407).
- ACPI: PM: s2idle: Check fixed wakeup events in
  acpi_s2idle_wake() (jsc#SLE-16407).
- ACPI: PM: s2idle: Prevent spurious SCIs from waking up the
  system (jsc#SLE-16407).
- ACPICA: Introduce acpi_any_gpe_status_set() (jsc#SLE-16407).
- ACPI: PM: s2idle: Avoid possible race related to the EC GPE
  (jsc#SLE-16407).
- ACPI/sleep: Convert acpi_wakeup_address into a function
  (jsc#SLE-16407).
- ACPICA: All acpica: Update copyrights to 2020 Including tool
  signons (jsc#SLE-16407).
- ACPICA: Dispatcher: always generate buffer objects for ASL
  create_field() operator (jsc#SLE-16407).
- ACPICA: debugger: fix spelling mistake "adress" -> "address"
  (jsc#SLE-16407).
- ACPI: PM: s2idle: Rework ACPI events synchronization
  (jsc#SLE-16407).
- ACPI: EC: Rework flushing of pending work (jsc#SLE-16407).
- ACPICA: debugger: remove leading whitespaces when converting
  a string to a buffer (jsc#SLE-16407).
- ACPICA: acpiexec: initialize all simple types and field units
  from user input (jsc#SLE-16407).
- ACPICA: debugger: add field unit support for
  acpi_db_get_next_token (jsc#SLE-16407).
- ACPICA: debugger: surround field unit output with braces '{'
  (jsc#SLE-16407).
- ACPICA: debugger: add command to dump all fields of particular
  subtype (jsc#SLE-16407).
- ACPICA: utilities: add flag to only display data when dumping
  buffers (jsc#SLE-16407).
- ACPICA: More Clang changes (jsc#SLE-16407).
- ACPICA: Win OSL: Replace get_tick_count with get_tick_count64
  (jsc#SLE-16407).
- ACPICA: Results from Clang (jsc#SLE-16407).
- ACPI: PM: Drop Dell XPS13 9360 from LPS0 Idle _DSM blacklist
  (jsc#SLE-16407).
- ACPICA: Add "Windows 2019" string to _OSI support
  (jsc#SLE-16407).
- ACPICA: Differentiate Windows 8.1 from Windows 8
  (jsc#SLE-16407).
- ACPICA: Fully deploy ACPI_PRINTF_LIKE macro (jsc#SLE-16407).
- ACPICA: Fix issues with arg types within printf format strings
  (jsc#SLE-16407).
- ACPICA: Increase total number of possible Owner IDs
  (jsc#SLE-16407).
- ACPICA: Debugger: remove redundant assignment on obj_desc
  (jsc#SLE-16407).
- ACPI: PM: s2idle: Always set up EC GPE for system wakeup
  (jsc#SLE-16407).
- ACPI: PM: s2idle: Avoid rearming SCI for wakeup unnecessarily
  (jsc#SLE-16407).
- PM: suspend: Fix platform_suspend_prepare_noirq()
  (jsc#SLE-16407).
- intel-hid: intel-vbtn: Avoid leaking wakeup_mode set
  (jsc#SLE-16407).
- ACPI: PM: s2idle: Execute LPS0 _DSM functions with suspended
  devices (jsc#SLE-16407).
- ACPI: EC: PM: Make acpi_ec_dispatch_gpe() print debug message
  (jsc#SLE-16407).
- ACPI: EC: PM: Consolidate some code depending on PM_SLEEP
  (jsc#SLE-16407).
- ACPI: PM: s2idle: Eliminate acpi_sleep_no_ec_events()
  (jsc#SLE-16407).
- ACPI: PM: s2idle: Switch EC over to polling during "noirq"
  suspend (jsc#SLE-16407).
- ACPI: PM: s2idle: Add acpi.sleep_no_lps0 module parameter
  (jsc#SLE-16407).
- ACPI: PM: s2idle: Rearrange lps0_device_attach()
  (jsc#SLE-16407).
- ACPI: PM: Set up EC GPE for system wakeup from drivers that
  need it (jsc#SLE-16407).
- PM: sleep: Simplify suspend-to-idle control flow
  (jsc#SLE-16407).
- ACPI: PM: Set s2idle_wakeup earlier and clear it later
  (jsc#SLE-16407).
- ACPI: EC: Return bool from acpi_ec_dispatch_gpe()
  (jsc#SLE-16407).
- ACPICA: Return u32 from acpi_dispatch_gpe() (jsc#SLE-16407).
- PCI: irq: Introduce rearm_wake_irq() (jsc#SLE-16407).
- commit 632d617
* Mon Dec 14 2020 fweisbecker@suse.de
- timers: Always keep track of next expiry (bsc#1179365)
- commit ee6d011
* Sun Dec 13 2020 tiwai@suse.de
- pinctrl: intel: Actually disable Tx and Rx buffers on GPIO
  request (git-fixes).
- pinctrl: jasperlake: Fix HOSTSW_OWN offset (git-fixes).
- pinctrl: jasperlake: Unhide SPI group of pins (git-fixes).
- commit 256e3b8
* Sun Dec 13 2020 tiwai@suse.de
- ALSA: usb-audio: workaround for iface reset issue (bsc#1178203).
- commit 4121b01
* Sun Dec 13 2020 tiwai@suse.de
- mmc: block: Fixup condition for CMD13 polling for RPMB requests
  (git-fixes).
- pinctrl: aspeed: Fix GPIO requests on pass-through banks
  (git-fixes).
- pinctrl: baytrail: Avoid clearing debounce value when turning
  it off (git-fixes).
- pinctrl: merrifield: Set default bias in case no particular
  value given (git-fixes).
- gpio: mvebu: fix potential user-after-free on probe (git-fixes).
- clk: renesas: r9a06g032: Drop __packed for portability
  (git-fixes).
- USB: serial: ch341: sort device-id entries (git-fixes).
- USB: serial: ch341: add new Product ID for CH341A (git-fixes).
- USB: serial: option: add support for Thales Cinterion EXS82
  (git-fixes).
- USB: serial: option: add Fibocom NL668 variants (git-fixes).
- commit 4d00577
* Sat Dec 12 2020 fweisbecker@suse.de
- timers: Recalculate next timer interrupt only when necessary (bsc#1179365)
- commit 5f04bac
* Sat Dec 12 2020 fweisbecker@suse.de
- timers: Lower base clock forwarding threshold (bsc#1179365)
- commit 72a03ba
* Sat Dec 12 2020 fweisbecker@suse.de
- timers: Remove must_forward_clk (bsc#1179365)
- commit c3083a1
* Sat Dec 12 2020 fweisbecker@suse.de
- timers: Spare timer softirq until next expiry (bsc#1179365)
- commit 1eaa492
* Sat Dec 12 2020 fweisbecker@suse.de
- timers: Expand clk forward logic beyond nohz (bsc#1179365)
- commit c14e398
* Sat Dec 12 2020 fweisbecker@suse.de
- timers: Reuse next expiry cache after nohz exit (bsc#1179365)
- commit 8c6d890
* Sat Dec 12 2020 fweisbecker@suse.de
- timers: Optimize _next_timer_interrupt() level iteration (bsc#1179365)
- commit 74e8303
* Sat Dec 12 2020 fweisbecker@suse.de
- timers: Add comments about calc_index() ceiling work (bsc#1179365)
- commit 1709f40
* Sat Dec 12 2020 fweisbecker@suse.de
- timers: Move trigger_dyntick_cpu() to enqueue_timer() (bsc#1179365)
- commit 79e5013
* Sat Dec 12 2020 fweisbecker@suse.de
- timers: Use only bucket expiry for base->next_expiry value (bsc#1179365)
- commit dc787a8
* Sat Dec 12 2020 fweisbecker@suse.de
- timers: Preserve higher bits of expiration on index (bsc#1179365)
- commit 242bf50
* Sat Dec 12 2020 jbohac@suse.cz
- pstore: Fix linking when crypto API disabled (jsc#SLE-16304).
- commit cf4291d
* Sat Dec 12 2020 jbohac@suse.cz
- mtd: Support kmsg dumper based on pstore/blk (jsc#SLE-16304).
- Update config files.
- supported.conf: add mtdpstore
- commit ffec888
* Sat Dec 12 2020 jbohac@suse.cz
- pstore/blk: Introduce "best_effort" mode (jsc#SLE-16304).
- pstore/blk: Support non-block storage devices (jsc#SLE-16304).
- pstore/blk: Provide way to query pstore configuration
  (jsc#SLE-16304).
- pstore/zone: Provide way to skip "broken" zone for MTD devices
  (jsc#SLE-16304).
- commit 278b9b6
* Sat Dec 12 2020 jbohac@suse.cz
- Documentation: Add details for pstore/blk (jsc#SLE-16304).
- commit f35da88
* Sat Dec 12 2020 jbohac@suse.cz
- pstore/zone,blk: Add ftrace frontend support (jsc#SLE-16304).
- Update config files.
- commit e482e99
* Sat Dec 12 2020 jbohac@suse.cz
- pstore/zone,blk: Add console frontend support (jsc#SLE-16304).
- Update config files.
- commit 8e4487a
* Sat Dec 12 2020 jbohac@suse.cz
- pstore/zone,blk: Add support for pmsg frontend (jsc#SLE-16304).
- Update config files.
- commit 03d39a5
* Sat Dec 12 2020 jbohac@suse.cz
- pstore/blk: Introduce backend for block devices (jsc#SLE-16304).
- Update config files.
- mark fs/pstore as supported
- commit 587a2b4
* Sat Dec 12 2020 jbohac@suse.cz
- pstore/zone: Introduce common layer to manage storage zones
  (jsc#SLE-16304).
- commit ba9c226
* Sat Dec 12 2020 jbohac@suse.cz
- ramoops: Add "max-reason" optional field to ramoops DT node
  (jsc#SLE-16304).
- pstore/ram: Introduce max_reason and convert dump_oops
  (jsc#SLE-16304).
- pstore/platform: Pass max_reason to kmesg dump (jsc#SLE-16304).
- printk: Introduce kmsg_dump_reason_str() (jsc#SLE-16304).
- printk: honor the max_reason field in kmsg_dumper
  (jsc#SLE-16304).
- printk: Collapse shutdown types into a single dump reason
  (jsc#SLE-16304).
- commit e8792b6
* Fri Dec 11 2020 jbohac@suse.cz
- pstore/ftrace: Provide ftrace log merging routine
  (jsc#SLE-16304).
- pstore/ram: Refactor ftrace buffer merging (jsc#SLE-16304).
- pstore/ram: Refactor DT size parsing (jsc#SLE-16304).
- pstore/ram: Adjust module param permissions to reflect reality
  (jsc#SLE-16304).
- pstore/platform: Move module params after declarations
  (jsc#SLE-16304).
- pstore/platform: Use backend name for console registration
  (jsc#SLE-16304).
- pstore/platform: Switch pstore_info::name to const
  (jsc#SLE-16304).
- pstore: Make sure console capturing will restart
  (jsc#SLE-16304).
- pstore: Remove filesystem records when backend is unregistered
  (jsc#SLE-16304).
- pstore: Do not leave timer disabled for next backend
  (jsc#SLE-16304).
- commit 8204cca
* Fri Dec 11 2020 jbohac@suse.cz
- pstore: Add locking around superblock changes (jsc#SLE-16304).
- commit 21099a7
* Fri Dec 11 2020 jbohac@suse.cz
- pstore: Refactor pstorefs record list removal (jsc#SLE-16304).
- commit 989da98
* Fri Dec 11 2020 jbohac@suse.cz
- pstore: Add proper unregister lock checking (jsc#SLE-16304).
- commit eed4072
* Fri Dec 11 2020 jbohac@suse.cz
- pstore: Convert "records_list" locking to mutex (jsc#SLE-16304).
- commit 5292e89
* Fri Dec 11 2020 jbohac@suse.cz
- pstore: Rename "allpstore" to "records_list" (jsc#SLE-16304).
- commit 70a8404
* Fri Dec 11 2020 jbohac@suse.cz
- pstore: Convert "psinfo" locking to mutex (jsc#SLE-16304).
- commit df8a1eb
* Fri Dec 11 2020 jbohac@suse.cz
- pstore: Rename "pstore_lock" to "psinfo_lock" (jsc#SLE-16304).
- commit 5e29b75
* Fri Dec 11 2020 jbohac@suse.cz
- pstore: Drop useless try_module_get() for backend
  (jsc#SLE-16304).
- Refresh
  patches.suse/pstore_disable_efi_backend_by_default.patch.
- commit de00068
* Fri Dec 11 2020 jbohac@suse.cz
- pstore/ram: Replace zero-length array with flexible-array member
  (jsc#SLE-16304).
- commit 992f876
* Fri Dec 11 2020 jbohac@suse.cz
- pstore/ram: remove unnecessary ramoops_unregister_dummy()
  (jsc#SLE-16304).
- commit b76e837
* Fri Dec 11 2020 msuchanek@suse.de
- powerpc/perf: Exclude kernel samples while counting events in
  user space (jsc#SLE-13513 bsc#1179950 ltc#190285).
- powerpc/perf: MMCR0 control for PMU registers under PMCC=00
  (jsc#SLE-13513 bsc#1179950 ltc#190285).
- powerpc/perf: Fix to update cache events with l2l3 events in
  power10 (jsc#SLE-13513 bsc#1179950 ltc#190285).
- powerpc/perf: Fix to update generic event codes for power10
  (jsc#SLE-13513 bsc#1179950 ltc#190285).
- powerpc/perf: Add generic and cache event list for power10 DD1
  (jsc#SLE-13513 bsc#1179950 ltc#190285).
- powerpc/perf: Fix the PMU group constraints for threshold
  events in power10 (jsc#SLE-13513 bsc#1179950 ltc#190285).
- powerpc/perf: Update the PMU group constraints for l2l3 events
  in power10 (jsc#SLE-13513 bsc#1179950 ltc#190285).
- powerpc/perf: Fix to update radix_scope_qual in power10
  (jsc#SLE-13513 bsc#1179950 ltc#190285).
- powerpc/perf: Invoke per-CPU variable access with disabled
  interrupts (jsc#SLE-13513 bsc#1179950 ltc#190285).
- commit da98715
* Fri Dec 11 2020 yousaf.kaukab@suse.com
- supported.conf: enable pwm-fan
  Jetson AGX Xavier uses pwm-fan to contol fan speed.
  References: bsc#1179597
- commit 134e477
* Fri Dec 11 2020 fdmanana@suse.com
- btrfs: fix readahead hang and use-after-free after removing
  a device (bsc#1179963).
- commit 170193e
* Fri Dec 11 2020 fdmanana@suse.com
- btrfs: fix use-after-free on readahead extent after failure
  to create it (bsc#1179963).
- commit 1429b0b
* Fri Dec 11 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream repository URL:
  patches.suse/ibmvnic-add-some-debugs.patch
- move unsortable patches out of sorted section:
  patches.suse/cifs-set_root_ses-ipc.patch
  patches.suse/powerpc-rtas-fix-typo-of-ibm-open-errinjct-in-rtas-f.patch
- commit 059dfec
* Fri Dec 11 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into "almost mainline" section:
  patches.suse/nvme-fc-avoid-calling-_nvme_fc_abort_outstanding_ios-from-interrupt-context.patch
- commit e446234
* Fri Dec 11 2020 osalvador@suse.de
- mm/memory_hotplug: shrink zones when offlining memory
  (bsc#1177679).
- commit ffb1814
* Fri Dec 11 2020 mbrugger@suse.com
- ARM: 8943/1: Fix topology setup in case of CPU hotplug for
  CONFIG_SCHED_MC (jsc#SLE-16614 jsc#SLE-13640).
- commit 66cc853
* Fri Dec 11 2020 tiwai@suse.de
- Revert "geneve: pull IP header before ECN decapsulation"
  (git-fixes).
- can: softing: softing_netdev_open(): fix error handling
  (git-fixes).
- mac80211: mesh: fix mesh_pathtbl_init() error path (git-fixes).
- commit dff69af
* Fri Dec 11 2020 tzimmermann@suse.de
- drm: panel: Fix bpc for OrtusTech COM43H4M85ULC panel (bsc#1152489)
- commit 68423a3
* Fri Dec 11 2020 msuchanek@suse.de
- ibmvnic: fix rx buffer tracking and index management in
  replenish_rx_pool partial success (bsc#1179929 ltc#189960).
- commit 53d60d5
* Fri Dec 11 2020 tbogendoerfer@suse.de
- IB/hfi1: Ensure correct mm is used at all times (bsc#1179878
  CVE-2020-27835).
- commit f84fcc4
* Fri Dec 11 2020 jslaby@suse.cz
- Update patches.suse/tty-Fix-pgrp-locking-in-tiocspgrp.patch
  (git-fixes bsc#1179745 CVE-2020-29661).
- Update patches.suse/tty-Fix-session-locking.patch (bsc#1179745
  CVE-2020-29660).
  Add CVE numbers.
- commit 034f28b
* Thu Dec 10 2020 dbueso@suse.de
- fail_function: Remove a redundant mutex unlock (bsc#1149032).
- locking/percpu-rwsem: Use this_cpu_{inc,dec}() for read_count
  (bsc#1149032).
- commit 7d88c68
* Thu Dec 10 2020 dbueso@suse.de
- blacklist.conf: Blacklist some lockdep updates
- commit 2f42c43
* Thu Dec 10 2020 msuchanek@suse.de
- kABI: genirq: add back irq_create_mapping (bsc#1065729).
- commit 0788f47
* Thu Dec 10 2020 msuchanek@suse.de
- genirq/irqdomain: Add an irq_create_mapping_affinity() function
  (bsc#1065729).
- commit 1e1b021
* Thu Dec 10 2020 msuchanek@suse.de
- powerpc/64s: Trim offlined CPUs from mm_cpumasks (bsc#1055117
  ltc#159753 git-fixes bsc#1179888 ltc#190253).
- kernel/cpu: add arch override for clear_tasks_mm_cpumask()
  mm handling (bsc#1055117 ltc#159753 git-fixes bsc#1179888
  ltc#190253).
- powerpc/64s/pseries: Fix hash tlbiel_all_isa300 for guest
  kernels (bsc#1179888 ltc#190253).
- powerpc/64s: Fix hash ISA v3.0 TLBIEL instruction generation
  (bsc#1055117 ltc#159753 git-fixes bsc#1179888 ltc#190253).
- commit 8cba4ab
* Thu Dec 10 2020 msuchanek@suse.de
- powerpc/64s/powernv: Fix memory corruption when saving SLB
  entries on MCE (jsc#SLE-9246 git-fixes).
- commit a63cfa4
* Thu Dec 10 2020 msuchanek@suse.de
- powerpc/pseries: Pass MSI affinity to irq_create_mapping()
  (bsc#1065729).
- ibmvnic: delay next reset if hard reset fails (bsc#1094840
  ltc#167098 git-fixes).
- ibmvnic: restore adapter state on failed reset (bsc#1152457
  ltc#174432 git-fixes).
- ibmvnic: avoid memset null scrq msgs (bsc#1044767 ltc#155231
  git-fixes).
- ibmvnic: enhance resetting status check during module exit
  (bsc#1065729).
- ibmvnic: fix NULL pointer dereference in reset_sub_crq_queues
  (FATE#322021 bsc#1040855 ltc#155067 git-fixes).
- ibmvnic: notify peers when failover and migration happen
  (bsc#1044120 ltc#155423 git-fixes).
- ibmvnic: fix call_netdevice_notifiers in do_reset (bsc#1115431
  ltc#171853 git-fixes).
- commit 00d731f
* Thu Dec 10 2020 mbrugger@suse.com
- clocksource/drivers/arm_arch_timer: validate arch_timer_rate
  (jsc#SLE-16614 jsc#SLE-13640).
- commit 4f4514c
* Thu Dec 10 2020 mbrugger@suse.com
- arm64: use activity monitors for frequency invariance
  (jsc#SLE-16614 jsc#SLE-13640).
- arm: Use common cpu_topology structure and functions
  (jsc#SLE-16614 jsc#SLE-13640).
- cpu-topology: Move cpu topology code to common code
  (jsc#SLE-16614 jsc#SLE-13640).
- commit 83df8e6
* Thu Dec 10 2020 msuchanek@suse.de
- powerpc/64s/exception: KVM Fix for host DSI being taken in
  HPT guest MMU context (jsc#SLE-9246 git-fixes).
- powerpc/64s: Fix KVM system reset handling when
  CONFIG_PPC_PSERIES=y (jsc#SLE-9246 git-fixes).
- commit 2b2f0ec
* Thu Dec 10 2020 msuchanek@suse.de
- powerpc/64s: Fix allnoconfig build since uaccess flush
  (bsc#1177666 git-fixes).
- commit 87d1aa2
* Thu Dec 10 2020 msuchanek@suse.de
- KVM: PPC: Book3S HV: XIVE: Fix possible oops when accessing
  ESB page (bsc#1156395).
- commit be0ace4
* Thu Dec 10 2020 msuchanek@suse.de
- ibmvnic: add some debugs (bsc#1179896 ltc#190255).
- commit 0ec6de5
* Thu Dec 10 2020 msuchanek@suse.de
- powerpc/rtas: fix typo of ibm,open-errinjct in rtas filter
  (CVE-2020-27777 bsc#1179107 bsc#1179887 ltc#190092).
- commit 8fcc087
* Thu Dec 10 2020 dwagner@suse.de
- nvme-fc: avoid calling _nvme_fc_abort_outstanding_ios from
  interrupt context (bsc#1177326).
- commit c6fa2f3
* Thu Dec 10 2020 mbenes@suse.cz
- ftrace: Fix updating FTRACE_FL_TRAMP (git-fixes).
- commit e552615
* Thu Dec 10 2020 mbenes@suse.cz
- blacklist.conf: 310e3a4b5a4f ("tracing: Remove WARN_ON in start_thread()")
  Not really necessary. Just a WARN_ON(). We may reevaluate if someone
  reports it.
- commit b62e034
* Thu Dec 10 2020 mbrugger@suse.com
- cpufreq: add function to get the hardware max frequency
  (jsc#SLE-16614 jsc#SLE-13640).
- commit 4ef407e
* Thu Dec 10 2020 mbrugger@suse.com
- Documentation: arm64: document support for the AMU extension
  (jsc#SLE-16614 jsc#SLE-13640).
- commit 814a63c
* Thu Dec 10 2020 mbrugger@suse.com
- arm64/kvm: disable access to AMU registers from kvm guests
  (jsc#SLE-16614 jsc#SLE-13640).
- commit 23654f6
* Thu Dec 10 2020 mbrugger@suse.com
- arm64: trap to EL1 accesses to AMU counters from EL0
  (jsc#SLE-16614 jsc#SLE-13640).
- commit 1ffcffa
* Thu Dec 10 2020 mbrugger@suse.com
- arm64: add support for the AMU extension v1 (jsc#SLE-16614
  jsc#SLE-13640).
- Update config files.
- Refresh patches.suse/arm64-Detect-the-ARMv8.4-TTL-feature.patch.
- Refresh
  patches.suse/arm64-tlb-Detect-the-ARMv8.4-TLBI-RANGE-feature.patch.
- Refresh
  patches.suse/kabi-arm64-reserve-space-in-cpu_hwcaps-and-cpu_hwcap.patch.
- commit db66333
* Thu Dec 10 2020 tiwai@suse.de
- Update config files: drop CONFIG_IP_PNP again
  CONFIG_IP_PNP was enabled as a result of Leap config merge, but it
  makes little sense without the built-in network drivers.  Drop it again.
- commit 43358fd
* Thu Dec 10 2020 mgorman@suse.de
- Update config files to disable CONFIG_DEBUG_SECTION_MISMATCH (bsc#1177403)
- commit 0b57f6d
* Thu Dec 10 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/0001-HMAT-Register-memory-side-cache-after-parsing.patch
  patches.suse/0001-HMAT-Skip-publishing-target-info-for-nodes-with-no-o.patch
  patches.suse/0001-mm-userfaultfd-do-not-access-vma-vm_mm-after-calling.patch
- commit 35937c0
* Wed Dec  9 2020 ematsumiya@suse.de
- iommu/amd: Set DTE[IntTabLen] to represent 512 IRTEs
  (bsc#1179652).
- commit fc46361
* Wed Dec  9 2020 hare@suse.de
- nvme-fabrics: allow to queue requests for live queues
  (git-fixes).
- nvme-tcp: cancel async events before freeing event struct
  (git-fixes).
- nvme-rdma: cancel async events before freeing event struct
  (git-fixes).
- nvme-fc: cancel async events before freeing event struct
  (git-fixes).
- commit bd7db2d
* Wed Dec  9 2020 hare@suse.de
- nvme: Revert: Fix controller creation races with teardown
  (git-fixes).
- Delete patches.kabi/nvme-kABI-fixes-for-nvme_ctrl.patch.
- commit 6f82fb0
* Wed Dec  9 2020 yousaf.kaukab@suse.com
- arm64: cpufreq: revert cppc to v5.10 level
  References: bsc#1179585
  cppc_cpufreq is being initialized without checking if
  acpi_cppc_processor_probe() succeeded. Revert to v5.10 to keep the old
  behavior for now.
- commit dc7e817
* Wed Dec  9 2020 hare@suse.de
- nvme-multipath: fix deadlock due to head->lock (git-fixes).
- nvme: don't protect ns mutation with ns->head->lock (git-fixes).
- nvme-multipath: fix deadlock between ana_work and scan_work
  (git-fixes).
- commit d1a90c1
* Wed Dec  9 2020 hare@suse.de
- nvme-fc: remove nvme_fc_terminate_io() (bsc#1177326).
- nvme-fc: eliminate terminate_io use by nvme_fc_error_recovery
  (bsc#1177326).
- nvme-fc: remove err_work work item (bsc#1177326).
- nvme-fc: track error_recovery while connecting (bsc#1177326).
- nvme-fc: shorten reconnect delay if possible for FC (git-fixes).
- nvme-fc: wait for queues to freeze before calling (git-fixes).
- nvme-fc: fix error loop in create_hw_io_queues (git-fixes).
- nvme-fc: fix io timeout to abort I/O (bsc#1177326).
- nvme-pci: properly print controller address (git-fixes).
- commit 42e24bd
* Wed Dec  9 2020 hare@suse.de
- nvme-tcp: optimize queue io_cpu assignment for multiple queue
  (git-fixes).
- Refresh
  patches.suse/nvme-tcp-have-queue-prod-cons-send-list-become-a-lli.patch.
- commit b1bde16
* Wed Dec  9 2020 hare@suse.de
- nvme-tcp: fix possible leakage during error flow (git-fixes).
- commit a68cfb4
* Wed Dec  9 2020 jeyu@suse.de
- random: try to actively add entropy rather than passively wait for it (bsc#1178404).
- commit f78131b
* Wed Dec  9 2020 vbabka@suse.cz
- Update config files: enable CONFIG_TEST_HMM on x86_64
- supported.conf: add lib/test_hmm as kselftests-kmp (jsc#SLE-16387)
- commit d44e369
* Wed Dec  9 2020 vbabka@suse.cz
- XArray: Add xa_for_each_range (jsc#SLE-16387).
- commit 89eed0c
* Wed Dec  9 2020 jack@suse.cz
- uapi: fix statx attribute value overlap for DAX & MOUNT_ROOT
  (bsc#1179819).
- commit 75cd8a8
* Wed Dec  9 2020 jack@suse.cz
- ext4: handle dax mount option collision (bsc#1179815).
- commit 2f4a2a2
* Wed Dec  9 2020 jack@suse.cz
- ext4: disallow modifying DAX inode flag if inline_data has
  been set (bsc#1179814).
- commit d0f441a
* Wed Dec  9 2020 tiwai@suse.de
- Input: xpad - support Ardwiino Controllers (git-fixes).
- Input: i8042 - add ByteSpeed touchpad to noloop table
  (git-fixes).
- usbnet: ipheth: fix connectivity with iOS 14 (git-fixes).
- commit 8f84738
* Tue Dec  8 2020 bp@suse.de
- x86/insn-eval: Use new for_each_insn_prefix() macro to loop
  over prefixes bytes (bsc#1152489).
- commit 73ffec0
* Tue Dec  8 2020 bp@suse.de
- x86/uprobes: Do not use prefixes.nbytes when looping over
  prefixes.bytes (bsc#1152489).
- commit 0b28903
* Tue Dec  8 2020 bp@suse.de
- x86/resctrl: Fix AMD L3 QOS CDP enable/disable (bsc#1152489).
- commit d839ba5
* Tue Dec  8 2020 vbabka@suse.cz
- lib/test_hmm.c: remove unused dmirror_zero_page (jsc#SLE-16387).
- commit 879f764
* Tue Dec  8 2020 vbabka@suse.cz
- mm: mmu_notifier: fix and extend kerneldoc (jsc#SLE-16387).
- commit a65787b
* Tue Dec  8 2020 vbabka@suse.cz
- mm/migrate: fix migrate_pgmap_owner w/o CONFIG_MMU_NOTIFIER
  (jsc#SLE-16387).
- blacklist.conf: remove this commit
- commit 3454164
* Tue Dec  8 2020 vbabka@suse.cz
- mm/hmm/test: use the new migration invalidation (jsc#SLE-16387).
- commit b9703ba
* Tue Dec  8 2020 vbabka@suse.cz
- Refresh
  patches.suse/0012-mm-migrate-add-a-flags-parameter-to-migrate_vma.patch.
- add mm/hmm/test part now that prerequisities are not missing anymore.
- commit 32a3dca
* Tue Dec  8 2020 vbabka@suse.cz
- mm/hmm: add tests for hmm_pfn_to_map_order() (jsc#SLE-16387).
- commit fea5fef
* Tue Dec  8 2020 jack@suse.cz
- io_uring: grab ->fs as part of async offload (bsc#1179434
  CVE-2020-29373).
- commit b260e71
* Tue Dec  8 2020 bp@suse.de
- x86/sev-es: Use new for_each_insn_prefix() macro to loop over
  prefixes bytes (bsc#1178134).
- x86/insn-eval: Use new for_each_insn_prefix() macro to loop
  over prefixes bytes (bsc#1178134).
- commit 25fe31b
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Avoid mixing integer types during batch copies'
- commit 7318e0c
* Tue Dec  8 2020 bp@suse.de
- x86/uprobes: Do not use prefixes.nbytes when looping over
  prefixes.bytes (bsc#1178134).
- commit 40a1a4a
* Tue Dec  8 2020 bp@suse.de
- x86/platform/uv: Fix UV4 hub revision adjustment (bsc#1178134).
- commit ddbaba1
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Clear the repeater bit on HDCP disable'
- commit c9b3793
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix sha_text population code'
- commit 3c40ed1
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gem: Delay tracking the GEM context until it is registered'
- commit 57a9af9
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: Fix hardmins not being sent to SMU for RV'
- commit 3708b97
* Tue Dec  8 2020 tiwai@suse.de
- iwlwifi: pcie: invert values of NO_160 device config entries
  (git-fixes).
- commit aa2884c
* Tue Dec  8 2020 oneukum@suse.com
- Update
  patches.suse/media-xirlink_cit-add-missing-descriptor-sanity-chec.patch
  (bsc#1168952 CVE-2020-11668).
  Added CVE number
- commit 15ca434
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Prevent kernel-infoleak in amdgpu_info_ioctl()'
- commit 13ab26a
* Tue Dec  8 2020 oneukum@suse.com
- Update
  patches.suse/media-xirlink_cit-add-missing-descriptor-sanity-chec.patch
  (bsc#1168952 CVE-2020-11668).
  Added CVE number
- commit a0ec304
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gem: Delay tracking the GEM context until it is registered'
- commit b9b8698
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/imx: tve remove extraneous type qualifier (bsc#1152489)
- commit ef93a79
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/vc4: hdmi: Avoid sleeping in atomic context (bsc#1152489)
  Backporting changes:
  * context fixes
- commit 507bd66
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/panfrost: increase readl_relaxed_poll_timeout values (bsc#1152472)
  Backporting changes:
  * context fixes
- commit c82949a
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/i915/gem: Avoid implicit vmap for highmem on x86-32 (bsc#1152489)
  Backporting changes:
  * context fixes
- commit 56c13b8
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/vc4: crtc: Rework a bit the CRTC state code (bsc#1152472)
  Backporting changes:
  * context fixes
- commit e8c9179
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/msm: Drop debug print in _dpu_crtc_setup_lm_bounds() (bsc#1152489)
  Backporting changes:
  * context fixes
- commit 620be39
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/msm: Avoid div-by-zero in dpu_crtc_atomic_check() (bsc#1152489)
- commit fa753cd
* Tue Dec  8 2020 tzimmermann@suse.de
- drm: mxsfb: check framebuffer pitch (bsc#1152472)
  Backporting changes:
  * context fixes
- commit 0dd9c60
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/panfrost: Ensure GPU quirks are always initialised (bsc#1152489)
- commit c088e37
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/crc-debugfs: Fix memleak in crc_control_write (bsc#1152472)
- commit 7cf7f8b
* Tue Dec  8 2020 tzimmermann@suse.de
- drm: rcar-du: Put reference to VSP device (bsc#1152489)
- commit 3aca956
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/radeon: Prefer lower feedback dividers (bsc#1152489)
- commit 7479884
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/amdgpu: pass NULL pointer instead of 0 (bsc#1152489)
  Backporting changes:
  * context fixes
- commit 7cc3993
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/amd/display: Fix wrong return value in dm_update_plane_state() (bsc#1152489)
- commit 7638845
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/gma500: fix error check (bsc#1152472)
  Backporting changes:
  * context fixes
- commit e0b3dc4
* Tue Dec  8 2020 tzimmermann@suse.de
- drm: panel: Fix bus format for OrtusTech COM43H4M85ULC panel (bsc#1152472)
  Backporting changes:
  * context fixes
- commit aaeda6a
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/vkms: fix xrgb on compute crc (bsc#1152472)
  Backporting changes:
  * changed filename from vkms_composer.c to vkms_crc.c
  * context fixes
- commit 84538b3
* Tue Dec  8 2020 tzimmermann@suse.de
- drm: mxsfb: Remove fbdev leftovers (bsc#1152472)
  Backporting changes:
  * context fixes
- commit 7b29584
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/sun4i: sun8i-csc: Secondary CSC register correction (bsc#1152489)
- commit c09dba1
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/vc4/vc4_hdmi: fill ASoC card owner (bsc#1152489)
- commit afa801d
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/mediatek: Add missing put_device() call in (bsc#1152472)
- commit 2465a49
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/mediatek: Add missing put_device() call in mtk_drm_kms_init() (bsc#1152472)
  Backporting changes:
  * context fixes
  * adapted to function layout
- commit 187e3d3
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/mediatek: Add exception handing in mtk_drm_probe() if component (bsc#1152472)
- commit 39014a3
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/i915: Fix sha_text population code (bsc#1152489)
  Backporting changes:
  * context fixes
  * adapted I/O functions to old driver
- commit d501c26
* Tue Dec  8 2020 tzimmermann@suse.de
- fbcon: Remove the superfluous break (bsc#1152472)
- commit e00dc98
* Tue Dec  8 2020 tzimmermann@suse.de
- video: fbdev: radeon: Fix memleak in radeonfb_pci_register (bsc#1152472)
- commit 9657792
* Tue Dec  8 2020 tzimmermann@suse.de
- video: fbdev: sis: fix null ptr dereference (bsc#1152472)
- commit d833a20
* Tue Dec  8 2020 denis.kirjanov@suse.com
- Refresh
  patches.suse/ibmvnic-Ensure-that-SCRQ-entry-reads-are-correctly-o.patch.
- Refresh
  patches.suse/ibmvnic-Fix-TX-completion-error-handling.patch.
- Refresh patches.suse/ibmvnic-avoid-memset-null-scrq-msgs.patch.
- Refresh
  patches.suse/ibmvnic-delay-next-reset-if-hard-reset-fails.patch.
- Refresh
  patches.suse/ibmvnic-enhance-resetting-status-check-during-module.patch.
- Refresh
  patches.suse/ibmvnic-fix-NULL-pointer-dereference-in-ibmvic_reset.patch.
- Refresh
  patches.suse/ibmvnic-fix-NULL-pointer-dereference-in-reset_sub_cr.patch.
- Refresh
  patches.suse/ibmvnic-fix-call_netdevice_notifiers-in-do_reset.patch.
- Refresh
  patches.suse/ibmvnic-handle-inconsistent-login-with-reset.patch.
- Refresh
  patches.suse/ibmvnic-no-reset-timeout-for-5-seconds-after-reset.patch.
- Refresh
  patches.suse/ibmvnic-notify-peers-when-failover-and-migration-hap.patch.
- Refresh
  patches.suse/ibmvnic-reduce-wait-for-completion-time.patch.
- Refresh
  patches.suse/ibmvnic-restore-adapter-state-on-failed-reset.patch.
- Refresh
  patches.suse/ibmvnic-send_login-should-check-for-crq-errors.patch.
- Refresh
  patches.suse/ibmvnic-skip-tx-timeout-reset-while-in-resetting.patch.
- Refresh
  patches.suse/ibmvnic-stop-free_all_rwi-on-failed-reset.patch.
- Refresh patches.suse/ibmvnic-track-pending-login.patch.
  Update patch metadata
- commit ec07814
* Tue Dec  8 2020 tiwai@suse.de
- speakup: Reject setting the speakup line discipline outside
  of speakup (CVE-2020-27830 bsc#1179656).
- commit ec50953
* Tue Dec  8 2020 jslaby@suse.cz
- tty: Fix ->session locking (bsc#1179745).
- commit a9a2af9
* Tue Dec  8 2020 jslaby@suse.cz
- Update patches.suse/tty-Fix-pgrp-locking-in-tiocspgrp.patch
  (git-fixes bsc#1179745).
- commit 556ded3
* Tue Dec  8 2020 glin@suse.com
- udp: Don't discard reuseport selection when group has connections (bsc#1177028).
- commit 7d84936
* Mon Dec  7 2020 vbabka@suse.cz
- Update
  patches.suse/mm-slub-add-missing-tid-bump-in-kmem_cache_alloc_bulk.patch
  (CVE-2020-29370, bsc#1179435, bsc#1167657, VM functionality).
- add reference to CVE and its bsc
- commit cc58091
* Mon Dec  7 2020 ematsumiya@suse.de
- patches.suse/iommu-amd-Increase-interrupt-remapping-table-limit-t.patch:
  (bsc#1179652).
- commit 34c2dd2
* Mon Dec  7 2020 jlee@suse.com
- efi/x86: Move 32-bit code into efi_32.c (jsc#SLE-16407).
- efi/libstub: Handle unterminated cmdline (jsc#SLE-16407).
- efi/libstub: Handle NULL cmdline (jsc#SLE-16407).
- efi/libstub: Stop parsing arguments at "--" (jsc#SLE-16407).
- efi/x86: Mark kernel rodata non-executable for mixed mode
  (jsc#SLE-16407).
- x86/efi: Remove unused EFI_UV1_MEMMAP code (jsc#SLE-16407).
- x86/platform/uv: Remove uv bios and efi code related to
  EFI_UV1_MEMMAP (jsc#SLE-16407).
- x86/efi: Remove references to no-longer-used
  efi_have_uv1_memmap() (jsc#SLE-16407).
- x86/platform/uv: Remove efi=old_map command line option
  (jsc#SLE-16407).
- efi: use sha256() instead of open coding (jsc#SLE-16407).
- crypto: lib/sha256 - add sha256() function (jsc#SLE-16407).
- crypto: lib/sha256 - return void (jsc#SLE-16407).
- commit f5714a4
* Mon Dec  7 2020 jack@suse.cz
- blacklist.conf: Blacklist fdeb17c70c9e
- commit 392d677
* Mon Dec  7 2020 jack@suse.cz
- ext4: fix bogus warning in ext4_update_dx_flag() (bsc#1179716).
- commit c86f418
* Mon Dec  7 2020 jack@suse.cz
- reiserfs: Fix oops during mount (bsc#1179715).
- commit 89f9917
* Mon Dec  7 2020 jack@suse.cz
- quota: clear padding in v2r1_mem2diskdqb() (bsc#1179714).
- commit 20af897
* Mon Dec  7 2020 jack@suse.cz
- reiserfs: Initialize inode keys properly (bsc#1179713).
- commit 2b68a22
* Mon Dec  7 2020 jack@suse.cz
- udf: Fix memory leak when mounting (bsc#1179712).
- commit 816f9a3
* Mon Dec  7 2020 jack@suse.cz
- fs: Don't invalidate page buffers in block_write_full_page()
  (bsc#1179711).
- commit 8f6f5ed
* Mon Dec  7 2020 jack@suse.cz
- mm/error_inject: Fix allow_error_inject function signatures
  (bsc#1179710).
- commit 2c7612f
* Mon Dec  7 2020 jack@suse.cz
- libfs: fix error cast of negative value in simple_attr_write()
  (bsc#1179709).
- commit 246e7d7
* Mon Dec  7 2020 jack@suse.cz
- jbd2: fix up sparse warnings in checkpoint code (bsc#1179707).
- commit 15002ce
* Mon Dec  7 2020 jack@suse.cz
- ubifs: journal: Make sure to not dirty twice for auth nodes
  (bsc#1179704).
- commit 0185a1d
* Mon Dec  7 2020 jack@suse.cz
- ubifs: dent: Fix some potential memory leaks while iterating
  entries (bsc#1179703).
- commit 32b7d27
* Mon Dec  7 2020 jack@suse.cz
- ubifs: xattr: Fix some potential memory leaks while iterating
  entries (bsc#1179690).
- commit 950038e
* Mon Dec  7 2020 jack@suse.cz
- ubifs: mount_ubifs: Release authentication resource in error
  handling path (bsc#1179689).
- commit 0b68da4
* Mon Dec  7 2020 jack@suse.cz
- ubifs: Don't parse authentication mount options in remount
  process (bsc#1179688).
- commit 391f198
* Mon Dec  7 2020 jack@suse.cz
- ubifs: Fix a memleak after dumping authentication mount options
  (bsc#1179687).
- commit 3c605f4
* Mon Dec  7 2020 jack@suse.cz
- iomap: Set all uptodate bits for an Uptodate page (bsc#1179685).
- commit 8e539c4
* Mon Dec  7 2020 jack@suse.cz
- iomap: Mark read blocks uptodate in write_begin (bsc#1179684).
- commit d032f23
* Mon Dec  7 2020 jack@suse.cz
- iomap: Clear page error before beginning a write (bsc#1179683).
- commit da58998
* Mon Dec  7 2020 jack@suse.cz
- blacklist.conf: Blacklist 50b7d8568008
- commit cc769c4
* Mon Dec  7 2020 jack@suse.cz
- fs/ufs: avoid potential u32 multiplication overflow
  (bsc#1179682).
- commit 8289be8
* Mon Dec  7 2020 jack@suse.cz
- fs/minix: remove expected error message in block_to_path()
  (bsc#1179681).
- commit 0ea255e
* Mon Dec  7 2020 jack@suse.cz
- fs/minix: fix block limit check for V1 filesystems
  (bsc#1179680).
- commit 06199cf
* Mon Dec  7 2020 jack@suse.cz
- fs/minix: set s_maxbytes correctly (bsc#1179679).
- commit 69dd22c
* Mon Dec  7 2020 jack@suse.cz
- fs/minix: reject too-large maximum file size (bsc#1179678).
- commit c5b4a77
* Mon Dec  7 2020 jack@suse.cz
- fs/minix: don't allow getting deleted inodes (bsc#1179677).
- commit cbd9376
* Mon Dec  7 2020 jack@suse.cz
- fs/minix: check return value of sb_getblk() (bsc#1179676).
- commit 86706a5
* Mon Dec  7 2020 jack@suse.cz
- ubifs: Fix wrong orphan node deletion in ubifs_jnl_update|rename
  (bsc#1179675).
- commit 7055a2f
* Mon Dec  7 2020 jack@suse.cz
- ext4: unlock xattr_sem properly in ext4_inline_data_truncate()
  (bsc#1179673).
- commit d17d948
* Mon Dec  7 2020 jack@suse.cz
- ext4: correctly report "not supported" for {usr,grp}jquota
  when !CONFIG_QUOTA (bsc#1179672).
- commit ace06ac
* Mon Dec  7 2020 jack@suse.cz
- ext4: limit entries returned when counting fsmap records
  (bsc#1179671).
- commit 869362f
* Mon Dec  7 2020 jack@suse.cz
- ext4: fix leaking sysfs kobject after failed mount
  (bsc#1179670).
- commit 2855c18
* Mon Dec  7 2020 bp@suse.de
- x86/mce: Do not overwrite no_way_out if mce_end() fails
  (bsc#1152489).
- commit 016650c
* Mon Dec  7 2020 mkubecek@suse.cz
- net/x25: prevent a couple of overflows (bsc#1178590).
- commit 9618139
* Mon Dec  7 2020 mkubecek@suse.cz
- Update patches.suse/xfrm-Fix-memleak-on-xfrm-state-destroy.patch
  references (add bsc#1158775).
- commit f5ca88c
* Mon Dec  7 2020 mkubecek@suse.cz
- ethtool: fix error handling in ethtool_phys_id (git-fixes).
- commit 62d5d56
* Mon Dec  7 2020 oneukum@suse.com
- blacklist.conf: breaks kABI and is only needed on 32 bit
- commit b613713
* Mon Dec  7 2020 oneukum@suse.com
- blacklist.conf: cleanup, no functional change
- commit f5a48eb
* Mon Dec  7 2020 oneukum@suse.com
- USB: serial: kl5kusb105: fix memleak on open (git-fixes).
- commit 5939355
* Mon Dec  7 2020 jlee@suse.com
- x86/platform/uv: Unexport sn_coherency_id (jsc#SLE-16407).
- x86/platform/uv: Mark uv_bios_call() and uv_bios_call_irqsave()
  static (jsc#SLE-16407).
- efi/x86: Disallow efi=old_map in mixed mode (jsc#SLE-16407).
- commit e8cfe8c
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/bnxt_re: Fix sizeof mismatch for allocation of pbl_tbl. (bsc#1152489)
- commit b293ffc
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/ipoib: Set rtnl_link_ops for ipoib interfaces (bsc#1152489)
- commit 2686c41
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/addr: Fix race with netevent_callback()/rdma_addr_cancel() (bsc#1152489)
- commit e7b302f
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/hns: Fix missing sq_sig_type when querying QP (bsc#1152489)
- commit 428c91c
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/hns: Add check for the validity of sl configuration (bsc#1152489)
- commit 1cb3ce0
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/hns: Correct typo of hns_roce_create_cq() (bsc#1152489)
- commit 8c66138
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/mlx5: Disable IB_DEVICE_MEM_MGT_EXTENSIONS if IB_WR_REG_MR can't work (bsc#1152489)
- commit a38a25c
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/hns: Set the unsupported wr opcode (bsc#1152489)
- commit e06fae1
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix iWARP active mtu display (bsc#1152489)
- commit d610dee
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- qede: Notify qedr when mtu has changed (bsc#1152489)
- commit 98fc763
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix resource leak in qedr_create_qp (bsc#1152489)
- commit bdb50f5
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix inline size returned for iWARP (bsc#1152489)
- commit 1a57d92
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix use of uninitialized field (bsc#1152489)
- commit 6926fdb
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix doorbell setting (bsc#1152489)
- commit 7085d43
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix qp structure memory leak (bsc#1152489)
- commit 15f0227
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/umem: Prevent small pages from being returned by ib_umem_find_best_pgsz() (bsc#1152489)
- commit 6fda3ed
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/umem: Fix ib_umem_find_best_pgsz() for mappings that cross a page boundary (bsc#1152489)
- commit e3d4c09
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- IB/mlx4: Adjust delayed work when a dup is observed (bsc#1152489)
- commit f007f05
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- IB/mlx4: Fix starvation in paravirt mux/demux (bsc#1152489)
- commit b4a4680
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- IB/mlx4: Add support for MRA (bsc#1152489)
- commit d8e693f
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- IB/mlx4: Add and improve logging (bsc#1152489)
- commit d9fbac5
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- IB/isert: Fix unaligned immediate-data handling (bsc#1152489)
- commit ff723af
* Mon Dec  7 2020 msuchanek@suse.de
- powerpc/numa: Fix a regression on memoryless node 0 (bsc#1179639
  ltc#189002).
- commit 3324f59
* Mon Dec  7 2020 hare@suse.de
- nvme-rdma: handle unexpected nvme completion data length
  (bsc#1178612).
- commit 302adf9
* Mon Dec  7 2020 tiwai@suse.de
- tty: Fix ->pgrp locking in tiocspgrp() (git-fixes).
- usb: gadget: f_fs: Use local copy of descriptors for userspace
  copy (git-fixes).
- USB: serial: kl5kusb105: fix memleak on open (git-fixes).
- USB: serial: option: fix Quectel BG96 matching (git-fixes).
- thunderbolt: Fix use-after-free in remove_unplugged_switch()
  (git-fixes).
- coredump: fix core_pattern parse error (git-fixes).
- commit c18ac30
* Mon Dec  7 2020 hare@suse.de
- nvme-tcp: avoid repeated request completion (bsc#1179519).
- nvme-rdma: avoid repeated request completion (bsc#1179519).
- nvme-tcp: avoid race between time out and tear down
  (bsc#1179519).
- nvme-rdma: avoid race between time out and tear down
  (bsc#1179519).
- nvme: introduce nvme_sync_io_queues (bsc#1179519).
- nvme-rdma: fix reset hang if controller died in the middle of
  a reset (bsc#1179519).
- nvme-rdma: fix timeout handler (bsc#1179519).
- nvme-rdma: serialize controller teardown sequences
  (bsc#1179519).
- nvme-tcp: fix reset hang if controller died in the middle of
  a reset (bsc#1179519).
- nvme-tcp: fix timeout handler (bsc#1179519).
- nvme-tcp: serialize controller teardown sequences (bsc#1179519).
- nvme: have nvme_wait_freeze_timeout return if it timed out
  (bsc#1179519).
- nvme-fabrics: don't check state NVME_CTRL_NEW for request
  acceptance (bsc#1179519).
- nvme-rdma: fix controller reset hang during traffic
  (bsc#1179519).
- nvme-tcp: fix controller reset hang during traffic
  (bsc#1179519).
- nvme-tcp: optimize network stack with setting msg flags
  (bsc#1179519).
- nvme-tcp: leverage request plugging (bsc#1179519).
- nvme-tcp: have queue prod/cons send list become a llist
  (bsc#1179519).
- commit 2ed3c82
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/core: Fix reported speed and width (bsc#1152489)
- commit 8c599c6
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix memleak in rxe_mem_init_user (bsc#1152489)
- commit cc6aac8
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix the parent sysfs read when the interface has 15 chars (bsc#1152489)
- commit e9e9418
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/bnxt_re: Do not add user qps to flushlist (bsc#1152489)
- commit 940898b
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/netlink: Remove CAP_NET_RAW check when dump a raw QP (bsc#1152489)
- commit ccd3388
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/core: Fix return error value in _ib_modify_qp() to negative (bsc#1152489)
- commit 687bd9b
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Prevent access to wr->next ptr afrer wr is posted to send queue (bsc#1152489)
- commit 4299c93
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: SRQ's bug fixes (bsc#1152489)
- commit 9e7f793
* Mon Dec  7 2020 hare@suse.de
- nvme-tcp: set MSG_SENDPAGE_NOTLAST with MSG_MORE when we have
  (bsc#1179519).
- Refresh
  patches.suse/0004-nvme-tcp-check-page-by-sendpage_ok-before-calling-ke.patch.
- commit 32b2bc0
* Mon Dec  7 2020 hare@suse.de
- nvme-tcp: try to send request in queue_rq context (bsc#1179519).
- nvme-tcp: avoid scheduling io_work if we are already polling
  (bsc#1179519).
- nvme-tcp: use bh_lock in data_ready (bsc#1179519).
- commit 0a88b1e
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Return void from rxe_mem_init_dma() (bsc#1152489)
- commit 3d531e1
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Return void from rxe_init_port_param() (bsc#1152489)
- commit d46a4c5
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Drop pointless checks in rxe_init_ports (bsc#1152489)
- commit 2094aae
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/counter: Allow manually bind QPs with different pids to same counter (bsc#1152489)
- commit 309f664
* Mon Dec  7 2020 hare@suse.de
- nvme-tcp: fix possible crash in recv error flow (bsc#1179519).
- commit 4c08b72
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/counter: Only bind user QPs in auto mode (bsc#1152489)
- commit 72cbdac
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Skip dgid check in loopback mode (bsc#1152489)
- commit e2d95da
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- IB/uverbs: Set IOVA on IB MR in uverbs layer (bsc#1152489)
- commit b8a964a
* Mon Dec  7 2020 hare@suse.de
- nvme-tcp: don't poll a non-live queue (bsc#1179519).
- Refresh
  patches.suse/net-use-skb_queue_empty_lockless-in-busy-poll-contex.patch.
- commit f682d57
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/core: Fix bogus WARN_ON during ib_unregister_device_queued() (bsc#1152489)
- commit 3cc3811
* Mon Dec  7 2020 hare@suse.de
- nvme-tcp: break from io_work loop if recv failed (bsc#1179519).
- nvme-tcp: move send failure to nvme_tcp_try_send (bsc#1179519).
- commit c56582a
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Remove unused rxe_mem_map_pages (bsc#1152489)
- commit e074cd4
* Mon Dec  7 2020 glin@suse.com
- doc: Add link to bpf helpers man page (bsc#1177028).
- udp, bpf: Ignore connections in reuseport group after BPF sk
  lookup (bsc#1177028).
- Documentation/bpf: Document CGROUP_STORAGE map type
  (bsc#1177028).
- udp6: Run SK_LOOKUP BPF program on socket lookup (bsc#1177028).
- udp6: Extract helper for selecting socket from reuseport group
  (bsc#1177028).
- udp: Run SK_LOOKUP BPF program on socket lookup (bsc#1177028).
- udp: Extract helper for selecting socket from reuseport group
  (bsc#1177028).
- inet6: Run SK_LOOKUP BPF program on socket lookup (bsc#1177028).
- inet6: Extract helper for selecting socket from reuseport group
  (bsc#1177028).
- bpf: Add info about .BTF_ids section to btf.rst (bsc#1177028).
- docs: bpf/bpf_devel_QA.rst: fix reference to nonexistent
  document (bsc#1177028).
- docs: bpf/index.rst: Add ringbuf.rst (bsc#1177028).
- bpf: Allow skb_ancestor_cgroup_id helper in cgroup skb
  (bsc#1177028).
- bpf: Avoid gcc-10 stringop-overflow warning in struct bpf_prog
  (bsc#1177028).
- s390: enable bpf jit by default when not built as always-on (bsc#1177028).
  Update s390x config files
- bpf: lsm: Add Documentation (bsc#1177028).
- bpf: lsm: Initialize the BPF LSM hooks (bsc#1177028).
  Refresh patches.suse/0001-security-create-hidden-area-to-keep-sensitive-data.patch
- bpf: Document bpf_inspect drgn tool (bsc#1177028).
- bpf: inet_diag: Dump bpf_sk_storages in inet_diag_dump()
  (bsc#1177028).
- inet_diag: Move the INET_DIAG_REQ_BYTECODE nlattr to cb->data
  (bsc#1177028).
- inet_diag: Refactor inet_sk_diag_fill(), dump(), and dump_one()
  (bsc#1177028).
- docs/bpf: Update bpf development Q/A file (bsc#1177028).
- security: selinux: allow per-file labeling for bpffs
  (bsc#1177028).
- bpf: Avoid setting bpf insns pages read-only when prog is jited
  (bsc#1177028).
- bpf, doc: Change right arguments for JIT example code
  (bsc#1177028).
- bpf, testing: Introduce 'gso_linear_no_head_frag' skb_segment
  test (bsc#1177028).
- bpf, testing: Refactor test_skb_segment() for testing
  skb_segment() on different skbs (bsc#1177028).
- bpf: Add s390 testing documentation (bsc#1177028).
- bpf: clarify description for CONFIG_BPF_EVENTS (bsc#1177028).
- test_bpf: Fix a new clang warning about xor-ing two numbers
  (bsc#1177028).
- bpf/flow_dissector: document flags (bsc#1177028).
- commit b8f0bd1
* Mon Dec  7 2020 ohering@suse.de
- scsi: storvsc: Fix error return in storvsc_probe() (git-fixes).
- commit 83d54ae
* Mon Dec  7 2020 jslaby@suse.cz
- asm-generic: Make msi.h a mandatory include/asm header
  (jsc#SLE-16823).
- Refresh
  patches.suse/powerpc-64s-Implement-queued-spinlocks-and-rwlocks.patch.
- commit 23f23de
* Mon Dec  7 2020 jslaby@suse.cz
- iommu/vt-d: Fix compile error with CONFIG_PCI_ATS not set
  (jsc#SLE-16823).
- commit 6568a78
* Mon Dec  7 2020 jslaby@suse.cz
- iommu/vt-d: Cure VF irqdomain hickup (jsc#SLE-16823).
- genirq/irqdomain: Make sure all irq domain flags are distinct
  (jsc#SLE-16823).
- commit c29c85b
* Mon Dec  7 2020 glin@suse.com
- bpftool: Fix error return value in build_btf_type_table
  (bsc#1177028).
- commit a2cdbec
* Sun Dec  6 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/ALSA-usb-audio-Use-ALC1220-VB-DT-mapping-for-ASUS-RO.patch
- commit 2b35630
* Sun Dec  6 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/cifs-allow-syscalls-to-be-restarted-in-__smb_send_rqst-.patch
  patches.suse/cifs-fix-potential-use-after-free-in-cifs_echo_request-.patch
- commit f9b149a
* Sun Dec  6 2020 tiwai@suse.de
- Input: i8042 - fix error return code in i8042_setup_aux()
  (git-fixes).
- i2c: qup: Fix error return code in qup_i2c_bam_schedule_desc()
  (git-fixes).
- commit 74aa114
* Fri Dec  4 2020 ykaukab@suse.de
- PCI: tegra: Read "dbi" base address to program in application
  logic (bsc#1179344).
- PCI: tegra: Move "dbi" accesses to post common DWC
  initialization (bsc#1179344).
- commit 4c0696d
* Fri Dec  4 2020 lduncan@suse.com
- scsi: fnic: Validate io_req before others (bsc#1175079).
- scsi: fnic: Set scsi_set_resid() only for underflow
  (bsc#1175079).
- scsi: fnic: Change shost_printk() to FNIC_MAIN_DBG()
  (bsc#1175079).
- scsi: fnic: Avoid looping in TRANS ETH on unload (bsc#1175079).
- scsi: fnic: Change shost_printk() to FNIC_FCS_DBG()
  (bsc#1175079).
- commit 5c596ff
* Fri Dec  4 2020 mkoutny@suse.com
- blacklist.conf: 586b58cac8b4 exit: Move preemption fixup up, move blocking operations down
- commit 280ad3c
* Fri Dec  4 2020 mkoutny@suse.com
- exit: Move preemption fixup up, move blocking operations down
  (bsc#1174019).
- commit 940f4a2
* Fri Dec  4 2020 palcantara@suse.de
- cifs: fix DFS mount with cifsacl/modefromsid (bsc#1178270).
- commit c824489
* Fri Dec  4 2020 palcantara@suse.de
- cifs: fix check of tcon dfs in smb1 (bsc#1178270).
- commit ff315b4
* Fri Dec  4 2020 palcantara@suse.de
- cifs: Fix an error pointer dereference in cifs_mount()
  (bsc#1178270).
- commit e5a8cdb
* Fri Dec  4 2020 palcantara@suse.de
- cifs: document and cleanup dfs mount (bsc#1178270).
- commit de6694e
* Fri Dec  4 2020 palcantara@suse.de
- cifs: only update prefix path of DFS links in
  cifs_tree_connect() (bsc#1178270).
- commit 1f46cb8
* Fri Dec  4 2020 palcantara@suse.de
- cifs: fix double free error on share and prefix (bsc#1178270).
- commit bf4c8ab
* Fri Dec  4 2020 palcantara@suse.de
- cifs: handle RESP_GET_DFS_REFERRAL.PathConsumed in reconnect
  (bsc#1178270).
- commit 947bd74
* Fri Dec  4 2020 palcantara@suse.de
- cifs: handle empty list of targets in cifs_reconnect()
  (bsc#1178270).
- commit 846daee
* Fri Dec  4 2020 palcantara@suse.de
- cifs: rename reconn_inval_dfs_target() (bsc#1178270).
- commit 12d8cf3
* Fri Dec  4 2020 palcantara@suse.de
- cifs: reduce number of referral requests in DFS link lookups
  (bsc#1178270).
- commit cc7ec21
* Fri Dec  4 2020 palcantara@suse.de
- cifs: merge __{cifs,smb2}_reconnect[_tcon]() into
  cifs_tree_connect() (bsc#1178270).
- commit b6f05ac
* Fri Dec  4 2020 palcantara@suse.de
- cifs: get rid of unused parameter in reconn_setup_dfs_targets()
  (bsc#1178270).
- commit a6a1916
* Fri Dec  4 2020 tiwai@suse.de
- Update patch reference for rawmidi security fix (CVE-2020-27786 bsc#1179601)
- commit 1c4c1fd
* Fri Dec  4 2020 palcantara@suse.de
- cifs: handle hostnames that resolve to same ip in failover
  (bsc#1178270).
- commit cd8e61d
* Fri Dec  4 2020 palcantara@suse.de
- cifs: set up next DFS target before generic_ip_connect()
  (bsc#1178270).
- commit 1099aff
* Fri Dec  4 2020 ykaukab@suse.de
- cppc_cpufreq: optimise memory allocation for HW and NONE coordination (bsc#1179585).
- commit 5c89e8a
* Fri Dec  4 2020 palcantara@suse.de
- cifs: fix leaked reference on requeued write (bsc#1178270).
- commit f474970
* Fri Dec  4 2020 palcantara@suse.de
- cifs: fix uninitialised lease_key in open_shroot()
  (bsc#1178270).
- commit dbce315
* Fri Dec  4 2020 palcantara@suse.de
- cifs: ensure correct super block for DFS reconnect
  (bsc#1178270).
- commit 5350fc5
* Fri Dec  4 2020 palcantara@suse.de
- cifs: do not share tcons with DFS (bsc#1178270).
- commit c8f7b47
* Fri Dec  4 2020 ykaukab@suse.de
- PCI: qcom: Make sure PCIe is reset before init for rev 2.1.0 (bsc#1179344).
- PCI: tegra: No need to check return value of debugfs_create() functions (bsc#1179344).
- commit e014876
* Fri Dec  4 2020 msuchanek@suse.de
- powerpc/perf: Fix crash with is_sier_available when pmu is
  not set (bsc#1179578 ltc#189313).
- commit 26fc4d5
* Fri Dec  4 2020 tiwai@suse.de
- rtw88: debug: Fix uninitialized memory in debugfs code
  (git-fixes).
- geneve: pull IP header before ECN decapsulation (git-fixes).
- can: c_can: c_can_power_up(): fix error handling (git-fixes).
- can: sun4i_can: sun4i_can_err(): don't count arbitration lose
  as an error (git-fixes).
- can: sja1000: sja1000_err(): don't count arbitration lose as
  an error (git-fixes).
- batman-adv: Don't always reallocate the fragmentation skb head
  (git-fixes).
- batman-adv: Reserve needed_*room for fragments (git-fixes).
- batman-adv: Consider fragmentation for needed_headroom
  (git-fixes).
- commit 5d0aad4
* Fri Dec  4 2020 jlee@suse.com
- arm64: efi: increase EFI PE/COFF header padding to 64 KB
  (jsc#SLE-16407).
- commit b4b728e
* Thu Dec  3 2020 palcantara@suse.de
- cifs: allow syscalls to be restarted in __smb_send_rqst()
  (bsc#1176956).
- commit 5ae286e
* Thu Dec  3 2020 palcantara@suse.de
- cifs: fix potential use-after-free in cifs_echo_request()
  (bsc#1139944).
- commit 1723321
* Thu Dec  3 2020 mkubecek@suse.cz
- Delete patches.suse/fs-select.c-batch-user-writes-in-do_sys_poll.patch (bsc#1179419)
  This patch causes a regression and while we are not 100%% sure it does not
  just trigger a bug somewhere else, as it's only a performance optimization,
  dropping it for now is the safer option.
- commit b48bf35
* Thu Dec  3 2020 aaptel@suse.com
- cifs: add NULL check for ses->tcon_ipc (bsc#1178270).
- commit 0e24399
* Thu Dec  3 2020 mbrugger@suse.com
- random: avoid warnings for !CONFIG_NUMA builds (jsc#SLE-16574
  jsc#SLE-13718).
- commit 707d14b
* Thu Dec  3 2020 mbrugger@suse.com
- random: Make RANDOM_TRUST_CPU depend on ARCH_RANDOM
  (jsc#SLE-16574 jsc#SLE-13718).
- arm64: Update config files. Enable RANDOM_TRUST_CPU
- commit 1874f3a
* Thu Dec  3 2020 mbrugger@suse.com
- arm64: add credited/trusted RNG support (jsc#SLE-16574
  jsc#SLE-13718).
- commit d313473
* Thu Dec  3 2020 mbrugger@suse.com
- random: add arch_get_random_*long_early() (jsc#SLE-16574
  jsc#SLE-13718).
- Refresh
  patches.suse/0008-random-move-FIPS-continuous-test-to-output-functions.patch.
- Refresh
  patches.suse/random-fix-circular-include-dependency-on-arm64-afte.patch.
- Refresh
  patches.suse/random32-move-the-pseudo-random-32-bit-definitions-t.patch.
- Refresh
  patches.suse/random32-update-the-net-random-state-on-interrupt-an.patch.
- commit f9d737f
* Thu Dec  3 2020 mbrugger@suse.com
- random: split primary/secondary crng init paths (jsc#SLE-16574
  jsc#SLE-13718).
- Refresh
  patches.suse/0008-random-move-FIPS-continuous-test-to-output-functions.patch.
- commit 95b7891
* Thu Dec  3 2020 yousaf.kaukab@suse.com
- PCI: rockchip: Fix bus checks in rockchip_pcie_valid_device().
- commit 1c9f6cd
* Thu Dec  3 2020 mbrugger@suse.com
- arm64: Use v8.5-RNG entropy for KASLR seed (jsc#SLE-16574
  jsc#SLE-13718).
- commit d1f775c
* Thu Dec  3 2020 mbrugger@suse.com
- arm64: Implement archrandom.h for ARMv8.5-RNG (jsc#SLE-16574
  jsc#SLE-13718).
- Refresh patches.suse/arm64-Detect-the-ARMv8.4-TTL-feature.patch.
- Refresh
  patches.suse/arm64-cpufeature-Add-remaining-feature-bits-in-ID_AA.patch.
- Refresh
  patches.suse/arm64-tlb-Detect-the-ARMv8.4-TLBI-RANGE-feature.patch.
- Refresh
  patches.suse/kabi-arm64-reserve-space-in-cpu_hwcaps-and-cpu_hwcap.patch.
- arm64: Update config files. Enable CONFIG_ARCH_RANDOM
- commit 7a3c65d
* Thu Dec  3 2020 yousaf.kaukab@suse.com
- PCI: cadence: Fix cdns_pcie_{host|ep}_setup() error path (bsc#1179344).
  Refresh:
  patches.suse/PCI-Set-bridge-map_irq-and-swizzle_irq-to-default-fu.patch.
  patches.suse/PCI-Set-default-bridge-parent-device.patch.
  patches.suse/PCI-cadence-Remove-private-bus-number-and-range-stor.patch.
  patches.suse/PCI-cadence-Use-struct-pci_host_bridge.windows-list-.patch.
- commit d8fd281
* Thu Dec  3 2020 ailiop@suse.com
- Revert "xfs: complain if anyone tries to create a too-large buffer"
  This reverts commit 293e483ad8434ee10a65f76743a0a654e34e76c6.
  References: bsc#1179425, bsc#1179550
- commit d88fa75
* Thu Dec  3 2020 mbrugger@suse.com
- arm64: kaslr: Check command line before looking for a seed
  (jsc#SLE-16574 jsc#SLE-13718).
- commit 6895a97
* Thu Dec  3 2020 mbrugger@suse.com
- arm64: kaslr: Announce KASLR status on boot (jsc#SLE-16574
  jsc#SLE-13718).
- commit bdab3d9
* Thu Dec  3 2020 yousaf.kaukab@suse.com
- PCI: Move DT resource setup into devm_pci_alloc_host_bridge() (bsc#1179344).
- PCI: rcar-gen2: Convert to use modern host bridge probe functions (bsc#1179344).
- PCI: of: Reduce missing non-prefetchable memory region to a warning (bsc#1179344).
- commit 10c6591
* Thu Dec  3 2020 yousaf.kaukab@suse.com
- PCI: cadence: Remove private bus number and range storage (bsc#1179344).
- commit 9499504
* Thu Dec  3 2020 yousaf.kaukab@suse.com
- PCI: cadence: Use bridge resources for outbound window setup (bsc#1179344).
- PCI: cadence: Remove "cdns,max-outbound-regions" DT property (bsc#1179344).
- commit 569c1e5
* Thu Dec  3 2020 yousaf.kaukab@suse.com
- PCI: cadence: Use struct pci_host_bridge.windows list directly
  (bsc#1179344).
- commit 946fb1a
* Thu Dec  3 2020 yousaf.kaukab@suse.com
- PCI: cadence: Move all files to per-device cadence directory (bsc#1179344)
  Refresh:
  patches.suse/PCI-cadence-Fix-updating-Vendor-ID-and-Subsystem-Ven.patch.
  patches.suse/PCI-hip-Add-handling-of-HiSilicon-HIP-PCIe-controlle.patch.
  patches.suse/PCI-mobiveil-Modularize-the-Mobiveil-PCIe-Host-Bridg.patch.
  patches.suse/pci-of-add-inbound-resource-parsing-to-helpers.patch.
- commit 52cc93a
* Thu Dec  3 2020 mbrugger@suse.com
- Refresh
  patches.suse/ftrace-Fix-DYNAMIC_FTRACE_WITH_DIRECT_CALLS-dependen.patch.
- commit c268ddc
* Thu Dec  3 2020 bp@suse.de
- x86/speculation: Fix prctl() when
  spectre_v2_user={seccomp,prctl},ibpb (bsc#1152489).
- commit bc73dfb
* Thu Dec  3 2020 bp@suse.de
- x86/resctrl: Add necessary kernfs_put() calls to prevent
  refcount leak (bsc#1152489).
- commit 506cd70
* Thu Dec  3 2020 yousaf.kaukab@suse.com
- PCI: cadence: Refactor driver to use as a core library (bsc#1179344).
- commit cb4f70b
* Thu Dec  3 2020 yousaf.kaukab@suse.com
- PCI: dwc: Detect number of iATU windows (bsc#1179344).
- PCI: dwc: Move inbound and outbound windows to common struct (bsc#1179344).
- PCI: dwc: Remove unnecessary wrappers around dw_pcie_host_init() (bsc#1179344).
- PCI: dwc: Move dw_pcie_setup_rc() to DWC common code (bsc#1179344).
- PCI: dwc: Move dw_pcie_msi_init() into core (bsc#1179344).
- PCI: dwc: Move link handling into common code (bsc#1179344).
- PCI: dwc: Rework MSI initialization (bsc#1179344).
- PCI: dwc: Move MSI interrupt setup into DWC common code (bsc#1179344).
- PCI: dwc: Drop the .set_num_vectors() host op (bsc#1179344).
- PCI: dwc/dra7xx: Use the common MSI irq_chip (bsc#1179344).
- PCI: dwc: Ensure all outbound ATU windows are reset (bsc#1179344).
- PCI: dwc/intel-gw: Remove some unneeded function wrappers (bsc#1179344).
- PCI: dwc: Move "dbi", "dbi2", and "addr_space" resource setup into common code (bsc#1179344).
- PCI: dwc/intel-gw: Move ATU offset out of driver match data (bsc#1179344).
- PCI: keystone: Enable compile-testing on !ARM (bsc#1179344).
- PCI: dwc: Support multiple ATU memory regions (bsc#1179344).
- PCI: dwc: Add support to program ATU for >4GB memory (bsc#1179344).
- PCI: of: Warn if non-prefetchable memory aperture size is > 32-bit (bsc#1179344).
- PCI: dwc: Restore ATU memory resource setup to use last entry (bsc#1179344).
- commit 6e5443d
* Thu Dec  3 2020 bp@suse.de
- x86/resctrl: Remove superfluous kernfs_get() calls to prevent
  refcount leak (bsc#1152489).
- commit 5e0ddcd
* Thu Dec  3 2020 tiwai@suse.de
- iwlwifi: mvm: properly cancel a session protection for P2P
  (git-fixes).
- iwlwifi: mvm: use the HOT_SPOT_CMD to cancel an AUX ROC
  (git-fixes).
- dmaengine: fix error codes in channel_register() (git-fixes).
- commit 2ca6174
* Thu Dec  3 2020 tiwai@suse.de
- USB: quirks: Add USB_QUIRK_DISCONNECT_SUSPEND quirk for Lenovo
  A630Z TIO built-in usb-audio card (git-fixes).
- HID: Add Logitech Dinovo Edge battery quirk (git-fixes).
- HID: logitech-hidpp: Add HIDPP_CONSUMER_VENDOR_KEYS quirk for
  the Dinovo Edge (git-fixes).
- HID: add HID_QUIRK_INCREMENT_USAGE_ON_DUPLICATE for Gamevice
  devices (git-fixes).
- HID: hid-sensor-hub: Fix issue with devices with no report ID
  (git-fixes).
- HID: add support for Sega Saturn (git-fixes).
- HID: cypress: Support Varmilo Keyboards' media hotkeys
  (git-fixes).
- HID: ite: Replace ABS_MISC 120/121 events with touchpad on/off
  keypresses (git-fixes).
- HID: uclogic: Add ID for Trust Flex Design Tablet (git-fixes).
- Input: i8042 - allow insmod to succeed on devices without an
  i8042 controller (git-fixes).
- commit 79be581
* Thu Dec  3 2020 tiwai@suse.de
- ASoC: rt5682: change SAR voltage threshold (git-fixes).
- commit 792c88a
* Thu Dec  3 2020 tiwai@suse.de
- kABI workaround for HD-audio generic parser (git-fixes).
- commit 233e3cc
* Thu Dec  3 2020 tiwai@suse.de
- ALSA: hda/realtek: Add mute LED quirk to yet another HP x360
  model (git-fixes).
- ALSA: hda/realtek: Fix bass speaker DAC assignment on Asus
  Zephyrus G14 (git-fixes).
- ALSA: hda/generic: Add option to enforce preferred_dacs pairs
  (git-fixes).
- ASoC: wm_adsp: fix error return code in wm_adsp_load()
  (git-fixes).
- ASoC: Intel: bytcr_rt5640: Fix HP Pavilion x2 Detachable quirks
  (git-fixes).
- ALSA: usb-audio: US16x08: fix value count for level meters
  (git-fixes).
- ALSA: hda/realtek - Add new codec supported for ALC897
  (git-fixes).
- ALSA: hda/realtek: Enable headset of ASUS UX482EG & B9400CEA
  with ALC294 (git-fixes).
- ALSA: hda/realtek - Fixed Dell AIO wrong sound tone (git-fixes).
- commit c480457
* Thu Dec  3 2020 jlee@suse.com
- mm/init-mm.c: include <linux/mman.h> for vm_committed_as_batch
  (jsc#SLE-16407).
- commit ec88d4f
* Thu Dec  3 2020 tonyj@suse.de
- perf/x86: Fix n_metric for cancelled txn (jsc#SLE-13346).
- perf/x86/intel: Check perf metrics feature for each CPU
  (jsc#SLE-13346).
- commit 3ed7afb
* Wed Dec  2 2020 tbogendoerfer@suse.de
- cxgb4: Fix build failure when CONFIG_TLS=m (jsc#SLE-15129).
- commit a2fe676
* Wed Dec  2 2020 tbogendoerfer@suse.de
- crypto/chcr: move nic TLS functionality to drivers/net
  (jsc#SLE-15129).
- Update config files.
- supported.conf: Added ch_ktls (Chelsio TLS offload module)
- commit 04b52e4
* Wed Dec  2 2020 tbogendoerfer@suse.de
- crypto/chcr: Moving chelsio's inline ipsec functionality to
  /drivers/net (jsc#SLE-15129).
- Update config files.
- supported.conf: added ch_ipsec (Chelsio ipsec offload module)
- commit 813c7b5
* Wed Dec  2 2020 yousaf.kaukab@suse.com
- PCI: Use devm_add_action_or_reset() (bsc#1179344).
- commit 2e95630
* Wed Dec  2 2020 tbogendoerfer@suse.de
- chelsio/chtls: separate chelsio tls driver from crypto driver
  (jsc#SLE-15129).
- Update config files.
- commit 3a32580
* Wed Dec  2 2020 tbogendoerfer@suse.de
- ch_ktls: lock is not freed (jsc#SLE-15129).
- cxgb4: fix the panic caused by non smac rewrite (jsc#SLE-15131).
- ch_ktls: stop the txq if reaches threshold (jsc#SLE-15129).
- ch_ktls: tcb update fails sometimes (jsc#SLE-15129).
- ch_ktls/cxgb4: handle partial tag alone SKBs (jsc#SLE-15129).
- ch_ktls: don't free skb before sending FIN (jsc#SLE-15129).
- ch_ktls: packet handling prior to start marker (jsc#SLE-15129).
- ch_ktls: Correction in middle record handling (jsc#SLE-15129).
- ch_ktls: missing handling of header alone (jsc#SLE-15129).
- ch_ktls: Correction in trimmed_len calculation (jsc#SLE-15129).
- cxgb4/ch_ktls: creating skbs causes panic (jsc#SLE-15129).
- ch_ktls: Update cheksum information (jsc#SLE-15129).
- ch_ktls: Correction in finding correct length (jsc#SLE-15129).
- cxgb4/ch_ktls: decrypted bit is not enough (jsc#SLE-15129).
- chelsio/chtls: fix always leaking ctrl_skb (jsc#SLE-15129).
- chelsio/chtls: fix memory leaks caused by a race
  (jsc#SLE-15129).
- chelsio/chtls: fix memory leaks in CPL handlers (jsc#SLE-15129).
- chelsio/chtls: fix deadlock issue (jsc#SLE-15129).
- cxgb4: set up filter action after rewrites (jsc#SLE-15131).
- chelsio/chtls: fix tls record info to user (jsc#SLE-15129).
- net: chelsio: inline_crypto: fix Kconfig and build errors
  (jsc#SLE-15129).
- chelsio/chtls: fix writing freed memory (jsc#SLE-15129).
- chelsio/chtls: correct function return and return type
  (jsc#SLE-15129).
- chelsio/chtls: Fix panic when listen on multiadapter
  (jsc#SLE-15129).
- chelsio/chtls: fix panic when server is on ipv6 (jsc#SLE-15129).
- chelsio/chtls: correct netdevice for vlan interface
  (jsc#SLE-15129).
- chelsio/chtls: fix socket lock (jsc#SLE-15129).
- cxgb4: handle 4-tuple PEDIT to NAT mode translation
  (jsc#SLE-15131).
- cxgb4/ch_ipsec: Replace the module name to ch_ipsec from chcr
  (jsc#SLE-15129).
- net: cxbg4: Remove pointless in_interrupt() check
  (jsc#SLE-15131).
- cxgb4/ch_ktls: ktls stats are added at port level
  (jsc#SLE-15129).
- cxgb4: Avoid log flood (jsc#SLE-15131).
- ch_ktls: Issue if connection offload fails (jsc#SLE-15129).
- cxgb4vf: convert to use DEFINE_SEQ_ATTRIBUTE macro
  (jsc#SLE-15131).
- chelsio/chtls: Re-add dependencies on CHELSIO_T4 to fix modular
  CHELSIO_T4 (jsc#SLE-15129).
- cxgb4/ch_ipsec: Registering xfrmdev_ops with cxgb4
  (jsc#SLE-15129).
- chelsio/chtls: CHELSIO_INLINE_CRYPTO should depend on CHELSIO_T4
  (jsc#SLE-15129).
- cxgb4: add error handlers to LE intr_handler (jsc#SLE-15131).
- cxgb4: insert IPv6 filter rules in next free region
  (jsc#SLE-15131).
- crypto: chelsio - fix minor indentation issue (jsc#SLE-15129).
- commit 9264232
* Wed Dec  2 2020 yousaf.kaukab@suse.com
- PCI: mvebu: Fix duplicate resource requests (bsc#1179344).
- PCI: meson: Build as module by default (bsc#1179344).
- PCI: kirin: Return -EPROBE_DEFER in case the gpio isn't ready (bsc#1179344).
- PCI: imx6: Do not output error message when devm_clk_get() failed with -EPROBE_DEFER (bsc#1179344).
- PCI: imx6: Use fallthrough pseudo-keyword (bsc#1179344).
- PCI: dwc: Add link up check in dw_child_pcie_ops.map_bus() (bsc#1179344).
- PCI: dwc: Fix MSI page leakage in suspend/resume (bsc#1179344).
- PCI: dwc: Skip PCIE_MSI_INTR0* programming if MSI is disabled (bsc#1179344).
- PCI: keystone: Remove iATU register mapping (bsc#1179344).
- PCI: dwc: Add common iATU register support (bsc#1179344).
- PCI: dwc: Fix 'cast truncates bits from constant value' (bsc#1179344).
- misc: pci_endpoint_test: Add LS1088a in pci_device_id table (bsc#1179344).
- PCI: layerscape: Add EP mode support for ls1088a and ls2088a (bsc#1179344).
- PCI: layerscape: Modify the MSIX to the doorbell mode (bsc#1179344).
- PCI: layerscape: Modify the way of getting capability with different PEX (bsc#1179344).
- PCI: layerscape: Fix some format issue of the code (bsc#1179344).
- PCI: designware-ep: Modify MSI and MSIX CAP way of finding (bsc#1179344).
- PCI: designware-ep: Move the function of getting MSI capability forward (bsc#1179344).
- PCI: designware-ep: Add the doorbell mode of MSI-X in EP mode (bsc#1179344).
- PCI: designware-ep: Add multiple PFs support for DWC (bsc#1179344).
- PCI: dwc: Use DBI accessors (bsc#1179344).
- PCI: dwc: Move N_FTS setup to common setup (bsc#1179344).
- PCI: dwc/intel-gw: Drop unused max_width (bsc#1179344).
- PCI: dwc/intel-gw: Move getting PCI_CAP_ID_EXP offset to intel_pcie_link_setup() (bsc#1179344).
- PCI: dwc/intel-gw: Drop unnecessary checking of DT 'device_type' property (bsc#1179344).
- PCI: dwc: Set PORT_LINK_DLL_LINK_EN in common setup code (bsc#1179344).
- PCI: dwc: Centralize link gen setting (bsc#1179344).
- PCI: dwc: Make ATU accessors private (bsc#1179344).
- PCI: dwc: Remove read_dbi2 code (bsc#1179344).
- PCI: dwc/tegra: Use common Designware port logic register definitions (bsc#1179344).
  Refresh:
  patches.suse/PCI-tegra-No-need-to-check-return-value-of-debugfs_c.patch
- PCI: dwc: Remove hardcoded PCI_CAP_ID_EXP offset (bsc#1179344).
- PCI: dwc/qcom: Use common PCI register definitions (bsc#1179344).
- PCI: dwc/imx6: Use common PCI register definitions (bsc#1179344).
- PCI: dwc/meson: Rework PCI config and DW port logic register accesses (bsc#1179344).
- PCI: dwc/meson: Drop unnecessary RC config space initialization (bsc#1179344).
- PCI: dwc/meson: Drop the duplicate number of lanes setup (bsc#1179344).
- PCI: dwc: Ensure FAST_LINK_MODE is cleared (bsc#1179344).
- PCI: dwc: Add a 'num_lanes' field to struct dw_pcie (bsc#1179344).
- PCI: dwc/imx6: Remove duplicate define PCIE_LINK_WIDTH_SPEED_CONTROL (bsc#1179344).
- PCI: dwc: Check CONFIG_PCI_MSI inside dw_pcie_msi_init() (bsc#1179344).
- PCI: dwc: Simplify config space handling (bsc#1179344).
- PCI: dwc: Remove storing of PCI resources (bsc#1179344).
- PCI: dwc: Remove root_bus pointer (bsc#1179344).
- PCI: dwc: Convert to use pci_host_probe() (bsc#1179344).
- PCI: dwc: keystone: Convert .scan_bus() callback to use add_bus (bsc#1179344).
- PCI: Also call .add_bus() callback for root bus (bsc#1179344).
- PCI: dwc: Use generic config accessors (bsc#1179344).
- PCI: dwc: Remove dwc specific config accessor ops (bsc#1179344).
- PCI: dwc: histb: Use pci_ops for root config space accessors (bsc#1179344).
- PCI: dwc: exynos: Use pci_ops for root config space accessors (bsc#1179344).
- PCI: dwc: kirin: Use pci_ops for root config space accessors (bsc#1179344).
- PCI: dwc: meson: Use pci_ops for root config space accessors (bsc#1179344).
- PCI: dwc: tegra: Use pci_ops for root config space accessors (bsc#1179344).
- PCI: dwc: keystone: Use pci_ops for config space accessors (bsc#1179344).
- PCI: dwc: al: Use pci_ops for child config space accessors (bsc#1179344).
- PCI: dwc: Add a default pci_ops.map_bus for root port (bsc#1179344).
- PCI: dwc: Allow overriding bridge pci_ops (bsc#1179344).
- PCI: dwc: Use DBI accessors instead of own config accessors (bsc#1179344).
- PCI: Allow root and child buses to have different pci_ops (bsc#1179344).
- PCI: designware-ep: Fix the Header Type check (bsc#1179344).
- PCI: Remove dev_err() when handing an error from platform_get_irq() (bsc#1179344).
- PCI: Fix kerneldoc warnings (bsc#1179344).
- PCI: Set bridge map_irq and swizzle_irq to default functions (bsc#1179344).
- PCI: Move setting pci_host_bridge.busnr out of host drivers (bsc#1179344).
- PCI: rockchip: Use pci_is_root_bus() to check if bus is root bus (bsc#1179344).
- PCI: xilinx: Use pci_is_root_bus() to check if bus is root bus (bsc#1179344).
- PCI: xilinx-nwl: Use pci_is_root_bus() to check if bus is root bus (bsc#1179344).
- PCI: mobiveil: Use pci_is_root_bus() to check if bus is root bus (bsc#1179344).
  Refresh:
  patches.suse/PCI-mobiveil-ls_pcie_g4-add-Workaround-for-A-011577.patch
- PCI: designware: Use pci_is_root_bus() to check if bus is root bus (bsc#1179344).
- PCI: aardvark: Use pci_is_root_bus() to check if bus is root bus (bsc#1179344).
- PCI: Drop unnecessary zeroing of bridge fields (bsc#1179344).
- PCI: Set default bridge parent device (bsc#1179344).
- PCI: versatile: Drop flag PCI_ENABLE_PROC_DOMAINS (bsc#1179344).
- PCI: xilinx: Use pci_host_probe() to register host (bsc#1179344).
- PCI: xilinx-nwl: Use pci_host_probe() to register host (bsc#1179344).
- PCI: rockchip: Use pci_host_probe() to register host (bsc#1179344).
- PCI: iproc: Use pci_host_probe() to register host (bsc#1179344).
- PCI: altera: Use pci_host_probe() to register host (bsc#1179344).
- PCI: xgene: Use pci_host_probe() to register host (bsc#1179344).
- PCI: versatile: Use pci_host_probe() to register host (bsc#1179344).
- PCI: v3: Use pci_host_probe() to register host (bsc#1179344).
- PCI: mobiveil: Use pci_host_probe() to register host (bsc#1179344).
- PCI: brcmstb: Use pci_host_probe() to register host (bsc#1179344).
  Refresh:
  patches.suse/PCI-controller-Convert-to-devm_platform_ioremap_reso.patch
- PCI: host-common: Use struct pci_host_bridge.windows list directly (bsc#1179344).
- PCI: mvebu: Use struct pci_host_bridge.windows list directly (bsc#1179344).
- PCI: Use of_node_name_eq() for node name comparisons (bsc#1179344).
- PCI: Fix pci_host_bridge struct device release/free handling (bsc#1179344).
- PCI: Make devm_of_pci_get_host_bridge_resources() static (bsc#1179344).
- commit 1cc12ed
* Wed Dec  2 2020 jlee@suse.com
- efi: Revert "efi/x86: Fix build with gcc 4" (jsc#SLE-16407).
- efi/libstub: Move the function prototypes to header file
  (jsc#SLE-16407).
- efi/libstub: Fix gcc error around __umoddi3 for 32 bit builds
  (jsc#SLE-16407).
- efi/x86: Only copy upto the end of setup_header (jsc#SLE-16407).
- efi/x86: Remove unused variables (jsc#SLE-16407).
- efi/libstub/arm64: Retain 2MB kernel Image alignment if !KASLR
  (jsc#SLE-16407).
- efi/libstub: arm: Print CPU boot mode and MMU state at boot
  (jsc#SLE-16407).
- efi/libstub: arm: Omit arch specific config table matching
  array on arm64 (jsc#SLE-16407).
- efi: Make it possible to disable efivar_ssdt entirely
  (jsc#SLE-16407).
- Refresh
  patches.suse/efi-EFI_EARLYCON-should-depend-on-EFI.patch
- Update config files.
  Add CONFIG_EFI_CUSTOM_SSDT_OVERLAYS=y to x86_64/default, arm64/default
- efi/libstub: Descriptions for stub helper functions
  (jsc#SLE-16407).
- efi/libstub: Fix missing-prototype warning for skip_spaces()
  (jsc#SLE-16407).
- efi: Replace zero-length array and use struct_size() helper
  (jsc#SLE-16407).
- efivarfs: Don't return -EINTR when rate-limiting reads
  (jsc#SLE-16407).
- efivarfs: Update inode modification time for successful writes
  (jsc#SLE-16407).
- efi/x86: Fix build with gcc 4 (jsc#SLE-16407).
- build, kcsan: Add KCSAN build exceptions (jsc#SLE-16407).
- mmap locking API: add MMAP_LOCK_INITIALIZER (jsc#SLE-16407).
- efi_test: get rid of pointless access_ok() (jsc#SLE-16407).
- efi/libstub: Disable Shadow Call Stack (jsc#SLE-16407).
- arm64: efi: Restore register x18 if it was corrupted
  (jsc#SLE-16407).
- arm64: kernel: Convert to modern annotations for assembly
  functions (jsc#SLE-16407).
- efi/libstub/arm64: align PE/COFF sections to segment alignment
  (jsc#SLE-16407).
- arm64: rename stext to primary_entry (jsc#SLE-16407).
- efi/x86: Don't blow away existing initrd (jsc#SLE-16407).
- efi/x86: Drop the special GDT for the EFI thunk (jsc#SLE-16407).
- efi/libstub: Add missing prototype for PE/COFF entry point
  (jsc#SLE-16407).
- efi/libstub: Use pool allocation for the command line
  (jsc#SLE-16407).
- efi/libstub: Don't parse overlong command lines (jsc#SLE-16407).
- efi/libstub: Use snprintf with %%ls to convert the command line
  (jsc#SLE-16407).
- efi/libstub: Get the exact UTF-8 length (jsc#SLE-16407).
- efi/libstub: Use %%ls for filename (jsc#SLE-16407).
- efi/libstub: Add UTF-8 decoding to efi_puts (jsc#SLE-16407).
- efi/printf: Add support for wchar_t (UTF-16) (jsc#SLE-16407).
- efi/gop: Add an option to list out the available GOP modes
  (jsc#SLE-16407).
- efi/libstub: Add definitions for console input and events
  (jsc#SLE-16407).
- efi/libstub: Implement printk-style logging (jsc#SLE-16407).
- efi/printf: Turn vsprintf into vsnprintf (jsc#SLE-16407).
- efi/printf: Abort on invalid format (jsc#SLE-16407).
- efi/printf: Refactor code to consolidate padding and output
  (jsc#SLE-16407).
- efi/printf: Handle null string input (jsc#SLE-16407).
- efi/printf: Factor out integer argument retrieval
  (jsc#SLE-16407).
- efi/printf: Factor out width/precision parsing (jsc#SLE-16407).
- efi/printf: Merge 'p' with the integer formats (jsc#SLE-16407).
- efi/printf: Fix minor bug in precision handling (jsc#SLE-16407).
- efi/printf: Factor out flags parsing and handle '%%' earlier
  (jsc#SLE-16407).
- efi/printf: Add 64-bit and 8-bit integer support
  (jsc#SLE-16407).
- efi/printf: Drop %%n format and L qualifier (jsc#SLE-16407).
- efi/libstub: Optimize for size instead of speed (jsc#SLE-16407).
- efi/libstub: Add a basic printf implementation (jsc#SLE-16407).
- efi/libstub: Buffer output of efi_puts (jsc#SLE-16407).
- efi/libstub: Rename efi_[char16_]printk to efi_[char16_]puts
  (jsc#SLE-16407).
- efi/libstub: Include dependencies of efistub.h (jsc#SLE-16407).
- efi/libstub: Correct comment typos (jsc#SLE-16407).
- efi/libstub: Make efi_printk() input argument const char*
  (jsc#SLE-16407).
- efi/libstub: Fix mixed mode boot issue after macro refactor
  (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
- efi/libstub: Check return value of efi_parse_options
  (jsc#SLE-16407).
- efi/x86: Support builtin command line (jsc#SLE-16407).
- efi/libstub: Unify initrd loading across architectures
  (jsc#SLE-16407).
- efi/x86: Move command-line initrd loading to efi_main
  (jsc#SLE-16407).
- efi/libstub: Upgrade ignored dtb= argument message to error
  (jsc#SLE-16407).
- efi/tpm: Use efi_err for error messages (jsc#SLE-16407).
- efi/gop: Use efi_err for error messages (jsc#SLE-16407).
- efi/x86: Use efi_err for error messages (jsc#SLE-16407).
- efi/libstub: Move pr_efi/pr_efi_err into efi namespace
  (jsc#SLE-16407).
  Refresh
  patches.suse/0001-efi-generalize-efi_get_secureboot.patch
- efi/libstub: Add a helper function to split 64-bit values
  (jsc#SLE-16407).
- efi/x86: Use correct size for boot_params (jsc#SLE-16407).
- efi/libstub: Re-enable command line initrd loading for x86
  (jsc#SLE-16407).
- efi: Move arch_tables check to caller (jsc#SLE-16407).
- efi: Clean up config table description arrays (jsc#SLE-16407).
- efi/libstub/x86: Avoid getter function for efi_is64
  (jsc#SLE-16407).
- efi/libstub: Drop __pure getters for EFI stub options
  (jsc#SLE-16407).
- efi/libstub: Drop __pure getter for efi_system_table
  (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
- efi: Kill __efistub_global (jsc#SLE-16407).
- efi/x86: Remove __efistub_global and add relocation check
  (jsc#SLE-16407).
- efi/arm: Remove __efistub_global annotation (jsc#SLE-16407).
- efi/libstub: Move efi_relocate_kernel() into separate source
  file (jsc#SLE-16407).
- efi/libstub/arm64: Switch to ordinary page allocator for kernel
  image (jsc#SLE-16407).
- efi/libstub: Add API function to allocate aligned memory
  (jsc#SLE-16407).
- efi/libstub/arm64: Simplify randomized loading of kernel image
  (jsc#SLE-16407).
- efi/libstub/arm64: Replace 'preferred' offset with alignment
  check (jsc#SLE-16407).
- efi/libstub/random: Increase random alloc granularity
  (jsc#SLE-16407).
- efi/libstub/random: Align allocate size to EFI_ALLOC_ALIGN
  (jsc#SLE-16407).
- efi/gop: Allow automatically choosing the best mode
  (jsc#SLE-16407).
- efi/gop: Allow specifying depth as well as resolution
  (jsc#SLE-16407).
- efi/gop: Allow specifying mode by <xres>x<yres> (jsc#SLE-16407).
- efi/gop: Allow specifying mode number on command line
  (jsc#SLE-16407).
- efi/gop: Add prototypes for query_mode and set_mode
  (jsc#SLE-16407).
- efi/gop: Remove unreachable code from setup_pixel_info
  (jsc#SLE-16407).
- efi/gop: Use helper macros for find_bits (jsc#SLE-16407).
- efi/gop: Use helper macros for populating lfb_base
  (jsc#SLE-16407).
- efi/gop: Move variable declarations into loop block
  (jsc#SLE-16407).
- efi/gop: Slightly re-arrange logic of find_gop (jsc#SLE-16407).
- efi/gop: Factor out locating the gop into a function
  (jsc#SLE-16407).
- efi/gop: Get mode information outside the loop (jsc#SLE-16407).
- efi/gop: Move check for framebuffer before con_out
  (jsc#SLE-16407).
- efi/gop: Remove redundant current_fb_base (jsc#SLE-16407).
- efi/libstub/arm: Make install_memreserve_table static
  (jsc#SLE-16407).
- efi/libstub: unify EFI call wrappers for non-x86
  (jsc#SLE-16407).
- efi/libstub: Make initrd file loader configurable
  (jsc#SLE-16407).
  Update config files.
  Add CONFIG_EFI_GENERIC_STUB_INITRD_CMDLINE_LOADER=y to x86_64/default,
  arm64/default
- efi/libstub: Move arm-stub to a common file (jsc#SLE-16407).
- Refresh
  patches.suse/0003-arm64-ima-add-ima_arch-support.patch
- Update config files.
- arm64: head: Annotate stext and preserve_boot_args as code
  (jsc#SLE-16407).
- commit dad69fe
* Wed Dec  2 2020 msuchanek@suse.de
- ibmvnic: Fix TX completion error handling (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: Ensure that SCRQ entry reads are correctly ordered
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- Refresh patches.suse/ibmvnic-Correctly-re-enable-interrupts-in-NAPI-polli.patch
- Refresh patches.suse/ibmvnic-Introduce-xmit_more-support-using-batched-su.patch
- ibmvnic: Fix TX completion error handling (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: Ensure that SCRQ entry reads are correctly ordered
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- Refresh patches.suse/ibmvnic-Correctly-re-enable-interrupts-in-NAPI-polli.patch
- Refresh patches.suse/ibmvnic-Introduce-xmit_more-support-using-batched-su.patch
- commit 02ce2a8
* Wed Dec  2 2020 yousaf.kaukab@suse.com
- PCI: controller: Remove duplicate error message (bsc#1179344).
- PCI: controller: Convert to devm_platform_ioremap_resource() (bsc#1179344).
- PCI: qcom: Fix runtime PM imbalance on error (bsc#1179344).
- PCI: dwc: pci-dra7xx: Fix runtime PM imbalance on error (bsc#1179344).
- PCI: dwc: hisi: Remove non-ECAM HiSilicon hip05/hip06 driver (bsc#1179344).
- PCI: dwc: Convert to devm_platform_ioremap_resource_byname() (bsc#1179344).
- PCI: qcom: Replace define with standard value (bsc#1179344).
- PCI: qcom: Support pci speed set for ipq806x (bsc#1179344).
- PCI: qcom: Add ipq8064 rev2 variant (bsc#1179344).
- PCI: qcom: Use bulk clk api and assert on error (bsc#1179344).
- PCI: qcom: Change duplicate PCI reset to phy reset (bsc#1179344).
  Refresh:
  patches.suse/PCI-qcom-Add-missing-reset-for-ipq806x.patch
- PCI: endpoint: Add support to handle multiple base for mapping outbound memory (bsc#1179344).
- PCI: endpoint: Pass page size as argument to pci_epc_mem_init() (bsc#1179344).
- PCI: host-generic: Eliminate pci_host_common_probe wrappers (bsc#1179344).
- PCI: host-generic: Support building as modules (bsc#1179344).
- PCI: Constify struct pci_ecam_ops (bsc#1179344).
- PCI: uniphier: Add Socionext UniPhier Pro5 PCIe endpoint controller driver (bsc#1179344).
- PCI: dwc: Use private data pointer of "struct irq_domain" to get pcie_port (bsc#1179344).
- PCI: dwc: pci-dra7xx: Use devm_platform_ioremap_resource_byname() (bsc#1179344).
- PCI: dwc: intel: Make intel_pcie_cpu_addr() static (bsc#1179344).
- PCI: dwc: Make hisi_pcie_platform_ops static (bsc#1179344).
- PCI: dwc: Clean up computing of msix_tbl (bsc#1179344).
- PCI: keystone: Don't select CONFIG_PCI_KEYSTONE_HOST by default (bsc#1179344).
- PCI: dra7xx: Don't select CONFIG_PCI_DRA7XX_HOST by default (bsc#1179344).
- PCI: keystone: Allow AM654 PCIe Endpoint to raise MSI-X interrupt (bsc#1179344).
- PCI: endpoint: Protect concurrent access to pci_epf_ops with mutex (bsc#1179344).
  Refresh:
  patches.suse/PCI-dwc-Fix-dw_pcie_ep_raise_msix_irq-to-get-correct.patch
- PCI: dwc: pci-dra7xx: Fix MSI IRQ handling (bsc#1179344).
- PCI: amlogic: Use AXG PCIE (bsc#1179344).
- PCI: uniphier: remove module code from built-in driver (bsc#1179344).
- PCI: qcom: Add support for SDM845 PCIe controller (bsc#1179344).
- PCI: artpec6: Configure FTS with dwc helper function (bsc#1179344).
- PCI: dwc: intel: PCIe RC controller driver (bsc#1179344).
- PCI: uniphier: Set mode register to host mode (bsc#1179344).
- PCI: amlogic: meson: Add support for G12A (bsc#1179344).
- PCI: amlogic: Fix reset assertion via gpio descriptor (bsc#1179344).
- PCI: armada8x: Propagate errors for optional PHYs (bsc#1179344).
- PCI: imx6: Limit DBI register length (bsc#1179344).
- PCI: kirin: Make structure kirin_dw_pcie_ops constant (bsc#1179344).
- PCI: dwc: al: Add Amazon Annapurna Labs PCIe controller driver (bsc#1179344).
- dt-bindings: PCI: Add Amazon's Annapurna Labs PCIe host bridge binding (bsc#1179344).
- commit 5b3f6b7
* Wed Dec  2 2020 mhocko@suse.com
- mm/userfaultfd: do not access vma->vm_mm after calling
  handle_userfault() (bsc#1179204).
- commit 6bb3d8f
* Wed Dec  2 2020 oneukum@suse.com
- crypto: sun4i-ss - add the A33 variant of SS (git-fixes).
- commit efe059b
* Wed Dec  2 2020 mkubecek@suse.cz
- Update kabi files.
- update to December 2020 maintenance update submission (commit 1069cd144905)
- commit 7054e5b
* Wed Dec  2 2020 nsaenzjulienne@suse.de
- supported.conf: Enable ledtrig-netdev (jsc#SLE-16874)
- commit ae02c2f
* Wed Dec  2 2020 nsaenzjulienne@suse.de
- i2c: brcmstb: Fix handling of optional interrupt
  (jsc#SLE-15318).
- i2c: brcmstb: Allow to compile it on BCM2835 (jsc#SLE-15318).
- supported.conf: Enable i2c-brcmstb
- i2c: brcmstb: Support BCM2711 HDMI BSC controllers
  (jsc#SLE-15318).
- commit 90fb88d
* Wed Dec  2 2020 mbrugger@suse.com
- arm64: mask PAC bits of __builtin_return_address (jsc#SLE-15188
  SLE-16566).
- arm64: Update config files. Enable HAVE_ARCH_COMPILER_H
- commit 3d9d4d8
* Wed Dec  2 2020 jslaby@suse.cz
- x86/kvm: Reserve KVM_FEATURE_MSI_EXT_DEST_ID (jsc#SLE-16823).
- PCI: MSI: Fix Kconfig dependencies for PCI_MSI_ARCH_FALLBACKS
  (jsc#SLE-16823).
- x86/apic/msi: Unbreak DMAR and HPET MSI (jsc#SLE-16823).
- iommu/amd: Remove domain search for PCI/MSI (jsc#SLE-16823).
- iommu/vt-d: Remove domain search for PCI/MSI (jsc#SLE-16823).
- x86/irq: Make most MSI ops XEN private (jsc#SLE-16823).
- x86/irq: Cleanup the arch_*_msi_irqs() leftovers
  (jsc#SLE-16823).
- PCI/MSI: Make arch_.*_msi_irq fallbacks selectable
  (jsc#SLE-16823).
- Update config files.
  PCI_MSI_ARCH_FALLBACKS is now auto-selected.
- x86/pci: Set default irq domain in pcibios_add_device()
  (jsc#SLE-16823).
- iommm/amd: Store irq domain in struct device (jsc#SLE-16823).
- iommm/vt-d: Store irq domain in struct device (jsc#SLE-16823).
- x86/xen: Wrap XEN MSI management into irqdomain (jsc#SLE-16823).
- irqdomain/msi: Allow to override msi_domain_alloc/free_irqs()
  (jsc#SLE-16823).
- x86/xen: Consolidate XEN-MSI init (jsc#SLE-16823).
- x86/xen: Rework MSI teardown (jsc#SLE-16823).
- x86/xen: Make xen_msi_init() static and rename it to
  xen_hvm_msi_init() (jsc#SLE-16823).
- PCI/MSI: Provide pci_dev_has_special_msi_domain() helper
  (jsc#SLE-16823).
- PCI_vmd_Mark_VMD_irqdomain_with_DOMAIN_BUS_VMD_MSI
  (jsc#SLE-16823).
- irqdomain/msi: Provide DOMAIN_BUS_VMD_MSI (jsc#SLE-16823).
- x86/irq: Initialize PCI/MSI domain at PCI init time
  (jsc#SLE-16823).
- Refresh
  patches.suse/x86-paravirt-allow-hypervisor-specific-vmmcall-handling-under-sev-es.
- x86/pci: Reducde #ifdeffery in PCI init code (jsc#SLE-16823).
- x86/irq: Move apic_post_init() invocation to one place
  (jsc#SLE-16823).
- x86/msi: Use generic MSI domain ops (jsc#SLE-16823).
- x86/msi: Consolidate MSI allocation (jsc#SLE-16823).
- PCI/MSI: Rework pci_msi_domain_calc_hwirq() (jsc#SLE-16823).
- x86/irq: Consolidate UV domain allocation (jsc#SLE-16823).
- x86/irq: Consolidate DMAR irq allocation (jsc#SLE-16823).
- x86_ioapic_Consolidate_IOAPIC_allocation (jsc#SLE-16823).
- x86/msi: Consolidate HPET allocation (jsc#SLE-16823).
- x86/irq: Prepare consolidation of irq_alloc_info
  (jsc#SLE-16823).
- iommu/irq_remapping: Consolidate irq domain lookup
  (jsc#SLE-16823).
- iommu/amd: Consolidate irq domain getter (jsc#SLE-16823).
- iommu/vt-d: Consolidate irq domain getter (jsc#SLE-16823).
- x86/irq: Add allocation type for parent domain retrieval
  (jsc#SLE-16823).
- x86_irq_Rename_X86_IRQ_ALLOC_TYPE_MSI_to_reflect_PCI_dependency
  (jsc#SLE-16823).
- x86/msi: Remove pointless vcpu_affinity callback
  (jsc#SLE-16823).
- x86/msi: Move compose message callback where it belongs
  (jsc#SLE-16823).
- genirq/chip: Use the first chip in irq_chip_compose_msi_msg()
  (jsc#SLE-16823).
- PCI: vmd: Dont abuse vector irqomain as parent (jsc#SLE-16823).
- x86/init: Remove unused init ops (jsc#SLE-16823).
- iommu/amd: Prevent NULL pointer dereference (jsc#SLE-16823).
- irqdomain: Export irq_domain_update_bus_token (jsc#SLE-16823).
- KVM: x86: Fixes posted interrupt check for IRQs delivery modes
  (jsc#SLE-16823).
- x86/apic/msi: Plug non-maskable MSI affinity race
  (jsc#SLE-16823).
- Refresh
  patches.suse/genirq-Add-protection-against-unsafe-usage-of-generi.patch.
- Refresh
  patches.suse/msft-hv-2119-irqdomain-treewide-Keep-firmware-node-unconditionall.patch.
- KVM: X86: Use APIC_DEST_* macros properly in
  kvm_lapic_irq.dest_mode (jsc#SLE-16823).
- commit 3ea20e1
* Wed Dec  2 2020 tbogendoerfer@suse.de
- gro_cells: reduce number of synchronize_net() calls
  (jsc#SLE-15075).
- net/mlx5e: Fix check if netdev is bond slave (jsc#SLE-15172).
- net/mlx5e: Fix refcount leak on kTLS RX resync (jsc#SLE-15172).
- mlxsw: Fix firmware flashing (bsc#1176447).
- qed: fix ILT configuration of SRC block (jsc#SLE-15143).
- net/tls: Fix wrong record sn in async mode of device resync
  (bsc#1176447).
- bnxt_en: Avoid unnecessary NVM_GET_DEV_INFO cmd error log on
  VFs (jsc#SLE-16649).
- bnxt_en: Fix counter overflow logic (jsc#SLE-15075).
- bnxt_en: Free port stats during firmware reset (jsc#SLE-15075).
- IB/hfi1: Fix error return code in hfi1_init_dd()
  (jsc#SLE-13208).
- RDMA/cm: Make the local_id_table xarray non-irq (jsc#SLE-15176).
- devlink: Avoid overwriting port attributes of registered port
  (bsc#1176447).
- ethtool: netlink: add missing netdev_features_change() call
  (bsc#1176447).
- tunnels: Fix off-by-one in lower MTU bounds for ICMP/ICMPv6
  replies (jsc#SLE-15172).
- net/mlx5e: Fix incorrect access of RCU-protected xdp_prog
  (jsc#SLE-15172).
- net/mlx5e: Fix VXLAN synchronization after function reload
  (jsc#SLE-15172).
- net/mlx5: E-switch, Avoid extack error log for disabled vport
  (jsc#SLE-15172).
- net/mlx5e: Use spin_lock_bh for async_icosq_lock
  (jsc#SLE-15172).
- xfrm: interface: fix the priorities for ipip and ipv6 tunnels
  (bsc#1176447).
- IB/srpt: docs: add a description for cq_size member
  (jsc#SLE-15176).
- net: protect tcf_block_unbind with block lock (bsc#1176447).
- sfc: move initialisation of efx->filter_sem to efx_init_struct()
  (jsc#SLE-16683).
- net/sched: act_gate: Unlock ->tcfa_lock in
  tc_setup_flow_action() (bsc#1176447).
- net/sched: act_ct: Fix adding udp port mangle operation
  (jsc#SLE-15172).
- nexthop: Fix performance regression in nexthop deletion
  (bsc#1176447).
- net: core: use list_del_init() instead of list_del() in
  netdev_run_todo() (bsc#1176447).
- ixgbe: fix probing of multi-port devices with one MDIO
  (jsc#SLE-13706).
- RDMA/qedr: Endianness warnings cleanup (jsc#SLE-15146).
- RDMA/hns: Fix configuration of ack_req_freq in QPC
  (jsc#SLE-14777).
- RDMA/hns: Add interception for resizing SRQs (jsc#SLE-14777).
- RDMA/mlx5: Remove dead check for EAGAIN after
  alloc_mr_from_cache() (jsc#SLE-15175).
- RDMA: Change XRCD destroy return value (jsc#SLE-15176).
- RDMA/rtrs-srv: Incorporate ib_register_client into rtrs server
  init (jsc#SLE-15176).
- mm/mmu_notifier: fix mmget() assert in
  __mmu_interval_notifier_insert (jsc#SLE-15176, jsc#SLE-16387).
- net: sched: Fix suspicious RCU usage while accessing
  tcf_tunnel_info (jsc#SLE-15075).
- xsk: Fix a documentation mistake in xsk_queue.h (jsc#SLE-13706).
- net/mlx5e: IPsec: Use kvfree() for memory allocated with
  kvzalloc() (jsc#SLE-15172).
- net/mlx5e: TC: Remove unused parameter from
  mlx5_tc_ct_add_no_trk_match() (jsc#SLE-15172).
- net/mlx5: E-Switch, Use vport metadata matching by default
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Setup all vports' metadata to support peer
  miss rule (jsc#SLE-15172).
- net/mlx5: E-Switch, Dedicated metadata for uplink vport
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Check and enable metadata support flag
  before using (jsc#SLE-15172).
- net/mlx5: Fix uninitialized variable warning (jsc#SLE-15172).
- sfc: don't double-down() filters in ef100_reset()
  (jsc#SLE-16683).
- commit e4545a1
* Wed Dec  2 2020 wqu@suse.com
- btrfs: qgroup: don't commit transaction when we already hold
  the handle (bsc#1178634).
- commit a88c82a
* Wed Dec  2 2020 glin@suse.com
- ftrace: Fix DYNAMIC_FTRACE_WITH_DIRECT_CALLS dependency
  (bsc#1177028).
- selftests/bpf: Fix error return code in run_getsockopt_test()
  (bsc#1177028).
- selftests/bpf: Add selftest for multi-prog sections and
  bpf-to-bpf calls (bsc#1177028).
- commit f0d11f0
* Wed Dec  2 2020 pjakobsson@suse.de
- Delete
  patches.suse/1239-media-cec-gpio-handle-gpiod_get_value-errors-correct.patch.
- commit 7b24ba3
* Tue Dec  1 2020 ailiop@suse.com
- xfs: prohibit fs freezing when using empty transactions
  (bsc#1179442).
- commit e04335b
* Tue Dec  1 2020 mcgrof@suse.com
- patches.suse/nvme-force-complete-cancelled-requests.patch:
  (bsc#1175995,bsc#1178756,jsc#SLE-15608).
  Without this we can end up with a series of nvme QID timeouts,
  regardless of filesystem when fstests is used or any error injection
  mechanism is used. Without this fix, we end up with 9 failures on xfs,
  but due to its generic nature, will likely end up with other failures
  on other filesystems. This does not allow a clean slate reliable
  fstests run. This fixes that issue.
  Through code inspection I found these changes were already present
  on SLE15-SP3 but not on SLE15-SP2.
- commit 9b6b1bb
* Tue Dec  1 2020 mcgrof@suse.com
- patches.suse/blk-mq-blk-mq-provide-forced-completion-method.patch:
  (bsc#1175995,jsc#SLE-15608,bsc#1178756).
- commit 88f0b07
* Tue Dec  1 2020 nsaenzjulienne@suse.de
- drm/vc4: kms: Don't disable the muxing of an active CRTC
  (jsc#SLE-15318).
- commit 39c97fe
* Tue Dec  1 2020 nsaenzjulienne@suse.de
- drm/vc4: kms: Store the unassigned channel list in the state
  (jsc#SLE-15318).
- drm/vc4: hdmi: Disable Wifi Frequencies (jsc#SLE-15318).
- drm/vc4: kms: Document the muxing corner cases (jsc#SLE-15318).
- drm/vc4: kms: Split the HVS muxing check in a separate function
  (jsc#SLE-15318).
- drm/vc4: kms: Rename NUM_CHANNELS (jsc#SLE-15318).
- drm/vc4: kms: Remove useless define (jsc#SLE-15318).
- drm/vc4: kms: Switch to drmm_add_action_or_reset
  (jsc#SLE-15318).
- drm/vc4: hdmi: Block odd horizontal timings (jsc#SLE-15318).
- drm/vc4: hdmi: Make sure our clock rate is within limits
  (jsc#SLE-15318).
- commit c55f585
* Tue Dec  1 2020 jlee@suse.com
- Documentation: x86: fix boot.rst warning and format
  (jsc#SLE-16407).
- x86/boot: Mark global variables as static (jsc#SLE-16407).
- commit f3aa594
* Tue Dec  1 2020 pjakobsson@suse.de
- drm/vc4: drv: Remove unused variable (jsc#SLE-15318).
- drm/vc4: kms: Add functions to create the state objects
  (jsc#SLE-15318).
- drm/vc4: Use devm_drm_dev_alloc (jsc#SLE-15318).
- drm/vc4: Use the helper to retrieve vc4_dev when needed
  (jsc#SLE-15318).
- drm/vc4: gem: Add a managed action to cleanup the job queue
  (jsc#SLE-15318).
- drm/vc4: drv: Use managed drm_mode_config_init (jsc#SLE-15318).
- drm/vc4: bo: Add a managed action to cleanup the cache
  (jsc#SLE-15318).
- drm/vc4: Rework the structure conversion functions
  (jsc#SLE-15318).
- drm/vc4: hdmi: Add a name to the codec DAI component
  (jsc#SLE-15318).
- drm/vc4: hdmi: Avoid sleeping in atomic context (jsc#SLE-15318).
- drm/vc4: drv: Add error handding for bind (jsc#SLE-15318).
- drm/vc4: crtc: Keep the previously assigned HVS FIFO
  (jsc#SLE-15318).
- drm/vc4: crtc: Rework a bit the CRTC state code (jsc#SLE-15318).
- drm/vc4: kms: Assign a FIFO to enabled CRTCs instead of active
  (jsc#SLE-15318).
- drm/vc4: hvs: Pull the state of all the CRTCs prior to PV muxing
  (jsc#SLE-15318).
- drm/vc4: Handing the return value of drm_universal_plane_init
  (jsc#SLE-15318).
- drm/vc4: Fix bitwise OR versus ternary operator in
  vc4_plane_mode_set (jsc#SLE-15318).
- drm/vc4: Update type of reg parameter in vc4_hdmi_{read,write}
  (jsc#SLE-15318).
- drm/vc4: hdmi: Fix NULL vs IS_ERR() checks in (jsc#SLE-15318).
- drm/vc4: hdmi: Fix off by ones in vc4_hdmi_read/write()
  (jsc#SLE-15318).
- drm/vc4: drv: Support BCM2711 (jsc#SLE-15318).
- drm/vc4: hdmi: Support the BCM2711 HDMI controllers
  (jsc#SLE-15318).
- drm/vc4: hdmi: Add pixel BVB clock control (jsc#SLE-15318).
- drm/vc4: hdmi: Switch to blank pixels when disabled
  (jsc#SLE-15318).
- drm/vc4: hdmi: Do the VID_CTL configuration at once
  (jsc#SLE-15318).
- drm/vc4: hdmi: Implement finer-grained hooks (jsc#SLE-15318).
- drm/vc4: hdmi: Always recenter the HDMI FIFO (jsc#SLE-15318).
- drm/vc4: hdmi: Remove register dumps in enable (jsc#SLE-15318).
- drm/vc4: hdmi: Deal with multiple ALSA cards (jsc#SLE-15318).
- drm/vc4: hdmi: Add audio-related callbacks (jsc#SLE-15318).
- drm/vc4: hdmi: Set the b-frame marker to the match ALSA's
  default (jsc#SLE-15318).
- drm/vc4: hdmi: Reset audio infoframe on encoder_enable if
  previously (jsc#SLE-15318).
- drm/vc4: hdmi: Use reg-names to retrieve the HDMI audio
  registers (jsc#SLE-15318).
- drm/vc4: hdmi: Use clk_set_min_rate instead (jsc#SLE-15318).
- drm/vc4: hdmi: Adjust HSM clock rate depending on pixel rate
  (jsc#SLE-15318).
- drm/vc4: hdmi: Rename drm_encoder pointer in mode_valid
  (jsc#SLE-15318).
- drm/vc4: hdmi: Remove unused CEC_CLOCK_DIV define
  (jsc#SLE-15318).
- drm/vc4: hdmi: Add CEC support flag (jsc#SLE-15318).
- drm/vc4: hdmi: Move CEC init to its own function
  (jsc#SLE-15318).
- drm/vc4: hdmi: Deal with multiple debugfs files (jsc#SLE-15318).
- drm/vc4: hdmi: Store the encoder type in the variant structure
  (jsc#SLE-15318).
- drm/vc4: hdmi: Add a set_timings callback (jsc#SLE-15318).
- drm/vc4: hdmi: Add a CSC setup callback (jsc#SLE-15318).
- drm/vc4: hdmi: Add PHY RNG enable / disable function
  (jsc#SLE-15318).
- drm/vc4: hdmi: Add PHY init and disable function
  (jsc#SLE-15318).
- drm/vc4: hdmi: Add reset callback (jsc#SLE-15318).
- drm/vc4: hdmi: Implement a register layout abstraction
  (jsc#SLE-15318).
- drm/vc4: hdmi: Introduce resource init and variant
  (jsc#SLE-15318).
- drm/vc4: hdmi: Remove vc4_hdmi_connector (jsc#SLE-15318).
- drm/vc4: hdmi: Remove vc4_dev hdmi pointer (jsc#SLE-15318).
- drm/vc4: hdmi: Retrieve the vc4_hdmi at unbind using our device
  (jsc#SLE-15318).
- drm/vc4: hdmi: Pass vc4_hdmi to CEC code (jsc#SLE-15318).
- drm/vc4: hdmi: Add container_of macros for encoders and
  connectors (jsc#SLE-15318).
- drm/vc4: hdmi: Use local vc4_hdmi directly (jsc#SLE-15318).
- drm/vc4: hdmi: Move accessors to vc4_hdmi (jsc#SLE-15318).
- drm/vc4: hdmi: Rename hdmi to vc4_hdmi (jsc#SLE-15318).
- drm/vc4: hdmi: Remove DDC argument to connector_init
  (jsc#SLE-15318).
- drm/vc4: hdmi: rework connectors and encoders (jsc#SLE-15318).
- drm/vc4: hdmi: Move structure to header (jsc#SLE-15318).
- drm/vc4: hdmi: Use debugfs private field (jsc#SLE-15318).
- drm/vc4: crtc: Add BCM2711 pixelvalves (jsc#SLE-15318).
- drm/vc4: drv: Disable the CRTC at boot time (jsc#SLE-15318).
- drm/vc4: crtc: Move the CRTC disable out (jsc#SLE-15318).
- drm/vc4: hvs: Introduce a function to get the assigned FIFO
  (jsc#SLE-15318).
- drm/vc4: hvs: Make the stop_channel function public
  (jsc#SLE-15318).
- drm/vc4: crtc: Clear the PixelValve FIFO during configuration
  (jsc#SLE-15318).
- drm/vc4: crtc: Clear the PixelValve FIFO on disable
  (jsc#SLE-15318).
- drm/vc4: crtc: Add a delay after disabling the PixelValve output
  (jsc#SLE-15318).
- drm/vc4: encoder: Add finer-grained encoder callbacks
  (jsc#SLE-15318).
- drm/vc4: crtc: Move HVS channel init before the PV
  initialisation (jsc#SLE-15318).
- drm/vc4: crtc: Remove redundant pixelvalve reset
  (jsc#SLE-15318).
- drm/vc4: crtc: Remove mode_set_nofb (jsc#SLE-15318).
- drm/vc4: hvs: Make sure our channel is reset (jsc#SLE-15318).
- drm/vc4: crtc: Move the HVS gamma LUT setup to our init function
  (jsc#SLE-15318).
- drm/vc4: crtc: Move HVS init and close to a function
  (jsc#SLE-15318).
- drm/vc4: crtc: Move PV dump to config_pv (jsc#SLE-15318).
- drm/vc4: crtc: Turn pixelvalve reset into a function
  (jsc#SLE-15318).
- drm/vc4: crtc: Disable color management for HVS5
  (jsc#SLE-15318).
- drm/vc4: crtc: Add HDMI1 encoder type (jsc#SLE-15318).
- drm/vc4: crtc: Rename HDMI encoder type to HDMI0
  (jsc#SLE-15318).
- drm/vc4: crtc: Add function to compute FIFO level bits
  (jsc#SLE-15318).
- drm/vc4: crtc: Add FIFO depth to vc4_crtc_data (jsc#SLE-15318).
- drm/vc4: crtc: Assign output to channel automatically
  (jsc#SLE-15318).
- drm/vc4: kms: Convert to for_each_new_crtc_state
  (jsc#SLE-15318).
- drm/vc4: crtc: Enable and disable the PV in atomic_enable /
  disable (jsc#SLE-15318).
- drm/vc4: crtc: Use local chan variable (jsc#SLE-15318).
- drm/vc4: crtc: Rename HVS channel to output (jsc#SLE-15318).
- drm/vc4: crtc: Move the cob allocation outside of bind
  (jsc#SLE-15318).
- drm/vc4: crtc: Use a shared interrupt (jsc#SLE-15318).
- drm/vc4: crtc: Deal with different number of pixel per clock
  (jsc#SLE-15318).
- drm/vc4: plane: Create more planes (jsc#SLE-15318).
- drm/vc4: plane: Optimize the LBM allocation size
  (jsc#SLE-15318).
- drm/vc4: plane: Change LBM alignment constraint on LBM
  (jsc#SLE-15318).
- drm/vc4: hvs: Boost the core clock during modeset
  (jsc#SLE-15318).
- drm/vc4: Add support for the BCM2711 HVS5 (jsc#SLE-15318).
- commit 1c47402
* Tue Dec  1 2020 mhocko@suse.com
- HMAT: Skip publishing target info for nodes with no online
  memory (bsc#1178660).
- HMAT: Register memory-side cache after parsing (bsc#1178660).
- commit c10070c
* Tue Dec  1 2020 wqu@suse.com
- btrfs: allow btrfs_truncate_block() to fallback to nocow for
  data space reservation (bsc#1161099).
- commit 9a9387d
* Tue Dec  1 2020 msuchanek@suse.de
- rpm/kernel-{source,binary}.spec: do not include ghost symlinks
  (boo#1179082).
- commit 76a9256
* Tue Dec  1 2020 mbrugger@suse.com
- PCI: hip: Add handling of HiSilicon HIP PCIe controller errors
  (jsc#SLE-16612 jsc#SLE-14766).
- Update config files. Enable PCIE_HISI_ERR.
- commit f5b42fa
* Tue Dec  1 2020 msuchanek@suse.de
- tpm: of: Handle IBM,vtpm20 case when getting log parameters
  (jsc#SLE-13630 bsc#1179446 ltc#190030).
- commit 96f9f02
* Tue Dec  1 2020 mbrugger@suse.com
- ACPI / APEI: Add a notifier chain for unknown (vendor) CPER
  records (jsc#SLE-16612 jsc#SLE-14766).
- commit 993ea8f
* Tue Dec  1 2020 msuchanek@suse.de
- config.conf: Remove vanilla config (jsc#SLE-17122).
- Delete config/arm64/vanilla.
- Delete config/ppc64le/vanilla.
- Delete config/s390x/vanilla.
- Delete config/x86_64/vanilla.
- commit 508c5d7
* Tue Dec  1 2020 pmladek@suse.com
- blacklist.conf: Remove duplicate entry (git-fixes)
- commit 9169068
* Tue Dec  1 2020 tbogendoerfer@suse.de
- devlink: Make sure devlink instance and port are in same net
  namespace (bsc#1154353).
- net: ena: fix packet's addresses for rx_offset feature
  (bsc#1174852).
- net: ena: handle bad request id in ena_netdev (bsc#1174852).
- RDMA/hns: Fix retry_cnt and rnr_cnt when querying QP
  (jsc#SLE-8449).
- RDMA/hns: Fix wrong field of SRQ number the device supports
  (jsc#SLE-8449).
- commit e8d7cf3
* Tue Dec  1 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/mm-gup-allow-FOLL_FORCE-for-get_user_pages_fast.patch
  patches.suse/mm-ksm-fix-NULL-pointer-dereference-when-KSM-zero-page-is-enabled.patch
  patches.suse/mm-mempolicy-require-at-least-one-nodeid-for-MPOL_PREFERRED.patch
  patches.suse/mm-swap-make-page_evictable-inline.patch
  patches.suse/mm-swap-use-smp_mb__after_atomic-to-order-LRU-bit-set.patch
- commit 6289c65
* Tue Dec  1 2020 jlee@suse.com
- efi/x86: Use symbolic constants in PE header instead of bare
  numbers (jsc#SLE-16407).
- commit 1efd668
* Tue Dec  1 2020 mhocko@suse.com
- Update
  patches.suse/mm-mmap-c-close-race-between-munmap-and-expand_upwards-downwards.patch
  (bsc#1174527, bsc#1179432, CVE-2020-29369).
- commit f55babe
* Tue Dec  1 2020 jlee@suse.com
- efi/x86: Setup stack correctly for efi_pe_entry (jsc#SLE-16407).
- tpm: check event log version before reading final events
  (jsc#SLE-16407).
- efi: Pull up arch-specific prototype efi_systab_show_arch()
  (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
- efi: cper: Add support for printing Firmware Error Record
  Reference (jsc#SLE-16407).
- efi/libstub/x86: Avoid EFI map buffer alloc in allocate_e820()
  (jsc#SLE-16407).
- efi/earlycon: Fix early printk for wider fonts (jsc#SLE-16407).
- efi/libstub: Avoid returning uninitialized data from
  setup_graphics() (jsc#SLE-16407).
- gcc-10: mark more functions __init to avoid section mismatch
  warnings (jsc#SLE-16407).
- efi/x86: Revert struct layout change to fix kexec boot
  regression (jsc#SLE-16407).
- efi/libstub/file: Merge file name buffers to reduce stack usage
  (jsc#SLE-16407).
- efi/x86: Always relocate the kernel for EFI handover entry
  (jsc#SLE-16407).
- efi/x86: Move efi stub globals from .bss to .data
  (jsc#SLE-16407).
- efi/libstub/x86: Remove redundant assignment to pointer hdr
  (jsc#SLE-16407).
- efi/cper: Use scnprintf() for avoiding potential buffer overflow
  (jsc#SLE-16407).
- arm64: remove CONFIG_DEBUG_ALIGN_RODATA feature (jsc#SLE-16407).
- x86/efi: Add a prototype for efi_arch_mem_reserve()
  (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
- x86/*/Makefile: Use -fno-asynchronous-unwind-tables to suppress
  .eh_frame sections (jsc#SLE-16407).
  Refresh
  patches.suse/0001-efi-generalize-efi_get_secureboot.patch
  patches.suse/x86-boot-compressed-64-setup-a-ghcb-based-vc-exception-handler
- efi/libstub/arm: Fix spurious message that an initrd was loaded
  (jsc#SLE-16407).
- efi/libstub/arm64: Avoid image_base value from efi_loaded_image
  (jsc#SLE-16407).
- efi/x86: Fix cast of image argument (jsc#SLE-16407).
- efi/libstub/x86: Use ULONG_MAX as upper bound for all
  allocations (jsc#SLE-16407).
- efi: Fix a mistype in comments mentioning
  efivar_entry_iter_begin() (jsc#SLE-16407).
- efi/libstub: Avoid linking libstub/lib-ksyms.o into vmlinux
  (jsc#SLE-16407).
- efi/x86: Preserve %%ebx correctly in
  efi_set_virtual_address_map() (jsc#SLE-16407).
- efi/x86: Don't relocate the kernel unless necessary
  (jsc#SLE-16407).
- efi/x86: Remove extra headroom for setup block (jsc#SLE-16407).
  Refresh
  patches.suse/efi-x86-Remove-extra-headroom-for-setup-block.patch
- efi/x86: Add kernel preferred address to PE header
  (jsc#SLE-16407).
- efi/x86: Decompress at start of PE image load address
  (jsc#SLE-16407).
  Refresh
  patches.suse/x86-boot-compressed-64-add-idt-infrastructure
- x86/boot/compressed/32: Save the output address instead of
  recalculating it (jsc#SLE-16407).
- efi/libstub/x86: Deal with exit() boot service returning
  (jsc#SLE-16407).
- x86/boot: Use unsigned comparison for addresses (jsc#SLE-16407).
- efi/x86: Avoid using code32_start (jsc#SLE-16407).
- efi/x86: Make efi32_pe_entry() more readable (jsc#SLE-16407).
- efi/x86: Respect 32-bit ABI in efi32_pe_entry() (jsc#SLE-16407).
- efi/x86: Annotate the LOADED_IMAGE_PROTOCOL_GUID with SYM_DATA
  (jsc#SLE-16407).
- efi/arm64: Clean EFI stub exit code from cache instead of
  avoiding it (jsc#SLE-16407).
- efi: Don't shadow 'i' in efi_config_parse_tables()
  (jsc#SLE-16407).
- efi/x86: Add RNG seed EFI table to unencrypted mapping check
  (jsc#SLE-16407).
- efi/libstub: Introduce symbolic constants for the stub
  major/minor version (jsc#SLE-16407).
- efi/x86: Add true mixed mode entry point into .compat section
  (jsc#SLE-16407).
- efi/x86: Drop redundant .bss section (jsc#SLE-16407).
- efi/x86: add headroom to decompressor BSS to account for setup
  block (jsc#SLE-16407).
- ocfs2/dlm: move BITS_TO_BYTES() to bitops.h for wider use
  (jsc#SLE-16407).
- x86/boot: Simplify calculation of output address
  (jsc#SLE-16407).
- x86/boot/compressed: Relax sed symbol type regex for LLVM ld.lld
  (jsc#SLE-16407).
- arch/x86/boot: Use prefix map to avoid embedded paths
  (jsc#SLE-16407).
  Refresh
  modified:   patches.suse/0001-efi-generalize-efi_get_secureboot.patch
  modified:   patches.suse/x86-boot-compressed-64-setup-a-ghcb-based-vc-exception-handler
- x86/boot: Introduce kernel_info (jsc#SLE-16407).
- commit 62d114b
* Mon Nov 30 2020 tiwai@suse.de
- romfs: fix uninitialized memory leak in romfs_dev_read()
  (CVE-2020-29371 bsc#1179429).
- commit aaf36e7
* Mon Nov 30 2020 jack@suse.cz
- patches.suse/block-Fix-use-after-free-in-blkdev_get.patch: Update tags
  (bsc#1173834 bsc#1179141 CVE-2020-15436).
- commit 6c1fbdb
* Mon Nov 30 2020 aaptel@suse.com
- cifs: Return the error from crypt_message when enc/dec key
  not found (bsc#1179426).
- commit b7a0fce
* Mon Nov 30 2020 aaptel@suse.com
- Convert trailing spaces and periods in path components
  (bsc#1179424).
- commit 88891c3
* Mon Nov 30 2020 aaptel@suse.com
- cifs: remove bogus debug code (bsc#1179427).
- commit 8a0ced9
* Mon Nov 30 2020 msuchanek@suse.de
- ibmvnic: reduce wait for completion time (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: no reset timeout for 5 seconds after reset
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: send_login should check for crq errors (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: track pending login (jsc#SLE-17043 bsc#1179243
  ltc#189290).
- ibmvnic: stop free_all_rwi on failed reset (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- Refresh patches.suse/ibmvnic-restore-adapter-state-on-failed-reset.patch.
- ibmvnic: handle inconsistent login with reset (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: reduce wait for completion time (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: no reset timeout for 5 seconds after reset
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: send_login should check for crq errors (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: track pending login (jsc#SLE-17043 bsc#1179243
  ltc#189290).
- ibmvnic: delay next reset if hard reset fails (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: restore adapter state on failed reset (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: avoid memset null scrq msgs (jsc#SLE-17043 bsc#1179243
  ltc#189290).
  - Refresh patches.suse/ibmvnic-Introduce-indirect-subordinate-Command-Respo.patch
- ibmvnic: stop free_all_rwi on failed reset (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: handle inconsistent login with reset (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- commit ce6d916
* Mon Nov 30 2020 pmladek@suse.com
- blacklist.conf: printk: cosmetic; documentation
- commit 609fe64
* Mon Nov 30 2020 pmladek@suse.com
- blacklist.conf: printk: just a preparation step for lockless ringbuffer.
- commit 8515274
* Mon Nov 30 2020 ohering@suse.de
- scripts/lib/SUSE/MyBS.pm: properly close prjconf Macros: section
- commit 965157e
* Mon Nov 30 2020 jlee@suse.com
- efi/arm: Rewrite FDT param discovery routines (jsc#SLE-16407).
- efi/arm: Move FDT specific definitions into fdtparams.c
  (jsc#SLE-16407).
- efi/arm: Move FDT param discovery code out of efi.c
  (jsc#SLE-16407).
  Refresh
  patches.suse/efi-Use-more-granular-check-for-availability-for-var.patch
- efi/x86: Implement mixed mode boot without the handover protocol
  (jsc#SLE-16407).
  Refresh
  patches.suse/x86-boot-compressed-64-add-idt-infrastructure
- efi/libstub/x86: Use Exit() boot service to exit the stub on
  errors (jsc#SLE-16407).
- efi/libstub/x86: Make loaded_image protocol handling mixed
  mode safe (jsc#SLE-16407).
- efi/x86: Drop 'systab' member from struct efi (jsc#SLE-16407).
  Refresh
  patches.suse/efi-Store-mask-of-supported-runtime-services-in-stru.patch
- efi/arm: Drop unnecessary references to efi.systab
  (jsc#SLE-16407).
- efi: Add 'runtime' pointer to struct efi (jsc#SLE-16407).
  Refresh
  patches.suse/efi-Store-mask-of-supported-runtime-services-in-stru.patch
- efi/x86: Merge assignments of efi.runtime_version
  (jsc#SLE-16407).
- efi/x86: Make fw_vendor, config_table and runtime sysfs nodes
  x86 specific (jsc#SLE-16407).
- efi/x86: Remove runtime table address from kexec EFI setup data
  (jsc#SLE-16407).
- efi: Clean up config_parse_tables() (jsc#SLE-16407).
- efi: Make efi_config_init() x86 only (jsc#SLE-16407).
- efi/ia64: Switch to efi_config_parse_tables() (jsc#SLE-16407).
- efi/ia64: Use existing helpers to locate ESI table
  (jsc#SLE-16407).
- efi: Merge EFI system table revision and vendor checks
  (jsc#SLE-16407).
  Refresh
  patches.suse/efi-Add-support-for-EFI_RT_PROPERTIES-table-fe4db90a.patch
- efi: Make memreserve table handling local to efi.c
  (jsc#SLE-16407).
  Refresh
  patches.suse/efi-Add-support-for-EFI_RT_PROPERTIES-table-fe4db90a.patch
- efi: Move mem_attr_table out of struct efi (jsc#SLE-16407).
- efi: Make rng_seed table handling local to efi.c
  (jsc#SLE-16407).
  Refresh
  patches.suse/efi-Add-support-for-EFI_RT_PROPERTIES-table-fe4db90a.patch
- efi: Move UGA and PROP table handling to x86 code
  (jsc#SLE-16407).
- efi/ia64: Move HCDP and MPS table handling into IA64 arch code
  (jsc#SLE-16407).
  Refresh
  patches.suse/efi-Store-mask-of-supported-runtime-services-in-stru.patch
- efi: Drop handling of 'boot_info' configuration table
  (jsc#SLE-16407).
- efi/libstub: Take noinitrd cmdline argument into account for
  devpath initrd (jsc#SLE-16407).
- efi/libstub: Add support for loading the initrd from a device
  path (jsc#SLE-16407).
- efi/dev-path-parser: Add struct definition for vendor type
  device path nodes (jsc#SLE-16407).
- efi/x86: Replace #ifdefs with IS_ENABLED() checks
  (jsc#SLE-16407).
- efi/x86: Reindent struct initializer for legibility
  (jsc#SLE-16407).
- efi/capsule-loader: Drop superfluous assignment (jsc#SLE-16407).
- efi/esrt: Clean up efi_esrt_init (jsc#SLE-16407).
- efi/libstub: Fix error message in handle_cmdline_files()
  (jsc#SLE-16407).
- efi/libstub: Describe RNG functions (jsc#SLE-16407).
- efi/libstub: Describe efi_relocate_kernel() (jsc#SLE-16407).
- efi/libstub: Describe memory functions (jsc#SLE-16407).
- efi/libstub: Simplify efi_get_memory_map() (jsc#SLE-16407).
- efi/libstub: Add function description of efi_allocate_pages()
  (jsc#SLE-16407).
- efi/libstub: Make the LoadFile EFI protocol accessible
  (jsc#SLE-16407).
  Refresh
  patches.suse/efi-Add-support-for-EFI_RT_PROPERTIES-table-fe4db90a.patch
- efi/libstub: Expose LocateDevicePath boot service
  (jsc#SLE-16407).
- efi/libstub: Clean up command line parsing routine
  (jsc#SLE-16407).
- efi/libstub: Take soft and hard memory limits into account
  for initrd loading (jsc#SLE-16407).
- efi: ia64: move SAL systab handling out of generic EFI code
  (jsc#SLE-16407).
- commit 2edf905
* Mon Nov 30 2020 nmoreychaisemartin@suse.com
- RDMA/core: Free DIM memory in error unwind (bsc#1152489)
- commit 21b1eaa
* Mon Nov 30 2020 nmoreychaisemartin@suse.com
- RDMA/core: Stop DIM before destroying CQ (bsc#1152489)
- commit 5bb1399
* Mon Nov 30 2020 ohering@suse.de
- video: hyperv_fb: Fix the cache type when mapping the VRAM (git-fixes).
- commit 1b3b221
* Mon Nov 30 2020 ohering@suse.de
- hv_balloon: disable warning when floor reached (git-fixes).
- commit 09540b9
* Mon Nov 30 2020 mgorman@suse.de
- mm/ksm: fix NULL pointer dereference when KSM zero page is
  enabled (git fixes (mm/ksm)).
- commit d498a49
* Mon Nov 30 2020 mgorman@suse.de
- mm: mempolicy: require at least one nodeid for MPOL_PREFERRED
  (git fixes (mm/mempolicy)).
- commit 82f5309
* Mon Nov 30 2020 mgorman@suse.de
- mm: swap: use smp_mb__after_atomic() to order LRU bit set
  (git fixes (mm/vmscan)).
- mm: swap: make page_evictable() inline (git fixes (mm/vmscan)).
- commit b3e8c49
* Mon Nov 30 2020 yousaf.kaukab@suse.com
- drivers: provide devm_platform_ioremap_resource_byname() (bsc#1179344).
- drivers: platform: provide devm_platform_ioremap_resource_wc() (bsc#1179344).
  Refresh:
  patches.suse/drivers-provide-devm_platform_get_and_ioremap_resource.patch
- lib: devres: provide devm_ioremap_resource_wc() (bsc#1179344).
- lib: devres: prepare devm_ioremap_resource() for more variants (bsc#1179344).
- commit 114fca9
* Mon Nov 30 2020 mgorman@suse.de
- blacklist.conf: KASAN is not enabled
- commit b3c7026
* Mon Nov 30 2020 nsaenzjulienne@suse.de
- spi: imx: fix the unbalanced spi runtime pm management
  (git-fixes).
- commit 1856d10
* Mon Nov 30 2020 mgorman@suse.de
- blacklist.conf: Supported arches enable SPARSEMEM_VMEMMAP
- commit 928fb30
* Mon Nov 30 2020 mgorman@suse.de
- mm/gup: allow FOLL_FORCE for get_user_pages_fast() (git fixes
  (mm/gup)).
- commit b4797b5
* Mon Nov 30 2020 mgorman@suse.de
- blacklist.conf: GUP benchmark not enabled in Kconfig
- commit d60c94e
* Mon Nov 30 2020 mgorman@suse.de
- mm/truncate.c: make __invalidate_mapping_pages() static (git
  fixes (mm/truncate)).
- commit 94f313f
* Mon Nov 30 2020 msuchanek@suse.de
- powerpc/test_emulate_step: Move extern declaration to sstep.h
  (jsc#SLE-13830 bsc#1179396 ltc#185738).
- powerpc/sstep: Introduce macros to retrieve Prefix instruction
  operands (jsc#SLE-13830 bsc#1179396 ltc#185738).
- powerpc/test_emulate_step: Add negative tests for prefixed addi
  (jsc#SLE-13830 bsc#1179396 ltc#185738).
- powerpc/test_emulate_step: Enhancement to test negative
  scenarios (jsc#SLE-13830 bsc#1179396 ltc#185738).
- commit ad5913e
* Mon Nov 30 2020 jlee@suse.com
- efi/libstub: Fix path separator regression (jsc#SLE-16407).
- lib/string: Make memzero_explicit() inline instead of external
  (jsc#SLE-16407).
- commit 6fa3e5e
* Mon Nov 30 2020 tiwai@suse.de
- efi/x86: Fix the deletion of variables in mixed mode
  (git-fixes).
- commit dd05038
* Mon Nov 30 2020 tiwai@suse.de
- efi: EFI_EARLYCON should depend on EFI (git-fixes).
- efivarfs: revert "fix memory leak in efivarfs_create()"
  (git-fixes).
- efi/efivars: Set generic ops before loading SSDT (git-fixes).
- efi/x86: Free efi_pgd with free_pages() (git-fixes).
- efi: efibc: check for efivars write capability (git-fixes).
- efi: add missed destroy_workqueue when efisubsys_init fails
  (git-fixes).
- efi: provide empty efi_enter_virtual_mode implementation
  (git-fixes).
- efi/esrt: Fix reference count leak in esre_create_sysfs_entry
  (git-fixes).
- efi/libstub/x86: Work around LLVM ELF quirk build regression
  (git-fixes).
- efi/x86: Ignore the memory attributes table on i386 (git-fixes).
- efi/x86: Handle by-ref arguments covering multiple pages in
  mixed mode (git-fixes).
- efi/x86: Align GUIDs to their size in the mixed mode runtime
  wrapper (git-fixes).
- efi/x86: Don't panic or BUG() on non-critical error conditions
  (git-fixes).
- efi/x86: Map the entire EFI vendor string before copying it
  (git-fixes).
- commit aaf9d90
* Mon Nov 30 2020 pvorel@suse.cz
- Refresh patches.suse/loop-fix-occasional-uevent-drop.patch (bsc#1177971)
  Add Git-commit: and Patch-mainline: tags (patch got into mainline).
- commit a78af51
* Mon Nov 30 2020 pvorel@suse.cz
- Refresh
  patches.suse/block-add-a-return-value-to-set_capacity_revalidate_and_notify.patch.
  (bsc#1177971)
  Add Git-commit: and Patch-mainline: tags (patch got into mainline).
- commit cf636f0
* Mon Nov 30 2020 jlee@suse.com
- crypto: n2 - Rename arrays to avoid conflict with
  crypto/sha256.h (jsc#SLE-16407).
- crypto: ccree - Rename arrays to avoid conflict with
  crypto/sha256.h (jsc#SLE-16407).
- crypto: s390 - Rename functions to avoid conflict with
  crypto/sha256.h (jsc#SLE-16407).
- crypto: arm64 - Rename functions to avoid conflict with
  crypto/sha256.h (jsc#SLE-16407).
- crypto: arm - Rename functions to avoid conflict with
  crypto/sha256.h (jsc#SLE-16407).
- commit c1688be
* Sun Nov 29 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/s390-cpum_sf-c-fix-file-permission-for-cpum_sfb_size
  patches.suse/s390-dasd-fix-null-pointer-dereference-for-erp-requests
  patches.suse/s390-pkey-fix-paes-selftest-failure-with-paes-and-pkey-static-build
- commit c3e5681
* Sun Nov 29 2020 tiwai@suse.de
- USB: core: Change %%pK for __user pointers to %%px (git-fixes).
- USB: core: Fix regression in Hercules audio card (git-fixes).
- usb: gadget: Fix memleak in gadgetfs_fill_super (git-fixes).
- usb: gadget: f_midi: Fix memleak in f_midi_alloc (git-fixes).
- commit ae495c3
* Sun Nov 29 2020 jlee@suse.com
- crypto: x86 - Rename functions to avoid conflict with
  crypto/sha256.h (jsc#SLE-16407).
- commit 2c4f35b
* Sun Nov 29 2020 jlee@suse.com
- crypto: sha256 - Fix some coding style issues (jsc#SLE-16407).
- commit 07ac84d
* Sun Nov 29 2020 jlee@suse.com
- crypto: sha256 - Remove sha256/224_init code duplication
  (jsc#SLE-16407).
- crypto: sha256 - Merge crypto/sha256.h into crypto/sha.h
  (jsc#SLE-16407).
- crypto: sha256 - Add missing MODULE_LICENSE() to
  lib/crypto/sha256.c (jsc#SLE-16407).
- crypto: sha256_generic - Switch to the generic
  lib/crypto/sha256.c lib code (jsc#SLE-16407).
- crypto: sha256 - Add sha224 support to sha256 library code
  (jsc#SLE-16407).
- crypto: sha256 - Make lib/crypto/sha256.c suitable for generic
  use (jsc#SLE-16407).
- Refresh
  patches.suse/crypto-blake2s-generic-c-library-implementation-and-selftest.patch
  patches.suse/crypto-poly1305-move-core-routines-into-a-separate-library.patch
- Update config files.
  x86_64/default, arm64/default, ppc64le/default, s390x/default
- crypto: sha256 - Use get/put_unaligned_be32 to get input,
  memzero_explicit (jsc#SLE-16407).
- crypto: sha256 - Move lib/sha256.c to lib/crypto
  (jsc#SLE-16407).
  Refresh
  patches.suse/crypto-sha256-Move-lib-sha256.c-to-lib-crypto.patch
- crypto: sha256_generic - Fix some coding style issues
  (jsc#SLE-16407).
- commit 6bb9a87
* Sat Nov 28 2020 pjakobsson@suse.de
- blacklist.conf: Blacklist dups from DRM backport v5.9
- commit 712b901
* Sat Nov 28 2020 pjakobsson@suse.de
- blacklist.conf: Temporary blacklist for DRM backport v5.9
- commit 7fca26d
* Sat Nov 28 2020 pjakobsson@suse.de
- Update config files. (for DRM backport v5.9)
- commit edca411
* Sat Nov 28 2020 tiwai@suse.de
- can: m_can: fix nominal bitiming tseg2 min for version >= 3.1
  (git-fixes).
- can: gs_usb: fix endianess problem with candleLight firmware
  (git-fixes).
- batman-adv: set .owner to THIS_MODULE (git-fixes).
- nfc: s3fwrn5: use signed integer for parsing GPIO numbers
  (git-fixes).
- iwlwifi: mvm: write queue_sync_state only for sync (git-fixes).
- platform/x86: toshiba_acpi: Fix the wrong variable assignment
  (git-fixes).
- platform/x86: thinkpad_acpi: Send tablet mode switch at wakeup
  time (git-fixes).
- commit 767fda0
* Fri Nov 27 2020 pjakobsson@suse.de
- scatterlist: add generic wrappers for iterating over sgtable
  objects (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- commit c162a26
* Fri Nov 27 2020 msuchanek@suse.de
- powerpc/perf: Use regs->nip when SIAR is zero (jsc#SLE-13513
  bsc#1176919 ltc#186162).
- powerpc/perf: Use the address from SIAR register to set cpumode
  flags (jsc#SLE-13513 bsc#1176919 ltc#186162).
- powerpc/perf: Drop the check for SIAR_VALID (jsc#SLE-13513
  bsc#1176919 ltc#186162).
- powerpc/perf: Add new power PMU flag "PPMU_P10_DD1" for power10
  DD1 (jsc#SLE-13513 bsc#1176919 ltc#186162).
- powerpc/perf: Exclude pmc5/6 from the irrelevant PMU group
  constraints (jsc#SLE-13513 bsc#1176919 ltc#186162).
- commit 6df36f6
* Fri Nov 27 2020 ailiop@suse.com
- xfs: revert "xfs: fix rmap key and record comparison functions"
  (git-fixes).
- commit 308ebc7
* Fri Nov 27 2020 yousaf.kaukab@suse.com
- config: arm64: enable rtc-max77686 driver
  References: jsc#SLE-15847
- commit 15655cf
* Fri Nov 27 2020 yousaf.kaukab@suse.com
- supported.conf: clk-max77686: enable for Jetson AGX Xavier
  References: jsc#SLE-15847
- commit a667bc6
* Fri Nov 27 2020 jlee@suse.com
- efi/libstub: Rewrite file I/O routine (jsc#SLE-16407).
- Refresh
  patches.rpmify/powerpc-Blacklist-GCC-5.4-6.1-and-6.2.patch
- Refresh
  patches.suse/efi-libstub-Move-file-I-O-support-code-into-separate.patch.
- efi/libstub: Move get_dram_base() into arm-stub.c
  (jsc#SLE-16407).
  Refresh
  patches.rpmify/powerpc-Blacklist-GCC-5.4-6.1-and-6.2.patch
  patches.suse/efi-libstub-Move-file-I-O-support-code-into-separate.patch
- efi/libstub/arm64: Use 1:1 mapping of RT services if property
  table exists (jsc#SLE-16407).
- efi/libstub/arm: Make efi_entry() an ordinary PE/COFF entrypoint
  (jsc#SLE-16407).
  Refresh
  patches.suse/efi-libstub-x86-Permit-cmdline-data-to-be-allocated-.patch
- efi/arm: Pass start and end addresses to cache_clean_flush()
  (jsc#SLE-16407).
  Refresh
  patches.suse/efi-arm-Pass-start-and-end-addresses-to-cache_clean_.patch
- efi/arm: Work around missing cache maintenance in decompressor
  handover (jsc#SLE-16407).
- ARM: 8942/1: Revert "8857/1: efi: enable CP15 DMB instructions
  before cleaning the cache" (jsc#SLE-16407).
- commit c31bfae
* Fri Nov 27 2020 jlee@suse.com
- efi/libstub: Move file I/O support code into separate file
  (jsc#SLE-16407).
- efi/libstub: Move efi_random_alloc() into separate source file
  (jsc#SLE-16407).
- efi/libstub/x86: Permit cmdline data to be allocated above 4 GB
  (jsc#SLE-16407).
- efi/libstub: Move stub specific declarations into efistub.h
  (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
- efi/libstub/x86: Permit bootparams struct to be allocated
  above 4 GB (jsc#SLE-16407).
- efi/libstub: Use consistent type names for file I/O protocols
  (jsc#SLE-16407).
- efi/libstub/x86: Incorporate eboot.c into libstub
  (jsc#SLE-16407).
- Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
- Update config files.
  The x86_64 eboot.c be moved to libstub, so the patches of EFI securet
  key should be refactory. I disabled CONFIG_EFI_SECRET_KEY and
  CONFIG_HIBERNATE_VERIFICATION here, and will refactory patches after
  EFI backporting then enable the function again.
- efi/libstub: Simplify efi_high_alloc() and rename to
  efi_allocate_pages() (jsc#SLE-16407).
- efi/libstub: Move memory map handling and allocation routines
  to mem.c (jsc#SLE-16407).
- efi/libstub/arm: Relax FDT alignment requirement
  (jsc#SLE-16407).
- efi/libstub: Use hidden visibility for all source files
  (jsc#SLE-16407).
- efi/libstub/x86: Avoid overflowing code32_start on PE entry
  (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
- efi/libstub/x86: Remove pointless zeroing of apm_bios_info
  (jsc#SLE-16407).
- efi/apple-properties: Replace zero-length array with
  flexible-array member (jsc#SLE-16407).
- efi/bgrt: Accept BGRT tables with a version of 0
  (jsc#SLE-16407).
- efi/x86: Mark setup_graphics static (jsc#SLE-16407).
- efi/x86: Remove GDT setup from efi_main (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
- efi/x86: Don't depend on firmware GDT layout (jsc#SLE-16407).
- platform/x86: touchscreen_dmi: Add EFI embedded firmware info
  support (jsc#SLE-16407).
- efi: Add embedded peripheral firmware support (jsc#SLE-16407).
- Refresh
  patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
- Update config files.
  x86_64/default
- efi: Export boot-services code and data as debugfs-blobs
  (jsc#SLE-16407).
  Refresh
  patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch
- commit 3dd5b5c
* Fri Nov 27 2020 pjakobsson@suse.de
- drm/amd/display: Change ABM config init interface
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- blacklist.conf: unblacklist patches included in drm v5.9
- drm/amdgpu/swsmu: fix ARC build errors (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix NULL pointer dereference for Renoir
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/mem: guard against NULL pointer access in mem_del
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/device: return error for unknown chipsets
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: drm_dsc.h: fix a kernel-doc markup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Partially revert "video: fbdev: amba-clcd: Retire elder
  CLCD driver" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: disable gfxoff temporarily for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/pm: setup APU dpm clock table in SMU HW initialization
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove duplicate call to (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/swsmu/smu12: fix force clock handling for mclk
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: restore proper ref count in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/display: fix CFLAGS setup for DCN30 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix return value check for hdcp_work
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove gpu_info fw support for sienna_cichlid etc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/pm: Removed fixed clock in auto mode DPM (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: remove experimental flag from navi12 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add device ID for sienna_cichlid (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use the AV1 defines for VCN 3.0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add VCN 3.0 AV1 registers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add the GC 10.3 VRS registers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: prevent double kfree ttm->sg (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: Fix error handling in get_node (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dmabuf: fix NULL pointer dereference in dma_buf_release()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Fix port number for BDW on EDID region setup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: mixer: Extend regmap max_register (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/sun4i: sun8i-csc: Secondary CSC register correction
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4/vc4_hdmi: fill ASoC card owner (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- fbcon: Fix user font detection test at fbcon_resize()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Add missing put_device() call in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mediatek: Add missing put_device() call in
  mtk_drm_kms_init() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Add exception handing in mtk_drm_probe()
  if component (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Add missing put_device() call in
  mtk_ddp_comp_init() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Use CPU when fail to get cmdq event
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: dsi: Fix scrolling of panel with small hfp or hbp
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Filter wake_flags passed to default_wake_function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Be wary of data races when reading the active
  execlists (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Reduce context termination list iteration guard to
  RCU (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Delay tracking the GEM context until it is
  registered (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Don't log hdcp module warnings in dmesg
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: declare ta firmware for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/dc: Require primary plane to be enabled whenever
  the CRTC is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Include sienna_cichlid in USBC PD FW support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: update nv1x stutter latencies (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Don't use DRM_ERROR() for DTM add topology
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/pm: support runtime pptable update for sienna_cichlid
  etc (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: fix a memory leak issue (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/kfd: fix a system crash issue during GPU recovery
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- vgacon: remove software scrollback support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- fbcon: remove now unusued 'softback_lines' cursor() argument
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: fix OOB read in vga_8planes_imageblit()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: drop virtio_gpu_output->enabled (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/sun4i: backend: Disable alpha on the lowest plane on the A20
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: backend: Support alpha property on lowest plane
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: Fix DE2 YVU handling (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tve200: Stabilize enable/disable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma-buf: fence-chain: Document missing dma_fence_chain_init()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: Fix kerneldoc of dma_buf_set_name() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: fix unblank (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: Fix dsi dcs long write function (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ingenic: Fix driver not probing when IPU port is missing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ingenic: Fix leak of device_node pointer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/sun4i: add missing put_device() call in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: Revert "drm/virtio: Call the right shmem helpers"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: fix regression leading to display audio probe
  failure on GLK (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: xlnx: dpsub: Fix DMADEVICES Kconfig dependency
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/i915/gem: Delete unused code" (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Revert "drm/i915/gem: Async GPU relocations only"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/i915: Remove i915_gem_object_get_dirty_page()"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: Disable the RPTR shadow (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: Disable preemption on all 5xx targets (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Enable expanded apriv support for a650 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Split the a5xx preemption record (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- xen: add helpers to allocate unpopulated memory (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- memremap: rename MEMORY_DEVICE_DEVDAX to MEMORY_DEVICE_GENERIC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-gp1xx: add WAR for EVO push buffer HW bug
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-gp1xx: disable notifies again after
  core update (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: add some whitespace before debug message
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/gv100-: Include correct push header in crcc37d.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Clear the repeater bit on HDCP disable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix sha_text population code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Ensure that ret is always initialized in
  icl_combo_phy_verify_state (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Fix bug in reporting voltage for CIK (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Specify get_argument function for ci_smu_funcs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/pm: enable MP0 DPM for sienna_cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/pm: avoid false alarm due to confusing
  softwareshutdowntemp (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/pm: fix is_dpm_running() run error on 32bit system
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- mm/gup: Remove enfornced COW mechanism (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: controlfb: Fix build for COMPILE_TEST=y &&
  PPC_PMAC=n (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix cmd parser desc matching with masks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: fix incorrect lock state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/modeset-lock: Take the modeset BKL for legacy drivers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Don't return error code when crtc is null
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix memleak in amdgpu_dm_mode_config_init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: disable runtime pm for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Retry AUX write when fail occurs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Fix buffer overflow in INFO ioctl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: Fix hardmins not being sent to SMU for RV
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use MODE1 reset for navy_flounder by default
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/pm: correct the thermal alert temperature limit settings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add asd fw check before loading asd (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Keep current gain when ABM disable immediately
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix passive dongle mistaken as active
  dongle in EDID (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Revert HDCP disable sequence change
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Send DISPLAY_OFF after power down on boot
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx10: refine mgcg setting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/pm: correct Vega20 swctf limit setting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/pm: correct Vega12 swctf limit setting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/pm: correct Vega10 swctf limit setting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/pm: set VCN pg per instances (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/pm: enable run_btc callback for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drivers: gpu: amd: Initialize amdgpu_dm_backlight_caps object
  to 0 in amdgpu_dm_update_backlight_caps (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Reject overlay plane configurations in
  multi-display (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: use correct scale for actual_brightness
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: should check error using DC_OK (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/a6xx: fix frequency not always being restored on
  GMU resume (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: add module param to enable debugbus snapshot
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: fix crashdec section name typo (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/a6xx: fix gmu start on newer firmware (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: enable vblank during atomic commits (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: add shutdown support for display platform_driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: msm: a6xx: use dev_pm_opp_set_bw to scale DDR
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/gpu: make ringbuffer readonly (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/adreno: fix updating ring fence (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: fix unitialized variable error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: Fix scale params in plane validation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: Fix reservation failures in modeset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/etnaviv: always start/stop scheduler in timeout processing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: fix external abort seen on GC600 rev 0x19
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: gem: Fix sparse warning (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- fbcon: prevent user font height or width change from causing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- treewide: Use fallthrough pseudo-keyword (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- efi: avoid error message when booting under Xen (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Make sure TC-cold is blocked before enabling TC
  AUX power wells (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Avoid passing a random 0 into ilog2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix wrong return value in intel_atomic_check()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Update bw_buddy pagemask table (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Check for an LPSP encoder before dereferencing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Copy default modparams to mock i915_device
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Provide the perf pmu.module (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gvt: Do not reset pv_notified when vGPU transit
  from D3->D0 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Do not destroy ppgtt_mm during vGPU D3->D0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/amdgpu: disable gfxoff for navy_flounder"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix pow() crashing when given base 0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Reset scrambling on Test Pattern
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix dcn3 wide timing dsc validation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix DFPstate hang due to view port changed
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Assign correct left shift (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Call DMUB for eDP power control (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: fix the wrong sdma instance query for renoir
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: parse ta firmware for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix NULL pointer access issue when unloading driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix uninit-value in
  arcturus_log_thermal_throttling_event() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: disable gfxoff for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/display: use GFP_ATOMIC in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Blank stream before destroying HDCP session
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix EDID parsing after resume from suspend
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Switch to immediate mode for updating
  infopackets (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix LFC multiplier changing erratically
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix incorrect backlight register offset for DCN
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update gc golden register for arcturus
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: correct UVD/VCE PG state on custom pptable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: correct Vega20 cached smu feature state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Skip some registers config for SRIOV (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: amdgpu: Use the correct size when allocating memory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: fix memory leak in virtio_gpu_cleanup_object()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: fix missing dma_fence_put() in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- backlight: pwm_bl: Use 64-bit division function (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Use 64-bit division macro (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/xen-front: Pass dumb buffer data offset to the backend
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- xen: Sync up with the canonical protocol definition in Xen
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/xen-front: Add YUYV to supported formats (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/xen-front: Fix misused IS_ERR_OR_NULL checks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: revert "drm/ttm: make TT creation purely optional v3"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: fix spelling mistake "Cant" -> "Can't"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: fix spelling mistake "Cound" -> "Could"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx/ldu: Use drm_mode_config_reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx/sou: Use drm_mode_config_reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx/stdu: Use drm_mode_config_reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: Fix two list_for_each loop exit tests
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Use correct vmw_legacy_display_unit pointer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Use struct_size() helper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Fix bug where DPM is not enabled after hibernate and
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: put VCN/JPEG into PG ungate state before
  dpm table (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update swSMU VCN/JPEG PG logics
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use mode1 reset by default for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu: rework i2c adpater registration (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Display goes blank after inst (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Change null plane state swizzle mode to 4kb_s
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use helper function to check for HDMI signal
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: AMD OUI (DPCD 0x00300) skipped on some sink
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix logger context (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: populate new dml variable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Read VBIOS Golden Settings Tbl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Use parameter for call to set output mux
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable GFXOFF for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm amdgpu: Skip tmr load for SRIOV (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix PSP autoload twice in FLR (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: update GC golden setting for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update driver if version for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: skip crit temperature values on APU (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix DP Compliance tests 4.3.2.1 and 4.3.2.2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use hw lock mgr (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: dchubbub p-state warning during surface planes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Allow asic specific FSFT timing optimization
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Disable idle optimizations before programming
  DCN (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix dmesg warning from setting abm level
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use proper abm/backlight functions for DCN3
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use seperate dmcub firmware for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Check lane status again after link
  training done (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Don't compare dppclk before updating DTO
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix naming of DSC Debugfs entry (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Rename bytes_pp to the correct bits_pp
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Clean up global sync param retrieval
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/swsmu: allow asic to handle sensor type by itself
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: off by one bugs in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: update driver if file for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary message support check(v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update dec ring test for VCN 3.0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/jpeg3.0: remove extra asic type check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: update golden setting for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: correct smu message for vf mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add msg map for mode1 reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: skip invalid msg when smu set mp1 state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: remove the dpm checking in the boot sequence
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/amd/powerplay: drop unnecessary message support
  check" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add printing after executing page reservation
  to eeprom (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: expand sienna chichlid reg access support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Added orientation quirk for ASUS tablet model T103HAF
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: force runtime PM suspend on system suspend
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tidss: fix modeset init for DPI panels (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: re-add deleted doc for drm_gem_open_ioctl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: fix offset in VMAs with a pg_offs in ttm_bo_vm_access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: fix drm_dp_mst_port refcount leaks in
  drm_dp_mst_allocate_vcpi (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- fbmem: pull fbcon_update_vcs() out of fb_set_var()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- vgaarb: mark vga_tryget static (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: xlnx: zynqmp: Use switch - case for link rate downshift
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: xlnx: Fix typo in parameter description (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: xlnx: fix spelling mistake "failes" -> "failed"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Remove redundant NULL check (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/fourcc: fix Amlogic Video Framebuffer Compression macro
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: Use {} to zero initialize the mode (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: convert to LE accessors (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- virtio_config: LE config space accessors (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: backlight: cr_bllcd: Remove unused variable 'intensity'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: backlight: Make of_find_backlight static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: backlight: Drop backlight_put() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- backlight: Use backlight_get_brightness() throughout
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: jornada720_bl: Introduce backlight_is_blank()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: gpio_backlight: Simplify update_status()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: cr_bllcd: Introduce gpio-backlight semantics
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: as3711_bl: Simplify update_status (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- backlight: backlight: Introduce backlight_get_brightness()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- doc-rst: Wire-up Backlight kernel-doc documentation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: backlight: Add overview and update existing doc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: backlight: Drop extern from prototypes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: generic_bl: Remove this driver as it is unused
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: backlight: Add backlight_is_blank() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- backlight: backlight: Refactor fb_notifier_callback()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: backlight: sky81452-backlight: Fix some kerneldoc issues
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: qcom-wled: Remove unused configs for LED3 and LED4
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: lm3630a_bl: Remove invalid checks for unsigned int <
  0 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: backlight: Supply description for function args in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: ili922x: Add missing kerneldoc description for
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: ili922x: Remove invalid use of kerneldoc syntax
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: ili922x: Add missing kerneldoc descriptions for
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: lcd: Add missing kerneldoc entry for 'struct device
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: lms501kf03: Remove unused const variables
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: lms501kf03: Drop unused include (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- backlight: Delete the OT200 backlight driver (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- backlight: sky81452: Privatize platform data (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- backlight: sky81452: Convert to GPIO descriptors (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- backlight: lm3533_bl: Use kobj_to_dev() instead (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma-buf: Remove custom seqcount lockdep class key
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- PCI: Move PCI_VENDOR_ID_REDHAT definition to pci_ids.h
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- vgacon: Fix for missing check in scrollback handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- ASoC: hdmi-codec: merge .digital_mute() into .mute_stream()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- sched: Remove sched_set_*() return value (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- sched,drm/scheduler: Convert to sched_set_fifo*()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- sched,msm: Convert to sched_set_fifo*() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- sched: Provide sched_set_fifo() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: use kthread_create_worker instead of kthread_run
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/mdp5: Add MDP5 configuration for SDM636/660
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dsi: Add DSI configuration for SDM660 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/mdp5: Add MDP5 configuration for SDM630 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dsi: Add phy configuration for SDM630/636/660
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: add A640/A650 hwcg (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: hwcg tables in gpulist (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: add SM8250 to hw catalog (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: add SM8150 to hw catalog (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: intf timing path for displayport (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: set missing flush bits for INTF_2 and INTF_3
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: don't use INTF_INPUT_CTRL feature on sdm845
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: move some sspp caps to dpu_caps (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: update UBWC config for sm8150 and sm8250
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: use right setup_blend_config for sm8150 and sm8250
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: set ubwc config for A640 and A650 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/adreno: un-open-code some packets (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: sync generated headers (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: add build_bw_table for A640/A650 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/a6xx: fix crashstate capture for A650 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Quiet error during failure in optional resource
  mappings (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: Garbage collect unused resource _len fields
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: fix/enable 6bpc dither with split-lm
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: msm: a6xx: fix gpu failure after system resume
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: dsi: Use OPP API to set clk/perf state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: Use OPP API to set clk/perf state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: ratelimit crtc event overflow error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: msm: a6xx: send opp instead of a frequency (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Fix a null pointer access in msm_gem_shrinker_count()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: add support for dither block in display
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/adreno: fix gpu probe if no interconnect-names
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: enumerate second cursor pipe for external interface
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: ensure device suspend happens during PM sleep
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: handle for EPROBE_DEFER for of_icc_get (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: reset devfreq freq_table/max_state before
  devfreq_add_device (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: fix unbalanced pm_runtime_enable in adreno_gpu_{init,
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Update DRIVER_DATE to 20200715 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Assert the kernel context is using the HWSP
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Trace placement of timeline HWSP (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove unused inline function drain_delayed_work()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftest: Fix an error code in live_noa_gpr()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dg1: Add fake PCH (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dg1: Remove SHPD_FILTER_CNT register programming
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dg1: add support for the master unit interrupt
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dg1: Add DG1 PCI IDs (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dg1: add initial DG-1 definitions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add has_master_unit_irq flag (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: WARN if max vswing/pre-emphasis violates the DP spec
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/mst: filter out the display mode exceed sink's
  capability (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/probe_helper: Add drm_connector_helper_funcs.mode_valid_ctx
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Skip signaling a signaled request (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftest: fix an error return path where err is
  not being (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Always reset the engine, even if inactive,
  on execlists (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pull printing GT capabilities on error to err_print_gt
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Be defensive in the face of false CS events
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftest: Check that GPR are restored across noa_wait
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Optimise aliasing-ppgtt allocations (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/bios: Parse HOBL parameter (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Remove port and phy from voltage swing
  functions (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Replace drm_i915_private in voltage swing
  functions by intel_encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Implement WAs 18011464164 and 22010931296
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Document FBC related w/as more thoroughly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Limit WaFbcHighMemBwCorruptionAvoidance to skl and bxt
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Don't do WaFbcTurnOffFbcWatermark for glk
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move all FBC w/as to .init_clock_gating()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dvo: Make .get_modes() return the number of modes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/sdvo: Make .get_modes() return the number of modes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/sdvo: Make SDVO deal with HDMI pixel repeat
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Reject DRM_MODE_FLAG_DBLCLK with DVI sinks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/sdvo: Implement limited color range for SDVO HDMI
  properly (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/sdvo: Fix SDVO colorimetry bit defines (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove i915_gem_object_get_dirty_page()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Release shortlived maps of longlived objects
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Replace opencoded i915_gem_object_pin_map()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Unpin idle contexts from kswapd reclaim
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move sseu debugfs under gt/ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: gt-fy sseu debugfs (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/sseu: Move sseu_info under gt_info (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/sseu: Move sseu detection and dump to intel_sseu
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Introduce gt_init_mmio (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move the engine mask to intel_gt_info (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Move engine-related mmio init to engines_init_mmio
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use the gt in HAS_ENGINE (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Convert device_info to uncore/de_read (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dp: Helper to check for DDI BUF status to get active
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Helper for checking DDI_BUF_CTL Idle status
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/huc: Adjust HuC state accordingly after GuC fetch error
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uc: Extract uc usage details into separate debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hdcp: Fix the return handling of
  drm_hdcp_check_ksvs_revoked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hdcp: Update CP as per the kernel internal state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/ehl: Add new PCI ids (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Implement new combo phy initialization step
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Update dma-attributes for our sg DMA (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix spelling mistake in i915_reg.h (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Don't taint when using fault injection (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Print caller when tainting for CI (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Reboot CI if we get wedged during driver init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/i915/dp: Correctly advertise HBR3 for GEN11+"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Export ppgtt_bind_vma (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: Allow FBC to recompress after a 3D workload
  on i85x/i865 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: Enable fbc on i865 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: Fix nuke for pre-snb platforms (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Use the correct plane stride (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Clamp min_cdclk to max_cdclk_freq to unblock 8K
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: Expand guc_info debugfs with more information
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: do not read swizzle info if unavailable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Split the context's obj:vma lut into its own mutex
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Drop forced struct_mutex from
  shrinker_taints_mutex (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Only revoke mmap handlers if active
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Only revoke the GGTT mmappings on aperture
  detiling (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: prefer dig_port to reference
  intel_digital_port (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm/nouveau: don't call tt destroy callback on alloc failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: ttm_bo_swapout_all doesn't use it's argument
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: drop unusued function declaration (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: make ttm_tt unbind function return void (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Revert "drm/amd/display: Expose connector VRR range via debugfs"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sienna_cichlid: add SMU i2c support (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/navi1x: add SMU i2c support (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/swSMU: remove eeprom from the smu i2c handlers (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vega20: enable the smu i2c bus for all boards
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove eeprom from the smu i2c handlers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: move i2c bus lock out of ras structure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Fix NULL dereference in dpm sysfs handlers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: retrieve VCN dpm table per instances
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update driver if version for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: fix typos for clk map (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/vcn: merge shared memory into vcpu (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Revert "drm/amdgpu/vcn: add shared memory restore after
  wake up from (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.95 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: interface to obtain minimum plane size caps
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add additional config guards for DCN
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Call dsc related functions indirectly via dc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Improve compatibility by re-ordering
  info-packets (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Release 0.0.25 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Make new dc interface for adding dsc resource
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: rename dsc extended caps as dsc branch
  decoder caps (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Decouple ABM init from dmcu (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Implement AMD VSIF V3 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add DSC parameters logging to debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove unhelpful 5ms delay (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: do not disable SMU on vm reboot (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add timeout flush mechanism to update wptr for self
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable xgmi support for sienna cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: load asd for sienna cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: tag swSMU code layers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: revise the calling flow on OD table update
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary message support check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: move SMC message issuing APIs to smu_cmn.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update the tables init related
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: move table setting common code to smu_cmn.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: maximum code sharing around watermarks
  setting (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: move more APIs to smu_cmn.c (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: common API for disabling all features with
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: move ppfeature mask setting to smu_cmn.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: implement smu_cmn_get_enabled_mask()
  for all ASICs (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: move dpm feature enablement checking
  to smu_cmn.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: move dpm feature support checking to
  smu_cmn.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: move clock dpm enablement check to
  smu_v11/v12 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unused code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: unify swSMU index to asic specific
  index mapping (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: widely share the API for data table
  retrieving (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add read amdgpu_gfxoff status in debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: load ta firmware for sienna cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: suppress compile error around BUG_ON
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: Fix CRC-related compile errors with
  debugfs disabled (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fence: use NVIDIA's headers for read()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fence: use NVIDIA's headers for sync()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fence: use NVIDIA's headers for emit()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/svm: use NVIDIA's headers for migrate_clear()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/svm: use NVIDIA's headers for migrate_copy()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/bo: use NVIDIA's headers for move move()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/bo: use NVIDIA's headers for move init()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fbcon/nv50-: use NVIDIA's headers for fillrect()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fbcon/nv50-: use NVIDIA's headers for copyarea()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fbcon/nv50-: use NVIDIA's headers for imageblit()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fbcon/nv50-: use NVIDIA's headers for accel_init()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core
  crc_set_ctx() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core
  crc_set_src() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core head_or()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core
  head_procamp() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core
  head_dither() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core head_ovly()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core head_base()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core
  head_curs_clr() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core
  head_curs_set() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core
  head_core_clr() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core
  head_core_set() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core
  head_olut_clr() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core
  head_olut_set() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core head_mode()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core head_view()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core
  or_get_caps() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core or_ctrl()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core
  wndw_owner() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core update()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core
  ntfy_wait_done() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core caps_init()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core ntfy_init()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for core init()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw update()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw blend_set()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw scale_set()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw image_clr()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw image_set()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw xlut_clr()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw xlut_set()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw csc_clr()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw csc_set()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw ntfy_clr()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw ntfy_set()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw
  ntfy_reset() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw sema_clr()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wndw sema_set()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wimm update()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wimm point()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: use NVIDIA's headers for wimm space()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fence: convert sync() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fence: convert emit() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gem: convert indirect pushbufs to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/chan: convert nvsw init to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: convert nvsw init to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv04-: no need for multiple nvsw objects
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv04: convert page_flip() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv04: convert page_flip_emit() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/svm: convert migrate_clear to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/svm: convert migrate_copy to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/bo: convert move move() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/bo: convert move init() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/bo: split buffer move functions into their
  own source (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fbcon: convert copyarea() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fbcon: convert fillrect() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fbcon: convert imageblit() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fbcon: convert accel_init() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: interop with new push macros (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/kms/nv50-: implement proper push buffer
  control logic (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core crc_set_ctx() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core crc_set_src() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core head_or() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core head_procamp() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core head_dither() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core head_ovly() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core head_base() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core head_curs_clr() to new push
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core head_curs_set() to new push
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core head_core_clr() to new push
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core head_core_set() to new push
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core head_olut_clr() to new push
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core head_olut_set() to new push
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core head_mode() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core head_view() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core or_ctrl() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core wndw_owner() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core update() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core caps_init() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert core init() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wndw update() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wndw blend_set() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wndw scale_set() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wndw image_clr() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wndw image_set() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wndw xlut_clr() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wndw xlut_set() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wndw csc_clr() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wndw csc_set() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wndw ntfy_clr() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wndw ntfy_set() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wndw sema_clr() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wndw sema_set() to new
  push macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wimm update() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: convert wimm point() to new push macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: wrap existing command submission
  in nvif_push (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvif: add support for object-level debug output
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvif: give every notify object a human-readable name
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvif: give every disp object a human-readable
  identifier (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvif: give every usermode object a human-readable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvif: give every vmm object a human-readable
  identifier (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvif: give every mem object a human-readable
  identifier (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvif: give every mmu object a human-readable
  identifier (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvif: give every device object a human-readable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvif: give every object a human-readable identifier
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvif: rename client ctor/dtor (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/kms/tu102: set (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: Use fallthrough pseudo-keyword (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/mmu: make nvkm_vmm_ctor() static (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau: fix reference count leak in
  nouveau_debugfs_strap_peek (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: Fix reference count leak in
  nouveau_connector_detect (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: fix reference count leak in nv50_disp_atomic_commit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: fix multiple instances of reference count leaks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/drm/noveau: fix reference count leak in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/sec2/gp102: allow module to load when LSFW
  is missing (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/gm200-: explicitly handle nofw (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/pmu/gm200-: explicitly handle nofw (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/pmu/gm20x: don't pretend we support loading with our
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/acr: store a mask of LS falcons the controlling LSFW
  can (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/acr: store a mask of LS falcons the HSFW can
  bootstrap (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/acr: allow module to load when HSFW(s) are missing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/acr: refuse to load LSFW if HSFW is missing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/core: drop error message when no compatible FW found
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/mmu/gp100-: enable mmu invalidate depth optimisation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvfw: firmware structures should begin with nvfw_
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/tmr: fix nvkm_usec/nvkm_msec definitions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/therm/gt215: make gt215_therm_init static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/mmu: make a couple of functions static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/mc/gp10b: make gp10b_mc_init static (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/nvfw/acr: make lsb_header_tail_dump static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/gf100-: make some functions static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp/gm200-: remove 'head' parameter from
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: mtk_dsi: Create connector for bridges
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: mtk_dsi: Use the drm_panel_bridge API
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: mtk_dsi: Use simple encoder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mediatek: mtk_dsi: Convert to bridge driver (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mediatek: mtk_dsi: Rename bridge to next_bridge
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- =?UTF-8?q?drm/tegra:=20plane:=20Support=20180=C2=B0=20rotation?=
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: plane: Support horizontal reflection (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tegra: plane: Rename bottom_up to reflect_y (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tegra: dc: Omit superfluous error message in
  tegra_dc_probe() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: gr2d: Add tiled PATBASE address register
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: gr3d: Assert reset before power-gating
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: sor: Use correct power supply names for HDMI
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gpu: host1x: debug: Dump push buffer state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- gpu: host1x: Put gather's BO on pinning error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- gpu: host1x: Optimize BOs usage when firewall is enabled
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gpu: host1x: mipi: Split tegra_mipi_calibrate() and
  tegra_mipi_wait() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- gpu: host1x: mipi: Use readl_relaxed_poll_timeout() in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gpu: host1x: mipi: Update tegra_mipi_request() to be node based
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdkfd: Fix large framesize for kfd_smi_ev_read()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- include/uapi/linux: Update KFD ioctl version (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: Provide SMI events watch (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable ih CG for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable hdp CG and LS for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable mc CG and LS for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable athub/mmhub PG for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: set VCN1 pg only for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add DC support for navy flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: support athub cg setting for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable GFX clock gating for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable JPEG3.0 PG and CG for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable VCN3.0 DPG for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable VCN3.0 PG and CG for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable cp_fw_write_wait for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add vcn ip block for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add navy_flounder vcn firmware support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx10: add gc golden setting for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Add kfd2kgd_funcs for navy_flounder kfd support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Support navy_flounder KFD (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: use front door firmware loading for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add psp block for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add psp support for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add smu block for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/powerplay: add smu support for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add gmc cg support for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: force pa_sc_tile_steering_override to 0 for
  navy_flounder (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: configure navy_flounder gfx according to gfx 10.3
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add virtual display support for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add sdma ip block for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add gfx ip block for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add ih ip block for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add gmc ip block for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add common ip block for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add support on mmhub for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: initialize IP offset for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/soc15: add support for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/gfx10: add clockgating support for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gmc10: add navy_flounder support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/gfx10: add support for navy_flounder firmware
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: set asic family and ip blocks for navy_flounder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: set fw load type for navy_flounder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add navy_flounder gpu info firmware (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add navy_flounder asic type (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: expand to add multiple trap event irq id
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/sriov skip vcn powergating and dec_ring_test
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: correct ta header v2 ucode init start address
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/sriov porting sriov cap to vcn3.0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/sriov add mmsch_v3 interface (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: optimize rlcg write for gfx_v10 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/sriov skip jped ip block and close pgcg flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unused code around thermal range setting
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: maximum the code sharing on thermal
  irq setting (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: sort the call flow on temperature ranges
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: cache the software_shutdown_temp
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: correct Sienna Cichlid temperature limit
  settings (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: correct Navi1X temperature limit settings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: correct the supported pcie GenSpeed and
  LaneCount (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary wrapper around pcie
  parameters (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unused APIs and parameters
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop smu_v12_0.c unnecessary wrapper V2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary wrappers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: apply gfxoff disablement/enablement for
  all SMU11 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop Sienna Cichlid specific (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary Sienna Cichlid specific APIs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary Navi1x specific APIs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary Arcturus specific APIs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update the common API for performance level
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update UMD pstate clock settings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add new UMD pstate data structure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update Sienna Cichlid default dpm table setup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update Navi10 default dpm table setup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update Arcturus default dpm table setting
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: implement a common set dpm table API for smu
  V11 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add more members for dpm table
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add module parameter choose reset mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable mode1 reset (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: RAS emergency restart logic refine (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: add SMU mode1 reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: fix kernel-doc and cleanup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: remove an unnecessary NULL check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sdma5: fix wptr overwritten in ->get_wptr()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use ARRAY_SIZE() to add amdgpu debugfs files
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Allow for vblank enabled with no active planes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add missing DCN30 registers and fields for
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Reuse parsing code of debugfs write buffer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.94 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Release 0.0.24 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix dcn3 p_state_change_support validation (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: p-state warning occurs while changing
  resolution (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: reduce sr_xxx_time by 3 us when ppt disable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Power down hardware if set mode is not
  called before (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: update dml var (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/powerplay: Target power profile mode should be
  the second (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix spelling mistake "Falied" -> "Failed"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: minor cleanup of phase1 suspend code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: put dpm frequency setting common code in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: revise calling chain on retrieving
  frequency range (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: revise calling chain on setting soft limit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: put setting hard limit common code in
  smu_v11_0.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unused code and wrapper around clock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: unshare the code for retrieving current clock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: bypass wrapper on retrieving current clock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary wrappers around clock
  retrieving (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update driver if file for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: correct the .get_workload_type() pointer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/amd/display: add mechanism to skip DCN init"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix CSC remap matrix not being applied on dcn30
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use VUPDATE_NO_LOCK instead of VUPDATE
  for dcn30 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable gpu recovery for sienna cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove unnecessary logic of ASIC check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gpu/drm: Remove debug info about CPU address (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add missing CW4 programming for DCN30
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use register distance member instead of hardcode
  in mmhub v9.4 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use register distance member instead of hardcode
  in mmhub v2 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use register distance member instead of hardcode
  in mmhub v1 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use register distance member instead of hardcode
  in gfxhub v2.1 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use register distance member instead of hardcode
  in gfxhub v2 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use register distance member instead of hardcode
  in gfxhub v1 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use register distance member instead of hardcode
  in VCN2/JEPG2 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use register distance member instead of hardcode
  in UVD7/VCE4 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use register distance member instead of hardcode
  in VCN1/JEPG1 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use register distance member instead of hardcode
  in GMC10 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use register distance member instead of hardcode
  in GMC9 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add register distance members into vmhub structure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Remove redundant kfd2kgd interface lookup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Refresh
  patches.suse/drm-iommu-change-type-of-pasid-to-u32.patch.
- drm/amdgpu: Move the mutex lock/unlock out (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add missing reg mask for dcn3 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add logger for SMU msg (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Request PHYCLK adjustment on PHY enable/disable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.93 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Release 0.0.23 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove VSC infoframe dep on DMCU
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Send VSIF on unsupported modes on DAL
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Register init (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add diags scaling log by default
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix coding error of mmhub pg enablement
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use RREG32_KIQ to read register when get cg state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: updated ta ucode loading (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: updated ta ucode header (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: remove redundant initialization of variable
  result (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/atomfirmware: update vram info handling for renoir
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/atomfirmware: update to latest integratedinfotable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: fix compile error with ARCH=arc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Create plane rotation property (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: Add Arcturus GWS support and fix VG10
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/amdgpu: support access regs outside of mmio bar"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: make IB test synchronize with init for SRIOV(v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Update hardware scheduling time quanta
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Enable 4 to 1 mpc combine for max detile use
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.92 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add register key and status for edid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Release 1.0.22 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix incorrect rounding for 10Hz refresh range
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Release 1.0.21 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: check dpcd read status of DP_DOWNSTREAM_PORT_0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Handle SMU msg response (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Release 1.0.20 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Preserve gpu memory allocation for life of dc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Initialize psr debug flags to 0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: correct discovery_tmr_size init val (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary "@" on OD sysfs output
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update driver if file for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: change method to set board parameters
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: reduce ip discovery data reading size
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: merge atombios init block (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: invoke req full access early enough (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: move reg base init forward for soc15 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: request init data in virt detection (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Let KFD use more VMIDs on Arcturus (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Clean up KFD VMID assignment (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: SI support for UVD and VCE power managment
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: SI support for VCE clock control (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: SI support for UVD clock control (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: xlnx: DRM/KMS driver for Xilinx ZynqMP DisplayPort
  Subsystem (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- dmaengine: Add support for repeating transactions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Refresh
  patches.suse/dmaengine-cookie-bypass-for-out-of-order-completion.patch.
- drm/etnaviv: fix ref count leak via pm_runtime_get_sync
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: Simplify clock enable/disable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/etnaviv: Make the "core" clock mandatory (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/etnaviv: Don't ignore errors on getting clocks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: Fix error path on failure to enable bus clk
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/imx: imx-tve: Delete an error message in imx_tve_bind()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gpu: ipu-v3: image-convert: Wait for all EOFs before completing
  a (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gpu: ipu-v3: image-convert: Combine rotate/no-rotate irq
  handlers (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- gpu: ipu-v3: Restore RGB32, BGR32 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/imx: imx-ldb: Disable both channels for split mode in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/imx: parallel-display: move panel/bridge detection to
  fail early (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/imx: imx-ldb: remove useless enum (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/imx: drop useless best_encoder callback (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/imx: tve: fix regulator_disable error path (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/imx: parallel-display: Adjust bus_flags handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/imx: fix use after free (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- dma-fence: Make symbol 'dma_fence_lockdep_map' static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vblank: Use spin_(un)lock_irq() in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vblank: Use spin_(un)lock_irq() in drm_queue_vblank_event()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vblank: Use spin_(un)lock_irq() in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vblank: Use spin_(un)lock_irq() in drm_crtc_vblank_on()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vblank: Use spin_(un)lock_irq() in drm_crtc_vblank_reset()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/qxl: stop using TTM_MEMTYPE_FLAG_MAPPABLE v2 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau: stop using TTM_MEMTYPE_FLAG_MAPPABLE
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: stop using TTM_MEMTYPE_FLAG_MAPPABLE (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: remove TTM_MEMTYPE_FLAG_CMA (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: cleanup coding style and implementation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: remove io_reserve_fastpath flag (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: cleanup io_mem interface with nouveau (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: remove optional dummy function from drivers using TTM
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-fence: prime lockdep annotations (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma-fence: basic lockdep annotations (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vram-helper: stop using TTM_MEMTYPE_FLAG_MAPPABLE
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: Replace HTTP links with HTTPS ones (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Replace HTTP links with HTTPS ones (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mxsfb: drop unused function parameter (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mxsfb: Make supported modifiers explicit (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: core: Convert device logging to drm_* functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i810: switch from 'pci_' to 'dma_' API (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Use managed MM initialization (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Initialize DRAM type before posting GPU (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Move VRAM size detection to ast_mm.c (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Use managed VRAM-helper initialization (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Rename ast_ttm.c to ast_mm.c (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vram-helper: Managed vram helpers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ingenic: Silence uninitialized-variable warning
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ingenic: Bump driver to version 1.1 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ingenic: Support multiple panels/bridges (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ingenic: Add support for the IPU (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ingenic: Add support for OSD mode (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ingenic: Use dmam_alloc_coherent() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ingenic: Move register definitions to ingenic-drm.h
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ingenic: Set DMA descriptor chain address in probe
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ingenic: Add missing CR in debug strings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ingenic: Rename ingenic-drm.c to ingenic-drm-drv.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ingenic: Fix incorrect assumption about plane->index
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nvd9-: Fix disabling CRCs alongside OR
  reprogramming (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nvd9-: Add CRC support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/kms/nv50-: Move hard-coded object handles
  into header (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: Expose nv50_outp_atom in disp.h
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv140-: Track wndw mappings in nv50_head_atom
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: Fix disabling dithering (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/kms/nv140-: Don't modify depth in state during
  atomic (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vblank: Add vblank works (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vblank: Use spin_(un)lock_irq() in drm_crtc_vblank_off()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vblank: Register drmm cleanup action once per
  drm_vblank_crtc (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tidss: Replace HTTP links with HTTPS ones (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vboxvideo: Replace HTTP links with HTTPS ones
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel-simple: Add 50 Hz mode to the Frida FRD350H54004 panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel-simple: Fix inverted V/H SYNC for Frida FRD350H54004
  panel (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: drm_rect.h: delete duplicated word in comment
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: msm_drm.h: delete duplicated words in comments
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: i915_drm.h: delete duplicated words in comments
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: drm_mode_config.h: delete duplicated words in comments
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: drm_gem.h: delete duplicated words in comments
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: drm_bridge.h: delete duplicated word in comment
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: drm_atomic.h: delete duplicated word in comment
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: Remove open-coded commit-tail function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tilcdc: Use standard drm_atomic_helper_commit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Inline mga_crtc_{prepare, commit}() into enable
  function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Rename G200WB prepare/commit function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Set/clear <syncrst> field in display enable/disable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Split DPMS function into helpers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mgag200: Don't set or clear <scroff> field during modeset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Move PLL setup out of mode-setting function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Don't write-protect CRTC 0-7 while in
  mga_crtc_prepare() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: sil_sii8620: initialize return of sii8620_readb
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: stop allocating dummy GTT nodes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: further cleanup ttm_mem_reg handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: radeon: fix common struct sg_table related issues
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: amdgpu: fix common struct sg_table related issues
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: Expose job_hang_limit module parameter (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vkms: change the max cursor width/height (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: panel: simple: Fix bpc for LG LB070WV8 panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: auo,b116xw03: fix flash backlight when power on
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: fb-helper: Convert logging to drm_* functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: mipi-dsi: Convert logging to drm_* functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Replace HTTP links with HTTPS ones (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: dw-hdmi: Always add the bridge in the global
  bridge list (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: dw-hdmi: Don't cleanup i2c adapter and ddc ptr in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: Replace HTTP links with HTTPS ones (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- fbdev: sm712fb: set error code in probe (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- fbdev: da8xx-fb: go to proper label on error handling paths
  in probe (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: vt8623fb: Constify static vga_regsets
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- omapfb: dss: Fix max fclk divider for omap36xx (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- omapfb: fix multiple reference count leaks due to
  pm_runtime_get_sync (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: neofb: fix memory leak in neo_scan_monitor()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: savage: fix memory leak on error handling
  path in probe (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- fbdev/fb.h: Use struct_size() helper in kzalloc()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- fbcon: Use array3_size() helper in scr_memcpyw() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: amifb: add FIXMEs about {put,get}_user() failures
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: amifb: add FIXME about dead APUS support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Clean up some curly braces (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/edid: Iterate through all DispID ext blocks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/edid: Allow looking for ext blocks starting from a
  specified index (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/dp: Include the AUX CH name in the debug messages
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vgem: Replace opencoded version of drm_gem_dumb_map_offset()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/stm: repair runtime power management (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/stm: ltdc: remove call of pm-runtime functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: overlay: fix build failure (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Initialize mode setting in ast_mode_config_init()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Use managed mode-config init (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Replace struct ast_crtc with struct drm_crtc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Init cursors before creating modesetting structures
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Managed cursor release (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Keep cursor HW BOs mapped (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Add helper to hide cursor (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Don't enable HW cursors twice during atomic update
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Replace ast_cursor_move() with ast_cursor_show()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Move cursor pageflip into helper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Update cursor image and checksum from same function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Move cursor fb pinning and mapping into helper
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Pass struct ast_private instance to cursor init/fini
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Move cursor functions to ast_cursor.c (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: crtc: Remove the feed_txp tests (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: txp: Turn the TXP into a CRTC of its own
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4: crtc: Move the txp_armed function to the TXP
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4: crtc: Move the CRTC initialisation to a separate
  function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4: crtc: Only access the PixelValve registers if we have
  to (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4: crtc: Split CRTC data in two (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: crtc: Make state functions public (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: crtc: Move HVS setup code to the HVS driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4: Reorder the bind order of the devices (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: Convert register accessors to FIELD_* (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: drm_fourcc: Add generic alias for 16_16_TILE modifier
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/hisilicon: Code refactoring for hibmc_drv_vdac
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: crtc: handle commit of Amlogic FBC frames
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: overlay: setup overlay for Amlogic FBC Scatter Memory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: overlay: setup overlay for Amlogic FBC Memory
  Saving mode (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: overlay: setup overlay for Amlogic FBC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: add Amlogic Video FBC registers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/fourcc: Add modifier definitions for describing
  Amlogic Video (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Use __drm_atomic_helper_crtc_reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: Use __drm_atomic_helper_crtc_reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mtk: Use __drm_atomic_helper_crtc_reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/imx: Use __drm_atomic_helper_crtc_reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Use __drm_atomic_helper_crtc_reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/atomic-helper: reset vblank on crtc reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm : Insert blank lines after declarations (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma-buf: fix dma-fence-chain out of order test (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Revert "dma-buf: Report signaled links inside dma-fence-chain"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix the old vs. new epoch counter check during hotplug
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/hisilicon: Use drmm_kzalloc() instead of devm_kzalloc()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: st7703: Assert reset prior to powering down the
  regulators (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: st7703: Enter sleep after display off (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: st7703: Add support for Xingbangda XBD599
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: st7703: Move generic part of init sequence to
  enable callback (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: st7703: Move code specific to jh057n closer together
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: st7703: Prepare for supporting multiple panels
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: st7703: Rename functions from jh057n prefix to st7703
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: rocktech-jh057n00900: Rename the driver to st7703
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/drm_connector: use inline comments for drm_bus_flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/drm_connector: drop legacy drm_bus_flags values
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: panel-simple: drop use of legacy drm_bus_flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: novatek-nt39016: drop use of legacy drm_bus_flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: raydium-rm67191: drop use of legacy drm_bus_flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ingenic-drm: drop use of legacy drm_bus_flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tidss: drop use of legacy drm_bus_flags (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/of: Make drm_of_find_panel_or_bridge() to check graph's
  presence (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- of_graph: add of_graph_is_present() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: panel: simple: Warn in case of incorrect bus format
  for LVDS (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: panel: simple: Drop drive/sample bus flags for LVDS panels
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: panel: simple: Correct bus format for Satoz SAT050AT40H12R2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: panel: simple: Correct connector type for Starry KR070PE2T
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Send hotplug event if edid had changed (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Introduce epoch counter to drm_connector (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Add helper to compare edids (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: pl111: Absorb the external register header (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: amba-clcd: Retire elder CLCD driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: pl111: Credit where credit is due (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: make TT creation purely optional v3 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: cleanup ttm_mem_type_manager_func.get_node interface v3
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/connector: fix minor typos in comments (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mipi: use dcs write for mipi_dsi_dcs_set_tear_scanline
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: use mipi_dsi_dcs_write_buffer where possible
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dsi: use stack buffer in mipi_dsi_dcs_write()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/zte: remove unneeded semicolon (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel-simple: Add missing BUS descriptions for some panels
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel-simple: Correct EDT ET057090DHU connector type
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: do not keep GPU dependent addresses (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/scheduler: improve job distribution with multiple queues
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: don't use ttm bo->offset v3 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: don't use ttm bo->offset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: ensure bridge suspend happens during
  PM (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Update DRIVER_DATE to 20200702 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Move the heartbeat into the high priority system wq
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Harden the heartbeat against a stuck driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Correctly advertise HBR3 for GEN11+ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix g4x fbc watermark enable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/icl+: Simplify combo/TBT PLL calculation call-chain
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl+: Fix TBT DPLL fractional divider for 38.4MHz
  ref clock (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Move obj->lut_list under its own lock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: remove alias to dig_port (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add PSR2 selective fetch registers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Reorder intel_psr2_config_valid() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add plane damage clips property (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Avoid kmalloc under i915->mm_lock (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Suppress spurious underruns on gen2 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Reduce fbc1 compression interval to 1 second
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: Store the fbc1 compression interval in the params
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: Parametrize FBC_CONTROL (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Don't clear busy_bits for origin==GTT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: fix missing null check on allocated dsb object
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: fix a couple of spelling mistakes in kernel
  parameter help (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: HDCP: retry link integrity check on failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Clamp linetime wm to <64usec (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gen12: implement Wa_14011508470 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Extend Wa_14010685332 to all ICP+ PCH's
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix DP_TRAIN_MAX_{PRE_EMPHASIS,SWING}_REACHED handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp_mst: Enable VC payload allocation after transcoder
  is enabled (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp_mst: Clear the ACT sent flag during encoder
  disabling too (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp_mst: Clear only the ACT sent flag from DP_TP_STATUS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp_mst: Move clearing the ACT sent flag closer to
  its polling (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp_mst: Disable link training fallback on MST links
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl+: Use the correct DP_TP_* register instances in
  MST encoders (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/params: switch to device specific parameters
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Replace manual kmap_atomic() with pin_map for
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Drop redundant prepare_write/pin_pages
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Show the culmative runtime as part of the
  engine info (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Initialise rps timestamp (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/query: Use struct_size() helper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Always report the sample time for busy-stats
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Enable selftesting of busy-stats
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: fix spelling mistake "submited" ->
  "submitted" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Check preemption rollback of different
  ring queue (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Use friendly request names for
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Exercise far preemption rollbacks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Remove redundant i915_request_await_object in
  blit clears (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Mark up inline getters as taking a const i915_request
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Fix inconsistent IS_ERR and PTR_ERR
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Don't flush the tasklet if not setup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Add a safety submission flush in the heartbeat
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Dump engine state and trace upon
  hanging after (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Disable preemptive heartbeats over
  preemption (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Flush gen3 relocs harder, again (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Trim execlists runtime (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/execlists: Lift opportunistic process_csb to
  before engine (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Leave vma intact as they are discarded (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Remove live_suppress_wait_preempt
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp_mst: Fix disabling MST on a port (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix the i915_dsc_fec_support debugfs file for DP
  MST connectors (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Include context status in debug dumps
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Teach hang-self to target only itself
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/rkl: Don't try to read out DSI transcoders
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/rkl: Update TGP's pin mapping when paired with RKL
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/rkl: RKL uses ABOX0 for pixel transfers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Make the hanging request non-preemptible
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Adjust the sentinel assert to match implementation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/i915: Remove unneeded hack now for CDCLK"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/psr: Program default IO buffer Wake and Fast Wake
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Restore DP-E to VBT mapping table (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Delete unused code (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Correct discard i915_vma_compare assertion
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Discard a misplaced GGTT vma (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Always check to enable timeslicing if not
  submitting (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Set timeslicing priority from queue (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Include the engine's fw-domains in the debug info
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix comments mentioning typo in IS_ENABLED()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Async GPU relocations only (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add psr_safest_params (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/rkl: Disable PSR2 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/rkl: Don't try to access transcoder D (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/rkl: Setup ports/phys (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Add HBR and HBR2+ voltage swing table
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix wrong CDCLK adjustment changes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/rkl: Handle comp master/slave relationships for PHYs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/rkl: Add DDC pin mapping (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/rkl: provide port/phy mapping for vbt (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/rkl: Set transcoder mask properly (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Track if an engine requires forcewake w/a
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Trim set_timer_ms() intervals (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Implement WA_16011163337 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Exercise all copy engines with the
  blt routines (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Replace some hand rolled max()s (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Reverse preemph vs. voltage swing preference
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add {preemph,voltage}_max() vfuncs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix ivb cpu edp vswing (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix ibx max vswing/preemph (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix cpt/ppt max pre-emphasis (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Drop i915_request.i915 backpointer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Suppress the error message for GT init failure
  on error (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Make the CTX_TIMESTAMP readable on !rcs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Identify Cometlake platform (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Ignore autoincrementing timestamp
  on verfifying whitelists (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Dont forget to clean up the connector on
  error (v2) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/params: prevent changing module params runtime
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Move legacy context wa to intel_workarounds
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Split low level gen2-7 CS emitters (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Update TC DP vswing table (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Trim the ironlake+ irq handler (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Relinquish forcewake immediately after manual grouping
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Handle very early engine initialisation failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add Plane color encoding support for YCBCR_BT2020
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Give each object class a friendly name
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Taint all shrinkable object locks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add a few asserts around handling of (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Replace I915_MODE_FLAG_INHERITED with a boolean
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Stop using mode->private_flags (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Start timeslice on partial submission
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Don't declare hangs if engine is stalled
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Remove local entries from GGTT on suspend
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Restore both GGTT bindings on resume
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Clear LOCAL_BIND from shared GGTT on resume
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Improve execute_cb struct packing (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/execlists: Shortcircuit queue_prio() for no
  internal levels (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Force the GT reset on shutdown (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Fix early deref of 'dsb' (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Stop cross-polluting PIN_GLOBAL with PIN_USER with
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Suppress some random warnings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Cancel the flush worker more thoroughly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsb: Pre allocate and late cleanup of cmd buffer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix includes and local vars order (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/ehl: Extend w/a 14010685332 to JSP/MCC (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove unneeded hack now for CDCLK (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Adjust CDCLK accordingly to our DBuf bw needs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Introduce for_each_dbuf_slice_in_mask macro
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Plane configuration affects CDCLK in Gen11+
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Check plane configuration properly (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Extract cdclk requirements checking to separate
  function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Decouple cdclk calculation from modeset checks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Remove PIN_UPDATE for i915_vma_pin (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Flush the submission, not cancel
  it! (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Measure CS_TIMESTAMP (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/ehl: Wa_22010271021 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/rkl: RKL only uses PHY_MISC for PHY's A and B
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/rkl: Add power well support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/rkl: Limit number of universal planes to 5
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/rkl: Update memory bandwidth parameters (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/rkl: Add PCH support (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/rkl: Load DMC firmware for Rocket Lake (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/rkl: Re-use TGL GuC/HuC firmware (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/rkl: Add RKL platform info and PCI ids (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Kick virtual siblings on timeslice out
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Add tests for timeslicing virtual engines
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Check for an initial-breadcrumb in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Change priority overflow detection
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Measure dispatch latency (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/runtime_pm: Prefer drm_WARN* over WARN* (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/pm: Prefer drm_WARN_ON over WARN_ON (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/pmu: Prefer drm_WARN_ON over WARN_ON (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/i915_drv: Prefer drm_WARN_ON over WARN_ON
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Prefer drm_WARN* over WARN* (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display/tc: Prefer drm_WARN_ON over WARN_ON
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/sdvo: Prefer drm_WARN* over WARN*
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/dp: Prefer drm_WARN* over WARN* (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display/display_power: Prefer drm_WARN_ON over WARN_ON
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Read out hrawclk on all gen3+ platforms
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Document our lackluster FSB frequency readout
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix 400 MHz FSB readout on elk (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Return error from dbuf allocation failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix dbuf slice mask when turning off all the pipes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Reuse the tasklet priority for virtual as
  their siblings (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Refactor sibling selection (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Retry faulthandlers on ENOSPC (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Clean up dbuf debugs during .atomic_check()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move the dbuf pre/post plane update (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Nuke skl_ddb_get_hw_state() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Introduce proper dbuf state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Unify the low level dbuf code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Polish some dbuf debugs (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Make skl_compute_dbuf_slices() behave consistently
  for all platforms (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Protect overlay colorkey macro arguments
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Enable pipe gamma for the overlay (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Configure overlay cc_out precision based on crtc
  gamma config (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix overlay colorkey for 30bpp and 8bpp
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix max cursor size for i915g/gm (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable runtime pm on vega10 when noretry=0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: rework runtime pm enablement for BACO
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: call release_firmware() without a NULL check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Fix circular locking dependency warning
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: fix array out-of-bounds read and write issues
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: ensure 0 is returned for success in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: make sure to reserve tmr region on all asics which
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: return current DCEFCLK on sysfs read (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/powerplay: fix compilation warning (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: 3.2.91 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Release 1.0.19 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: DP link layer test 4.2.1.1 fix due to
  specs update (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: allow query ddc data over aux to be read only
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Compare v_front_porch when checking if streams
  are (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: enable seamless boot for dcn30 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Red screen observed on startup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Allow 4 split on 10K 420 modes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: VSC SDP supported for SST (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fill in dmub_srv fw_version from firmware
  metadata (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Force ODM combine on 5K+ 420 modes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix 4to1 odm MPC_OUT_FLOW_CONTROL_COUNT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: use dispclk AVFS for dppclk (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: add mechanism to skip DCN init (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fine tune logic of edid max TMDS clock check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Added local_sink null check before access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: clip plane rects in DM before passing into DC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.90 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Release 1.0.18 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Correctly respond in psr enablement interface
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix DML failures caused by doubled stereo
  viewport (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: enable assr (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: implement edid max TMDS clock check in DC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Release 1.0.17 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fixed using wrong eDP power sequence function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix calculation of virtual channel payload
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Release 1.0.16 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use dmub fw to lock pipe, cursor, dig
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm amdgpu: SI UVD enabled on Verde, Tahiti, Pitcairn
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm amdgpu: SI UVD enable for Oland (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm amdgpu: SI UVD add uvd_v3_1 to makefile (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm amdgpu: SI UVD context rreg/wreg (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm amdgpu: SI UVD v3_1 (v2) (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm amdgpu: SI UVD registers (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm amdgpu: SI UVD PACKET_TYPE0 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm amdgpu: SI UVD add firmwares (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/uvd3.x: fix register definition warnings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix compilation error on allmodconfig
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix unused variable (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: sdma v5_2 ring bo mem leak (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: remove perf level dpm in one-VF (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add XGMI support for sienna cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: restrict the hw sched jobs number to power of two
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Update bounding box states (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: remove redundant initialization of variable ret
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove unused functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/display: properly guard the calls to swSMU functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display bail early in dm_pp_get_static_clocks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn2.0: fix no previous prototype for functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn1.0: fix no previous prototype for functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/pm: fix ref count leak when pm_runtime_get_sync fails
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/debugfs: fix ref count leak when pm_runtime_get_sync
  fails (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: label internally used symbols as static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/powerplay: label internally used symbols as static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: label internally used symbols as static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: label internally used symbols as static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/jpeg2.0: fix no previous prototype for functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/jpeg1.0: fix no previous prototype for functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: fix ref count leak when pm_runtime_get_sync fails
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/fence: fix ref count leak when pm_runtime_get_sync
  fails (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/debugfs: fix memory leak when (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/debugfs: fix memory leak when pm_runtime_get_sync
  failed (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: vcn_v2_5_mc_resume_dpg_mode() can be static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix compiler warning (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/smu: unify smu ppt callback macros (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/smu: unify pptable_func{} callback interface
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Update DCN3 bounding box (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: remove distinction between explicit and implicit
  sync (v2) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: Fix offset for SQ_DEBUG_STS_GLOBAL on gfx10 (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: Fix reference count leaks caused by
  pm_runtime_get_sync (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: fix ref count leak when pm_runtime_get_sync
  fails (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix ref count leak in amdgpu_display_crtc_set_config
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix ref count leak in amdgpu_drm_ioctl
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix ref count leak in amdgpu_driver_open_kms
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: fix multiple reference count leak (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/gfx9: Fix incorrect firmware size calculation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Fix reference count leaks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: Add eviction debug messages (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: Fix SQ_DEBUG_STS_GLOBAL* registers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Get num_chans from VBIOS table (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd: add missing fill of the array`s first element
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Reconfigure ULV for gfx9 server SKUs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: 3.2.89 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Release 1.0.15 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Not doing bios data pack (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: not reset dmub in driver (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Disable pipe split for modes with borders
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: change global buffer to local buffer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Improve DisplayPort monitor interop
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Enable use of dmub iff dmcu is disabled
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: make calculate watermarks a function pointer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add helper to convert DC status (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: add support for per-state dummy-pstate latency
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Revert "DP link layer test 4.2.1.1 fix
  due to specs (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove unnecessary mpcc updates (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: runtime select dmub emulatior (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Passing initial SDP deadline to dmub
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Force delay after DP receive power up
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.88 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Release 1.0.14 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: update audio wall clock programming
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix VBA chroma calculation for pipe splitting
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Revert "enable plane if plane_status changed"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove unused macro from dcn21 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Use u16 for drm_bpp in DSC calculations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Move call to disable DPG (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Release 1.0.13 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix incorrect dcn1 bandwidth calculations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: correct alpha_en programming for new
  pixel format (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: Add SQ_DEBUG_STS_GLOBAL* registers/bits
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/jpeg: fix race condition issue for jpeg start
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sriov: Need to clear kiq position (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/sriov: Disable pm for multiple vf sriov
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sriov: Add clear vf fw support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix the nullptr issue as for PWR IP not existing in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Fix a buffer overflow handling the serial number
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: maximum code sharing on sensor reading
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: revise the calling chain on sensor reading
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary SMU_MSG_GetDpmClockFreq
  check (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary wrapper .populate_smc_tables
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop redundant .set_min_dcefclk_deep_sleep
  API (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd: correct trivial kernel-doc inconsistencies
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: Add SQ debug registers to GFX9/GFX10
  headers (v2) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: handle return value of amdgpu_driver_load_kms
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: move maximum sustainable clock retrieving to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add check for power limit OD support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: correct power limit retrieving based
  on current (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unused code around power limit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: simplify the code around setting power limit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: simplify the code around retrieving
  power limit (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: maximize code sharing around power limit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary get_pptable_power_limit
  wrappers (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: correct the APIs' naming (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary wrappers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: drop dead vce powergate code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: add error messages on some critical paths
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: forbid to use pr_err/warn/info/debug
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: use MGPU friendly err/warn/info/dbg messages
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/soc15: fix nullptr issue in soc15_read_register() for
  reg (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix indenting in
  dcn30_set_output_transfer_func() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: skip BAR resizing if the bios already did it
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: use the same interval as PMFW on retrieving
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update how to use metrics table on
  Sienna Cichlid (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update how to use metrics table on Navi10
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update how to use metrics table on Arcturus
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: drop duplicated .dsc_pg_control for dcn30
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: drop duplicated structure (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: update driver if file for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update powerplay table for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add smu v11_0_7 pptable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: move powerplay table operation out of
  smu_v11_0.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: support reserve bad page for virt (v3)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: use work queue to perform throttling logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: skip BACO feature on DPMs disablement
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add firmware cleanup on sw_fini
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: move amdgpu_irq_src to the smu structure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: maximize code sharing between .hw_fini and
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: better namings (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: sort those operations performed in hw setup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: maximize code sharing between .hw_init
  and .resume (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: move those operations not needed for resume
  out (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: postpone operations not required for hw setup
  to (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: clean up the overdrive settings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: clean up the APIs for pptable setup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: clean up the APIs for bootup clocks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: centralize all buffer allocation in
  sw_init phase (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: implement a common API for dpms disablement
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unused APIs and unnecessary checks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: eliminate asic type check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix spelling mistake: "propogation" ->
  "propagation" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/fence: use the no_scheduler flag (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Revert "drm/[radeon|amdgpu]: Replace one-element array and
  use struct_size() helper" (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Only actually breakpoint if DEBUG_KERNEL_DC is
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: use existed smu_dpm_set* interfaces to
  implement (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: temporarily read bounding box from gpu_info fw
  for navi12 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 to Kconfig (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add DCN3 blocks to Makefile (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/display: fix build without CONFIG_DRM_AMD_DC_DCN3_0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix and simplify pipe split logic for DCN3
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Enable DM block for DCN3 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Remove Unused Registers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Handle RGBE_ALPHA Pixel Format (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Init function tables for DCN3 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add DCN3 VPG (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 AFMT (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 Command Table Helpers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add DCN3 Resource (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add DCN3 Support in DM (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add DCN3 HWSEQ (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 DMUB (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 GPIO (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 IRQ (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 DML (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 DWB (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 MMHUBHUB (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add DCN3 HUBP (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 HUBHUB (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 DPP (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 MPC (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 OPP header (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add DCN3 OPTC (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 DCCG (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 CLK_MGR (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 DIO (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DCN3 chip ids (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: bypass tmr when reserve c2p memory (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: remove unnecessary check for mem train
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: support memory training for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: reserve fb according to return value from vbios
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: let PMFW to handle the features disablement
  on (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop sienna_cichlid hardcode of using pptable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update smu function for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update golden setting for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/psp: support for loading PSP SPL fw (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/psp: initialization PSP SPL fw (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/psp: add structure to support PSP SPL (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: show gfxclk=0 in gfxoff state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable gfxoff for sienna_cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: disable gfxoff to retrieve gfxclk
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: support mclk socclk limit value set for
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sriov : Add sriov detection for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: only use one gfx pipe for Sienna_Cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop jpeg instance1 dpm setup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: disable runtime pm for sienna_cichlid temporarily
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable fw ctf (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: skip GPU scheduler setup for KIQ and MES ring
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable VDDCI and MVDD for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: append pptable for sienna_cichlid (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: and smc dpm info struct for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sriov : Use kiq to do tlb invalidation for gfx10
  on sriov (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable ULCK DS for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn3.0: schedule instance 0 for decode and 1
  for encode (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes10.1: add no scheduler flag for mes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable DPG mode for VCN3.0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add workaround for issue in DPG for VCN3.0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: rename macro for VCN2.0 2.5 and 3.0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: rename macro for VCN1.0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add internal reg offset translation for VCN inst 1
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: set indirect sram mode for VCN3.0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add pause DPG mode for VCN3.0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add stop DPG mode for VCN3.0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add start DPG mode for VCN3.0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add mc resume DPG mode for VCN3.0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add clock gating DPG mode for VCN3.0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/am/powerplay: enable OUT OF BAND MONITER for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable RSMU SMN PG for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update golden setting for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: bundle GPO with gfx DPM (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: enable GPO (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable mmhub pg (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: enable athub pg (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: skip VM inv eng assignment for mes ring
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes: allocate memory slots for hw resource setting
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes: add status fence memory definitions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes: update mes fw api (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add function to get power limit for
  sienna_cichlid (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable APCC DFLL for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable BACO for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Sienna_Cichlid don't enable SMU for SRIOV
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable MM DPM PG for sienna_cichlid (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix typo for vcn3/jpeg3 idle check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: enable FCLK DS for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable VR0HOT for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: sienna_cichlid virtual function support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Support debugger in Navi1x trap handler
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Support newer assemblers in gfx10 trap handler
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Add Sienna_Cichlid trap handler support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Support Sienna_Cichlid KFD v4 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/dc: Add missing Sienna_Cichlid chip id
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable 3D pipe 1 on Sienna_Cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix SDMA hdp flush engine conflict (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Enable Multi Media Hub (MMHUB) Clock Gating for
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: add athub ls support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: add IH cg support (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: add HDP mgcg and ls support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: fix the HDP LS/DS/SD programming (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: update golden setting for gfx10.3 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: set the LMI ctrl and reset earlier (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix the PSP front door loading VCN firmware
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: change the offset for VCN FW cache window
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: open GFX clock gating for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: switch to query reserved fb size from vbios (v3)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add atomfirmware helper funciton to query reserved
  fb (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add firmware_info v3_4 structure for Sienna_Cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: only send one sdma firmware for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: drop gfx_v10_0_tiling_mode_table_init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: support query vram info for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add vram_info v2_5 in atomfirmware header
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: disable gfxoff for sienna_cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add cp firmware backdoor loading triger
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: force pa_sc_tile_steering_override to 0 for gfx10.3
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx10: add gc golden setting for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable JPEG3.0 for Sienna_Cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable JPEG3.0 PG and CG for Sienna_Cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add Sienna_Cichlid JPEG PG and CG support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add JPEG3.0 support for Sienna_Cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable VCN3.0 for Sienna_Cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add Sienna_Cichlid VCN to the VCN family
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable VCN3.0 PG and CG for Sienna_Cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add Sienna_Cichlid VCN PG and CG support (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add VCN3.0 support for Sienna_Cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes: correct register offset for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update the num of queue per pipe for mec on
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add mes block to sienna_cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/mes10.1: update mes initialization (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: no need to set up GPU scheduler for mes ring
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/psp: convert amdgpu mes ucode type (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: upload mes firmware to gpu buffer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/mes10.1: copy mes fw info into global fw array
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes10.1: add sienna_cichlid mes firmware support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes10.1: implement setting hardware resources
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes10.1: implement querying the scheduler status
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes10.1: implement removing hardware queue
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes10.1: implement adding hardware queue
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes10.1: add the helper function for mes command
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes10.1: add the mes fw api (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/mes10.1: enable the mes ring during initialization
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes10.1: install mes queue via kiq (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/mes10.1: install mes queue by register programming
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes10.1: initialize the mqd (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/mes10.1: allocate mqd buffer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/mes10.1: implement the ring functions of mes specific
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes10.1: initialize the software part of mes ring
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/mes10.1: allocate the eop buffer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/mes: update some mes definitions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: avoid dereferencing a NULL pointer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add the ring type definition of MES (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: assign the doorbell index to mes ring
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add 2rd VCN instance doorbell support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add psp block load condition for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add gmc cg support for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add support for athub v2.1 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Use variable instead of constant for sdma
  doorbell range (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update SDMA 5.2 microcode init (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable psp ip block for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: skip for reroute ih for sienna_cichlid psp ring init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/psp: add psp support for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: skip ASD fw load for sienna_cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/powerplay: add smu block for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable PPT and TDC for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: support to get power index for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable Fan control for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable GFX SS for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable LCLK DPM for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: support to print pcie levels for
  sienna_cichlid (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: support pcie value set and update for
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable DCEFCLK DPM and DS for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: Enable SOCCLK ULV for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: make gfx ds can be configure for
  sienna_cichlid (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/powerplay: set UCLK DPM for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/powerplay: set Thermal control for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable SOC Clock Deep Sleep for
  sienna_cichlid (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable Graphics Clock Deep Sleep for
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable Ultra Low Voltage for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: set FCLK DPM for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: set SOCCLK DPM for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add support to set performance level for
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/powerplay: add initial swSMU support for
  sienna_cichlid (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add virtual display support for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx10: change register configure for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: correct SDMA3 IH clinet id for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add sdma ip block for sienna_cichlid (v5)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add sdma2 and sdma3 irqsrc header files for
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add gfx ip block for sienna_cichlid (v3)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add ih ip block for sienna_cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add gmc ip block for sienna_cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add support gfxhub for sienna_cichlid (v3)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add support on mmhub for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/soc15: add common ip block for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: initialize IP offset for sienna_cichlid (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/soc15: add support for sienna_cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/gfx10: add clockgating support for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gmc10: add sienna_cichlid support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/gfx10: add support for sienna_cichlid firmware
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: set asic family and ip blocks for sienna_cichlid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: set fw load type for sienna_cichlid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add sienna_cichlid gpu info firmware v2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add sienna_cichlid asic type (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add dcn30 Headers (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add VCN3.0 register headers (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Add ATHUB 2.1 header files (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add GC 10.3 header files (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: restrict bo mapping within gpu address limits
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add unique_id and serial_number for Arcturus v3
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add ReadSerial defines for Arcturus (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: remove useless code in RAS (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix RAS memory leak in error case (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/fru: fix header guard and include header
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/nv: enable init reset check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/nv: remove some dead code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/nv: allow access to SDMA status registers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use IP discovery table for renoir (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: clean up discovery testing (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: skip gpu_info firmware if discovery info is
  available (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: give better names for the thermal IRQ
  related APIs (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: use the common APIs for IRQ
  disablement/enablement (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: stop thermal IRQs on suspend (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: added a sysfs interface for thermal throttling
  related V4 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable thermal throttling logging support V2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: implement ASIC specific thermal throttling
  logging (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update Arcturus smu-driver headers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: fix a dereference of pdd before it is null checked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gmc10: program the smallK fragment size
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Fix GCC 10 compiler warning (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: Fix the CGCG setting is overwritten for SRIOV
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.87 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Don't compare same stream for synchronized
  vblank (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Release 1.0.12 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: enable plane if container of plane_status
  changed (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: combine public interfaces into single header
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Allow Diagnostics test with eDP not connected
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: unit show garbage when do OPTC blank
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Guard against invalid array access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Disable PG on NV12 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Increase Default Sizes of FW State and
  Trace Buffer (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Handle link loss interrupt better
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: simplify dml log2 function (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix incorrect HDCP caps for dongle
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: link_status not align when power off encoder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.86 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Improve the MTYPE comments (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: Track SDMA utilization per process (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: add check before i2c_add_adapter
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: remove SRIOV check in SMU11 (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable SMC message filter (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: add SMC message filter for SMU11
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: check whether SMU IP is enabled before access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Make BREAK_TO_DEBUGGER() a debug print
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/[radeon|amdgpu]: Replace one-element array and use
  struct_size() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon/dpm: Replace one-element array and use struct_size()
  helper (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: put some case statments in family order
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sdma4: simplify the logic around powering up sdma
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: simplify mec2 fw check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: simplify CZ/ST and KV/KB/ML checks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: simplify raven and renoir checks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/gfx10: add navi12 to gfxoff case (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/sdma4: add renoir to powergating setup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: simplify ATIF backlight handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/radeon: disable AGP by default (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: print warning when input address is invalid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: skip smu_i2c_eeprom_init/fini under
  sriov mode (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: remove the support of vega20 from swsmu
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: remove the support of xgmi pstate on
  vega20 from (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: change memory training to common function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: FW Release 1.0.11 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Remove nv12 work around (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix dml immediate flip input (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix dml log2 function (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Support CW4 for DMUB ringbuffer inbox
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DMUB firmware version helpers in
  DMUB service (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: vbios data table packing (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: DP link layer test 4.2.1.1 fix due to
  specs update (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: update dml interfaces and variables
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.85 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix ABM memory alignment issue (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: FW release 1.0.10 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Implement some asic specific abm call backs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add bit swap helper based on endianness
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Don't pass invalid fw_bss_data pointer
  into DMUB srv (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Check bss_data_size before going down
  legacy DMUB (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Do not fail if build scaling params fails
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Handle persistence in DM (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/debug: Expose connector VRR monitor range via debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bochs: use drm_gem_vram_offset to get bo offset v2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vram-helper: don't use ttm bo->offset v4 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/qxl: don't use ttm bo->offset (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: don't use ttm bo->offset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: move ttm bo->offset to amdgpu_bo (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: dw-mipi-dsi.c: remove unused header file
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: minor doc touch-ups (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mipi-dbi: Remove ->enabled (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tiny/repaper: Drop edp->enabled (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: bridge: dw-hdmi: Make connector creation optional
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: dw-hdmi: Pass drm_connector to internal functions
  as (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: dw-hdmi: Store current connector in struct dw_hdmi
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: dw-hdmi: Split connector creation to a separate
  function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: dw-hdmi: Pass drm_display_info to
  dw_hdmi_support_scdc() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: dw-hdmi: Constify mode argument to internal
  functions (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: dw-hdmi: Constify mode argument to dw_hdmi_phy_ops
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: dw-hdmi: Pass drm_display_info to .mode_valid()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: meson: dw-hdmi: Use dw_hdmi context to replace hack
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: dw-hdmi: Remove unused field from dw_hdmi_plat_data
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: dw-hdmi: Pass private data pointer to
  .configure_phy() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: dw-hdmi: Pass private data pointer to .mode_valid()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: Pass drm_display_info to drm_bridge_funcs
  .mode_valid() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: edid: Constify connector argument to infoframe functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: simple-bridge: Make connector creation optional
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: simple-bridge: Delegate operations to next bridge
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: Return NULL on error from drm_bridge_get_edid()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: adv7511: Make connector creation optional
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: adv7511: Implement bridge connector operations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: adv7511: Split connector creation to a separate
  function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: adv7511: Split EDID read to a separate function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mm/selftests: fix wrong return type casting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mm: cleanup and improve next_hole_*_addr() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mm: optimize find_hole() as well (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mm: remove unused rb_hole_size() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Use per-device logging macros (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Upcast from DRM device to ast structure via
  to_ast_private() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Remove test for device from ast_pm_freeze()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Remove unused code paths for AST 1180 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: simple: add Tianma TM070JVHG33 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: simple: add CDTech S070PWS19HP-FC21 and
  S070SWV29HG-DC44 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: tfp410: Fix setup and hold time calculation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: tfp410: fix de-skew value retrieval from DT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel-simple: Add missing connector type for some panels
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: otm8009a: Drop unnessary
  backlight_device_unregister() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/dp: DRM DP helper for reading Ignore MSA from DPCD
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/arm: fix unintentional integer overflow on left shift
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: drm_fourcc: Add uncompressed AFBC modifier (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: drm_fourcc: add NV15, Q410, Q401 YUV formats
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panfrost: Use kvfree() to free bo->sgts (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panfrost: Fix runtime PM imbalance on error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panfrost: Fix inbalance of devfreq record_busy/idle()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Check the regmap return value
  when setting (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Fix kernel-doc typo ln_polr =>
  ln_polrs (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Don't use kernel-doc comment for local
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Don't compile GPIO bits if not
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panfrost: Reduce the amount of logs on deferred probe
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: Add per-pixel alpha support for the PX30 VOP
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/shmem-helper: Only dma-buf imports are private obj
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/shmem-helper: Fix obj->filp derefence (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/kselftest: fix spellint typo in test-drm_mm.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Use managed pci functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/malidp: convert platform driver to use dev_groups
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/arm: Kconfig annotate drivers as COMPILE_TEST
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/todo: Add item about modeset properties (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/auth: make drm_{set,drop}master_ioctl symmetrical
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: vmwgfx: remove drm_driver::master_set() return type
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mm: remove invalid entry based optimization (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Fix flushing the delayed port/mstb destroy work
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Fix the DDC I2C device registration of an MST port
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Fix the DDC I2C device unregistration of an MST port
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp_mst: Work around out-of-spec adapters filtering
  short pulses (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Sanitize mgr->qlock locking in
  drm_dp_mst_wait_tx_reply() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Use managed device initialization (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mgag200: Embed instance of struct drm_device in struct
  mga_device (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Allocate device structures in mgag200_driver_load()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Separate device initialization into allocation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Move device init and cleanup to mgag200_drv.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Prefix symbol names in mgag200_drv.c with mgag200_
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Separate DRM and PCI functionality from each other
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Switch to managed MM (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Merge VRAM setup into MM initialization
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Lookup VRAM PCI BAR start and length only once
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Rename mgag200_ttm.c to mgag200_mm.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Use pcim_enable_device() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mgag200: Remove mgag200_cursor.c (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mgag200: Remove declaration of mgag200_mmap() from
  header file (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drivers: gpu: drm: Fix trivial spelling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: crtc: Restrict HACT_ACT setup to DSI (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: crtc: Turn static const variable into a define
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4: crtc: Move crtc state to common header (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: crtc: Switch to of_device_get_match_data
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4: crtc: Rename SoC data structures (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: plane: Move additional planes creation to driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4: plane: Move planes creation to its own function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4: drv: Add include guards (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Use GEM vmap/mmap function from SHMEM helpers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/shmem-helper: Add .gem_create_object helper that sets
  map_cached (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Remove struct drm_driver.gem_print_info (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/zte: Set GEM CMA functions with DRM_GEM_CMA_DRIVER_OPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/zte: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tve200: Set GEM CMA functions with DRM_GEM_CMA_DRIVER_OPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tve200: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tilcdc: Set GEM CMA functions with DRM_GEM_CMA_DRIVER_OPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tilcdc: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/sti: Set GEM CMA functions with DRM_GEM_CMA_DRIVER_OPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sti: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/stm: Set GEM CMA functions with (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/stm: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/shmobile: Set GEM CMA functions with DRM_GEM_CMA_DRIVER_OPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/shmobile: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/rcar-du: Set GEM CMA functions with (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/rcar-du: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mxsfb: Set GEM CMA functions with DRM_GEM_CMA_DRIVER_OPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mxsfb: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/meson: Set GEM CMA functions with (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/meson: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mcde: Set GEM CMA functions with DRM_GEM_CMA_DRIVER_OPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mcde: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/malidp: Set GEM CMA functions with (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/malidp: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/komeda: Set GEM CMA functions with (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/komeda: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ingenic: Set GEM CMA functions with DRM_GEM_CMA_DRIVER_OPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ingenic: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/imx: Set GEM CMA functions with DRM_GEM_CMA_DRIVER_OPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/imx: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/hisilicon/kirin: Set GEM CMA functions with (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/hisilicon/kirin: Use GEM CMA object functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/hisilicon/kirin: Set .dumb_create to
  drm_gem_cma_dumb_create() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/fsl-dcu: Set GEM CMA functions with DRM_GEM_CMA_DRIVER_OPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/fsl-dcu: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/atmel-hlcdc: Set GEM CMA functions with
  DRM_GEM_CMA_DRIVER_OPS (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/atmel-hlcdc: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/arm: Set GEM CMA functions with DRM_GEM_CMA_DRIVER_OPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/arm: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/arc: Set GEM CMA functions with DRM_GEM_CMA_DRIVER_OPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/arc: Use GEM CMA object functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/cma-helper: Add DRM_GEM_CMA_DRIVER_OPS to set default GEM
  CMA (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/cma-helper: Rework DRM_GEM_CMA_VMAP_DRIVER_OPS macro
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/cma-helper: Rename symbols from drm_cma_gem_ to drm_gem_cma_
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/shmem-helpers: Simplify dma-buf importing (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/shmem-helpers: Ensure get_pages is not called on imported
  dma-buf (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mm: add ig_frag selftest (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: document how user-space should use link-status
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: simple: Add support for KOE TX26D202VM0BWA panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: simple: Set connector type for DSI panels
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mm: fix hole size comparison (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/hdlcd: Don't call drm_crtc_vblank_off on unbind
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/malidp: Don't call drm_crtc_vblank_off on unbind
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/shmem-helpers: Redirect mmap for imported dma-buf
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/shmem-helpers: Don't call get/put_pages on imported
  dma-buf in vmap (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Don't call get/put_pages on imported dma-buf
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: Call the right shmem helpers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/doc: Some polish for shmem helpers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gem: WARN if drm_gem_get_pages is called on a private obj
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: Don't call dma_buf_vunmap without _vmap (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: add docs for standard CRTC properties (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: Use IS_BUILTIN (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: pxafb: Use correct return value for pxafb_probe()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: pxafb: Fix the function used to balance a (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drivers: video: hdmi: cleanup coding style in video a bit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- console: newport_con: fix an issue about leak related system
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: sm712fb: fix an issue about iounmap for a
  wrong address (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- omapfb/dss: fix comparison to bool warning (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: DPMS is no longer the only mutable connector prop
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: convert get_user_pages() --> pin_user_pages()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: fix error handling for get_user_pages_fast()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vblank: use drm_WARN for all warnings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vblank: use drm_* functions for logging (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Documentation: Fix typo error in todo.rst (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: use drm_dev_has_vblank more (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: Stop using mode->private_flags (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mcde: Use mode->clock instead of reverse calculating it
  from the vrefresh (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: pahole struct drm_display_mode (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Flatten drm_mode_vrefresh() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Shrink drm_display_mode timings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Make mode->flags u32 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Shrink mode->type to u8 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Shrink {width,height}_mm to u16 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: Stop copying around mode->private_flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Nuke mode->vrefresh (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Introduce some local intel_dp variables
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/format-helper: Add drm_fb_swab() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/client: Add drm_client_modeset_check() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/client: Add drm_client_framebuffer_flush() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: hdmi: Silence pixel clock error on -EPROBE_DEFER
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/auth: remove redundant assignment to variable ret
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/writeback: don't set fence->ops to default (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Restore the NULL check for drm_gem_object_put()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-fence: add might_sleep annotation to _wait() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/file: wrap excessively long line (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: print the current->comm alongside the pid (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: remove transient drm_gem_object_put_unlocked()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/xen: remove _unlocked suffix in drm_gem_object_put_unlocked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vkms: remove _unlocked suffix in drm_gem_object_put_unlocked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: remove _unlocked suffix in
  drm_gem_object_put_unlocked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vgem: remove _unlocked suffix in drm_gem_object_put_unlocked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4: remove _unlocked suffix in drm_gem_object_put_unlocked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/v3d: remove _unlocked suffix in drm_gem_object_put_unlocked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: remove _unlocked suffix in
  drm_gem_object_put_unlocked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: remove _unlocked suffix in
  drm_gem_object_put_unlocked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: remove _unlocked suffix in
  drm_gem_object_put_unlocked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/qxl: remove _unlocked suffix in drm_gem_object_put_unlocked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panfrost: remove _unlocked suffix in
  drm_gem_object_put_unlocked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/omapdrm: remove _unlocked suffix in
  drm_gem_object_put_unlocked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: remove _unlocked suffix in
  drm_gem_object_put_unlocked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: remove _unlocked suffix in drm_gem_object_put_unlocked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: remove _unlocked suffix in
  drm_gem_object_put_unlocked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: remove _unlocked suffix in
  drm_gem_object_put_unlocked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: remove _unlocked suffix in drm_gem_object_put_unlocked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: remove _unlocked suffix in drm_gem_object_put_unlocked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: remove _unlocked suffix in
  drm_gem_object_put_unlocked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: remove _unlocked suffix in
  drm_gem_object_put_unlocked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: remove _unlocked suffix in
  drm_gem_object_put_unlocked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/armada: remove _unlocked suffix in
  drm_gem_object_put_unlocked (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/arm: remove _unlocked suffix in drm_gem_object_put_unlocked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd: remove _unlocked suffix in drm_gem_object_put_unlocked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: remove _unlocked suffix in drm_gem_object_put_unlocked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gem: add drm_gem_object_put helper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gem: add _locked suffix to drm_gem_object_put
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gem: fold drm_gem_object_put_unlocked and
  __drm_gem_object_put() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: remove drm_driver::gem_free_object (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gma500: Use lockless gem BO free callback (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: use the unlocked drm_gem_object_put (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/doc: drop struct_mutex reference for drm_gem_object_free
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/doc: add WARNING for drm_device::struct_mutex
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/doc: drop struct_mutex references (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/todo: mention i915 in the struct_mutex section
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gem: use _unlocked reference in drm_gem_objects_lookup docs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: remove unused drm_gem.h include (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mgag200: Replace VRAM helpers with SHMEM helpers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Convert to simple KMS helper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mgag200: Use simple-display data structures (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mgag200: Remove out-commented suspend/resume helpers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Move register initialization into separate function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Move hiprilvl setting into separate functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Move TAGFIFO reset into separate function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Set primary plane's format in separate helper
  function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Set pitch in a separate helper function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Update mode registers after plane registers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Split MISC register update into PLL selection, SYNC
  and (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Move mode-setting code into separate helper
  function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Clean up mga_crtc_do_set_base() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mgag200: Clean up mga_set_start_address() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mgag200: Remove HW cursor (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tilcdc: add missing static for panel_driver (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tilcdc: remove unnecessary state->fb check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tilcdc: fix leak & null ref in panel_connector_get_modes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Implement lane reordering + polarity
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Fix off-by-one error in clock choice
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Clear old error bits before AUX
  transfers (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Export bridge GPIOs to Linux
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Match drm_dp_send_clear_payload_id_table definition to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Describe dp_rev for drm_dp_set_phy_test_pattern
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Help unconfuse gcc, avoid accidental impossible unsigned
  comparisons (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Include internal header for managed function declarations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: amba-clcd: use devm_of_find_backlight (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Add DRM_MODE_TYPE_USERDEF flag to probed modes matching
  a video= (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/debugfs: fix plain echo to connector "force" attribute
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gem: Fix a leak in drm_gem_objects_lookup() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/rockchip: vop: call vop_cfg_done() under reg_lock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tilcdc: use devm_of_find_backlight (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: display: use devm_of_find_backlight (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Fix timeout handling of MST down messages
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vblank: remove outdated and noisy output (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- nouveau/svm: use the new migration invalidation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- mm/notifier: add migration invalidation type (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- mm/migrate: add a flags parameter to migrate_vma (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- nouveau: fix storing invalid ptes (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- nouveau/hmm: support mapping large sysmem pages (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- nouveau: fix mapping 2MB sysmem pages (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- nouveau/hmm: fault one page at a time (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- mm/hmm: provide the page mapping order in hmm_range_fault()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: lvds-codec: simplify error handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge/sii8620: fix resource acquisition error handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- driver core: add device probe log helper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Documentation: gpu/drm-uapi: eliminate duplicated word
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Documentation: gpu/komeda-kms: eliminate duplicated word
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- docs: move nommu-mmap.txt to admin-guide and rename to ReST
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- treewide: Remove uninitialized_var() usage (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: remove fb-puv3 driver (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- commit ee626ec
* Fri Nov 27 2020 ptesarik@suse.cz
- scsi: zfcp: Clarify access to erp_action in
  zfcp_fsf_req_complete() (jsc#SLE-15871 bsc#1176961 LTC#187760).
- scsi: zfcp: Use list_first_entry_or_null() in zfcp_erp_thread()
  (jsc#SLE-15871 bsc#1176961 LTC#187760).
- scsi: zfcp: Avoid benign overflow of the Request Queue's
  free-level (jsc#SLE-15871 bsc#1176961 LTC#187760).
- scsi: zfcp: Replace open-coded list move (jsc#SLE-15871
  bsc#1176961 LTC#187760).
- scsi: zfcp: Clean up zfcp_erp_action_ready() (jsc#SLE-15871
  bsc#1176961 LTC#187760).
- scsi: zfcp: Use prandom_u32_max() for backoff (jsc#SLE-15871
  bsc#1176961 LTC#187760).
- commit 6b83ff7
* Fri Nov 27 2020 ptesarik@suse.cz
- scsi: zfcp: use fallthrough; (jsc#SLE-15871 bsc#1176961
  LTC#187760).
- Refresh
  patches.suse/scsi-zfcp-Move-shost-updates-during-xconfig-data-han.patch.
- commit f093ef6
* Fri Nov 27 2020 ptesarik@suse.cz
- Move endpoint security DASD info patches to the sorted section
- patches.suse/s390-sles15sp3-03-01-s390-cio-Export-information-about-Endpoint-Security-.patch
- patches.suse/s390-sles15sp3-03-02-s390-cio-Provide-Endpoint-Security-Mode-per-CU.patch
- patches.suse/s390-sles15sp3-03-03-s390-cio-Add-support-for-FCES-status-notification.patch.
- patches.suse/s390-sles15sp3-03-04-s390-dasd-Remove-unused-parameter-from-dasd_generic_.patch
- patches.suse/s390-sles15sp3-03-05-s390-dasd-Move-duplicate-code-to-separate-function.patch
- patches.suse/s390-sles15sp3-03-06-s390-dasd-Store-path-configuration-data-during-path-.patch
- patches.suse/s390-sles15sp3-03-07-s390-dasd-Fix-operational-path-inconsistency.patch
- patches.suse/s390-sles15sp3-03-08-s390-dasd-Display-FC-Endpoint-Security-information-v.patch
- patches.suse/s390-sles15sp3-03-09-s390-dasd-Prepare-for-additional-path-event-handling.patch
- patches.suse/s390-sles15sp3-03-10-s390-dasd-Process-FCES-path-event-notification.patch
- commit 5e6fdd9
* Fri Nov 27 2020 jlee@suse.com
- efi/libstub: Rename efi_call_early/_runtime macros to be more
  intuitive (jsc#SLE-16407).
- Refresh
  patches.suse/0001-efi-generalize-efi_get_secureboot.patch.
- Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- Refresh
  patches.suse/0006-efi-allow-user-to-regenerate-secret-key.patch.
- commit 34853ac
* Fri Nov 27 2020 jlee@suse.com
- efi/libstub: Remove 'sys_table_arg' from all function prototypes
  (jsc#SLE-16407).
- Refresh
  patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch.
- Refresh
  patches.suse/0001-efi-generalize-efi_get_secureboot.patch.
- commit f1a59c9
* Fri Nov 27 2020 jlee@suse.com
- efi/libstub: Drop sys_table_arg from printk routines
  (jsc#SLE-16407).
- Refresh
  patches.suse/0001-efi-generalize-efi_get_secureboot.patch.
- Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- Refresh
  patches.suse/0006-efi-allow-user-to-regenerate-secret-key.patch.
- commit cbab4fc
* Thu Nov 26 2020 mgorman@suse.de
- sched: Fix data-race in wakeup (bnc#1178227).
- Delete
  patches.suse/sched-Fix-loadavg-accounting-race-on-arm64-kabi.patch.
  Replaces a KABI-safe fix in SP2 with the upstream version.
- commit 1fe5fc0
* Thu Nov 26 2020 nsaenzjulienne@suse.de
- of/address: check for invalid range.cpu_addr (jsc#SLE-16543).
- commit 3da893a
* Thu Nov 26 2020 nsaenzjulienne@suse.de
- powerpc: Drop using struct of_pci_range.pci_space field
  (jsc#SLE-16543).
- commit 55da8d8
* Thu Nov 26 2020 lhenriques@suse.de
- ceph: downgrade warning from mdsmap decode to debug
  (bsc#1178653).
- ceph: fix race in concurrent __ceph_remove_cap invocations
  (bsc#1178635).
- commit b0ab459
* Thu Nov 26 2020 ptesarik@suse.cz
- s390/dasd: fix null pointer dereference for ERP requests
  (git-fixes).
- s390/cpum_sf.c: fix file permission for cpum_sfb_size
  (git-fixes).
- s390/pkey: fix paes selftest failure with paes and pkey static
  build (git-fixes).
- s390/bpf: Fix multiple tail calls (git-fixes).
- commit d7dbfa4
* Thu Nov 26 2020 msuchanek@suse.de
- powerpc/pseries: new lparcfg key/value pair:
  partition_affinity_score (jsc#SLE-16360 jsc#SLE-16915).
- powerpc/perf: consolidate GPCI hcall structs into asm/hvcall.h
  (jsc#SLE-16360 jsc#SLE-16915).
- commit 918cff8
* Thu Nov 26 2020 nsaenzjulienne@suse.de
- Update configs: Refresh arm64's config
- commit 96a2987
* Thu Nov 26 2020 msuchanek@suse.de
- MAINTAINERS: remove John Allen from ibmvnic (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- commit 223af9b
* Thu Nov 26 2020 nsaenzjulienne@suse.de
- dt-bindings: pwm: Add binding for RPi firmware PWM bus
  (jsc#SLE-16543).
- staging: vchiq: Release firmware handle on unbind
  (jsc#SLE-16543).
- soc: bcm: raspberrypi-power: Release firmware handle on unbind
  (jsc#SLE-16543).
- reset: raspberrypi: Release firmware handle on unbind
  (jsc#SLE-16543).
- pwm: Add Raspberry Pi Firmware based PWM bus (jsc#SLE-16543).
- Update configs
- supported.conf: Enable pwm driver
- input: raspberrypi-ts: Release firmware handle when not needed
  (jsc#SLE-16543).
- gpio: raspberrypi-exp: Release firmware handle on unbind
  (jsc#SLE-16543).
- firmware: raspberrypi: Keep count of all consumers
  (jsc#SLE-16543).
- firmware: raspberrypi: Introduce devm_rpi_firmware_get()
  (jsc#SLE-16543).
- clk: bcm: rpi: Release firmware handle on unbind
  (jsc#SLE-16543).
- arm64: mm: Set ZONE_DMA size based on early IORT scan
  (jsc#SLE-17068).
- arm64: mm: Set ZONE_DMA size based on devicetree's dma-ranges
  (jsc#SLE-17068).
- of/address: Introduce of_dma_get_max_cpu_address()
  (jsc#SLE-17068).
- arm64: mm: Move zone_dma_bits initialization into
  zone_sizes_init() (jsc#SLE-17068).
- arm64: mm: Move reserve_crashkernel() into mem_init()
  (jsc#SLE-17068).
- arm64: Force NO_BLOCK_MAPPINGS if crashkernel reservation is
  required (jsc#SLE-17068).
- arm64: Ignore any DMA offsets in the max_zone_phys() calculation
  (jsc#SLE-17068).
- usb: host: pci-quirks: Bypass xHCI quirks for Raspberry Pi 4
  (jsc#SLE-17068).
- reset: Add Raspberry Pi 4 firmware reset controller
  (jsc#SLE-17068).
- Update configs
- supported.conf: Enable reset controller
- dt-bindings: reset: Add a binding for the RPi Firmware reset
  controller (jsc#SLE-17068).
- soc: bcm2835: Add notify xHCI reset property (jsc#SLE-17068).
- of/address: Support multiple 'dma-ranges' entries
  (jsc#SLE-17068).
- of/address: use range parser for of_dma_get_range
  (jsc#SLE-17068).
- of/address: Rework of_pci_range parsing for non-PCI buses
  (jsc#SLE-17068).
- of: Drop struct of_pci_range.pci_space field (jsc#SLE-17068).
- of/address: Move range parser code out of CONFIG_PCI
  (jsc#SLE-17068).
- usb: xhci: Enable LPM for VIA LABS VL805 (jsc#SLE-17068).
- Refresh:  patches.suse/usb-xhci-define-IDs-for-various-ASMedia-host-control.patch
- commit 410dbc7
* Thu Nov 26 2020 nsaenzjulienne@suse.de
- Revert "USB: pci-quirks: Add Raspberry Pi 4 quirk (bsc#1163560)." (jsc#SLE-17068)
  We can now use the proper upstream patch series:
  https://lkml.org/lkml/2020/6/29/606
  This reverts commit e30de5ffe3acb6c8dd1892793ce6899a79bd38bd.
- commit 1644970
* Thu Nov 26 2020 nsaenzjulienne@suse.de
- Revert "soc: bcm2835: Sync xHCI reset firmware property with downstream" (jsc#SLE-17068)
  We can now use the proper upstream patch series:
  https://lkml.org/lkml/2020/6/29/606
  This reverts commit 32f4877b5567ad9d16055f194bb21bb6dde55341.
- commit ded9d4a
* Thu Nov 26 2020 nsaenzjulienne@suse.de
- Revert "firmware: raspberrypi: Introduce vl805 init routine" (jsc#SLE-17068)
  We can now use the proper upstream patch series:
  https://lkml.org/lkml/2020/6/29/606
  This reverts commit d18390349922079ee04fe357c88651c04db51968.
- commit 585af47
* Thu Nov 26 2020 nsaenzjulienne@suse.de
- Revert "PCI: brcmstb: Wait for Raspberry Pi's firmware when present" (jsc#SLE-17068)
  We can now use the proper upstream patch series:
  https://lkml.org/lkml/2020/6/29/606
  This reverts commit 41c84ba0bba58cf9d61a81aeb6e3eb4b1fcc468f.
- commit 9addf5a
* Thu Nov 26 2020 nsaenzjulienne@suse.de
- Revert "Refresh: patches.suse/firmware-raspberrypi-introduce-vl805-init-routine.patch" (jsc#SLE-17068)
  We can now use the proper upstream patch series:
  https://lkml.org/lkml/2020/6/29/606
  This reverts commit 24cdb0de74210a49a6118ffa6db198eca0f0aad9.
- commit 233d8c1
* Thu Nov 26 2020 nsaenzjulienne@suse.de
- Revert "Update patches.suse/firmware-raspberrypi-introduce-vl805-init-routine.patch." (jsc#SLE-17068)
  We can now use the proper upstream patch series:
  https://lkml.org/lkml/2020/6/29/606
  This reverts commit 984c0bd050167f3492694794b785e90921bc60e9.
- commit b168995
* Thu Nov 26 2020 oneukum@suse.com
- tpm: efi: Don't create binary_bios_measurements file for an
  empty log (git-fixes).
- x86/i8259: Use printk_deferred() to prevent deadlock
  (git-fixes).
- commit 91b284d
* Thu Nov 26 2020 martin.wilck@suse.com
- scsi: core: Return BLK_STS_AGAIN for ALUA transitioning
  (bsc#1165933, bsc#1171000).
- commit 56a64e3
* Thu Nov 26 2020 oneukum@suse.com
- fpga: add kABI padding (jsc#SLE-13441).
- commit 963653a
* Thu Nov 26 2020 msuchanek@suse.de
- ibmvnic: Do not replenish RX buffers after every polling loop
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Use netdev_alloc_skb instead of alloc_skb to replenish
  RX buffers (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Correctly re-enable interrupts in NAPI polling routine
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Ensure that device queue memory is cache-line aligned
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Remove send_subcrq function (jsc#SLE-17043 bsc#1179243
  ltc#189290).
- ibmvnic: Clean up TX code and TX buffer data structure
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Introduce xmit_more support using batched subCRQ hcalls
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Introduce batched RX buffer descriptor transmission
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Introduce indirect subordinate Command Response Queue
  buffer (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: fix NULL pointer dereference in ibmvic_reset_crq
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: skip tx timeout reset while in resetting (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: create send_control_ip_offload (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: create send_query_ip_offload (jsc#SLE-17043 bsc#1179243
  ltc#189290).
- ibmvnic: rename send_map_query to send_query_map (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: rename ibmvnic_send_req_caps to send_request_cap
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: rename send_cap_queries to send_query_cap
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- Revert "ibmvnic: remove never executed if statement"
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Harden device Command Response Queue handshake
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: merge ibmvnic_reset_init and ibmvnic_init
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- Refresh patches.suse/ibmvnic-restore-adapter-state-on-failed-reset.patch.
- ibmvnic: remove never executed if statement (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: improve ibmvnic_init and ibmvnic_reset_init
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: compare adapter->init_done_rc with more readable
  ibmvnic_rc_codes (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Fix use-after-free of VNIC login response buffer
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: store RX and TX subCRQ handle array in ibmvnic_adapter
  struct (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: update MAINTAINERS (jsc#SLE-17043 bsc#1179243
  ltc#189290).
- ibmvnic: Do not replenish RX buffers after every polling loop
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Use netdev_alloc_skb instead of alloc_skb to replenish
  RX buffers (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Correctly re-enable interrupts in NAPI polling routine
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Ensure that device queue memory is cache-line aligned
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Remove send_subcrq function (jsc#SLE-17043 bsc#1179243
  ltc#189290).
- ibmvnic: Clean up TX code and TX buffer data structure
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Introduce xmit_more support using batched subCRQ hcalls
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Introduce batched RX buffer descriptor transmission
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Introduce indirect subordinate Command Response Queue
  buffer (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: enhance resetting status check during module exit
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: fix NULL pointer dereference in ibmvic_reset_crq
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: fix NULL pointer dereference in reset_sub_crq_queues
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: skip tx timeout reset while in resetting (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: notify peers when failover and migration happen
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: fix call_netdevice_notifiers in do_reset (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: create send_control_ip_offload (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: create send_query_ip_offload (jsc#SLE-17043 bsc#1179243
  ltc#189290).
- ibmvnic: rename send_map_query to send_query_map (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: rename ibmvnic_send_req_caps to send_request_cap
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: rename send_cap_queries to send_query_cap
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- Revert "ibmvnic: remove never executed if statement"
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Harden device Command Response Queue handshake
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: merge ibmvnic_reset_init and ibmvnic_init
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: remove never executed if statement (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: improve ibmvnic_init and ibmvnic_reset_init
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: compare adapter->init_done_rc with more readable
  ibmvnic_rc_codes (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Fix use-after-free of VNIC login response buffer
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: store RX and TX subCRQ handle array in ibmvnic_adapter
  struct (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: update MAINTAINERS (jsc#SLE-17043 bsc#1179243
  ltc#189290).
- commit a8dadbf
* Thu Nov 26 2020 yousaf.kaukab@suse.com
- arm64: mm: fix inverted PAR_EL1.F check (jsc#13705,jsc#13695).
- arm64: mm: fix spurious fault detection (jsc#13705,jsc#13695).
- commit 0de2657
* Thu Nov 26 2020 jlee@suse.com
- arm64: mm: use single quantity to represent the PA to VA
  translation (jsc#SLE-16407).
- commit 202adf6
* Thu Nov 26 2020 jlee@suse.com
- docs: arm64: Add layout and 52-bit info to memory document
  (jsc#SLE-16407).
- arm64: mm: Remove vabits_user (jsc#SLE-16407).
- arm64: mm: Separate out vmemmap (jsc#SLE-16407).
  Refresh
  patches.suse/0002-arm64-rename-variables-used-to-calculate-ZONE_DMA32-.patch
  patches.suse/0003-arm64-use-both-ZONE_DMA-and-ZONE_DMA32.patch
  patches.suse/arm64-mm-Introduce-52-bit-Kernel-VAs.patch
- commit 0d98a48
* Thu Nov 26 2020 jlee@suse.com
- efi/x86: Don't remap text<->rodata gap read-only for mixed mode
  (jsc#SLE-16407).
- efi/x86: Fix the deletion of variables in mixed mode
  (jsc#SLE-16407).
- arm64: Fix kcore macros after 52-bit virtual addressing fallout
  (jsc#SLE-16407).
- arm64: fix fixmap copy for 16K pages and 48-bit VA
  (jsc#SLE-16407).
- arm64: memory: rename VA_START to PAGE_END (jsc#SLE-16407).
- arm64: memory: Add comments to end of non-trivial #ifdef blocks
  (jsc#SLE-16407).
- arm64: memory: Simplify _VA_START and _PAGE_OFFSET definitions
  (jsc#SLE-16407).
- arm64: memory: Rewrite default page_to_virt()/virt_to_page()
  (jsc#SLE-16407).
- arm64: memory: Ensure address tag is masked in conversion macros
  (jsc#SLE-16407).
- arm64: memory: Fix virt_addr_valid() using __is_lm_address()
  (jsc#SLE-16407).
- arm64: mm: Simplify definition of virt_addr_valid()
  (jsc#SLE-16407).
- arm64: mm: Introduce 52-bit Kernel VAs (jsc#SLE-16407).
- arm64: mm: Modify calculation of VMEMMAP_SIZE (jsc#SLE-16407).
- arm64: mm: Logic to make offset_ttbr1 conditional
  (jsc#SLE-16407).
- arm64: mm: Introduce vabits_actual (jsc#SLE-16407).
  Refresh
  patches.suse/0002-arm64-rename-variables-used-to-calculate-ZONE_DMA32-.patch
  patches.suse/0003-arm64-use-both-ZONE_DMA-and-ZONE_DMA32.patch
- arm64: dump: De-constify VA_START and KASAN_SHADOW_START
  (jsc#SLE-16407).
- arm64: mm: Remove bit-masking optimisations for PAGE_OFFSET
  and VMEMMAP_START (jsc#SLE-16407).
- commit 65ae799
* Thu Nov 26 2020 clin@suse.com
- Fix compiler warnings (jsc#SLE-15020)
- Refresh
  patches.suse/0001-efi-generalize-efi_get_secureboot.patch.
  patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch.
- commit c2e474d
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: fix relocation failure due to race with fallocate
  (bsc#1179217).
- commit e680b1d
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: rename btrfs_insert_clone_extent() to a more generic name
  (bsc#1179217).
- commit 27c703c
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: imx8mm: fix voltage for 1.6GHz CPU operating point
  (git-fixes).
- commit 36b05ae
* Wed Nov 25 2020 yousaf.kaukab@suse.com
- arm64: signal: nofpsimd: Handle fp/simd context for signal frames (jsc#13705,jsc#13695).
- arm64: fpsimd: Make sure SVE setup is complete before SIMD is used (jsc#13705,jsc#13695).
- arm64: Introduce system_capabilities_finalized() marker (jsc#13705,jsc#13695).
  Refresh:
  patches.suse/arm64-tlb-Use-the-TLBI-RANGE-feature-in-arm64.patch
- arm64: kpti: Add Broadcom Brahma-B53 core to the KPTI whitelist (jsc#13705,jsc#13695).
- arm64: Introduce ID_ISAR6 CPU register (jsc#13705,jsc#13695).
- arm64: cpufeature: Export matrix and other features to userspace (jsc#13705,jsc#13695).
  Refresh:
  patches.suse/arm64-tlb-Detect-the-ARMv8.4-TLBI-RANGE-feature.patch
- arm64: docs: cpu-feature-registers: Document ID_AA64PFR1_EL1 (jsc#13705,jsc#13695).
- arm64: cpufeature: Fix typos in comment (jsc#13705,jsc#13695).
- docs/arm64: cpu-feature-registers: Rewrite bitfields that don't follow [e, s] (jsc#13705,jsc#13695).
- docs/arm64: cpu-feature-registers: Documents missing visible fields (jsc#13705,jsc#13695).
- arm64: sysreg: fix incorrect definition of SYS_PAR_EL1_F (jsc#13705,jsc#13695).
- arm64: entry.S: Do not preempt from IRQ before all cpufeatures are enabled (jsc#13705,jsc#13695).
- arm64: kvm: Replace hardcoded '1' with SYS_PAR_EL1_F (jsc#13705,jsc#13695).
- arm64: mm: Ignore spurious translation faults taken from the kernel (jsc#13705,jsc#13695).
- arm64: sysreg: Add some field definitions for PAR_EL1 (jsc#13705,jsc#13695).
- arm64: mm: Add ISB instruction to set_pgd() (jsc#13705,jsc#13695).
- arm64: constify sys64_hook instances (jsc#13705,jsc#13695).
- arm64: constify aarch64_insn_encoding_class (jsc#13705,jsc#13695).
- arm64: constify icache_policy_str (jsc#13705,jsc#13695).
- arm64: sysreg: Remove unused and rotting SCTLR_ELx field definitions (jsc#13705,jsc#13695).
  Refresh:
  patches.suse/arm64-cpufeature-Add-remaining-feature-bits-in-ID_AA.patch
- commit 844c03f
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: h5: OrangePi Prime: Fix ethernet node
  (git-fixes).
- commit 858be95
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: a64: bananapi-m64: Enable RGMII RX/TX
  delay on PHY (git-fixes).
- commit 5a17bb5
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: h5: OrangePi PC2: Fix ethernet node
  (git-fixes).
- commit b4307bb
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: a64: Pine64 Plus: Fix ethernet node
  (git-fixes).
- commit dfebf26
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: a64: OrangePi Win: Fix ethernet node
  (git-fixes).
- commit 4eec57a
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: Pine H64: Enable both RGMII RX/TX delay
  (git-fixes).
- commit 8bd0d47
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: beelink-gs1: Enable both RGMII RX/TX
  delay (git-fixes).
- commit 62c9be4
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: fsl: DPAA FMan DMA operations are coherent
  (git-fixes).
- commit b68f0fe
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: zynqmp: Remove additional compatible string for
  i2c IPs (git-fixes).
- commit 99df01c
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: imx8mq: Add missing interrupts to GPC (git-fixes).
- commit 1af8481
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: imx8mq: Fix TMU interrupt property (git-fixes).
- commit de53464
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: tegra: Add missing timeout clock to Tegra194 SDMMC nodes
  (git-fixes).
- commit 6169028
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: rename btrfs_punch_hole_range() to a more generic name
  (bsc#1179217).
- commit ae0b28b
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: tegra: Add missing timeout clock to Tegra186 SDMMC nodes
  (git-fixes).
- commit 044ef73
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: tegra: Add missing timeout clock to Tegra210 SDMMC
  (git-fixes).
- commit f6b3b97
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: rename struct btrfs_clone_extent_info to a more generic
  name (bsc#1179217).
- commit de43bbe
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: vdso: Add --eh-frame-hdr to ldflags (git-fixes).
- commit 937dc61
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: vdso: Add '-Bsymbolic' to ldflags (git-fixes).
- commit 96e1736
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: remove item_size member of struct btrfs_clone_extent_info
  (bsc#1179217).
- commit d01ef40
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: kprobe: add checks for ARMv8.3-PAuth combined
  instructions (git-fixes).
- commit c7c922c
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: fix metadata reservation for fallocate that leads to
  transaction aborts (bsc#1179217).
- commit 68ec4df
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: bpf: Fix branch offset in JIT (git-fixes).
- commit dcf0a55
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: fix bytes_may_use underflow in prealloc error condtition
  (bsc#1179217).
- commit c6b65e2
* Wed Nov 25 2020 aaptel@suse.com
- cifs: Fix incomplete memory allocation on setxattr path
  (bsc#1179211).
- commit 17e4326
* Wed Nov 25 2020 tiwai@suse.de
- Re-enable openSUSE Leap features (jsc#SLE-11796)
  Most of Leap 15.2 configs are taken over for x86_64 and arm64, while a
  few features are dropped (e.g. PCMCIA, X32, ISDN).  ppc64le and s390x
  are kept unchanged.  The Leap-only modules are packaged into
  kernel-*-optional subpackage.
- commit d64e6b6
* Wed Nov 25 2020 tiwai@suse.de
- Fix wrongly set CONFIG_SOUNDWIRE=y (bsc#1179201)
  CONFIG_SOUNDWIRE was mistakenly set as built-in.  Mark it as module.
- commit 8298c55
* Wed Nov 25 2020 tiwai@suse.de
- ACPICA: Add NHLT table signature (bsc#1176200).
- commit c68e192
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: Run ARCH_WORKAROUND_2 enabling code on all CPUs
  (git-fixes).
- commit 2b0db2e
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: Run ARCH_WORKAROUND_1 enabling code on all CPUs
  (git-fixes).
- commit 8d1bf8e
* Wed Nov 25 2020 mbrugger@suse.com
- KVM: arm64: ARM_SMCCC_ARCH_WORKAROUND_1 doesn't return
  SMCCC_RET_NOT_REQUIRED (git-fixes).
- commit 3fc2241
* Wed Nov 25 2020 dwagner@suse.de
- qla2xxx: Add MODULE_VERSION back to driver (bsc#1179160).
- commit 5e4a1f7
* Wed Nov 25 2020 tiwai@suse.de
- efivarfs: fix memory leak in efivarfs_create() (git-fixes).
- staging: rtl8723bs: Add 024c:0627 to the list of SDIO device-ids
  (git-fixes).
- mmc: sdhci-pci: Prefer SDR25 timing for High Speed mode for
  BYT-based Intel controllers (git-fixes).
- hwmon: (pwm-fan) Fix RPM calculation (git-fixes).
- ACPI: button: Add DMI quirk for Medion Akoya E2228T (git-fixes).
- commit 0493181
* Wed Nov 25 2020 tiwai@suse.de
- dmaengine: idxd: Add shared workqueue support (jsc#SLE-12688).
- Update config files: CONFIG_INTEL_IDXD_SVM=y
- commit cda5f69
* Wed Nov 25 2020 tiwai@suse.de
- dmaengine: idxd: define table offset multiplier (jsc#SLE-12688).
- dmaengine: idxd: Update calculation of group offset to be more
  readable (jsc#SLE-12688).
- dmaengine: idxd: Add ABI documentation for shared wq
  (jsc#SLE-12688).
- dmaengine: idxd: Clean up descriptors with fault error
  (jsc#SLE-12688).
- commit 84ee085
* Wed Nov 25 2020 jlee@suse.com
- Documentation/admin-guide/module-signing.rst: add openssl
  command option example for CodeSign EKU (bsc#1177353,
  bsc#1179076).
- modsign: Add codeSigning EKU when generating X.509 key
  generation config (bsc#1177353, bsc#1179076).
- commit 09c2c7d
* Wed Nov 25 2020 tiwai@suse.de
- dmaengine: idxd: add sysfs ABI for idxd driver (jsc#SLE-12688).
- Refresh
  patches.suse/dmaengine-idxd-export-hw-version-through-sysfs.patch.
- commit 30e848c
* Wed Nov 25 2020 tiwai@suse.de
- dmaengine: idxd: fix mapping of portal size (jsc#SLE-12688).
- dmaengine: idxd: fix wq config registers offset programming
  (jsc#SLE-12688).
- dmaengine: idxd: add command status to idxd sysfs attribute
  (jsc#SLE-12688).
- dmaengine: idxd: add support for configurable max wq batch size
  (jsc#SLE-12688).
- dmaengine: idxd: add support for configurable max wq xfer size
  (jsc#SLE-12688).
- dmaengine: idxd: clear misc interrupt cause after read
  (jsc#SLE-12688).
- dmaengine: idxd: add leading / for sysfspath in ABI
  documentation (jsc#SLE-12688).
- commit 428b8a5
* Wed Nov 25 2020 tiwai@suse.de
- x86/asm: Add an enqcmds() wrapper for the ENQCMDS instruction
  (jsc#SLE-12688).
- x86/asm: Carve out a generic movdir64b() helper for general
  usage (jsc#SLE-12688).
- commit 269143b
* Wed Nov 25 2020 jlee@suse.com
- driver core: Add support for linking devices during device
  addition (jsc#SLE-16407).
- driver core: Add fwnode_to_dev() to look up device from fwnode
  (jsc#SLE-16407).
- commit 0ba9e50
* Tue Nov 24 2020 mkubecek@suse.cz
- Update patches.suse/icmp-randomize-the-global-rate-limiter.patch
  references (add CVE-2020-25705 bsc#1175721).
- commit 302c097
* Tue Nov 24 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/sched-Fix-rq-nr_iowait-ordering.patch
  patches.suse/sched-fair-Ensure-tasks-spreading-in-LLC-during-LB.patch
  patches.suse/sched-fair-Fix-unthrottle_cfs_rq-for-leaf_cfs_rq-list.patch
- commit 07cd2c9
* Tue Nov 24 2020 mgorman@suse.de
- blacklist.conf: Kernel building with clang is not supported
- commit 66e9cbf
* Tue Nov 24 2020 mgorman@suse.de
- sched/fair: Fix unthrottle_cfs_rq() for leaf_cfs_rq list
  (git fixes (sched)).
- commit 155f594
* Tue Nov 24 2020 mgorman@suse.de
- sched: Fix rq->nr_iowait ordering (git fixes (sched)).
- commit 0f2faa6
* Tue Nov 24 2020 mgorman@suse.de
- sched/fair: Ensure tasks spreading in LLC during LB (git fixes
  (sched)).
- commit f2af668
* Tue Nov 24 2020 mgorman@suse.de
- blacklist.conf: Alternative KABI-safe fix used instead (bnc#1178227)
- commit 307bf60
* Tue Nov 24 2020 tiwai@suse.de
- net: sctp: Rename fallthrough label to unhandled (bsc#1178203).
- commit 6ea8e73
* Tue Nov 24 2020 oneukum@suse.com
- blacklist.conf: breaks kABI
- commit c7c8b0d
* Tue Nov 24 2020 oneukum@suse.com
- timer: Fix wheel index calculation on last level (git-fixes).
- commit 7f8a2b1
* Tue Nov 24 2020 oneukum@suse.com
- timer: Prevent base->clk from moving backward (git-fixes).
- commit 48a61b6
* Tue Nov 24 2020 tiwai@suse.de
- Update patch reference for serial security fix (CVE-2020-15437 bsc#1179140)
- commit 195abfd
* Tue Nov 24 2020 ptesarik@suse.cz
- s390/zcrypt: Fix ZCRYPT_PERDEV_REQCNT ioctl (bsc#1177070
  LTC#188342).
- s390/zcrypt: fix kmalloc 256k failure (bsc#1177066 LTC#188341).
- commit 0bca1b7
* Tue Nov 24 2020 ptesarik@suse.cz
- s390/cpum_cf,perf: change DFLT_CCERROR counter name (bsc#1175918
  LTC#187935).
- commit 142fe1e
* Tue Nov 24 2020 ohering@suse.de
- video: hyperv_fb: include vmalloc.h (git-fixes).
- commit 9598448
* Tue Nov 24 2020 jlee@suse.com
- arm64: mm: convert mm/dump.c to use walk_page_range()
  (jsc#SLE-16407).
- efi/arm: Defer probe of PCIe backed efifb on DT systems
  (jsc#SLE-16407).
- arm/efi: EFI soft reservation to memblock (jsc#SLE-16407).
- arm64: memory: fix flipped VA space fallout (jsc#SLE-16407).
- commit aa2fd77
* Tue Nov 24 2020 tiwai@suse.de
- compiler_attributes.h: Add 'fallthrough' pseudo keyword for
  switch/case use (bsc#1178203).
- commit 83cd53c
* Tue Nov 24 2020 tiwai@suse.de
- ALSA: usb-audio: Fix MOTU M-Series quirks (bsc#1178203).
- ALSA: usb-audio: Fix quirks for other BOSS devices
  (bsc#1178203).
- ALSA: usb-audio: Add implicit_fb module option (bsc#1178203).
- ALSA: usb-audio: Add generic implicit fb parsing (bsc#1178203).
- ALSA: usb-audio: Factor out the implicit feedback quirk code
  (bsc#1178203).
- ALSA: usb-audio: Quirk for BOSS GT-001 (bsc#1178203).
- ALSA: usb-audio: Show sync endpoint information in proc outputs
  (bsc#1178203).
- ALSA: usb-audio: Use unsigned char for iface and altsettings
  fields (bsc#1178203).
- ALSA: usb-audio: Replace slave/master terms (bsc#1178203).
- ALSA: usb-audio: Simplify rate_min/max and rates set up
  (bsc#1178203).
- ALSA: usb-audio: Unify the code for the next packet size
  calculation (bsc#1178203).
- ALSA: usb-audio: Drop unneeded snd_usb_substream fields
  (bsc#1178203).
- ALSA: usb-audio: Refactoring endpoint URB deactivation
  (bsc#1178203).
- ALSA: usb-audio: Use atomic_t for endpoint use_count
  (bsc#1178203).
- ALSA: usb-audio: Constify audioformat pointer references
  (bsc#1178203).
- ALSA: usb-audio: Fix possible stall of implicit fb packet
  ring-buffer (bsc#1178203).
- ALSA: usb-audio: Refactor endpoint management (bsc#1178203).
- ALSA: usb-audio: Fix EP matching for continuous rates
  (bsc#1178203).
- ALSA: usb-audio: Always set up the parameters after resume
  (bsc#1178203).
- ALSA: usb-audio: Set callbacks via
  snd_usb_endpoint_set_callback() (bsc#1178203).
- ALSA: usb-audio: Stop both endpoints properly at error
  (bsc#1178203).
- ALSA: usb-audio: Simplify snd_usb_init_pitch() arguments
  (bsc#1178203).
- ALSA: usb-audio: Simplify snd_usb_init_sample_rate() arguments
  (bsc#1178203).
- ALSA: usb-audio: Pass snd_usb_audio object to quirk functions
  (bsc#1178203).
- ALSA: usb-audio: Don't set altsetting before initializing
  sample rate (bsc#1178203).
- ALSA: usb-audio: Add snd_usb_get_host_interface() helper
  (bsc#1178203).
- ALSA: usb-audio: Drop keep_interface flag again (bsc#1178203).
- ALSA: usb-audio: Create endpoint objects at parsing phase
  (bsc#1178203).
- ALSA: usb-audio: Avoid doubly initialization for implicit fb
  (bsc#1178203).
- ALSA: usb-audio: Drop debug.h (bsc#1178203).
- ALSA: usb-audio: Simplify hw_params rules (bsc#1178203).
- ALSA: usb-audio: Add hw constraint for implicit fb sync
  (bsc#1178203).
- ALSA: usb-audio: Move snd_usb_autoresume() call out of
  setup_hw_info() (bsc#1178203).
- ALSA: usb-audio: Track implicit fb sync endpoint in audioformat
  list (bsc#1178203).
- ALSA: usb-audio: Improve some debug prints (bsc#1178203).
- ALSA: usb-audio: Set and clear sync EP link properly
  (bsc#1178203).
- ALSA: usb-audio: Add snd_usb_get_endpoint() helper
  (bsc#1178203).
- ALSA: usb-audio: Check implicit feedback EP generically for UAC2
  (bsc#1178203).
- ALSA: usb-audio: Check valid altsetting at parsing rates for
  UAC2/3 (bsc#1178203).
- ALSA: usb-audio: Don't call usb_set_interface() at trigger
  callback (bsc#1178203).
- ALSA: usb-audio: Handle discrete rates properly in hw
  constraints (bsc#1178203).
- commit 25f15d1
* Tue Nov 24 2020 jlee@suse.com
- arm64: mm: Introduce VA_BITS_MIN (jsc#SLE-16407).
- Refresh
  patches.suse/efi-libstub-Rename-efi_call_early-_runtime-macros-to-966291f6.patch.
- Refresh
  patches.suse/efi-libstub-Get-rid-of-sys_table_arg-macro-parameter-2fcdad2a.patch.
- arm64: kasan: Switch to using KASAN_SHADOW_OFFSET
  (jsc#SLE-16407).
- arm64: mm: Flip kernel VA space (jsc#SLE-16407).
- commit 12d714f
* Mon Nov 23 2020 pjakobsson@suse.de
- Refresh
  patches.suse/1322-amdgpu-a-NULL-mm-does-not-mean-a-thread-is-a-kthread.patch.
- commit 2d2501a
* Mon Nov 23 2020 msuchanek@suse.de
- powerpc/rtas: Restrict RTAS requests from userspace
  (CVE-2020-27777 bsc#1179107).
  Update config files.
- commit 4d9370a
* Mon Nov 23 2020 pvorel@suse.cz
- Add missing '.patch' extension
- commit 6639fd0
* Mon Nov 23 2020 pvorel@suse.cz
- Add missing '.patch' extension
- commit cb5e93e
* Mon Nov 23 2020 tbogendoerfer@suse.de
- net/mlx5: E-Switch, Fail mlx5_esw_modify_vport_rate if qos
  disabled (jsc#SLE-8464).
- net/mlx5: Clear bw_share upon VF disable (jsc#SLE-8464).
- ionic: check port ptr before use (bsc#1167773).
- bnxt_en: Send HWRM_FUNC_RESET fw command unconditionally
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Check abort error state in bnxt_open_nic()
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Invoke cancel_delayed_work_sync() for PFs also
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix regression in workqueue cleanup logic in
  bnxt_remove_one() (jsc#SLE-8371 bsc#1153274).
- RDMA/mlx5: Fix devlink deadlock on net namespace deletion
  (jsc#SLE-8464).
- SUNRPC: fix copying of multiple pages in gss_read_proxy_verf()
  (bsc#1154353).
- RDMA/hns: Fix the wrong value of rnr_retry when querying qp
  (jsc#SLE-8449).
- RDMA/hns: Solve the overflow of the calc_pg_sz() (jsc#SLE-8449).
- RDMA/qedr: Fix return code if accept is called on a destroyed qp
  (jsc#SLE-8215).
- RDMA/ucma: Add missing locking around rdma_leave_multicast()
  (git-fixes).
- net: fix pos incrementment in ipv6_route_seq_next (bsc#1154353).
- bnxt_en: return proper error codes in bnxt_show_temp
  (git-fixes).
- igc: Fix not considering the TX delay for timestamps
  (bsc#1160634).
- igc: Fix wrong timestamp latency numbers (bsc#1160634).
- bnxt_en: Fix NULL ptr dereference crash in bnxt_fw_reset_task()
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Avoid sending firmware messages when AER error is
  detected (jsc#SLE-8371 bsc#1153274).
- commit b757d92
* Mon Nov 23 2020 tiwai@suse.de
- Update patch reference tag for fbcon fix (CVE-2020-28974 bsc#1178589)
- commit 4526eab
* Mon Nov 23 2020 msuchanek@suse.de
- powerpc/uaccess: Evaluate macro arguments once, before user access is
  allowed (CVE-2020-4788 bsc#1177666).
- commit 3a6dc74
* Mon Nov 23 2020 yousaf.kaukab@suse.com
- blacklist.conf: coresight: mark duplicate fixes
- commit 4122655
* Mon Nov 23 2020 oneukum@suse.com
- usb: core: driver: fix stray tabs in error messages (git-fixes).
- commit a37b0ae
* Mon Nov 23 2020 oneukum@suse.com
- Revert "cdc-acm: hardening against malicious devices"
  (git-fixes).
- commit 1bc383a
* Mon Nov 23 2020 jlee@suse.com
- efi/x86: Handle by-ref arguments covering multiple pages in
  mixed mode (jsc#SLE-16407).
- efi/x86: Remove support for EFI time and counter services in
  mixed mode (jsc#SLE-16407).
- efi/x86: Align GUIDs to their size in the mixed mode runtime
  wrapper (jsc#SLE-16407).
- efi/x86: Fix boot regression on systems with invalid memmap
  entries (jsc#SLE-16407).
- efi/x86: Disable instrumentation in the EFI runtime handling
  code (jsc#SLE-16407).
- efi/libstub/x86: Fix EFI server boot failure (jsc#SLE-16407).
- efi/x86: avoid KASAN false positives when accessing the 1:
  1 mapping (jsc#SLE-16407).
- efi: Fix comment for efi_mem_type() wrt absent physical
  addresses (jsc#SLE-16407).
  Refresh
  patches.suse/x86-efi-Delete-SGI-UV1-detection.patch
- efi/x86: Limit EFI old memory map to SGI UV machines
  (jsc#SLE-16407).
  Refresh
  patches.suse/x86-mm-efi-convert-ptdump_walk_pgd_level-to-take-a-mm_struct.patch
  patches.suse/x86-efi-Delete-SGI-UV1-detection.patch
- efi/x86: Avoid RWX mappings for all of DRAM (jsc#SLE-16407).
- efi/x86: Don't map the entire kernel text RW for mixed mode
  (jsc#SLE-16407).
- efi/libstub/x86: Fix unused-variable warning (jsc#SLE-16407).
- efi/libstub/x86: Use mandatory 16-byte stack alignment in
  mixed mode (jsc#SLE-16407).
- efi/libstub/x86: Use const attribute for efi_is_64bit()
  (jsc#SLE-16407).
  Refresh
  patches.suse/x86-boot-compressed-64-add-idt-infrastructure.
- efi: Allow disabling PCI busmastering on bridges during boot
  (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
  Update config files.
  Add "CONFIG_EFI_DISABLE_PCI_DMA is not set" to x86_64/default and
  arm64/default
- efi/x86: Allow translating 64-bit arguments for mixed mode calls
  (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- efi/x86: Check number of arguments to variadic functions
  (jsc#SLE-16407).
- efi/x86: Remove unreachable code in kexec_enter_virtual_mode()
  (jsc#SLE-16407).
- efi/x86: Don't panic or BUG() on non-critical error conditions
  (jsc#SLE-16407).
- efi/x86: Clean up efi_systab_init() routine for legibility
  (jsc#SLE-16407).
- efi/x86: Drop two near identical versions of efi_runtime_init()
  (jsc#SLE-16407).
- efi/x86: Simplify mixed mode call wrapper (jsc#SLE-16407).
- efi/x86: Simplify 64-bit EFI firmware call wrapper
  (jsc#SLE-16407).
- efi/x86: Simplify i386 efi_call_phys() firmware call wrapper
  (jsc#SLE-16407).
- efi/x86: Split SetVirtualAddresMap() wrappers into 32 and 64
  bit versions (jsc#SLE-16407).
- efi/x86: Split off some old memmap handling into separate
  routines (jsc#SLE-16407).
- efi/x86: Avoid redundant cast of EFI firmware service pointer
  (jsc#SLE-16407).
- efi/x86: Map the entire EFI vendor string before copying it
  (jsc#SLE-16407).
- efi/x86: Re-disable RT services for 32-bit kernels running on
  64-bit EFI (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
- efi/libstub/x86: Force 'hidden' visibility for extern
  declarations (jsc#SLE-16407).
- efi/libstub: Fix boot argument handling in mixed mode entry code
  (jsc#SLE-16407).
  Refresh
  patches.suse/x86-boot-compressed-64-add-idt-infrastructure
- efi/libstub/x86: Avoid globals to store context during mixed
  mode calls (jsc#SLE-16407).
- efi/libstub: Tidy up types and names of global cmdline variables
  (jsc#SLE-16407).
- commit 05d5a7e
* Mon Nov 23 2020 msuchanek@suse.de
- Refresh L1D flush patches to upstream.
- commit 6f67758
* Mon Nov 23 2020 yousaf.kaukab@suse.com
- config: arm64: enable coresight support
  References: jsc#SLE-13629,jsc#SLE-14776
- commit 82b71f4
* Mon Nov 23 2020 ohering@suse.de
- Delete patches.suse/suse-hv-balloon-debug.patch.
- commit f2ea562
* Mon Nov 23 2020 yousaf.kaukab@suse.com
- dt-bindings: arm: Adds CoreSight CTI hardware definitions
  (jsc#SLE-13629,jsc#SLE-14776).
- commit 06e36ad
* Mon Nov 23 2020 bp@suse.de
- x86/microcode/intel: Check patch signature before saving
  microcode for early loading (bsc#1152489).
- commit 8621df1
* Mon Nov 23 2020 msuchanek@suse.de
- powerpc/pseries: Add KVM guest doorbell restrictions
  (jsc#SLE-15869 jsc#SLE-16321).
- powerpc/pseries: Use doorbells even if XIVE is available
  (jsc#SLE-15869 jsc#SLE-16321).
- powerpc: Inline doorbell sending functions (jsc#SLE-15869
  jsc#SLE-16321).
- commit 1caac5a
* Mon Nov 23 2020 yousaf.kaukab@suse.com
- coresight: tmc-etr: Assign boolean values to a bool variable
  (jsc#SLE-13629,jsc#SLE-14776).
- commit 9f54ba1
* Mon Nov 23 2020 bp@suse.de
- x86/speculation: Allow IBPB to be conditionally enabled on
  CPUs with always-on STIBP (bsc#1152489).
- commit 7689d05
* Mon Nov 23 2020 jslaby@suse.cz
- rpm/kernel-binary.spec.in: use grep -E instead of egrep (bsc#1179045)
  egrep is only a deprecated bash wrapper for "grep -E". So use the latter
  instead.
- commit 63d7072
* Mon Nov 23 2020 yousaf.kaukab@suse.com
- coresight: etb10: Fix possible NULL ptr dereference in
  etb_enable_perf() (jsc#SLE-13629,jsc#SLE-14776).
- coresight: tmc-etf: Fix NULL ptr dereference in
  tmc_enable_etf_sink_perf() (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Remove unnecessary THIS_MODULE of funnel and
  replicator driver (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Handle TRCVIPCSSCTLR accesses
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Fix accesses to TRCPROCSELR
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Update TRCIDR3.NUMPROCS handling to match v4.2
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Fix accesses to TRCCIDCTLR1
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Fix accesses to TRCVMIDCTLR1
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: core: Remove unneeded semicolon
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Fix uninitialised pointer bug in etm_setup_aux()
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Initialize dynamic sysfs attributes
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: add module license (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Skip setting LPOVERRIDE bit for
  qcom,skip-power-up (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Fix save and restore of TRCVMIDCCTLR1 register
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: core: Allow the coresight core driver to be built
  as a module (jsc#SLE-13629,jsc#SLE-14776).
- coresight: catu: Allow catu drivers to be built as modules
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: tmc-etr: Add function to register catu ops
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Allow cti to be built as a module
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Increase reference count when enabling cti
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Don't disable ect device if it's not enabled
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Fix bug clearing sysfs links on callback
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Fix remove sysfs link error
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Add function to register cti associate ops
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: replicator: Allow replicator driver to be built as
  module (jsc#SLE-13629,jsc#SLE-14776).
- coresight: funnel: Allow funnel driver to be built as module
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: tmc: Allow tmc to be built as a module
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: tpiu: Allow tpiu to be built as a module
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etb: Allow etb to be built as a module
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Allow etm4x to be built as a module
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm3x: Allow etm3x to be built as a module
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm: perf: Fix warning caused by etm_setup_aux
  failure (jsc#SLE-13629,jsc#SLE-14776).
- coresight: stm: Allow to build coresight-stm as a module
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Add try_get_module() in coresight_grab_device()
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Export global symbols (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Add coresight prefix to barrier_pkt
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Use IS_ENABLED for CONFIGs that may be modules
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cpu_debug: Define MODULE_DEVICE_TABLE
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cpu_debug: Add module name in Kconfig
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Fix number of resources check for ETM 4.3
  and above (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Fix mis-usage of nr_resource in sysfs
  interface (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Make sysfs functional on topologies with per core
  sink (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm: perf: Sink selection using sysfs is deprecated
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Fix issues on trcseqevr access
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Handle unreachable sink in perf mode
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Write regsiters directly in cti_enable_hw()
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Fix issues within reset interface of sysfs
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Ensure default perf settings filter
  user/kernel (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: remove pm_runtime_get_sync() from CPU hotplug
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: disclaim device only when it's claimed
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Add Support for HiSilicon ETM device
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: fix offset by one error in counting ports
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: stm: Support marked packet
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Fix etm4_count race by moving cpuhp callbacks
  to init (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Fix save/restore during cpu idle
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm: perf: Add default sink selection to etm perf
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: tmc: Update sink types for default selection
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Add default sink selection to CoreSight base
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: tmc: Fix TMC mode read in tmc_read_unprepare_etb()
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: tmc: Add shutdown callback for TMC ETR
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Fix comment in main header file
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etmv4: Counter values not saved on disable
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etmv4: Fix resource selector constant
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Drop double check for ACPI companion device
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Use devm_kcalloc() in coresight_alloc_conns()
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: replicator: Reset replicator if context is lost
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Add support to skip trace unit power up
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: catu: Use CS_AMBA_ID macro for id table
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: replicator: Use CS_AMBA_ID macro for id table
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etmv4: Fix CPU power management setup in probe()
  function (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Fix error handling in probe
  (jsc#SLE-13629,jsc#SLE-14776).
- stm class: Replace zero-length array with flexible-array
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Add CPU idle pm notifer to CTI devices
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Add CPU Hotplug handling to CTI driver
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Fix use-after-free of per-cpu etm drvdata
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Avoid casting void pointers
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Include required headers in C files
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Initialize arg in sparse friendly way
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Don't initialize variables unnecessarily
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Mark some functions static
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Add support for Neoverse N1 ETM
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etmv4: Update default filter and initialisation
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: tmc: Fix TMC mode read in tmc_read_prepare_etb()
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Fix support for sparsely populated ports
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etb10: Make coresight_etb_groups static
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Make some symbols static
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Replace ETM PIDs with UCI IDs for Kryo385
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: etm4x: Add support for Qualcomm SC7180 SoC
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Add in sysfs links to other coresight devices
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Expose device connections via sysfs
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Add generic sysfs link creation functions
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Add return value for fixup connections
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: Pass coresight_device for
  coresight_release_platform_data (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: remove incorrect NULL return check
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Add connection information to sysfs
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Enable CTI associated with devices
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Add device tree support for custom CTI
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Add device tree support for v8 arch CTI
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Add sysfs trigger / channel programming API
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Add sysfs access to program function registers
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Add sysfs coresight mgmt register access
  (jsc#SLE-13629,jsc#SLE-14776).
- coresight: cti: Initial CoreSight CTI Driver
  (jsc#SLE-13629,jsc#SLE-14776).
- stm class: sys-t: Fix the use of time_after()
  (jsc#SLE-13629,jsc#SLE-14776).
- commit a8be182
* Mon Nov 23 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/scsi-libiscsi-fix-nop-race-condition
- commit 8f31344
* Mon Nov 23 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-mm-THP-swap-fix-allocating-cluster-for-swapfile-by-m.patch
- commit 47f49e5
* Mon Nov 23 2020 bp@suse.de
- blacklist.conf: ffedeeb780dc linkage: Introduce new macros for assembler symbols
- commit 3f22bb2
* Mon Nov 23 2020 nsaenzjulienne@suse.de
- usb: typec: ucsi: Report power supply changes (git-fixes).
- commit 23870a2
* Mon Nov 23 2020 jslaby@suse.cz
- kernel-{binary,source}.spec.in: do not create loop symlinks (bsc#1179082)
- commit adf56a8
* Mon Nov 23 2020 clin@suse.com
- arm64: lock down kernel in secure boot mode (jsc#SLE-15020).
- Update config file: Enable CONFIG_IMA_SECURE_AND_OR_TRUSTED_BOOT and its
  dependencies.
- commit 6f11f98
* Mon Nov 23 2020 clin@suse.com
- arm64/ima: add ima_arch support (jsc#SLE-15020).
- ima: generalize x86/EFI arch glue for other EFI architectures
  (jsc#SLE-15020).
- commit 6c08e9b
* Mon Nov 23 2020 tiwai@suse.de
- mac80211: free sta in sta_info_insert_finish() on errors
  (git-fixes).
- commit 61bc819
* Mon Nov 23 2020 tiwai@suse.de
- HID: logitech-dj: Fix Dinovo Mini when paired with a MX5x00
  receiver (git-fixes).
- HID: logitech-dj: Fix an error in mse_bluetooth_descriptor
  (git-fixes).
- HID: logitech-dj: Handle quad/bluetooth keyboards with a
  builtin trackpad (git-fixes).
- HID: logitech-hidpp: Add PID for MX Anywhere 2 (git-fixes).
- iio: accel: kxcjk1013: Add support for KIOX010A ACPI DSM for
  setting tablet-mode (git-fixes).
- iio: accel: kxcjk1013: Replace is_smo8500_device with an
  acpi_type enum (git-fixes).
- iio: light: fix kconfig dependency bug for VCNL4035 (git-fixes).
- iio: adc: mediatek: fix unset field (git-fixes).
- tty: serial: imx: keep console clocks always on (git-fixes).
- tty: serial: imx: fix potential deadlock (git-fixes).
- mac80211: always wind down STA state (git-fixes).
- commit 0772cb9
* Mon Nov 23 2020 jslaby@suse.cz
- rpm/kernel-binary.spec.in: avoid using more barewords (bsc#1179014)
  %%split_extra still contained two.
- commit d9b4c40
* Mon Nov 23 2020 clin@suse.com
- efi: generalize efi_get_secureboot (jsc#SLE-15020).
- Refresh
  patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch.
- commit 5086d30
* Mon Nov 23 2020 tiwai@suse.de
- speakup: Do not let the line discipline be used several times
  (CVE-2020-28941 bsc#1178740).
- commit 94aeaf9
* Mon Nov 23 2020 clin@suse.com
- x86/ima: use correct identifier for SetupMode variable
  (jsc#SLE-15020).
- commit f8d6ce0
* Mon Nov 23 2020 glin@suse.com
- blacklist.conf: add two more bpf commits
  197afc631413 libbpf: Don‘t attempt to load unused subprog as an entry-point BPF program
  2acc3c1bc8e9 selftests/bpf: Fix error return code in run_getsockopt_test()
- commit d1b0a66
* Mon Nov 23 2020 glin@suse.com
- lib/strncpy_from_user.c: Mask out bytes after NUL terminator (bsc#1155518).
- commit c5101f8
* Mon Nov 23 2020 glin@suse.com
- libbpf: Fix VERSIONED_SYM_COUNT number parsing (bsc#1177028).
- bpf: Relax return code check for subprograms (bsc#1177028).
- tools, bpftool: Add missing close before bpftool net attach exit
  (bsc#1177028).
- bpf: verifier: Use target program's type for access
  verifications (bsc#1177028).
- bpf: sockmap: Allow update from BPF (bsc#1177028).
- bpf: sockmap: Call sock_map_update_elem directly (bsc#1177028).
- bpf: sockmap: Merge sockmap and sockhash update functions
  (bsc#1177028).
- commit c8ac81c
* Sun Nov 22 2020 tiwai@suse.de
- kABI workaround for USB audio driver (bsc#1178203).
- commit 9a89b5e
* Sat Nov 21 2020 bp@suse.de
- EDAC/amd64: Support asymmetric dual-rank DIMMs (bsc#1179001).
- EDAC/amd64: Cache secondary Chip Select registers (bsc#1179001).
- commit 5ad6aa8
* Sat Nov 21 2020 tiwai@suse.de
- ALSA: hda/ca0132: Fix compile warning without PCI (git-fixes).
- commit 279d4c5
* Sat Nov 21 2020 bp@suse.de
- EDAC/amd64: Find Chip Select memory size using Address Mask
  (bsc#1179001).
- Refresh
  patches.suse/edac-amd64-add-amd-family-17h-model-60h-pci-ids.patch.
- Refresh
  patches.suse/edac-amd64-add-family-ops-for-family-19h-models-00h-0fh.patch.
- Refresh
  patches.suse/edac-amd64-add-pci-device-ids-for-family-17h-model-70h.patch.
- Refresh
  patches.suse/edac-amd64-save-max-number-of-controllers-to-family-type.patch.
- commit 889ea68
* Sat Nov 21 2020 tiwai@suse.de
- ALSA: usb-audio: Support PCM sync_stop (bsc#1178203).
- Refresh
  patches.suse/ALSA-usb-audio-Fix-potential-use-after-free-of-strea.patch.
- Refresh
  patches.suse/ALSA-usb-audio-set-the-interface-format-after-resume.patch.
- commit 0f18878
* Sat Nov 21 2020 tiwai@suse.de
- ALSA: usb-audio: Use ALC1220-VB-DT mapping for ASUS ROG Strix
  TRX40 mobo (bsc#1178203).
- ALSA: usb-audio: Correct wrongly matching entries with audio
  class (bsc#1178203).
- ALSA: usb-audio: Properly match with audio interface class
  (bsc#1178203).
- ALSA: usb-audio: Simplify quirk entries with a macro
  (bsc#1178203).
- ALSA: usb-audio: Move device rename and profile quirks to an
  internal table (bsc#1178203).
- ALSA: usb-audio: Use managed buffer allocation (bsc#1178203).
- ALSA: usb-audio: Convert to the common vmalloc memalloc
  (bsc#1178203).
- commit 535b061
* Sat Nov 21 2020 tiwai@suse.de
- ALSA: hda: Add Alderlake-S PCI ID and HDMI codec vid
  (jsc#SLE-13489).
- commit 9c738ab
* Sat Nov 21 2020 tiwai@suse.de
- ASOC: Intel: kbl_rt5663_rt5514_max98927: Do not try to disable
  disabled clock (git-fixes).
- ASoC: Intel: KMB: Fix S24_LE configuration (git-fixes).
- commit 4a82e7d
* Sat Nov 21 2020 tiwai@suse.de
- ASoC: qcom: lpass-platform: Fix memory leak (git-fixes).
- ALSA: mixart: Fix mutex deadlock (git-fixes).
- ALSA: usb-audio: Add delay quirk for all Logitech USB devices
  (git-fixes).
- ALSA: firewire: Clean up a locking issue in copy_resp_to_buf()
  (git-fixes).
- ALSA: ctl: fix error path at adding user-defined element set
  (git-fixes).
- ALSA: hda/realtek - HP Headset Mic can't detect after boot
  (git-fixes).
- ALSA: hda/realtek - Add supported mute Led for HP (git-fixes).
- ALSA: hda/realtek: Add some Clove SSID in the ALC293(ALC1220)
  (git-fixes).
- ALSA: hda/realtek - Add supported for Lenovo ThinkPad Headset
  Button (git-fixes).
- commit 55dbb32
* Sat Nov 21 2020 bp@suse.de
- EDAC/amd64: Initialize DIMM info for systems with more than
  two channels (bsc#1179001).
- commit 263a905
* Sat Nov 21 2020 bp@suse.de
- EDAC/amd64: Gather hardware information early (bsc#1179001).
- Refresh
  patches.suse/edac-amd64-save-max-number-of-controllers-to-family-type.patch.
- commit 23c7468
* Sat Nov 21 2020 bp@suse.de
- EDAC/amd64: Save max number of controllers to family type
  (bsc#1179001).
  Refresh patches.suse/edac-amd64-add-family-ops-for-family-19h-models-00h-0fh.patch.
- EDAC/amd64: Make struct amd64_family_type global (bsc#1179001).
- commit 7a2a5fc
* Fri Nov 20 2020 msuchanek@suse.de
- kernel-source.spec: Fix build with rpm 4.16 (boo#1179015).
  RPM_BUILD_ROOT is cleared before %%%%install. Do the unpack into
  RPM_BUILD_ROOT in %%%%install
- commit 13bd533
* Fri Nov 20 2020 vbabka@suse.cz
- mm/memremap.c: convert devmap static branch to {inc,dec}
  (jsc#SLE-16387).
- commit 28e3712
* Fri Nov 20 2020 vbabka@suse.cz
- lib: fix test_hmm.c reference after free (jsc#SLE-16387).
- commit 6494bc7
* Fri Nov 20 2020 vbabka@suse.cz
- MAINTAINERS: add HMM selftests (jsc#SLE-16387).
- commit de2b551
* Fri Nov 20 2020 vbabka@suse.cz
- mm/hmm/test: add selftests for HMM (jsc#SLE-16387).
- commit 04c8e1c
* Fri Nov 20 2020 vbabka@suse.cz
- mm/hmm/test: add selftest driver for HMM (jsc#SLE-16387).
- Update config files.
- commit dc51e9f
* Fri Nov 20 2020 tiwai@suse.de
- brcmfmac: Fix warning message after dongle setup failed
  (git-fixes).
- commit 21b5253
* Fri Nov 20 2020 nsaenzjulienne@suse.de
- Update config files: Enable imx8's SPI, dmaengine and alsa components
- supported.conf: Add spi-imx and imx-sdma
- commit e5360c4
* Fri Nov 20 2020 msuchanek@suse.de
- powerpc/32s: Prepare prevent_user_access() for user_access_end()
  (CVE-2020-4788 bsc#1177666).
- commit 2118998
* Fri Nov 20 2020 msuchanek@suse.de
- powerpc/32s: Drop NULL addr verification (CVE-2020-4788
  bsc#1177666).
- commit 764b74e
* Fri Nov 20 2020 mbrugger@suse.com
- spi: cadence-quadspi: Fix error return code in cqspi_probe
  (git-fixes).
- commit 8996fc5
* Fri Nov 20 2020 nsaenzjulienne@suse.de
- dmaengine: imx-dma: Mark expected switch fall-through
  (jsc#SLE-16106).
- commit 6962d07
* Fri Nov 20 2020 jslaby@suse.cz
- rpm/kernel-binary.spec.in: avoid using barewords (bsc#1179014)
  Author: Dominique Leuenberger <dimstar@opensuse.org>
- commit 21f8205
* Fri Nov 20 2020 jslaby@suse.cz
- rpm/mkspec: do not build kernel-obs-build on x86_32
  We want to use 64bit kernel due to various bugs (bsc#1178762 to name
  one).
  There is:
  ExportFilter: ^kernel-obs-build.*\.x86_64.rpm$ . i586
  in Factory's prjconf now. No other actively maintained distro (i.e.
  merging packaging branch) builds a x86_32 kernel, hence pushing to
  packaging directly.
- commit 8099b4b
* Fri Nov 20 2020 msuchanek@suse.de
- fs/select.c: batch user writes in do_sys_poll (CVE-2020-4788
  bsc#1177666).
- commit e2a69e2
* Fri Nov 20 2020 lhenriques@suse.de
- ceph: check session state after bumping session->s_seq
  (bsc#1179012).
- ceph: check the sesion state and return false in case it is
  closed (bsc#1179012).
- ceph: add check_session_state() helper and make it global
  (bsc#1179012).
- commit d99bb08
* Fri Nov 20 2020 nsaenzjulienne@suse.de
- Refresh patches.suse/crypto-safexcel-des-switch-to-new-verification-routines.patch.
  The removal of the variable flags in safexcel_aead_setkey() was somehow
  missed, creating warnings on Leap kernels.
- commit 88b5f9f
* Fri Nov 20 2020 nsaenzjulienne@suse.de
- Revert "- crypto: caam - share definition for MAX_SDLEN (jsc#SLE-14454)."
  This reverts commit 3551d7147c4c8c2560932f1461fa9ae2dabaae66.
  The patch was already introduced by
  51f999dc1fe74962969c521a27218efa49298292 but with a slightly different
  file name.
- commit c8b4478
* Fri Nov 20 2020 nsaenzjulienne@suse.de
- spi: introduce fallback to pio (jsc#SLE-16106).
- commit 415e477
* Fri Nov 20 2020 glin@suse.com
- Restore the header of series.conf
  The header of series.conf was accidentally changed by abb50be8e6bc
  "(kABI: revert use_mm name change (MM Functionality, bsc#1178426))".
  The scripts/git_sort/lib.py script matches the upper-case "K" in the
  header.
- commit cec3f48
* Fri Nov 20 2020 msuchanek@suse.de
- selftests/powerpc: entry flush test (CVE-2020-4788 bsc#1177666).
- powerpc/64s: flush L1D after user accesses (CVE-2020-4788
  bsc#1177666).
- powerpc/64s: flush L1D on kernel entry (CVE-2020-4788
  bsc#1177666).
- selftests/powerpc: rfi_flush: disable entry flush if present
  (CVE-2020-4788 bsc#1177666).
- powerpc/64s: rename pnv|pseries_setup_rfi_flush to
  _setup_security_mitigations (CVE-2020-4788 bsc#1177666).
- selftests/powerpc: entry flush test (CVE-2020-4788 bsc#1177666).
- powerpc: Only include kup-radix.h for 64-bit Book3S
  (CVE-2020-4788 bsc#1177666).
- powerpc/64s: flush L1D after user accesses (CVE-2020-4788
  bsc#1177666).
- powerpc/64s: flush L1D on kernel entry (CVE-2020-4788
  bsc#1177666).
- selftests/powerpc: rfi_flush: disable entry flush if present
  (CVE-2020-4788 bsc#1177666).
- commit e2755de
* Fri Nov 20 2020 tiwai@suse.de
- Fonts: Replace discarded const qualifier (CVE-2020-28915
  bsc#1178886).
- commit 1896c0d
* Fri Nov 20 2020 tiwai@suse.de
- fbcon: Fix global-out-of-bounds read in fbcon_get_font()
  (CVE-2020-28915 bsc#1178886).
- Fonts: Support FONT_EXTRA_WORDS macros for built-in fonts
  (CVE-2020-28915 bsc#1178886).
- commit cf5442f
* Fri Nov 20 2020 tiwai@suse.de
- Refresh patch reference for font fix patch (CVE-2020-28915 bsc#1178886)
- commit 1add793
* Fri Nov 20 2020 msuchanek@suse.de
- selftests/powerpc: Skip security tests on older CPUs
  (CVE-2020-4788 bsc#1177666).
- commit 1bc32c0
* Fri Nov 20 2020 yousaf.kaukab@suse.com
- ACPI: processor: fix NONE coordination for domain mapping
  failure (jsc#SLE-14771).
- cppc_cpufreq: expose information on frequency domains
  (jsc#SLE-14771).
- cppc_cpufreq: clarify support for coordination types
  (jsc#SLE-14771).
- cppc_cpufreq: use policy->cpu as driver of frequency setting
  (jsc#SLE-14771).
- cppc_cpufreq: replace per-cpu structures with lists
  (jsc#SLE-14771).
- cppc_cpufreq: simplify use of performance capabilities
  (jsc#SLE-14771).
- cppc_cpufreq: clean up cpu, cpu_num and cpunum variable use
  (jsc#SLE-14771).
- cppc_cpufreq: fix misspelling, code style and readability issues
  (jsc#SLE-14771).
- ACPI: CPPC: Make some symbols static (jsc#SLE-14771).
- ACPI: CPPC: clean up acpi_get_psd_map() (jsc#SLE-14771).
- commit f7b4058
* Fri Nov 20 2020 jslaby@suse.cz
- blacklist.conf: add RISC V patch
- commit 42e5de9
* Fri Nov 20 2020 tiwai@suse.de
- ACPI: fan: Initialize performance state sysfs attribute
  (git-fixes).
- net: phy: realtek: support paged operations on RTL8201CP
  (git-fixes).
- commit f04c666
* Fri Nov 20 2020 tiwai@suse.de
- can: kvaser_usb: kvaser_usb_hydra: Fix KCAN bittiming limits
  (git-fixes).
- can: m_can: m_can_stop(): set device to software init mode
  before closing (git-fixes).
- can: m_can: m_can_handle_state_change(): fix state change
  (git-fixes).
- can: flexcan: flexcan_setup_stop_mode(): add missing "req_bit"
  to stop mode property comment (git-fixes).
- can: peak_usb: fix potential integer overflow on shift of a int
  (git-fixes).
- can: mcba_usb: mcba_usb_start_xmit(): first fill skb, then
  pass to can_put_echo_skb() (git-fixes).
- can: dev: can_restart(): post buffer from the right context
  (git-fixes).
- can: af_can: prevent potential access of uninitialized member
  in canfd_rcv() (git-fixes).
- can: af_can: prevent potential access of uninitialized member
  in can_rcv() (git-fixes).
- lan743x: prevent entire kernel HANG on open, for some platforms
  (git-fixes).
- lan743x: fix issue causing intermittent kernel log warnings
  (git-fixes).
- mac80211: minstrel: fix tx status processing corner case
  (git-fixes).
- mac80211: minstrel: remove deferred sampling code (git-fixes).
- rfkill: Fix use-after-free in rfkill_resume() (git-fixes).
- spi: lpspi: Fix use-after-free on unbind (git-fixes).
- regulator: ti-abb: Fix array out of bound read access on the
  first transition (git-fixes).
- regulator: workaround self-referent regulators (git-fixes).
- regulator: avoid resolve_supply() infinite recursion
  (git-fixes).
- regulator: fix memory leak with repeated
  set_machine_constraints() (git-fixes).
- regulator: pfuze100: limit pfuze-support-disable-sw to
  pfuze{100,200} (git-fixes).
- commit 3d08124
* Fri Nov 20 2020 glin@suse.com
- kbuild: make Clang build userprogs for target architecture (bsc#1177028).
- commit 11fffeb
* Fri Nov 20 2020 jlee@suse.com
- efi/libstub: Drop 'table' argument from efi_table_attr() macro
  (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
- efi/libstub: Drop protocol argument from efi_call_proto()
  macro (jsc#SLE-16407).
- efi/libstub/x86: Work around page freeing issue in mixed mode
  (jsc#SLE-16407).
- efi/libstub/x86: Drop __efi_early() export and efi_config struct
  (jsc#SLE-16407).
  Refresh
  patches.suse/x86-boot-compressed-64-add-idt-infrastructure.
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch
- efi/libstub: Unify the efi_char16_printk implementations
  (jsc#SLE-16407).
- efi/libstub: Get rid of 'sys_table_arg' macro parameter
  (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- efi/libstub: Avoid protocol wrapper for file I/O routines
  (jsc#SLE-16407).
- efi/libstub/x86: Avoid thunking for native firmware calls
  (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- efi/libstub: Annotate firmware routines as __efiapi
  (jsc#SLE-16407).
- efi/libstub: Use stricter typing for firmware function pointers
  (jsc#SLE-16407).
- efi/libstub: Drop explicit 32/64-bit protocol definitions
  (jsc#SLE-16407).
- efi/libstub: Distinguish between native/mixed not 32/64 bit
  (jsc#SLE-16407).
- efi/libstub: Extend native protocol definitions with mixed_mode
  aliases (jsc#SLE-16407).
- efi/libstub: Use a helper to iterate over a EFI handle array
  (jsc#SLE-16407).
- efi/x86: Rename efi_is_native() to efi_is_mixed()
  (jsc#SLE-16407).
- efi/libstub: Remove unused __efi_call_early() macro
  (jsc#SLE-16407).
- efi/gop: Unify 32/64-bit functions (jsc#SLE-16407).
- efi/gop: Convert GOP structures to typedef and clean up some
  types (jsc#SLE-16407).
- efi/gop: Remove unused typedef (jsc#SLE-16407).
- efi/gop: Remove bogus packed attribute from GOP structures
  (jsc#SLE-16407).
- efi/capsule-loader: Explicitly include linux/io.h for
  page_to_phys() (jsc#SLE-16407).
- x86/efi: Explicitly include realmode.h to handle RM trampoline
  quirk (jsc#SLE-16407).
- x86/efistub: Disable paging at mixed mode entry (jsc#SLE-16407).
- commit 7d8fae9
* Fri Nov 20 2020 jlee@suse.com
- treewide: Use sizeof_field() macro (jsc#SLE-16407).
- commit f4dcb62
* Fri Nov 20 2020 tiwai@suse.de
- pinctrl: lynxpoint: Move GPIO driver to pin controller folder
  (jsc#SLE-12730).
- Refresh
  patches.suse/pinctrl-intel-Add-Intel-Alder-Lake-S-pin-controller-.patch.
- commit 66f9d94
* Thu Nov 19 2020 pjakobsson@suse.de
- blacklist.conf: git-fixes blacklist for drm v5.8
- commit 9af7e74
* Thu Nov 19 2020 tiwai@suse.de
- usb: dwc3: pci: add support for the Intel Alder Lake-S
  (jsc#SLE-13489).
- commit 030ca85
* Thu Nov 19 2020 tiwai@suse.de
- uio: Fix use-after-free in uio_unregister_device() (git-fixes).
- mei: protect mei_cl_mtu from null dereference (git-fixes).
- usb: cdc-acm: Add DISABLE_ECHO for Renesas USB Download mode
  (git-fixes).
- pinctrl: amd: use higher precision for 512 RtcClk (git-fixes).
- pinctrl: amd: fix incorrect way to disable debounce filter
  (git-fixes).
- usb: gadget: goku_udc: fix potential crashes in probe
  (git-fixes).
- i2c: sh_mobile: implement atomic transfers (git-fixes).
- i2c: mediatek: move dma reset before i2c reset (git-fixes).
- tpm_tis: Disable interrupts on ThinkPad T490s (git-fixes).
- cfg80211: regulatory: Fix inconsistent format argument
  (git-fixes).
- cfg80211: initialize wdev data earlier (git-fixes).
- mac80211: fix use of skb payload instead of header (git-fixes).
- mfd: sprd: Add wakeup capability for PMIC IRQ (git-fixes).
- commit 0ba4e11
* Thu Nov 19 2020 dbueso@suse.de
- futex: Don't enable IRQs unconditionally in put_pi_state()
  (bsc#1149032).
- futex: Handle transient "ownerless" rtmutex state correctly
  (bsc#1149032).
- commit 15c899a
* Thu Nov 19 2020 tiwai@suse.de
- kABI workaround for HD-audio (git-fixes).
- commit 97e2fbf
* Thu Nov 19 2020 tiwai@suse.de
- ALSA: hda: Reinstate runtime_allow() for all hda controllers
  (git-fixes).
- ALSA: hda: fix jack detection with Realtek codecs when in D3
  (git-fixes).
- commit 6f153b9
* Thu Nov 19 2020 jlee@suse.com
- x86/asm/32: Change all ENTRY+ENDPROC to SYM_FUNC_*
  (jsc#SLE-16407).
  Joey Lee:
  Only backporting EFI files for later EFI stub changing.
- linkage: Introduce new macros for assembler symbols
  (jsc#SLE-16407).
- commit 0db172f
* Thu Nov 19 2020 tiwai@suse.de
- gpio: aspeed: avoid return type warning (git-fixes).
- commit 3ce1279
* Thu Nov 19 2020 tiwai@suse.de
- Add blacklist and no-fix for superfluous gpio and pinctrl commits
- commit e89ba63
* Thu Nov 19 2020 tiwai@suse.de
- gpio: aspeed: fix ast2600 bank properties (git-fixes).
- gpio/aspeed-sgpio: don't enable all interrupts by default
  (git-fixes).
- gpio/aspeed-sgpio: enable access to all 80 input & output sgpios
  (git-fixes).
- Revert "gpio: thunderx: Switch to GPIOLIB_IRQCHIP" (git-fixes).
- MAINTAINERS: Append missed file to the database (git-fixes).
- pinctrl: pinmux: fix a possible null pointer in
  pinmux_can_be_used_for_gpio (git-fixes).
- gpio: aspeed-sgpio: Rename and add Kconfig/Makefile (git-fixes).
- pinctrl: stmfx: fix valid_mask init sequence (git-fixes).
- commit d2a6950
* Thu Nov 19 2020 yousaf.kaukab@suse.com
- arm64: thunderX2: drop support for pre-production silicon revisions
  References: jsc#11529
- commit 5a94cc5
* Thu Nov 19 2020 yousaf.kaukab@suse.com
- cpufreq: CPPC: Reuse caps variable in few routines
  (jsc#SLE-14771).
- cpufreq: cppc: Reorder code and remove apply_hisi_workaround
  variable (jsc#SLE-14771).
- mailbox: pcc: Put the PCCT table for error path (jsc#SLE-14771).
- mailbox: pcc: make pcc_mbox_driver static (jsc#SLE-14771).
- cpufreq: CPPC: add SW BOOST support (jsc#SLE-14771).
- cpufreq: change '.set_boost' to act on one policy
  (jsc#SLE-14771).
- cpufreq: CPPC: put ACPI table after using it (jsc#SLE-14771).
- cpufreq : CPPC: Break out if HiSilicon CPPC workaround is
  matched (jsc#SLE-14771).
- commit 7996b85
* Thu Nov 19 2020 tiwai@suse.de
- pinctrl: intel: Fix 2 kOhm bias which is 833 Ohm
  (jsc#SLE-12730).
- pinctrl: sunrisepoint: Modify COMMUNITY macros to be consistent
  (jsc#SLE-12730).
- pinctrl: cannonlake: Modify COMMUNITY macros to be consistent
  (jsc#SLE-12730).
- pinctrl: intel: Update header block to reflect direct
  dependencies (jsc#SLE-12730).
- pinctrl: cherryview: Switch to use intel_pinctrl_get_soc_data()
  (jsc#SLE-12730).
- pinctrl: baytrail: Switch to use intel_pinctrl_get_soc_data()
  (jsc#SLE-12730).
- pinctrl: intel: Extract intel_pinctrl_get_soc_data() helper
  for wider use (jsc#SLE-12730).
- pinctrl: cherryview: Utilize temporary variable to hold device
  pointer (jsc#SLE-12730).
- pinctrl: cherryview: Switch to use struct intel_pinctrl
  (jsc#SLE-12730).
- pinctrl: cherryview: Move custom community members to separate
  data struct (jsc#SLE-12730).
- pinctrl: cherryview: Drop stale comment (jsc#SLE-12730).
- commit 19aef60
* Thu Nov 19 2020 tiwai@suse.de
- pinctrl: merrifield: Add I2S bus 2 pins to groups and functions
  (jsc#SLE-12730).
- commit ba1d01c
* Thu Nov 19 2020 tiwai@suse.de
- pinctrl: cherryview: Preserve CHV_PADCTRL1_INVRXTX_TXDATA flag
  on GPIOs (jsc#SLE-12730).
- pinctrl: baytrail: Use fallthrough pseudo-keyword
  (jsc#SLE-12730).
- pinctrl: merrifield: Update pin names in accordance with
  official list (jsc#SLE-12730).
- pinctrl: baytrail: Drop no-op ACPI_PTR() call (jsc#SLE-12730).
- pinctrl: lynxpoint: Drop no-op ACPI_PTR() call (jsc#SLE-12730).
- pinctrl: lynxpoint: Introduce helpers to enable or disable input
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Make use of for_each_requested_gpio()
  (jsc#SLE-12730).
- pinctrl: intel: Make use of for_each_requested_gpio_in_range()
  (jsc#SLE-12730).
- pinctrl: intel: Protect IO in few call backs by lock
  (jsc#SLE-12730).
- pinctrl: intel: Split intel_config_get() to three functions
  (jsc#SLE-12730).
- pinctrl: intel: Drop the only label in the code for consistency
  (jsc#SLE-12730).
- pinctrl: intel: Get rid of redundant 'else' in
  intel_config_set_debounce() (jsc#SLE-12730).
- pinctrl: intel: Make use of IRQ_RETVAL() (jsc#SLE-12730).
- pinctrl: intel: Reduce scope of the lock (jsc#SLE-12730).
- pinctrl: intel: Disable input and output buffer when switching
  to GPIO (jsc#SLE-12730).
- pinctrl: cherryview: Re-use data structures from pinctrl-intel.h
  (part 3) (jsc#SLE-12730).
- pinctrl: intel: Allow drivers to define ACPI address space ID
  (jsc#SLE-12730).
- pinctrl: intel: Allow drivers to define total amount of IRQs
  per community (jsc#SLE-12730).
- pinctrl: cherryview: Convert chv_writel() to use chv_padreg()
  (jsc#SLE-12730).
- pinctrl: cherryview: Introduce helpers to IO with common
  registers (jsc#SLE-12730).
- pinctrl: cherryview: Introduce chv_readl() helper
  (jsc#SLE-12730).
- gpiolib: Introduce for_each_requested_gpio_in_range() macro
  (jsc#SLE-12730).
- commit 2be8053
* Thu Nov 19 2020 tiwai@suse.de
- pinctrl: baytrail: Fix pin being driven low for a while on
  gpiod_get(..., GPIOD_OUT_HIGH) (jsc#SLE-12730).
- pinctrl: intel: Move npins closer to pin_base in struct
  intel_community (jsc#SLE-12730).
- pinctrl: intel: Update description in struct intel_community
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Use platform_get_irq_optional() explicitly
  (jsc#SLE-12730).
- pinctrl: baytrail: Use platform_get_irq_optional() explicitly
  (jsc#SLE-12730).
- pinctrl: icelake: Use generic flag for special GPIO base
  treatment (jsc#SLE-12730).
- pinctrl: cannonlake: Use generic flag for special GPIO base
  treatment (jsc#SLE-12730).
- pinctrl: cherryview: Use GENMASK() consistently (jsc#SLE-12730).
- pinctrl: cherryview: Re-use data structures from pinctrl-intel.h
  (part 2) (jsc#SLE-12730).
- commit efa95a6
* Thu Nov 19 2020 tiwai@suse.de
- Update config files.
- Refresh
  patches.suse/pinctrl-intel-Add-Intel-Alder-Lake-S-pin-controller-.patch.
- Refresh
  patches.suse/pinctrl-lynxpoint-Move-GPIO-driver-to-pin-controller.patch.
- supported.conf: Add pinctrl-lynxpoint
- commit 7d43af8
* Thu Nov 19 2020 tiwai@suse.de
- pinctrl: sunrisepoint: Add Coffee Lake-S ACPI ID
  (jsc#SLE-12730).
- pinctrl: intel: Pass irqchip when adding gpiochip
  (jsc#SLE-12730).
- pinctrl: intel: Add GPIO <-> pin mapping ranges via callback
  (jsc#SLE-12730).
- pinctrl: baytrail: Replace WARN with dev_info_once when setting
  direct-irq pin to output (jsc#SLE-12730).
- pinctrl: lynxpoint: Update summary in the driver
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Switch to pin control API (jsc#SLE-12730).
- pinctrl: lynxpoint: Add GPIO <-> pin mapping ranges via callback
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Implement ->pin_dbg_show() (jsc#SLE-12730).
- pinctrl: lynxpoint: Add pin control operations (jsc#SLE-12730).
- pinctrl: lynxpoint: Reuse struct intel_pinctrl in the driver
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Add pin control data structures
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Implement intel_gpio_get_direction callback
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Implement ->irq_ack() callback
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Move ownership check to IRQ chip
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Move lp_irq_type() closer to IRQ related
  routines (jsc#SLE-12730).
- pinctrl: lynxpoint: Move ->remove closer to ->probe()
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Extract lp_gpio_acpi_use() for future use
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Convert unsigned to unsigned int
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Switch to memory mapped IO accessors
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Keep pointer to struct device instead of
  its container (jsc#SLE-12730).
- pinctrl: lynxpoint: Relax GPIO request rules (jsc#SLE-12730).
- pinctrl: lynxpoint: Assume 2 bits for mode selector
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Use standard pattern for memory allocation
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Use %%pR to print IO resource
  (jsc#SLE-12730).
- pinctrl: lynxpoint: Drop useless assignment (jsc#SLE-12730).
- pinctrl: lynxpoint: Correct amount of pins (jsc#SLE-12730).
- pinctrl: lynxpoint: Use raw_spinlock for locking
  (jsc#SLE-12730).
- pinctrl: baytrail: Reuse struct intel_pinctrl in the driver
  (jsc#SLE-12730).
- pinctrl: baytrail: Use local variable to keep device pointer
  (jsc#SLE-12730).
- pinctrl: baytrail: Keep pointer to struct device instead of
  its container (jsc#SLE-12730).
- pinctrl: intel: Share struct intel_pinctrl for wider use
  (jsc#SLE-12730).
- pinctrl: intel: Use GPIO direction definitions (jsc#SLE-12730).
- pinctrl: cherryview: Use GPIO direction definitions
  (jsc#SLE-12730).
- pinctrl: baytrail: Use GPIO direction definitions
  (jsc#SLE-12730).
- pinctrl: baytrail: Move IRQ valid mask initialization to a
  dedicated callback (jsc#SLE-12730).
- pinctrl: baytrail: Group GPIO IRQ chip initialization
  (jsc#SLE-12730).
- pinctrl: baytrail: Allocate IRQ chip dynamic (jsc#SLE-12730).
- commit be1af4d
* Thu Nov 19 2020 tiwai@suse.de
- pinctrl: sunrisepoint: Add missing Interrupt Status register
  offset (jsc#SLE-12730).
- Refresh
  patches.suse/pinctrl-sunrisepoint-Fix-PAD-lock-register-offset-fo.patch.
- commit 58844ce
* Thu Nov 19 2020 tiwai@suse.de
- pinctrl: cherryview: Missed type change to unsigned int
  (jsc#SLE-12730).
- Refresh
  patches.suse/pinctrl-cherryview-Add-missing-spinlock-usage-in-chv.patch.
- commit 2b6f93f
* Thu Nov 19 2020 tiwai@suse.de
- pinctrl: intel: Use helper to restore register values on
  - >resume() (jsc#SLE-12730).
- Refresh
  patches.suse/pinctrl-intel-Introduce-common-flags-for-GPIO-mappin.patch.
- commit 07edd70
* Thu Nov 19 2020 tiwai@suse.de
- pinctrl: intel: Introduce intel_restore_hostown() helper
  (jsc#SLE-12730).
- Refresh
  patches.suse/pinctrl-intel-Introduce-common-flags-for-GPIO-mappin.patch.
- commit 2eb52ff
* Thu Nov 19 2020 mbenes@suse.cz
- SUNRPC: Fix general protection fault in trace_rpc_xdr_overflow()
  (git-fixes).
- commit 0640a68
* Thu Nov 19 2020 jeyu@suse.de
- Move patches.suse/compiler.h-Enforce-that-READ_ONCE_NOCHECK-access-siz.patch
  into sorted section.
  For some reason, the above patch was in the kABI padding section. That's
  clearly wrong, move it out of the kABI padding section and into sorted
  patches section.
- commit a46db82
* Thu Nov 19 2020 pjakobsson@suse.de
- tty/sysrq: constify the sysrq API (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- commit 28757bc
* Thu Nov 19 2020 pjakobsson@suse.de
- tty/sysrq: alpha: export and use __sysrq_get_key_op()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- commit 0885df4
* Thu Nov 19 2020 pjakobsson@suse.de
- i2c: add helper to check if a client has a driver attached
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- commit ff6d2f4
* Thu Nov 19 2020 mhocko@suse.com
- mm/gup: fix gup_fast with dynamic page table folding
  (bnc#1176586, LTC#188235).
- commit b2a9d8e
* Thu Nov 19 2020 jlee@suse.com
- x86/asm: Change all ENTRY+ENDPROC to SYM_FUNC_* (jsc#SLE-16407).
  Joey Lee:
  Only backporting EFI files for later EFI stub changing.
- x86/asm: Make some functions local (jsc#SLE-16407).
- Refresh
  patches.suse/x86-entry-64-handle-fsgsbase-enabled-paranoid-entry-exit.patch.
- Refresh
  patches.suse/x86-entry-64-switch-cr3-before-swapgs-in-paranoid-entry.patch.
- Refresh
  patches.suse/x86-powerpc-rename-memcpy_mcsafe-to-copy_mc_to_-user-kernel.patch.
- x86/boot: Annotate data appropriately (jsc#SLE-16407).
  Refresh
  patches.suse/x86-boot-compressed-64-add-idt-infrastructure.
- x86/asm: Annotate aliases (jsc#SLE-16407).
  Refresh
  patches.suse/x86-cpufeatures-Add-support-for-fast-short-REP-MOVSB.patch.
- x86/asm/crypto: Annotate local functions (jsc#SLE-16407).
- x86/asm: Make more symbols local (jsc#SLE-16407).
- commit c5b2503
* Thu Nov 19 2020 glin@suse.com
- bpf: Fix two typos in uapi/linux/bpf.h (bsc#1177028).
- bpf: Make bpf_link API available indepently of
  CONFIG_BPF_SYSCALL (bsc#1177028).
- bpf: Drop duplicated words in uapi helper comments
  (bsc#1177028).
- xdp: introduce xdp_get_shared_info_from_{buff, frame} utility routines (bsc#1177028).
  Refresh patches
- patches.suse/bpf-cpumap-Add-the-possibility-to-attach-an-eBPF-pro.patch
- patches.suse/bpf-cpumap-Implement-XDP_REDIRECT-for-eBPF-programs-.patch
- bpf: Switch most helper return values from 32-bit int to 64-bit long (bsc#1177028).
  Refresh patches:
- patches.suse/bpf-Introduce-SK_LOOKUP-program-type-with-a-dedicate.patch
- patches.suse/bpf-Sync-linux-bpf.h-to-tools.patch
- patches.suse/bpf-Fix-comment-for-helper-bpf_current_task_under_cg.patch
- commit dd3217c
* Thu Nov 19 2020 lduncan@suse.com
- scsi: libiscsi: Fix NOP race condition (bsc#1176481).
- commit ed80277
* Wed Nov 18 2020 pjakobsson@suse.de
- memremap: provide a not device managed memremap_pages
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Refresh
  patches.suse/mm-memunmap-don-t-access-uninitialized-memmap-in-mem.patch.
- commit a124be7
* Wed Nov 18 2020 pjakobsson@suse.de
- memremap: don't use a separate devm action for
  devmap_managed_enable_get (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- commit 4d6242f
* Wed Nov 18 2020 pjakobsson@suse.de
- memremap: remove the dev field in struct dev_pagemap
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Refresh
  patches.suse/PCI-P2PDMA-Introduce-private-pagemap-structure.patch.
- Refresh
  patches.suse/mm-memunmap-don-t-access-uninitialized-memmap-in-mem.patch.
- commit 1feeaf5
* Wed Nov 18 2020 jlee@suse.com
- x86/efi: EFI soft reservation to E820 enumeration
  (jsc#SLE-16407).
  Refresh
  patches.suse/x86-efi-Add-efi_fake_mem-support-for-EFI_MEMORY_SP-199c8471.patch.
- efi: Common enable/disable infrastructure for EFI soft
  reservation (jsc#SLE-16407).
- Refresh
  patches.suse/efi-Store-mask-of-supported-runtime-services-in-stru.patch.
  patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch.
- Update config files.
  CONFIG_EFI_SOFT_RESERVE=y on x86_64/default, arm64/default
- x86: efi/random: Invoke EFI_RNG_PROTOCOL to seed the UEFI RNG
  table (jsc#SLE-16407).
- commit 4faf531
* Wed Nov 18 2020 yousaf.kaukab@suse.com
- usb: dwc3: Add ACPI support for xHCI ports (jsc#SLE-12251).
- commit 324b394
* Wed Nov 18 2020 tiwai@suse.de
- pinctrl: cherryview: Pass irqchip when adding gpiochip
  (jsc#SLE-12730).
- pinctrl: cherryview: Add GPIO <-> pin mapping ranges via
  callback (jsc#SLE-12730).
- pinctrl: cherryview: Split out irq hw-init into a separate
  helper function (jsc#SLE-12730).
- pinctrl: baytrail: Pass irqchip when adding gpiochip
  (jsc#SLE-12730).
- pinctrl: baytrail: Add GPIO <-> pin mapping ranges via callback
  (jsc#SLE-12730).
- pinctrl: baytrail: Update North Community pin list
  (jsc#SLE-12730).
- pinctrl: intel: Missed type change to unsigned int
  (jsc#SLE-12730).
- pinctrl: intel: Drop level from warning to debug in
  intel_restore_hostown() (jsc#SLE-12730).
- pinctrl: intel: Introduce intel_restore_intmask() helper
  (jsc#SLE-12730).
- pinctrl: intel: Introduce intel_restore_padcfg() helper
  (jsc#SLE-12730).
- pinctrl: cherryview: Fix spelling mistake in the comment
  (jsc#SLE-12730).
- commit 7f8dbee
* Wed Nov 18 2020 tiwai@suse.de
- pinctrl: baytrail: Re-use data structures from pinctrl-intel.h
  (part 2) (jsc#SLE-12730).
- Refresh
  patches.suse/0001-pinctrl-baytrail-Really-serialize-all-register-acces.patch.
- commit e0a9108
* Wed Nov 18 2020 tiwai@suse.de
- pinctrl: sunrisepoint: Provide Interrupt Status register offset
  (jsc#SLE-12730).
- Refresh
  patches.suse/pinctrl-sunrisepoint-Fix-PAD-lock-register-offset-fo.patch.
- commit dfae0e2
* Wed Nov 18 2020 tiwai@suse.de
- pinctrl: intel: mark intel_pin_to_gpio __maybe_unused
  (jsc#SLE-12730).
- pinctrl: intel: Allow to request locked pads (jsc#SLE-12730).
- pinctrl: cherryview: Remove dev_err() usage after
  platform_get_irq() (jsc#SLE-12730).
- pinctrl: intel: Remove dev_err() usage after platform_get_irq()
  (jsc#SLE-12730).
- pinctrl: intel: Use NSEC_PER_USEC for debounce calculus
  (jsc#SLE-12730).
- pinctrl: intel: Remove default Interrupt Status offset
  (jsc#SLE-12730).
- pinctrl: lewisburg: Provide Interrupt Status register offset
  (jsc#SLE-12730).
- pinctrl: icelake: Provide Interrupt Status register offset
  (jsc#SLE-12730).
- pinctrl: geminilake: Provide Interrupt Status register offset
  (jsc#SLE-12730).
- pinctrl: cannonlake: Provide Interrupt Status register offset
  (jsc#SLE-12730).
- pinctrl: broxton: Provide Interrupt Status register offset
  (jsc#SLE-12730).
- pinctrl: intel: Simplify offset validation in intel_get_padcfg()
  (jsc#SLE-12730).
- pinctrl: intel: Drop double check for data in
  intel_pinctrl_probe_by_uid() (jsc#SLE-12730).
- pinctrl: merrifield: Use devm_platform_ioremap_resource()
  (jsc#SLE-12730).
- pinctrl: intel: Use devm_platform_ioremap_resource()
  (jsc#SLE-12730).
- pinctrl: cherryview: Use devm_platform_ioremap_resource()
  (jsc#SLE-12730).
- pinctrl: baytrail: Use devm_platform_ioremap_resource()
  (jsc#SLE-12730).
- commit ee7dd05
* Wed Nov 18 2020 tiwai@suse.de
- Revert "gpio: merrifield: Pass irqchip when adding gpiochip"
  (jsc#SLE-12730).
- Revert "gpio: merrifield: Restore use of irq_base"
  (jsc#SLE-12730).
- commit 778c0ed
* Wed Nov 18 2020 tiwai@suse.de
- Revert "gpio: merrifield: Move hardware initialization to
  callback" (jsc#SLE-12730).
- gpio: lynxpoint: set default handler to be handle_bad_irq()
  (jsc#SLE-12730).
- gpio: merrifield: Move hardware initialization to callback
  (jsc#SLE-12730).
- gpio: lynxpoint: Move hardware initialization to callback
  (jsc#SLE-12730).
- gpio: intel-mid: Move hardware initialization to callback
  (jsc#SLE-12730).
- gpio: merrifield: Restore use of irq_base (jsc#SLE-12730).
- pinctrl/gpio: Take MUX usage into account (jsc#SLE-12730).
- commit a8fa4e0
* Wed Nov 18 2020 tiwai@suse.de
- gpiolib: of: add a fallback for wlf,reset GPIO name
  (jsc#SLE-12730).
- Refresh
  patches.suse/usb-fusb302-convert-to-use-gpio-descriptors.patch.
- commit 9cd8b23
* Wed Nov 18 2020 tiwai@suse.de
- gpio: Initialize the irqchip valid_mask with a callback
  (jsc#SLE-12730).
- Refresh
  patches.suse/gpiolib-Initialize-the-hardware-with-a-callback.patch.
- Refresh
  patches.suse/pinctrl-cherryview-Fix-irq_valid_mask-calculation.patch.
- commit 65c5c62
* Wed Nov 18 2020 tiwai@suse.de
- gpio: htc-egpio: Remove unused exported
  htc_egpio_get_wakeup_irq() (jsc#SLE-12730).
- gpio: remove explicit comparison with 0 (jsc#SLE-12730).
- gpio: creg-snps: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-12730).
- gpio: aspeed: Add in ast2600 details to Aspeed driver
  (jsc#SLE-12730).
- gpio: aspeed: Use ngpio property from device tree if available
  (jsc#SLE-12730).
- gpio: aspeed: Setup irqchip dynamically (jsc#SLE-12730).
- gpiolib: acpi: make acpi_can_fallback_to_crs() static
  (jsc#SLE-12730).
- commit bf8a468
* Wed Nov 18 2020 tiwai@suse.de
- gpio: of: Normalize return code variable name (jsc#SLE-12730).
- Refresh
  patches.suse/gpiolib-No-need-to-call-gpiochip_remove_pin_ranges-t.patch.
- commit a436005
* Wed Nov 18 2020 tiwai@suse.de
- gpio: gpiolib: Normalize return code variable name
  (jsc#SLE-12730).
- Refresh
  patches.suse/gpiolib-Initialize-the-hardware-with-a-callback.patch.
- Refresh
  patches.suse/gpiolib-Introduce-add_pin_ranges-callback.patch.
- Refresh
  patches.suse/gpiolib-Switch-order-of-valid-mask-and-hw-init.patch.
- Refresh
  patches.suse/gpiolib-don-t-clear-FLAG_IS_OUT-when-emulating-open-.patch.
- commit 591fe46
* Wed Nov 18 2020 tiwai@suse.de
- gpio: merrifield: Pass irqchip when adding gpiochip
  (jsc#SLE-12730).
- gpio: lynxpoint: Pass irqchip when adding gpiochip
  (jsc#SLE-12730).
- gpio: intel-mid: Pass irqchip when adding gpiochip
  (jsc#SLE-12730).
- gpio: pch: Use dev_get_drvdata (jsc#SLE-12730).
- gpio: ep93xx: Pass irqchip when adding gpiochip (jsc#SLE-12730).
- gpio: lpc32xx: allow building on non-lpc32xx targets
  (jsc#SLE-12730).
- gpio: ixp4xx: remove redundant dev_err message (jsc#SLE-12730).
- commit 970dbfe
* Wed Nov 18 2020 ggherdovich@suse.cz
- intel_idle: Customize IceLake server support (bsc#1178286).
- commit eac5b5e
* Wed Nov 18 2020 tiwai@suse.de
- gpio: em: use a helper variable for &pdev->dev (jsc#SLE-12730).
- gpio: zynq: Pass irqchip when adding gpiochip (jsc#SLE-12730).
- gpio: mt7621: Pass irqchip when adding gpiochip (jsc#SLE-12730).
- gpio: aspeed: Add SGPIO driver (jsc#SLE-12730).
- gpio: tqmx86: Pass irqchip when adding gpiochip (jsc#SLE-12730).
- gpio: vf610: Pass irqchip when adding gpiochip (jsc#SLE-12730).
- gpio: zx: Pass irqchip when adding gpiochip (jsc#SLE-12730).
- gpio: ftgpio: Move hardware initialization (jsc#SLE-12730).
- gpio: Use callback presence to determine need of valid_mask
  (jsc#SLE-12730).
- pinctrl: stmfx: Use the callback to populate valid_mask
  (jsc#SLE-12730).
- commit 2c3ab09
* Wed Nov 18 2020 mbrugger@suse.com
- spi: Stop selecting MTD_SPI_NOR for SPI_HISI_SFC_V3XX
  (jsc#SLE-14214 jsc#SLE-16606).
- commit bcf49c6
* Wed Nov 18 2020 mhocko@suse.com
- mm, THP, swap: fix allocating cluster for swapfile by mistake
  (bsc#1178755).
- commit ba1483e
* Wed Nov 18 2020 yousaf.kaukab@suse.com
- drivers: qcom: rpmh-rsc: Use rcuidle tracepoints for rpmh
  (jsc#SLE-12251).
- commit e5cbc97
* Wed Nov 18 2020 yousaf.kaukab@suse.com
- supported.conf: enable fsl-mph-dr-of for NXP LS1012A
  References: jsc#SLE-12251
- commit 985a505
* Wed Nov 18 2020 yousaf.kaukab@suse.com
- USB: phy: fsl-usb: remove character device usage
  (jsc#SLE-12251).
- USB: phy: fsl-usb: remove sysfs abuse (jsc#SLE-12251).
- usb: phy: phy-fsl-usb: Make structure fsl_otg_initdata constant
  (jsc#SLE-12251).
- USB: phy: fsl-usb: convert platform driver to use dev_groups
  (jsc#SLE-12251).
- commit d31fcb5
* Wed Nov 18 2020 ohering@suse.de
- Add bug reference to two hv_netvsc patches (bsc#1178853).
- commit 2fdc798
* Wed Nov 18 2020 ohering@suse.de
- x86/hyperv: Clarify comment on x2apic mode (git-fixes).
- commit 47d9c63
* Wed Nov 18 2020 ohering@suse.de
- hv: clocksource: Add notrace attribute to
  read_hv_sched_clock_*() functions (git-fixes).
- commit 803c2b1
* Wed Nov 18 2020 yousaf.kaukab@suse.com
- cpuidle: psci: Fix suspicious RCU usage (jsc#SLE-12251).
- cpuidle: psci: Prevent domain idlestates until consumers are
  ready (jsc#SLE-12251).
- cpuidle: psci: Convert PM domain to platform driver
  (jsc#SLE-12251).
- cpuidle: psci: Fix error path via converting to a platform
  driver (jsc#SLE-12251).
- cpuidle: psci: Fail cpuidle registration if set OSI mode failed
  (jsc#SLE-12251).
- cpuidle: psci: Split into two separate build objects
  (jsc#SLE-12251).
- drivers/firmware/psci: Assign @err directly in hotplug_tests()
  (jsc#SLE-12251).
- cpuidle: psci: Fixup execution order when entering a domain
  idle state (jsc#SLE-12251).
- cpuidle: psci: Split psci_dt_cpu_init_idle() (jsc#SLE-12251).
- cpuidle: psci: Add support for PM domains by using genpd
  (jsc#SLE-12251).
- PM / Domains: Introduce a genpd OF helper that removes a
  subdomain (jsc#SLE-12251).
- cpuidle: psci: Support CPU hotplug for the hierarchical model
  (jsc#SLE-12251).
- cpuidle: psci: Manage runtime PM in the idle path
  (jsc#SLE-12251).
- cpuidle: psci: Prepare to use OS initiated suspend mode via
  PM domains (jsc#SLE-12251).
- cpuidle: psci: Attach CPU devices to their PM domains
  (jsc#SLE-12251).
- cpuidle: psci: Add a helper to attach a CPU to its PM domain
  (jsc#SLE-12251).
- cpuidle: psci: Support hierarchical CPU idle states
  (jsc#SLE-12251).
- cpuidle: psci: Simplify OF parsing of CPU idle state nodes
  (jsc#SLE-12251).
- cpuidle: dt: Support hierarchical CPU idle states
  (jsc#SLE-12251).
- of: base: Add of_get_cpu_state_node() to get idle states for
  a CPU node (jsc#SLE-12251).
- cpuidle: psci: Align psci_power_state count with idle state
  count (jsc#SLE-12251).
- PM / Domains: Align in-parameter names for some genpd functions
  (jsc#SLE-12251).
- commit cfb59fe
* Wed Nov 18 2020 msuchanek@suse.de
- powerpc/pmem: Initialize pmem device on newer hardware
  (jsc#SLE-16402 jsc#SLE-16497 bsc#1176109 ltc#187964).
- powerpc/pmem: Avoid the barrier in flush routines (jsc#SLE-16402
  jsc#SLE-16497 bsc#1176109 ltc#187964).
- powerpc/pmem: Update ppc64 to use the new barrier instruction
  (jsc#SLE-16402 jsc#SLE-16497 bsc#1176109 ltc#187964).
- libnvdimm/nvdimm/flush: Allow architecture to override the flush
  barrier (jsc#SLE-16402 jsc#SLE-16497 bsc#1176109 ltc#187964).
- powerpc/pmem: Add flush routines using new pmem store and sync
  instruction (jsc#SLE-16402 jsc#SLE-16497 bsc#1176109 ltc#187964).
- powerpc/pmem: Add new instructions for persistent storage and
  sync (jsc#SLE-16402 jsc#SLE-16497 bsc#1176109 ltc#187964).
- powerpc/pmem: Restrict papr_scm to P8 and above (jsc#SLE-16402
  jsc#SLE-16497 bsc#1176109 ltc#187964).
- commit 5a4cff0
* Wed Nov 18 2020 tiwai@suse.de
- gpio: Pass mask and size with the init_valid_mask()
  (jsc#SLE-12730).
- Refresh
  patches.suse/gpiolib-Introduce-add_pin_ranges-callback.patch.
- commit 4f43960
* Wed Nov 18 2020 tiwai@suse.de
- gpio: aspeed: Pass irqchip when adding gpiochip (jsc#SLE-12730).
- Refresh
  patches.suse/gpio-aspeed-Fix-incorrect-number-of-banks.patch.
- commit 4ad35e3
* Wed Nov 18 2020 tiwai@suse.de
- gpio: Remove dev_err() usage after platform_get_irq()
  (jsc#SLE-12730).
- Refresh
  patches.suse/gpio-max77620-Don-t-shadow-error-code-of-platform_ge.patch.
- commit 3167e98
* Wed Nov 18 2020 tiwai@suse.de
- gpio: mockup: don't depend twice on GPIOLIB (jsc#SLE-12730).
- gpio: hlwd: Pass irqchip when adding gpiochip (jsc#SLE-12730).
- gpio: xlp: Pass irqchip when adding gpiochip (jsc#SLE-12730).
- gpio: cadence: Pass irqchip when adding gpiochip
  (jsc#SLE-12730).
- gpio: thunderx: Switch to GPIOLIB_IRQCHIP (jsc#SLE-12730).
- gpio: ixp4xx: Convert to hierarchical GPIOLIB_IRQCHIP
  (jsc#SLE-12730).
- gpio: remove ks8695 driver (jsc#SLE-12730).
- commit 7ebfb0b
* Wed Nov 18 2020 tiwai@suse.de
- gpiolib: acpi: Split ACPI stuff to gpiolib-acpi.h
  (jsc#SLE-12730).
- Refresh
  patches.suse/gpiolib-acpi-Add-honor_wakeup-module-option-quirk-me.patch.
- Refresh
  patches.suse/gpiolib-acpi-Rework-honor_wakeup-option-into-an-igno.patch.
- Refresh
  patches.suse/gpiolib-acpi-Turn-dmi_system_id-table-into-a-generic.patch.
- commit f7da78b
* Wed Nov 18 2020 tiwai@suse.de
- gpio: madera: Use local copy of pdata (jsc#SLE-12730).
- gpio: arizona: Use local copy of pdata (jsc#SLE-12730).
- gpio: viperboard: Replace 'unsigned' with 'unsigned int'
  (jsc#SLE-12730).
- gpio: refactor gpiochip_allocate_mask() with bitmap_alloc()
  (jsc#SLE-12730).
- gpiolib-acpi: Move acpi_dev_add_driver_gpios() et al to
  consumer.h (jsc#SLE-12730).
- gpio: max77650: add MODULE_ALIAS() (jsc#SLE-12730).
- gpio: bd70528: remove redundant assignment to variable ret
  (jsc#SLE-12730).
- gpio: bd70528: fix spelling misstake "debouce" -> "debounce"
  (jsc#SLE-12730).
- commit b978538
* Wed Nov 18 2020 ohering@suse.de
- Drivers: hv: vmbus: Allow cleanup of VMBUS_CONNECT_CPU if
  disconnected (git-fixes).
- commit 1361be0
* Wed Nov 18 2020 jeyu@suse.de
- Update Patch-metadata after merging into mainline:
- patches.suse/i40e-xsk-uninitialized-variable-in-i40e_clean_rx_irq.patch
- commit 0b71e11
* Wed Nov 18 2020 yousaf.kaukab@suse.com
- optee: model OP-TEE as a platform device/driver (jsc#SLE-12251).
- tee: optee: Fix compilation issue with nommu (jsc#SLE-12251).
- optee: Fix multi page dynamic shm pool alloc (jsc#SLE-12251).
- tee: optee: fix device enumeration error handling
  (jsc#SLE-12251).
- tee: optee: Fix dynamic shm pool allocations (jsc#SLE-12251).
- tee: optee: add might_sleep for RPC requests (jsc#SLE-12251).
- commit 859d294
* Wed Nov 18 2020 jslaby@suse.cz
- x86/platform/uv: Fix copied UV5 output archtype (bsc#1178908
  bsc#1177710 jsc#SLE-13285).
- x86/platform/uv: Drop last traces of uv_flush_tlb_others
  (bsc#1178908 bsc#1177710 jsc#SLE-13285).
- x86/tlb/uv: Add a forward declaration for struct flush_tlb_info
  (bsc#1178908 bsc#1177710 jsc#SLE-13285).
- x86/platform/uv: Mark is_uv_hubless() static (bsc#1178908
  bsc#1177710 jsc#SLE-13285).
- commit a7ea789
* Wed Nov 18 2020 tiwai@suse.de
- Input: resistive-adc-touch - fix kconfig dependency on
  IIO_BUFFER (git-fixes).
- Input: adxl34x - clean up a data type in adxl34x_probe()
  (git-fixes).
- commit 35dd120
* Wed Nov 18 2020 ohering@suse.de
- Add bug reference to a pci-hyperv patch (bsc#1178901).
- commit 5530843
* Wed Nov 18 2020 glin@suse.com
- bpfilter: switch bpfilter_ip_set_sockopt to sockptr_t
  (bsc#1177028).
- commit f612634
* Wed Nov 18 2020 tiwai@suse.de
- Input: sunkbd - avoid use-after-free in teardown paths
  (CVE-2020-25669 bsc#1178182).
- commit bafe1db
* Wed Nov 18 2020 glin@suse.com
- bpfilter: Allow to build bpfilter_umh as a module without static library (bsc#1177028).
  Update config files:
- Add CONFIG_BPFILTER_UMH=m back to x86_64/default
- umd: Stop using split_argv (bsc#1177028).
- umd: Remove exit_umh (bsc#1177028).
- bpfilter: Take advantage of the facilities of struct pid (bsc#1177028).
  Refresh patches.suse/net-bpfilter-split-__bpfilter_process_sockopt.patch
- exit: Factor thread_group_exited out of pidfd_poll
  (bsc#1177028).
- umd: Track user space drivers with struct pid (bsc#1177028).
  Refresh patches:
- patches.suse/bpfilter-Initialize-pos-variable.patch
- patches.suse/bpfilter-fix-up-a-sparse-annotation.patch
- patches.suse/net-bpfilter-split-__bpfilter_process_sockopt.patch
- bpfilter: Move bpfilter_umh back into init data (bsc#1177028).
- exec: Remove do_execve_file (bsc#1177028).
- umh: Stop calling do_execve_file (bsc#1177028).
- umd: Transform fork_usermode_blob into fork_usermode_driver
  (bsc#1177028).
- umd: Rename umd_info.cmdline umd_info.driver_name (bsc#1177028).
- umd: For clarity rename umh_info umd_info (bsc#1177028).
- umh: Separate the user mode driver and the user mode helper
  support (bsc#1177028).
- umh: Remove call_usermodehelper_setup_file (bsc#1177028).
- umh: Rename the user mode driver helpers for clarity
  (bsc#1177028).
- umh: Move setting PF_UMH into umh_pipe_setup (bsc#1177028).
- umh: Capture the pid in umh_pipe_setup (bsc#1177028).
- commit 7fb16dd
* Wed Nov 18 2020 glin@suse.com
- bpfilter: document build requirements for bpfilter_umh
  (bsc#1177028).
- bpfilter: use 'userprogs' syntax to build bpfilter_umh
  (bsc#1177028).
- kbuild: add infrastructure to build userspace programs
  (bsc#1177028).
- bpfilter: check if $(CC) can link static libc in Kconfig (bsc#1177028).
  Update config files
- Set CONFIG_CC_CAN_LINK_STATIC=n since we don't build in bpfilter
- Temporarily remove CONFIG_BPFILTER_UMH=m
  + Will add it back later
- commit 4602c14
* Tue Nov 17 2020 tonyj@suse.de
- perf/x86/intel: Support per-thread RDPMC TopDown metrics
  (jsc#SLE-13346).
- perf/x86/intel: Support TopDown metrics on Ice Lake
  (jsc#SLE-13346).
- perf/x86: Add a macro for RDPMC offset of fixed counters
  (jsc#SLE-13346).
- commit 6b22c07
* Tue Nov 17 2020 tonyj@suse.de
- perf/x86/intel: Generic support for hardware TopDown metrics
  (jsc#SLE-13346).
- Refresh
  patches.suse/perf-x86-fix-n_pair-for-cancelled-txn.patch.
- commit dba68ee
* Tue Nov 17 2020 tonyj@suse.de
- perf/core: Add a new PERF_EV_CAP_SIBLING event capability
  (jsc#SLE-13346).
- perf/x86/intel: Use switch in intel_pmu_disable/enable_event
  (jsc#SLE-13346).
- perf/x86/intel: Fix the name of perf METRICS (jsc#SLE-13346).
- perf/x86/intel: Move BTS index to 47 (jsc#SLE-13346).
- perf/x86/intel: Introduce the fourth fixed counter
  (jsc#SLE-13346).
- perf/x86/intel: Name the global status bit in NMI handler
  (jsc#SLE-13346).
- perf/x86: Use event_base_rdpmc for the RDPMC userspace support
  (jsc#SLE-13346).
- perf/x86: Keep LBR records unchanged in host context for guest
  usage (jsc#SLE-13346).
- perf/x86: Add constraint to create guest LBR event without hw
  counter (jsc#SLE-13346).
- perf/x86/lbr: Add interface to get LBR information
  (jsc#SLE-13346).
- perf/x86/core: Refactor hw->idx checks and cleanup
  (jsc#SLE-13346).
- perf/core: Unify {pinned,flexible}_sched_in() (jsc#SLE-13346).
- perf/x86/intel: Avoid unnecessary PEBS_ENABLE MSR access in PMI
  (jsc#SLE-13346).
- perf/x86: Provide stubs of KVM helpers for non-Intel CPUs
  (jsc#SLE-13346).
- perf/x86/intel: Implement LBR callstack context synchronization
  (jsc#SLE-13346).
- perf/core, perf/x86: Introduce swap_task_ctx() method at
  'struct pmu' (jsc#SLE-13346).
- commit 0679634
* Tue Nov 17 2020 yousaf.kaukab@suse.com
- regulator: fixed: add off-on-delay (jsc#SLE-12251).
- commit 799dfed
* Tue Nov 17 2020 pjakobsson@suse.de
- resource: add a not device managed request_free_mem_region
  variant (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- Refresh
  patches.suse/dev-mem-Revoke-mappings-when-a-driver-claims-the-reg.patch.
- commit 970e8db
* Tue Nov 17 2020 yousaf.kaukab@suse.com
- rtc: ds1307: Clear OSF flag on DS1388 when setting time
  (jsc#SLE-12251).
- commit cc52d58
* Tue Nov 17 2020 yousaf.kaukab@suse.com
- rtc: ds1307: provide an indication that the watchdog has fired
  (jsc#SLE-12251).
- rtc: ds1307: check for failed memory allocation on wdt
  (jsc#SLE-12251).
- rtc: ds1307: add support for watchdog timer on ds1388
  (jsc#SLE-12251).
- rtc: ds1307: handle oscillator failure flags for ds1388 variant
  (jsc#SLE-12251).
- commit d4d523e
* Tue Nov 17 2020 yousaf.kaukab@suse.com
- i2c: mux: pca954x: Convert license to SPDX identifier
  (jsc#SLE-12251).
- i2c: mux: pca954x: Move device_remove_file() out of
  pca954x_cleanup() (jsc#SLE-12251).
- i2c: mux: pca954x: Make use of device properties
  (jsc#SLE-12251).
- i2c: mux: pca954x: Refactor pca954x_irq_handler()
  (jsc#SLE-12251).
- i2c: mux: pca954x: support property idle-state (jsc#SLE-12251).
- commit 8b7638a
* Tue Nov 17 2020 yousaf.kaukab@suse.com
- i2c: imx: ACPI support for NXP i2c controller (jsc#SLE-12251).
- commit 0652f75
* Tue Nov 17 2020 oneukum@suse.com
- docs: ABI: sysfs-c2port: remove a duplicated entry (git-fixes).
- commit 436b016
* Tue Nov 17 2020 yousaf.kaukab@suse.com
- dmaengine: fsl-dpaa2-qdma: remove set but not used variable
  'dpaa2_qdma' (jsc#SLE-12251).
- dmaengine: fsl-dpaa2-qdma: Adding shutdown hook (jsc#SLE-12251).
- dmaengine: fsl-dpaa2-qdma: Remove unnecessary local variables
  in DPDMAI_CMD_CREATE macro (jsc#SLE-12251).
- dmaengine: fsl-dpaa2-qdma: export the symbols (jsc#SLE-12251).
- dmaengine: fsl-dpaa2-qdma: Add NXP dpaa2 qDMA controller driver
  for Layerscape SoCs (jsc#SLE-12251).
- dmaengine: fsl-dpaa2-qdma: Add the DPDMAI(Data Path DMA
  Interface) support (jsc#SLE-12251).
- commit 297a0bf
* Tue Nov 17 2020 yousaf.kaukab@suse.com
- mmc: sdio: fix clock rate setting for SDR12/SDR25 mode
  (jsc#SLE-12251).
- mmc: sdhci-of-esdhc: exit HS400 properly before setting any
  speed mode (jsc#SLE-12251).
- mmc: sdhci: add spin lock for sdhci_set_default_irqs in
  sdhci_init (jsc#SLE-12251).
- mmc: sdhci-of-esdhc: fix serious issue clock is always disabled
  (jsc#SLE-12251).
- mmc: sdhci-of-esdhc: fix transfer mode register reading
  (jsc#SLE-12251).
- mmc: sdhci-of-esdhc: fix clock setting for different controller
  versions (jsc#SLE-12251).
- mmc: sdhci-of-esdhc: update tuning erratum A-008171
  (jsc#SLE-12251).
- mmc: sdhci-of-esdhc: convert to use esdhc_tuning_window_ptr()
  (jsc#SLE-12251).
- mmc: sdhci-of-esdhc: use 1/2 periperhal clock for ls1088a
  (jsc#SLE-12251).
- commit c331989
* Tue Nov 17 2020 oneukum@suse.com
- kgdb: Fix spurious true from in_dbg_master() (git-fixes).
- commit 1e8d73b
* Tue Nov 17 2020 pjakobsson@suse.de
- Update config files.
  Update for DRM v5.8 backport
- commit db4dda7
* Tue Nov 17 2020 glin@suse.com
- bpf, doc: Remove references to warning message when using
  bpf_trace_printk() (bsc#1177028).
- commit 305cc47
* Tue Nov 17 2020 glin@suse.com
- bpf: Setup socket family and addresses in bpf_prog_test_run_skb (bsc#1177028).
  Refresh patches.suse/bpf-Allow-to-specify-ifindex-for-skb-in-bpf_prog_tes.patch
- commit 4740764
* Tue Nov 17 2020 glin@suse.com
- s390/bpf: Use bpf_skip() in bpf_jit_prologue() (bsc#1177028).
- commit 3e03b2e
* Tue Nov 17 2020 jlee@suse.com
- efi: Fix handling of multiple efi_fake_mem= entries
  (jsc#SLE-16407).
- efi: Fix efi_memmap_alloc() leaks (jsc#SLE-16407).
- efi: Add tracking for dynamically allocated memmaps
  (jsc#SLE-16407).
- efi: Add a flags parameter to efi_memory_map (jsc#SLE-16407).
- efi/libstub/random: Initialize pointer variables to zero for
  mixed mode (jsc#SLE-16407).
- x86/efi: Update e820 with reserved EFI boot services data to
  fix kexec breakage (jsc#SLE-16407).
- efi: Fix efi_loaded_image_t::unload type (jsc#SLE-16407).
- efi/apple-properties: use PROPERTY_ENTRY_U8_ARRAY_LEN
  (jsc#SLE-16407).
- software node: introduce PROPERTY_ENTRY_XXX_ARRAY_LEN()
  (jsc#SLE-16407).
- x86/efi: Add efi_fake_mem support for EFI_MEMORY_SP
  (jsc#SLE-16407).
  Refresh
  patches.suse/0002-ima-generalize-x86-EFI-arch-glue-for-other-EFI-archi.patch
- x86/efi: Push EFI_MEMMAP check into leaf routines
  (jsc#SLE-16407).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- efi: Enumerate EFI_MEMORY_SP (jsc#SLE-16407).
- ACPICA: make acpi_load_table() return table index
  (jsc#SLE-16407).
  Refresh
  patches.suse/ACPI-configfs-Add-missing-config_item_put-to-fix-ref.patch.
- ACPICA: Add new external interface, acpi_unload_table()
  (jsc#SLE-16407).
  Refresh
  patches.suse/ACPI-configfs-Add-missing-config_item_put-to-fix-ref.patch.
- efi/random: use arch-independent efi_call_proto()
  (jsc#SLE-16407).
- efi/efi_test: Lock down /dev/efi_test and require CAP_SYS_ADMIN
  (jsc#SLE-16407).
- commit 672368d
* Tue Nov 17 2020 glin@suse.com
- arm64: bpf: Fix branch offset in JIT (bsc#1177028).
- bpf: Remove inline from bpf_do_trace_printk (bsc#1177028).
- bpf, arm64: Add BPF exception tables (bsc#1177028).
- bpf: Use dedicated bpf_trace_printk event instead of
  trace_printk() (bsc#1177028).
- bpf: Allow %%pB in bpf_seq_printf() and bpf_trace_printk()
  (bsc#1177028).
- bpf: Support 'X' in bpf_seq_printf() helper (bsc#1177028).
- commit 8b2406b
* Tue Nov 17 2020 glin@suse.com
- bpf: Zero-fill re-used per-cpu map element (bsc#1155518).
- libbpf, hashmap: Fix undefined behavior in hash_bits
  (bsc#1155518).
- bpf: Don't rely on GCC __attribute__((optimize)) to disable GCSE
  (bsc#1155518).
- bpf: Fix comment for helper bpf_current_task_under_cgroup()
  (bsc#1155518).
- commit fb71c62
* Tue Nov 17 2020 pjakobsson@suse.de
- blacklist.conf: Add dups from DRM v5.8 backport
- commit 34e47a8
* Mon Nov 16 2020 mgorman@suse.de
- sched: Fix loadavg accounting race on arm64 kabi (bnc#1178227).
- commit a595855
* Mon Nov 16 2020 mkoutny@suse.com
- blacklist.conf: 11d6761218d1 mm, memcg: fix error return value of mem_cgroup_css_alloc()
- commit 0ae5ae6
* Mon Nov 16 2020 mkoutny@suse.com
- blacklist.conf: 8380ce479010 mm: fork: fix kernel_stack memcg stats for various stack implementations
- commit 5d6fe57
* Mon Nov 16 2020 mkoutny@suse.com
- mm, memcg: fix error return value of mem_cgroup_css_alloc()
  (bsc#1178852).
- mm: fork: fix kernel_stack memcg stats for various stack
  implementations (bsc#1177709).
- commit 7d19c25
* Mon Nov 16 2020 lduncan@suse.com
- loop: Set correct device size when using LOOP_CONFIGURE
  (bsc#1177476).
- commit 3d60db0
* Mon Nov 16 2020 pjakobsson@suse.de
- Revert "drm/amdgpu: Fix NULL dereference in dpm sysfs handlers"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- blacklist.conf: unblacklist patches included in the DRM v5.8
  backport.
- drm/amd/display: Clear dm_state for fast updates (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Prevent kernel-infoleak in amdgpu_info_ioctl()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: Accept 'legacy' format modifiers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: hold gem reference until object is no longer accessed
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dbi: Fix SPI Type 1 (9-bit) transfer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/drm_fb_helper: fix fbdev with sparc64 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mcde: Fix stability issue (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: nwl-dsi: Drop DRM_BRIDGE_ATTACH_NO_CONNECTOR check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: Fix auo, kd101n80-45na horizontal noise on edges
  of panel (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: panel: simple: Delay HPD checking on boe_nv133fhm_n61
  for 15 ms (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge/adv7511: set the bridge type properly (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: of: Fix double-free bug (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fbcon: zero-initialise the mode_cmd2 structure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fbcon: fix module unload when fbcon init has failed
  for (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/tu102: wait for core update to complete when
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/gf100: use correct format modifiers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp/gm200-: fix regression from HDA SOR selection
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- fbdev: Detect integer underflow at "struct
  fbcon_ops"->clear_margins (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Fix NULL dereference in dpm sysfs handlers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: fix a crash when overclocking Vega M
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: fix wait pp reset timeout (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: sun4i: hdmi: Fix inverted HPD result (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/sdma5: fix wptr overwritten in ->get_wptr()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/powerplay: Modify SMC message name for setting power
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: handle failed allocation during stream
  construction (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: OLED panel backlight adjust not work with
  external (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: create fake mst encoders ahead of time (v4)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix preemption unit test (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/gfx10: fix race condition for kiq (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Recalculate FBC w/a stride when needed (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Move cec_notifier to intel_hdmi_connector_unregister,
  v2 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Only swap to a random sibling once upon creation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Ignore irq enabling on the virtual engines
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: Use GTT when saving/restoring engine GPR
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Fix compare functions provided for sorting
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dmabuf: use spinlock to access dmabuf->name (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/aspeed: Call drm_fbdev_generic_setup after drm_dev_register
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: fix update of display surface when resolution
  changes (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: don't do soft recovery if gpu_recovery=0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: fix double free (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add dmcub check on RENOIR (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add TMR destory function for psp (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: asd function needs to be unloaded in suspend phase
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Pin the rings before marking active (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Also drop vm.ref along error paths for vma
  construction (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Drop vm.ref for duplicate vma on construction
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: Fix fence_y_offset handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Skip stale object handle for debugfs per-file-stats
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nouveau: fix page fault on device private memory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/svm: fix migrate page regression (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/i2c/g94-: increase NV_PMGR_DP_AUXCTL_TRANSACTREQ
  timeout (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: bail from nv50_audio_disable() early
  if audio (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/hisilicon/hibmc: Move drm_fbdev_generic_setup() down
  to avoid the (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: viu: fix setting the OSD burst length in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: sun4i: hdmi: Remove extra HPD polling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma-buf: Move dma_buf_release() from fops to dentry_ops
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use %%u rather than %%d for sclk/mclk (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/atomfirmware: fix vram_info fetching for renoir
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Only revalidate bandwidth on medium and
  fast updates (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: Fix NULL dereference in lock_bus() on Vega20
  w/o (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Include asm sources for {ivb, hsw}_clear_kernel.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Use GFP_ATOMIC instead of GFP_KERNEL in
  atomic context (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Fix incorrect check of enabled bits in mask
  registers (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Fix two CFL MMIO handling caused by regression
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Add one missing MMIO handler for D_SKL_PLUS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: fix ref count leak in mic_pre_enable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/exynos: Properly propagate return value in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/exynos: Remove dev_err() on platform_get_irq() failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: Fix up the rest of the messed up address sizes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: Fix setup of a6xx create_address_space (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Fix address space size after refactor (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Fix 0xfffflub in "Refactor address space
  initialization" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: allow initialization of encoder locks during
  encoder (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: fix error return code in dpu_encoder_init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: fix potential memleak in error branch (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: request for display color blocks based on
  hw catalog (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/fb-helper: Fix vt restore (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: mixer: Call of_dma_configure if there's an IOMMU
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: panel-orientation-quirks: Use generic orientation-data
  for Acer (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: panel-orientation-quirks: Add quirk for Asus T101HA panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: uvesafb: fix "noblank" option handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel-simple: fix connector type for (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel-simple: fix connector type for LogicPD Type28 Display
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: mcde: Fix forgotten user of drm->dev_private
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: mcde: Fix display initialization problem (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: Fix dma_fence refcnt leak when adding move fence
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: Fix dma_fence refcnt leak in ttm_bo_vm_fault_reserved
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd: fix potential memleak in err branch (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix ineffective setting of max bpc property
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Enable output_bpc property on all outputs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add fw release for sdma v5_0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/radeon: fix fb_div check in ni_init_smc_spll_table()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: Unlock mutex on error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tegra: Add zpos property for cursor planes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- gpu: host1x: Correct trivial kernel-doc inconsistencies
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: hub: Register child devices (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- gpu: host1x: Register child devices (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tegra: hub: Do not enable orphaned window group
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gpu: host1x: Clean up debugfs in error handling path
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: rcar-du: Fix build error (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: backlight: tosa_lcd: convert to use
  i2c_new_client_device() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: encoder_slave: use new I2C API (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: encoder_slave: fix refcouting error for modules
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix documentation around busy_percentage
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/pm: update comment to clarify Overdrive interfaces
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Use correct major in devcgroup check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Rework dsc to isolate FPU operations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Replace invalid device ID with a valid device ID
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use kfree() to free rgb_user in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Use kvfree() to free coeff in build_regamma()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Fix the encoder type check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/icl+: Fix hotplug interrupt disabling after storm
  detection (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Move gen4 GT workarounds from init_clock_gating to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Move ilk GT workarounds from init_clock_gating to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Move snb GT workarounds from init_clock_gating to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Move vlv GT workarounds from init_clock_gating to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Move ivb GT workarounds from init_clock_gating to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Move hsw GT workarounds from init_clock_gating to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/icl: Disable DIP on MST ports with the transcoder clock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Incrementally check for rewinding (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tc: fix the reset of ln0 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Prevent timeslicing into unpreemptable requests
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Restore to default heartbeat (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: work around false-positive maybe-uninitialized warning
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pmu: avoid an maybe-uninitialized warning
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Incorporate the virtual engine into timeslicing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Replace zero-length array with flexible-array
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- amdgpu: a NULL ->mm does not mean a thread is a kthread
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: fix missing break in switch statement for format->cpp
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: hdmi ddc clk: Fix size of m divider (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/connector: notify userspace on hotplug after register
  complete (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Only query DP state of a DDI encoder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/params: fix i915.reset module param type
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Mark the buffer pool as active for the cmdparser
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- i915:get_engines(): get rid of pointless access_ok()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- i915: alloc_oa_regs(): get rid of pointless access_ok()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- i915 compat ioctl(): just use drm_ioctl_kernel() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- i915: switch copy_perf_config_registers_or_number() to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- i915: switch query_{topology,engine}_info() to copy_to_user()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- mmap locking API: use coccinelle to convert mmap_sem rwsem
  call sites (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- DMA reservations: use the new mmap locking API (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- mmap locking API: initial implementation as rwsem wrappers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- mm: don't include asm/pgtable.h if linux/mm.h is already
  included (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/msm/dpu: add support for clk and bw scaling
  for display" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: skip HFI set freq if GMU is powered down
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: Update the MMU helper function APIs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Refactor address space initialization (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Attach the IOMMU device during initialization
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: dpu_setup_dspp_pcc() can be static (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/a6xx: a6xx_hfi_send_start() can be static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a4xx: add a405_registers for a405 device (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/a4xx: add adreno a405 support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/a6xx: update a6xx_hw_init for A640 and A650
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: enable GMU log (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: update pdc/rscc GMU registers for A640/A650
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: A640/A650 GMU firmware path (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/a6xx: HFI v2 for A640 and A650 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/a6xx: add A640/A650 to gpulist (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/a6xx: use msm_gem for GMU memory objects (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: add internal MSM_BO_MAP_PRIV flag (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: add msm_gem_get_and_pin_iova_range (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Check for powered down HW in the devfreq callbacks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: update bandwidth threshold check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: add support for clk and bw scaling for display
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: add support for pcc color block in dpu driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: add support for color processing blocks in
  dpu driver (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/mdp5: Fix mdp5_init error path for failed mdp5_kms
  allocation (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: Fix typo (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: Fix undefined "rd_full" link error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Add syncobj support (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: Fix compile warnings (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: Fix a typo in an error message (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/mdp5: Add MDP5 configuration for MSM8x36 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gvt: Use ARRAY_SIZE for vgpu_types (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/params: fix i915.fake_lmem_start module param sysfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/params: don't expose inject_probe_failure in debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Whitelist context-local timestamp in the gen9
  cmdparser (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix global state use-after-frees with a refcount
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Check for awaits on still currently executing requests
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Do not schedule normal requests immediately along
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Reorder await_execution before await_request
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Avoid iterating an empty list (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Avoid using rq->engine after free during
  i915_fence_release (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Disable semaphore inter-engine sync without
  timeslicing (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Don't set queue-priority hint when supressing the
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Revalidate bandwidth before commiting
  DC updates (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: use blanked rather than plane state for sync
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/amd/display: disable dcn20 abm feature for bring up"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: ack the SMUToHost interrupt on receive V2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/pm: return an error during GPU reset or suspend (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: clear SW state of disabled windows harder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: gr/gk20a: Use firmware version 0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/disp/gm200-: detect and potentially disable
  HDA support (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp/gp100: split SOR implementation from gm200
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp: modify OR allocation policy to account for HDA
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp: split part of OR allocation logic into
  a function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp: provide hint to OR allocation about HDA
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/gt215-: fix race with audio driver runpm
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp/gm200-: fix NV_PDISP_SOR_HDMI2_CTRL(n)
  selection (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: constify sysrq_key_op (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- powerpc: Remove Xilinx PPC405/PPC440 support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drivers/powerpc: Replace _ALIGN_UP() by ALIGN() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: remove drm specific kmap_atomic code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- backlight: Add backlight_device_get_by_name() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- backlight: qcom-wled: Add support for WLED5 peripheral that is
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: qcom-wled: Add callback functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- backlight: l4f00242t03: Convert to GPIO descriptors
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: lp855x: Ensure regulators are disabled on probe
  failure (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- media: cec-gpio: handle gpiod_get_value errors correctly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix device attribute node create failed with multi
  gpu (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Sync with VM root BO when switching VM to CPU
  update mode (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Handle GPU reset for DC block (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add apu flags (v2) (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerpay: Disable gfxoff when setting manual mode on
  picasso and raven (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix pm sysfs node handling (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: move gpu_info parsing after common early init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: move discovery gfx config fetching (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: resize VRAM BAR for CPU access on gfx10
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: drop navi pcie bw callback (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: improve error handling in pcie_bw (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: fix restore worker race condition (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: off by one in amdgpu_device_attr_create_groups()
  error handling (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu10: Replace one-element array and use
  struct_size() helper (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Set/Reset avmute when disable/enable stream
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix incorrectly pruned modes with deep color
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: correct rn NUM_VMID (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Avoid pipe split when plane is too small
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix and simplify pipe split logic
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Minimize DSC resource re-assignment
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add condition to set MP1 state on gpu reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: report the real PCI bus number (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu fix incorrect sysfs remove behavior for xgmi
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: unify the prompts on thermal interrupts
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Enable fp16 also on DCE-11.0 - DCE-12. (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Expose support for xBGR ordered fp16 formats
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn2.5: Remove old DPG workaround (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/jpeg2.5: Remove JPEG_ENC_MASK from clock ungating
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: resolve ras recovery vs smi race condition
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Fix boolreturn.cocci warnings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Respect PP_STUTTER_MODE but don't override
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix disable_stutter debug option
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DC Debug mask to disable features
  for bringup (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: cleanup unnecessary virt sriov check in amdgpu
  attribute (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vblank: Fix -Wformat compile warnings on some arches
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp: Lenovo X13 Yoga OLED panel brightness fix
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: use correct conflicting framebuffer API
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/dispnv50: fix runtime pm imbalance on error
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: fix runtime pm imbalance on error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/debugfs: fix runtime pm imbalance on error
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nouveau/hmm: fix migrate zero page to GPU
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nouveau/hmm: fix nouveau_dmem_chunk allocations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: Share DP SST mode_valid() handling with
  MST (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: Move 8BPC limit for MST into
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/gv100-: Add support for interlaced modes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: Probe SOR and PIOR caps for DP
  interlacing (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: Initialize core channel in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp/hda/gv100-: NV_PDISP_SF_AUDIO_CNTRL0
  register moved (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp/hda/gf119-: select HDA device entry based
  on bound (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp/hda/gf119-: add HAL for programming device
  entry in (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp/hda/gt215-: pass head to nvkm_ior.hda.eld()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp/nv50-: increase timeout on pio channel free()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms: Fix regression by audio component transition
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/device: use regular PRI accessors in chipset
  detection (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/device: detect vGPUs (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/device: detect if changing endianness failed
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/device: rework mmio mapping code to get rid of
  second map (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/mmu: Remove unneeded semicolon (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau: Use generic helper to check _PR3 presence
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/acr: Use kmemdup instead of kmalloc and memcpy
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/core/memory: remove redundant assignments to
  variable ret (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/svm: map pages after migration (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/disp/gv100-: expose capabilities class
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/bios: move ACPI _ROM handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau: remove open-coded version of (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/gr/gk20a: move MODULE_FIRMWARE firmware definitions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/ibus: use nvkm_subdev_new_() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/core: add nvkm_subdev_new_() for bare subdevs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms: Support NVIDIA format modifiers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/kms: Check framebuffer size against bo
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms: Add format mod prop to base/ovly/nvdisp
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/acr: ensure falcon providing acr functions is
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms: Remove struct nouveau_framebuffer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms: Remove field nvbo from struct
  nouveau_framebuffer (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms: Move struct nouveau_framebuffer.vma to struct
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms: Remove unused fields from struct
  nouveau_framebuffer (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: fix out-of-tree module build (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Generalized NV Block Linear DRM format mod (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix AUX power domain toggling across TypeC mode resets
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Mark check_shadow_context_ppgtt as maybe unused
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: avoid unused scale_user_to_hw() warning
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos-vidi: convert platform driver to use dev_groups
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: dsi: Remove bridge node reference in error
  handling path (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: mixer: Fix enabling of the runtime power management
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: make pointer to const data const type
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: gem: Get rid of the internal 'pages' array
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: gem: rework scatter-list contiguity check on
  prime import (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: gem: Remove dead-code (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: Delete an error message in three functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Update DRIVER_DATE to 20200515 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Document locking guidelines (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Extract i915_cs_timestamp_{ns_to_ticks,tick_to_ns}()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Store CS timestamp frequency in Hz (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Nuke pointless div by 64bit (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Enable SAGV support for Gen12 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Restrict qgv points which don't have enough bandwidth
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add TGL+ SAGV support (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: use context lrc_reg_state for shadow ppgtt
  override (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Support PPGTT table load command (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gvt: move workload destroy out of execlist complete
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/psr: Use new DP VSC SDP compute routine on PSR
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Add compute routine for DP PSR VSC SDP
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Stop sending DP SDPs on ddi disable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Program DP SDPs on pipe updates (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix enabled infoframe states of lspcon (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add state readout for DP VSC SDP (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add state readout for DP HDR Metadata Infoframe SDP
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Program DP SDPs with computed configs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Include DP VSC SDP in the crtc state dump
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Include DP HDR Metadata Infoframe SDP in the
  crtc state (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Include HDMI DRM infoframe in the crtc state dump
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Add logging function for DP VSC SDP (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dp: Read out DP SDPs (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video/hdmi: Add Unpack only function for DRM infoframe
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Transfer old virtual breadcrumbs to irq_worker
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Always call the provided (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Show per-engine default property values in sysfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Drop no-semaphore boosting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Drop I915_RESET_TIMEOUT and friends (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Mark the addition of the initial-breadcrumb in
  the request (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Remove redundant exec_fence (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove duplicate inline specifier on write_pte
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Suspend tasklets before resume sanitization
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Make active_pipes check skl specific (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Extract skl SAGV checking (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Introduce skl_plane_wm_level accessor (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Reset execlists registers before HWSP
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/ehl: Restrict w/a 1607087056 for EHL/JSL
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Restore Cherryview back to full-ppgtt
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Force pte cacheline to main memory (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove unused HAS_FWTABLE macro (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Always flush before unpining after writing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Emit await(batch) before MI_BB_START (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Use stashed away hpd isr bits in
  intel_digital_port_connected() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Stash hpd status bits under dev_priv (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Turn intel_digital_port_connected() in a vfunc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix glk watermark calculations (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/mst: Wait for ACT sent before enabling the pipe
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Tidy awaiting on dma-fences (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Make intel_timeline_init static (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Mark up the racy read of execlists->context_tag
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Replace zero-length array with flexible-array
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Replace the hardcoded I915_FENCE_TIMEOUT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Prevent using semaphores to chain up to external
  fences (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Peel dma-fence-chains for await (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Improve precision on defer_request assert
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pull waiting on an external dma-fence into its routine
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Ignore submit-fences on the same timeline
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gen12: Add aux table invalidate for all engines
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Remove wait priority boosting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gen12: Invalidate aux table entries forcibly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gen12: Flush L3 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gen12: Fix HDC pipeline flush (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Revert "drm/i915/tgl: Include ro parts of l3 to invalidate"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/icp: Add Wa_14010685332 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Stop holding onto the pinned_default_state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Record the active CCID from before reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Added required new PCode commands (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Small tidy of gen8+ breadcrumb emission
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Repeat the rps clock frequency measurement
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Warn if the FBC is still writing to stolen
  on removal (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Streamline the artihmetic (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Rename variables to be consistent with bspec
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Nuke mode.vrefresh usage (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove cnl pre-prod workarounds (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Require linear fb stride to be multiple of 512
  bytes on gen9/glk (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Rename bw_state to new_bw_state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Track active_pipes in bw_state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Use bw state for per crtc SAGV evaluation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Implement legacy MI_STORE_DATA_IMM (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Specify address type for chained reloc batches
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Allow some leniency in PCU reads (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Lazily acquire the device wakeref for freeing
  objects (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Sanitize RPS interrupts upon resume (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Try an alternate engine for relocations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Use a single chained reloc batches for a
  single execbuf (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Use chained reloc batches (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Implement vm_ops->access for gdb access into mmaps
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pmu: Keep a reference to module while active
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Move the batch buffer pool from the engine to the
  gt (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add a UAPI flag for user to call mem_sync
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: apply AMDGPU_IB_FLAG_EMIT_MEM_SYNC to compute
  IBs too (v3) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add mem_sync implementation for all the ASICs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add new ring callback to insert memory sync
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: optimize amdgpu device attribute code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add amdgpu_virt_get_vf_mode helper function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add autodump debugfs node for gpu reset v8
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Updated XGMI power down control support check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Update RAS XGMI error inject sequence
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add DPM function for XGMI link power down control
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add cmd to control XGMI link sleep (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: remove redundant assignment to variable ret
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: turn back rlcg write for gfx_v10 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: report correct AC/DC event based on ctxid V2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: shutdown on HW CTF (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: try to do a graceful shutdown on SW CTF
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add AQUIRE_MEM PACKET3 fields defintion
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: Use atomic_fetch_add() for the context id
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mcde: dsi: Fix return value check in mcde_dsi_bind()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Embed connector instance in struct mga_device
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Remove unused fields from struct mga_device
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Use managed mode-config initialization
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Integrate init function into load function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Remove several references to struct mga_device.dev
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Convert struct drm_device to struct mga_device with
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: pxa168fb: make pxa168fb_init_mode() return void
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i2c/tda998x: Make tda998x_audio_digital_mute static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel-simple: Support hpd-gpios for delaying prepare()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- panel: simple: Add BOE NV133FHM-N62 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- panel: simple: Fix size and bpp of BOE NV133FHM-N61
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- uapi/drm/drm_fourcc.h: Note on platform specificity for format
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Don't check new mode if CRTC is being disabled
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Make ast_primary_plane_helper_atomic_update static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drivers: drm: panel: Add ASUS TM5P5 NT35596 panel driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: panel: add MODULE_LICENSE to panel-visionox-rm69299.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: rcar-du: Set primary plane zpos immutably at initializing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: plane: Verify that no or all planes have a zpos property
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: remove defined but not used 'crtc_offsets'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: Add missing GRBM bits for GFX 10.1
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: skip judging if baco support for
  Arcturus sriov (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: only set DPM_FLAG_NEVER_SKIP for legacy ATPX BOCO
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: drop extra runtime pm handling in resume pmop
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix runpm logic in amdgpu_pmops_resume
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: drop pm_runtime_set_active (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: cleanup sysfs file handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: use node_id and node_size to calcualte
  dram_base_address (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: switch to common rlc_autoload helper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: drop unused ras ta helper function (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: switch to common ras ta helper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: switch to common xgmi ta helpers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: remove duplicate headers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: remove variable "result" in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: cleanup coding style a bit (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Fix bug in RAS invoke (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/navi10: fix unsigned comparison with 0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: disable MGCG/MGLS also on gfx CG ungate
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use the BAR if possible in amdgpu_device_vram_access
  v2 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add dm support for DP 1.4 Compliance edid
  corruption (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: allocate large structures dynamically
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- amdgpu_acpi: add backlight control for the DC case
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: fix unsigned comparison with 0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Avoid integer overflow in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: 3.2.84 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add struct field for future use (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: move location of dmub_srv.h file
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove unused module/stats (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Check DMCU Exists Before Loading
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add 4 to 1 MPC split support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: The external monitor will show gray
  screen during (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add addition dc type to translate to
  dmub fw type (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Support FP16 pixel format (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: temporary clamp the vratio used to 1.0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Allow PState switch in VBLANK one display
  VACTIVE (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Mode change with same timing causing
  long display (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Move panel_cntl specific register from abm to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove unused variable 'ret' in dm_suspend()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- amd/amdgpu: Limit rlcg write registers only for nv12
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Use a systematic method to calculate queue mask bit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Rename amdgpu_gfx_kcq_queue_mask_transform()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: skip reservation of discovery tmr region in pre-Navi
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: re-structue members for ip discovery (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: update the method to set kcq queue mask
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: check SMU NULL ptr on gfx hw init (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: change HWIP from UVD to VCN for VCN2.5
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add missing parameter description in comments
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Fix comment formatting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Changed CU reservation golden settings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Report domain with topology (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix unsigned comparison to zero (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: remove set but not used variable 'speakers'
  in dcn10_stream_encoder.c (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove set but not used variable 'speakers'
  in dce_stream_encoder.c (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove set but not used variable 'pixel_width'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove set but not used variable 'dc'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove set but not used variable 'direct_poll'
  in vcn_v2_5.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove set but not used variable 'direct_poll'
  in vcn_v2_0.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove set but not used variable 'priority'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: cleanup coding style a bit (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: update RAS sequence to parse TA flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update RAS TA to Host interface (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: update RAS error handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: put the audio codec into suspend state before
  gpu reset (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu10: remove duplicate assignment of
  smu10_hwmgr_funcs (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove duplicate assignment of dcn21_funcs
  members (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Track GPU memory utilization per process
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Update DRIVER_DATE to 20200430 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gvt: skip populate shadow context if guest context not
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: combine access to consecutive guest context pages
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: access shadow ctx via its virtual address directly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- i915/gvt: remove unused xen bits (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Add tiled blits selftest (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Restore aggressive post-boost downclocking
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Apply the aggressive downclocking to parking
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Switch to manual evaluation of RPS (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Track use of RPS interrupts in flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Move rps.enabled/active to flags (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Always enable busy-stats for execlists
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Keep a no-frills swappable copy of the default
  context (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: fix error handling in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Avoid uninitialized use of rpcurupei in
  frequency_show (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Verify we don't submit two identical CCIDs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Wa_14011059788 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Tweak the tolerance for clock ticks to 12.5%%
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: fix spelling mistake "evalution" -> "evaluation"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Fix up clock frequency (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Sanitize GT first (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Check preempt-timeout target before
  submit_ports (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: re-disable -Wframe-address (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Use indirect ctx bb to mend CMD_BUF_CCTL
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add live selftests for indirect ctx batchbuffers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add per ctx batchbuffer wa for timestamp
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add engine scratch register to live_lrc_fixed
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Drop rq->ring->vma peeking from error capture
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Use the RPM config register to determine clk
  frequencies (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Trace RPS events (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Prefer soft-rc6 over RPS DOWN_TIMEOUT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Split some long lines (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Introduce .set_idle_link_train() vfunc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Introduce .set_signal_levels() vfunc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Introduce .set_link_train() vfunc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Have pfit calculations return an error code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pass connector state to pfit calculations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: s/pipe_config/crtc_state/ in pfit functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use drm_rect to store the pfit window pos/size
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Flatten a bunch of the pfit functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix skl+ non-scaled pfit modes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Only close vma we open (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Make define for lrc state offset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Add context batchbuffers registers to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Add request throughput measurement to perf
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Check carefully for an idle engine in wait-for-idle
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Carefully order virtual_submission_tasklet
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/icl: Fix timeout handling during TypeC AUX power
  well enabling (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Drop request-before-CS assertion
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Try to detect rollback during batchbuffer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Disable heartbeat around RPS interrupt
  testing (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Unroll the CS frequency loop (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Poison residual state across resume (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Disable C-states when measuring RPS
  frequency (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Show the full scaling curve on failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Show the pstate limits on any failure
  to reset (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/vlv_dsi: Prefer drm_WARN_ON over WARN_ON
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/overlay: Prefer drm_WARN_ON over WARN_ON
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/global_state: Prefer drm_WARN* over WARN*
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/frontbuffer: Prefer drm_WARN_ON over WARN_ON
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/dpll_mgr: Prefer drm_WARN_ON over WARN_ON
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/display: Prefer drm_WARN_ON over WARN_ON
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/ddi: Prefer drm_WARN* over WARN*
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/atomic_plane: Prefer drm_WARN_ON over WARN_ON
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/icl_dsi: Prefer drm_WARN_ON over WARN_ON
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/audio: fix compressed_bpp check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: drop a bunch of superfluous inlines (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/hdmi: remove unused intel_hdmi_hdcp2_protocol()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use single set of AUX powerwell ops for gen11+
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Exercise dynamic reclocking with RPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Show the pcode frequency table on error
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Split RPS frequency measurement
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Check RPS controls (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Skip energy consumption tests if not
  controlling (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Verify frequency scaling with RPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Push MST link retraining to the hotplug work
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Flatten intel_dp_check_mst_status() a bit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pass encoder all the way to
  intel_ddi_transcoder_func_reg_val_get() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Push TRANS_DDI_FUNC_CTL into the encoder->enable()
  hook (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move the TRANS_DDI_FUNC_CTL enable to a later point
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pass encoder to intel_ddi_enable_pipe_clock()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Move the late flush_submission in retire to the end
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/audio: error log non-zero audio power refcount
  after unbind (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Refactor setting dma info to a common helper
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: remove redundant assignment to variable test_result
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add ICL PG3 PW ID for EHL (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tc: Do not warn when aux power well of static TC
  ports timeout (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tc: Catch TC users accessing FIA registers without
  enable aux (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tc/tgl: Implement TC cold sequences (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tc: Skip ref held check for TC legacy aux power wells
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tc/icl: Implement TC cold sequences (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Split hsw_power_well_enable() into two
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Add intel_legacy_aux_to_power_domain()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Move out code to return the digital_port
  of the aux ch (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add missing deinitialization cases of load failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/icl: Update forcewake firmware ranges (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Check power consumption at min/max
  frequencies (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Move gpu energy measurement into its
  own little (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add pre/post plane updates for SAGV (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Prepare to extract gen specific functions from
  intel_can_enable_sagv (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add intel_atomic_get_bw_*_state helpers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Take the engine wakeref around
  __rps_up_interrupt (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Delay spinner before waiting for an
  interrupt (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Scrub execlists state on resume (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Enable DP Display Audio WA (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add i915_lpsp_status debugfs attribute (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add connector dbgfs for all connectors (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add i915_lpsp_capability debugfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Power well id for ICL PG3 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vkms: Hold gem object while still in-use (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vkms: enable cursor by default (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Make udl_handle_damage static (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: valkyriefb.c: fix warning comparing pointer to 0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: add support for rm69299 visionox panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: w100fb: Fix a potential double free
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- fbdev: aty: use true, false for bool variables in atyfb_base.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: uvesafb: use true,false for bool variables
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: udlfb: use true,false for bool variables (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: i810: use true,false for bool variables
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mm: optimize rb_hole_addr rbtree search (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: Remove reference to the mem_glob member (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/client: Dual licence the header in GPL-2 and MIT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Replace drm_modeset_lock/unlock_all with
  DRM_MODESET_LOCK_ALL_* (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: add mode selection limits against specific SoC
  revisions (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: chrontel-ch7033: Add a new driver (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tidss: remove AM65x PG1 YUV erratum code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: change default signal polarities and drives
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: boe-tv101wum-n16: fine tune clock (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: panel-simple: fix AUO G101EVN010 connector/panel type
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Correct DP DSC macro typo (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: remove duplicate assignment of ast_crtc_funcs member
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: fix stack usage warning on old gcc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: controlfb: fix build for COMPILE_TEST=y &&
  PPC_PMAC=y (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Nuke mode->hsync (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: pl111: Move VExpress setup into versatile init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: pl111: Simplify vexpress init (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: pl111: Fix module autoloading (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Use devm_drm_dev_alloc (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/qxl: Don't use drm_device->dev_private (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/qxl: Use devm_drm_dev_alloc (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: make drm_file use keyed wakeups (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bochs: Remove explicit drm_connector_register
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Drop explicit connector register/unregister
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/aspeed: Use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/aspeed: Drop aspeed_gfx->fbdev (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/cirrus: Move to drm/tiny (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/cirrus: Don't use drm_device->dev_private (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/cirrus: Use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/komeda: use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ingenic: Don't set drm_device->dev_private (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ingenic: Use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mcde: Don't use drm_device->dev_private (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mcde: Use devm_drm_dev_alloc (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tidss: Delete tidss->saved_state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tidss: Don't use drm_device->dev_private (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tidss: Use devm_drm_dev_alloc (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/gm12u320: Don't use drm_device->dev_private (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gm12u320: Use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/hx8357d: Use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ili9225: Use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ili9341: Use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ili9486: Use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mi0283qt: Use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/repaper: Use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/st7586: Use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/st7735r: Use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: don't set drm_device->dev_private (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Use devm_drm_dev_alloc (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/v3d: Delete v3d_dev->pdev (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/v3d: Delete v3d_dev->dev (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/v3d: Use devm_drm_dev_alloc (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/v3d: Don't set drm_device->dev_private (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vboxvideo: Use devm_gen_pool_create (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vboxvideo: use managed pci functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vboxvideo: Stop using drm_device->dev_private
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vboxvideo: Use devm_drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vboxvideo: drop DRM_MTRR_WC #define (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Add devm_drm_dev_alloc macro (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: venc: remove unused variable 'venc_config_pal_bdghi'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: Remove unneeded semicolon (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Kill the second sideband tx slot, save the world
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: Remove unneeded semicolon (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/rockchip: cdn-dp-core: Make cdn_dp_core_suspend/resume
  static (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/stm: ltdc: check number of endpoints (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- panel: simple: Add Ivo M133NWF4 R0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- panel: simple: Add BOE NV133FHM-N61 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video/fbdev/riva: Remove dead code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: remove set but not used variable 'config'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: panel: Return always an error pointer in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ps8640: Let panel to set the connector type
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: panel: Set connector type for LP120UP1 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: ili9322: Remove unneeded semicolon (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: simple: Add support for AUO G121EAN01.4 panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: simple: Add support for AUO G156XTN01.0 panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: simple: Add support for AUO G190EAN01 panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: enable runtime pm (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: add pm resume/suspend ops (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: separate clk/regulator enable/disable function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: add resume/suspend callback for each ip
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: power down ip blocks when pmu exit (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: add lima_devfreq_resume/suspend (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: always set page directory when switch vm
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: check vm != NULL in lima_vm_put (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: print process name and pid when task error
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: use module_platform_driver helper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: Clean up redundant pdev pointer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: Clean up IRQ warnings (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/dp_mst: Remove single tx msg
  restriction." (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Enable over-subscription with >1 GWS queue
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Enable GWS based on FW Support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: New IOCTL to allocate queue GWS (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: pass unlocked flag to params at
  amdgpu_vm_bo_update_mapping (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add new unlocked flag for PTE updates
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: rename direct to immediate for VM updates
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: cleanup IB pool handling a bit (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: partial revert VM sync changes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: check ring type for secure IBs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix size calculation in amdgpu_ttm_copy_mem_to_mem
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add full TMZ support into amdgpu_ttm_map_buffer v2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: cleanup amdgpu_ttm_copy_mem_to_mem and
  amdgpu_map_buffer v2 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Fix per-IB secure flag GFX hang (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Fine-grained TMZ support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: stop evicting encrypted BOs to swap (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add TMZ handling to amdgpu_move_blit (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: also add the TMZ flag to GART (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix the wrong logic checking when secure buffer
  is created (v3) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Move to a per-IB secure flag (TMZ) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Indicate use of TMZ buffers to DC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: implement TMZ accessor (v3) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: remove the alignment placeholder for secure buffer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: move CS secure flag next the structs where it's used
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable TMZ bit in FRAME_CONTROL for gfx10
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable TMZ bit in sdma copy pkt for sdma v5
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable TMZ bit in sdma copy pkt for sdma v4
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: expand amdgpu_copy_buffer interface with tmz
  parameter (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: expand sdma copy_buffer interface with tmz parameter
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix up for amdgpu_tmz.c and removal of drm/drmP.h
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: set TMZ bits in PTEs for secure BO (v4)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: job is secure iff CS is secure (v5) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: expand the context control interface with trust flag
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: expand the emit tmz interface with trusted flag
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add tmz bit in frame control packet (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add function to check tmz capability (v4)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add amdgpu_tmz data structure (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add tmz feature parameter (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: define the TMZ bit for the PTE (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add UAPI to create secure commands (v3)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add UAPI for creating encrypted buffers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.83.1 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.83 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Internal refactoring to abstract color caps
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add set backlight to hw sequencer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add dummy p-state latency bounding box override
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add panel cntl id for set backlight level
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Pass command instead of header into DMUB
  service (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Change viewport limit to 12 for DCN2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fail validation if building scaling
  params fails (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DML variable for future asics
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: clean up some header paths (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix DMUB meta offset for new load method
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Do not disable pipe split if mode is not
  supported (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.82 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn2.5: wait for tiles off after unpause
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/amd/powerplay: avoid using pm_en before it is
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Put ASIC revision into HSA capability
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove conversion to bool in dc_link_ddc.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove conversion to bool in dcn20_mpc.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove conversion to bool in amdgpu_device.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: decouple EccErrCnt query and clear operation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: switch to SMN interface to operate RSMU index mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: sw pstate switch should only be for vega20
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Remove unneeded semicolon (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- amdgpu/dc: remove redundant assignment to variable 'option'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gmc: Use consistent variable on unlocks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove redundant assignment to variable ret
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: protect ring overrun (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: extent threshold of waiting FLR_COMPLETE
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: for nv12 always need smu ip (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: skip sysfs node not belong to one vf mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable one vf mode for nv12 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: clear the messed up checking logic (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: provide RREG32_SOC15_NO_KIQ, will be used later
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: sriov is forbidden to call disable DPM
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: skip cg/pg set for SRIOV (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: ignore TA ucode for SRIOV (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: retire legacy vega10 sos version check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: switch to helper function to init sos ucode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add helper function to init sos ucode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: switch to helper function to init asd ucode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add helper function to init asd ucode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: retire unused check_fw_loading status
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove unnecessary tOS version check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: retire support_vmr_ring interface (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: shrink critical section in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Init data to avoid oops while reading pp_num_states
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove set but not used variable 'priority'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: amdgpu: fix kernel-doc struct warning (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: amd/display: fix Kconfig help text (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: request reg_val_offs each kiq read reg
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: change how we update mmRLC_SPM_MC_CNTL
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: set error query ready after all IPs late init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: code cleanup around gpu reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: optimize the gpu reset for XGMI setup V2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: correct cancel_delayed_work_sync on gpu reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: correct fbdev suspend on gpu reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: cleanup coding style in amdkfd a bit (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: clean up unused variable about ring lru
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: replace DRM prefix with PCI device info for
  gfx/mmhub (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: limit smu support to Arcturus for onevf
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: disble vblank when unloading sriov driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Print CU information by default during
  initialization (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update smu12_driver_if.h to align with pmfw
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/powerplay:avoid to show invalid DPM table info
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Adjust the SDMA doorbell info printing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Adjust three kfd dmesg printings during
  initialization (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix bug in the logic for panel power control
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Convert memory from cpu to fw endianness
  correctly (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Adjust refactored dm for color management only
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: access ABM from stream resource (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: change from panel to panel cntl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add HW rotation cursor changes to dcn10
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Factor in immediate flip support into DLG
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix virtual signal dsc setup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: destroy panel on link destruct (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: dmcu wait loop calculation is incorrect in RV
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: move panel power seq to new panel struct
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: make all backlight calls link based
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Cap certain DML values for Low Pix Clk
  on DCN2.1 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Various fixes for PSR on DMCUB (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: 3.2.81 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Update MPCC if requested (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix HDR visual confirm (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Use the correct input TF for video formats
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Change infopacket type programming
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Avoid NULL pointer in set_backlight when
  ABM is NULL (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix stream setting for diags on silicon
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Cast int to float before division
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Set meta_chunk_value to 0 in DML if DCC
  disabled in (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add optc get crc support for timings
  with ODM/DSC (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Workaround to disable YCbCr (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Check ramp != NULL before applying lut1d
  for degamma (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Unify psr feature flags (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Support plane-level gamut remap in DM
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add SetBacklight call to abm on dmcub
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove byte swapping for dmcub abm config table
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Force watermark value propagation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Move enable fractional pwm call (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add user backlight level reg write
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Correct updating logic of dcn21's pipe VM flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove aconnector condition check for dpcd read
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/dc: remove unused variable 'video_optimized_pixel_rates'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: remove defined but not used variables
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix race between pstate and remote buffer map
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/amdgpu: Disable gfx off if VCN is busy"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix kernel page fault issue by ras recovery on sGPU
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Disable FRU read on Arcturus (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/gmc: Fix spelling mistake (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: cache smu fw version info (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Revert "drm/amdgpu: use the BAR if possible in
  amdgpu_device_vram_access v2" (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: set mp1 state before reload (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: update psp fw loading sequence (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: update Arcturus smu-driver if header
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: properly set the dpm_enabled state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: correct i2c eeprom init/fini sequence
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: bump the NAVI10 smu-driver if version
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: revise the way to retrieve the board
  parameters (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix the hw hang during perform system reboot
  and reset (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove redundant assignment to variable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: remove defined but not used variables in ci_dpm.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: remove defined but not used 'dte_data_tahiti_le'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove dead code in si_dpm.c (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: remove hardcoded module name in prints
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: add print prefix for dev_* variants
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: add prefix for pr_* prints (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: code clean up in dce80_hw_sequencer.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/ring: simplify scheduler setup logic (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/kiq: add no_scheduler flag to KIQ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/ring: add no_scheduler flag (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/powerplay: get SMC FW size to a flexible way
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: replace DRM prefix with PCI device info for GFX RAS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: resume kiq access debugfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: refine ras related message print (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add uncorrectable error count print in UMC ecc irq
  cb (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Change "error" to "dc_log" at amdgpu_dm
  dpcd reading (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: restrict debugfs register access under SR-IOV
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: increased atom cmd timeout (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- amdgpu_kms: Remove unnecessary condition check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: support access regs outside of mmio bar
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: retire AMDGPU_REGS_KIQ flag (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: retire RREG32_IDX/WREG32_IDX (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: retire indirect mmio reg support from cgs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: replace indirect mmio access in non-dc code path
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove inproper workaround for vega10
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix gfx hang during suspend with video playback (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add HDCP caps debugfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: query hdcp capability during link detect
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Re-enable FRU check for most models v5
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.80 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Make DMCUB bss/data firmware blob optional
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: determine USB C DP2 mode only when USB DP Alt
  is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Update DRAM watermark before checking to
  update TTU (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Revert to old formula in set_vtg_params
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Refactor color management to take dm
  plane state (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: initialize get_max_link_cap (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix dml pipe merge logic (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: 3.2.79 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove unused defines (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix ABM config copy for dmcub (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: only blank dp stream which will be powered off
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix typo (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use config flag to disable dmcu obj creation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Check power_down functions exist before calling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Don't change mpcc tree for medium updates
  on DCN20 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: blank dp stream before power off receiver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Power down hw blocks on boot (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Remove hdcp display state with mst fix
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Implement abm config table copy to dmcub
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Program DSC before enabling link
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: prevent loop from occuring in pipe list
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.78 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sriov add amdgpu_amdkfd_pre_reset in gpu reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd Avoid destroy hqd when GPU is on reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: Correct gfx10's CG sequence (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add SPM golden settings for Navi12 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add SPM golden settings for Navi14 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add SPM golden settings for Navi10(v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Print UTCL2 client ID on a gpuvm fault
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: fix a typo (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn: add shared memory restore after wake up
  from sleep (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: rework sched_list generation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: sync ring type and drm hw_ip type (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/sriov add amdgpu_amdkfd_pre_reset in gpu reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix the broken logic in dc_link.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: avoid using pm_en before it is initialized
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- amdgpu/drm: remove psp access on navi10 for sriov
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Guard calls to hdcp_ta and dtm_ta
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove
  mod_hdcp_hdcp2_get_link_encryption_status() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/dc: Kill dc_conn_log_hex_linux() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu_dm/mst: Remove useless sideband tracing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn: fix spelling mistake "fimware" -> "firmware"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix and cleanup amdgpu_gem_object_close v4
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: code cleanup of dc_link file on func
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: code cleanup on dc_link from is_same_edid to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: codestyle cleanup on dc_link file until
  detect_dp (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: cleanup codestyle type BLOCK_COMMENT_STYLE on
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable VCN2.5 DPG mode for Arcturus (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/vcn2.5: Add firmware w/r ptr reset sync
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn2.0: Add firmware w/r ptr reset sync
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn: Add firmware share memory support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn2.5: stall DPG when WPTR/RPTR reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn2.0: stall DPG when WPTR/RPTR reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn: fix race condition issue for dpg unpause
  mode switch (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn: fix race condition issue for vcn start
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: skip access sdma_v5_0 registers under SRIOV (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: stop disable the scheduler during HW fini
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: added mutex protection on msg issuing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: unified interfaces for message issuing and
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: avoid calling Vega20 specific SMU message
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: avoid calling SMU10 specific SMU message
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: avoid calling SMU9 specific SMU message
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: avoid calling SMU8 specific SMU message
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerpaly: drop unused APIs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: avoid calling SMU7 specific SMU message
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: avoid calling CI specific SMU message
  implemention (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: reroute VMC and UMD to IH ring 1 for oss v5
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: call psp to program ih cntl in SR-IOV for Navi
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable IH ring 1 and ring 2 for navi (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: ih doorbell size of range changed for nbio v7.4
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: infinite retries fix from UTLC1 RB SDMA
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix non-pointer dereference for non-RAS supported
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: Include headers for PWR and SMUIO registers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: implement more ib pools (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Move backlight pwm enable function call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add ABM driver implementation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: 3.2.77 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: extend compute job timeout (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: No need support vcn decode (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: postpone entering fullaccess mode (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: adjust sequence of ip_discovery init and
  timeout_setting (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: equip new req_init_data handshake (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: use static mmio offset for NV mailbox
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: introduce new request and its function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: introduce new idh_request/event enum (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: cleanup idh event/req for NV headers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: Fix SMUIO/PWR Confusion (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: Move PWR_MISC_CNTL_STATUS to its own header
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: Add missing SMUIO v12 register to headers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/uvd7: remove unnecessary conversion to bool
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: align short build log (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: use pattern rule to avoid code duplication
  in Makefile (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: fix build rules of *_reg_safe.h (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/radeon: remove unneeded header include path (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Ignore the not supported error from psp
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add 4k resolution for virtual display
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Virtual display need to support multiple ctrcs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: disable ras query and iject during gpu reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: added xgmi ras error reset sequence (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: cleanup all virtualization detection routine
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: amends feature bits for MM bandwidth mgr
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: purge ip_discovery headers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Fix FRU data checking (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Expose TA FW version in fw_version file
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: disabled fru eeprom access (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: Add GFX9.1 PWR_MISC_CNTL_STATUS register
  to headers (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add documentation for unique_id (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Add documentation for PCIe accounting
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add documentation for memory info (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Enable reading FRU chip via I2C v3 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gma500: Remove dead code (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: remove unused variable 'hdmi_ids' (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Fix misspellings of "Analog Devices" (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Allocate initial CRTC state of the correct size
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: Clean up GPIO includes (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: vesafb: add missed release_region (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: arcfb: add missed free_irq and fix the order of
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- fbdev: s1d13xxxfb: add missed unregister_framebuffer in remove
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- ARM/fbdev: sa11x0: Switch to use GPIO descriptors
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: aty128fb: remove unused 'sdr_64' (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- omapfb/dss: remove unused variable 'venc_config_pal_bdghi'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: vt8500lcdfb: fix fallthrough warning (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: imxfb: ensure balanced regulator usage
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: controlfb: remove function prototypes part #3
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: controlfb: remove function prototypes part #2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: controlfb: remove function prototypes part #1
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: controlfb: remove obsolete module support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: controlfb: add COMPILE_TEST support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: controlfb: fix sparse warning about using
  incorrect (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: ssd1307fb: Remove redundant forward declaration
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: ssd1307fb: Convert to atomic PWM API (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: ssd1307fb: Make use of device properties (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: ssd1307fb: Introduce temporary variable to increase
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: ssd1307fb: Convert driver to use ->probe_new()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Don't free a struct never allocated by drm_gem_fb_init()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: fix spelling mistake "modifer" -> "modifier"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/device: Deprecate dev_private harder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: bridge: adv7511: Extend list of audio sample rates
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: adv7511: Enable SPDIF DAI (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: kirin: Revert change to add register connect helper
  functions (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- fbdev: mx3fb: const pointer to ipu_di_signal_cfg (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma-buf: Exercise dma-fence-chain under selftests
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: Report signaled links inside dma-fence-chain
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: Prettify typecasts for dma-fence-chain (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Print errors on ACT timeouts (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Increase ACT retry timeout to 3s (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Reformat drm_dp_check_act_status() a bit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Improve kdocs for drm_dp_check_act_status()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add NWL MIPI DSI host controller support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vram-helpers: Merge code into a single file (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vram-helpers: Set plane fence for display update
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Don't return 0 from a void drm_fbdev_generic_setup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: support for boe,tv105wum-nw0 dsi video mode panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- fbdev: mx3fb: avoid warning about psABI change (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/fb-helper: Remove return value from
  drm_fbdev_generic_setup() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vboxvideo: Set up fbdev after registering device; remove
  error checks (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Remove error check from fbdev setup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tilcdc: Set up fbdev after fully registering device
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Set up fbdev after registering device; remove
  error checks (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Remove error check from fbdev setup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ingenic: Remove error check from fbdev setup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/kirin: Set up fbdev after fully registering device
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/hibmc: Remove error check from fbdev setup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Set up fbdev after registering device; remove
  error checks (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: clean up ttm_trace_dma_map/ttm_trace_dma_unmap (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: nt39016: Add support for 50 Hz refresh rate
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: nt39016: Add support for multiple modes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: mb862xx: remove set but not used variable 'mdr'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: matroxfb: remove dead code and set but not
  used variable (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: add panel driver for Leadtek LTK050H3146W
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: Add missing annotation for cyber2000fb_enable_ddc() and
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ingenic: Delete an error message in ingenic_drm_probe()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Remove drm_dp_mst_has_audio() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dp_mst: Cast intel_connector->port as drm_dp_mst_port
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: don't print error message on platform_get_irq()
  failure (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vblank: Add intro to documentation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/writeback: wire drm_writeback.h to kernel-doc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: writeback: document callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Don't drop NAKs for down responses (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Fix NULL deref in drm_dp_get_one_sb_msg()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: tcon: Delete an error message in
  sun4i_tcon_init_irq() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: fix kernel-doc warning in panel.c (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/sched: fix kernel-doc in gpu_scheduler.h (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Remove drm_dp_mst_topology_cbs.destroy_connector
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu_dm/mst: Stop printing extra messages in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu_dm/mst: Remove ->destroy_connector() callback
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu_dm/mst: Remove unneeded edid assignment when
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel-leadtek-ltk500hd1829: Fix dotclock (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: delete drm_pci.h (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/pci: Move drm_pci_alloc/free under CONFIG_DRM_LEGACY
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: make virtio_gpu_object_attach void (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: delete notify in virtio_gpu_object_create
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: delete notify after virtio_gpu_cmd_context_create
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: random virtgpu_drv.h cleanups (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/hisilicon: Enforce 128-byte stride alignment to fix
  the hardware (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/zte: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vkms: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/virtgpu: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tilcdc: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/shmobile: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/rcar-du: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ingenic: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/imx: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i2c/tda998x: Use simple encoder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/hisilicon/kirin: Use simple encoder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gma500: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/fsl-dcu: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/atmel-hlcdc: Use simple encoder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Fix wrong kfree() in managed resource usage example
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/core: Calculate bpp in afbc helper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/core: Use proper debugging macro (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: improve amdgpu_gem_info debugfs file (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add support for exporting VRAM using DMA-buf v3
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add checks if DMA-buf P2P is supported
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: note that we can handle peer2peer DMA-buf
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: lock resv object during destruction (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma-buf: add peer2peer flag (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: make build_clear_payload_id_table return void
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/qxl: Use correct notify port address when creating
  cursor ring (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: add docs about the IN_FORMATS plane property
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/managed: Fix off-by-one in warning (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/fb: fix kernel-doc in drm_framebuffer.h (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: add kernel-doc for drm_dp_mst_port.fec_capable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: error out with EBUSY when device has existing master
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: rework SET_MASTER and DROP_MASTER perm handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: convert to use i2c_new_client_device()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/therm: convert to use i2c_new_client_device()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i2c/tda998x: convert to use i2c_new_client_device()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i2c/sil164: convert to use i2c_new_client_device()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: convert to use i2c_new_client_device()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: convert to use i2c_new_client_device()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: panel: Add Starry KR070PE2T (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: Add optional devfreq and cooling device support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Remove single tx msg restriction (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mst: Support simultaneous down replies (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mst: Separate sideband packet header parsing from message
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/fb-helper: Add TODO for making drm_fb_helper_alloc_fbi fill
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: sii9234: silence warning about regulators during
  deferred (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Add docs for managed resources (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: drop drm_driver.release hook (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mipi-dbi: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mipi-dbi: Move drm_mode_config_init into mipi library
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/repaper: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gm12u320: Simplify upload work (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gm12u320: Use helpers for shutdown/suspend/resume
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gm12u320: Use devm_drm_dev_init (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gm12u320: More drmm_ (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tidss: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mtk: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/shmob: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/stm: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rcar-du: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/pl111: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mcde: More devm_drm_dev_init (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mcde: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ingenic: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/cirrus: Fully embrace devm_ (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/cirrus: Drop explicit drm_mode_config_cleanup call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bochs: Drop explicit drm_mode_config_cleanup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bochs: Remove leftover drm_atomic_helper_shutdown
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Manage drm_mode_config_init with drmm_ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Garbage collect drm_dev_fini (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Manage drm_vblank_cleanup with drmm_ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Manage drm_gem_init with drmm_ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: manage drm_minor cleanup with drmm_ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Use drmm_ for drm_dev_init cleanup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Handle dev->unique with drmm_ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Cleanups after drmm_add_final_kfree rollout (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/<drivers>: Use drmm_add_final_kfree (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gm12u320: Use drmm_add_final_kfree (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ingenic: Use drmm_add_final_kfree (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/repaper: Use drmm_add_final_kfree (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vkms: Use drmm_add_final_kfree (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vgem: Use drmm_add_final_kfree (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mcde: Use drmm_add_final_kfree (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tidss: Use drmm_add_final_kfree (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/v3d: Use drmm_add_final_kfree (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/cirrus: Use drmm_add_final_kfree (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Use drmm_add_final_kfree (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/qxl: Use drmm_add_final_kfree (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Use drmm_add_final_kfree (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mipi_dbi: Use drmm_add_final_kfree in all drivers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Set final_kfree in drm_dev_alloc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: add managed resources tied to drm_device (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Don't clear drvdata in ->release (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- mm/slb: export __kmalloc_track(_node)_caller (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: dw-hdmi: rework csc related functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: dw-hdmi: Add support for RGB limited range
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: dw-hdmi: do not force "none" scan mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: Sort includes in VI and UI layer code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/sun4i: de2: Don't return de2_fmt_info struct (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/sun4i: de2: csc_mode in de2 format struct is mostly
  redundant (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: de2: rgb field in de2 format struct is redundant
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vram-helper: remove unneeded #if defined/endif guards
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: Add support for afbc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: add trace point for tasks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: add error sysfs to export error task dump
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: save task info dump when task fail (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: add max_error_tasks module parameter (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: save process info for debug usage (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mipi-dbi: Make mipi_dbi_command_stackbuf() data
  parameter const (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- omapfb: Remove unused writeback code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- fbdev: via: fix -Wextra build warning and format warning
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- fbdev: pmfb.c: fix -Wextra build warnings and errors
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- fbdev: savage: fix -Wextra build warning (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- fbdev: matrox: fix -Wextra build warnings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- fbdev: aty: fix -Wextra build warning (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- fbdev: fbmon: fix -Wextra build warnings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: uvesafb: Use scnprintf() for avoiding potential buffer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: omap2: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: omapfb: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Skip drm_mode_config_validate() for !modeset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: convert .debugfs_init() hook to return void (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Validate encoder->possible_crtcs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Validate encoder->possible_clones (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/imx: Remove the bogus possible_clones setup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gma500: Sanitize possible_clones (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Include the encoder itself in possible_clones
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/debugfs: remove checks for return value of drm_debugfs
  functions (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Fix DispID tile parsing for override EDID
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Clarify validate_displayid() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/edid: Don't include ext block csum in DispID size
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Don't parse garbage as DispID blocks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/edid: Move validate_displayid()
  drm_find_displayid_extension() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Return DispID length from
  drm_find_displayid_extension() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Remove idx==1 assumptions from all over the
  DispID parsing (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Swap some operands in for_each_displayid_db()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Constify topology id (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: make various debugfs_init() functions return 0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: have *_debugfs_init() functions return void
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: remove checks for return value of drm_debugfs
  functions (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/pl111: make pl111_debugfs_init return 0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vram-helper: make drm_vram_mm_debugfs_init() return 0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sti: remove use of drm_debugfs functions as return values
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: remove checks for return value of
  drm_debugfs_create_files() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: remove check for return value of (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/arm: make hdlcd_debugfs_init() return 0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/arc: make arcgpu_debugfs_init() return 0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: remove check of return value of drm_debugfs functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/v3d: make v3d_debugfs_init() return 0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tilcdc: remove check for return value of debugfs functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: remove checks for debugfs functions return value
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Correct a typo in a function comment (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: drm_vm: Use fallthrough; (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/hisilicon: Drop unused #include (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/core: Add drm_afbc_framebuffer and a corresponding helper
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/core: Allow drivers allocate a subclass of struct
  drm_framebuffer (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Update DRIVER_DATE to 20200417 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dp: Program vswing, pre-emphasis, test-pattern
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Register definition for DP compliance register
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Add debugfs entry for DP phy compliance
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Preparation for DP phy compliance auto test
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Made intel_dp_adjust_train() non-static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp: get/set phy compliance pattern (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Align macro name as per DP spec (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add YUV444 packed format support for skl+
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Exercise basic RPS interrupt generation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Initialize multicast register steering for
  workarounds (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Extend Wa_1409767108:tgl to B0 stepping
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/ehl: extended Wa_2006604312 to ehl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Start passing latency as parameter (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: do AUD_FREQ_CNTRL state save on all gen9+ platforms
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Check for an already completed timeslice
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: remove redundant assignment to variable err
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/evict: watch out for unevictable nodes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Take an explicit ref for rq->batch
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Mark up racy check of breadcrumb irq enabled
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Mark up racy read of intel_ring.head
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uc: prefer struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: prefer struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/stolen: prefer struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uncore: prefer struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dram: prefer struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pmu: prefer struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/error: prefer struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uc: prefer struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/switcheroo: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/state: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/bw: use struct drm_device based logging (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/debugfs: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/crt: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: use struct drm_device based logging (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tc: use struct drm_device based logging (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/panel: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/audio: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Drop vestigal timeslicing assert
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Promote 'remain' to unsigned long (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Wait until the context is finally retired before
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Allow asynchronous waits on the i915_active barriers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Make exclusive awaits on i915_active optional
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Take DBG_FORCE_RELOC into account prior to using
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Extend hotplug detect retry on TypeC connectors
  to 5 seconds (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add a retry counter for hotplug detect retries
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Free request pool from virtual engines
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Wait until we start timeslicing after
  a submit (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Revoke mmap before fence (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Move the port sync DP_TP_CTL stuff to the encoder hook
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pass atomic state to encoder hooks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Do pipe updates after enables for everyone
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix port sync code to work with >2 pipes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Eliminate port sync copy pasta (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Implement port sync for SKL+ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Store cpu_transcoder_mask in device info
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Avoid setting timer->expires to 0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Keep a per-engine request pool (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Make Wa_14010229206 permanent (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Check for has-reset before testing hostile
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Utilize rcu iteration of context engines
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Peek at the next submission for error
  interrupts (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uc: Cleanup kerneldoc warnings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Drop cached obj->bind_count (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Make fence revocation unequivocal (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Store the fence details on the fence
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Only wait for GPU activity before unbinding
  a GGTT fence (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Try allocating va from free space (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: fix spelling mistake "undeflow" -> "underflow"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Align engine dump active/pending (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Report all failed registers for ctx isolation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Include the execlists CCID of each port in
  the engine (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Pause CS flow before reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Tidy up an error message for
  live_error_interrupt (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Include a few tracek for timeslicing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Defer kicking the tasklet until all rescheduling is
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tc/icl: Update TC vswing tables (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dp/ehl: Update vswing table for HBR and RBR
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Double check breadcrumb before crying foul
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: don't read head/tail pointers outside critical
  section (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Explicitly reset both reg and context
  runtime (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Split eb_vma into its own allocation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: Schedule oa_config after modifying the contexts
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Wrap i915_active in a simple kreffed struct
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Allow for different modes of interruptible
  i915_active_wait (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Check timeout before flush and cond checks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Include priority info in trace_ports
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/huc: Fix HuC register used in debugfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/huc: Add more errors for I915_PARAM_HUC_STATUS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Add definitions for VRR registers and bits
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Workaround switching back to a completed
  context (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Include port sync state in the state dump
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use REG_FIELD_PREP() & co. for TRANS_DDI_FUNC_CTL2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move icl_get_trans_port_sync_config() into the
  DDI code (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Drop usless master_transcoder assignments
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move TRANS_DDI_FUNC_CTL2 programming where it belongs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/mst: Use .compute_config_late() to compute master
  transcoder (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Differentiate between aliasing-ppgtt and ggtt pinning
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Constify adjusted_mode a bit (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Get rid of silly void* from MST code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: use forced codec wake on all gen9+ platforms
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: add new open param to configure polling of
  OA buffer (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: move pollin setup to non hw specific code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: rework aging tail workaround (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Cast remain to unsigned long in eb_relocate_vma
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uc: do not free err log on uc_fini (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/uc: Move uC debugfs to its own folder under GT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/debugfs: move uC printers and update debugfs file names
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/huc: make "support huc" reflect HW capabilities
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: drop stage_pool debugfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: allow setting generic data pointer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Return early after MISSING_CASE for
  write_dp_sdp (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Remove useless but deadly local
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Drop final few uses of drm_i915_private.engine
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/wopcm: convert to drm device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/psr: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: clean up intel_PLL_is_valid() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tv: use struct drm_device based logging (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/connector: use MISSING_CASE instead of logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hdmi: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp_mst: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp_aux_backlight: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display_power: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/ddi: use struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Immediately execute the fenced work (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/execlists: Pull tasklet interrupt-bh local to direct
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Measure the energy consumed while in RC6
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Drop setting sibling priority hint
  on virtual (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/fbc: Make fences a nice-to-have for GEN9+
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Use private flags to indicate TE in cmd mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Add check for periodic command mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Add cmd mode flags in display mode private flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Add vblank calculation for command mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Configure transcoder operation for command mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Only delay the context barrier pm (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: mark huge_gem_object as not shrinkable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Delay release of engine-pm after last retirement
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Extend intel_wakeref to support delayed puts
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests/perf: watch out for stolen objects
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Rely on direct submission to the queue (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Avoid gem_context->mutex for simple vma lookup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Mark timeline->cacheline as destroyed after
  rcu grace (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/edp: Ignore short pulse when panel powered off
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Leave rps->cur_freq on unpark (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Use the correct err_unlock unwind path for a closed
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Report context-is-closed prior to pinning
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix crtc nv12 etc. plane bitmasks for DPMS off
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Add writing of DP SDPs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dp: Add compute routine for DP HDR Metadata Infoframe
  SDP (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Add compute routine for DP VSC SDP (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Add DP1.4 VSC SDP Payload related Data Structures
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Prefer '%%ps' for printing function symbol names
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/workarounds: convert to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/rps: use struct drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/ring_submission: use drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/renderstate: use struct drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/rc6: convert to struct drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/lrc: convert to struct drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/ggtt: convert to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Add new PCI IDs to TGL (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dp: Add dpcd link_rate quirk for Apple 15" MBP
  2017 (v3) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hdcp: convert to struct drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbdev: convert to drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: convert to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/color: Extract icl_read_luts() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Enable non-contiguous pipe fusing (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Always reschedule the new heartbeat (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix up documentation paths after file moving
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: introduce global sseu pinning (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/perf: remove redundant power configuration register
  override (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: remove generated code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Restore check for invalid vma for fencing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Allocate i915_fence_reg array (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove manual save/resume of fence register state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Pull restoration of GGTT fences underneath the GT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move GGTT fence registers under gt/ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- mm/hmm: remove the customizable pfn format from hmm_range_fault
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- mm/hmm: remove HMM_PFN_SPECIAL (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove dead code after hmm_range_fault()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- mm/hmm: make hmm_range_fault return 0 or -1 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- PM: sleep: core: Rename DPM_FLAG_NEVER_SKIP (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Refresh patches.suse/igc-Add-initial-EEE-support.patch.
- Refresh
  patches.suse/i2c-i801-exclude-device-from-suspend-direct-complete.patch.
- gpu/drm: remove the powerpc hack in drm_legacy_sg_alloc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gup: document and work around "COW can break either way" issue
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Replace user_access_begin by
  user_write_access_begin (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- uaccess: Add user_read_access_begin/end and (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm_read(): get rid of pointless access_ok() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- omapfb: get rid of pointless access_ok() calls (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- amifb: get rid of pointless access_ok() calls (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- docs: filesystems: fix renamed references (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- docs: fix broken references to text files (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Update rmk's email address in various drivers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Make drm_dp_mst_dsc_aux_for_port() safe for old compilers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- commit 01b18a4
* Mon Nov 16 2020 bp@suse.de
- blacklist.conf: 4d6ffa27b8e5 x86/lib: Change .weak to SYM_FUNC_START_WEAK for arch/x86/lib/mem*_64.S
- commit 95f1309
* Mon Nov 16 2020 bp@suse.de
- blacklist.conf: e81e07244325 objtool: Support Clang non-section symbols in ORC generation
- commit b650d28
* Mon Nov 16 2020 oneukum@suse.com
- crypto: add suse_kabi_padding (jsc#SLE-14454).
  This patch adds reserve fields to structures of the
  generic crypto layer to make backporting fixes and ECOs easier.
- QAT: add suse_kabi_padding (jsc#SLE-14454).
  This patch adds reserve fields to structures of the
  QAT driver to make backporting fixes and ECOs for QAT easier.
- commit 16c9bda
* Mon Nov 16 2020 dwagner@suse.de
- nvme: do not update disk info for multipathed device
  (bsc#1171558).
- commit 72db678
* Mon Nov 16 2020 yousaf.kaukab@suse.com
- net: macb: use resolved link config in mac_link_up()
  (jsc#SLE-12251).
- commit 3a4483e
* Mon Nov 16 2020 ailiop@suse.com
- xfs: fix a missing unlock on error in xfs_fs_map_blocks
  (git-fixes).
- commit cc2433b
* Mon Nov 16 2020 ailiop@suse.com
- xfs: fix brainos in the refcount scrubber's rmap fragment
  processor (git-fixes).
- commit 3faadca
* Mon Nov 16 2020 ailiop@suse.com
- xfs: fix rmap key and record comparison functions (git-fixes).
- commit 7b24498
* Mon Nov 16 2020 ailiop@suse.com
- xfs: set the unwritten bit in rmap lookup flags in
  xchk_bmap_get_rmapextents (git-fixes).
- commit ac90c4a
* Mon Nov 16 2020 ailiop@suse.com
- xfs: fix flags argument to rmap lookup when converting shared
  file rmaps (git-fixes).
- commit ed43f56
* Mon Nov 16 2020 tbogendoerfer@suse.de
- drivers/net/ethernet: remove incorrectly formatted doc
  (bsc#1177397).
- net: ena: Fix all static chekers' warnings (bsc#1177397).
- net: ena: Change RSS related macros and variables names
  (bsc#1177397).
- net: ena: Remove redundant print of placement policy
  (bsc#1177397).
- net: ena: Capitalize all log strings and improve code
  readability (bsc#1177397).
- net: ena: Change log message to netif/dev function
  (bsc#1177397).
- net: ena: Change license into format to SPDX in all files
  (bsc#1177397).
- net: ena: xdp: add queue counters for xdp actions (bsc#1177397).
- net: ena: ethtool: add stats printing to XDP queues
  (bsc#1177397).
- net: ena: ethtool: Add new device statistics (bsc#1177397).
- net: ena: ethtool: convert stat_offset to 64 bit resolution
  (bsc#1177397).
- commit 3fe7896
* Mon Nov 16 2020 tiwai@suse.de
- r8169: disable hw csum for short packets on all chip versions
  (git-fixes).
- commit 30d1ce9
* Mon Nov 16 2020 tiwai@suse.de
- virtio: virtio_console: fix DMA memory allocation for rproc
  serial (git-fixes).
- xhci: hisilicon: fix refercence leak in xhci_histb_probe
  (git-fixes).
- thunderbolt: Fix memory leak if ida_simple_get() fails in
  enumerate_services() (git-fixes).
- thunderbolt: Add the missed ida_simple_remove() in
  ring_request_msix() (git-fixes).
- kernel/watchdog: fix watchdog_allowed_mask not used warning
  (git-fixes).
- reboot: fix overflow parsing reboot cpu number (git-fixes).
- Revert "kernel/reboot.c: convert simple_strtoul to kstrtoint"
  (git-fixes).
- clk: define to_clk_regmap() as inline function (git-fixes).
- xhci: Fix sizeof() mismatch (git-fixes).
- commit a563406
* Mon Nov 16 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/ACPI-GED-fix-Wformat.patch
  patches.suse/cosa-Add-missing-kfree-in-error-path-of-cosa_write.patch
  patches.suse/gpio-pcie-idio-24-Enable-PEX8311-interrupts.patch
  patches.suse/gpio-pcie-idio-24-Fix-IRQ-Enable-Register-value.patch
  patches.suse/gpio-pcie-idio-24-Fix-irq-mask-when-masking.patch
  patches.suse/lan743x-fix-BUG-invalid-wait-context-when-setting-rx.patch
  patches.suse/mmc-renesas_sdhi_core-Add-missing-tmio_mmc_host_free.patch
  patches.suse/mmc-sdhci-of-esdhc-Handle-pulse-width-detection-erra.patch
  patches.suse/pinctrl-aspeed-Fix-GPI-only-function-problem.patch
  patches.suse/pinctrl-intel-Set-default-bias-in-case-no-particular.patch
- commit e7295f4
* Mon Nov 16 2020 mkubecek@suse.cz
- update patch metadata
  patches.suse/SUNRPC-Revert-241b1f419f0e-SUNRPC-Remove-xdr_buf_tri.patch was
  replaced by a no-op stub only preserving kABI but the upstream reference
  was left in place. Our kbuild checks complain because the same commit id is
  also blacklisted. Drop the mainline reference which is no longer
  appropriate and refer to the commit id in commit message instead.
- commit c39115f
* Mon Nov 16 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/NFSv4-Handle-NFS4ERR_OLD_STATEID-in-CLOSE-OPEN_DOWNG.patch
  patches.suse/NFSv4-Wait-for-stateid-updates-after-CLOSE-OPEN_DOWN.patch
  patches.suse/NFSv4.x-recover-from-pre-mature-loss-of-openstateid.patch
  patches.suse/svcrdma-fix-bounce-buffers-for-unaligned-offsets-and.patch
- commit 6b62933
* Mon Nov 16 2020 mkubecek@suse.cz
- series.conf: whitespace cleanup
- commit 3581101
* Mon Nov 16 2020 neilb@suse.de
- NFS: only invalidate dentrys that are clearly invalid
  (bsc#1178669 bsc#1170139).
- commit f10a996
* Mon Nov 16 2020 glin@suse.com
- samples: bpf: Cleanup bpf_load.o from Makefile (bsc#1177028).
- commit a1f6952
* Sun Nov 15 2020 lduncan@suse.com
- loop: Fix occasional uevent drop (bsc#1177971).
- block: add a return value to set_capacity_revalidate_and_notify
  (bsc#1177971).
- block: use revalidate_disk_size in
  set_capacity_revalidate_and_notify (bsc#1177971).
- block: add a new revalidate_disk_size helper (bsc#1177971).
- commit 076c587
* Sat Nov 14 2020 colyli@suse.de
- dax: Fix stack overflow when mounting fsdax pmem device
  (bsc#1171073).
- dax: fix detection of dax support for non-persistent memory
  block devices (bsc#1171073).
- commit 91904e0
* Sat Nov 14 2020 colyli@suse.de
- libceph: use sendpage_ok() in ceph_tcp_sendpage() (bsc#1172873).
- scsi: libiscsi: use sendpage_ok() in iscsi_tcp_segment_map()
  (bsc#1172873).
- drbd: code cleanup by using sendpage_ok() to check page for
  kernel_sendpage() (bsc#1172873).
- tcp: use sendpage_ok() to detect misused .sendpage
  (bsc#1172873).
- nvme-tcp: check page by sendpage_ok() before calling
  kernel_sendpage() (bsc#1172873).
- net: add WARN_ONCE in kernel_sendpage() for improper zero-copy
  send (bsc#1172873).
- net: introduce helper sendpage_ok() in include/linux/net.h
  (bsc#1172873).
  kABI workaround for including mm.h in include/linux/net.h
  (bsc#1172873).
- commit 5b20669
* Sat Nov 14 2020 tiwai@suse.de
- pinctrl: intel: Set default bias in case no particular value
  given (git-fixes).
- pinctrl: aspeed: Fix GPI only function problem (git-fixes).
- gpio: pcie-idio-24: Enable PEX8311 interrupts (git-fixes).
- gpio: pcie-idio-24: Fix IRQ Enable Register value (git-fixes).
- gpio: pcie-idio-24: Fix irq mask when masking (git-fixes).
- mmc: sdhci-of-esdhc: Handle pulse width detection erratum for
  more SoCs (git-fixes).
- mmc: renesas_sdhi_core: Add missing tmio_mmc_host_free()
  at remove (git-fixes).
- cosa: Add missing kfree in error path of cosa_write (git-fixes).
- lan743x: fix "BUG: invalid wait context" when setting rx mode
  (git-fixes).
- ACPI: GED: fix -Wformat (git-fixes).
- commit 4dd9cfa
* Sat Nov 14 2020 tiwai@suse.de
- vt: Disable KD_FONT_OP_COPY (bsc#1178589).
- commit a819dc3
* Fri Nov 13 2020 mbrugger@suse.com
- mm/memory-failure: Add memory_failure_queue_kick()
  (jsc#SLE-16610).
- commit 58bbb5e
* Fri Nov 13 2020 mbrugger@suse.com
- mtd: spi-nor: Fix address width on flash chips > 16MB
  (jsc#SLE-14214 jsc#SLE-1660).
- commit 25da357
* Fri Nov 13 2020 mbrugger@suse.com
- mtd: spi-nor: Don't copy self-pointing struct around
  (jsc#SLE-14214 jsc#SLE-1660).
- commit 72ce51f
* Fri Nov 13 2020 mbrugger@suse.com
- spi: spi-cadence-quadspi: Populate get_name() interface
  (jsc#SLE-14214 jsc#SLE-1660).
- commit bcb9418
* Fri Nov 13 2020 yousaf.kaukab@suse.com
- net: ethernet: ti: cpsw_new: fix suspend/resume (jsc#SLE-12251).
- net: macb: fix for pause frame receive enable bit (jsc#SLE-12251).
- net: ethernet: ti: cpsw_new: fix error handling in cpsw_ndo_vlan_rx_kill_vid() (jsc#SLE-12251).
- net: ethernet: ti: cpsw_new: fix clean up of vlan mc entries for host port (jsc#SLE-12251).
- net: macb: Properly handle phylink on at91sam9x (jsc#SLE-12251).
- net: macb: fix macb_suspend() by removing call to netif_carrier_off() (jsc#SLE-12251).
- net: macb: fix macb_get/set_wol() when moving to phylink (jsc#SLE-12251).
- net: macb: free resources on failure path of at91ether_open() (jsc#SLE-12251).
  Refresh:
  patches.suse/net-macb-call-pm_runtime_put_sync-on-failure-path.patch
- net: phylink: ensure manual pause mode configuration takes effect (jsc#SLE-12251).
- net: macb: undo operations in case of failure (jsc#SLE-12251).
- net: macb: Only disable NAPI on the actual error path (jsc#SLE-12251).
- net: cadence: macb: disable NAPI on error (jsc#SLE-12251).
- net: ethernet: ti: fix some return value check of cpsw_ale_create() (jsc#SLE-12251).
- net: macb: Fix handling of fixed-link node (jsc#SLE-12251).
- net: stmmac: update pci platform data to use phy_interface (jsc#SLE-12251).
- of: mdio: Add missing inline to of_mdiobus_child_is_phy() dummy (jsc#SLE-12251).
- net: ag71xx: fix compile warnings (jsc#SLE-12251).
- net: ethernet: ti: build cpsw-common for switchdev (jsc#SLE-12251).
- net: ethernet: ti: select PAGE_POOL for switchdev driver (jsc#SLE-12251).
- net: ethernet: emac: Fix phy mode type (jsc#SLE-12251).
- commit 67c4a94
* Fri Nov 13 2020 glin@suse.com
- samples/bpf: xdp_redirect_cpu: Load a eBPF program on cpumap
  (bsc#1177028).
- samples/bpf: xdp_redirect_cpu_user: Do not update bpf maps in
  option loop (bsc#1177028).
- samples: bpf: Add an option for printing extra statistics in
  xdpsock (bsc#1177028).
- bpf: Fix fds_example SIGSEGV error (bsc#1177028).
- samples: bpf: Refactor BPF map performance test with libbpf
  (bsc#1177028).
- samples: bpf: Refactor BPF map in map test with libbpf
  (bsc#1177028).
- samples: bpf: Fix bpf programs with kprobe/sys_connect event
  (bsc#1177028).
- commit 9874b44
* Fri Nov 13 2020 glin@suse.com
- blacklist.conf: 6f64e4778300 ("bpf: Update verification logic for LSM programs")
  Apply the commit later.
- commit 548a6df
* Fri Nov 13 2020 glin@suse.com
- tools/bpftool: Fix attaching flow dissector (bsc#1177028).
- commit 44b2c56
* Fri Nov 13 2020 shung-hsi.yu@suse.com
- i40e, xsk: uninitialized variable in i40e_clean_rx_irq_zc()
  (jsc#SLE-13701).
- commit b2ee981
* Fri Nov 13 2020 glin@suse.com
- bpf: Enforce id generation for all may-be-null register type
  (bsc#1177028).
- selftests/bpf: Fix endianness issues in
  sk_lookup/ctx_narrow_access (bsc#1177028).
- commit 4610751
* Fri Nov 13 2020 glin@suse.com
- blacklist.conf: add the unneeded bpf git-fixes commits
- d3c481515129 net: remove sockptr_advance
  It requires several treewide changes which were not backported.
- 47f7cf6325f7 libbpf: Skip CO-RE relocations for not loaded BPF programs
  The target code was not backported yet.
- commit cf96a2f
* Thu Nov 12 2020 msuchanek@suse.de
- prom_init: enable verbose prints (bsc#1178142 bsc#1180759).
- prom_init: enable verbose prints (bsc#1178142) (bsc#1178142).
- commit c0bbedb
* Thu Nov 12 2020 msuchanek@suse.de
- powerpc/vnic: Extend "failover pending" window (bsc#1176855
  ltc#187293).
- commit 8c35da0
* Thu Nov 12 2020 mbrugger@suse.com
- spi: hisi-sfc-v3xx: fix spelling mistake "occured" -> "occurred"
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 8b3eca5
* Thu Nov 12 2020 mbrugger@suse.com
- spi: hisi-sfc-v3xx: add support for IRQ mode (jsc#SLE-14214
  jsc#SLE-16606).
- commit 4a666b4
* Thu Nov 12 2020 mbrugger@suse.com
- spi: hisi-sfc-v3xx: factor out the bit definition of interrupt
  register (jsc#SLE-14214 jsc#SLE-16606).
- commit dabd6b3
* Thu Nov 12 2020 mbrugger@suse.com
- spi: hisi-sfc-v3xx: factor out bus config and transfer functions
  (jsc#SLE-14214 jsc#SLE-16606).
- commit b1adebf
* Thu Nov 12 2020 mbrugger@suse.com
- spi: hisi-sfc-v3xx: factor out IO modes configuration
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 56e8610
* Thu Nov 12 2020 mbrugger@suse.com
- spi: hisi-sfc-v3xx: add error check after per operation
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 382883e
* Thu Nov 12 2020 ailiop@suse.com
- Update config files.
  Set CONFIG_HIBERNATION_SNAPSHOT_DEV=y.
  Upstream commit c4f39a6c7438 ("PM: hibernate: Split off snapshot dev
  option") has made userspace hibernation conditional on a separate config
  option that can be disabled.
  The SLE15-SP3 backport (commit 17f3cdc2427e) has left this option unset,
  but this breaks the userspace hibernation functionality that we have
  been supporting in all previous SPs. Re-enable and fix this.
  This also fixes bsc#1178609 which uncovered this issue via fstests
  (generic/570) failure.
- commit 660a013
* Thu Nov 12 2020 yousaf.kaukab@suse.com
- dpaa2-eth: fix command version for Tx shaping (jsc#SLE-12251).
- net/fsl: quieten expected MDIO access failures (jsc#SLE-12251).
- dpaa2-eth: fix a build warning in dpmac.c (jsc#SLE-12251).
- enetc: Fix mdio bus removal on PF probe bailout (jsc#SLE-12251).
- net: gianfar: Add of_node_put() before goto statement (jsc#SLE-12251).
- enetc: use napi_schedule to be compatible with PREEMPT_RT (jsc#SLE-12251).
- dpaa2-eth: use napi_schedule to be compatible with PREEMPT_RT (jsc#SLE-12251).
- fsl/fman: fix eth hash table allocation (jsc#SLE-12251).
- fsl/fman: check dereferencing null pointer (jsc#SLE-12251).
- fsl/fman: fix unreachable code (jsc#SLE-12251).
- fsl/fman: fix dereference null return value (jsc#SLE-12251).
- fsl/fman: use 32-bit unsigned integer (jsc#SLE-12251).
- net/enetc: Fix wrong return value in enetc_psfp_parse_clsflower() (jsc#SLE-12251).
- enetc: Remove the imdio bus on PF probe bailout (jsc#SLE-12251).
- dpaa2-eth: add support for TBF offload (jsc#SLE-12251).
- dpaa2-eth: add API for Tx shaping (jsc#SLE-12251).
- dpaa2-eth: move the mqprio setup into a separate function (jsc#SLE-12251).
- enetc: Add adaptive interrupt coalescing (jsc#SLE-12251).
- enetc: Add interrupt coalescing support (jsc#SLE-12251).
- enetc: Drop redundant ____cacheline_aligned_in_smp (jsc#SLE-12251).
- enetc: Fix interrupt coalescing register naming (jsc#SLE-12251).
- enetc: Factor out the traffic start/stop procedures (jsc#SLE-12251).
- enetc: Refine buffer descriptor ring sizes (jsc#SLE-12251).
- net: enetc: Use DT protocol information to set up the ports (jsc#SLE-12251).
- net: enetc: Initialize SerDes for SGMII and USXGMII protocols (jsc#SLE-12251).
- net: phy: add USXGMII link partner ability constants (jsc#SLE-12251).
- net: enetc: use eth_broadcast_addr() to assign broadcast (jsc#SLE-12251).
- dpaa2-eth: fix draining of S/G cache (jsc#SLE-12251).
- dpaa2-eth: add software counter for Tx frames converted to S/G (jsc#SLE-12251).
- dpaa2-eth: send a scatter-gather FD instead of realloc-ing (jsc#SLE-12251).
- dpaa2-eth: fix misspelled function parameters in dpni__taildrop (jsc#SLE-12251).
- dpaa2-eth: fix recursive header include (jsc#SLE-12251).
- dpaa2-eth: fix condition for number of buffer acquire retries (jsc#SLE-12251).
- dpaa2-eth: check the result of skb_to_sgvec() (jsc#SLE-12251).
- dpaa2-eth: trim debugfs FQ stats (jsc#SLE-12251).
- net: enetc add tc flower offload flow metering policing action (jsc#SLE-12251).
  Refresh:
  patches.suse/net-qos-offload-add-flow-status-with-dropped-count.patch
- net: enetc: add support max frame size for tc flower offload (jsc#SLE-12251).
- net/fsl: enable extended scanning in xgmac_mdio (jsc#SLE-12251).
- net/fsl: acpize xgmac_mdio (jsc#SLE-12251).
- net: phy: Allow mdio buses to auto-probe c45 devices (jsc#SLE-12251).
- enetc: Use struct_size() helper in kzalloc() (jsc#SLE-12251).
- dpaa2-eth: check fsl_mc_get_endpoint for IS_ERR_OR_NULL() (jsc#SLE-12251).
- gianfar: Use random MAC address when none is given (jsc#SLE-12251).
- enetc: Fix HW_VLAN_CTAG_TX|RX toggling (jsc#SLE-12251).
- drivers: dpaa2: Use devm_kcalloc() in setup_dpni() (jsc#SLE-12251).
- dpaa2-eth: Keep congestion group taildrop enabled when PFC on (jsc#SLE-12251).
- dpaa2-eth: Add PFC support through DCB ops (jsc#SLE-12251).
- dpaa2-eth: Update FQ taildrop threshold and buffer pool count (jsc#SLE-12251).
- dpaa2-eth: Add congestion group taildrop (jsc#SLE-12251).
- dpaa2-eth: Add helper functions (jsc#SLE-12251).
- dpaa2-eth: Distribute ingress frames based on VLAN prio (jsc#SLE-12251).
- dpaa2-eth: Add support for Rx traffic classes (jsc#SLE-12251).
- dpaa2-eth: add bulking to XDP_TX (jsc#SLE-12251).
- vhost_net: Also populate XDP frame size (jsc#SLE-12251).
- net: thunderx: Add XDP frame size (jsc#SLE-12251).
- net: ethernet: ti: Add XDP frame size to driver cpsw (jsc#SLE-12251).
- dpaa2-eth: Add XDP frame size (jsc#SLE-12251).
- net: XDP-generic determining XDP frame size (jsc#SLE-12251).
- net: netsec: Add support for XDP frame size (jsc#SLE-12251).
- dpaa2-eth: create a function to flush the XDP fds (jsc#SLE-12251).
- net:enetc: bug fix for qos sfi operate space after freed (jsc#SLE-12251).
- net: enetc: Make some symbols static (jsc#SLE-12251).
- Merge branch 'net-smc-extent-buffer-mapping-and-port-handling' (jsc#SLE-12251).
- net: enetc: add tc flower psfp offload driver (jsc#SLE-12251).
- net: enetc: add hw tc hw offload features for PSPF capability (jsc#SLE-12251).
- dpaa2-eth: fix error return code in setup_dpni() (jsc#SLE-12251).
- dpaa_eth: Fix comparing pointer to 0 (jsc#SLE-12251).
- dpaa2-eth: Use proper division helper in dpaa2_dbg_ch_show (jsc#SLE-12251).
- dpaa2-eth: add channel stat to debugfs (jsc#SLE-12251).
- dpaa2-eth: fix return codes used in ndo_setup_tc (jsc#SLE-12251).
- dpaa2-eth: use bulk enqueue in .ndo_xdp_xmit (jsc#SLE-12251).
- dpaa2-eth: split the .ndo_xdp_xmit callback into two stages (jsc#SLE-12251).
- dpaa2-eth: use the bulk ring mode enqueue interface (jsc#SLE-12251).
- dpaa2-eth: return num_enqueued frames from enqueue callback (jsc#SLE-12251).
- enetc: permit configuration of rx-vlan-filter with ethtool (jsc#SLE-12251).
- net: freescale: select CONFIG_FIXED_PHY where needed (jsc#SLE-12251).
- enetc: Remove unused variable 'enetc_drv_name' (jsc#SLE-12251).
- net: gianfar: reject unsupported coalescing params (jsc#SLE-12251).
- net: dpaa: reject unsupported coalescing params (jsc#SLE-12251).
- enetc: Add dynamic allocation of extended Rx BD rings (jsc#SLE-12251).
- enetc: Clean up Rx BD iteration (jsc#SLE-12251).
- enetc: Clean up of ehtool stats len (jsc#SLE-12251).
- enetc: Drop redundant device node check (jsc#SLE-12251).
- dpaa_eth: Use random MAC address when none is given (jsc#SLE-12251).
- fsl/fman: tolerate missing MAC address in device tree (jsc#SLE-12251).
- fsl/fman: reuse set_mac_address() in dtsec init() (jsc#SLE-12251).
- gianfar: remove unnecessary zeroing coalesce settings (jsc#SLE-12251).
- net/freescale: Don't set zero if FW iand bus not-available in gianfar (jsc#SLE-12251).
- net/freescale: Don't set zero if FW not-available in ucc_geth (jsc#SLE-12251).
- net/freescale: Clean drivers from static versions (jsc#SLE-12251).
- net: dpaa2-mac: use resolved link config in mac_link_up() (jsc#SLE-12251).
- net: dsa: propagate resolved link config via mac_link_up() (jsc#SLE-12251).
- net: phylink: propagate resolved link config via mac_link_up() (jsc#SLE-12251).
- dpaa2-eth: add support for nway reset (jsc#SLE-12251).
- dpaa2-eth: add support for mii ioctls (jsc#SLE-12251).
- enetc: remove "depends on (ARCH_LAYERSCAPE || COMPILE_TEST)" (jsc#SLE-12251).
- ptp_qoriq: drop the code of alarm (jsc#SLE-12251).
- dpaa_eth: Remove unnecessary boolean expression in dpaa_get_headroom (jsc#SLE-12251).
- net: macb: Properly handle phylink on at91rm9200 (jsc#SLE-12251).
- net: socionext: get rid of huge dma sync in netsec_alloc_rx_data (jsc#SLE-12251).
- net: macb: add support for C45 MDIO read/write (jsc#SLE-12251).
- enetc: Fix an off by one in enetc_setup_tc_txtime() (jsc#SLE-12251).
- net: netsec: Change page pool nid to NUMA_NO_NODE (jsc#SLE-12251).
- enetc: add support time specific departure base on the qos etf (jsc#SLE-12251).
- fsl/fman: use resource_size (jsc#SLE-12251).
- net: dsa: Make PHYLINK related function static again (jsc#SLE-12251).
- dpaa2-ptp: add external trigger event support (jsc#SLE-12251).
- ptp_qoriq: export extts_clean_up() function (jsc#SLE-12251).
- ptp_qoriq: check valid status before reading extts fifo (jsc#SLE-12251).
- net: fsl/fman: rename IF_MODE_XGMII to IF_MODE_10G (jsc#SLE-12251).
- net/fsl: treat fsl,erratum-a011043 (jsc#SLE-12251).
- net: macb: fix for fixed-link mode (jsc#SLE-12251).
- net: macb: fix probing of PHY not described in the dt (jsc#SLE-12251).
- of: mdio: export of_mdiobus_child_is_phy (jsc#SLE-12251).
- net: ethernet: ti: cpsw_switchdev: fix unmet direct dependencies detected for NET_SWITCHDEV (jsc#SLE-12251).
- net: ethernet: ti: ale: ensure vlan/mdb deleted when no members (jsc#SLE-12251).
- phy: ti: phy-gmii-sel: dependency from ti cpsw-switchdev driver (jsc#SLE-12251).
- net: ethernet: ti: introduce cpsw switchdev based driver part 2 - switch (jsc#SLE-12251).
- net: ethernet: ti: introduce cpsw switchdev based driver part 1 - dual-emac (jsc#SLE-12251).
- net: ethernet: ti: cpsw: move set of common functions in cpsw_priv (jsc#SLE-12251).
  Refresh:
  patches.suse/net-ethernet-ti-cpsw-fix-extra-rx-interrupt.patch
  patches.suse/netdev-pass-the-stuck-queue-to-the-timeout-handler.patch
  patches.suse/xdp-Rename-convert_to_xdp_frame-in-xdp_convert_buff_.patch
- net: ethernet: ti: cpsw: resolve build deps of cpsw drivers (jsc#SLE-12251).
- net: ethernet: ti: ale: modify vlan/mdb api for switchdev (jsc#SLE-12251).
- net: ethernet: ti: cpsw: allow untagged traffic on host port (jsc#SLE-12251).
- net: macb: convert to phylink (jsc#SLE-12251).
- net: macb: move the Tx and Rx buffer initialization into a function (jsc#SLE-12251).
- ethernet: ti: cpts: use ktime_get_real_ns helper (jsc#SLE-12251).
- dpaa2-eth: add ethtool MAC counters (jsc#SLE-12251).
- dpaa2-ptp: fix compile error (jsc#SLE-12251).
- dpaa2-eth: fix an always true condition in dpaa2_mac_get_if_mode (jsc#SLE-12251).
- net: of_get_phy_mode: Change API to solve int/unit warnings (jsc#SLE-12251).
  Refresh:
  patches.suse/net-dsa-sja1105-Don-t-error-out-on-disabled-ports-wi.patch
  patches.suse/net-mscc-ocelot-make-phy_mode-a-member-of-the-common.patch
  patches.suse/net-mscc-ocelot-separate-net_device-related-items-ou.patch
  patches.suse/net-stmmac-platform-fix-probe-for-ACPI-devices.patch
- dpaa2-eth: add MAC/PHY support through phylink (jsc#SLE-12251).
- dpaa2-eth: update the TX frame queues on DPNI_IRQ_EVENT_ENDPOINT_CHANGED (jsc#SLE-12251).
- dpaa2-eth: Avoid unbounded while loops (jsc#SLE-12251).
- dpaa2-eth: Fix minor bug in ethtool stats reporting (jsc#SLE-12251).
- dpaa2-eth: Cleanup dead code (jsc#SLE-12251).
- net: dpaa2: Use the correct style for SPDX License Identifier (jsc#SLE-12251).
- macb: propagate errors when getting optional clocks (jsc#SLE-12251).
- dpaa2-eth: add irq for the dpmac connect/disconnect event (jsc#SLE-12251).
- davinci_cpdma: make cpdma_chan_split_pool static (jsc#SLE-12251).
- net: macb: Remove dead code (jsc#SLE-12251).
- gianfar: Make reset_gfar static (jsc#SLE-12251).
- net: stmmac: socfpga: re-use the `interface` parameter from platform data (jsc#SLE-12251).
- net: stmmac: implement support for passive mode converters via dt (jsc#SLE-12251).
  Refresh:
  patches.suse/net-stmmac-platform-fix-probe-for-ACPI-devices.patch
- gianfar: use DT more consistently when selecting PHY connection type (jsc#SLE-12251).
- gianfar: cleanup gianfar.h (jsc#SLE-12251).
- gianfar: make five functions static (jsc#SLE-12251).
- dpaa2-eth: Poll Tx pending frames counter on if down (jsc#SLE-12251).
- dpaa2-eth: Add new DPNI statistics counters (jsc#SLE-12251).
- dpaa2-eth: Minor refactoring in ethtool stats (jsc#SLE-12251).
- dpaa2-eth: Add pause frame support (jsc#SLE-12251).
  Refresh:
  patches.suse/dpaa2-eth-Fix-TX-FQID-values.patch
- dpaa2-eth: Use stored link settings (jsc#SLE-12251).
  Refresh:
  patches.suse/dpaa2-eth-Fix-TX-FQID-values.patch
- dpaa2-eth: Remove support for changing link settings (jsc#SLE-12251).
- dpaa2: no need to check return value of debugfs_create functions (jsc#SLE-12251).
- commit fe806c5
* Thu Nov 12 2020 mbrugger@suse.com
- spi: HiSilicon v3xx: Use DMI quirk to set controller buswidth
  override bits (jsc#SLE-14214 jsc#SLE-16606).
  Update config files.
- commit b5743d8
* Thu Nov 12 2020 mbrugger@suse.com
- spi: HiSilicon v3xx: Properly set CMD_CONFIG for Dual/Quad modes
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 646d618
* Thu Nov 12 2020 mbrugger@suse.com
- spi: Allow SPI controller override device buswidth
  (jsc#SLE-14214 jsc#SLE-16606).
- commit df26c6c
* Thu Nov 12 2020 mbrugger@suse.com
- spi: Add HiSilicon v3xx SPI NOR flash controller driver
  (jsc#SLE-14214 jsc#SLE-16606).
- supported.conf: add spi-hisi-sfc-v3xx
- commit 01912fa
* Thu Nov 12 2020 mbrugger@suse.com
- Revert "mtd: spi-nor: Add capability to disable flash quad mode"
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 08912f6
* Thu Nov 12 2020 mbrugger@suse.com
- Revert "mtd: spi-nor: Disable the flash quad mode in
  spi_nor_restore()" (jsc#SLE-14214 jsc#SLE-16606).
- commit fcdc78b
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: revert "spi-nor: intel: provide a range for poll_timout"
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 3fba279
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: update read capabilities for w25q64 and s25fl064k
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 095c8c3
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: micron: Add SPI_NOR_DUAL_READ flag on mt25qu02g
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 6d23666
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: macronix: Add support for mx66u2g45g
  (jsc#SLE-14214 jsc#SLE-16606).
- commit c06f001
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: intel-spi: Simulate WRDI command (jsc#SLE-14214
  jsc#SLE-16606).
- commit c667137
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Disable the flash quad mode in spi_nor_restore()
  (jsc#SLE-14214 jsc#SLE-16606).
- commit b334fbb
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add capability to disable flash quad mode
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 1d7663a
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: spansion: Remove s70fl01gs from flash_info
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 4f84141
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: sfdp: do not make invalid quad enable fatal
  (jsc#SLE-14214 jsc#SLE-16606).
- commit e70eaa2
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: winbond: Add support for w25q64jvm (jsc#SLE-14214
  jsc#SLE-16606).
- commit 2af6c2f
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: macronix: Add support for MX25R1635F
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 9e1bbfd
* Thu Nov 12 2020 mbrugger@suse.com
- spi: Move cadence-quadspi driver to drivers/spi/ (jsc#SLE-14214
  jsc#SLE-16606).
- supported.conf: add spi-cadence-quadspi
- commit 8a1f9bb
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Convert cadence-quadspi to use spi-mem framework
  (jsc#SLE-14214 jsc#SLE-16606).
- commit d8c2e6c
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: cadence-quadspi: Drop redundant WREN in erase path
  (jsc#SLE-14214 jsc#SLE-16606).
- commit a9da923
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: cadence-quadspi: Handle probe deferral while
  requesting DMA channel (jsc#SLE-14214 jsc#SLE-16606).
- commit 4ac0f60
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: cadence-quadspi: Fix error path on failure to
  acquire reset lines (jsc#SLE-14214 jsc#SLE-16606).
- commit 54ad082
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: cadence-quadspi: Don't initialize rx_dma_complete
  on failure (jsc#SLE-14214 jsc#SLE-16606).
- commit 93b08a2
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: cadence-quadspi: Provide a way to disable DAC mode
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 7d7032e
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: cadence-quadspi: Make driver independent of
  flash geometry (jsc#SLE-14214 jsc#SLE-16606).
- commit bdbc8f6
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: winbond: Fix 4-byte opcode support for w25q256
  (jsc#SLE-14214 jsc#SLE-16606).
- commit aa20dbb
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: sfdp: add/use local variable in
  spi_nor_parse_bfpt() (jsc#SLE-14214 jsc#SLE-16606).
- commit 792c4b4
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: sfdp: prepare BFPT parsing for JESD216 rev D
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 2cdc01c
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: sfdp: default to addr_width of 3 for configurable
  widths (jsc#SLE-14214 jsc#SLE-16606).
- commit 3606f8f
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add support for Cypress cy15x104q (jsc#SLE-14214
  jsc#SLE-16606).
- commit 33bff7c
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Fix SPI NOR acronym (jsc#SLE-14214 jsc#SLE-16606).
- commit f99be6c
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: spansion: Differentiate between s25fl256s and
  s25fs256s (jsc#SLE-14214 jsc#SLE-16606).
- commit 3307881
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add support for s25fs128s1 (jsc#SLE-14214
  jsc#SLE-16606).
- commit 8ab6047
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: spansion: fix writes on S25FS512S (jsc#SLE-14214
  jsc#SLE-16606).
- commit 34481df
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Fix description of the sr_ready() return value
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 13bc551
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Uniformize the return value in spi_nor_*_ready()
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 58aa248
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: micron-st: Enable locking for n25q00
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 6181ce7
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: macronix: Add support for mx25u51245g
  (jsc#SLE-14214 jsc#SLE-16606).
- commit c638b1b
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: macronix: Add support for mx25l51245g
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 84a5b3e
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: core: fix kernel-doc typo for
  spi_nor_[{info|sfdp}_]init_params() (jsc#SLE-14214
  jsc#SLE-16606).
- commit 8d20204
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: core: fix kernel-doc typo for
  spi_nor_manufacturer_init_params() (jsc#SLE-14214
  jsc#SLE-16606).
- commit 1004b63
* Thu Nov 12 2020 mbrugger@suse.com
- blacklist.conf: ignore documentation fixes
- commit d0366bc
* Thu Nov 12 2020 oneukum@suse.com
- usb-storage: use hcd_uses_dma to check for DMA capabilities
  (jsc#SLE-14911).
- commit 4fe856d
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Enable locking for n25q128a11 (jsc#SLE-14214
  jsc#SLE-16606).
- commit ce5c6e7
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: spansion: Enable dual and quad read for s25fl256s0
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 0fedc0f
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: move #define SPINOR_OP_WRDI (jsc#SLE-14214
  jsc#SLE-16606).
- commit a740fae
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Compile files in controllers/ directory
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 3bf9af8
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: Convert fallthrough comments into statements (jsc#SLE-14214
  jsc#SLE-16606).
- commit f4df930
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Enable locking for n25q512ax3/n25q512a
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 482ec39
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add SR 4bit block protection support
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 0627c1d
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add generic formula for SR block protection
  handling (jsc#SLE-14214 jsc#SLE-16606).
- commit 639adb7
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Set all BP bits to one when lock_len == mtd->size
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 80eb618
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: controllers: aspeed-smc: Replace zero-length
  array with flexible-array member (jsc#SLE-14214 jsc#SLE-16606).
- commit a134d0f
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Clear WEL bit when erase or program errors occur
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 600fa7b
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Trim what is exposed in spi-nor.h (jsc#SLE-14214
  jsc#SLE-16606).
- commit c3171b9
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Drop the MFR definitions (jsc#SLE-14214
  jsc#SLE-16606).
- commit 09c77fe
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Get rid of the now empty spi_nor_ids table
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 461f102
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move XMC bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit 190113a
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move Xilinx bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit bd875e9
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move Catalyst bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit 7cfa7ae
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move Winbond bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit cf1356c
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move SST bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit 690cd26
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move Spansion bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit e840536
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move Micron/ST bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit d6903e7
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move Macronix bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit 115905b
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move ISSI bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit 983f546
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move Intel bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit 3580c50
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move GigaDevice bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit 63a2aec
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move Fujitsu bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit 30aa231
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move Everspin bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit bf67a19
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move ESMT bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit 7ff9de8
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move Eon bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit d06a50b
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move Atmel bits out of core.c (jsc#SLE-14214
  jsc#SLE-16606).
- commit 5254c3f
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add the concept of SPI NOR manufacturer driver
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 3c7083f
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Expose stuctures and functions to manufacturer
  drivers (jsc#SLE-14214 jsc#SLE-16606).
- commit 2ff3420
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move SFDP logic out of the core (jsc#SLE-14214
  jsc#SLE-16606).
- commit eb3902e
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Prepare core / manufacturer code split
  (jsc#SLE-14214 jsc#SLE-16606).
- Refresh
  patches.suse/mtd-spi-nor-intel-spi-Add-support-for-Intel-Alder-La.patch.
- Refresh
  patches.suse/mtd-spi-nor-intel-spi-Add-support-for-Intel-Emmitsbu.patch.
- Refresh
  patches.suse/mtd-spi-nor-intel-spi-Add-support-for-Intel-TGL-H.patch.
- commit 98c41c0
* Thu Nov 12 2020 oneukum@suse.com
- USB: Fix incorrect DMA allocations for local memory pool drivers
  (jsc#SLE-14911).
- commit 5d64050
* Thu Nov 12 2020 oneukum@suse.com
- usb/ohci-tmio: remove the HCD_DMA flag (jsc#SLE-14911).
- commit 474181f
* Thu Nov 12 2020 oneukum@suse.com
- usb/ohci-sm501: remove the HCD_DMA flag (jsc#SLE-14911).
- commit 912f98f
* Thu Nov 12 2020 mkoutny@suse.com
- mm/memcg: fix refcount error while moving and swapping
  (bsc#1178686).
- commit cbd5a59
* Thu Nov 12 2020 oneukum@suse.com
- usb: host: xhci-plat: add quirks member into struct
  xhci_plat_priv (jsc#SLE-14911).
- Refresh
  patches.suse/usb-host-xhci-plat-add-.suspend_quirk-for-struct-xhc.patch.
- commit 73d2d44
* Thu Nov 12 2020 tiwai@suse.de
- USB: serial: option: add Telit FN980 composition 0x1055
  (git-fixes).
- USB: serial: option: add LE910Cx compositions 0x1203, 0x1230,
  0x1231 (git-fixes).
- USB: serial: option: add Quectel EC200T module support
  (git-fixes).
- USB: Add NO_LPM quirk for Kingston flash drive (git-fixes).
- net: usb: qmi_wwan: add Telit LE910Cx 0x1230 composition
  (git-fixes).
- kthread_worker: prevent queuing delayed work from timer_fn
  when it is being canceled (git-fixes).
- lib/crc32test: remove extra local_irq_disable/enable
  (git-fixes).
- tty: serial: fsl_lpuart: LS1021A has a FIFO size of 16 words,
  like LS1028A (git-fixes).
- usb: typec: tcpm: reset hard_reset_count for any disconnect
  (git-fixes).
- usb: host: fsl-mph-dr-of: check return of dma_set_mask()
  (git-fixes).
- ACPI: dock: fix enum-conversion warning (git-fixes).
- ACPI: NFIT: Fix comparison to '-ENXIO' (git-fixes).
- 9P: Cast to loff_t before multiplying (git-fixes).
- fbdev, newport_con: Move FONT_EXTRA_WORDS macros into
  linux/font.h (git-fixes).
- tty: serial: fsl_lpuart: add LS1028A support (git-fixes).
- commit af1d39a
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Emphasise which is the generic
  set_4byte_addr_mode() method (jsc#SLE-14214 jsc#SLE-16606).
- commit e53efc5
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Stop prefixing generic functions with a
  manufacturer name (jsc#SLE-14214 jsc#SLE-16606).
- commit a59dfd9
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: remove mtk-quadspi driver (jsc#SLE-14214
  jsc#SLE-16606).
- config: delete SPI_MTK_QUADSPI
- commit 97c9b43
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Refactor spi_nor_read_id() (jsc#SLE-14214
  jsc#SLE-16606).
- commit 75d66ec
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: use spi-mem dirmap API (jsc#SLE-14214
  jsc#SLE-16606).
- commit ff9409c
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: split spi_nor_spimem_xfer_data() (jsc#SLE-14214
  jsc#SLE-16606).
- commit b35b619
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: introduce SR_BP_SHIFT define (jsc#SLE-14214
  jsc#SLE-16606).
- commit 50a2cd7
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: use le32_to_cpu_array() (jsc#SLE-14214
  jsc#SLE-16606).
- commit 1a5d515
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add support for at25sl321 (jsc#SLE-14214
  jsc#SLE-16606).
- commit 80d213f
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add support for w25q32jwm (jsc#SLE-14214
  jsc#SLE-16606).
- commit 4343ce6
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Fix quad enable for Spansion like flashes
  (jsc#SLE-14214 jsc#SLE-16606).
- commit d524953
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Fix selection of 4-byte addressing opcodes on
  Spansion (jsc#SLE-14214 jsc#SLE-16606).
- commit 1f182d9
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: remove unused enum spi_nor_ops (jsc#SLE-14214
  jsc#SLE-16606).
- commit f55ddd2
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: hisi-sfc: Try to provide some clarity on which
  SFC we are (jsc#SLE-14214 jsc#SLE-16606).
- commit e7154aa
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add support for sst26vf016b (jsc#SLE-14214
  jsc#SLE-16606).
- commit f3555b4
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Fix the writing of the Status Register on micron
  flashes (jsc#SLE-14214 jsc#SLE-16606).
- commit 84601a1
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add support for mx25r3235f (jsc#SLE-14214
  jsc#SLE-16606).
- commit daefcbe
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add USE_FSR flag for n25q* entries (jsc#SLE-14214
  jsc#SLE-16606).
- commit 391a590
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add entries for mt25q variants (jsc#SLE-14214
  jsc#SLE-16606).
- commit a522644
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Split mt25qu512a (n25q512a) entry into two
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 9eb6351
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: add Gigadevice gd25lq128d support (jsc#SLE-14214
  jsc#SLE-16606).
- commit 010c025
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Fix wrong TB selection of GD25Q256 (jsc#SLE-14214
  jsc#SLE-16606).
- commit 45b3108
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Support TB selection using SR bit 6 (jsc#SLE-14214
  jsc#SLE-16606).
- commit a014cc1
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Rename SR_TB to indicate the bit used
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 0b013c9
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: fix typo of "JESB216" in comment (jsc#SLE-14214
  jsc#SLE-16606).
- commit b67360a
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add 4B_OPCODES flag to w25q256 (jsc#SLE-14214
  jsc#SLE-16606).
- commit 7060b68
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Set default Quad Enable method for ISSI flashes
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 2ff48df
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add support for is25wp256 (jsc#SLE-14214
  jsc#SLE-16606).
- commit dc96dfb
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add support for w25q256jw (jsc#SLE-14214
  jsc#SLE-16606).
- commit 2f5d120
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move condition to avoid a NULL check
  (jsc#SLE-14214 jsc#SLE-16606).
- commit fadcbe0
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Make sure nor->spimem and nor->controller_ops
  are mutually exclusive (jsc#SLE-14214 jsc#SLE-16606).
- commit ca273d3
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Rename Quad Enable methods (jsc#SLE-14214
  jsc#SLE-16606).
- commit e637be0
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Merge spansion Quad Enable methods (jsc#SLE-14214
  jsc#SLE-16606).
- commit c6078f3
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Rename CR_QUAD_EN_SPAN to SR2_QUAD_EN_BIT1
  (jsc#SLE-14214 jsc#SLE-16606).
- commit c9c7c34
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Extend the SR Read Back test (jsc#SLE-14214
  jsc#SLE-16606).
- commit d0471db
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Rework the disabling of block write protection
  (jsc#SLE-14214 jsc#SLE-16606).
- commit be85bc9
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Fix clearing of QE bit on lock()/unlock()
  (jsc#SLE-14214 jsc#SLE-16606).
- commit bec399a
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Print debug message when the read back test fails
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 99bf3f5
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Check all the bits written, not just the BP ones
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 6a51b7d
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Fix errno on Quad Enable methods (jsc#SLE-14214
  jsc#SLE-16606).
- commit a18d9e2
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Drop spansion_quad_enable() (jsc#SLE-14214
  jsc#SLE-16606).
- commit a6da1db
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Describe all the Reg Ops (jsc#SLE-14214
  jsc#SLE-16606).
- commit ca4ee89
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Merge spi_nor_write_sr() and spi_nor_write_sr_cr()
  (jsc#SLE-14214 jsc#SLE-16606).
- commit b9a5ece
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move the WE and wait calls inside Write SR methods
  (jsc#SLE-14214 jsc#SLE-16606).
- commit e5cdc63
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Void return type for spi_nor_clear_sr/fsr()
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 002d9b0
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Rename label as it is no longer generic
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 1fad7ff
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Check for errors after each Register Operation
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 73426d9
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Print debug info inside Reg Ops methods
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 156c73d
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Use dev_dbg insted of dev_err for low level info
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 4709e02
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Print device info in case of error (jsc#SLE-14214
  jsc#SLE-16606).
- commit 6e2adcc
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Constify data to write to the Status Register
  (jsc#SLE-14214 jsc#SLE-16606).
- commit a8f80bb
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Fix retlen handling in sst_write() (jsc#SLE-14214
  jsc#SLE-16606).
- commit dd2683f
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Drop redundant error reports in Reg Ops callers
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 77fd879
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Pointer parameter for CR in spi_nor_read_cr()
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 8952a80
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Pointer parameter for FSR in spi_nor_read_fsr()
  (jsc#SLE-14214 jsc#SLE-16606).
- commit ac5daf2
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Pointer parameter for SR in spi_nor_read_sr()
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 724e24c
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Don't overwrite errno from Reg Ops (jsc#SLE-14214
  jsc#SLE-16606).
- commit 28be0a5
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Drop explicit cast to int to already int value
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 09d1d5b
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Stop compare with negative in Reg Ops methods
  (jsc#SLE-14214 jsc#SLE-16606).
- commit b4cf257
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Group all Reg Ops to avoid forward declarations
  (jsc#SLE-14214 jsc#SLE-16606).
- commit bc9653a
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Drop duplicated new line (jsc#SLE-14214
  jsc#SLE-16606).
- commit 52586cb
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Prepend spi_nor_ to all Reg Ops methods
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 0ecd679
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: cadence-quadspi: Fix cqspi_command_read()
  definition (jsc#SLE-14214 jsc#SLE-16606).
- commit 874543a
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Introduce 'struct spi_nor_controller_ops'
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 97c7be8
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: hisi-sfc: Drop nor->erase NULL assignment
  (jsc#SLE-14214 jsc#SLE-16606).
- commit ca9042d
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: add support for en25qh16 (jsc#SLE-14214
  jsc#SLE-16606).
- commit 25ce894
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: intel-spi: support chips without software
  sequencer (jsc#SLE-14214 jsc#SLE-16606).
- commit 933d220
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: Remove dev_err() usage after platform_get_irq()
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 795a9b6
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Fix direction of the write_sr() transfer
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 5e765f9
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Rename "n25q512a" to "mt25qu512a (n25q512a)"
  (jsc#SLE-14214 jsc#SLE-16606).
- commit cc8813b
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: remove superfluous pass of nor->info->sector_size
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 959a02f
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: enable the debugfs for the partname and partid
  (jsc#SLE-14214 jsc#SLE-16606).
- mtd: mtdcore: add debugfs nodes for querying the flash name
  and id (jsc#SLE-14214 jsc#SLE-16606).
- commit 873f36c
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: hisi-sfc: Add of_node_put() before break
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 1b6d34e
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: aspeed-smc: Add of_node_put() (jsc#SLE-14214
  jsc#SLE-16606).
- commit d310896
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Introduce spi_nor_get_flash_info() (jsc#SLE-14214
  jsc#SLE-16606).
- commit 683ab9b
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Introduce spi_nor_set_addr_width() (jsc#SLE-14214
  jsc#SLE-16606).
- commit e7da70b
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Bring flash params init together (jsc#SLE-14214
  jsc#SLE-16606).
- commit 334a227
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add the SPI_NOR_XSR_RDY flag (jsc#SLE-14214
  jsc#SLE-16606).
- commit 7301863
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add s3an_post_sfdp_fixups() (jsc#SLE-14214
  jsc#SLE-16606).
- commit 09bd056
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add a ->setup() method (jsc#SLE-14214
  jsc#SLE-16606).
- commit 298c366
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add a ->convert_addr() method (jsc#SLE-14214
  jsc#SLE-16606).
- commit 3fe8621
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add spansion_post_sfdp_fixups() (jsc#SLE-14214
  jsc#SLE-16606).
- commit 56fc35d
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add post_sfdp() hook to tweak flash config
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 7abebf2
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Rework the SPI NOR lock/unlock logic
  (jsc#SLE-14214 jsc#SLE-16606).
- commit df6a378
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Create a ->set_4byte() method (jsc#SLE-14214
  jsc#SLE-16606).
- commit f825652
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Split spi_nor_init_params() (jsc#SLE-14214
  jsc#SLE-16606).
- commit 98aa133
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move manufacturer quad_enable() in
  - >default_init() (jsc#SLE-14214 jsc#SLE-16606).
- commit 4a3a36f
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add a default_init() fixup hook for gd25q256
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 236dc7a
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add default_init() hook to tweak flash parameters
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 03135bd
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move erase_map to 'struct spi_nor_flash_parameter'
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 2a373ff
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Regroup flash parameter and settings
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 23c4d78
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Remove unused macro (jsc#SLE-14214 jsc#SLE-16606).
- commit 6d0859d
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: fix description for int (*flash_is_locked)()
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 5b49c81
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Drop quad_enable() from 'struct spi-nor'
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 069a210
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Use nor->params (jsc#SLE-14214 jsc#SLE-16606).
- commit b675819
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: intel-spi: Whitelist 4B read commands
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 156ea66
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor : Remove SPI_NOR_HAS_TB flag on s25fl512s
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 04b480f
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: add support for sst26wf016b memory IC
  (jsc#SLE-14214 jsc#SLE-16606).
- commit c986061
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Add Winbond w25q256jvm (jsc#SLE-14214
  jsc#SLE-16606).
- commit 778875b
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Rework hwcaps selection for the spi-mem case
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 431fa40
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: Move m25p80 code in spi-nor.c (jsc#SLE-14214
  jsc#SLE-16606).
- Refresh
  patches.suse/mtd-spi-nor-Fix-an-error-code-in-spi_nor_read_raw.patch.
- Refresh
  patches.suse/mtd-spi-nor-fix-silent-truncation-in-spi_nor_read_ra.patch.
- supported.conf: delete m25p80 entry. driver is now part of spi-nor
- config: delete MTD_M25P80
- commit cafe293
* Thu Nov 12 2020 mbrugger@suse.com
- mtd: spi-nor: always use bounce buffer for register read/writes
  (jsc#SLE-14214 jsc#SLE-16606).
- commit 1d72a96
* Thu Nov 12 2020 glin@suse.com
- libbpf: Fix XDP program load regression for old kernels (bsc#1177028).
- libbpf: Fix native endian assumption when parsing BTF
  (bsc#1177028).
- tools/bpftool: Support passing BPFTOOL_VERSION to make
  (bsc#1177028).
- tools/libbpf: Avoid counting local symbols in ABI check
  (bsc#1177028).
- selftests/bpf: Add bpf_{update, delete}_map_elem in hashmap
  iter program (bsc#1177028).
- libbpf: Remove arch-specific include path in Makefile
  (bsc#1177028).
- selftests/bpf: Fix massive output from test_maps (bsc#1177028).
- selftests/bpf: Fix test_progs-flavor run getting number of tests
  (bsc#1177028).
- bpf: selftests: global_funcs: Check err_str before strstr
  (bsc#1177028).
- libbpf: Fix map index used in error message (bsc#1177028).
- bpftool: Handle EAGAIN error code properly in pids collection
  (bsc#1177028).
- libbpf: Fix build on ppc64le architecture (bsc#1177028).
- selftests/bpf: Make test_varlen work with 32-bit user-space arch
  (bsc#1177028).
- tools/bpftool: Generate data section struct with conservative
  alignment (bsc#1177028).
- selftests/bpf: Correct various core_reloc 64-bit assumptions
  (bsc#1177028).
- libbpf: Enforce 64-bitness of BTF for BPF object files
  (bsc#1177028).
- selftests/bpf: Fix btf_dump test cases on 32-bit arches
  (bsc#1177028).
- libbpf: Handle BTF pointer sizes more carefully (bsc#1177028).
- selftest/bpf: Fix compilation warnings in 32-bit mode
  (bsc#1177028).
- tools/bpftool: Fix compilation warnings in 32-bit mode
  (bsc#1177028).
- bpf, selftests: Add tests to sock_ops for loading sk
  (bsc#1177028).
- bpf, selftests: Add tests for sock_ops load with r9, r8.r7
  registers (bsc#1177028).
- bpf, selftests: Add tests for ctx access in sock_ops with
  single register (bsc#1177028).
- libbpf: Prevent overriding errno when logging errors
  (bsc#1177028).
- libbpf: Handle GCC built-in types for Arm NEON (bsc#1177028).
- selftests/bpf: Fix v4_to_v6 in sk_lookup (bsc#1177028).
- selftests/bpf: Fix segmentation fault in test_progs
  (bsc#1177028).
- libbpf: Do not use __builtin_offsetof for offsetof
  (bsc#1177028).
- bpf: Fix compilation warning of selftests (bsc#1177028).
- selftests: bpf: Switch off timeout (bsc#1177028).
- libbf: Fix uninitialized pointer at btf__parse_raw()
  (bsc#1177028).
- tools/bpf: Support new uapi for map element bpf iterator
  (bsc#1177028).
- bpf: Allow to specify ifindex for skb in bpf_prog_test_run_skb
  (bsc#1177028).
- tools/resolve_btfids: Use libbpf's btf__parse() API
  (bsc#1177028).
- tools/bpftool: Use libbpf's btf__parse() API for parsing BTF
  from file (bsc#1177028).
- tools, bpftool: Fix wrong return value in do_dump()
  (bsc#1177028).
- selftests/bpf: Fix spurious test failures in core_retro selftest
  (bsc#1177028).
- tools/bpftool: Add documentation and bash-completion for
  `link detach` (bsc#1177028).
- tools/bpftool: Add `link detach` subcommand (bsc#1177028).
- selftests/bpf: Add link detach tests for cgroup, netns, and
  xdp bpf_links (bsc#1177028).
- bpf, selftests: Use single cgroup helpers for both
  test_sockmap/progs (bsc#1177028).
- selftests/bpf: Omit nodad flag when adding addresses to loopback
  (bsc#1177028).
- selftests/bpf: Don't destroy failed link (bsc#1177028).
- selftests/bpf: Add xdpdrv mode for test_xdp_redirect
  (bsc#1177028).
- selftests/bpf: Verify socket storage in cgroup/sock_{create,
  release} (bsc#1177028).
- selftests/bpf: Test bpf_iter buffer access with negative offset
  (bsc#1177028).
- bpf, selftests: use :: 1 for localhost in tcp_server.py
  (bsc#1177028).
- selftests/bpf: Add new bpf_iter context structs to fix build
  on old kernels (bsc#1177028).
- tools, bpftool: Add LSM type to array of prog names
  (bsc#1177028).
- tools, bpftool: Skip type probe if name is not found
  (bsc#1177028).
- selftests/bpf: Add BPF XDP link selftests (bsc#1177028).
- selftests/bpf: Test CGROUP_STORAGE behavior on shared egress +
  ingress (bsc#1177028).
- selftests/bpf: Test CGROUP_STORAGE map can't be used by multiple
  progs (bsc#1177028).
- selftests/bpf: Add test for CGROUP_STORAGE map on multiple
  attaches (bsc#1177028).
- selftests/bpf: Add get_stackid_cannot_attach (bsc#1177028).
- selftests/bpf: Add callchain_stackid (bsc#1177028).
- selftests/bpf: Add a test for out of bound rdonly buf access
  (bsc#1177028).
- selftests/bpf: Add a test for bpf sk_storage_map iterator
  (bsc#1177028).
- selftests/bpf: Add test for bpf array map iterators
  (bsc#1177028).
- selftests/bpf: Add test for bpf hash map iterators
  (bsc#1177028).
- tools/bpftool: Add bpftool support for bpf map element iterator
  (bsc#1177028).
- selftests/bpf: Test BPF socket lookup and reuseport with
  connections (bsc#1177028).
- tools/bpftool: Strip BPF .o files before skeleton generation
  (bsc#1177028).
- bpftool: Use only nftw for file tree parsing (bsc#1177028).
- samples/bpf, selftests/bpf: Use bpf_probe_read_kernel
  (bsc#1177028).
- selftests/bpf: Fix test_lwt_seg6local.sh hangs (bsc#1177028).
- selftests: bpf: test_kmod.sh: Fix running out of srctree
  (bsc#1177028).
- selftests/bpf: Tests for BPF_SK_LOOKUP attach point
  (bsc#1177028).
- selftests/bpf: Add verifier tests for bpf_sk_lookup context
  access (bsc#1177028).
- tools/bpftool: Add name mappings for SK_LOOKUP prog and attach
  type (bsc#1177028).
- selftests/bpf: Fix possible hang in sockopt_inherit
  (bsc#1177028).
- selftest: Add tests for XDP programs in CPUMAP entries
  (bsc#1177028).
- selftests/bpf: Add selftests verifying bpf_trace_printk()
  behaviour (bsc#1177028).
- tools/bpftool: Remove warning about PID iterator support
  (bsc#1177028).
- bpf: Compile resolve_btfids tool at kernel compilation start
  (bsc#1177028).
- selftests/bpf: Switch perf_buffer test to tracepoint and
  skeleton (bsc#1177028).
- selftests/bpf: Add test relying only on CO-RE and no recent
  kernel features (bsc#1177028).
- selftests/bpf: test_progs avoid minus shell exit codes (bsc#1177028).
  blacklist.conf: remove b8c50df0cb3eb9008f8372e4ff0317eee993b8d1
- selftests/bpf: test_progs use another shell exit on non-actions
  (bsc#1177028).
- bpf: Fix another bpftool segfault without skeleton code enabled
  (bsc#1177028).
- selftests: bpf: Remove unused bpf_map_def_legacy struct
  (bsc#1177028).
- selftests/bpf: Test BPF_CGROUP_INET_SOCK_RELEASE (bsc#1177028).
- bpftool: Add support for BPF_CGROUP_INET_SOCK_RELEASE
  (bsc#1177028).
- selftests/bpf: Fix compilation error of bpf_iter_task_stack.c
  (bsc#1177028).
- bpf: Fix bpftool without skeleton code enabled (bsc#1177028).
- bpf: selftests: Restore netns after each test (bsc#1177028).
- bpf: selftests: A few improvements to network_helpers.c
  (bsc#1177028).
- selftests/bpf: Test_progs option for listing test names
  (bsc#1177028).
- selftests/bpf: Test_progs option for getting number of tests
  (bsc#1177028).
- selftests/bpf: Test_progs indicate to shell on non-actions
  (bsc#1177028).
- tools/bpftool: Turn off -Wnested-externs warning (bsc#1177028).
- selftests/bpf: Switch test_vmlinux to use hrtimer_range_start_ns
  (bsc#1177028).
- selftests/bpf: Add bpf_iter test with bpf_get_task_stack()
  (bsc#1177028).
- selftests/bpf: Add byte swapping selftest (bsc#1177028).
- tools/bpftool: Allow substituting custom vmlinux.h for the build
  (bsc#1177028).
- selftests/bpf: Test auto-load disabling logic for BPF programs
  (bsc#1177028).
- tools, bpftool: Define attach_type_name array only once
  (bsc#1177028).
- tools, bpftool: Define prog_type_name array only once
  (bsc#1177028).
- selftests/bpf: Add tcp/udp iterator programs to selftests
  (bsc#1177028).
- selftests/bpf: Implement sample udp/udp6 bpf_iter programs
  (bsc#1177028).
- selftests/bpf: Implement sample tcp/tcp6 bpf_iter programs
  (bsc#1177028).
- selftests/bpf: Add more common macros to bpf_tracing_net.h
  (bsc#1177028).
- selftests/bpf: Refactor some net macros to bpf_tracing_net.h
  (bsc#1177028).
- selftests/bpf: Move newer bpf_iter_* type redefining to a new
  header file (bsc#1177028).
- selftests/bpf: Workaround for get_stack_rawtp test
  (bsc#1177028).
- tools, bpftool: Fix variable shadowing in emit_obj_refs_json()
  (bsc#1177028).
- tools, bpftool: Correctly evaluate $(BUILD_BPF_SKELS) in
  Makefile (bsc#1177028).
- selftests/bpf: Add variable-length data concat pattern less
  than test (bsc#1177028).
- selftests/bpf: Add variable-length data concatenation pattern
  test (bsc#1177028).
- tools/bpftool: Add documentation and sample output for process
  info (bsc#1177028).
- tools/bpftool: Show info for processes holding BPF
  map/prog/link/btf FDs (bsc#1177028).
- tools/bpftool: Generalize BPF skeleton support and generate
  vmlinux.h (bsc#1177028).
- tools/bpftool: Minimize bootstrap bpftool (bsc#1177028).
- tools/bpftool: Move map/prog parsing logic into common
  (bsc#1177028).
- selftests/bpf: Add __ksym extern selftest (bsc#1177028).
- selftests/bpf: Test access to bpf map pointer (bsc#1177028).
- tools/bpftool: Relicense bpftool's BPF profiler prog as
  dual-license GPL/BSD (bsc#1177028).
- tools/bpf: Add verifier tests for 32bit pointer/scalar
  arithmetic (bsc#1177028).
- tools: bpf: Use local copy of headers including
  uapi/linux/filter.h (bsc#1177028).
- commit 7c3819c
* Wed Nov 11 2020 oneukum@suse.com
- xhci: Don't create stream debugfs files with spinlock held
  (jsc#SLE-14911).
- commit 33f4905
* Wed Nov 11 2020 oneukum@suse.com
- xhci: Fix sizeof() mismatch (jsc#SLE-14911).
- commit b128595
* Wed Nov 11 2020 oneukum@suse.com
- usb: xhci: add debugfs support for ep with stream
  (jsc#SLE-14911).
- commit 8f4b107
* Wed Nov 11 2020 oneukum@suse.com
- xhci: Tune interrupt blocking for isochronous transfers
  (jsc#SLE-14911).
- commit eb96741
* Wed Nov 11 2020 oneukum@suse.com
- usb: host: xhci-plat: add wakeup entry at sysfs (jsc#SLE-14911).
- commit e6a9364
* Wed Nov 11 2020 oneukum@suse.com
- usb: host: xhci-plat: add priv quirk for skip PHY initialization
  (jsc#SLE-14911).
- commit f463b1c
* Wed Nov 11 2020 oneukum@suse.com
- usb: host: xhci-plat: add .suspend_quirk for struct
  xhci_plat_priv (jsc#SLE-14911).
- commit 57038c6
* Wed Nov 11 2020 oneukum@suse.com
- usb: host: xhci-plat: add platform data support (jsc#SLE-14911).
- commit 880e577
* Wed Nov 11 2020 oneukum@suse.com
- usb: xhci-pci: Add support for reset controllers
  (jsc#SLE-14911).
- commit 7f849f0
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbgtty: Make some functions static (jsc#SLE-14911).
- commit 853016a
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Make function xhci_dbc_ring_alloc() static
  (jsc#SLE-14911).
- commit 92c3cc8
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: remove tty specific port structure from struct
  xhci_dbc (jsc#SLE-14911).
- commit 8cec92f
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbgcap: remove dbc dependency on dbctty specific flag
  (jsc#SLE-14911).
- commit a0d1ad9
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Add a operations structure to access driver functions
  (jsc#SLE-14911).
- commit 8d65e54
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbctty: split dbc tty driver registration and
  unregistration functions (jsc#SLE-14911).
- commit 3bf24ba
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: remove endpoint pointers from dbc_port structure
  (jsc#SLE-14911).
- commit ce6c68c
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: simplify dbc requests allocation and queueing
  (jsc#SLE-14911).
- commit f4336e0
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Pass dbc pointer to dbc start and stop functions
  (jsc#SLE-14911).
- commit 5cf2e31
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Pass dbc pointer to dbc memory init and cleanup
  functions (jsc#SLE-14911).
- commit 1f3a440
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: don't use generic xhci ring allocation functions
  for dbc (jsc#SLE-14811).
- commit e02b765
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Don't use generic xhci context allocation for dbc
  (jsc#SLE-14911).
- commit 4885a56
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Use dbc structure in the request completion instead
  of xhci_hcd (jsc#SLE-14911).
- commit 652c626
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Pass dbc pointer to get_in/out_ep() helper functions
  to get endpoints (jsc#SLE-14911).
- commit 4b67d19
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbgtty: Pass dbc pointer when registering a dbctty device
  (jsc#SLE-14911).
- commit 82d6c7a
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Pass dbc pointer to dbc_handle_xfer_event() instead
  of xhci_hcd pointer (jsc#SLE-14911).
- commit 7982f7d
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Change to pass dbc pointer to xhci_do_dbc_stop()
  (jsc#SLE-14911).
- commit ae30b9e
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Pass dbc pointer to endpoint init and exit functions
  (jsc#SLE-14911).
- commit 3a441cb
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Get the device pointer from dbc structure in
  dbc_ep_do_queue() (jsc#SLE-14911).
- usb: xhci: dbc: Simplify error handling in
  'xhci_dbc_alloc_requests()' (jsc#SLE-14911).
- commit edc2d95
* Wed Nov 11 2020 ohering@suse.de
- hv_netvsc: make recording RSS hash depend on feature flag
  (bsc#1177820).
- commit 84f7284
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Don't pass the xhci pointer as a parameter to
  xhci_dbc_init_context() (jsc#SLE-14911).
- commit 2697b5c
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Don't use xhci_write_64() as it takes xhci as a
  parameter (jsc#SLE-14911).
- commit 29fd0ed
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Use dev_info() and similar instead of xhci_info()
  (jsc#SLE-14911).
- commit 29b7ba7
* Wed Nov 11 2020 tbogendoerfer@suse.de
- ice: docs fix a devlink info that broke a table (jsc#SLE-12878).
- devlink: include <linux/const.h> for _BITUL (bsc#1176447).
- ionic: add DIMLIB to Kconfig (jsc#SLE-16649).
- commit 2d33c8a
* Wed Nov 11 2020 nborisov@suse.com
- Refresh patches.suse/vfs-add-super_operations-get_inode_dev. (bsc#1176983)
  It had a missing hunk in prof_namespace.c so simply add it, this fixes
  the issue reported in bsc#1176983
- commit 4999b20
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Add device pointer to dbc structure (jsc#SLE-14911).
- commit cbfe43e
* Wed Nov 11 2020 ohering@suse.de
- hv_netvsc: Fix XDP refcnt for synthetic and VF NICs
  (bsc#1177820).
- commit c7e2d68
* Wed Nov 11 2020 mkoutny@suse.com
- mm/memcontrol.c: add missed css_put() (bsc#1178661).
- commit 50e1826
* Wed Nov 11 2020 ohering@suse.de
- hv_netvsc: Add XDP support (bsc#1177820).
- refresh patches.suse/msft-hv-2073-hv_netvsc-Fix-netvsc_start_xmit-s-return-type.patch
- commit e1c99b4
* Wed Nov 11 2020 ohering@suse.de
- hv_netvsc: record hardware hash in skb (bsc#1177820).
- refresh patches.suse/suse-hv-kabi.patch b/patches.suse/suse-hv-kabi.patch
  (drop chunks which are in patches.suse/msft-hv-1962-hv_netvsc-record-hardware-hash-in-skb.patch)
- commit f89c5c0
* Wed Nov 11 2020 tbogendoerfer@suse.de
- ionic: check port ptr before use (jsc#SLE-16649).
- bnxt_en: Send HWRM_FUNC_RESET fw command unconditionally
  (jsc#SLE-16649).
- bnxt_en: Check abort error state in bnxt_open_nic()
  (jsc#SLE-16649).
- bnxt_en: Re-write PCI BARs after PCI fatal error
  (jsc#SLE-16649).
- bnxt_en: Invoke cancel_delayed_work_sync() for PFs also
  (jsc#SLE-16649).
- bnxt_en: Fix regression in workqueue cleanup logic in
  bnxt_remove_one() (jsc#SLE-16649).
- ionic: fix mem leak in rx_empty (jsc#SLE-16649).
- ionic: no rx flush in deinit (jsc#SLE-16649).
- ionic: clean up sparse complaints (jsc#SLE-16649).
- bnxt_en: Add stored FW version info to devlink info_get cb
  (jsc#SLE-16649).
- bnxt_en: Refactor bnxt_dl_info_get() (jsc#SLE-16649).
- bnxt_en: Add bnxt_hwrm_nvm_get_dev_info() to query NVM info
  (jsc#SLE-16649).
- bnxt_en: Log unknown link speed appropriately (jsc#SLE-16649).
- bnxt_en: Log event_data1 and event_data2 when handling
  RESET_NOTIFY event (jsc#SLE-16649).
- bnxt_en: Simplify bnxt_async_event_process() (jsc#SLE-16649).
- bnxt_en: Set driver default message level (jsc#SLE-16649).
- bnxt_en: Enable online self tests for multi-host/NPAR mode
  (jsc#SLE-16649).
- bnxt_en: Return -EROFS to user space, if NVM writes are not
  permitted (jsc#SLE-16649).
- ice: fix adding IP4 IP6 Flow Director rules (jsc#SLE-12878).
- ice: Fix pointer cast warnings (jsc#SLE-12878).
- ice: add additional debug logging for firmware update
  (jsc#SLE-12878).
- ice: refactor devlink_port to be per-VSI (jsc#SLE-12878).
- ice: add the DDP Track ID to devlink info (jsc#SLE-12878).
- ice: Change ice_info_get_dsn to be void (jsc#SLE-12878).
- ice: remove repeated words (jsc#SLE-12878).
- ice: devlink: use %%*phD to print small buffer (jsc#SLE-12878).
- bnxt_en: Eliminate unnecessary RX resets (jsc#SLE-16649).
- bnxt_en: Reduce unnecessary message log during RX errors
  (jsc#SLE-16649).
- bnxt_en: Add a software counter for RX ring reset
  (jsc#SLE-16649).
- bnxt_en: Implement RX ring reset in response to buffer errors
  (jsc#SLE-16649).
- bnxt_en: Refactor bnxt_init_one_rx_ring() (jsc#SLE-16649).
- bnxt_en: Refactor bnxt_free_rx_skbs() (jsc#SLE-16649).
- bnxt_en: Log FW health status info, if reset is aborted
  (jsc#SLE-16649).
- bnxt_en: perform no master recovery during startup
  (jsc#SLE-16649).
- bnxt_en: log firmware status on firmware init failure
  (jsc#SLE-16649).
- bnxt_en: refactor bnxt_alloc_fw_health() (jsc#SLE-16649).
- bnxt_en: Update firmware interface spec to 1.10.1.68
  (jsc#SLE-16649).
- ionic: add new bad firmware error code (jsc#SLE-16649).
- ionic: use lif ident for filter count (jsc#SLE-16649).
- ionic: refill lif identity after fw_up (jsc#SLE-16649).
- ionic: disable all queue napi contexts on timeout
  (jsc#SLE-16649).
- ionic: check qcq ptr in ionic_qcq_disable (jsc#SLE-16649).
- ionic: clear linkcheck bit on alloc fail (jsc#SLE-16649).
- ionic: drain the work queue (jsc#SLE-16649).
- ionic: contiguous memory for notifyq (jsc#SLE-16649).
- ionic: prevent early watchdog check (jsc#SLE-16649).
- ionic: stop watchdog timer earlier on remove (jsc#SLE-16649).
- net: ionic: Remove WARN_ON(in_interrupt()) (jsc#SLE-16649).
- net: ionic: Replace in_interrupt() usage (jsc#SLE-16649).
- ice: convert to new udp_tunnel infrastructure (jsc#SLE-12878).
- ice: remove unused args from ice_get_open_tunnel_port()
  (jsc#SLE-12878).
- bnxt_en: Improve preset max value for ethtool -l
  (jsc#SLE-16649).
- bnxt_en: Implement ethtool set_fec_param() method
  (jsc#SLE-16649).
- bnxt_en: Report Active FEC encoding during link up
  (jsc#SLE-16649).
- bnxt_en: Report FEC settings to ethtool (jsc#SLE-16649).
- bnxt_en: avoid link reset if speed is not changed
  (jsc#SLE-16649).
- bnxt_en: Handle ethernet link being disabled by firmware
  (jsc#SLE-16649).
- bnxt_en: ethtool: support PAM4 link speeds up to 200G
  (jsc#SLE-16649).
- bnxt_en: add basic infrastructure to support PAM4 link speeds
  (jsc#SLE-16649).
- bnxt_en: refactor bnxt_get_fw_speed() (jsc#SLE-16649).
- bnxt_en: refactor code to limit speed advertising
  (jsc#SLE-16649).
- bnxt_en: Update firmware interface spec to 1.10.1.65
  (jsc#SLE-16649).
- ice: add support for flash update overwrite mask
  (jsc#SLE-12878).
- netdevsim: add support for flash_update overwrite mask
  (bsc#1176447).
- devlink: introduce flash update overwrite mask (bsc#1176447).
- devlink: convert flash_update to use params structure
  (bsc#1176447).
- devlink: check flash_update parameter support in net core
  (bsc#1176447).
- hinic: improve the comments of function header (bsc#1176447).
- ice: simplify the return expression of ice_finalize_update()
  (jsc#SLE-12878).
- net: devlink: region: Pass the region ops to the snapshot
  function (bsc#1176447).
- net: devlink: regions: Add a priv member to the regions ops
  struct (bsc#1176447).
- hinic: modify irq name (bsc#1176447).
- ionic: add devlink firmware update (jsc#SLE-16649).
- ionic: update the fw update api (jsc#SLE-16649).
- netdevsim: devlink flash timeout message (bsc#1176447).
- devlink: collect flash notify params into a struct
  (bsc#1176447).
- devlink: add timeout information to status_notify
  (jsc#SLE-16649).
- ionic: dynamic interrupt moderation (jsc#SLE-16649).
- devlink: introduce the health reporter test command
  (bsc#1176447).
- mlxsw: Move fw flashing code into core.c (bsc#1176447).
- bnxt: add pause frame stats (jsc#SLE-15075).
- ethtool: add standard pause stats (jsc#SLE-15075).
- ionic: fix up debugfs after queue swap (jsc#SLE-16649).
- hinic: add vxlan segmentation and cs offload support
  (bsc#1176447).
- net: hns: Fix a kernel-doc warning in hinic_hw_eqs.c
  (bsc#1176447).
- net: hns: Fix a kernel-doc warning in hinic_hw_api_cmd.c
  (bsc#1176447).
- hinic: Fix some kernel-doc warnings in hinic_hw_io.c
  (bsc#1176447).
- net: remove napi_hash_del() from driver-facing API
  (jsc#SLE-15075).
- devlink: Introduce controller number (bsc#1176447).
- devlink: Introduce external controller flag (bsc#1176447).
- devlink: Move structure comments outside of structure
  (bsc#1176447).
- devlink: Add comment block for missing port attributes
  (bsc#1176447).
- net/mlx5: E-switch, Read controller number from device
  (bsc#1176447).
- ionic: clarify boolean precedence (jsc#SLE-16649).
- ionic: remove unused variable (jsc#SLE-16649).
- ionic: clean adminq service routine (jsc#SLE-16649).
- ionic: clean up desc_info and cq_info structs (jsc#SLE-16649).
- ionic: struct reorder for faster access (jsc#SLE-16649).
- ionic: clean up page handling code (jsc#SLE-16649).
- hinic: add support to query function table (bsc#1176447).
- hinic: add support to query rq info (bsc#1176447).
- hinic: add support to query sq info (bsc#1176447).
- ionic: pull reset_queues into tx_timeout handler
  (jsc#SLE-16649).
- ionic: change queue count with no reset (jsc#SLE-16649).
- ionic: change the descriptor ring length without full reset
  (jsc#SLE-16649).
- ionic: change mtu without full queue rebuild (jsc#SLE-16649).
- ionic: use index not pointer for queue tracking (jsc#SLE-16649).
- ionic: reduce contiguous memory allocation requirement
  (jsc#SLE-16649).
- ionic: clean up unnecessary non-static functions
  (jsc#SLE-16649).
- ionic: rework and simplify handling of the queue stats block
  (jsc#SLE-16649).
- ionic: remove lif list concept (jsc#SLE-16649).
- ionic: use kcalloc for new arrays (jsc#SLE-16649).
- ionic: fix up a couple of debug strings (jsc#SLE-16649).
- ionic: set MTU floor at ETH_MIN_MTU (jsc#SLE-16649).
- net: hinic: fix DEVLINK build errors (bsc#1176447).
- hinic: fix wrong return value of mac-set cmd (bsc#1176447).
- hinic: fix sending pkts from core while self testing
  (bsc#1176447).
- hinic: fix potential resource leak (bsc#1176447).
- hinic: fix rewaking txq after netif_tx_disable (bsc#1176447).
- hinic: bump up the timeout of UPDATE_FW cmd (bsc#1176447).
- hinic: bump up the timeout of SET_FUNC_STATE cmd (bsc#1176447).
- hinic: fix strncpy output truncated compile warnings
  (bsc#1176447).
- hinic: add check for mailbox msg from VF (bsc#1176447).
- hinic: add generating mailbox random index support
  (bsc#1176447).
- hinic: add log in exception handling processes (bsc#1176447).
- hinic: add support to handle hw abnormal event (bsc#1176447).
- hinic: add firmware update support (bsc#1176447).
- hinic: remove unused but set variable (bsc#1176447).
- hinic: add support to get eeprom information (bsc#1176447).
- hinic: add support to identify physical device (bsc#1176447).
- hinic: add self test support (bsc#1176447).
- hinic: add support to set and get irq coalesce (bsc#1176447).
- hinic: add support to set and get pause params (bsc#1176447).
- hinic: fix sending mailbox timeout in aeq event work
  (bsc#1176447).
- hinic: fix passing non negative value to ERR_PTR (bsc#1176447).
- hinic: add set_channels ethtool_ops support (bsc#1176447).
- hinic: add set_ringparam ethtool_ops support (bsc#1176447).
- hinic: add link_ksettings ethtool_ops support (bsc#1176447).
- hinic: add three net_device_ops of vf (bsc#1176447).
- hinic: Use kmemdup instead of kzalloc and memcpy (bsc#1176447).
- hinic: make symbol 'dump_mox_reg' static (bsc#1176447).
- hinic: Use ARRAY_SIZE for nic_vf_cmd_msg_handler (bsc#1176447).
- hinic: make a bunch of functions static (bsc#1176447).
- hinic: add net_device_ops associated with vf (bsc#1176447).
- hinic: add sriov feature support (bsc#1176447).
- hinic: add mailbox function support (bsc#1176447).
- hinic: fix wrong value of MIN_SKB_LEN (bsc#1176447).
- hinic: fix out-of-order excution in arm cpu (bsc#1176447).
- hinic: fix the bug of clearing event queue (bsc#1176447).
- hinic: fix a bug of waitting for IO stopped (bsc#1176447).
- hinic: fix a bug of rss configuration (bsc#1176447).
- hinic: fix a bug of setting hw_ioctxt (bsc#1176447).
- hinic: fix a irq affinity bug (bsc#1176447).
- commit d0f8bf4
* Wed Nov 11 2020 mkoutny@suse.com
- mm, memcg: fix inconsistent oom event behavior (bsc#1178659).
- commit 9f54445
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Remove dbc_dma_free_coherent() wrapper
  (jsc#SLE-14911).
- commit f669366
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Remove dbc_dma_alloc_coherent() wrapper
  (jsc#SLE-14911).
- commit 57b7868
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Don't use generic xhci erst allocation and free
  functions (jsc#SLE-14911).
- commit f1f3a81
* Wed Nov 11 2020 oneukum@suse.com
- xhci: Don't pass struct xhci_hcd pointer to xhci_link_seg()
  (jsc#SLE-14911).
- commit 1a4ff11
* Wed Nov 11 2020 oneukum@suse.com
- xhci: dbc: Don't use generic xhci inc_deq() function for dbc
  (jsc#SLE-14911).
- commit 19973f0
* Wed Nov 11 2020 oneukum@suse.com
- xhci: Make debug message consistent with bus and port number
  (jsc#SLE-14911).
- commit 60b582d
* Wed Nov 11 2020 glin@suse.com
- libbpf: Add btf__parse_raw() and generic btf__parse() APIs
  (bsc#1177028).
- libbpf: Add bpf_link detach APIs (bsc#1177028).
- libbpf: Fix register in PT_REGS MIPS macros (bsc#1177028).
- libbpf: Make destructors more robust by handling ERR_PTR(err)
  cases (bsc#1177028).
- libbpf: Add support for BPF XDP link (bsc#1177028).
- libbpf: Print hint when PERF_EVENT_IOC_SET_BPF returns -EPROTO
  (bsc#1177028).
- tools/libbpf: Add support for bpf map element iterator
  (bsc#1177028).
- libbpf bpf_helpers: Use __builtin_offsetof for offsetof
  (bsc#1177028).
- libbpf: Add support for SK_LOOKUP program type (bsc#1177028).
- bpf: Sync linux/bpf.h to tools/ (bsc#1177028).
- libbpf: Add SEC name for xdp programs attached to CPUMAP
  (bsc#1177028).
- libbpf: Fix memory leak and optimize BTF sanitization
  (bsc#1177028).
- libbpf: Handle missing BPF_OBJ_GET_INFO_BY_FD gracefully in
  perf_buffer (bsc#1177028).
- libbpf: Improve BTF sanitization handling (bsc#1177028).
- libbpf: Add btf__set_fd() for more control over loaded BTF FD
  (bsc#1177028).
- libbpf: Make BTF finalization strict (bsc#1177028).
- libbpf: Make bpf_endian co-exist with vmlinux.h (bsc#1177028).
- libbpf: Support disabling auto-loading BPF programs
  (bsc#1177028).
- libbpf: Fix spelling mistake "kallasyms" -> "kallsyms"
  (bsc#1177028).
- libbpf: Add support for extracting kernel symbol addresses
  (bsc#1177028).
- libbpf: Generalize libbpf externs support (bsc#1177028).
- libbpf: Add a bunch of attribute getters/setters for map
  definitions (bsc#1177028).
- libbpf: Bump version to 0.1.0 (bsc#1177028).
- commit 33e5f72
* Wed Nov 11 2020 mbenes@suse.cz
- ring-buffer: Fix recursion protection transitions between
  interrupt context (git-fixes).
- commit 5a991eb
* Wed Nov 11 2020 shung-hsi.yu@suse.com
- i40e: convert to new udp_tunnel infrastructure (jsc#SLE-13701).
- udp_tunnel: add the ability to share port tables
  (jsc#SLE-13701).
- commit 2887511
* Tue Nov 10 2020 pjakobsson@suse.de
- blacklist.conf: Add temporary blacklists for DRM backport
- commit 77bef97
* Tue Nov 10 2020 oneukum@suse.com
- xhci: Show host status when watchdog triggers and host is
  assumed dead (jsc#SLE-14911).
- commit 53efdb1
* Tue Nov 10 2020 oneukum@suse.com
- xhci: Add a separate debug message for split transaction errors
  (jsc#SLE-14911).
- commit d343dbc
* Tue Nov 10 2020 oneukum@suse.com
- USB: Replace zero-length array with flexible-array member
  (jsc#SLE-14911).
- Refresh patches.suse/0001-USB-fix-kABI-padding.patch.
- Refresh
  patches.suse/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
- Refresh
  patches.suse/usb-audio-v2-Add-uac2_effect_unit_descriptor-definit.patch.
- commit c75fffa
* Tue Nov 10 2020 oneukum@suse.com
- usb: host: xhci: Support running urb giveback in tasklet context
  (jsc#SLE-14911).
- xhci: Add tracing for xhci doorbell register writes
  (jsc#SLE-14911).
- commit 2db51be
* Tue Nov 10 2020 oneukum@suse.com
- xhci: add TSP bitflag to TRB tracing (jsc#SLE-14911).
- commit 264d360
* Tue Nov 10 2020 oneukum@suse.com
- usb: xhci: dbc: Use GFP_KERNEL instead of GFP_ATOMIC in
  'xhci_dbc_alloc_requests()' (jsc#SLE-14911).
- commit 89d6cd8
* Tue Nov 10 2020 oneukum@suse.com
- usb: add a HCD_DMA flag instead of guestimating DMA capabilities
  (jsc#SLE-14911).
- commit 29e46e1
* Tue Nov 10 2020 oneukum@suse.com
- usb: host: Remove call to memset after dma_alloc_coherent
  (jsc#SLE-14911).
- commit eb4b699
* Tue Nov 10 2020 trenn@suse.com
- powercap/intel_rapl: enumerate Psys RAPL domain together with
  package RAPL domain (bsc#1178325).
- powercap/intel_rapl: Fix domain detection (bsc#1178325).
- commit 14f7f31
* Tue Nov 10 2020 mbenes@suse.cz
- ftrace: Handle tracing when switching between context
  (git-fixes).
- commit ae03fad
* Tue Nov 10 2020 mbenes@suse.cz
- ftrace: Fix recursion check for NMI test (git-fixes).
- commit 030da09
* Tue Nov 10 2020 mbenes@suse.cz
- tracing: Fix out of bounds write in get_trace_buf (git-fixes).
- commit 67e9ee9
* Tue Nov 10 2020 pjakobsson@suse.de
- Refresh
  patches.suse/1553-drm-tegra-Fix-SMMU-support-on-Tegra124-and-Tegra210.patch.
- commit 1fa0e6a
* Tue Nov 10 2020 pjakobsson@suse.de
- drm/tee_shm: Drop dma_buf_k(unmap) support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- commit aa6de37
* Tue Nov 10 2020 pjakobsson@suse.de
- soc: mediatek: cmdq: add cmdq_dev_get_client_reg function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- commit cf12177
* Tue Nov 10 2020 shung-hsi.yu@suse.com
- i40e: Allow changing FEC settings on X722 if supported by FW
  (jsc#SLE-13701).
- i40e, xsk: move buffer allocation out of the Rx processing loop
  (jsc#SLE-13701).
- i40e: use 16B HW descriptors instead of 32B (jsc#SLE-13701).
- i40e, xsk: remove HW descriptor prefetch in AF_XDP path
  (jsc#SLE-13701).
- i40e: optimise prefetch page refcount (jsc#SLE-13701).
- i40e: not compute affinity_mask for IRQ (jsc#SLE-13701).
- xsk: i40e: ice: ixgbe: mlx5: Test for dma_need_sync earlier for better
  performance (jsc#SLE-12878 jsc#SLE-13701 jsc#SLE-13706 jsc#SLE-15172).
- xsk: i40e: ice: ixgbe: mlx5: Rename xsk zero-copy driver interfaces
  (jsc#SLE-12878 jsc#SLE-13701 jsc#SLE-13706 jsc#SLE-15172).
- commit 4c2bca6
* Tue Nov 10 2020 shung-hsi.yu@suse.com
- xsk: i40e: ice: ixgbe: mlx5: Pass buffer pool to driver instead of
  umem (jsc#SLE-12878 jsc#SLE-13701 jsc#SLE-13706 jsc#SLE-15172)
- Refresh
  patches.suse/0001-intel-ethernet-clean-up-W-1-warnings-in-kdoc.patch
- commit be04004
* Tue Nov 10 2020 pjakobsson@suse.de
- soc: mediatek: cmdq: add polling function (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- commit 2d15bfb
* Tue Nov 10 2020 shung-hsi.yu@suse.com
- Refresh
  patches.suse/xsk-replace-the-cheap_dma-flag-with-a-dma_need_sync-flag.
  Correct the polarity inversion.
- commit d48732d
* Tue Nov 10 2020 pjakobsson@suse.de
- soc: mediatek: cmdq: define the instruction struct
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- commit 0f24531
* Tue Nov 10 2020 pjakobsson@suse.de
- Refresh
  patches.suse/1367-drm-tegra-Do-not-implement-runtime-PM.patch.
- commit 7513d8f
* Tue Nov 10 2020 pjakobsson@suse.de
- Refresh
  patches.suse/1366-gpu-host1x-Rename-parent-to-host.patch.
- commit 7b574ae
* Tue Nov 10 2020 pjakobsson@suse.de
- Refresh
  patches.suse/0131-drm-tegra-Delete-host1x_bo_ops-k-un-map.patch.
- commit 54cdf86
* Tue Nov 10 2020 pjakobsson@suse.de
- supported.conf: add drivers/media/cec
  Several supported DRM modules depend on this
- commit 019d0eb
* Tue Nov 10 2020 msuchanek@suse.de
- xfs: show the dax option in mount options (bsc#1178366).
- ext4: show the dax option in mount options (bsc#1178366).
- commit 0d2614f
* Tue Nov 10 2020 vbabka@suse.cz
- mm/hmm: return error for non-vma snapshots (jsc#SLE-16387).
- commit cb4cd5c
* Tue Nov 10 2020 vbabka@suse.cz
- mm/hmm: do not set pfns when returning an error code
  (jsc#SLE-16387).
- commit d79f1a1
* Tue Nov 10 2020 vbabka@suse.cz
- mm/hmm: do not unconditionally set pfns when returning EBUSY
  (jsc#SLE-16387).
- commit 5c2e183
* Tue Nov 10 2020 vbabka@suse.cz
- mm/hmm: use device_private_entry_to_pfn() (jsc#SLE-16387).
- commit fdfc1a4
* Tue Nov 10 2020 vbabka@suse.cz
- mm/hmm: remove HMM_FAULT_SNAPSHOT (jsc#SLE-16387).
- commit 595b3de
* Tue Nov 10 2020 vbabka@suse.cz
- mm/hmm: remove unused code and tidy comments (jsc#SLE-16387).
- commit 1b3c7a1
* Tue Nov 10 2020 vbabka@suse.cz
- mm/hmm: return the fault type from hmm_pte_need_fault()
  (jsc#SLE-16387).
- commit 7cfcf46
* Tue Nov 10 2020 vbabka@suse.cz
- mm/hmm: remove pgmap checking for devmap pages (jsc#SLE-16387).
- commit f55826e
* Tue Nov 10 2020 vbabka@suse.cz
- mm/hmm: check the device private page owner in hmm_range_fault()
  (jsc#SLE-16387).
- commit 3210c7b
* Tue Nov 10 2020 vbabka@suse.cz
- mm: simplify device private page handling in hmm_range_fault
  (jsc#SLE-16387).
- commit d68ff3f
* Tue Nov 10 2020 vbabka@suse.cz
- mm: handle multiple owners of device private pages in
  migrate_vma (jsc#SLE-16387).
- commit bde305b
* Tue Nov 10 2020 vbabka@suse.cz
- mm/migrate.c: clean up useless code in migrate_vma_collect_pmd()
  (jsc#SLE-16387).
- commit 80ded04
* Tue Nov 10 2020 nsaenzjulienne@suse.de
- net: fec: fix MDIO probing for some FEC hardware blocks
  (git-fixes).
- spi: imx: fix runtime pm support for !CONFIG_PM (git-fixes).
- commit c0c4018
* Tue Nov 10 2020 vbabka@suse.cz
- mm: merge hmm_vma_do_fault into into hmm_vma_walk_hole_
  (jsc#SLE-16387).
- commit 58359ea
* Tue Nov 10 2020 vbabka@suse.cz
- mm/hmm: don't handle the non-fault case in hmm_vma_walk_hole_()
  (jsc#SLE-16387).
- commit e7fef6e
* Tue Nov 10 2020 vbabka@suse.cz
- mm/hmm: simplify hmm_vma_walk_hugetlb_entry() (jsc#SLE-16387).
- commit d96991d
* Tue Nov 10 2020 yousaf.kaukab@suse.com
- PCI: dwc: Program outbound ATU upper limit register
  (jsc#SLE-12251).
- commit 5653ea0
* Tue Nov 10 2020 vbabka@suse.cz
- mm/hmm: remove the unused HMM_FAULT_ALLOW_RETRY flag
  (jsc#SLE-16387).
- commit 4e5b1eb
* Tue Nov 10 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/exfat-fix-name_hash-computation-on-big-endian-systems.patch
  patches.suse/exfat-fix-overflow-issue-in-exfat_cluster_to_sector.patch
  patches.suse/exfat-fix-possible-memory-leak-in-exfat_find.patch
  patches.suse/exfat-fix-use-of-uninitialized-spinlock-on-error-path.patch
  patches.suse/exfat-fix-wrong-hint_stat-initialization-in-exfat_find_dir_entry.patch
  patches.suse/exfat-fix-wrong-size-update-of-stream-entry-by-typo.patch
  patches.suse/mmswapfile.c-fix-potential-memory-leak-in-sys_swapon.patch
- commit 37fd1b5
* Tue Nov 10 2020 vbabka@suse.cz
- mm/hmm: don't provide a stub for hmm_range_fault()
  (jsc#SLE-16387).
- commit 7bd4083
* Tue Nov 10 2020 glin@suse.com
- bpf: Fix "unresolved symbol" build error with resolve_btfids
  (bsc#1177028).
- bpf: Rename bpf_htab to bpf_shtab in sock_map (bsc#1177028).
  Refresh patches.suse/bpf-Set-map_btf_-name-id-for-all-map-types.patch
- bpf: sk_storage: Prefer to get a free cache_idx (bsc#1177028).
- ocfs2: fix build failure when TCP/IP is disabled (bsc#1177028).
- commit d5b78b7
* Tue Nov 10 2020 jslaby@suse.cz
- x86/platform/uv: Remove unused variable in UV5 NMI handler
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Update Copyrights to conform to HPE standards
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Update for UV5 NMI MMR changes (bnc#1177710
  jsc#SLE-13285).
- x86/platform/uv: Update UV5 TSC checking (bnc#1177710
  jsc#SLE-13285).
- x86/platform/uv: Update node present counting (bnc#1177710
  jsc#SLE-13285).
- x86/platform/uv: Update UV5 MMR references in UV GRU
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Adjust GAM MMR references affected by UV5
  updates (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Update MMIOH references based on new UV5 MMRs
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Add and decode Arch Type in UVsystab
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Add UV5 direct references (bnc#1177710
  jsc#SLE-13285).
- x86/platform/uv: Update UV MMRs for UV5 (bnc#1177710
  jsc#SLE-13285).
- drivers/misc/sgi-xp: Adjust references in UV kernel modules
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Remove SCIR MMR references for UV systems
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Remove UV BAU TLB Shootdown Handler
  (bnc#1177710 jsc#SLE-13285).
- x86/efi: Delete SGI UV1 detection (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Remove vestigial mention of UV1 platform from
  bios header (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Remove support for UV1 platform from uv
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Remove support for uv1 platform from uv_hub
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Remove support for UV1 platform from uv_bau
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Remove support for UV1 platform from uv_mmrs
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Remove support for UV1 platform from
  x2apic_uv_x (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Remove support for UV1 platform from uv_tlb
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Remove support for UV1 platform from uv_time
  (bnc#1177710 jsc#SLE-13285).
- x86/apic/uv: Remove code for unused distributed GRU mode
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Remove the unused _uv_cpu_blade_processor_id()
  macro (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Unexport uv_apicid_hibits (bnc#1177710
  jsc#SLE-13285).
- x86/platform/uv: Simplify uv_send_IPI_one() (bnc#1177710
  jsc#SLE-13285).
- x86/platform/uv: Mark uv_min_hub_revision_id static (bnc#1177710
  jsc#SLE-13285).
- x86/platform/uv: Remove the UV*_HUB_IS_SUPPORTED macros
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Unexport symbols only used by x2apic_uv_x.c
  (bnc#1177710 jsc#SLE-13285).
- x86/apic/uv: Avoid unused variable warning (bnc#1177710
  jsc#SLE-13285).
- x86/platform/uv: Fix kmalloc() NULL check routine (bnc#1177710
  jsc#SLE-13285).
- commit eb2cde9
* Tue Nov 10 2020 jslaby@suse.cz
- blacklist.conf: remove a cleanup
  We will backport it as a part of a series, so that it applies cleanly.
- commit 9f12703
* Tue Nov 10 2020 jslaby@suse.cz
- x86/platform/uv: Recognize UV5 hubless system identifier
  (bnc#1177710 jsc#SLE-13285).
- x86/platform/uv: Remove spaces from OEM IDs (bnc#1177710
  jsc#SLE-13285).
- x86/platform/uv: Fix missing OEM_TABLE_ID (bnc#1177710
  jsc#SLE-13285).
- commit e2421fe
* Tue Nov 10 2020 shung-hsi.yu@suse.com
- e1000e: Add support for Meteor Lake (jsc#SLE-13532).
- commit 374797f
* Tue Nov 10 2020 shung-hsi.yu@suse.com
- e1000: remove unused and incorrect code (jsc#SLE-15368).
- intel: handle unused assignments (jsc#SLE-15368).
- net: e1000: Remove set but not used variable (jsc#SLE-15368).
- commit 2aff626
* Mon Nov  9 2020 vbabka@suse.cz
- mm/hmm: do not check pmd_protnone twice in hmm_vma_handle_pmd()
  (jsc#SLE-16387).
- commit 16e1ed6
* Mon Nov  9 2020 vbabka@suse.cz
- mm/hmm: add missing call to hmm_pte_need_fault in
  HMM_PFN_SPECIAL handling (jsc#SLE-16387).
- commit e5953d6
* Mon Nov  9 2020 vbabka@suse.cz
- mm/hmm: return -EFAULT when setting HMM_PFN_ERROR on requested
  valid pages (jsc#SLE-16387).
- commit 7ba9153
* Mon Nov  9 2020 vbabka@suse.cz
- mm/hmm: reorganize how !pte_present is handled in
  hmm_vma_handle_pte() (jsc#SLE-16387).
- commit e36e8ab
* Mon Nov  9 2020 vbabka@suse.cz
- mm/hmm: add missing call to hmm_range_need_fault() before
  returning EFAULT (jsc#SLE-16387).
- commit 153ced0
* Mon Nov  9 2020 vbabka@suse.cz
- mm/hmm: add missing pfns set to hmm_vma_walk_pmd()
  (jsc#SLE-16387).
- commit 1333fe7
* Mon Nov  9 2020 vbabka@suse.cz
- mm/hmm: do not call hmm_vma_walk_hole() while holding a spinlock
  (jsc#SLE-16387).
- commit 5670219
* Mon Nov  9 2020 vbabka@suse.cz
- x86: mm: convert ptdump_walk_pgd_level_debugfs() to take an
  mm_struct (jsc#SLE-16387).
- Refresh
  patches.suse/x86-head-64-move-early-exception-dispatch-to-c-code.
- commit 0532584
* Mon Nov  9 2020 vbabka@suse.cz
- x86: mm+efi: convert ptdump_walk_pgd_level() to take a mm_struct
  (jsc#SLE-16387).
- Refresh
  patches.suse/x86-head-64-move-early-exception-dispatch-to-c-code.
- commit 7c4de70
* Mon Nov  9 2020 vbabka@suse.cz
- x86: mm: point to struct seq_file from struct pg_state
  (jsc#SLE-16387).
- commit f3fcb52
* Mon Nov  9 2020 vbabka@suse.cz
- mm: pagewalk: add 'depth' parameter to pte_hole (jsc#SLE-16387).
- commit 422f5fc
* Mon Nov  9 2020 vbabka@suse.cz
- mm: pagewalk: fix termination condition in walk_pte_range()
  (jsc#SLE-16387).
- commit fece2d0
* Mon Nov  9 2020 vbabka@suse.cz
- mm: pagewalk: don't lock PTEs for walk_page_range_novma()
  (jsc#SLE-16387).
- commit 39ed827
* Mon Nov  9 2020 vbabka@suse.cz
- mm: pagewalk: Take the pagetable lock in walk_pte_range()
  (jsc#SLE-16387).
- commit 5795e66
* Mon Nov  9 2020 vbabka@suse.cz
- mm: pagewalk: allow walking without vma (jsc#SLE-16387).
- commit b305cfb
* Mon Nov  9 2020 vbabka@suse.cz
- mm: pagewalk: add p4d_entry() and pgd_entry() (jsc#SLE-16387).
- commit 256b3d8
* Mon Nov  9 2020 vbabka@suse.cz
- x86: mm: add p?d_leaf() definitions (jsc#SLE-16387).
- commit c00cbb0
* Mon Nov  9 2020 vbabka@suse.cz
- s390: mm: add p?d_leaf() definitions (jsc#SLE-16387).
- commit 4cf6cf2
* Mon Nov  9 2020 vbabka@suse.cz
- powerpc: mm: add p?d_leaf() definitions (jsc#SLE-16387).
- commit e3519bd
* Mon Nov  9 2020 vbabka@suse.cz
- arm64: mm: add p?d_leaf() definitions (jsc#SLE-16387).
- commit d4d874a
* Mon Nov  9 2020 vbabka@suse.cz
- mm: add generic p?d_leaf() macros (jsc#SLE-16387).
- commit 0a30765
* Mon Nov  9 2020 vbabka@suse.cz
- mm/hmm: add missing unmaps of the ptep during
  hmm_vma_handle_pte() (jsc#SLE-16387).
- commit df3bac7
* Mon Nov  9 2020 vbabka@suse.cz
- mm/page_reporting: add free page reporting documentation
  (MM Functionality, jsc#SLE-12717).
- commit faeb6d4
* Mon Nov  9 2020 vbabka@suse.cz
- mm/page_reporting: add budget limit on how many pages can be
  reported per pass (MM Functionality, jsc#SLE-12717).
- commit e26edbf
* Mon Nov  9 2020 vbabka@suse.cz
- mm/page_reporting: rotate reported pages to the tail of the list
  (MM Functionality, jsc#SLE-12717).
- commit 8f659f2
* Mon Nov  9 2020 yousaf.kaukab@suse.com
- tty: serial: fsl_lpuart: LS1021A has a FIFO size of 16 words,
  like LS1028A (jsc#SLE-12251).
- commit 26807c4
* Mon Nov  9 2020 vbabka@suse.cz
- virtio-balloon: add support for providing free page reports
  to host (MM Functionality, jsc#SLE-12717).
- Update config files. Free page reporting selected by virtio-balloon.
- commit 93ef96c
* Mon Nov  9 2020 vbabka@suse.cz
- mm: introduce Reported pages (MM Functionality, jsc#SLE-12717).
- Update config files. Disable the new config, will be updated later.
- commit d3c28ff
* Mon Nov  9 2020 rgoldwyn@suse.com
- mm/swapfile.c: fix potential memory leak in sys_swapon
  (git-fixes).
- exfat: fix use of uninitialized spinlock on error path
  (git-fixes).
- exfat: fix name_hash computation on big endian systems
  (git-fixes).
- exfat: fix wrong size update of stream entry by typo
  (git-fixes).
- exfat: fix wrong hint_stat initialization in
  exfat_find_dir_entry()  (git-fixes).
- exfat: fix overflow issue in exfat_cluster_to_sector()
  (git-fixes).
- exfat: fix possible memory leak in exfat_find()  (git-fixes).
- commit 97624cb
* Mon Nov  9 2020 vbabka@suse.cz
- virtio-balloon: pull page poisoning config out of free page
  hinting (MM Functionality, jsc#SLE-12717).
- commit 6aed9c7
* Mon Nov  9 2020 vbabka@suse.cz
- mm: add function __putback_isolated_page (MM Functionality,
  jsc#SLE-12717).
- commit 6e0fba7
* Mon Nov  9 2020 vbabka@suse.cz
- mm: use zone and order instead of free area in free_list
  manipulators (MM Functionality, jsc#SLE-12717).
- Refresh
  patches.suse/mm-hwpoison-rework-soft-offline-for-free-pages.patch.
- commit 168d915
* Mon Nov  9 2020 vbabka@suse.cz
- Update patch metadata after merging to mainline
- Refresh
  patches.suse/mm-hwpoison-Try-to-narrow-window-race-for-free-pages.patch
- Refresh
  patches.suse/mm-hwpoison-cleanup-unused-PageHuge-check.patch.
- Refresh
  patches.suse/mm-hwpoison-double-check-page-count-in-__get_any_pag.patch.
- Refresh
  patches.suse/mm-hwpoison-inject-don-t-pin-for-hwpoison_filter.patch.
- Refresh
  patches.suse/mm-hwpoison-introduce-MF_MSG_UNSPLIT_THP.patch.
- Refresh patches.suse/mm-hwpoison-kill-put_hwpoison_page.patch.
- Refresh
  patches.suse/mm-hwpoison-refactor-madvise_inject_error.patch.
- Refresh
  patches.suse/mm-hwpoison-refactor-soft_offline_huge_page-and-__so.patch.
- Refresh
  patches.suse/mm-hwpoison-remove-recalculating-hpage.patch.
- Refresh
  patches.suse/mm-hwpoison-return-0-if-the-page-is-already-poisoned.patch.
- Refresh
  patches.suse/mm-hwpoison-rework-soft-offline-for-free-pages.patch.
- Refresh
  patches.suse/mm-hwpoison-rework-soft-offline-for-in-use-pages.patch.
- Refresh
  patches.suse/mm-hwpoison-unexport-get_hwpoison_page-and-make-it-s.patch.
- Refresh
  patches.suse/mm-hwpoison-unify-THP-handling-for-hard-and-soft-off.patch.
- commit 220db41
* Mon Nov  9 2020 yousaf.kaukab@suse.com
- include/linux/units.h: add helpers for kelvin to/from Celsius
  conversion (jsc#SLE-12251).
- commit c279345
* Mon Nov  9 2020 fdmanana@suse.com
- btrfs: reschedule if necessary when logging directory items
  (bsc#1178585).
- commit 5a09bb7
* Mon Nov  9 2020 fdmanana@suse.com
- btrfs: cleanup cow block on error (bsc#1178584).
- commit 080ee21
* Mon Nov  9 2020 yousaf.kaukab@suse.com
- tty: serial: fsl_lpuart: minimum baud rate support (jsc#SLE-12251).
- gpio: mpc8xxx: change the gpio interrupt flags (jsc#SLE-12251).
- thermal: qoriq: Update the settings for TMUv2 (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Use __maybe_unused instead of #if CONFIG_PM_SLEEP (jsc#SLE-12251).
- serial: fsl_lpuart: Change DMA failure messages to debug level (jsc#SLE-12251).
- tty: serial: fsl_lpuart: make coverity happy (jsc#SLE-12251).
- thermal: qoriq: Sort includes alphabetically (jsc#SLE-12251).
- thermal: qoriq: Use devm_add_action_or_reset() to handle all cleanups (jsc#SLE-12251).
- tty: serial: fsl_lpuart: fix return value checking (jsc#SLE-12251).
- tty: serial: fsl_lpuart: move dma_request_chan() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: add LS1028A earlycon support (jsc#SLE-12251).
- tty: serial: fsl_lpuart: add LS1028A support (jsc#SLE-12251).
- tty: serial: fsl_lpuart: fix DMA mapping (jsc#SLE-12251).
- tty: serial: fsl_lpuart: fix DMA operation when using IOMMU (jsc#SLE-12251).
- tty: serial: fsl_lpuart: drop earlycon entry for i.MX8QXP (jsc#SLE-12251).
- tty: serial: fsl_lpuart: support UPIO_MEM32 for lpuart32 (jsc#SLE-12251).
- tty: serial: lpuart: Add RS485 support for 32-bit uart flavour (jsc#SLE-12251).
- tty: serial: lpuart: Use defines that correspond to correct register (jsc#SLE-12251).
- tty: serial: lpuart: Remove unnecessary code from set_mctrl (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Fix lpuart_flush_buffer() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Ignore TX/RX interrupts if DMA is enabled (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Don't enable TIE in .startup() or .resume() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Introduce lpuart*_setup_watermark_enable() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Introduce lpuart32_configure() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Introduce lpuart_rx_dma_startup() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Introduce lpuart_tx_dma_startup() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Introduce lpuart_dma_shutdown() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Drop unnecessary lpuart*_stop_tx() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Introduce lpuart_stopped_or_empty() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Use cpu_relax() instead of barrier() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Introduce lpuart_wait_bit_set() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Clear CSTOPB unconditionally (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Drop unnecessary extra parenthesis (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Drop no-op bit opearation (jsc#SLE-12251).
- tty: serial: fls_lpuart: Split shared TX IRQ handler into two (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Fix issue in software flow control (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Drop unnecessary uart_write_wakeup() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Fix bogus indentation (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Simplify RX/TX IRQ handlers (jsc#SLE-12251).
- tty: serial: fsl_lpuart: Flush HW FIFOs in .flush_buffer (jsc#SLE-12251).
- tty: serial: fsl_lpuart: flush receive FIFO after overruns (jsc#SLE-12251).
- tty: serial: fsl_lpuart: fix framing error handling when using DMA (jsc#SLE-12251).
- tty: serial: fsl_lpuart: correct the FIFO depth size (jsc#SLE-12251).
- tty: serial: fsl_lpuart: remove sg_set_buf() for sport->rx_sgl (jsc#SLE-12251).
- tty: serial: fsl_lpuart: use kzalloc() instead of kmalloc() (jsc#SLE-12251).
- tty: serial: fsl_lpuart: add earlycon for imx8qxp platform (jsc#SLE-12251).
- tty: serial: fsl_lpuart: remove the dev.coherent_dma_mask zero setting (jsc#SLE-12251).
- commit 463bebe
* Mon Nov  9 2020 fdmanana@suse.com
- btrfs: send, recompute reference path after orphanization of
  a directory (bsc#1178581).
- commit 1067aa3
* Mon Nov  9 2020 fdmanana@suse.com
- btrfs: send, orphanize first all conflicting inodes when
  processing references (bsc#1178579).
- commit 972ec4e
* Mon Nov  9 2020 pjakobsson@suse.de
- Update config files.
  Updating config files for DRM backport
- commit cdfeead
* Mon Nov  9 2020 oneukum@suse.com
- crypto: caam - share definition for MAX_SDLEN (jsc#SLE-14454).
- commit 3551d71
* Mon Nov  9 2020 tonyj@suse.de
- perf/core: Fix a memory leak in perf_event_parse_addr_filter()
  (bsc#1178393, CVE-2020-25704).
- commit ec449ad
* Mon Nov  9 2020 mbenes@suse.cz
- Refresh
  patches.suse/x86-unwind-orc-Fix-inactive-tasks-with-stack-pointer.patch.
  "series_sort -u" applied
- commit 3711acc
* Mon Nov  9 2020 pjakobsson@suse.de
- blacklist.conf: Blacklist cherry-picks (dups) for drm v5.7
- commit aeb9d5f
* Mon Nov  9 2020 pjakobsson@suse.de
- blacklist.conf: Blacklist cherry-picks (dups) for drm v5.6
- commit 02b6132
* Mon Nov  9 2020 vbabka@suse.cz
- mm: adjust shuffle code to allow for future coalescing (MM
  Functionality, jsc#SLE-12717).
- commit 0fa6dd2
* Mon Nov  9 2020 denis.kirjanov@suse.com
- s390/ap: fix ap devices reference counting (git-fixes).
- commit b8ffb64
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: improve return codes for SMC-Dv2 (jsc#SLE-13761).
- s390/ism: fix incorrect system EID (jsc#SLE-13761).
- net/smc: fix null pointer dereference in smc_listen_decline()
  (jsc#SLE-13761).
- net/smc: fix valid DMBE buffer sizes (jsc#SLE-13761).
- net/smc: restore smcd_version when all ISM V2 devices failed
  to init (jsc#SLE-13761).
- net/smc: cleanup buffer usage in smc_listen_work()
  (jsc#SLE-13761).
- net/smc: consolidate unlocking in same function (jsc#SLE-13761).
- net/smc: use an array to check fields in system EID
  (jsc#SLE-13761).
- net/smc: send ISM devices with unique chid in CLC proposal
  (jsc#SLE-13761).
- net/smc: CLC decline - V2 enhancements (jsc#SLE-13761).
- net/smc: introduce CLC first contact extension (jsc#SLE-13761).
- net/smc: CLC accept / confirm V2 (jsc#SLE-13761).
- net/smc: determine accepted ISM devices (jsc#SLE-13761).
- net/smc: build and send V2 CLC proposal (jsc#SLE-13761).
- net/smc: determine proposed ISM devices (jsc#SLE-13761).
- net/smc: introduce list of pnetids for Ethernet devices
  (jsc#SLE-13761).
- net/smc: introduce CHID callback for ISM devices
  (jsc#SLE-13761).
- net/smc: introduce System Enterprise ID (SEID) (jsc#SLE-13761).
- net/smc: prepare for more proposed ISM devices (jsc#SLE-13761).
- net/smc: split CLC confirm/accept data to be sent
  (jsc#SLE-13761).
- net/smc: separate find device functions (jsc#SLE-13761).
- net/smc: CLC header fields renaming (jsc#SLE-13761).
- net/smc: remove constant and introduce helper to check for a
  pnet id (jsc#SLE-13761).
- commit a261cba
* Mon Nov  9 2020 tbogendoerfer@suse.de
- Refresh patches.suse/0002-igb-add-XDP-support.patch.
  Fix for bsc#1178464.
- commit 5da54c8
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: fix suppressed return code (git-fixes).
- commit 0fa48a6
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: fix invalid return code in smcd_new_buf_create()
  (git-fixes).
- net/smc: fix use-after-free of delayed events (git-fixes).
- net: smc: fix missing brace warning for old compilers
  (git-fixes).
- commit 9e5f788
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: fix double kfree in smc_listen_work() (jsc#SLE-13763).
- commit 906451f
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: check variable before dereferencing in smc_close.c
  (jsc#SLE-13763).
- net/smc: use separate work queues for different worker types
  (jsc#SLE-13763).
- net/smc: use the retry mechanism for netlink messages
  (jsc#SLE-13763).
- net/smc: immediate freeing in smc_lgr_cleanup_early()
  (jsc#SLE-13763).
- net/smc: reduce smc_listen_decline() calls (jsc#SLE-13763).
- net/smc: improve server ISM device determination
  (jsc#SLE-13763).
- net/smc: common routine for CLC accept and confirm
  (jsc#SLE-13763).
- commit 61f2ea9
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: dynamic allocation of CLC proposal buffer
  (jsc#SLE-13763).
- net/smc: introduce better field names (jsc#SLE-13763).
- net/smc: reduce active tcp_listen workers (jsc#SLE-13763).
- net/smc: fix sock refcounting in case of termination
  (jsc#SLE-13763).
- net/smc: reset sndbuf_desc if freed (jsc#SLE-13763).
- net/smc: set rx_off for SMCR explicitly (jsc#SLE-13763).
- net/smc: fix toleration of fake add_link messages
  (jsc#SLE-13763).
- commit fa7dce6
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: unique reason code for exceeded max dmb count
  (jsc#SLE-13763).
- net/smc: fix dmb buffer shortage (jsc#SLE-13763).
- net/smc: remove freed buffer from list (jsc#SLE-13763).
- net/smc: do not call dma sync for unmapped memory
  (jsc#SLE-13763).
- net/smc: fix handling of delete link requests (jsc#SLE-13763).
- net/smc: move add link processing for new device into llc layer
  (jsc#SLE-13763).
- commit 28f585b
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: drop out-of-flow llc response messages (jsc#SLE-13763).
- net/smc: protect smc ib device initialization (jsc#SLE-13763).
- net/smc: fix link lookup for new rdma connections
  (jsc#SLE-13763).
- net/smc: clear link during SMC client link down processing
  (jsc#SLE-13763).
- net/smc: handle unexpected response types for confirm link
  (jsc#SLE-13763).
- net/smc: switch smcd_dev_list spinlock to mutex (jsc#SLE-13763).
- net/smc: fix sleep bug in smc_pnet_find_roce_resource()
  (jsc#SLE-13763).
- commit 4dd55b0
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: fix work request handling (jsc#SLE-13763).
- net/smc: separate LLC wait queues for flow and messages
  (jsc#SLE-13763).
- net/smc: pre-fetch send buffer outside of send_lock
  (jsc#SLE-13763).
- net/smc: mark smc_pnet_policy as const (jsc#SLE-13763).
- net/smc: remove set but not used variables 'del_llc,
  del_llc_resp' (jsc#SLE-13763).
- net/smc: remove unused inline function smc_curs_read
  (jsc#SLE-13763).
- net/smc: log important pnetid and state change events
  (jsc#SLE-13763).
- Refresh
  patches.suse/RDMA-Allow-ib_client-s-to-fail-when-add-is-called.patch.
- commit 290cbef
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: save SMC-R peer link_uid (jsc#SLE-13763).
- net/smc: create improved SMC-R link_uid (jsc#SLE-13763).
- net/smc: improve termination processing (jsc#SLE-13763).
- net/smc: add termination reason and handle LLC protocol
  violation (jsc#SLE-13763).
- net/smc: asymmetric link tagging (jsc#SLE-13763).
- net/smc: assign link to a new connection (jsc#SLE-13763).
- net/smc: send DELETE_LINK, ALL message and wait for send to
  complete (jsc#SLE-13763).
- commit 7b84fa6
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: wait for departure of an IB message (jsc#SLE-13763).
- net/smc: handle incoming CDC validation message (jsc#SLE-13763).
- net/smc: send failover validation message (jsc#SLE-13763).
- net/smc: switch connections to alternate link (jsc#SLE-13763).
- net/smc: save state of last sent CDC message (jsc#SLE-13763).
- net/smc: enqueue local LLC messages (jsc#SLE-13763).
- net/smc: delete link processing as SMC server (jsc#SLE-13763).
- commit a6ff6ec
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: delete link processing as SMC client (jsc#SLE-13763).
- net/smc: llc_del_link_work and use the LLC flow for delete link
  (jsc#SLE-13763).
- net/smc: delete an asymmetric link as SMC server
  (jsc#SLE-13763).
- net/smc: final part of add link processing as SMC server
  (jsc#SLE-13763).
- net/smc: rkey processing for a new link as SMC server
  (jsc#SLE-13763).
- net/smc: first part of add link processing as SMC server
  (jsc#SLE-13763).
- net/smc: final part of add link processing as SMC client
  (jsc#SLE-13763).
- commit 62a06e5
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: rkey processing for a new link as SMC client
  (jsc#SLE-13763).
- net/smc: first part of add link processing as SMC client
  (jsc#SLE-13763).
- smc: Remove unused function (jsc#SLE-13763).
- net/smc: llc_add_link_work to handle ADD_LINK LLC requests
  (jsc#SLE-13763).
- net/smc: allocate index for a new link (jsc#SLE-13763).
- net/smc: introduce smc_pnet_find_alt_roce() (jsc#SLE-13763).
- net/smc: remove DELETE LINK processing from smc_core.c
  (jsc#SLE-13763).
- net/smc: take link down instead of terminating the link group
  (jsc#SLE-13763).
- commit 32caa81
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: add smcr_port_err() and smcr_link_down() processing
  (jsc#SLE-13763).
- net/smc: add smcr_port_add() and smcr_link_up() processing
  (jsc#SLE-13763).
- net/smc: remember PNETID of IB device for later device matching
  (jsc#SLE-13763).
- net/smc: mutex to protect the lgr against parallel
  reconfigurations (jsc#SLE-13763).
- net/smc: extend smc_llc_send_add_link() and
  smc_llc_send_delete_link() (jsc#SLE-13763).
- net/smc: map and register buffers for a new link
  (jsc#SLE-13763).
- net/smc: unmapping of buffers to support multiple links
  (jsc#SLE-13763).
- commit ec6693c
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: multiple link support for rmb buffer registration
  (jsc#SLE-13763).
- net/smc: remove obsolete link state DELETING (jsc#SLE-13763).
- net/smc: remove handling of CONFIRM_RKEY_CONTINUE
  (jsc#SLE-13763).
- net/smc: adapt SMC remote DELETE_RKEY processing to use the
  LLC flow (jsc#SLE-13763).
- net/smc: adapt SMC remote CONFIRM_RKEY processing to use the
  LLC flow (jsc#SLE-13763).
- net/smc: new smc_rtoken_set functions for multiple link support
  (jsc#SLE-13763).
- net/smc: move the TEST_LINK response processing into event
  handler (jsc#SLE-13763).
- commit 3d116ae
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: multiple link support and LLC flow for
  smc_llc_do_delete_rkey (jsc#SLE-13763).
- net/smc: multiple link support and LLC flow for
  smc_llc_do_confirm_rkey (jsc#SLE-13763).
- net/smc: adapt SMC client code to use the LLC flow
  (jsc#SLE-13763).
- Refresh patches.suse/net-smc-tolerate-future-smcd-versions.
- net/smc: adapt SMC server code to use the LLC flow
  (jsc#SLE-13763).
- net/smc: add logic to evaluate CONFIRM_LINK messages to LLC
  layer (jsc#SLE-13763).
- net/smc: introduce link group type (jsc#SLE-13763).
- net/smc: enqueue all received LLC messages (jsc#SLE-13763).
- commit f1b36b4
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: add event-based llc_flow framework (jsc#SLE-13763).
- net/smc: move llc layer related init and clear into smc_llc.c
  (jsc#SLE-13763).
- net/smc: use mutex instead of rwlock_t to protect buffers
  (jsc#SLE-13763).
- net/smc: process llc responses in tasklet context
  (jsc#SLE-13763).
- net/smc: use worker to process incoming llc messages
  (jsc#SLE-13763).
- net/smc: simplify link deactivation (jsc#SLE-13763).
- net/smc: move testlink work to system work queue
  (jsc#SLE-13763).
- commit 9e3ac5a
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: add new link state and related helpers (jsc#SLE-13763).
- net/smc: multi-link support for smc_rmb_rtoken_handling()
  (jsc#SLE-13763).
- net/smc: convert static link ID instances to support multiple
  links (jsc#SLE-13763).
- Refresh patches.suse/net-smc-tolerate-future-smcd-versions.
- net/smc: convert static link ID to dynamic references
  (jsc#SLE-13763).
- net/smc: introduce link_idx for link group array
  (jsc#SLE-13763).
- net/smc: separate function for link initialization
  (jsc#SLE-13763).
- net/smc: rework pnet table to support SMC-R failover
  (jsc#SLE-13763).
- Refresh
  patches.suse/RDMA-Allow-ib_client-s-to-fail-when-add-is-called.patch.
- commit c9fb3e8
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: improve peer ID in CLC decline for SMC-R
  (jsc#SLE-13763).
- net/smc: rework peer ID handling (jsc#SLE-13763).
- net/smc: reduce port_event scheduling (jsc#SLE-13763).
- net/smc: simplify normal link termination (jsc#SLE-13763).
- net/smc: remove unused parameter of smc_lgr_terminate()
  (jsc#SLE-13763).
- net/smc: do not delete lgr from list twice (jsc#SLE-13763).
- net/smc: use termination worker under send_lock (jsc#SLE-13763).
- commit ff91c5c
* Mon Nov  9 2020 ptesarik@suse.cz
- net/smc: improve smc_lgr_cleanup() (jsc#SLE-13763).
- net/smc: cancel event worker during device removal
  (jsc#SLE-13763).
- net/smc: fix cleanup for linkgroup setup failures
  (jsc#SLE-13763).
- net/smc: no peer ID in CLC decline for SMCD (jsc#SLE-13763).
- net/smc: transfer fasync_list in case of fallback
  (jsc#SLE-13763).
- net/smc: allow unprivileged users to read pnet table
  (jsc#SLE-13763).
- net/smc: shorten lgr_cnt initialization (jsc#SLE-13763).
- commit 7b16f62
* Mon Nov  9 2020 mbrugger@suse.com
- arm64: acpi: Make apei_claim_sea() synchronise with APEI's irq work (jsc#SLE-16610).
- arm64: acpi: Make apei_claim_sea() synchronise with APEI's
  irq work (jsc#SLE-16610).
- commit 5f689d9
* Mon Nov  9 2020 mbrugger@suse.com
- ACPI: APEI: Kick the memory_failure() queue for synchronous errors (jsc#SLE-16610).
- ACPI: APEI: Kick the memory_failure() queue for synchronous
  errors (jsc#SLE-16610).
- commit 36dbacd
* Mon Nov  9 2020 mbrugger@suse.com
- mm/memory-failure: Add memory_failure_queue_kick()
  (jsc#SLE-16610).
- Refresh patches.suse/mm-hwpoison-kill-put_hwpoison_page.patch.
- Refresh
  patches.suse/mm-hwpoison-unexport-get_hwpoison_page-and-make-it-s.patch.
- commit 7b68336
* Mon Nov  9 2020 mbrugger@suse.com
- firmware: arm_sdei: Document the motivation behind these set_fs() calls (jsc#SLE-16610).
- firmware: arm_sdei: Document the motivation behind these
  set_fs() calls (jsc#SLE-16610).
- commit 7d33342
* Mon Nov  9 2020 tiwai@suse.de
- ALSA: make snd_kcontrol_new name a normal string (git-fixes).
- commit e08e803
* Mon Nov  9 2020 ailiop@suse.com
- xfs: fix scrub flagging rtinherit even if there is no rt device
  (git-fixes).
- commit abfd9e4
* Mon Nov  9 2020 ailiop@suse.com
- xfs: flush new eof page on truncate to avoid post-eof corruption
  (git-fixes).
- commit 8dd6e4b
* Mon Nov  9 2020 ailiop@suse.com
- xfs: set xefi_discard when creating a deferred agfl free log
  intent item (git-fixes).
- commit 9130952
* Mon Nov  9 2020 tbogendoerfer@suse.de
- Refresh
  patches.suse/RDMA-umem-Add-a-schedule-point-in-ib_umem_get.patch.
- Delete
  patches.suse/IB-umem-use-get_user_pages_fast-to-pin-DMA-pages.patch.
  get_user_pages_fast() in SP3 doesn't support requested features so we
  drop this patch.
- commit 24e600c
* Mon Nov  9 2020 tiwai@suse.de
- serial: txx9: add missing platform_driver_unregister() on
  error in serial_txx9_init (git-fixes).
- serial: 8250_mtk: Fix uart_get_baud_rate warning (git-fixes).
- USB: serial: cyberjack: fix write-URB completion race
  (git-fixes).
- usb: mtu3: fix panic in mtu3_gadget_stop() (git-fixes).
- can: flexcan: flexcan_remove(): disable wakeup completely
  (git-fixes).
- can: flexcan: remove FLEXCAN_QUIRK_DISABLE_MECR quirk for
  LS1021A (git-fixes).
- can: peak_canfd: pucan_handle_can_rx(): fix echo management
  when loopback is on (git-fixes).
- can: peak_usb: peak_usb_get_ts_time(): fix timestamp wrapping
  (git-fixes).
- can: peak_usb: add range checking in decode operations
  (git-fixes).
- can: can_create_echo_skb(): fix echo skb generation: always
  use skb_clone() (git-fixes).
- can: dev: __can_get_echo_skb(): fix real payload length return
  value for RTR frames (git-fixes).
- can: dev: can_get_echo_skb(): prevent call to kfree_skb()
  in hard IRQ context (git-fixes).
- can: rx-offload: don't call kfree_skb() from IRQ context
  (git-fixes).
- commit efd4e46
* Mon Nov  9 2020 yousaf.kaukab@suse.com
- spi: fsl-dspi: fix wrong pointer in suspend/resume
  (jsc#SLE-12251).
- commit 3118159
* Mon Nov  9 2020 tiwai@suse.de
- intel_idle: Fix max_cstate for processor models without C-state
  tables (git-fixes).
- commit c5463fe
* Mon Nov  9 2020 tiwai@suse.de
- Replace intel_idle fix with the upstream change (bsc#1177399)
- commit 54ee77b
* Mon Nov  9 2020 tiwai@suse.de
- tty: serial: imx: enable earlycon by default if
  IMX_SERIAL_CONSOLE is enabled (git-fixes).
- r8169: work around short packet hw bug on RTL8125 (git-fixes).
- mac80211: don't require VHT elements for HE on 2.4 GHz
  (git-fixes).
- mac80211: fix regression where EAPOL frames were sent in
  plaintext (git-fixes).
- rtw88: pci: Power cycle device during shutdown (git-fixes).
- mt76: mt7622: fix fw hang on mt7622 (git-fixes).
- mt76: mt7915: do not do any work in napi poll after calling
  napi_complete_done() (git-fixes).
- mt76: mt7615: move drv_own/fw_own in mt7615_mcu_ops (git-fixes).
- mac80211: add missing queue/hash initialization to 802.3 xmit
  (git-fixes).
- brcmfmac: increase F2 watermark for BCM4329 (git-fixes).
- ath10k: fix retry packets update in station dump (git-fixes).
- ASoC: AMD: Clean kernel log from deferred probe error messages
  (git-fixes).
- commit 17b9091
* Mon Nov  9 2020 glin@suse.com
- bpf: Plug hole in struct bpf_sk_lookup_kern (bsc#1177028).
- bpf: Prevent .BTF section elimination (bsc#1177028).
- bpf: Bpf_skc_to_* casting helpers require a NULL check on sk
  (bsc#1177028).
- bpf: Fix clobbering of r2 in bpf_gen_ld_abs (bsc#1177028).
- tools/bpf: build: Make sure resolve_btfids cleans up after
  itself (bsc#1177028).
- bpf: xdp: Fix XDP mode when no mode flags specified
  (bsc#1177028).
- tools/resolve_btfids: Fix sections with wrong alignment
  (bsc#1177028).
- bpf: sock_ops sk access may stomp registers when dst_reg =
  src_reg (bsc#1177028).
- bpf: sock_ops ctx access may stomp registers in corner case
  (bsc#1177028).
- bpf: Fix XDP FD-based attach/detach logic around
  XDP_FLAGS_UPDATE_IF_NOEXIST (bsc#1177028).
- bpf: Add missing return to resolve_btfids (bsc#1177028).
- bpf: Expose socket storage to BPF_PROG_TYPE_CGROUP_SOCK
  (bsc#1177028).
- net: make sockptr_is_null strict aliasing safe (bsc#1177028).
- net: switch copy_bpf_fprog_from_user to sockptr_t (bsc#1177028).
- net: add a new sockptr_t type (bsc#1177028).
- net: simplify cBPF setsockopt compat handling (bsc#1177028).
- Refresh patches.suse/bpf-Introduce-SK_LOOKUP-program-type-with-a-dedicate.patch
- bpf: Fix net/core/filter build errors when INET is not enabled
  (bsc#1177028).
- bpf: Add SO_KEEPALIVE and related options to bpf_setsockopt
  (bsc#1177028).
- tcp: Expose tcp_sock_set_keepidle_locked (bsc#1177028).
- sock: Move sock_valbool_flag to header (bsc#1177028).
- tcp: add tcp_sock_set_keepcnt (bsc#1177028).
- tcp: add tcp_sock_set_keepintvl (bsc#1177028).
- tcp: add tcp_sock_set_keepidle (bsc#1177028).
- tcp: add tcp_sock_set_user_timeout (bsc#1177028).
- tcp: add tcp_sock_set_syncnt (bsc#1177028).
- tcp: add tcp_sock_set_quickack (bsc#1177028).
- tcp: add tcp_sock_set_nodelay (bsc#1177028).
- tcp: add tcp_sock_set_cork (bsc#1177028).
- net: add sock_set_keepalive (bsc#1177028).
  Refresh patches.suse/net-Make-locking-in-sock_bindtoindex-optional.patch
- net: add sock_set_priority (bsc#1177028).
- Restore patches.suse/net-add-sock_bindtoindex.patch to upstream commit
- Refresh patches.suse/net-Make-locking-in-sock_bindtoindex-optional.patch
- net: add sock_no_linger (bsc#1177028).
  Refresh patches.suse/net-add-sock_bindtoindex.patch and
  patches.suse/net-Make-locking-in-sock_bindtoindex-optional.patch
- net: add sock_set_reuseaddr (bsc#1177028).
  Refresh patches.suse/net-add-sock_bindtoindex.patch and
  patches.suse/net-Make-locking-in-sock_bindtoindex-optional.patch
- commit 407d988
* Mon Nov  9 2020 pjakobsson@suse.de
- gpu/drm: Ingenic: Fix opaque pointer casted to wrong type
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- blacklist.conf: unblacklist patches included in drm v5.7 backport
- gpu/drm: ingenic: Fix bogus crtc_atomic_check callback
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix potential integer wraparound resulting
  in a hang (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: drop cursor position check in atomic test
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- device_cgroup: Cleanup cgroup eBPF device filter code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Defer cursor lock until after VUPDATE
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove dml_common_def file (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: DP training to set properly SCRAMBLING_DISABLE
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: Fix a leak in submit_pin_objects() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/etnaviv: fix perfmon domain interation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/edid: Add Oculus Rift S to non-desktop list (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: Return true in function vmw_fence_obj_signaled()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: remove redundant assignment to variable ret
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Fix parameter name in vmw_bo_init (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/meson: pm resume add return errno branch (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Handle idling during i915_gem_evict_something
  busy loops (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Fix kernel oops for 3-level ppgtt guest
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Init DPLL/DDI vreg for virtual display instead of
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Mark concurrent submissions with a weak-dependency
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Propagate error from completed fences (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: Update update_config() logic (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: add raven1 part to the gfxoff quirk list
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add basic atomic check for cursor plane
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix vblank and pageflip event handling
  for FreeSync (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: implement soft_recovery for gfx10 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable hibernate support on Navi1X (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Use GEM obj reference for KFD BOs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: force fbdev into vram (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: perform PG ungate prior to CG ungate
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: drop unnecessary cancel_delayed_work_sync on
  PG ungate (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: disable MGCG/MGLS also on gfx CG ungate
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gpu: host1x: Use SMMU on Tegra124 and Tegra210 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tegra: Fix SMMU support on Tegra124 and Tegra210
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Track inflight CCID (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/execlists: Avoid reusing the same logical CCID
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Remove object_is_locked assertion from
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Yield the timeslice if caught waiting on a user
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Check current i915_vma.pin_count status first
  on unbind (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl+: Fix interrupt handling for DP AUX transactions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Make the "Reducing compressed framebufer size" message be
  DRM_INFO_ONCE() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Don't enable WaIncreaseLatencyIPCEnabled when IPC
  is disabled (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Make timeslicing an explicit engine property
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Avoid dereferencing a dead context (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: fix trivial field description cut-and-paste error
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Fix HDCP failures when SRM fw is missing (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- sun6i: dsi: fix gcc-4.8 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: ingenic-drm: add MODULE_DEVICE_TABLE (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: create context before RESOURCE_CREATE_2D in 3D mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Prevent dpcd reads with passive dongles
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix counter in wait_for_no_pipes_pending
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Update DCN2.1 DV Code Revision (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: work around fp code being emitted outside of
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/dc: Use WARN_ON_ONCE for ASSERT (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: drop redundant cg/pg ungate on runpm enter
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: move kfd suspend after ip_suspend_phase1
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use cursor locking to prevent flip delays
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Update downspread percent to match spreadsheet
  for (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Defer cursor update around VUPDATE for all ASIC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix rn soc bb update (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: check if REFCLK_CNTL register is present
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: bump version for invalidate L2 before SDMA IBs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: invalidate L2 before SDMA IBs (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add tiling flags from Mesa (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: avoid using pm_en before it is initialized
  revised (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/amd/powerplay: avoid using pm_en before it is
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix green screen issue after suspend
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: blank dp stream before re-train the link
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: DispalyPort: Write OUI only if panel supports
  it (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use proper fault mask in interrupt postinstall too
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Check cacheline is valid before acquiring
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Hold obj->vma.lock over for_each_ggtt_vma()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Fix i915_address_space refcnt leak
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: fix documentation build warnings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/qxl: qxl_release use after free (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/qxl: lost qxl_bo_kunmap_atomic_page in
  qxl_image_init_helper() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/qxl: qxl_release leak in qxl_hw_surface_alloc()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/qxl: qxl_release leak in qxl_draw_dirty_fb() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: only destroy created contexts (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Fix drm_dp_send_dpcd_write() return code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: Fix SET_NAME ioctl uapi (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Fix off-by-one in DispID DTD pixel clock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tidss: fix crash related to accessing freed memory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Zero assigned PBN when releasing VCPI slots
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/scheduler: fix drm_sched_get_cleanup_job (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/meson: Delete an error message in meson_dw_hdmi_bind()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: anx6345: set correct BPC for display_info of
  connector (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dpcd_bl: Unbreak enable_dpcd_backlight modparam
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: fix Sphinx build duplicate label warning
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Load DP_TP_CTL/STATUS offset before use it
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: TBT AUX should use TC power well ops
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: HDCP: fix Ri prime check done during link check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Update PMINTRMSK holding fw (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Add Wa_14010477008:tgl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/display: give aux i2c buses more meaningful names
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: fix aux registration (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Correctly initialize thermal controller for
  GPUs with (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: fix resume failed as smu table initialize
  early (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: fix up for include file changes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- virtgpu: pull in uaccess.h (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/sec2/gv100-: add missing MODULE_FIRMWARE()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx9: add gfxoff quirk (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix the hw hang during perform system reboot
  and reset (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix wrong vram lost counter increment V2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: unload mp1 for Arcturus RAS baco reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: force the trim of the mclk dpm_levels if OD
  is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/amdgpu: change SH MEM alignment mode for gfx10"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: Do not clear pollin for small user read buffers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: remove always-defined CONFIG_AS_MOVNTDQA
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: fix warning when compiling without debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: unify fw_write_wait for new gfx9 asics
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: error out on forcing clock setting not
  supported (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix gfx hang during suspend with video playback (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Check for null fclk voltage when parsing
  clock table (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Acknowledge wm_optimized_required
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Make cursor source translation adjustment
  optional (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Calculate scaling ratios on every medium/full
  update (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Program viewport when source pos changes
  for DCN20 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix incorrect cursor pos on scaled
  primary plane (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: change default pipe_split policy for DCN1
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Translate cursor position by source rect
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Update stream adjust in
  dc_stream_adjust_vmin_vmax (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Avoid create MST prop after registration
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/psp: dont warn on missing optional TA's
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update RAS related dmesg print (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: resolve mGPU RAS query instability (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: Correct gfx10's CG sequence (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Fix oops when pp_funcs is unset in ACPI event
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: change SH MEM alignment mode for gfx10
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: avoid using pm_en before it is initialized
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: implement the is_dpm_running()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: re-order asic declarations (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/powerplay: using the FCLK DPM table to set the MCLK
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Flush all the reloc_gpu batch (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Ignore readonly failures when updating relocs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Fill all the unused space in the GGTT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Return the right vswing tables (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/icl+: Don't enable DDI IO power on a TypeC port
  in TBT mode (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: Temporarily disable the huge_fault() callback
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: analogix_dp: Split bind() into probe() and
  real bind() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/legacy: Fix type for drm_local_map.offset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: fix OOB in virtio_gpu_object_create (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/prime: fix extracting of the DMA addresses from a
  scatterlist (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: kfree the wrong pointer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: increase HDCP authentication delay
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Correctly cancel future watchdog and
  callback events (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Don't try hdcp1.4 when content_type is
  set to type1 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: move the ASIC specific nbio operation out of
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop redundant BIF doorbell interrupt
  operations (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix dcn21 num_states (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Enable BT2020 in COLOR_ENCODING property
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: LFC not working on 2.0x range monitors (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Support plane level CTM (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Revert change to HDCP display states
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Not doing optimize bandwidth if flip pending
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use double buffered DRR timing update
  by default (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Support P010 pixel format (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Update function to get optimal number of taps
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix hpd bo size calculation error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/kms/nv50-: wait for FIFO space on PIO channels
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvif: protect waits against GPU falling off the bus
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvif: access PTIMER through usermode class,
  if available (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/gp107,gp108: implement workaround for HW hanging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: workaround runpm fail by disabling PCI power
  management (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/svm: remove useless SVM range check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/svm: check for SVM initialized before migrating
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/svm: fix vma range check for migration
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: remove checks for return value of debugfs functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/ttm: evict other IO mappings when running
  out of BAR1 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mm: revert "Break long searches in fragmented address
  spaces" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/xen: fix passing zero to 'PTR_ERR' warning (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- fbcon: fix null-ptr-deref in fbcon_switch (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: Fix HDMI mode validation (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vboxvideo: Add missing remove_conflicting_pci_framebuffers
  call, (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel-simple: drop use of data-mapping property
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: Improve CONFIG_DMABUF_MOVE_NOTIFY help text
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Fix klocwork issues about data size
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: do not check len & max_len for lri (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gvt: add support to command SWTESS_BASE_ADDRESS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Fix display port type issue (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gvt: Add some regs to force-to-nonpriv whitelist
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: corgi: Convert to use GPIO descriptors
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: pwm_bl: Switch to full GPIO descriptor
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gpu/trace: add a gpu total memory usage tracepoint
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Hook up the helpers to align buffer objects
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Introduce a huge page aligning TTM range manager
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Add a drm_get_unmapped_area() helper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: Support huge page faults (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm, drm/vmwgfx: Support huge TTM pagefaults (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- mm: Add vmf_insert_pfn_xxx_prot() for huge page-table entries
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- mm: Split huge pages on write-notify or COW (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- mm: Introduce vma_is_special_huge (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- fs: Constify vma argument to vma_is_dax (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
  Refresh
  patches.suse/fs-Remove-unneeded-IS_DAX-check-in-io_is_direct.patch.
- drm/omap: Prepare DSS for probing without legacy platform data
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- PCI: Use ioremap(), not phys_to_virt() for platform ROM
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- misc: cleanup minor number definitions in c file into
  miscdevice.h (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- .gitignore: add SPDX License Identifier (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- .gitignore: remove too obvious comments (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mediatek: fix race condition for HDMI jack status reporting
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: support HDMI jack status reporting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mediatek: exit earlier if failed to register audio driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- memremap: add an owner field to struct dev_pagemap
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: Use the DMA API for GMU memory objects
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: Fix CP_MEMPOOL state name (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: devcoredump should dump MSM_SUBMIT_BO_DUMP buffers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a5xx: Always set an OPP supported hardware value
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: fix comparing pointer to 0 in dpu_encoder.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: fix comparing pointer to 0 in dpu_vbif.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: fix comparing pointer to 0 in
  dpu_encoder_phys_vid.c (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: fix comparing pointer to 0 in
  dpu_encoder_phys_cmd.c (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: Remove some set but not used variables
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: Use scnprintf() for avoiding potential buffer overflow
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/msm_gem.h: Replace zero-length array with flexible-array
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: fix leaks if initialization fails (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: avoid double-attaching hdmi/edp bridges (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: Track resources in global state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: Refactor resource manager (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: Refactor rm iterator (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: Remove unused function arguments (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Fix mode private_flags comparison at
  atomic_check (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Stage the transfer of the virtual breadcrumb
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Select the deepest available parking mode for rc6
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Avoid live-lock with i915_vma_parked() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Treat idling as a RPS downclock event
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Cancel a hung context if already closed
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use explicit flag to mark unreachable intel_context
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: Invalidate OA TLB on when closing perf stream
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Check for a closed context when looking up
  an engine (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Restrict gen7 w/a batch to Haswell (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: don't try to reserve training bo for sriov (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu11: add support for SMU AC/DC interrupts
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/swSMU: handle manual AC/DC notifications
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/swSMU: handle DC controlled by GPIO for navi1x
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/swSMU: set AC/DC mode based on the current
  system state (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/swSMU: correct the bootup power source for
  Navi1X (v2) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/swSMU: use the smu11 power source helper for navi1x
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu11: add a helper to set the power source
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/swSMU: add callback to set AC/DC power source (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix the coverage issue to clear ArcVPGRs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix pageflip event race condition for DCN
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/[radeon|amdgpu]: Remove HAINAN board from max_sclk
  override check (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/amdgpu: add CAP fw loading" (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/sriov : Don't resume RLCG for SRIOV guest
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: protect RAS sysfs during GPU reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: Use vmwgfx version 2.18 to signal SM5 compatibility
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Add SM5 param for userspace (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: Add surface define v4 command (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: Refactor surface_define to use vmw_surface_metadata
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Split surface metadata from struct vmw_surface
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Add support for streamoutput with mob commands
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Rename stream output target binding tracker struct
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Add support for indirect and dispatch commands
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Add support for UA view commands (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: Support SM5 shader type in command buffer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Read new register for GB memory when available
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Add a new enum for SM5 graphics context capability
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Sync virtual device headers for new feature
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Use enum to represent graphics context capabilities
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Deprecate logic ops commands (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: Sync legacy multisampling device capability
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Also check for SVGA_CAP_DX before reading DX
  context support (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: fix TS cache flushing on GPUs with BLT engine
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: request pages from DMA32 zone when needed
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: Replace zero-length array with flexible-array
  member (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: Warn when GPU doesn't idle fast enough
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: Ignore MC when checking runtime suspend idleness
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: Consider all kwnown idle bits in debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: Update idle bits (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: Fix typo in comment (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: rework perfmon query infrastructure (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/etnaviv: add hwdb entry for gc400 found in STM32
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: update hwdb selection logic (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/etnaviv: update gc7000 chip identity entry (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/etnaviv: show identity information in debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: determine product, customer and eco id
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: update hardware headers from rnndb (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mediatek: add mt8183 dpi clock factor (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: amd: fix spelling mistake "shoudn't" -> "shouldn't"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Remove unnecessary variable shadow in
  gfx_v9_0_rlcg_wreg (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add CAP fw loading (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- amd/powerplay: arcturus baco reset disable all features
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: miss PRT case when bo update (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: add on demand pipe merge logic for dcn2+
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Allocate scratch space for DMUB CW7
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: DPP DTO isn't update properly (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Remove connect DIG FE to its BE during timing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: combine watermark change and clock change
  for update (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: guard DPPHY_Internal_ctrl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: differentiate vsc sdp colorimetry use criteria
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Program self refresh control register on boot
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove magic numbers in hdcp_ddc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fallback to dmcub for psr when dmcu is disabled
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Set disable_dmcu flag properly per asic
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove PSR dependency on swizzle mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Explicitly disable triplebuffer flips
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Pass triplebuffer surface flip flags down
  to plane (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix split threshold w/a to work with mpo
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: workaround for HDMI hotplug in DPMSOFF state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove redundant hdcp display state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix test pattern color space inconsistency
  for Linux (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: update connector->display_info after read edid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: disable gpu_sched load balancer for vcn jobs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sched: implement and export drm_sched_pick_best
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/scheduler: improve job distribution with multiple
  queues" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Move EEPROM I2C adapter to amdgpu_device
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm_amdgpu: Add job fence to resv conditionally (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix switch-case indentation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: revise RLCG access path (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/scheduler: fix inconsistent locking of job_list_lock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sched: add run job trace (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/swsmu: clean up unused header in swsmu
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add codes to clear AccVGPR for arcturus
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Stop using the DRIVER debugging flag for vblank
  debugging (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Possible divide by zero in set_speed()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: clean up some indenting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: clean up a condition in
  dmub_psr_copy_settings() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: amd/acp: fix broken menu structure (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- AMD KFD: Use fallthrough; (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: Move fallthrough; into containing
  [#]ifdef/#endif (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- AMD POWERPLAY: Use fallthrough; (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- AMD DISPLAY CORE: Use fallthrough; (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix warning in ras_debugfs_create_all()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update ras capability's query based on mem ecc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use amdgpu_ras.h in amdgpu_debugfs.c (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: check GFX RAS capability before reset counters
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: resolve failed error inject msg (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/sriov refine vcn_v2_5_early_init func (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/exynos: Use mode->clock instead of reverse calculating it
  from the vrefresh (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: Use drm_encoder_mask() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Mark up racy check of drm_gem_object.handle_count
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mm: Allow drm_mm_initialized() to be used outside of
  the locks (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Distribute switch variables for initialization
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: lock: Clean up documentation (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: bufs: Clean up documentation (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: vm: Clean up documentation (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: context: Clean up documentation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tiny: fix sparse warning: incorrect type in assignment
  (different (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Convert
  drm_dp_mst_topology_mgr.is_waiting_for_dwn_reply (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Remove drm dp mst destroy_connector callbacks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Add drm_dp_destroy_connector helper and use it
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Remove register_connector callback (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Remove dp mst register connector callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Register connector instead of calling register_connector
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Add function to parse EDID descriptors for
  monitor range (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Name the detailed monitor range flags (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel-simple: Fix dotclock for Logic PD Type 28
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel-sony-acx424akp: Fix dotclocks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel-lg-lg4573: Fix dotclock (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel-ilitek-ili9322: Fix dotclocks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel-novatek-nt35510: Fix dotclock (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: sysfs: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: Use scnprintf() for avoiding potential buffer overflow
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: fix false positive assert (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/rockchip: rgb: don't count non-existent devices when
  determining (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Fix drm_dp_check_mstb_guid() return code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Make drm_dp_mst_dpcd_write() consistent with
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel-simple: Fix dotclock for Ortustech COM37H3M
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: panel: Set connector type for OrtusTech COM43H4M85ULC panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mm: Remove redundant assignment in drm_mm_reserve_node
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: Add YUV420 output support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/meson: vclk: add support for YUV420 setup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/meson: venc: add support for YUV420 setup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/meson: dw-hdmi: stop enforcing input_bus_format
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: meson_dw_hdmi: add bridge and switch to
  drm_bridge_funcs (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: venc: make drm_display_mode const (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: synopsys: dw-hdmi: allow ycbcr420 modes for
  >= 0x200a (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: synopsys: dw-hdmi: add bus format negociation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: dw-hdmi: Plug atomic state hooks to the default
  implementation (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: dw-hdmi: add max bpc connector property
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: dw-hdmi: set mtmdsclock for deep color
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Replace zero-length array with flexible-array member
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Remove a few unused functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: Drop preempt_disable() in vmw_fifo_ping_host()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Refuse DMA operation when SEV encryption is active
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Fix the refuse_dma mode when using guest-backed
  objects (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Update DRIVER_DATE to 20200313 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Remove require_force_probe protection
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add Wa_1605460711 / Wa_1408767742 to ICL and EHL
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Apply Wa_1406680159:icl,ehl as an engine workaround
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add Wa_1406306137:icl,ehl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add Wa_1604278689:icl,ehl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add Wa_1209644611:icl,ehl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftest: Add more poison patterns (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Wait for RCUs frees before asserting idle on unload
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Use igt_random_offset() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Drop relocation slowpath (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gen12: Disable preemption timeout (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Take a copy of the engines for
  context_barrier_task (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Mark up sw-fence notify function (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add missing HDMI audio pixel clocks for gen12
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Mark up the racy read of the mmap_singleton
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Pull checking rps->pm_events under the irq_lock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Extend i915_request_await_active to use all timelines
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/overlay: convert to drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/lvds: convert to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/lpe_audio: convert to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hotplug: convert to drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gmbus: convert to drm_device based logging,
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fifo_underrun: convert to drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsb: convert to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Remove debugfs i915_drpc_info and
  i915_forcewake_domains (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Mark up data-races in virtual engines
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Mark up racy read of active rq->engine (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Mark up racy reads for intel_context.inflight
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Tweak scheduler's kick_submission() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gvt: Wean gvt off using dev_priv (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gvt: Wean gvt off dev_priv->engine (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gvt: cleanup debugfs scan_nonprivbb (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Do not write in removed FBC fence registers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Deactive FBC in fastsets when disabled
  by parameter (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/mst: Hookup DRM DP MST late_register/early_unregister
  callbacks (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Improve the start alignment of bonded pairs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Defend against concurrent updates to
  execlists->active (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Lock gmbus/aux mutexes while changing cdclk
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pass the crtc to the low level read_lut() funcs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix readout of PIPEGCMAX (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Refactor LUT read functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Clean up integer types in color code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: s/chv_read_cgm_lut/chv_read_cgm_gamma/ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: s/blob_data/lut/ (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Split i9xx_read_lut_8() to gmch vs. ilk variants
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Clean up i9xx_load_luts_internal() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Polish CHV CGM CSC loading (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Mark up intel_rps.active for racy reads
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlsts: Mark up racy inspection of current
  i915_request (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Mark up read of i915_request.fence.flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Mark up racy check of last list element
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Mark up unlocked update of i915_request.hwsp_seqno
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Mark up the racy access to
  switch_priority_hint (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Mark racy read of intel_engine_cs.saturated
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Mark up intel_rps.active for racy reads
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Don't treat unslice registers as masked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix documentation for intel_dpll_get_freq()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Wait for the wa batch to be pinned (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Apply a heavy handed flush to i915_active
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Do not poison i915_request.link on removal
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Make Wa_1606700617 permanent (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/hotplug: Use phy to get the hpd_pin instead of
  the port (v5) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: try to rein in alloc_smoke (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/buddy: avoid double list_add (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: properly sanity check batch_start_offset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Limit struct_mutex to eb_reserve (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Always propagate the invocation to i915_schedule
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Assert requests within a context are submitted
  in order (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/phys: unconditionally call release_memory_region
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gen7: Clear all EU/L3 residual contexts (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add mechanism to submit a context WA on ring
  submission (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Show the "switch priority hint" in dumps
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Decrease log level (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Implement display w/a 1140 for glk/cnl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Enable transition watermarks for glk (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Don't check for wm changes until we've compute
  the wms fully (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Don't check uv_wm in skl_plane_wm_equals()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: WaDisableGPGPUMidThreadPreemption (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Cancel banned contexts after GT reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add invert-brightness quirk for Thundersoft
  TST178 tablet (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: panel: Use intel_panel_compute_brightness() from
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Propagate change in error status to children
  on unhold (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Apply i915_request_skip() on submission
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/ehl: Check PHY type before reading DPLL frequency
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Inlcude intel_gvt.h where needed (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Force DPCD backlight mode for some Dell CML
  2020 panels (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Force DPCD backlight mode on X1 Extreme 2nd Gen
  4K AMOLED (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/dp: Introduce EDID-based quirks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/hdcp: Fix config_stream_type() ret value
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hdcp: Mandate (seq_num_V==0) at first RecvId msg
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Only call eb_lookup_vma once during execbuf ioctl
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Extract transient execbuf flags from i915_vma
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Drop inspection of execbuf flags during evict
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Move and restrict Wa_1408615072 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gen11: Moving WAs to rcs_engine_wa_init()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Fix uninitialized variable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Drop vma is-closed assertion on insert (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Check that the context wasn't closed during setup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Prevent allocation on a banned context
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Consolidate ctx->engines release (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Polish CHV .load_luts() a bit (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gvt: only include intel_gvt.h where needed
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: make intel_gvt_active internal to intel_gvt
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/vgpu: improve vgpu abstractions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix kbuild test robot build error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/hdcp: conversion to struct drm_device based
  logging macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: move watermark structs more towards usage
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix doclinks (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dmc: Use firmware v2.06 for TGL (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/huc: update TGL HuC to v7.0.12 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/execlists: Check the sentinel is alone in the ELSP
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Add Wa number to
  WaAllowPMDepthAndInvocationCountAccessFromUMD (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Add note about Wa_1409142259 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Fix the Wa number of a fix (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Add note about Wa_1607063988 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Add note to Wa_1607297627 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Extend Wa_1606931601 for all steppings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Add Wa_1409085225, Wa_14010229206 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Implement Wa_1806527549 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Implement Wa_1409804808 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Unify the DPLL ref clock frequency tracking
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hsw: Use the read-out WRPLL/SPLL state instead of
  reading out again (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/skl, cnl: Split out the WRPLL/LCPLL frequency
  calculation (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hsw: Split out the WRPLL, LCPLL, SPLL frequency
  calculation (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hsw: Split out the SPLL parameter calculation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hsw: Rename the get HDMI/DP DPLL funcs to get
  WRPLL/LCPLL (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/skl: Parametrize the DPLL ref clock instead of
  open-coding it (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move DPLL frequency calculation to intel_dpll_mgr.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hsw: Use the DPLL ID when calculating DPLL clock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move the DPLL vfunc inits after the func defines
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Keep the global DPLL state in a DPLL specific struct
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move DPLL HW readout/sanitize fns to intel_dpll_mgr.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix bounds check in intel_get_shared_dpll_id()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use intel_plane_data_rate for min_cdclk calculation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use a sentinel to terminate the dbuf slice arrays
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add missing commas to dbuf tables (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove garbage WARNs (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Handle some leftover s/intel_crtc/crtc/
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix 90/270 degree rotated RGB565 src coord checks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Use BDB_GENERAL_FEATURES VBT block info for builtin
  panel-orientation (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Remove readback of panel orientation on BYT / CHT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: remove unused orig_clock i915 member (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: add i915_ioc32.h for compat (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dram: hide the dram structs better (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/crc: move pipe_crc from drm_i915_private to intel_crtc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Expose heartbeat interval via sysfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Expose preempt reset timeout via sysfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Expose reset stop timeout via sysfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Expose busywait duration to sysfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Expose timeslice duration to sysfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Expose engine->mmio_base via sysfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Expose engine properties via sysfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Drop WaDDIIOTimeout:glk (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Limit display Wa_1405510057 to gen11 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Nuke pre-production GLK HDMI w/a 1139 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Reset queue_priority_hint after wedging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Be a little more lenient for reset workers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add glk to intel_detect_preproduction_hw()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Wait for the context switch (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/perf: Manually acquire engine-wakeref around use of
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: Mark up the racy use of perf->exclusive_stream
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix wrongly populated plane possible_crtcs bit mask
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Check recovery from corrupted LRC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Verify LRC isolation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Pull marking vm as closed underneath the vm->mutex
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Check engine-is-awake on reset later
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Disable heartbeat around manual pulse tests
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Skip barriers inside waits (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/ggtt: do not set bits 1-11 in gen12 ptes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Set up PIPE_MISC truncate bit on tgl+ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: remove ICP_PP_CONTROL (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/drv: use intel_uncore_write() for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dram: use intel_uncore_*() functions for register
  access (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: split out intel_dram. from i915_drv.c (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: significantly reduce the use of <drm/i915_drm.h>
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Add Wa_1606054188:tgl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Allow DC5/DC6 entry while PG2 is active
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Fix drm_WARN issue where vgpu ptr is unavailable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Make WARN* drm specific where vgpu ptr is
  available (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Make WARN* drm specific where drm_priv ptr
  is available (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: make gvt oblivious of kvmgt data structures
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: remove unused vblank_done completion
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Enable vfio edid for all GVT supported platform
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: remove unused type attributes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix broken num_entries in skl_ddb_allocation_overlaps
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add WARN_ON in intel_get_crtc_for_pipe()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Get first crtc instead of PIPE_A crtc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix broken transcoder err state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove (pipe == crtc->index) assumption
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Iterate over pipes and skip the disabled one
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: split intel_modeset_init() to pre/post irq install
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: stop assigning drm->dev_private pointer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Honour O_NONBLOCK before throttling execbuf
  submissions (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Allow userspace to specify ringsize on construction
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Flush idle barriers when waiting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tegra: hdmi: Silence deferred-probe error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tegra: dc: Silence RGB output deferred-probe error
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: dc: Release PM and RGB output when client's
  registration (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: dc: Use devm_platform_ioremap_resource
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/runpm: disable runpm on Vega10 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: call ras_debugfs_create_all in debugfs_init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add function to creat all ras debugfs node
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: fix the coverity warning about negative check
  for (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Correct the condition of warning while bo release
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Consolidate duplicated bo alloc flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Use pr_debug to print the message of reaching
  event limit (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: do not set nil entry in compute_prio_sched
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove unused functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: change hw sched list on ctx priority override
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/scheduler: implement a function to modify sched list
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: set compute queue priority at mqd_init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add smu if version for navi12 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/display: Fix Pollock Variant Detection
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: fix pci revision id fetching (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Enter low power state if CRTC active (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: dcn20: remove an unused function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.76 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: separate FEC capability from fec debug flag
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: writing stereo polarity register if swapped
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Stop if retimer is not available
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix a minor HDCP logging error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: determine rx id list bytes to read based
  on device (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Program DSC during timing programming
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Not check wm and clk change flag in optimized
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add registry for mem pwr control
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: determine is mst hdcp based on stream instead
  of (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add stay count and bstatus to HDCP log
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Signal eviction fence on process destruction (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: disable clock/power gating for SRIOV (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: cleanup ring/ib test for SRIOV vcn2.0 (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: implement initialization part on VCN2.0 for SRIOV
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: disable jpeg block for SRIOV (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: introduce mmsch v2.0 header (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: Add more comments on GFX9 user CP queue MQD
  workaround (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Use better names to reflect it is CP MQD buffer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Fix GPU reset error (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Update SPM_VMID with the job's vmid when application
  reserves the vmid (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update page retirement sequence (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: toggle DF-Cstate when accessing UMC ras error
  related (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: increase atombios cmd timeout (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable PCS error report on arcturus (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable PCS error report on VG20 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add helper funcs to detect PCS error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add wafl2 ip headers (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add xgmi ip headers (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove pointless NULL checks in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Wrap clflush_cache_range with x86 ifdef
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add support for USBC PD FW download (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Add USBC PD FW load to PSP 11 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Add USBC PD FW load interface to PSP (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add reset_ras_error_count function for HDP
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add reset_ras_error_count function for GFX
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add reset_ras_error_count function for MMHUB
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add reset_ras_error_count function for SDMA
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sriov: Use VF-accessible register for gpu_clock_count
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sriov: skip programing some regs with new L1 policy
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: set lttpr mode before link settings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix default logger mask definition
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add ABM command structs to DMCUB
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.75 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add 'disable FEC for specific monitor'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Set clock optimization required after
  update clocks (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: change number of cursor policy for dml
  calculation (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Disable freesync borderless on Renoir
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove DISPCLK Limit Floor for Certain
  SMU Versions (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Workaround to do HDCP authentication twice on
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix image corruption with ODM 2:1 DSC 2 slice
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: program DPG_OFFSET_SEGMENT for odm_pipe
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add vsc update support for test pattern request
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix typo "to found" -> "to find"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Make clock table struct more accessible
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add worst case dcc meta pitch to fake plane
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: only include FEC overhead if both asic
  and display (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add driver support for enabling PSR on DMCUB
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Move mod_hdcp_displays to mod_hdcp struct
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Link training TPS1 workaround add back in dpcd
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Rearm IRQ in Navi10 SR-IOV if IRQ lost
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: stop using sratch_reg in IB test (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix IB test MCBP bug (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add debugfs interface to set arbitrary sclk
  for navi14 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add lock option for smu_set_soft_freq_range()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: dc_link: code clean up on detect_dp function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: dc_link: code clean up on enable_link_dp
  function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix dmub_psr_destroy() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix indentation issue on a hunk of code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: fix indentation issue (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Write blocked CP registers using RLC on VF
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu: Add message sending lock (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/powerplay: Remove deprecated smc_read_arg
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/powerplay: Refactor SMU message handling for safety
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: release drm_device after amdgpu_driver_unload_kms
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: no need to clean debugfs at amdgpu (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Initialize SPM_VMID with 0xf (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/sriov: Use kiq to copy the gpu clock (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: change SDMA MQD memory type (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: Make get_tile_config() generic (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Add num_banks and num_ranks to gfx config structure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: add case for shmem objects in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: factor out the sg_table from virtio_gpu_object
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Make drm_pci_agp_init legacy (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/panel: simple: Add support for Sharp LQ150X1LG11
  panels" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vboxvideo/vboxvideo.h: Replace zero-length array with
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/pci: Unexport drm_get_pci_dev (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/todo: Update drm_fb_helper tasks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/fb-helper: Remove drm_fb_helper add, add_all and remove
  connector (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Remove drm_fb_helper add, add all and remove connector
  calls (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Remove
  drm_fb_helper_{add,remove}_one_connector (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Remove drm_fb_helper_{add,remove}_one_connector
  calls (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: remove radeon_fb_{add,remove}_connector functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Remove unused arg from drm_fb_helper_init (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: unbreak the DRM menu, broken by DRM_EXPORT_FOR_TESTS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mm: Break long searches in fragmented address spaces
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge/mhl.h: Replace zero-length array with flexible-array
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4/vc4_drv.h: Replace zero-length array with flexible-array
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500/intel_bios.h: Replace zero-length array with
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vblank: Fix documentation of VBLANK timestamp helper
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/simple-kms: Fix documentation for drm_simple_encoder_init()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: add panel driver for Elida KD35T133 panels
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/v3d: Replace wait_for macros to remove use of msleep
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4: Replace wait_for macros to remove use of msleep
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/hdcp: fix DRM_HDCP_2_KSV_COUNT_2_LSBITS (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/hdcp: optimizing the srm handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: Replace zero-length array with flexible-array member
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: radeon: Remove dead code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- matroxfb: add Matrox MGA-G200eW board support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: atyfb: remove set but not used variable
  'mach64RefFreq' (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: kyrofb: remove set but not used variable
  'ulScaleRight' (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: radeonfb: remove set but not used variable 'bytpp'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- =?UTF-8?q?video:=20fbdev:=20radeonfb:=20remove=20set=20but=20not?=
  =?UTF-8?q?=20used=20variable=20'=E2=80=98cSync=E2=80=99'?=
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: radeonfb: remove set but not used variable
  'vSyncPol' (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: radeonfb: remove set but not used variable
  'hSyncPol' (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: wm8505fb: add COMPILE_TEST support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: wm8505fb: fix sparse warnings about using
  incorrect (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: w100fb: add COMPILE_TEST support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: w100fb: fix sparse warnings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: arcfb: add COMPILE_TEST support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: sh_mobile_lcdcfb: add COMPILE_TEST support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: sh_mobile_lcdcfb: fix sparse warnings about using
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: pxa168fb: remove unnecessary platform_get_irq
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/qxl: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Use simple encoder (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/simple-kms: Add drm_simple_encoder_{init,create}()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: simple: add panel-dpi support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: Add driver for Novatek NT35510-based panels
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: prevent a harmless integer overflow in
  drm_legacy_sg_alloc() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/client: Dual licence the file in GPL-2 and MIT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tidss: Drop pointless static qualifier in dispc_find_csc()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tidss: fix spelling mistakes "bufer" and "requsted"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tidss: Use drm_for_each_bridge_in_chain() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tidss: dispc: Fix broken plane positioning code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Check crc4 value while building sideband message
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Fix W=1 warnings (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panfrost: default_supplies can be static (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma-buf: make move_notify mandatory if importer_ops are provided
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: drop dynamic_mapping flag (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: implement amdgpu_gem_prime_move_notify v2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add amdgpu_dma_buf_pin/unpin v2 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: use allowed_domains for exported DMA-bufs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: remove the backing store if no placement is given
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: add dynamic DMA-buf handling v15 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: simple: Add NewEast Optoelectronics CO., LTD
  WJFH116008A (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: anx6345: don't print error message if regulator is
  not (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: add virtio_gpu_is_shmem helper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: make mmap callback consistent with callbacks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/hisilicon: Fixed pcie resource conflict between drm
  and firmware (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/hisilicon: Set preferred mode resolution and maximum
  resolution (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/hisilicon: Add the mode_valid function (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/hisilicon: fixed the wrong resolution configurations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/hisilicon: Enable the shadowfb for hibmc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/hisilicon: Add new clock/resolution configurations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: dss: Remove unused omap_dss_device operations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: dss: Remove unused omapdss_of_find_connected_device()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: dss: Inline the omapdss_display_get() function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: Hardcode omap_connector type to DSI (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: sdi: Register a drm_bridge (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: sdi: Sort includes alphabetically (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: dpi: Register a drm_bridge (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: dpi: Simplify clock setting API (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: dpi: Reorder functions in sections (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: dpi: Sort includes alphabetically (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: hdmi5: Simplify EDID read (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: hdmi4: Simplify EDID read (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: venc: Remove omap_dss_device operations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: hdmi: Remove omap_dss_device operations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: Remove HPD, detect and EDID omapdss operations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: Switch the HDMI and VENC outputs to drm_bridge
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: Create connector for bridges (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: venc: Register a drm_bridge (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: dss: Remove .set_hdmi_mode() and .set_infoframe()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: hdmi4: Implement drm_bridge .hpd_notify() operation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: hdmi5: Move mode set, enable and disable operations to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: hdmi4: Move mode set, enable and disable operations to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: hdmi5: Register a drm_bridge for EDID read
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: hdmi4: Register a drm_bridge for EDID read
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: hdmi5: Rework EDID read to isolate data read
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: hdmi4: Rework EDID read to isolate data read
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: hdmi: Allocate EDID in the .read_edid() operation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: dss: Make omap_dss_device_ops optional (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: Add infrastructure to support drm_bridge local to DSS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: dss: Fix output next device lookup in DT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: Use the drm_panel_bridge API (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: Factor out display type to connector type conversion
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: Simplify HDMI mode and infoframe configuration
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: dss: Cleanup DSS ports on initialisation failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Add helper to create a connector for a chain of bridges
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: tfp410: Allow operation without drm_connector
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: tfp410: Replace manual connector handling
  with bridge (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: panel: Implement bridge connector operations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add driver for the TI TPD12S015 HDMI level shifter
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add bridge driver for display connectors
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: simple-bridge: Add support for the TI OPA362
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: simple-bridge: Add support for enable GPIO
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: simple-bridge: Add support for non-VGA bridges
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: dumb-vga-dac: Rename driver to simple-bridge
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: dumb-vga-dac: Rename internal symbols to
  simple-bridge (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Extend bridge API to disable connector creation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add interlace_allowed flag to drm_bridge
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add connector-related bridge operations and data
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Improve overview documentation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: Fix atomic state ops documentation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: Document the drm_encoder.bridge_chain field
  as private (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Add flag to drm_display_info to identify HDMI sinks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/connector: Add helper to get a connector type name
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: hdmi: Change return type of hdmi_avi_infoframe_init()
  to void (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panfrost: Add support for multiple power domains
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panfrost: Add support for multiple regulators
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panfrost: Improve error reporting in panfrost_gpu_power_on
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: panel: Propagate bus format/flags (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: lvds-codec: Constify the drm_bridge_funcs structure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: lvds-codec: Add to_lvds_codec() function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: enqueue virtio_gpu_create_context after the first 3D
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: track whether or not a context has been initiated
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: factor out context create hypercall (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: use consistent names for drm_files (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: ld9040: add MODULE_DEVICE_TABLE with SPI IDs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: simple: fix osd070t1718_19ts sync drive edge
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: tcon: Support LVDS on the A33 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: analogix-anx6345: Avoid duplicate -supply suffix
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: analogix-anx78xx: Fix drm_dp_link helper removal
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: drop legacy drm load and unload callbacks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: don't call
  drm_dp_mst_connector_late_register (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/display: split dp connector registration (v4)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: add a late register connector callback
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: move dpcd debugfs members setup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/display: move debugfs init into core amdgpu
  debugfs (v2) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: don't call drm_connector_register for non-MST ports
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/ring: move debugfs init into core amdgpu debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/firmware: move debugfs init into core amdgpu debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/regs: move debugfs init into core amdgpu debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gem: move debugfs init into core amdgpu debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/fence: move debugfs init into core amdgpu debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sa: move debugfs init into core amdgpu debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/pm: move debugfs init into core amdgpu debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/ttm: move debugfs init into core amdgpu debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: rename amdgpu_debugfs_preempt_cleanup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Increase timout on emulator to tenfold instead
  of twice (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add DFCstate control pptable func for arct
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update arcturus ppsmc header to 54.15.0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Delete unnecessary unmap queue package submissions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Delete excessive printings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: Fix a memory leak in queue creation error handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Count active CP queues directly (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: Avoid ambiguity by indicating it's cp queue
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Rename queue_count to active_queue_count
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd: Extend ROCt to surface UUID for devices that have them
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Fix check for DPM when returning max clock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Don't write GCVM_L2_CNTL* regs on navi12 VF
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: Use bitwise instead of arithmetic operator
  for (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove set but not used variable
  'mc_vm_apt_default' (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: Add gfxoff debugfs entry (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: use amdgpu_ring_test_helper when possible
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add VM update fences back to the root PD v2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: cleanup amdgpu_ring_fini (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Add Arcturus D342 page retire support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: toggle DF-Cstate to protect DF reg access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: move get_xgmi_relative_phy_addr to amdgpu_xgmi.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add dpm helper function for DF Cstate control
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update psp firmwares loading sequence V2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Remove kfd eviction fence before release bo (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: limit display clock to 100MHz to avoid
  FIFO error (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Access patches from stream for ignore
  MSA monitor (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Temporarily disable stutter on MPO transition
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Make clock table struct more accessible
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: optimize prgoram wm and clks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: correct dml surface size assignment
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Update TTU properly (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix RV2 Variant Detection (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add driver support for enabling PSR on DMCUB
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.74 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove unused dml variable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: update dml input population function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add visual confirm support for FreeSync 2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Link training TPS1 workaround (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Monitor patch to delay setting ignore MSA bit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Workaround required for link training
  reliability (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Revert "DCN2.x Do not program DPPCLK if
  same value" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DMUB firmware state debugfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: programming last delta in output transfer
  function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: make some rn_clk_mgr structs and funcs static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add function pointers for panel related
  hw functions (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix HDMI repeater authentication
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.73 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Only round InfoFrame refresh rates
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: System crashes when add_ptb_to_table()
  gets called (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: do not force UCLK DPM to stay at highest state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add dmcu f/w loading for NV12 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Don't ask PSP to load DMCUB for backdoor load
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Wait for DMCUB to finish loading before
  executing (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Disable PG on NV12 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: DMUB Firmware Load by PSP (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: dmub back door load (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Update TX masks correctly (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: update scaling filters (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: dal_ddc_i2c_payloads_create can fail
  causing panic (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add aconnector condition check for dpcd read
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Improve Vega20 XGMI TLB flush workaround
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix psp ucode not loaded in bare-metal
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/discovery: make the discovery code less chatty
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix colliding of preemption (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: cleanup some incorrect reg access for SRIOV
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: drop the non-sense firmware version check on
  arcturus (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: record non-zero error counter info in NBIO before
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: log on non-zero error conter per IP before GPU reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Don't take the address of skip_scdc_overwrite
  in (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: correct the way for checking
  SMU_FEATURE_BACO_BIT (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: return -EFAULT if copy_to_user() fails
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display move get_num_odm_splits() into dc_resource.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: extend DCN guards (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/display: extend DCN guard in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/powerplay: Ratelimit PP_ASSERT warnings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix message for encryption (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: update HDCP DTM immediately after hardware
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: no hdcp retry if bksv or ksv list is revoked
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Handle revoked receivers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/runpm: enable runpm on baco capable VI+ asics
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: refactor runtime pm for baco (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: show warning when kfd is locked (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Fix missing error check in suspend (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Remove set but not unused variable
  'stream_status' (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/powerplay: fix baco check for vega20 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/smu: properly handle runpm/suspend/reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add flag for runtime suspend (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Do not move root PT bo to relocated list
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: suppress nonsupport profile mode overrun
  message (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: update smu11_driver_if_navi10.h
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use fb_base/fb_offset if available for
  translation (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add psr get_state call (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: add monitor patch to disable SCDC read/write
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add odm split logic to scaling calculations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.72 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Drop unused field from dc_panel_patch
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Update register defines (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Toggle VSR button cause system crash
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add backlight support via AUX (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add AUX backlight register (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Hookup psr set version call (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Pass override OUI in to dc_init_data
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove unused values from psr struct
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Don't treat missing command table as failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: always apply T7/T9 delay logic (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/sriov set driver_table address in VF (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: use amdgpu_device_vram_access in
  amdgpu_ttm_access_memory v2 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use amdgpu_device_vram_access in
  amdgpu_ttm_vram_read (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use the BAR if possible in amdgpu_device_vram_access
  v2 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: optimize amdgpu_device_vram_access a bit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: handle features disablement for baco reset in
  SMU (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sriov Don't send msg when smu suspend (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix wrongly passed static prefix
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Add queue information to sysfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: turn off the mst hub before we do detection
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix workaround for incorrect double buffer
  register (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: linux enable oled panel support dc part
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: external monitor abm enabled in modern standby
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DMUB tracebuffer debugfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: 3.2.71 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use uint64_t logger_mask instead of uint32_t
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add wm ranges to clk_mgr (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Check hyperV flag in DC (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix inputting clk lvl into dml for RN
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: decouple global lock out of pipe control lock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add stream_enc_inst for PSP HDCP inst use
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Update hubbub description comment
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove early break in interdependent_lock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: dc_get_vmid_use_vector() crashes when
  get called (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.70 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove unused variable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix GSL acquire (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Added locking for atomic update stream
  and update (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Wait for clean shutdown in DMCUB reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add GPINT handler interface (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix various issues found by compiler warning as
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Indicate dsc updates explicitly (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Split program front end part that occur
  outside lock (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove invalid dc_is_hw_initialized function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Move USB-C workaround to after parameter
  variables (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add set psr version message (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: move xgmi init/fini to xgmi_add/remove_device
  call (v2) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: call psp set/get interfaces (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Load srm before enabling HDCP (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add sysfs interface for set/get srm
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: update psp interface header (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Pass amdgpu_device instead of psp_context
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: rework synchronization of VM updates v4
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: simplify and fix amdgpu_sync_resv (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: allow higher level PD invalidations (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: return EINVAL instead of ENOENT in the VM code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix parentheses in amdgpu_vm_update_ptes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: make sure to never allocate PDs/PTs for
  invalidations (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: drop unnecessary restriction for huge root PDEs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: stop using amdgpu_bo_gpu_offset in the VM backend
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: rework job synchronization v2 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: use the VM as job owner (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: explicitly sync VM update to PDs/PTs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Update DRIVER_DATE to 20200225 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Drop assertion that active->fence is unchanged
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Cleanup shadow batch after I915_EXEC_SECURE
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Update DRIVER_DATE to 20200224 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Correctly terminate connector iteration
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Fix inverted WARN_ON (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display/hdcp: Make WARN* drm specific where
  drm_priv ptr is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/dp: Make WARN* drm specific where drm_device
  ptr is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/power: Make WARN* drm specific where
  drm_priv ptr is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/display: Make WARN* drm specific where
  drm_device (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/ddi: Make WARN* drm specific where drm_device
  ptr is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/cdclk: Make WARN* drm specific where
  drm_priv ptr is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Distribute switch variables for initialization
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: make dbuf configurations const (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: split i915_driver_modeset_probe() to pre/post
  irq install (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: remove redundant assignment to variable dw
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Push the GPU cancellation to the backend
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Check that the vma hasn't been closed before we insert
  it (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: conversion to struct drm_device based
  logging macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Program MBUS_ABOX{1,2}_CTL during display init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use intel_de_write_fw() for skl+ scaler registers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Parametrize PFIT_PIPE (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Mark all HPD capabled connectors as such
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hpd: Replace the loop-within-loop with two
  independent loops (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add i9xx_lut_8() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uc: consolidate firmware cleanup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/uc: Abort early on uc_init failure (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/guc: Apply new uC status tracking to GuC submission
  as well (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uc: Improve tracking of uC init status (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/uc: autogenerate uC checker functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/uc: Update the FW status on injected fetch error
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: Kill USES_GUC_SUBMISSION macro (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/guc: Kill USES_GUC macro (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/debugfs: Pass guc_log struct to i915_guc_log_info
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Double check bumping after the spinlock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Protect signaler walk with RCU (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: remove the other slab_dependencies (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dp: Add all tiled and port sync conns to modeset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Compute port sync crtc states post compute_config()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Introduce encoder->compute_config_late()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Do not attempt to reprogram IA/ring frequencies
  for dgfx (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Mark GPR checking more hostile
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftest: Analyse timestamp behaviour across context
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Read rawclk_freq earlier (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Refactor l3cc/mocs availability (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: split i915_driver_modeset_remove() to pre/post
  irq uninstall (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: split intel_modeset_driver_remove() to pre/post
  irq uninstall (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: use spinlock_t instead of struct spinlock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Show the cumulative context runtime in engine debug
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Flush tasklet on wait_for_submit()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Fix up missing error propagation for heartbeat
  pulses (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Check for any sign of request starting in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Add Wa_1808121037 to tgl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/csr: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Mark the mock ring->vma as being in the GGTT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Rearrange code to silence compiler (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: switch vlv_suspend to use intel uncore register
  accessors (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: split out vlv/chv specific suspend/resume code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Avoid potential division-by-zero in computing
  CS timestamp (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Track hw reported context runtime (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Force state->modeset=true when distrust_bios_wm==true
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Ensure no conflicts with BIOS when updating Dbuf
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/mst: Set intel_dp_set_m_n() for MST slaves
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Check for the error interrupt before
  we wait! (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: split out display debugfs to a separate file
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: move intel_csr. under display/ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: switch i915_driver_probe() to use i915 local variable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: register vga switcheroo later, unregister earlier
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hdmi: prefer to_i915() over drm->dev_private to
  get at i915 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Exercise timeslice rewinding (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Suppress warnings for unused debugging locals
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use engine wa list for Wa_1607090982 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Expand bad CS completion event debug
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Avoid choosing zero for phys_sz
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Sabotague the RING_HEAD (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Poison rings after use (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Don't leak non-persistent requests on changing
  engines (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix the docs for intel_set_cdclk_post_plane_update()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Don't use uninitialized 'ret' (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Disable use of hwsp_cacheline for kernel_context
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Relax timeout for error-interrupt reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dpio_phy: convert to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi_vbt: convert to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/combo_phy: convert to struct drm_device logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dpll_mgr: convert to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/crt: automatic conversion to drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/color: conversion to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/atomic: conversion to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp_link_training: convert to drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: HDCP support on above PORT_E (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Skip CPU synchronisation on dmabuf attachments
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Trim blitter block size (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Update cdclk voltage level settings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dc3co: Add description of how it works (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Drop live_preempt_hang (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Disable capturing forced error states
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/ehl: Add HBR2 and HBR3 voltage swing table
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/psr: pass i915 to psr_global_enabled() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/mst: fix pipe and vblank enable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Remove erroneous intel_engine_pm_put
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Ignore tracek for nop process_csb
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Fix hold/unhold recursion (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove lite restore defines (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Never allow userptr into the new mapping types
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/debugfs: Remove i915_energy_uJ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Only ignore already reset requests (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Implement Wa_1607090982 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Disable tesselation clock gating on tgl A0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Use the kernel_context to measure the
  breadcrumb size (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix force-probe failure message (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/guc: Make sure to sanitize CT status (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Protect execlists_hold/unhold from new waiters
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/i915: Don't use VBT for detecting DPCD backlight
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: drop igt_ppgtt_exhaust_huge (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Set TRANS_DDI_MODE_SELECT to default value
  when clearing DDI select (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Set the PP_DIR registers upon enabling ring
  submission (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Flush execution tasklets before checking request
  status (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Mark i915.reset as unsigned (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Correctly map DBUF slices to pipes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Manipulate DBuf slices properly (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Introduce parameterized DBUF_CTL (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Update dbuf slices only with full modeset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move dbuf slice update to proper place (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove skl_ddl_allocation struct (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Be explicit in handling the preallocated vma
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Explicitly cleanup initial_plane_config
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hdcp: move update pipe code to hdcp (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Fix rc6 on Ivybridge (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Sprinkle missing commas (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dvo: Mark TMDS DVO connectors as polled (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Mark ns2501 as LVDS without a fixed mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/crt: Configure connector->polled and encoder->hpd_pin
  consistently (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Introduce intel_connector_hpd_pin() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Pull sseu context updates under gt (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftest: Ensure string fits within name
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Add a simple rollover test for the
  kernel context (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Defer application of initial chv_phy_control
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Fix NULL-crtc deref in calc_min_cdclk()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/audio: Skip the cdclk modeset if no pipes attached
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pci: conversion to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/cmd_parser: conversion to struct drm_device
  logging macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/debugfs: conversion to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: conversion to drm_device logging macros when
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/panel: automatic conversion to drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pipe_crc: automatic conversion to drm_device
  based logging (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/psr: automatic conversion to drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/quirks: automatic conversion to drm_device based
  logging (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/sdvo: automatic conversion to drm_device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/sprite: automatic conversion to drm_device based
  logging (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tc: automatic conversion to drm_device based
  logging macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tv: automatic conversion to drm_device based
  logging macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/vdsc: convert to struct drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/vga: conversion to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/vlv_dsi: conversion to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/vlv_dsi_pll: conversion to struct drm_device
  logging macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Make WARN* drm specific where drm_device ptr
  is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/tc: Make WARN* drm specific where drm_priv ptr
  is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/sdvo: Make WARN* drm specific where
  drm_priv ptr is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/psr: Make WARN* drm specific where drm_priv ptr
  is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/panel: Make WARN* drm specific where
  drm_priv ptr is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/overlay: Make WARN* drm specific where drm_priv
  ptr (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/hdmi: Make WARN* drm specific where drm_device
  ptr (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbdev: Make WARN* drm specific where drm_device ptr is
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/fbc: Make WARN* drm specific where drm_priv ptr
  is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/dpll_mgr: Make WARN* drm specific where
  drm_device (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Warn about the hidden i915_vma_pin in
  timeline_get_seqno (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Hold reference to previous active fence as we queue
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/crt: Make WARN* drm specific where drm_priv ptr
  is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/audio: Make WARN* drm specific where
  drm_priv ptr is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/icl_dsi: Make WARN* drm specific where drm_priv
  ptr (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move ringbuffer WAs to engine workaround list
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Skip rmw for masked registers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: extract engine WA programming to common resume
  function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: Introduce guc_is_ready (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Disable heartbeat around hang tests
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Also wait for the scratch buffer to be bound
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Also use async bind for PIN_USER into bsw/bxt ggtt
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Store active_pipes bitmask in cdclk state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Convert cdclk to global state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Introduce intel_calc_active_pipes() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Convert bandwidth state to global state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Introduce better global state handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Move intel_atomic_state_free() into intel_atomic.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: s/init_cdclk/init_cdclk_hw/ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: swap() the entire cdclk state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Extract intel_cdclk_state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Simplify intel_set_cdclk_{pre,post}_plane_update()
  calling convention (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: s/cdclk_state/cdclk_config/ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: s/need_cd2x_updare/can_cd2x_update/ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Collect more cdclk state under the same roof
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move more cdclk state handling into the cdclk code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Nuke skl wm.dirty_pipes bitmask (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Move linetime wms into the crtc state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Polish WM_LINETIME register stuff (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: move intel_dp_set_m_n() to encoder for DDI platforms
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Enable ICL DSI transcoder as part of
  encoder->enable (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: move pipe, pch and vblank enable to encoders on DDI
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/debugfs: remove VBT data about DRRS (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Use the async worker to avoid reclaim tainting the
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Rename i915_gem_restore_ggtt_mappings() for its new
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: __intel_fbc_cleanup_cfb() may be called
  multiple times (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Skip global serialisation of clear_range for bxt
  vtd (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/ring: convert to new logging macros in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: convert to new logging macros in gt/intel_gt.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/engine_cs: use new drm logging macros in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/reset: conversion to new drm logging macros in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/ggtt: use new drm logging macros in gt/intel_ggtt.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: add extra slice common debug registers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/execlists: Ignore discrepancies in pending across
  resets (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Hook up CS_MASTER_ERROR_INTERRUPT (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/execlist: Mark up racy read of execlists->pending
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests/perf: measure memcpy bw between regions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/debugfs: remove i915_dpcd file (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/psr: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hdcp: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display_power: use intel_de_*() functions for register
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/ddi: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/combo_phy: use intel_de_*() functions for register
  access (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/icl_dsi: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Lock the drm_mm as we search (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/trace: i915_request.prio is a signed value
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Lift set-wedged engine dumping out of user paths
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Tidy repetition in declaring gen8+ interrupts
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Reorganise gen8+ interrupt handler (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Skip capturing errors from internal contexts
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: Fix OA context id overlap with idle context id
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Restore the kernel context after verifying the w/a
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/vlv_dsi_pll: use intel_de_*() functions for
  register access (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/vlv_dsi: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/vdsc: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/sprite: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/psr: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pipe_crc: use intel_de_*() functions for register
  access (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Give aux channels a better name (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Include the AUX CH name in the debug messages
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/vga: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tv: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/sdvo: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/panel: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/overlay: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/lvds: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/lpe_audio: use intel_de_*() functions for register
  access (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hdmi: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gmbus: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fifo_underrun: use intel_de_*() functions for register
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dvo: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsb: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp_mst: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dpll_mgr: use intel_de_*() functions for register
  access (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dpio_phy: use intel_de_*() functions for register
  access (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/crt: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/color: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/cdclk: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/audio: use intel_de_*() functions for register access
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Prefer intel_connector over drm_connector in
  hotplug code (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix modeset locks in sanitize_watermarks()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix inconsistance between pfit.enable and scaler
  freeing (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Remove 'prefault_disable' modparam (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Squelch kerneldoc complaints (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: manual conversion to struct drm_device
  logging macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: initial conversion to new logging macros using
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pm: use intel de functions for forcewake register
  access (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/irq: use intel de functions for forcewake register
  access (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dmc: use intel uncore functions for forcewake
  register access (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hdcp: conversion to struct drm_device based
  logging macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/opregion: conversion to struct drm_device logging
  macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: conversion to struct drm_device logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/power: convert to struct drm_device macros in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: conversion to struct drm_device log macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: conversion to new struct drm_device
  logging macros (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: Don't GEM_BUG_ON on corrupted H2G CTB
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Re-enable RPS (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Poison GTT scratch pages (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Flush engine parking before release (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/ehl: Ensure that the DDI selection MUX is programmed
  correctly (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dc3co: Avoid full modeset when EXITLINE needs to
  be changed (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dc3co: Do the full calculation of DC3CO exit only once
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/acpi: Move the code to populate ACPI device ID into
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Wait on vma activity before taking the mutex
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Prevent NULL pointer dereference on missing
  ctx->vm (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Show the RC6 residency on parking failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Do not set master_trans bit in bitmak if
  INVALID_TRANSCODER (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/cdclk: use new struct drm_device logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/bw: convert to drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/audio: convert to struct drm_device logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/bios: convert to struct drm_device logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/atomic: use struct drm_device logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: add display engine uncore helpers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Cleanup properly if the implicit fence setup fails
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Balance prepare_fb/cleanup_fb (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: s/intel_state/state/ in
  intel_{prepare,cleanup}_plane_fb() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Stop looking at plane->state in
  intel_prepare_plane_fb() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Clear old hw.fb & co. from slave plane's state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Convert vm idr to xarray (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Include a tell-tale for engine parking
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Make WARN* drm specific where uncore or stream ptr is
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Make WARN* drm specific where drm_priv ptr is
  available (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Make WARN* drm specific where drm_priv ptr
  is available (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Make WARN* drm specific where drm_priv ptr
  is available (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Make WARN* drm specific where encoder ptr is
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Clear the GGTT_WRITE bit on unbinding the vma
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Don't use VBT for detecting DPCD backlight controls
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: drop alpha_support for good in favour of force_probe
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/hdcp: Clean up local variables (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Rename conn_to_dig_port() to intel_attached_dig_port()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use intel_attached_dp() instead of hand rolling it
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Relocate intel_attached_dp() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Use intel_attached_encoder() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dp: debug log max vswing and pre-emphasis
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: use intel_bios_is_port_present() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/bios: check DDI port presence based on child device
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/bios: add intel_bios_port_supports_*() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/bios: add intel_bios_alternate_ddc_pin()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/bios: add intel_bios_dp_max_link_rate() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/bios: intel_bios_hdmi_boost_level() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/bios: intel_bios_dp_boost_level() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/bios: add intel_bios_hdmi_level_shift() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/bios: add intel_bios_max_tmds_encoder() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/sdvo: Consolidate SDVO HDMI force_dvi handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Consolidate HDMI force_dvi handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/sdvo: Reduce the size of the on stack buffers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move encoder variable to tighter scope (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Use PIPE_CONF_CHECK_X() for sync_mode_slaves_mask
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Prefer to use the pipe to index the ddb entries
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Clear most of crtc state when disabling the crtc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Be paranoid and reset the GPU before release
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/userptr: add user_size limit check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Report the currently active execlists request
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: convert to new logging macros in
  i915/intel_memory_region.c (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: convert to new logging macros in i915/intel_gvt.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: conversion to new logging macros in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: conversion to new logging macros in i915/intel_csr.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: conversion to new logging macros in i915/i915_vgpu.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: Introduce CT_DEBUG (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: Switch to CT_ERROR in ct_read (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/guc: Don't pass CTB while reading (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/guc: Don't pass CTB while writing (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/guc: Don't GEM_BUG_ON on corrupted G2H CTB
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Satisfy smatch that a loop has at least one iteration
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix typo in kerneldoc function name (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Include the debugfs params header for its own
  definition (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Auto detect DPCD backlight support by default
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix DPCD register order in
  intel_dp_aux_enable_backlight() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Assume 100%% brightness when not in DPCD control mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix eDP DPCD aux max backlight calculations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/psr: Share the computation of idle frames
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: add Wa_14010594013: icl,ehl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Drop rogue space in the middle of GT_TRACE
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Add Wa_1409825376 to tgl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Add fbc tracepoints (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: Nuke fbc_supported() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Move the plane state check into the fbc functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/params: support bool values for int and uint params
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/params: add i915 parameters to debugfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gen11: Add additional pcode status values
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/vbt: Rename BDB_LVDS_POWER to BDB_LFP_POWER
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp/tgl+: Update combo phy vswing tables (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/guc: Use correct name for last CT fence (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/guc: Update CTB helpers to use CT_ERROR (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/guc: Introduce CT_ERROR (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: Simpler CT message size calculation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Clear rc6 residency trackers across suspend
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: tcon: Support LVDS output on Allwinner A20
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: tcon: Separate quirks for tcon0 and tcon1 on A20
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: tcon: Introduce LVDS setup routine setting
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: dsi: Avoid hotplug race with DRM driver bind
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Fix the bridge kernel doc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: move remaining virtio_gpu_notify calls
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: batch display query (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: batch resource creation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: batch plane updates (pageflip) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: notify before waiting (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: rework notification for better batching
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: Fix a typo in Kconfig (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/format_helper: Dual licence the file in GPL 2 and MIT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: fix recovering from PLBU out of memory (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/pl111: Support Integrator IM-PD1 module (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: drop unused drm_display_mode.private (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: drop unused drm_crtc callback (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/print: clean up RATELIMITED macros (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/atomic-helper: fix kerneldoc (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Add a FIXME about DispID CEA data block revision
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Document why we don't bounds check the DispID CEA
  block start/end (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Clear out spurious whitespace (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/edid: Introduce is_detailed_timing_descritor()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Don't accept any old garbage as a display descriptor
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Check the number of detailed timing descriptors in
  the CEA ext block (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mcde: Fix Sphinx formatting (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/print: Delete a few unused shouting macros (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/sun4i: dsi: Remove incorrect use of runtime PM
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: dsi: Allow binding the host without a panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: dsi: Use NULL to signify "no panel" (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/sun4i: dsi: Remove unused drv from driver context
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: fix error check (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Add support for DP 1.4 Compliance edid corruption test
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Remove legacy version of get_scanout_position()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Clean-up VBLANK-related callbacks in struct drm_driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Convert to CRTC VBLANK callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vkms: Convert to CRTC VBLANK callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: Convert to CRTC VBLANK callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: Convert to struct (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/sti: Convert to CRTC VBLANK callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/stm: Convert to CRTC VBLANK callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/stm: Convert to struct
  drm_crtc_helper_funcs.get_scanout_position() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Convert to CRTC VBLANK callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Convert to struct (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: Convert to CRTC VBLANK callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/radeon: Convert to struct (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: Convert to CRTC VBLANK callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau: Convert to struct (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Convert to CRTC VBLANK callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gma500: Convert to CRTC VBLANK callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Convert to CRTC VBLANK callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Convert to struct (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Add get_vblank_timestamp() to struct drm_crtc_funcs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Add get_scanout_position() to struct drm_crtc_helper_funcs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Remove internal setup of struct
  drm_device.vblank_disable_immediate (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: fix virtio_gpu_execbuffer_ioctl locking
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/qxl: replace zero-length array with flexible-array member
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/hisilicon/hibmc: add gamma_set function (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/hisilicon/hibmc: add DPMS on/off function (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/hisilicon/hibmc: fix 'xset dpms force off' fail
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Avoid invalid rates (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Train at faster rates if slower
  ones fail (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Group DP link training bits in
  a function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Use 18-bit DP if we can
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Read num lanes from the DP sink
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Config number of DP lanes Mo' Betta
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Don't use MIPI variables for DP link
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: zero is never greater than an unsigned
  int (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-sn65dsi86: Split the setting of the dp and
  dsi rates (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: individualize resv objects before calling
  release_notify (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: replace dma_resv object on deleted BOs v3
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: rework BO delayed delete. v2 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: add drm_driver.release callback (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/cirrus: add drm_driver.release callback (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bochs: add drm_driver.release callback (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/irq: remove check on dev->dev_private (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: simple: Add Rocktech RK101II01D-CT panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Nerf drm_global_mutex BKL for good drivers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Push drm_global_mutex locking in drm_open (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/client: Rename _force to _locked (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/fbdev-helper: don't force restores (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: use RCU in ttm_bo_flush_all_fences (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: cleanup ttm_buffer_object_transfer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: refine ghost BO resv criteria (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/qxl: add drm_driver.release callback (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/qxl: reorder calls in qxl_device_fini() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: fix possible object reference leak (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: dmm_tiler: Remove the dma_async_issue_pending() call
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: dmm_tiler: Use dmaengine_prep_dma_memcpy() for i878
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/omapdrm: Fix trivial spelling (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/omap: use true,false for bool variable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: tfp410: add pclk limits (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: move virtio_gpu_mem_entry initialization to
  new function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: move mapping teardown to virtio_gpu_cleanup_object()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: resource teardown tweaks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: simplify virtio_gpu_alloc_cmd (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bochs: deinit bugfix (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: panel: Fix typo in drm_panel_bridge_add docs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge/synopsys: dsi: missing post disable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: sii902x: Select SND_SOC_HDMI_CODEC if SND_SOC is
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add tc358768 driver (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: bridge: adv7511: Add support for ADV7535 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: bridge: adv7511: Remove DRM_I2C_ADV7533 Kconfig
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Clear struct drm_connector_funcs.dpms (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bochs: Clear struct drm_connector_funcs.dpms (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tiny/st7735r: No need to set ->owner for
  spi_register_driver() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tiny/st7735r: Make driver OF-independent (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tiny/repaper: No need to set ->owner for
  spi_register_driver() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tiny/repaper: Make driver OF-independent (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tiny: add support for tft displays based on ilitek,ili9486
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: fix ring free check (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: move virtqueue_notify into virtio_gpu_queue_ctrl_sgs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: move the check for vqs_ready earlier (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: move locking into virtio_gpu_queue_ctrl_sgs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: set up virtqueue sgs before locking (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: unlock object array on errors (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: no need to pass virtio_gpu_ctrl_hdr (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: add virtio_gpu_vbuf_ctrl_hdr (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: remove incorrect ENOSPC check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: fix a wait_event condition (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: ratelimit error logging (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vboxvideo: Implement struct drm_mode_config_funcs.mode_valid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/hibmc: Implement struct drm_mode_config_funcs.mode_valid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bochs: Implement struct drm_mode_config_funcs.mode_valid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vram: Add helpers to validate a display mode's memory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: fix vblank handling (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Remove the dma_alloc_coherent wrapper for internal usage
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Remove PageReserved manipulation from drm_pci_alloc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/stm: dsi: stm mipi dsi doesn't print error on probe deferral
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/stm: ltdc: check crtc state before enabling LIE
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/stm: ltdc: add number of interrupts (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: simple: Fix the lt089ac29000 bus_format
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/imx: pd: Use bus format/flags provided by the bridge when
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add the necessary bits to support bus format
  negotiation (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add an ->atomic_check() hook (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: Patch atomic hooks to take a drm_bridge_state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: analogix: Plug atomic state hooks to the default
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rcar-du: Plug atomic state hooks to the default
  implementation (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add a drm_bridge_state object (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: Add Samsung s6e88a0-ams452ef01 panel driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: simple: Add EDT panel support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/xen: Explicitly disable automatic sending of vblank event
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: Remove sending of vblank event (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vboxvideo: Remove sending of vblank event (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Don't set struct drm_crtc_state.no_vblank explicitly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/st7586: Remove sending of vblank event (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/repaper: Remove sending of vblank event (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/qxl: Remove sending of vblank event (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mipi-dbi: Remove sending of vblank event (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ili9225: Remove sending of vblank event (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gm12u320: Remove sending of vblank event (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/cirrus: Remove sending of vblank event (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bochs: Remove sending of vblank event (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Don't set struct drm_crtc_state.no_vblank explicitly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/arc: Remove sending of vblank event (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Initialize struct drm_crtc_state.no_vblank from device
  settings (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/auth: Drop master_create/destroy hooks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/crc: Actually allow to change the crc source (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/zte: plane_state->fb iff plane_state->crtc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vkms: plane_state->fb iff plane_state->crtc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: plane_state->fb iff plane_state->crtc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/rockchip: plane_state->fb iff plane_state->crtc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/imx: plane_state->fb iff plane_state->crtc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/todo: Add item for the plane->atomic_check confusion
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tidss: New driver for TI Keystone platform Display SubSystem
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: increase driver version to 1.1 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: recover task by enlarging heap buffer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: support heap buffer creation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: add lima_vm_map_bo (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: update register info (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/debugfs: also take per device driver features into account
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: add drm_core_check_all_features() to check for a mask
  of features (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: Fix boe,tv101wum-n53 htotal timing (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Avoid drm_global_mutex for simple inc/dec of
  dev->open_count (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Release filp before global lock (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: simple: add display timings for logic technologies
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/print: introduce new struct drm_device based WARN* macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Mention max_payloads in proposed_vcpis/payloads docs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Fix clearing payload state on topology disable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Fix indenting in drm_dp_mst_topology_mgr_set_mst()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add I2C based driver for ps8640 bridge
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: flush the fence on the bo after we individualize the
  reservation object (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/drm_dp_mst:remove set but not used variable 'origlen'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panfrost: Prefix interrupt handlers' names (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panfrost: Remove core stack power management (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/syncobj: Add documentation for timeline syncobj
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: tiny: st7735r: Add support for Okaya RH128128T
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: tiny: st7735r: Prepare for adding support for more displays
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mipi_dbi: Add support for display offsets (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: fix parameters documentation style in drm_dma
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mst: Some style improvements in
  drm_dp_mst_topology_mgr_set_mst() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/dp_mst: Remove VCPI while disabling topology mgr"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: Add Feixin K101 IM2BA02 panel (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: support for auo, b101uan08.3 wuxga dsi video
  mode panel (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: support for boe, tv101wum-n53 wuxga dsi video
  mode panel (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: support for auo, kd101n80-45na wuxga dsi video
  mode panel (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: support for boe tv101wum-nl6 wuxga dsi video
  mode panel (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: nuke invalidate_caches callback (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: nvidia: clean up indentation issues and
  comment block (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- fbdev: remove object duplication in Makefile (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: exynos: Rename Exynos to lowercase (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- fbdev: cg14fb: use resource_size (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- fbdev: s1d13xxxfb: use resource_size (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: sa1100fb: constify copied structure (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- fbmem: Adjust indentation in fb_prepare_logo and fb_blank
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- fbcon: Adjust indentation in set_con2fb_map (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- pxa168fb: fix release function mismatch in probe failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- OMAP: DSS2: remove non-zero check on variable r (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: Fix Kconfig indentation (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: ssd1307fb: add the missed regulator_disable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- fbdev: potential information leak in do_fb_ioctl()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Add getfb2 ioctl (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: simple: Add support for the Frida FRD350H54004 panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: Add missing vmalloc header (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/rockchip: use DIV_ROUND_UP macro for calculations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/drm_panel: fix export of drm_panel_of_backlight, try #3
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: panel: fix excessive stack usage in td028ttec1_prepare
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/connector: Hookup the new drm_cmdline_mode panel_orientation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/connector: Split out orientation quirk detection (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: always determine branch device with drm_dp_is_branch()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: move DP_MAX_DOWNSTREAM_PORTS from i915 to drm core
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix two documentation mismatch issues
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- fbdev/g364fb: Fix build failure (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- fbdev: c2p: Use BUILD_BUG() instead of custom solution
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: i915: Call cpu_latency_qos_*() instead of pm_qos_*()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- PM: QoS: Add CPU latency QoS API wrappers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- docs: gpu: i915.rst: fix warnings due to file renames
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- commit 22a7131
* Sun Nov  8 2020 tiwai@suse.de
- mfd: wcd934x: Add support to wcd9340/wcd9341 codec
  (jsc#SLE-16518).
- Update config files.
- commit a6ab479
* Sun Nov  8 2020 tiwai@suse.de
- mfd: wcd934x: Simplify with dev_err_probe() (jsc#SLE-16518).
- mfd: wcd934x: Drop kfree for memory allocated with devm_kzalloc
  (jsc#SLE-16518).
- gpio: wcd934x: Fix logic of wcd_gpio_get (jsc#SLE-16518).
- gpio: wcd934x: Don't change gpio direction in wcd_gpio_set
  (jsc#SLE-16518).
- gpio: wcd934x: Add support to wcd934x gpio controller
  (jsc#SLE-16518).
- commit 6f31bff
* Sun Nov  8 2020 tiwai@suse.de
- ASoC: codecs: wcd934x: Set digital gain range correctly
  (git-fixes).
- ASoC: SOF: loader: handle all SOF_IPC_EXT types (git-fixes).
- ASoC: codecs: wsa881x: add missing stream rates and format
  (git-fixes).
- ASoC: mediatek: mt8183-da7219: fix DAPM paths for rt1015
  (git-fixes).
- ALSA: hda: Reinstate runtime_allow() for all hda controllers
  (git-fixes).
- ALSA: hda: Separate runtime and system suspend (git-fixes).
- ALSA: hda: Refactor codec PM to use direct-complete optimization
  (git-fixes).
- commit 8e08376
* Sun Nov  8 2020 tiwai@suse.de
- ASoC: codecs: wcd9335: Set digital gain range correctly
  (git-fixes).
- ASoC: cs42l51: manage mclk shutdown delay (git-fixes).
- ASoC: qcom: sdm845: set driver name correctly (git-fixes).
- ASoC: Intel: kbl_rt5663_max98927: Fix kabylake_ssp_fixup
  function (git-fixes).
- ALSA: usb-audio: Add implicit feedback quirk for Qu-16
  (git-fixes).
- ALSA: usb-audio: Add implicit feedback quirk for MODX
  (git-fixes).
- ALSA: usb-audio: add usb vendor id as DSD-capable for Khadas
  devices (git-fixes).
- ALSA: hda/realtek - Enable headphone for ASUS TM420 (git-fixes).
- ALSA: hda: prevent undefined shift in
  snd_hdac_ext_bus_get_link() (git-fixes).
- ALSA: hda/realtek - Fixed HP headset Mic can't be detected
  (git-fixes).
- ALSA: usb-audio: Add implicit feedback quirk for Zoom UAC-2
  (git-fixes).
- ALSA: fix kernel-doc markups (git-fixes).
- commit 91a799a
* Sat Nov  7 2020 pjakobsson@suse.de
- Refresh
  patches.suse/drm-iommu-change-type-of-pasid-to-u32.patch.
- commit bede6dd
* Sat Nov  7 2020 pjakobsson@suse.de
- drm/scheduler: fix rare NULL ptr race (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- blacklist.conf: unblacklist backported drm v.5.6 patches
- drm/prime: use dma length macro when mapping sg (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Handle all MCR ranges (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/i915/tgl: Add extra hdc flush workaround"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Track active elements during dequeue
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix pageflip event race condition for DCN
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix typo for vcn2.5/jpeg2.5 idle check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix typo for vcn2/jpeg2 idle check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix typo for vcn1 idle check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add link_rate quirk for Apple 15" MBP 2017
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add fbdev suspend/resume on gpu reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: Fix GPR read from debugfs (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix typos for dcn20_funcs and dcn21_funcs
  struct (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/lease: fix WARNING in idr_destroy (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/komeda: mark PM functions as __maybe_unused (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: dw-hdmi: fix AVI frame colorimetry (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Rewrite and fix bandwidth limit checks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Reprobe path resources in CSN handler
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Use full_pbn instead of available_pbn for bandwidth
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Rename drm_dp_mst_is_dp_mst_end_device() to be less
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Defer semaphore priority bumping to a workqueue
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Close race between cacheline_retire and free
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Enable timeslice on partial virtual engine
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: be more solid in checking the alignment
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Fix dma-buf display blur issue on CFL
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Return early for await_start on same timeline
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Actually emit the await_start (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gvt: Fix emulated vbt size issue (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gvt: Fix unnecessary schedule timer when no vGPU exits
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/powerplay: nv1x, renior copy dcn clock settings of
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: correct ROM_INDEX/DATA offset for VEGA20
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: update soc bb for nv14 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/exynos: Fix cleanup of IOMMU related objects (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- backlight: add led-backlight driver (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- vgacon: Fix a UAF in vgacon_invert_region (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/display: navi1x copy dcn watermark clock settings to
  smu (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: map mclk to fclk for COMBINATIONAL_BYPASS
  case (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: fix pre-check condition for setting
  clock range (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix dcc swath size calculations on dcn1
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Clear link settings on MST disable connector
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: disable 3D pipe 1 on Navi1x (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: clean wptr on wb when gpu recovery (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Drop the timeline->mutex as we wait for retirement
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: Reintroduce wait on OA configuration completion
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Fix return in assert_mmap_offset()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Protect i915_request_await_start from early waits
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Add Wa_1608008084 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Add Wa_22010178259:tgl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Program MBUS with rmw during initialization
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/psr: Force PSR probe only after full initialization
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Break up long lists of object reclaim
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: kirin: Revert "Fix for hikey620 display offset problem"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: Fix DE2 VI layer format support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/sun4i: Add separate DE3 VI layer formats (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/sun4i: de2/de3: Remove unsupported VI layer formats
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/shmem: drop pgprot_decrypted() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: fix mmap page attributes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/shmem: add support for per object caching flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: analogix-anx6345: fix set of link bandwidth
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: fix leaking fences via ttm_buffer_object_transfer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panfrost: Don't try to map on error faults (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: fix resource id creation race (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mediatek: Handle component type MTK_DISP_OVL_2L correctly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Make sure previous message done or be aborted
  before (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Move gce event property to mutex device node
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Add fb swap in async_update (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mediatek: Add plane check in async_check function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Ensure the cursor plane is on top of other
  overlays (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Find the cursor plane instead of hard coding it
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: hdmi: don't leak enable HDMI_EN regulator if
  probe fails (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: dsi: fix workaround for the legacy clock name
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: dsi: propagate error value and silence meaningless
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Fix orphan vgpu dmabuf_objs' lifetime
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: Separate display reset from ALL_ENGINES reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Avoid recursing onto active vma from the shrinker
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pmu: Avoid using globals for PMU events (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/pmu: Avoid using globals for CPU hotplug state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gtt: Downgrade gen7 (ivb, byt, hsw) back to
  aliasing-ppgtt (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: fix header test with GCOV (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/radeon: Inline drm_get_pci_dev (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Drop DRIVER_USE_AGP (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- amdgpu/gmc_v9: save/restore sdpif regs during S3 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: fix memory leak during TDR test(v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Avoid resetting ring->head outside of its
  timeline mutex (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Always force a context reload when rewinding
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Wean off drm_pci_alloc/drm_pci_free (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Protect defer_request() from new waiters
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Prevent queuing retire workers on the virtual
  engine (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsc: force full modeset whenever DSC is enabled
  at probe (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/ehl: Update port clock voltage level requirements
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Update drm/i915 bug filing URL (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Initialise basic fence before acquiring seqno
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Require per-engine reset support for
  non-persistent (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panfrost: perfcnt: Reserve/use the AS attached to the
  perfcnt MMU (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panfrost: Remove set but not used variable 'bo'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/modes: Allow DRM_MODE_ROTATE_0 when applying video mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/modes: Make sure to parse valid rotation value from cmdline
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: ti-tfp410: Update drm_connector_init_with_ddc()
  error (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: tc358767: fix poll timeouts (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/kms/gv100-: Re-set LUT after clearing for modesets
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/tu11x: initial support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/acr/tu11x: initial support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: fix BGR565 vs RGB565 confusion (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dsi/pll: call vco set rate explicitly (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dsi: save pll state before dsi host is powered off
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: Fix a6xx GMU shutdown sequence (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/a6xx: Update the GMU bus tables for sc7180
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: Remove unneeded GBIF unhalt (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: msm: Fix return type of dsi_mgr_connector_mode_valid
  for kCFI (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/a6xx: Correct the highestbank configuration
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- msm:disp:dpu1: add UBWC support for display on SC7180
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/mdp5: rate limit pp done timeout warnings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: clean up hdcp workqueue handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add is_raven_kicker judgement for raven1
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx10: disable gfxoff when reading rlc clock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx9: disable gfxoff when reading rlc clock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/soc15: fix xclk for raven (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: always refetch the enabled features status on
  dpm (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix dtm unloading (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix backwards byte order in rx_caps
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Mark the removal of the i915_request from the
  sched.link (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Reclaim the hanging virtual request
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Take a reference while capturing the guilty
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Offline error capture (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Allow temporary suspension of inflight requests
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Keep track of request among the scheduling lists
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gvt: more locking for ppgtt mm LRU list (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gvt: fix high-order allocation failure on late load
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Tighten checks and acquiring the mmap object
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix preallocated barrier list append (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Acquire ce->active before
  ce->pin_count/ce->pin_mutex (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Tighten atomicity of i915_active_acquire vs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Stub out i915_gpu_coredump_put (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Check activity on i915_vma after confirming
  pin_count==0 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Detect overflow in calculating dumb buffer size
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Don't show the blank process name for
  internal/simulated (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Store mmap_offsets in an rbtree rather than
  a plain (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Leave resetting ring to intel_ring
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Use the BIT when checking the flags, not the index
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Add a mock i915_vma to the mock_ring
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Make a copy of the ggtt view for slave plane
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Take local vma references for the parser
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pmu: Correct the rc6 offset upon enabling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix i915_error_state_store error defination
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/bios: Fix the timing parameters (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dsi: Ensure that the ACPI adapter lookup overrides the
  bus (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix post-fastset modeset check for port sync
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Lookup the i2c bus from ACPI NS only if
  CONFIG_ACPI=y (v2) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu:/navi10: use the ODCAP enum to index the caps array
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update smu_v11_0_pptable.h (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: correct comment to clear up the confusion
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: DCN2.x Do not program DPPCLK if same value
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Don't map ATOM_ENABLE to ATOM_INIT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn2.5: fix warning (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: limit GDS clearing workaround in cold boot sequence
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix amdgpu pmu to use hwc->config instead of
  hwc->conf (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- amdgpu: Prevent build errors regarding soft/hard-float
  FP ABI tags (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn2.5: fix DPG mode power off issue on instance 1
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add initialitions for PLL2 clock source
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Limit minimum DPPCLK to 100MHz (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Check engine is not NULL before acquiring
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use dcfclk to populate watermark ranges
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Do not set optimized_require to false
  after plane (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix psr static frames calculation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: fix building error (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vgem: Close use-after-free race in vgem_gem_create
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: Set dma maximum segment size for mdss (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panfrost: Make sure the shrinker does not reclaim referenced
  BOs (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mst: Fix possible NULL pointer dereference in
  drm_dp_mst_process_up_req() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/sun4i: drv: Allow framebuffer modifiers in
  mode config" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/dm/mst: Ignore payload update failures (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: update default voltage for boot od table for navi1x
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu10: fix smu10_get_clock_by_type_with_voltage
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu10: fix smu10_get_clock_by_type_with_latency
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: handle multiple numbers of fclks in
  dcn_calcs.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fetch default VDDC curve voltages (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu_v11_0: Correct behavior of restoring default
  tables (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/navi10: add OD_RANGE for navi overclocking
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/navi: fix index for OD MCLK (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix HW/SW state mismatch (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix a typo when computing dsc configuration
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: fix navi10 system intermittent reboot issue
  V2 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Fix a bug in SDMA RLC queue counting under HWS mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Only enable cursor on pipes that need it
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/navi10: add mclk to
  navi10_get_clock_by_type_with_latency (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Fix implicit enum conversion in
  gfx_v9_4_ras_error_inject (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- radeon: completely remove lut leftovers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Move drm_dp_mst_atomic_check() to the front of
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- radeon: insert 10ms sleep in dce5_crtc_load_lut (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix spelling mistake link_integiry_check ->
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- amdgpu: using vmalloc requires includeing vmalloc.h
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: allocate entities on demand (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Enable DISABLE_BARRIER_WAITCNT for Arcturus
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: fix spelling mistake "Attemp" -> "Attempt"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix for-loop with incorrectly sized loop
  counter (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable GPU reset by default on renoir
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable GPU reset by default on Navi (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: do not allocate display_mode_lib unnecessarily
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add coreboot workaround for KV/KB (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Revert "drm/amd/display: Don't skip link training for
  empty dongle" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Retrain dongles when SINK_COUNT becomes
  non-zero (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: original raven doesn't support full asic reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: attempt to enable gfxoff on more raven1 boards (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: fix spelling mistake "to" -> "too"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: use true, false for bool variable in
  smu7_hwmgr.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix doc by clarifying sched_list definition
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: initialize bo_va_list when add gws to process
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn: use inst_idx relacing inst (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/vcn: fix typo error (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn: fix vcn2.5 instance issue (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/vcn2.5: fix a bug for the 2nd vcn instance (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn: Share vcn_v2_0_dec_ring_test_ring to vcn2.5
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Use the correct flush_type in flush_gpu_tlb_pasid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Fix TLB invalidation request when using semaphore
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: use odm combine for YCbCr420 timing with
  h_active (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: init hw i2c speed (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: changed max_downscale_src_width to 4096
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: support VSC SDP update on video test
  pattern request (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Check hw_init state when determining if DMCUB
  is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Reset inbox rptr/wptr when resetting DMCUB
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Call ATOM_INIT instead of ATOM_ENABLE for DMCUB
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add hardware reset interface for DMUB service
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix update type for multiple planes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix rotation_angle to use enum values
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.69 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Refine i2c frequency calculating sequence
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Refactor to remove diags specific rgam func
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix DML dummyinteger types mismatch
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Do DMCUB hw_init before DC (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fixed comment styling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: check pipe_ctx is split pipe or not
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fallback to DMCUB when command table is missing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Get fb base and fb offset for DMUB from
  registers (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add debug option to disable DSC support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Do not send training pattern if VS Different
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: update MSA and VSC SDP on video test
  pattern request (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: individualize fence allocation per entity
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/amdgpu: fix modprobe failure of the secondary GPU
  when GDDR6 training enabled(V5)" (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix VRAM partially encroached issue in GDDR6 memory
  training(V2) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove unnecessary conversion to bool
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add RAS support for the gfx block of Arcturus
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add EDC counter registers of gc for Arcturus
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: abstract EDC counter clear to a separated function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: refine the security check for RAS functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable RAS feature for more mmhub sub-blocks
  of Acrturus (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update mmhub 9.4.1 header files for Acrturus
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: read gfx register using RREG32_KIQ macro
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add kiq version interface for RREG32/WREG32
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: provide a generic function interface for
  reading/writing register by KIQ (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: added support to get mGPU DRAM base (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: modify packet size for pm4 flush tlbs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/gv100-: avoid sending a core update until
  the first (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/gv100-: move window ownership setup into
  modesetting (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp/gv100-: halt (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- gpu: host1x: Set DMA direction only for DMA-mapped buffer
  objects (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: Reuse IOVA mapping where possible (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tegra: Relax IOMMU usage criteria on old Tegra
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: sor: Initialize runtime PM before use (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tegra: sor: Disable runtime PM on probe failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: sor: Suspend on clock registration failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- proc: convert everything to "struct proc_ops" (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- mm, drm/ttm: Fix vm page protection handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- mm: Add a vmf_insert_mixed_prot() function (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- clk: mux: Add support for specifying parents via DT/pointers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: qcom-wled: Fix unsigned comparison to zero
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: bd6107: Convert to use GPIO descriptor
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- backlight: ams369fg06: Drop GPIO include (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- mm, tree-wide: rename put_user_page*() to unpin_user_page*()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/via: set FOLL_PIN via pin_user_pages_fast() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/fb/gp102-: allow module to load even when
  scrubber binary (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/acr: return error when registering LSF if ACR not
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp/gv100-: not all channel types support reporting
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp/nv50-: prevent oops when no channel method map
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: support synchronous pushbuf submission
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: signal pending fences when channel has been killed
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: reject attempts to submit to dead channels
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: zero vma pointer even if we only unreference
  it rather (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: Add HD-audio component notifier support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: fix build error without CONFIG_IOMMU_API
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv04: remove set but not used variable 'width'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50: remove set but not unused variable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/mmu: fix comptag memory leak (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/gr/gp10b: Use gp100_grctx and gp100_gr_zbc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/pmu/gm20b,gp10b: Fix Falcon bootstrapping
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: Rename Exynos to lowercase (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/exynos: change callback names (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Use VM_PFNMAP instead of VM_MIXEDMAP when possible
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Bump driver minor version (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: add ioctl for messaging from/to guest userspace
  to/from (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: prevent memory leak in vmw_cmdbuf_res_add
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: drop DRM_AUTH for render ioctls (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: check master authentication in surface_ref ioctls
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: move the require_exist handling together
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Replace deprecated PTR_RET (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: Call vmw_driver_{load,unload}() before registering
  device (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vmwgfx: Don't use the HB port if memory encryption is active
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: Fix error about comments within a comment block
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: allow zapfw to not be specified in gpulist
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: support firmware-name for zap fw (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: Allow UBWC on NV12 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: msm: Quiet down plane errors in atomic_check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: update LANE_CTRL register value from default value
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: add DSI support for sc7180 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dsi: split clk rate setting and enable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: use BUG_ON macro for debugging (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/adreno: Do not print error on "qcom, gpu-pwrlevels"
  absence (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: Remove unneeded semicolon in dpu_encoder.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: Remove unneeded semicolon in dpu_plane.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/mdp5: Remove unneeded semicolon (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/hdmi: Remove unneeded semicolon (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: msm: mdp4: Adjust indentation in mdp4_dsi_encoder_enable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: Remove unnecessary NULL checks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: Remove unreachable code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: Remove unnecessary NULL check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: Remove unnecessary NULL checks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: msm: a6xx: Dump GBIF registers, debugbus in gpu state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: msm: a6xx: Add support for A618 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: msm: Add 618 gpu to the adreno gpu list (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dsi: Delay drm_panel_enable() until
  dsi_mgr_bridge_enable() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- msm:disp:dpu1: Fix core clk rate in display driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- msm:disp:dpu1: add scaler support on SC7180 display
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- msm:disp:dpu1: add mixer selection for display topology
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- msm:disp:dpu1: setup display datapath for SC7180 target
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- msm:disp:dpu1: add support for display for SC7180 target
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- msm: disp: dpu1: add support to access hw irqs regs depending on
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: Add UBWC support for RGB8888 formats
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/dpu: Mark various data tables as const (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/a4xx: set interconnect bandwidth vote (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/a3xx: set interconnect bandwidth vote (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/gpu: add support for ocmem interconnect path
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/adreno: fix zap vs no-zap handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/a6xx: restore previous freq on resume (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm/dpu: ignore NULL clocks (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mst: Don't do atomic checks over disabled managers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: skip opp blank or unblank if test pattern
  enabled (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.68 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: reallocate MST payload when link loss
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fixup DML dependencies (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Use mdelay to avoid context switch
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Only program surface flip for video plane
  via dmcub (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Enable double buffer for OTG_BLANK
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add monitor patch for AUO dpcd issue
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: wait for test pattern after when all pipes are
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: make PSR static screen entry within 30 ms
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.67 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove psr state condition when psr exit case
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: implement fw-driver interface for abm 2.4
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add default switch case for DCC (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Use SMU ClockTable Values for DML Calculations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: rename _lvp to l_vp (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add w/a to reset PHY before link training in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix DMUB PSR command IDs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Refactor surface flip programming
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Indirect reg read macro with shift and mask
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: DMCUB FW Changes to support PSR (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: programing surface flip by dmcub
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Double buffer dcn2 Gamut Remap (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Driverside changes to support PSR in DMCUB
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix double buffering in dcn2 ICSC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.66 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: expand dml structs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: stop doing unnecessary detection when going to
  D3 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: wait for update when setting dpg test pattern
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Update HDMI hang w/a to apply to all
  TMDS signals (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Don't always set pstate true if dummy latency =
  0 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: store lttpr mode with dpcd (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add double buffering to dcn20 OCSC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Soft reset DMUIF during DMUB reset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Read inst_fb data back during DMUB loading
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Flush framebuffer data before passing to DMCUB
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Adding forgotten hubbub func (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Disable secondary link for certain monitors
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix 300Hz Freesync bug (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix chroma vp wa corner case (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: 3.2.65 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Clear state after exiting fixed active
  VRR state (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/include: Add OCSC registers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/scheduler: fix documentation by replacing rq_list with
  sched_list (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add arcturus to gpu recovery check code path
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: check if driver should try recovery in ras
  recovery path (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: a quick fix for the deadlock issue below
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: only set cp active field for kiq queue
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Add a message when SW scheduler is used
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/pm: clean up return types (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/scheduler: improve job distribution with multiple queues
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn2.5: implement indirect DPG SRAM mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn2.5: add dpg pause mode (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/vcn2.5: add DPG mode start and stop (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/vcn: move macro from vcn2.0 to share amdgpu_vcn (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn: support multiple instance direct SRAM read
  and write (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn: support multiple-instance dpg pause mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sriov skip the update of
  SMU_TABLE_ACTIVITY_MONITOR_COEFF (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix modprobe failure of the secondary GPU when
  GDDR6 training enabled(V5) (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx10: update gfx golden settings for navi14
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx10: update gfx golden settings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: check rlc_g firmware pointer is valid before using
  it (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: drop amdgpu_job.owner (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: error out on entity with no run queue
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: use map_queues for hiq on gfx v10 as well
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: use kiq to load the mqd of hiq queue for gfx v9 (v6)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: flush TLB functions removal from kfd2kgd interface
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: GPU TLB flush API moved to amdgpu_amdkfd
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: export function to flush TLB via pasid
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: replace kcq enable/disable functions on gfx_v9
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: implement tlbs invalidate on gfx9 gfx10
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: kiq pm4 function implementation for gfx_v9
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Avoid reclaim fs while eviction lock (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/debugfs: properly handle runtime pm (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/pm: properly handle runtime pm (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add header file for macro SZ_1M (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: remove unnecessary conversion to bool
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/psp: declare navi1x ta firmware (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Match TC hash settings to DF settings (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add defines for DF and TCP Hashing (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Create generic DF struct in adev (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: add Pollock IDs, fix Pollock & Dali clk mgr
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: preserve RSMU UMC index mode state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: disable XGMI TA unload for arcturus (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: update SMU12_DRIVER_IF_VERSION to 11
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gmc10: free stolen memory in late_init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gmc10: remove dead code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/display: set gpu vm flag for renoir (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable S/G display on PCO and RV2 (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: set gpu vm flag for all asics which support
  it (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx9: remove unused sdma headers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/amdgpu: add missing umc_6_1_2_sh_mask.h header file (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: check sdma ras funcs pointer before accessing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: calculate MCUMC_ADDRT0 per asic's UMC offset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add MCUMC_ADDRT0 offset to ip header file
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/powerplay: fix warning in smu_v11_0.c (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: sw ctf for arcturus (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/sriov: workaround on rev_id for Navi12 under sriov
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Don't disable DP PHY when link loss happens
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: read sdma edc counter to clear the counters
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add ras_late_init and ras_fini for sdma v4
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: support error reporting for sdma ip block
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add query_ras_error_count function for sdma v4
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable VCN2.5 IP block for Arcturus (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/vcn2.5: fix PSP FW loading for the second instance
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: catch amdgpu_irq_add_id failure (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: cover the powerplay implementation details V3
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Improve function get_sdma_rlc_reg_offset() (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: Use u64 divide macro for round up division
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Update DRIVER_DATE to 20200114 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Always reset the timeslice after a context switch
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix too few arguments to function
  i915_capture_error_state (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix multiple definition of 'i915_vma_capture_finish'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use the passed in encoder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Pass intel_encoder to enc_to_*() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Pass intel_connector to intel_attached_*()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Bump up CDCLK to eliminate underruns on TGL
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Correct typo in i915_vma_compress_finish stub
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uc: Add sanitize to to intel_uc_ops (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/uc: Add init/fini to to intel_uc_ops (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/uc: Add init_fw/fini_fw to to intel_uc_ops
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uc: Add ops to intel_uc (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Hold rpm wakeref before taking ggtt->vm.mutex
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Parse the I2C element from the VBT MIPI sequence
  block (v3) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Drop request list from error state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Drop the shadow ring state from the error capture
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Drop the shadow w/a batch buffer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Start chopping up the GPU error capture
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Skip trying to unbind in restore_ggtt_mappings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uncore: use new struct drm_device based macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/sideband: convert to using new struct drm_device
  logging (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/lmem: use new struct drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pm: use new struct drm_device logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pch: convert to using the drm_dbg_kms() macro
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gtt: add missing include file asm/smp.h (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Pass cpu_transcoder to assert_pipe_disabled() always
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix MST disable sequence (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: use true,false for bool variable in intel_crt.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: use true,false for bool variable in intel_dp.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: use true,false for bool variable in i915_debugfs.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: runtime-pm is no longer required for ce->ops->pin()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Pull context activation into central
  intel_context_pin() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Push context state allocation earlier
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pin the context as we work on it (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Revert "drm/i915/tgl: Wa_1607138340" (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Reduce warning for i915_vma_pin_iomap() without
  runtime-pm (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Early return for no-op i915_vma_pin_fence()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Drop a defunct timeline assertion (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Fix warning about MST and DDI restrictions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/icl+: Do not program clockgating
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Force the state compute phase once to enable
  PSR (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Always force restore freshly pinned contexts
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gtt: split up i915_gem_gtt (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Take responsibility for engine->release as
  the last step (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Use external dependency loop for port sync
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: fix an error code in intel_modeset_all_tiles()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Gen-12 display can decompress surfaces
  compressed by the media engine (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/fb: Extend format_info member arrays to handle four planes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/framebuffer: Format modifier for Intel Gen-12 media
  compression (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Make sure plane dims are correct for UV CCS planes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add debug message for FB plane.offset!=0 error
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Make sure a semiplanar UV plane is tile row
  size aligned (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add support for non-power-of-2 FB plane alignment
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Use memset_p to clear the ports (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Drop mutex serialisation between context pin/unpin
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Convert the final GEM_TRACE to GT_TRACE and co
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Merge i915_request.flags with i915_request.fence.flags
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Impose a timeout for request submission
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Fixup sparse __user annotation on local var
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Create dumb buffer from LMEM (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: lookup for mem_region of a mem_type (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Compare user mmap against GPU
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Extend fault handler selftests to all memory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Extend mmap support for lmem (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Make headers self-contained (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Move igt_atomic_section out of the header
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Support discontiguous lmem object maps
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Always poison the kernel_context image before
  unparking (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Discard stale context state from across idling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Ignore stale context state upon resume
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Clear LRC image inline (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Include a bunch more rcs image state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Control panel and backlight enable GPIOs on BYT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Move Crystal Cove PMIC panel GPIO lookup from mfd
  to the i915 driver (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Init panel-enable GPIO to low when the LCD
  is initially (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Move poking of panel-enable GPIO to
  intel_dsi_vbt.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Flush ongoing retires during wait_for_idle
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Single page objects are naturally contiguous
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: reimplement header test feature (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Drop local vma->vm_file reference (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Introduce remap_io_sg() to prefault discontiguous
  objects (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Assume future platforms will inherit TGL's SFC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Tweak flushes around ivb ppgtt (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Leave RING_BB_STATE to default value
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Flush the context worker (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Avoid using the GPU before initialisation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Avoid using tag 0 for the very first submission
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Ensure that all new contexts clear STOP_RING
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drn/i915: Break up long i915_buddy_free_list() with a
  cond_resched() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Disable Port sync mode correctly on teardown
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Make port sync mode assignments only if all
  tiles present (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Make sure all tiled connectors get added to
  the state with full modeset (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/fbdev: Fallback to non tiled mode if all tiles not present
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Handle connector tile support only for modes that match
  tile size (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: prefer 3-letter acronym for tigerlake (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: prefer 3-letter acronym for ivybridge (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: prefer 3-letter acronym for broadwell (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: prefer 3-letter acronym for ironlake (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: prefer 3-letter acronym for icelake (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: prefer 3-letter acronym for cannonlake (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: prefer 3-letter acronym for skylake (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: prefer 3-letter acronym for haswell (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: prefer 3-letter acronym for pineview (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: simplify prefixes on device_info (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/lmem: debugfs for LMEM details (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Restore very early GPU reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Extend Wa_1408615072 to tgl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Extend WaDisableDARBFClkGating to icl,ehl,tgl
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Err out on coherency if initialisation
  failed (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Ignore incomplete engines after init failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Apply sanitiization just before resume
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Stop poking at engine->serial at a high level
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add spaces before compound GEM_TRACE (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Switch context id allocation directly to xarray
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Flush other retirees inside
  intel_gt_retire_requests() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: cleanup intel_bw_state on i915 module removal
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Tidy up checking active timelines during retirement
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Add comment to a function that probably
  can be removed (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/mst: Force modeset on MST slaves when master needs
  a modeset (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Prepare for fastset external dependencies
  check (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Fix MST disable sequence (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Always enables MST master pipe first
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Select master transcoder for MST stream
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Share intel_connector_needs_modeset()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/tu10x: initial support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/acr/tu10x: initial support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/core: remove previous versioned fw loader
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/secboot: remove (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/acr: implement new subdev to replace "secure boot"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fb/gp102-: unlock VPR as part of FB init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/core/memory: add macros to read/write blocks
  from objects (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/secboot: move code to boot LS falcons to subdevs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/msgq: rename msgq-related nvkm_msgqueue_queue
  to (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/msgq: pass explicit message queue pointer
  to recv() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/msgq: move handling of init message to subdevs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/msgq: drop nvkm_msgqueue argument to functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/msgq: switch to falcon queue printk macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/msgq: simplify msg_queue_pop() error handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/msgq: remove error handling for
  msg_queue_open(), it (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/cmdq: move command generation to subdevs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/cmdq: rename cmdq-related nvkm_msqqueue_queue
  to (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/cmdq: implement a more explicit send()
  interface (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/cmdq: drop nvkm_msgqueue argument to functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/cmdq: switch to falcon queue printk macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/cmdq: cmd_queue_close always commits, simplify
  it (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/cmdq: cmd_queue_push can't fail, remove error
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/cmdq: split the condition for queue
  readiness vs pmu (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/qmgr: rename remaining nvkm_msgqueue bits to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/qmgr: support syncronous command submission
  from (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/qmgr: allow arbtrary priv + return code for
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/qmgr: move sequence tracking from nvkm_msgqueue
  to (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/msgq: explicitly create message queue
  from subdevs (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/cmdq: explicitly create command queue(s) from
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn/qmgr: explicitly create queue manager
  from subdevs (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn: split msgqueue into multiple pieces
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn: add printk macros (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/flcn: reset sec2/gsp falcons harder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/flcn: specify queue register offsets from subdev
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn: specify debug/production register offset from
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn: specify EMEM address from subdev
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn: move bind_context WAR out of common code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn: specify FBIF offset from subdev
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvenc: add a stub implementation for the GPUs where
  it (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvdec/gm107-: add missing engine instances
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvdec/gm107: rename from gp102 implementation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvdec: initialise SW state for falcon from
  constructor (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/nvdec: select implementation based on available fw
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/sec2: move interrupt handler to hw-specific module
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/sec2: use falcon funcs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/sec2: initialise SW state for falcon from
  constructor (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/sec2: select implementation based on available
  firmware (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/sec2/gp108: split from gp102 implementation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/gf100-: initialise SW state for falcon from
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/gf100-: select implementation based on available
  FW (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/gp108: split from gp107 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/gr/gf100-: move fecs/gpccs ucode into their
  substructures (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/gf100-: drop fuc_ prefix on sw init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/gk20a,gm200-: use nvkm_firmware_load_blob
  for sw init (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/gf100-: use nvkm_blob structure for fecs/gpccs fw
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/pmu: initialise SW state for falcon from constructor
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/pmu: select implementation based on available
  firmware (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/pmu/gp10b: split from gm20b implementation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gsp: initialise SW state for falcon from constructor
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gsp: select implementation based on available
  firmware (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/acr: add loaders for currently available LS firmware
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/acr: add stub implementation for all GPUs currently
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/core: define ACR subdev (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/core: add representation of generic binary objects
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/core: add a macro to better handle multiple firmware
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/core: output fw size in debug messages
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn: export existing funcs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/flcn: fetch PRI address from TOP if not provided by
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/flcn: move fetching of configuration until first use
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fault/gv100-: fix memory leak on module unload
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/disp/dp: fix typo when determining failsafe link
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/drm/ttm: Remove set but not used variable 'mem'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: Fix copy-paste error in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/gr/gv100-: modify gr init to match newer version of
  RM (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/gk20a,gm200-: add terminators to method
  lists read (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/gf100-: remove dtor (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/fault/tu102: define nvkm_fault_func.pin
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/core: fix missing newline in fw loader error message
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/secboot/gm20b: initialize pointer in
  gm20b_secboot_new() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/mmu: Add correct turing page kinds (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau: Fix ttm move init with multiple GPUs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: use NULL for pointer assignment (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/kms/nv04: remove set but unused variable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fb/gf100-: declare constants as unsigned long long
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv04-nv4x: Use match_string() helper to simplify
  the (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/ce/gp10b: Use correct copy engine (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/ltc/gp10b: Add custom L2 cache implementation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/secboot/gm20b,gp10b: Read WPR configuration from GPU
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/tegra: Set clock rate if not set (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/tegra: Avoid pulsing reset twice (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau: Do not try to disable PCI device on Tegra
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/fault: Add support for GP10B (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau/kms/nv50-: Report possible_crtcs incorrectly on
  mstos, for now (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: Use less encoders by making mstos
  per-head (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/nv50-: Remove nv50_mstc_best_encoder()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/kms/gf119-: allow both 256- and 1024-sized LUTs to
  be (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau/gr/gk208-gm10x: regenerate built-in firmware
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Fix indentation in Makefile (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mediatek: Turn off Alpha bit when plane format has no alpha
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Return from mtk_ovl_layer_config after
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Add ctm property support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mediatek: Add gamma property according to hardware
  capability (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: apply CMDQ control flow (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mediatek: support CMDQ interface in ddp component
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: remove unused external function (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mediatek: disable all the planes in atomic_disable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: update cursors by using async atomic update
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: handle events when enabling/disabling crtc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: use DRM core's atomic commit helper
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gpu: host1x: Remove dev_err() on platform_get_irq() failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: output: Implement system suspend/resume
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: sor: Mark PM functions as __maybe_unused
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: Do not implement runtime PM (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- gpu: host1x: Rename "parent" to "host" (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix compilation warnings on i386
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: fix documentation of
  drm_dp_mst_add_affected_dsc_crtcs (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: protect new DSC code with
  CONFIG_DRM_AMD_DC_DCN (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: add dp helper to initialize remote aux channel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Trigger modesets on MST DSC connectors
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Add helper to trigger modeset on affected DSC
  MST CRTCs (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Recalculate VCPI slots for new DSC connectors
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Check return value of drm helper
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: MST DSC compute fair share (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add PBN per slot calculation for DSC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Rename drm_dp_mst_atomic_check_topology_state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Add branch bandwidth validation to MST atomic check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Add DSC enablement helpers to DRM (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Manually overwrite PBN divider for calculating
  timeslots (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Write DSC enable to MST DPCD (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Validate DSC caps on MST endpoints
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Initialize DSC PPS variables to 0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Add new quirk for Synaptics MST hubs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Add helpers for MST DSC and virtual DPCD aux
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Fill branch->num_ports (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Add MST support to DP DPCD R/W functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Parse FEC capability on MST ports (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: Add PBN calculation for DSC modes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: Improve kfd_process lookup in kfd_ioctl
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add event type check before restart the
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add delay after h' watchdog timeout event
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: rx_validation failed resume from sleep
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Return correct Error code for validate h_prime
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix hdcp1 create session (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix psp return condition for hdcp module
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd: use list_for_each_entry for list iteration
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: remove unnecessary braces around conditionals
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: remove boolean checks in if statements
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx: simplify old firmware warning (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/gmc10: use common invalidation engine helper
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gmc: move invaliation bitmap setup to common code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: updated UMC error address record with correct
  channel (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: resolved bug in UMC RAS CE query (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: cleanup the interfaces for powergate setting
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: issue proper hdp flush for table transferring
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: refine code to support no-dpm case
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: unified VRAM address for driver table
  interaction (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: cache the watermark settings on system memory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu: custom pstate profiling clock frequence for navi
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: L1 Policy(5/5) - removed IH_CHICKEN from VF
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: L1 Policy(3/5) - removed ECC interrupt from VF
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: L1 Policy(2/5) - removed GC GRBM violations from
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu: L1 Policy(1/5) - removed VM settings for mmhub
  and (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: removed GFX RAS support check in UMC ECC callback
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: added function to wait for PSP BL availability
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use linux size macro to simplify ONE_Kib & One_Mib
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: resolve bug in UMC 6 error counter query
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add smu11_driver_if_arcturus.h new
  OOB members (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- amd/amdgpu/sriov tdr enablement with pp_onevf_mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- amd/amdgpu/sriov enable onevf mode for ARCTURUS VF
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: retrieve the enabled feature mask from cache
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: avoid deadlock on Vega20 swSMU routine
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update UMC 6.1 RAS error counter register
  access path (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu: add helper function smu_get_dpm_level_range()
  for smu (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: remove three set but not used variable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/powerplay: fix NULL pointer issue when SMU disabled
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu: use unified variable smu->is_apu to check
  apu asic (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: amalgamated PSP TA invoke functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: amalgamate PSP TA load/unload functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: by default output PSP ret status in event of
  cmd failure (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add check for baco support on Arcturus
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: use true, false for bool variable in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: use true, false for bool variable in
  dce_calcs.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: use true, false for bool variable in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: use true, false for bool variable in
  dcn20_hwseq.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: use true, false for bool variable in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: use true, false for bool variable in
  dc_link_ddc.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: use true, false for bool variable in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu: make the set_performance_level logic easier
  to follow (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: simplify function return logic (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: support custom power profile setting
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix kernel_fpu_begin/_end() warnings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Avoid hanging hardware in stop_cpsch (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: Improve HWS hang detection and handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Remove unused variable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: Fix permissions of hang_hws (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: use true, false for bool variable in amdgpu_psp.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use true, false for bool variable in
  amdgpu_debugfs.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use true, false for bool variable in amdgpu_device.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use true, false for bool variable in mxgpu_nv.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use true, false for bool variable in mxgpu_ai.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: use true,false for bool variable in ni.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: use true,false for bool variable in cik.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: use true,false for bool variable in rv770.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: use true, false for bool variable in evergreen.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: use true,false for bool variable in r600.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: use true,false for bool variable in si.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: use true,false for bool variable in r100.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu: add peak profile support for navi12
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu/navi: Adjust default behavior for peak
  sclk profile (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add missed return value set for error case
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove FB location config for sriov (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable xgmi init for sriov use case (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: remove memory training p2c buffer reservation(V2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update the method to get fb_loc of memory
  training(V4) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Remove unneeded variable 'ret' in navi10_ih.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Remove unneeded variable 'ret' in amdgpu_device.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx: Add mmSDMA2-7_EDC_COUNTER to support Arcturus
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx: Add mmCOMPUTE_STATIC_THREAD_MGMT_SE4-7
  to support (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx: Replace ARRAY_SIZE with size variable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add mmCOMPUTE_STATIC_THREAD_MGMT_SE4-7 to support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Added ASIC specific check in gmc v9.0 ECC interrupt
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enlarge agp_start address into 48bit (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: disable VCN2.5 ib test for Arcturus sriov
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix ctx init failure for asics without gfx ring
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: attempt xgmi perfmon re-arm on failed arm
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add perfmons accessible during df c-states
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: simplify padding calculations (v2) (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: expose num_cp_queues data field to topology
  node (v2) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: expose num_sdma_queues_per_engine data field
  to topology (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: skip disable dynamic state management
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable VCN0 and VCN1 sriov instances support
  for Arcturus (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: skip VCN2.5 power gating and clock gating for sriov
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: update VCN1(dual instances) fw types ID and
  VCN ip block (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add VCN2.5 sriov start for Arctrus (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add VCN2.5 MMSCH start for Arcturus (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: move umc offset to one new header file for Arcturus
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu: add metrics table lock for renoir (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gpu: drm: dead code elimination (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: wait for all rings to drain before runtime
  suspending (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/smu: fix spelling (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Switch from system_highpri_wq to system_unbound_wq
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Redo XGMI reset synchronization (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Add task barrier to XGMI hive (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Add Reusable task barrier (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: reverts commit
  ce316fa55ef0f1751276b846a54fb3b835bd5e64 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/vcn: remove unnecessary included headers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix KIQ ring test fail in TDR of SRIOV
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix double gpu_recovery for NV of SRIOV
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: skip soc clk setting under pp one vf
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/scheduler: do not keep a copy of sched list (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- amd/amdgpu: add sched array to IPs with multiple run-queues
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: replace vm_pte's run-queue list with drm gpu
  scheds list (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/scheduler: rework entity creation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/pm_runtime: update usage count in fence handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: Add SMU WMTABLE Validity Check for Renoir
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Remove unneeded semicolon in amdgpu_ras.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Remove unneeded semicolon in gfx_v10_0.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Remove unneeded semicolon in amdgpu_pmu.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove unneeded semicolon (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/sdma5: make ring tests less chatty (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/gfx10: make ring tests less chatty (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add debug option to override DSC target bpp
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Do not handle linkloss for eDP (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix missing cursor on some rotated SLS displays
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Formula refactor for calculating DPP CLK DTO
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Lower DPP DTO only when safe (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: support virtual DCN (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix manual trigger source for DCN2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Update extended timeout support for DCN20
  and DCN21 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix update_bw_bounding_box Calcs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use absolute time stamp to follow the
  eDP T7 spec (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.64 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix 270 degree rotation for mixed-SLS mode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Get cache window sizes from DMCUB firmware
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove reliance on pipe indexing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Specified VR patch skip to reset segment to 0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: check link status before disable stream
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: disable lttpr for Navi (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Perform DMUB hw_init on resume (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Map ODM memory correctly when doing ODM combine
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add warmup escape call support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix regamma build optimization (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: scaling changes should also be a full update
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.63 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove integer scaling code from DC and
  fix cursor (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Enable Seamless Boot Transition for Multiple
  Streams (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Default max bpc to 16 for eDP (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Collapse resource arrays when pipe is disabled
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: update chroma viewport wa (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Use pipe_count for num of opps (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Reinstate LFC optimization (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: AVI info package change due to spec update
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add definition for number of backlight
  data points (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add interface to adjust DSC max target
  bpp limit (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Disable integerscaling for downscale and MPO
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use physical addressing for DMCUB on both
  dcn20/21 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Get DMUB registers from ASIC specific structs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add wait for flip not pending on pipe unlock
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: disable lttpr for RN (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: HDMI 2.x audio bandwidth check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/vcn: remove JPEG related code from idle handler
  and begin (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/vcn1.0: use its own idle handler and begin use funcs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sriov: Tonga sriov also need load firmware with smu
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: drop useless BACO arg in amdgpu_ras_reset_gpu
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add missing dcn link encoder regs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add dpcs20 registers (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: move dpcs headers to dpcs includes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Add CU info print log (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Use Arcturus specific
  set_vm_context_page_table_base() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: fix various dereferences of a pointer
  before it is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: queue kfd interrupt work to different CPU
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- amdgpu: Wrap FPU dependent functions in dc20 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- amdgpu: Enable initial DCN support on POWER (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- amdgpu: Prepare DCN floating point macros for generic
  arch support (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: simple: Add Satoz SAT050AT40H12R2 panel support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/fb-cma-helpers: Fix include issue (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/modes: tag unused variables to avoid warnings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: Add support for BOE NV140FHM-N49 panel to
  panel-simple (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: Add driver for Sony ACX424AKP panel (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Make udl driver depend on CONFIG_USB (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/Kconfig: add missing 'depends on DRM' for DRM_DP_CEC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/lima: use drm_sched_fault for error task handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: Add support for AUO B116XAK01 panel (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- gpu/drm: clean up white space in
  drm_legacy_lock_master_cleanup() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/omapdrm: use BUG_ON macro for error debugging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: meson: fix address type confusion (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gma500: remove set but not used variables 'hist_reg'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: drc: Make sure we enforce the clock rate
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: backend: Make sure we enforce the clock rate
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: dsi: Fix bridge chain handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: dsi: Fix bridge chain handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: mmp: fix platform_get_irq.cocci warnings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/bridge: Add a drm_bridge_state object"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/bridge: Patch atomic hooks to take a
  drm_bridge_state" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/bridge: Add an ->atomic_check() hook"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/bridge: Add the necessary bits to support bus format
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/bridge: Fix a NULL pointer dereference in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Set crc->opened to false before setting crc source to NULL
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: remove the newline for CRC source name (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: zte: Provide ddc symlink in vga connector sysfs directory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: zte: Provide ddc symlink in hdmi connector sysfs directory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vc4: Provide ddc symlink in connector sysfs directory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: Provide ddc symlink in output connector sysfs
  directory (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Fix a NULL pointer dereference in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mgag200: Add module parameter to pin all buffers at offset
  0 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vram-helper: Support struct drm_driver.gem_create_object
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vram-helper: Remove BO device from public interface
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vram-helper: Remove interruptible flag from public interface
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add the necessary bits to support bus format
  negotiation (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add an ->atomic_check() hook (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: Patch atomic hooks to take a drm_bridge_state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add a drm_bridge_state object (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Revert "drm: atmel-hlcdc: enable sys_clk during
  initalization." (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: atmel-hlcdc: prefer a lower pixel-clock than requested
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: atmel-hlcdc: enable clock before configuring timing engine
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: atmel-hlcdc: use double rate for pixel clock only if
  supported (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: cdns: remove set but not used variable 'nlanes'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: cdns: remove set but not used variable 'bpp'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: meson: Remove unneeded semicolon (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: bridge: dw-hdmi: constify copied structure (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/hisilicon/hibmc: Export VRAM MM information to debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/hisilicon/hibmc: Implement hibmc_dumb_create() with generic
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/vram: Support scanline alignment for dumb buffers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/hisilicon/hibmc: Replace struct hibmc_framebuffer
  with generic (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/hisilicon/hibmc: Switch to generic fbdev emulation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: rockchip: rk3066_hdmi: set edid fifo address
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: lvds: Add PX30 support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/rockchip: lvds: move hardware-specific functions together
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: lvds: improve error handling in helper functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: lvds: Create an RK3288 specific probe function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: lvds: Change platform data to hold helper_funcs
  pointer (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: lvds: Harmonize function names (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/rockchip: lvds: Fix indentation of a #define (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: add panel driver for Leadtek LTK500HD1829
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: add panel driver for Xinpeng XPP055C272 panels
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- omapfb/dss: remove unneeded conversions to bool (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: pxafb: Use devm_platform_ioremap_resource() in
  pxafb_probe() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: ocfb: Use devm_platform_ioremap_resource() in
  ocfb_probe() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: fsl-diu-fb: mark expected switch fall-throughs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- fbdev: matrox: make array wtst_xlat static const, makes
  object smaller (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- fbdev/sa1100fb: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- fbdev: s3c-fb: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- fbdev: omapfb: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video/fbdev/68328fb: Remove dead code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- pxa168fb: Fix the function used to release some memory
  in an error (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- fbdev: fbmem: avoid exporting fb_center_logo (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- fbdev: fbmem: allow overriding the number of bootup logos
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: mmp: fix sparse warnings about using incorrect
  types (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: mmp: add COMPILE_TEST support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: mmp: remove duplicated MMP_DISP dependency
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mipi_dbi: Fix off-by-one bugs in mipi_dbi_blank()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: of: Fix linking when CONFIG_OF is not set (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: declare variable as __be16 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/komeda: Add runtime_pm support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/komeda: Add event handling for EMPTY/FULL (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/sun4i: dsi: Add Allwinner A64 MIPI DSI support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: dsi: Handle bus clock via regmap_mmio_attach_clk
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: dsi: Get the mod clock for A31 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: sun4i: Add support for suspending the display driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/atomic: Spell CRTC consistently (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Fix a couple of typos, punctation and whitespace issues
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/stm: ltdc: move pinctrl to encoder mode set (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/todo: Updating logging todo (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: fix null dereference of pointer fb before null check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gem-fb-helper: convert to drm device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/fb-helper: convert to drm device based logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/client: convert to drm device based logging (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: move drm_connector_to_virtio_gpu_output to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: move to_virtio_fence inside virtgpu_fence
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: simplify getting fake offset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: get rid of drm_encoder_to_virtio_gpu_output
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: static-ify virtio_gpu_framebuffer_init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: static-ify virtio_fence_signaled (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: lvds-codec: Simplify panel DT node localisation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: lvds-codec: Add "lvds-decoder" support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Repurpose lvds-encoder.c (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- udmabuf: fix dma-buf cpu access (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mcde: Some fixes to handling video mode (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/drm_panel: Fix EXPORT of drm_panel_of_backlight() one
  more time (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- dma-heap: Make the symbol 'dma_heap_ioctl_cmds' static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: fix resource leak on -ENOTTY error return path
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: remove duplicate check on parent and avoid BUG_ON
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: plane_state->fb iff plane_state->crtc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/malidp: plane_state->fb iff plane_state->crtc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: Use dma_resv locking wrappers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: Use dma_resv locking wrappers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Use dma_resv locking wrappers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma-buf: heaps: Remove redundant heap identifier from
  system heap (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: heaps: Use _IOCTL_ for userspace IOCTL identifier
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/print: introduce new struct drm_device based logging macros
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Make sure the CEA mode arrays have the correct
  amount of modes (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Throw away the dummy VIC 0 cea mode (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/edid: Add CTA-861-G modes with VIC >= 193 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/edid: Abstract away cea_edid_modes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: use damage info for display updates (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: batch display update commands (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: skip set_scanout if framebuffer didn't change
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: plane_state->fb iff plane_state->crtc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bochs: Remove unneeded semicolon (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/modes: parse_cmdline: Explicitly memset the passed in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/modes: parse_cmdline: Remove some unnecessary code (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/modes: parse_cmdline: Add support for specifying
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/modes: parse_cmdline: Allow specifying stand-alone options
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/modes: parse_cmdline: Set bpp/refresh_specified after
  successful (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/modes: parse_cmdline: Add freestanding argument to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/modes: parse_cmdline: Rework
  drm_mode_parse_cmdline_options() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/modes: parse_cmdline: Accept extras directly after
  mode combined (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/modes: parse_cmdline: Stop parsing extras after bpp /
  refresh at (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/modes: parse_cmdline: Make various char pointers const
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/modes: parse_cmdline: Fix possible reference past end
  of string (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: dsi: add px30 support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/rockchip: add ability to handle external dphys in mipi-dsi
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge/synopsys: dsi: move phy_ops callbacks around panel
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge/synopsys: dsi: driver-specific configuration of phy
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Update DRIVER_DATE to 20191223 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Mark the GEM context link as RCU protected
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Introduce a vma.kref (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add a simple is-bound check before unbinding
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Make sure CCS YUV semiplanar format checks work
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Make sure Y slave planes get all the required state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Skip rotated offset adjustment for unsupported
  modifiers (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Make sure FBs have a correct CCS plane stride
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Gen-12 render decompression (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/framebuffer: Format modifier for Intel Gen-12 render
  compression (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add helpers to select correct ccs/aux planes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Extract framebufer CCS offset checks into a function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move CCS stride alignment W/A inside
  intel_fb_stride_alignment (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use intel_tile_height() instead of re-implementing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: make mock_drm.h self-contained
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: make mock_context.h self-contained
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: fix comment for POWER_DOMAIN_TRANSCODER_VDSC_PW2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Move pm debug files into a gt aware debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Merge engine init/setup loops (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Pull intel_gt_init_hw() into intel_gt_resume()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Pull GT initialisation under intel_gt_init()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move i915_gem_init_contexts() earlier (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Repeat wait_for_idle for retirement workers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Remove i915->kernel_context (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Setup engine->retire for mock_engine
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Introduce intel_crtc_state_alloc() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/execlists: Select arb on/off around batches based on
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Push the use-semaphore marker onto the intel_context
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Drop GEM context as a direct link from i915_request
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Teach veng to defer the context allocation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Add breadcrumb retire to physical engine
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Rename pipe update tracepoints (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Remove second redundant intel_fbc_pre_update()
  call (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: Reject PLANE_OFFSET.y%%4!=0 on icl+ too
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Suppress threshold updates on RPS parking
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Use non-forcewake writes for RPS (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Track engine round-trip times (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Schedule request retirement when signaler idles
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsc: fix DSC power domains for DSI (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dsc: clarify DSC support for pipe A on ICL
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsc: fix DSC register selection for ICL DSI transcoders
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Provide ddc symlink in hdmi connector sysfs directory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: fix phy name (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: use clk_off name to avoid double negation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: move clk off sanitize to its own function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Ratelimit i915_globals_park (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Remove direct invocation of breadcrumb signaling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move stuff from haswell_crtc_disable() into encoder
  .post_disable() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pass old crtc state to intel_crtc_vblank_off()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pass old crtc state to skylake_scaler_disable()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Nuke .post_pll_disable() for DDI platforms
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Call hsw_fdi_link_train() directly() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Introduce intel_plane_state_reset() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Introduce intel_crtc_state_reset() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Introduce intel_crtc_{alloc,free}() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: s/intel_crtc/crtc/ in intel_crtc_init()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Add __drm_atomic_helper_crtc_state_reset() & co
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pmu: Skip sampling engines if gt is asleep
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Unpin vma->obj on early error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/guc: Unify notify() functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/guc: Remove function pointers for send/receive calls
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc/ct: Group request-related variables in a
  sub-structure (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc/ct: Stop expecting multiple CT channels
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc/ct: Drop guards in enable/disable calls
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: Merge communication_stop and communication_disable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Eliminate the trylock for reading a timeline's hwsp
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: DSI: select correct PWM controller to use based
  on the VBT (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Avoid multi-LRI on Sandybridge (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Eliminate the trylock for awaiting an earlier request
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Correct function name in comment (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Tidy up full-ppgtt on Ivybridge (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Apply lmem size restriction to get_pages
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix typecheck macro in GT_TRACE (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove unneeded semicolon (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: opregion: set opregion chpd value to indicate
  the driver handles hotplug (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Serialise object before changing cache-level
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: fix pipe D readout for DSI transcoders
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/bios: remove extra debug messages (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/rps: Add frequency translation helpers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Use EAGAIN for trylock failures (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Introduce new macros for tracing (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/perf: Register sysctl path globally (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/icl: Cleanup combo PHY aux power well handlers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: remove a condition (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/bios: fix off by one in parse_generic_dtd()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Streamline skl_commit_modeset_enables()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/cml: Separate U series pci id from origianl list
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/cml: Remove unsupport PCI ID (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Mark up ips_mchdev pointer access (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Improve i915_inject_probe_error macro (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Asynchronous cmdparser (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Prepare gen7 cmdparser for async execution
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Only ignore rc6 parking for PCU on byt/bsw
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Align start for memcpy_from_wc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Tidy up error handling for eb_parse()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Simplify error escape from cmdparser (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove redundant parameters from
  intel_engine_cmd_parser (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Fix cmdparser drm.debug (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Disable manual rc6 for Braswell/Baytrail
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uc: Drop explicit ggtt param in some uc_fw functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uc: Drop explicit gt param in some uc_fw functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/uc: Drop explicit i915 param in some uc_fw functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use the i915_device name for identifying our
  request fences (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: remove redundant checks for a null fb pointer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: remove duplicated assignment to pointer
  crtc_state (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pass cpu transcoder to assert_pipe() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: ELiminate intel_pipe_to_cpu_transcoder() from
  assert_fdi_tx() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Show the i915_active on failure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Wait on unbind barriers when invalidating userptr
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Check we are the Ironlake IPS provider before
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Improve execbuf debug (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: add support for DSC (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Fix state mismatch warns for horizontal
  timings with (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: account for DSC in horizontal timings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: use compressed pixel format with DSC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: take compression into account in afe_clk()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: use afe_clk() instead of intel_dsi_bitrate()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: abstract afe_clk calculation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dsi: set pipe_bpp on ICL configure config
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsc: add basic hardware state readout support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsc: make DSC source support helper generic
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsc: add support for computing and writing PPS for
  DSI encoders (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsc: move slice height calculation to encoder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsc: move DP specific compute params to intel_dp.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/bios: add support for querying DSC details for encoder
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/bios: parse compression parameters block
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/bios: pass devdata to parse_ddi_port (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Program BW_BUDDY registers during display init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: fix uninitialized variable sum when summing
  up (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: kill the GuC client (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: kill doorbell code and selftests (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/guc: add a helper to allocate and map guc vma
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: Drop leftover preemption code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Reallocate cfb if we need more of it
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: Enable fbc by default on glk+ once again
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: Wait for vblank after FBC disable on glk+
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: Start using flip nuke (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Nuke fbc.enabled (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: s/gen9 && !glk/gen9_bc || bxt/ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Make fence_id optional for i965gm (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Store fence_id directly in fbc cache/params
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/fbc: Track plane visibility (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Precompute gen9 cfb stride w/a (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Remove the FBC_RT_BASE setup for ILK/SNB
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Relocate intel_crtc_active() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/fbc: Nuke bogus single pipe fbc1 restriction
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Change i915_vma_unbind() to report -EAGAIN on activity
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Avoid rcu_barrier() from shrinker paths
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Flesh out device_info pretty printer (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Comment on inability to check args.pad for
  MMAP_OFFSET (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Turn vm off then on again for gen7 mm switch
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gtt: Account for preallocation in asserts
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Avoid calling i915_gem_object_unbind holding
  object lock (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: Update uncore access path in flush_ggtt_writes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Pin gen6_ppgtt prior to constructing the request
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Replace I915_WRITE with its uncore counterpart
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Refactor intel_commit_modeset_disables()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/tgl: Fix the order of the step to turn
  transcoder clock off (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Do not check for the ddb allocations of
  turned off pipes (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add new EHL/JSL PCI ids (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Propagate errors on awaiting already signaled
  dma-fences (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Propagate errors on awaiting already signaled fences
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Check for error before calling cmpxchg()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pmu: Report frequency as zero while GPU is sleeping
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Flush the pwrite through the chipset before
  signaling (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Acquire a GT wakeref for the breadcrumb interrupt
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Claim vma while under closed_lock in i915_vma_parked()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Trim gen6 ppgtt updates to PD cachelines
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Serialise i915_active_acquire() with __active_retire()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Replace I915_READ with intel_uncore_read
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Reinitialise the local list before repeating
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Bump the PP_DIR invalidation for Baytrail
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Try hard to bind the context (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Ignore most failures during evict-vm (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove vestigal i915_gem_context locals from cmdparser
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Hook user-extensions upto MMAP_OFFSET_IOCTL
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Hold the obj->vma.lock while walking the vma.list
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Try to flush pending unbind events (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Introduce DRM_I915_GEM_MMAP_OFFSET (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/perf: drop pointless static qualifier in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Make intel_crtc_arm_fifo_underrun() functional on gen2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Nuke intel_pre_disable_primary_noatomic()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Clean up the gen2 "no planes -> underrun" workaround
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Clean up intel_{pre,post}_plane_update()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: s/pipe_config/new_crtc_state/
  intel_{pre,post}_plane_update() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pass dev_priv to ilk_disable_lp_wm() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Clean up arguments to nv12/scaler w/a funcs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Set the PD again for Haswell (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Avoid parking the vma as we unbind (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display/mst: Move DPMS_OFF call to post_disable
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: Power down sink before disable pipe/transcoder
  clock (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display: Check the old state to find port sync slave
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/irq: Refactor gen11 display interrupt handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Track the context validity explicitly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Skip nested spinlock for validating pending
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Add a couple more validity checks to
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Lift i915_vma_pin() out of intel_renderstate_emit()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Take runtime-pm wakeref prior to unbinding
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Serialise i915_active_wait() with its retirement
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Specialise i915_active.work lock classes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Unbind all current vma on changing cache-level
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Simplify rc6 w/a application (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Use soft-rc6 for w/a protection (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/bios: assume vbt is 4-byte aligned into oprom
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/bios: fold pci rom map/unmap into copy function
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/bios: do not discard address space (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display: Suspend MST topology manager before
  destroy fbdev (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/vbt: Parse power conservation features block
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/psr: Check if sink PSR capability changed
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/psr: Enable ALPM lock timeout error interruption
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/psr: Refactor psr short pulse handler (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/psr: Add bits per pixel limitation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dsb: fix cmd_buf being wrongly set (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Stop using connector->encoder and encoder->crtc
  links in i915_display_info (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Dump both the uapi and hw states for crtcs and planes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use the canonical [CRTC:%%d:%%s]/etc. format in
  i915_display_info (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use drm_modeset_lock_all() in debugfs display info
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Dump the mode for the crtc just the once
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Refactor debugfs display info code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Reorganize plane/fb dump in debugfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Switch to intel_ types in debugfs display_info
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use drm_rect to simplify plane {crtc,src}_{x,y,w,h}
  printing (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Switch intel_crtc_disable_noatomic() to intel_ types
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Program SHPD_FILTER_CNT on CNP+ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Handle SDEISR according to PCH rather than platform
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use the correct PCH transcoder for LPT/WPT
  in intel_sanitize_frame_start_delay() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Refactor gen6_flush_pd() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Serialise access to GFX_FLSH_CNTL (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Push the flush_pd before the set-context
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gen7: Re-enable full-ppgtt for ivb & hsw
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Keep engine awake during live_coherency
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Ensure the tasklet is decoupled upon
  shutdown (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Don't set undefined bits in dirty_pipes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/i915: use a separate context for gpu relocs"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Wait only on the expected barrier
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Always lock the drm_mm around insert/remove
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Use sgt_iter for huge_pages_free
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Implement Wa_1604555607 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Drop local vm reference! (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Count the number of engines used
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Try to show where the pulse went
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Excise the per-batch whitelist from the context
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Defer breadcrumb processing to after the
  irq handler (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Serialise i915_active_fence_set() with itself
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Manual rc6 entry upon parking (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Disable display interrupts during display IRQ handler
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dp: fix DP audio for PORT_A on gen12+ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Support more QGV points (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Move mock_vma to the heap to reduce
  stack_frame (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Serialise with engine-pm around requests on the
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Switch kunmap() to take the page not vaddr
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Include the subsubtest name for
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: coffeelake supports hdcp2.2 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Flush the active callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Force bonded submission to overlap
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use a ctor for TYPESAFE_BY_RCU i915_request
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Shorten infinite wait for sseu
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Always hold a reference on a waited
  upon request (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Mark intel_wakeref_get() as a sleeper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/execlists: Lock the request while validating it during
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Hold request reference while waiting for w/a
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Use intel_gt_pm_put_async in GuC submission path
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Declare timeline.lock to be irq-free
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Do not initialize display BW when display not
  available (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- Skip MCHBAR queries when display is not available
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Change .crtc_enable/disable() calling convention
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: s/pipe_config/new_crtc_state/ in .crtc_enable()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: s/intel_crtc/crtc/ in .crtc_enable() and
  .crtc_disable() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pass dev_priv to cpt_verify_modeset() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Change watermark hook calling convention
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Pass intel_crtc to ironlake_fdi_disable()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Move crtc_state to tighter scope (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Move assert_vblank_disabled() into
  intel_crtc_vblank_on() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add intel_crtc_vblank_off() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Change intel_encoders_<hook>() calling convention
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Take a ref to the request we wait upon
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Be explicit in ERR_PTR handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Exercise rc6 w/a handling (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Manually dump the debug trace on GEM_BUG_ON
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Flush the requests after wedging on suspend
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Schedule next retirement worker first
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Do not read the transcoder register
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Protect the obj->vma.list during iteration
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Merge GGTT vma flush into a single loop
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Track ggtt writes from userspace on the bound vma
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Only wait for register chipset flush if active
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsb: fix extra warning on error path handling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsb: remove atomic operations (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/mst: Check uapi enable not intel one during mst
  atomic check (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/vbt: Handle generic DTD block (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/vbt: Parse panel options separately from timing data
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Add intel_gt_driver_late_release for
  mock device (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Purge the sudden reappearance of
  i915_gem_object_pin() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Mention which device failed (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Fix frame start delay programming (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Disable heartbeat around context
  barrier tests (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Exercise long preemption chains
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/perf: Add preemption check while waiting for OA
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Flush retire.work timer object on unload
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Use gt locals for accessing rc6 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Silence sparse for RCU protection inside the
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/guc: Properly capture & release GuC interrupts
  on Gen11+ (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Drop redundant aspec ratio prop value initialization
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Do not override mode's aspect ratio with the prop
  value NONE (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Add coverage of mocs registers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Refactor mocs loops into single control macro
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Tidy up debug-warns for the mocs control table
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Set unused mocs entry to follow PTE on tgl as on
  all (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: Wa_1606679103 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/tgl: allow DVI/HDMI on port A (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/display/mst: Enable virtual channel payload allocation
  earlier (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/display/dsi: Add support to pipe D (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/bios: make sure to check vbt size (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/bios: rename bios to oprom when mapping pci rom
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Invalidate as we write the gen7 breadcrumb
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: do not warn late about hdmi on port A (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gt: Flush gen7 even harder (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/selftests: Remove unused local variable 'file'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsi: Define command mode registers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/bios: store child devices in a list (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/bios: use a flag for vbt hdmi level shift presence
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Try an extra flush on the Haswell blitter
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Remove leftover gem.pm_notifier member (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Pass mem region to preallocated stolen
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Replace implicit dev_priv->uncore for stolen init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Perform some basic cycle counting of MI ops
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/userptr: Handle unlocked gup retries (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/execlists: Reduce barrier on context switch to a wmb()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Taint the kernel on dumping the GEM ftrace buffer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Fill all the drm_vma_manager holes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Exercise parallel blit operations on
  a single ctx (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Cancel context if it hangs after it is closed
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Show guilty context name on GPU reset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Update context name on closing (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/gem: Embed context/timeline name inside the GEM context
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/icl: Refine PG_HYSTERESIS (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/pmu: Only use exclusive mmio access for gen7
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/pmu: Cheat when reading the actual frequency to avoid
  fw (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Mark up sole accessor to ctx->vm as being
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Complete transition to a real struct
  file mock (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: make more headers self-contained (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: change to_mock() to an inline function (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Expand documentation for gen12 DP pre-enable sequence
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Verify mmap_gtt revocation on unbinding
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Wrap vm_mmap() around GEM objects
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Replace mock_file hackery with drm's
  true fake (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: Expose a method for creating anonymous struct file around
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Move EXPORT_SYMBOL_FOR_TESTS_ONLY under a separate Kconfig
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Safely acquire the ctx->vm when copying
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Defer engine registration until fully initialised
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: FB backing gem obj should reside in LMEM
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: use might_lock_nested in get_pages annotation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- lockdep: add might_lock_nested() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Switch obj->mm.lock lockdep annotations on its head
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Cleanup heartbeat systole first (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: switch intel_ddi_init() to intel types (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: Add second TGL PCH ID (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Remove unwanted rcu_read_lock/unlock (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/lmem: fixup fake lmem teardown (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Frob the correct crtc state in
  intel_crtc_disable_noatomic() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gem: Early rejection of no-aperture map_ggtt
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsb: Remove PIN_MAPPABLE from the DSB object VMA
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsc: rename functions for consistency (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dsc: split out encoder specific parts from DSC compute
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/dsc: clean up rc parameter table access (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/dsc: make parameter arrays const (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: avoid reading DP_TP_CTL twice (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/tgl: do not enable transcoder clock twice on MST
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: add wrappers to get intel connector state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add for_each_new_intel_connector_in_state()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Eliminate redundancy in intel_primary_plane_create()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Sort format arrays consistently (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add 10bpc formats with alpha for icl+ (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Expose C8 on VLV/CHV sprite planes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Add missing 10bpc formats for pipe B sprites on CHV
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Expose alpha formats on VLV/CHV primary planes
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Expose 10:10:10 XRGB formats on SNB-BDW sprites
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Reset CSB pointers by mmio as well
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: add for_each_port() and use it (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/execlists: Ignore the inactive kernel context in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/execlists: Verify context register state before
  execution (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Flush all active callbacks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915/perf: Reverse a ternary to make sparse happy
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/gt: Pull timeline initialise to intel_gt_init_early
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Remove special case slave handling during hw
  programming, v3 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Complete plane hw and uapi split, v2 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Perform automated conversions for plane uapi/hw split,
  base -> uapi (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Perform automated conversions for plane uapi/hw
  split, base -> hw (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Perform manual conversions for plane uapi/hw split,
  v2 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add aliases for uapi and hw to plane_state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Complete crtc hw/uapi split, v6 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Perform automated conversions for crtc uapi/hw split,
  base -> uapi (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Perform automated conversions for crtc uapi/hw split,
  base -> hw (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Perform manual conversions for crtc uapi/hw split,
  v2 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Add aliases for uapi and hw to crtc_state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Handle a few more cases for crtc hw/uapi split, v3
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/i915/selftests: Spin on all engines simultaneously
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: use msleep rather than udelay for HDCP
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: include delay.h (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: rcar-du: Add r8a77980 support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: rcar-du: lvds: Allow for even and odd pixels swap
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: rcar-du: lvds: Get dual link configuration from DT
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: rcar-du: lvds: Improve identification of panels
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: of: Add drm_of_lvds_get_dual_link_pixel_order
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: rcar-du: lvds: Get mode from state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: rcar-du: Recognize "renesas,vsps" in addition to "vsps"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: rcar-du: crtc: Register GAMMA_LUT properties
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: rcar-du: crtc: Control CMM operations (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: rcar-du: kms: Initialize CMM instances (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: rcar-du: Add support for CMM (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: log when amdgpu.dc=1 but ASIC is unsupported
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix JPEG instance checking when ctx init
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix VCN2.x number of irq types (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable gfxoff feature for navi10 asic
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: enable pp one vf mode for vega10
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Added RAS UMC error query support for Arcturus
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: correct the value retrieved through GPU_LOAD
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: implement the get_enabled_mask callback
  for smu12 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: implement interface to retrieve clock freq
  for (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: implement interface to retrieve gpu
  temperature (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: clear VBIOS scratchs on baco exit V2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add condition to enable baco for ras recovery
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: pre-check the SMU state before issuing
  message (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: drop unnecessary warning prompt
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: fix resume failures due to psp fw loading
  sequence change (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- Revert "drm/amdgpu: enable VCN DPG on Raven and Raven2"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add VM eviction lock v3 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: stop adding VM updates fences to the resv obj
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: explicitely sync to VM updates v2 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: move VM eviction decision into amdgpu_vm.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Fix BACO entry failure in NAVI10 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Extend DMCUB offload testing into dcn20/21
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: correct log message for lttpr (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: update dml related structs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Change HDR_MULT check (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: 3.2.62 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Implement DePQ for DCN2 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix cursor positioning for multiplane cases
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Limit NV12 chroma workaround (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: add dsc policy getter (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: remove spam DSC log (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: add dc dsc functions to return bpp range
  for pixel (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove redundant call (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Modify logic for when to wait for mpcc idle
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: check for repeater when setting aux_rd_interval
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove flag check in mpcc update
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: update sr latency for renoir when using lpddr4
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add shared DMCUB/driver firmware state
  cache window (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Split DMUB cmd type into type/subtype
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Return a correct error value (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Save/restore link setting for disable phy
  when link (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add DP protocol version (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: update p-state latency for renoir when
  using lpddr4 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Implement DePQ for DCN1 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix dml20 min_dst_y_next_start calculation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Disable chroma viewport w/a when rotated
  180 degrees (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add log for lttpr (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: 3.2.61 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix dprefclk and ss percentage reading on RN
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Program CW5 for tracebuffer for dcn20
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Return DMUB_STATUS_OK when autoload unsupported
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Only wait for DMUB phy init on dcn21
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DMCUB__PG_DONE trace code enum
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Disable link before reenable (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Reset PHY in link re-training (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Wrong ifdef guards were used around DML
  validation (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix Dali clk mgr construct (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: add separate of private hwss functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: rename core_dc to dc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: reduce redundant uvd context lost warning message
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: clear err_event_athub flag after reset exit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: support full gpu reset workflow when ras
  err_event_athub (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add concurrent baco reset support for XGMI
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable/disable doorbell interrupt in baco entry/exit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: clear uncorrectable parity error status bit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: clear ras controller status registers when interrupt
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: export amdgpu_ras_find_obj to use externally
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove ras global recovery handling from
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Eliminate unnecessary kernel queue function pointers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx: Improvement on EDC GPR workarounds
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Loading NV10/14 Bounding Box Data Directly
  From Code (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Contain MMHUB number in
  mmhub_v9_4_setup_vm_pt_regs() (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: load np fw prior before loading the TAs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: unload asd in psp hw de-init phase (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: drop asd shared memory (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- amd/amdgpu/sriov swSMU disable for sriov (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: remove redundant assignment to variable v_total
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove unneeded semicolon in (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Remove unneeded semicolon in hdcp.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove unneeded semicolon in bios_parser2.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Remove unneeded semicolon in bios_parser.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: Remove unneeded variable 'ret' in
  amdgpu_smu.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: Remove unneeded variable 'result' in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: Remove unneeded variable 'ret' in
  smu7_hwmgr.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: Remove unneeded variable 'result' in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: Remove unneeded variable 'result' in
  smu10_hwmgr.c (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix double assignment to msg_id field
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/sriov: No need the event 3 and 4 now (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Load TA firmware for navi10/12/14
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: not remove sysfs if not create sysfs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Drop AMD_EDID_UTILITY defines (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Include num_vmid and num_dsc within NV14's
  resource (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/gfx: Increase dispatch packet number (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/gfx: Clear more EDC cnt (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu/gfx10: remove outdated comments (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: radeon: replace 0 with NULL (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Fix a bug in jpeg_v1_0_start() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: move pci handling out of pm ops (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Modify comments to match the code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: apply gpr/gds workaround before enabling GFX
  EDC mode (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/amdgpu/sriov skip jpeg ip block for ARCTURUS VF
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Raise KFD unpinned system memory limit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Null check aconnector in
  event_property_validate (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: remove set but not used variable
  'stretch_amount2' (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove set but not used variable 'msg_out'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: remove redundant assignment to variable ret
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Ensure ret is always initialized when using
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use NULL for pointer assignment in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: remove redundant assignment to variables
  HiSidd (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd: Fix Kconfig indentation (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Apply noretry setting for mmhub9.4 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Use ARRAY_SIZE for sos_old_versions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: Use ARRAY_SIZE for smu7_profiling
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Remove duplicate functions update_mqd_hiq()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove redundant assignment to pointer write_frame
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: simplify runtime suspend (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: DIQ should not use HIQ way to allocate memory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Delete KFD_MQD_TYPE_COMPUTE (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: implement querying ras error count for mmhub9.4
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: refine query function of mmhub EDC counter in vg20
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: define soc15_ras_field_entry for reuse
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- amd/amdgpu: force to trigger a no-retry-fault after a
  retry-fault (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add flag to indicate amdgpu vm context
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable runtime pm on BACO capable boards if runpm=1
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: disentangle runtime pm and vga_switcheroo
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: start to disentangle boco from runtime pm
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add baco support to runtime suspend/resume
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add helpers for baco entry and exit (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: split swSMU baco_reset into enter and exit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add additional boco checks to runtime suspend/resume
  (v2) (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: rename amdgpu_device_is_px to
  amdgpu_device_supports_boco (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add a amdgpu_device_supports_baco helper
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add supports_baco callback for NV asics
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add supports_baco callback for VI asics
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add supports_baco callback for CIK asics
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add supports_baco callback for SI asics
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add supports_baco callback for soc15 asics. (v2)
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add asic callback for BACO support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: enable gpu_busy_percent sys interface
  for renoir (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: pull ras controller int status only when ras enabled
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: switch to common helper func for psp cmd submission
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add helper func for psp ring cmd submission
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add psp funcs for ring write pointer read/write
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add missing header file declaration
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add Arcturus baco reset support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: correct swSMU baco reset related settings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: return errno code to caller when error occur
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove not needed memset (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/radeon: remove set but not used variable 'tv_pll_cntl1'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: remove set but not used variable 'blocks'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: remove set but not used variable 'radeon_connector'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: remove set but not used variable 'dig_connector'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: remove set but not used variable
  'backbias_response_time' (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: remove set but not used variable 'size',
  'relocs_chunk' (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix coding error in connector atomic check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix static analysis bug in validate_bksv
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: split rxstatus for hdmi and dp (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: use drm defines for MAX CASCADE MASK
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add and use defines from drm_hdcp.h
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Refactor HDCP encryption status update
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add force Type0/1 flag (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Refactor HDCP to handle multiple displays
  per link (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Handle hdcp2.2 type0/1 in dm (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Enable HDCP 2.2 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Change ERROR to WARN for HDCP module
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add logging for HDCP2.2 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add execution and transition states for HDCP2.2
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DDC handles for HDCP2.2 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add PSP block to verify HDCP2.2 steps
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add Navi10 DMUB VBIOS code (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add DSC 422Native debug option (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Use a temporary copy of the current state when
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Spin for DMCUB PHY init in DC (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: DML Validation Dump/Check with Logging
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: cleanup of function pointer tables
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Don't spin forever waiting for DMCUB
  phy/auto init (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Avoid conflict between HDR multiplier and 3dlut
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add debugfs sdp hook up function for Navi
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.60 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add debug trace for dmcub FW autoload
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Adjust DML workaround threshold (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: add color space option when sending link test
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: cleanup of construct and destruct funcs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix debugfs on MST connectors (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: revert change causing DTN hang for RV
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Clean up some code with unused registers
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Connect DIG FE to its BE before link
  training starts (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add debugfs initalization on mst connectors
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DMUB param to load inst const from driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add DMUB service function check if hw
  initialized (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Changes in dc to allow full update in
  some cases (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix stereo with DCC enabled (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: 3.2.59 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Fix incorrect deep color setting in
  YCBCR420 modes (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Update background color in bottommost mpcc
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add hubp clock status in DTN log for Navi
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Renoir chroma viewport WA Read the correct
  register (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Renoir chroma viewport WA change formula
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add automated audio test support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/dm: Do not throw an error for a display with no audio
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove set but not used variable 'min_content'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove set but not used variable 'bp' in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove set but not used variable
  'old_plane_crtc' (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/soc15: move struct definition around to align
  with other (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: remove set but not used variable 'top_dev'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable Arcturus JPEG2.5 block (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable Arcturus CG for VCN and JPEG blocks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: move JPEG2.5 out from VCN2.5 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: enable JPEG2.0 for Navi1x and Renoir (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add driver support for JPEG2.0 and above
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable JPEG2.0 dpm (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: set JPEG to SMU dpm (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: add JPEG power control for Renoir
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add Powergate JPEG for Renoir (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/powerplay: add JPEG power control for Navi1x
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: add JPEG Powerplay interface (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add PG and CG for JPEG2.0 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add JPEG PG and CG interface (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: remove unnecessary JPEG2.0 code from VCN2.0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add JPEG v2.0 function supports (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add JPEG common functions to amdgpu_jpeg
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add JPEG IP block type (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: use the JPEG structure for general driver support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: separate JPEG1.0 code out from VCN1.0
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add amdgpu_jpeg and JPEG tests (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: add JPEG HW IP and SW structures (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: init umc functions for arcturus umc ras
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: enable ras capablity check on arcturus
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Rename kfd_kernel_queue_*.c to
  kfd_packet_manager_*.c (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Eliminate ops_asic_specific in kernel queue
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Merge CIK kernel queue functions into VI
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: remove set but not used variable 'us_mvdd'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove set but not used variable 'invalid'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove set but not used variable 'count'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove set but not used variable 'amdgpu_connector'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove set but not used variable 'mc_shared_chmap'
  from 'gfx_v6_0.c' and 'gfx_v7_0.c' (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: remove set but not used variable 'bpc'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Stop using GFP_NOIO explicitly for two places
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Use QUEUE_IS_ACTIVE macro in mqd v10 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: Fix a bug when calculating save_area_used_size
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Update get_wave_state() for GFX10 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdkfd: Implement queue priority controls for gfx10
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Rename create_cp_queue() to init_user_queue()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Avoid using doorbell_off as offset in process
  doorbell (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Use better name to indicate the offset is in dwords
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove set but not used variable 'ds_port'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: remove set but not used variable 'threshold',
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use static const, not const static
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: remove set but not used variable 'data'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/powerplay: remove set but not used variable
  'vbios_version', (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove duplicated comparison expression
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: fix spelling mistake "exeuction" -> "execution"
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Simplify the mmap offset related bit operations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Use kernel queue v9 functions for v10
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Only keep release_mem function for Hawaii
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdkfd: Adjust function sequences to avoid unnecessary
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove redundant variable status
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: remove duplicated assignment to grph_obj_type
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove set but not used variable 'mc_shared_chmap'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove always false comparison in
  'amdgpu_atombios_i2c_process_i2c_ch' (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: remove set but not used variable 'dig'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove set but not used variable 'dig_connector'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add function parameter description in
  'amdgpu_gart_bind' (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: add function parameter description in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: remove 4 set but not used variable in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: fix warning when CONFIG_DRM_AMD_DC_DCN
  is not set (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu/display: fix the build when CONFIG_DRM_AMD_DC_DCN is
  not (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: rename DCN1_0 kconfig to DCN (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Drop CONFIG_DRM_AMD_DC_DCN2_1 flag
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Drop CONFIG_DRM_AMD_DC_DCN2_0 and DSC_SUPPORTED
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Disable VUpdate interrupt for DCN hardware
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Send vblank and user events at vsartup for DCN
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: disable lttpr for invalid lttpr caps
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: use previous aux timeout val if no repeater
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: implement lttpr logic (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: configure lttpr mode (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: check for dp rev before reading lttpr regs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: initialize lttpr (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Unify all scaling when Integer Scaling enabled
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: add oem i2c implemenation in dc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add some hardware status in DTN log debugfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.58 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: optimize bandwidth after commit streams
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Create debug option to disable v.active
  clock change (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: set MSA MISC1 bit 6 while sending colorimetry
  in VSC (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add a sanity check for DSC already
  enabled/disabled (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Use SIGNAL_TYPE_NONE in disable_output unless
  eDP (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Renoir chroma viewport WA (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Fix assert observed when performing dummy
  p-state (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: 3.2.57 (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Drop CONFIG_DRM_AMD_DC_DMUB guards
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Register DMUB service with DC (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add DMUB support to DC (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Add DMCUB to firmware query interface
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Hook up the DMUB service in DM (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Add PSP FW version mask (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Change dmcu init sequence for dmcub loading
  dmcu FW (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add the DMUB service (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: Drop DMCUB from DCN21 resources (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amdgpu: Add PSP loading support for DMCUB ucode
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Add ucode support for DMCUB (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/amd/display: fix dereference of pointer aconnector when it
  is (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amd/display: Add MST atomic routines (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- DRM: ARC: PGU: add ARGB8888 format to supported format list
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- DRM: ARC: PGU: replace unsupported by HW RGB888 format
  by XRGB888 (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- DRM: ARC: PGU: cleanup supported format list code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- DRM: ARC: PGU: fix framebuffer format switching (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- linux-next: build failure after merge of the drm-misc tree
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tilcdc: Remove obsolete bundled tilcdc tfp410 driver
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gpu/drm: ingenic: Add support for the JZ4770 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- gpu/drm: ingenic: Check for display size in CRTC atomic check
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- gpu/drm: ingenic: Set max FB height to 4095 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- gpu/drm: ingenic: Use the plane's src_[x,y] to configure
  DMA length (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- gpu/drm: ingenic: Avoid null pointer deference in plane
  atomic update (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: Remove unneeded semicolon in sun4i_layer.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: Remove unneeded semicolon in sun8i_mixer.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: Pass GPIO for Intel MID using descriptors
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/atmel: plane_state->fb iff plane_state->crtc (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: Add Boe Himax8279d MIPI-DSI LCD panel (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gma500: globle no more! (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/komeda: Enable new product D32 support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/komeda: Update the chip identify (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/komeda: Correct d71 register block counting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Remove udl_fb.c (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Move udl_handle_damage() into udl_modeset.c
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Remove struct udl_device.active_fb_16 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Convert to drm_atomic_helper_dirtyfb() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Set preferred color depth to 16 bpp (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Inline DPMS code into CRTC enable and disable functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Switch to atomic suspend/resume helpers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Convert to struct drm_simple_display_pipe
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Init connector before encoder and CRTC (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/edid: Increase size of VDB and CMDB bitmaps to 256 bits
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: heaps: Add CMA heap to dmabuf heaps (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma-buf: heaps: Add system heap to dmabuf heaps (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma-buf: heaps: Add heap helpers (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- dma-buf: Add dma-buf heaps framework (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/drm_panel: fix EXPORT of drm_panel_of_backlight
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/doc: Drop :c:func: markup (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/atomic: Update docs around locking and commit sequencing
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: panel: export drm_panel_bridge_connector
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Store primary-plane format in struct ast_crtc_state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Store VBIOS mode info in struct ast_crtc_state
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Introduce struct ast_crtc_state (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Add plane atomic_check() functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Clean up arguments of register functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Enable and disable screen in primary-plane functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Move modesetting code to CRTC's atomic_flush()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: crtc: add OSD1 plane AFBC commit (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/meson: hold 32 lines after vsync to give time for AFBC start
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: viu: add AFBC modules routing functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: plane: add support for AFBC mode for OSD1 plane
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: Add AFBCD module driver (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/meson: add RDMA module driver (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: store the framebuffer width for plane commit
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/meson: add RDMA register bits defines (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/meson: add AFBC decoder registers for GXM and G12A
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: tpo-tpg110: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: tpo-td028ttec1: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: sitronix-st7789v: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: sitronix-st7701: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: sharp-ls043t1le01: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: sharp-lq101r1sx01: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: seiko-43wvf1g: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: ronbo-rb070d30: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: rocktech-jh057n00900: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: raydium-rm68200: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: panasonic-vvx10f034n00: use drm_panel backlight
  support (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: osd-osd101t2587-53ts: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: olimex-lcd-olinuxino: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: lvds: use drm_panel backlight support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: kingdisplay-kd097d04: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: innolux-p079zca: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: ilitek-ili9881c: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: feiyang-fy07024di26a30d: use drm_panel backlight
  support (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: drop drm_device from drm_panel (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: decouple connector from drm_panel (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: add drm_connector argument to get_modes()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: get drm_bridge_panel connector via helper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: simple: use drm_panel backlight support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: add backlight support (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/drm_panel: no error when no callback (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gma500: add a missed gma_power_end in error path
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Clarify the atomic enable/disable hooks semantics
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add the drm_bridge_get_prev_bridge() helper
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add the drm_for_each_bridge_in_chain() helper
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Make the bridge chain a double-linked list
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Stop accessing encoder->bridge directly (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: Introduce drm_bridge_get_next_bridge()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Rename bridge helpers targeting a bridge chain
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Remove VCPI while disabling topology mgr
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panfrost: Register devfreq cooling device (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Remove field lost_pixels from struct udl_device
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Begin/end access to imported buffers in damage-handler
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Move log-cpp code out of udl_damage_handler()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Move clip-rectangle code out of udl_handle_damage()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Vmap framebuffer after all tests succeeded in damage
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Don't track number of identical and sent pixels
  per line (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Remove unused statistics counters (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: share address space for dma bufs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: call drm_gem_object_funcs.mmap with fake offset
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Add FEC registers for LT-tunable repeaters (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Fix DSC throughput mode 0 mask definition (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vkms: Fix typo and preposion in function documentation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/doc: Add VKMS module description and use to "Testing and
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dp_mst: Clear all payload id tables downstream when
  initializing (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Debug-print unique revisions id on G200 SE
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mgag200: Call mgag200_driver_{load, unload}() before
  registering (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: Call psb_driver_{load, unload}() before registering
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: constify fb ops across all drivers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: intelfb: use const pointer for fb_ops
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: constify fb ops across all drivers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: make fbops member of struct fb_info a const
  pointer (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: uvesafb: modify the static fb_ops directly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: nvidia: modify the static fb_ops directly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: mb862xx: modify the static fb_ops directly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fbdev: atyfb: modify the static fb_ops directly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- udmabuf: implement begin_cpu_access/end_cpu_access hooks
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- udmabuf: separate out creating/destroying scatter-table
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- udmabuf: add a pointer to the miscdevice in dma-buf private data
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- udmabuf: use cache_sgt_mapping option (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/via: Don't include <drm/drm_pci.h> (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tdfx: Don't include <drm/drm_pci.h> (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/sis: Don't include <drm/drm_pci.h> (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/savage: Don't include <drm/drm_pci.h> (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/radeon: Don't include <drm/drm_pci.h> (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/r128: Don't include <drm/drm_pci.h> (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mgag200: Don't include <drm/drm_pci.h> (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mga: Don't include <drm/drm_pci.h> (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i810: Don't include <drm/drm_pci.h> (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Don't include <drm/drm_pci.h> (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/pci: Hide legacy PCI functions from non-legacy code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/pci: Only build drm_pci.c if CONFIG_PCI is set
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panel: rpi: Drop unused GPIO includes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/crtc-helper: drm_connector_get_single_encoder prototype
  is missing (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- video: omapfb: use const pointer for fb_ops (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbmem: use const pointer for fb_ops (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- video: fbdev: vesafb: modify the static fb_ops directly
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: udlfb: don't restore fb_mmap after deferred IO cleanup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: smscufx: don't restore fb_mmap after deferred IO cleanup
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/fb-helper: don't preserve fb_ops across deferred IO use
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- video: fb_defio: preserve user fb_ops (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: drop DRM_AUTH from PRIME_TO/FROM_HANDLE ioctls
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/panfrost: remove DRM_AUTH and respective comment
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: use correct dev node location in comment (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/exynos: Don't reset bridge->next (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tegra: fix opencoded use of drm_panel_* (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: fix opencoded use of drm_panel_* (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/exynos: fix opencoded use of drm_panel_* (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: clean up indentation issue (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/panel: simple: Add Logic PD Type 28 display support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: Inline drm_color_lut_extract() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/todo: Add entry for fb funcs related cleanups
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: Add alternate clock for SMPTE 4K (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/edid: Add aspect ratios to HDMI 4K modes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/qxl: Complete exception handling in qxl_device_init()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: Use drm_gem_fb_create_with_dirty (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/rect: update kerneldoc for drm_rect_clip_scaled()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/selftests: Add drm_rect selftests (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/rect: Keep the clipped dst rectangle in place
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rect: Keep the scaled clip bounded (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/rect: Avoid division by zero (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/fourcc: Fill out all block sizes for P210 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/fourcc: Fill out all block sizes for P10/12/16
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Fix build break (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/scheduler: Avoid accessing freed bad job (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vram: remove unused declaration (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- udmabuf: Remove deleted map/unmap handlers (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Replace struct udl_framebuffer with generic
  implementation (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Call udl_handle_damage() with DRM framebuffer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Store active framebuffer in device structure
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Remove udl implementation of GEM's free_object()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Unmap buffer object after damage update (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma-buf: Remove kernel map/unmap hooks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/armada: Delete dma_buf->k(un)map implemenation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- sample/vfio-mdev/mbocs: Remove dma_buf_k(un)map support
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- xen/gntdev-dmabuf: Ditch dummy map functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- media/videobuf2: Drop dma_buf->k(un)map support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vmwgfx: Delete mmaping functions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma-buf: Drop dma_buf_k(un)map (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tegra: Remove dma_buf->k(un)map (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omapdrm: Drop dma_buf->k(un)map (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/i915: Drop dma_buf->k(un)map (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: Remove dma_buf_kmap selftest (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tegra: Delete host1x_bo_ops->k(un)map (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/tegra: Map cmdbuf once for reloc processing (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Revert "drm/fbdev: Fallback to non tiled mode if all tiles
  not present" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: Remove struct psb_fbdev (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gma500: Store framebuffer in struct drm_fb_helper
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: Pass struct drm_gem_object to framebuffer functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: Replace struct psb_framebuffer with struct
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: Remove field 'fbdev' from struct psb_framebuffer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: Remove addr_space field from psb_framebuffer
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/sun4i: Fix Kconfig indentation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/vc4: Fix Kconfig indentation (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mcde: Do not needlessly logically and with 3 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mcde: Reuse global DSI command defs (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mediatek: don't open-code drm_gem_fb_create (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/msm: Don't init ww_mutec acquire ctx before needed
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- dma-resv: Also prime acquire ctx for lockdep (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/modeset: Prime modeset lock vs dma_resv (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dp_mst: fix multiple frees of tx->bytes (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mgag200: Fix Kconfig indentation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: Fix Kconfig indentation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/lima: Fix Kconfig indentation (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: Fix Kconfig indentation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/omap: Fix Kconfig indentation (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: Fix Kconfig indentation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Fix Kconfig indentation (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- vga: Fix Kconfig indentation (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/dsi: add helpers for DSI compression mode and PPS packets
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/dsi: rename MIPI_DCS_SET_PARTIAL_AREA to (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dsi: add missing DSI DCS commands (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dsi: add missing DSI data types (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/dsi: clean up DSI data type definitions (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma_resv: prime lockdep annotations (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/r128: make ATI PCI GART part of its only user, r128
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: factor out virtio_gpu_update_dumb_bo (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtio: Simplify virtio_gpu_primary_plane_update workflow
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/virtio: fix byteorder handling in
  virtio_gpu_cmd_transfer_{from, (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/xen: Simplify fb_create (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/tilcdc: Drop drm_gem_fb_create wrapper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/atmel: ditch fb_create wrapper (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gma500: Fixup fbdev stolen size usage evaluation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- fbdev: Unexport unlink_framebuffer() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/fb-helper: Remove drm_fb_helper_unlink_fbi() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Replace fbdev code with generic emulation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- =?UTF-8?q?drm/komeda:=20Clean=20warnings:=20candidate=20for=20'gn?=
  =?UTF-8?q?u=5Fprintf=E2=80=99=20format=20attribute?=
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: remove set but not used variable 'channel_eq'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/fbdev: Fallback to non tiled mode if all tiles not present
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/edid: no CEA v3 extension is not an error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gma500: remove set but not used variable 'is_hdmi','is_crt'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: remove set but not used variable 'error'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/gma500: remove set but not used variable 'htotal'
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Call struct drm_driver.{load, unload} before
  registering (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Replace drm_get_pci_device() and drm_put_dev()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/print: group logging functions by prink or device based
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/print: convert debug category macros into an enum
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/print: underscore prefix functions that should be private
  to print (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/print: rename drm_debug to __drm_debug to discourage use
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: use drm_debug_enabled() to check for debug
  categories (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/nouveau: use drm_debug_enabled() to check for debug
  categories (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/i915: use drm_debug_enabled() to check for debug categories
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/komeda: Adds gamma and color-transform support for DOU-IPS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/komeda: Add drm_ctm_to_coeffs() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/komeda: Add drm_lut_to_fgamma_coeffs() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: Add a new helper drm_color_ctm_s31_32_to_qm_n()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/fb-helper: unexport drm_fb_helper_generic_probe
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: anx6345: Fix compilation breakage on systems without
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/komeda: Fix komeda driver build error (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: fix anx6345 compilation for v5.5 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/virtgpu: fix double unregistration (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/komeda: add rate limiting disable to err_verbosity
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/komeda: Add option to print WARN- and INFO-level IRQ events
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/komeda: Optionally dump DRM state on interrupts
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/komeda: Remove CONFIG_KOMEDA_ERROR_PRINT (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/komeda: Add debugfs node to control error verbosity
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mcde: Handle pending vblank while disabling display
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mcde: dsi: Enable clocks in pre_enable() instead of
  mode_set() (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/mcde: dsi: Fix duplicated DSI connector (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/mcde: dsi: Delay start of video stream generator
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mcde: dsi: Make video mode errors more verbose
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mcde: Fix frame sync setup for video mode panels
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mcde: Provide vblank handling unconditionally
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/rockchip: use DRM_DEV_ERROR for log output (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/udl: Remove struct udl_gem_object and functions
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Switch to SHMEM (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Allocate GEM object via struct
  drm_driver.gem_create_object (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/udl: Remove flags field from struct udl_gem_object
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: finally fix the racy VMA setup (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ttm: also export ttm_bo_vm_fault v2 (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Enable atomic modesetting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Add cursor plane (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Add CRTC helpers for atomic modesetting (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Add primary plane (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Split ast_set_vbios_mode_info() (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/ast: Split ast_set_ext_reg() into color and threshold
  function (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Don't clear base address and offset with default values
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Check video-mode requirements against VRAM size
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ast: Remove last traces of struct ast_gem_object
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: Add Analogix anx6345 support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: Prepare Analogix anx6345 support (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/bridge: extract some Analogix I2C DP common code
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: split some definitions of ANX78xx to dedicated
  headers (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/bridge: move ANA78xx driver to analogix subdirectory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/tilcdc: Provide ddc symlink in connector sysfs directory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/mediatek: Provide ddc symlink in hdmi connector sysfs
  directory (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/exynos: Provide ddc symlink in connector's sysfs
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm/hdmi: Provide ddc symlink in hdmi connector sysfs
  directory (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm: rockchip: Provide ddc symlink in inno_hdmi sysfs directory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: rockchip: Provide ddc symlink in rk3066_hdmi sysfs
  directory (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/amdgpu: Provide ddc symlink in dm connector's sysfs
  directory (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/radeon: Provide ddc symlink in connector sysfs directory
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm: atomic helper: fix W=1 warnings (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gma500: Add page flip support on psb/cdv (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/gma500: Add missing call to allow enabling vblank on psb/cdv
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/fb-helper: Remove drm_fb_helper_fbdev_{setup, teardown}()
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/todo: Convert drivers to generic fbdev emulation
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/komeda: Use devm_platform_ioremap_resource() in
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: remove ttm_bo_wait_unreserved (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/nouveau: slowpath for pushbuf ioctl (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- dma_resv: prime lockdep annotations (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/doc: Update IGT documentation (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/vkms: Update VKMS documentation (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/todo: Add entry to remove load/unload hooks (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/property: Enforce more lifetime rules (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm: use DIV_ROUND_UP helper macro for calculations
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/scdc: Fix typo in bit definition of SCDC_STATUS_FLAGS
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/ttm: ttm_tt_init_fields() can be static (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- Revert "drm/etnaviv: reject timeouts with tv_nsec >=
  NSEC_PER_SEC" (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882,
  jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- drm/etnaviv: avoid deprecated timespec (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- drm/etnaviv: reject timeouts with tv_nsec >= NSEC_PER_SEC
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- drm/msm: avoid using 'timespec' (jsc#SLE-12680, jsc#SLE-12880,
  jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496, jsc#SLE-15322).
- console/dummycon: Remove bogus depends on from DUMMY_CONSOLE
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- pinctrl: Allow modules to use pinctrl_register_mappings
  (jsc#SLE-12680, jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883,
  jsc#SLE-13496, jsc#SLE-15322).
- remove ioremap_nocache and devm_ioremap_nocache (jsc#SLE-12680,
  jsc#SLE-12880, jsc#SLE-12882, jsc#SLE-12883, jsc#SLE-13496,
  jsc#SLE-15322).
- commit 9955060
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/stp: unify stp_work_mutex and clock_sync_mutex
  (jsc#SLE-13821).
- s390/stp: add sysfs file to show scheduled leap seconds
  (jsc#SLE-13821).
- s390/stp: add support for leap seconds (jsc#SLE-13821).
- Refresh
  patches.suse/s390-sles15sp3-03-02-s390-cio-Provide-Endpoint-Security-Mode-per-CU.patch.
- s390/stp: use u32 instead of unsigned int (jsc#SLE-13821).
- s390/stp: use __packed (jsc#SLE-13821).
- s390/stp: add locking to sysfs functions (jsc#SLE-13821).
- commit 0307c9d
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/topology: remove offline CPUs from CPU topology masks
  (jsc#SLE-13727).
- commit 1f00baa
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: implement ndo_bridge_setlink for learning_sync
  (jsc#SLE-13764).
- s390/qeth: implement ndo_bridge_getlink for learning_sync
  (jsc#SLE-13764).
- s390/qeth: Reset address notification in case of buffer overflow
  (jsc#SLE-13764).
- bridge: Add SWITCHDEV_FDB_FLUSH_TO_BRIDGE notifier
  (jsc#SLE-13764).
- s390/qeth: Translate address events into switchdev notifiers
  (jsc#SLE-13764).
- s390/qeth: Detect PNSO OC3 capability (jsc#SLE-13764).
- s390/cio: Helper functions to read CSSID, IID, and CHID
  (jsc#SLE-13764).
- s390/cio: Add new Operation Code OC3 to PNSO (jsc#SLE-13764).
- commit 77e80d7
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/ctcm: remove orphaned function declarations
  (jsc#SLE-13690).
- s390/qeth: static checker cleanups (jsc#SLE-13690).
- commit f2438b0
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: use netdev_name() (jsc#SLE-13690).
- s390/qeth: constify the disciplines (jsc#SLE-13690).
- s390/qeth: allow configuration of TX queues for OSA devices
  (jsc#SLE-13690).
- s390/qeth: de-magic the QIB parm area (jsc#SLE-13690).
- s390/qeth: keep track of wanted TX queues (jsc#SLE-13690).
- s390/qeth: remove forward declarations in L2 code
  (jsc#SLE-13690).
- s390/qeth: consolidate teardown code (jsc#SLE-13690).
- commit 656ad94
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: consolidate online code (jsc#SLE-13690).
- s390/qeth: cancel cmds earlier during teardown (jsc#SLE-13690).
- s390/qeth: tighten ucast IP locking (jsc#SLE-13690).
- s390/qeth: replace deprecated simple_stroul() (jsc#SLE-13690).
- s390/qeth: clean up string ops in qeth_l3_parse_ipatoe()
  (jsc#SLE-13690).
- s390/qeth: relax locking for ipato config data (jsc#SLE-13690).
- s390/qeth: don't init refcount twice for mcast IPs
  (jsc#SLE-13690).
- commit c7164a0
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: strictly order bridge address events (jsc#SLE-13690).
- s390/cio, s390/qeth: cleanup PNSO CHSC (jsc#SLE-13690).
- s390/qeth: unify structs for bridge port state (jsc#SLE-13690).
- s390/qeth: copy less data from bridge state events
  (jsc#SLE-13690).
- s390/qeth: don't let HW override the configured port role
  (jsc#SLE-13690).
- s390/qeth: don't disable address events during initialization
  (jsc#SLE-13690).
- commit 6718f0f
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: make queue lock a proper spinlock (jsc#SLE-13690).
- s390/qeth: use to_delayed_work() (jsc#SLE-13690).
- s390/qeth: clean up qeth_l3_send_setdelmc()'s declaration
  (jsc#SLE-13690).
- s390/qeth: delay draining the TX buffers (jsc#SLE-13690).
- s390/qeth: use all configured RX buffers (jsc#SLE-13690).
- s390/ism: indicate correct error reason in ism_alloc_dmb()
  (jsc#SLE-13690).
- s390/qeth: constify the MPC initialization data (jsc#SLE-13690).
- commit c17a727
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: unify RX-mode hashtables (jsc#SLE-13690).
- s390/qeth: cleanup OAT code (jsc#SLE-13690).
- s390/qeth: clean up a magic number in the OAT callback
  (jsc#SLE-13690).
- s390/qeth: use u64_to_user_ptr() in the OAT code
  (jsc#SLE-13690).
- s390/qeth: clean up error handling for isolation mode cmds
  (jsc#SLE-13690).
- s390/qeth: don't clear the configured isolation mode
  (jsc#SLE-13690).
- s390/qeth: only init the isolation mode when necessary
  (jsc#SLE-13690).
- commit fdcdead
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: fine-tune errno when cmds are cancelled
  (jsc#SLE-13690).
- s390/qeth: reject unsupported link type earlier (jsc#SLE-13690).
- s390/qdio: remove internal polling in non-thinint path
  (jsc#SLE-13690).
- s390/qdio: allow to scan all 128 Input SBALs (jsc#SLE-13690).
- s390/qdio: fix statistics for 128 SBALs (jsc#SLE-13690).
- s390/qeth: let isolation mode override HW offload restrictions
  (jsc#SLE-13690).
- s390/qdio: warn about unexpected SLSB states (jsc#SLE-13690).
- commit 22cf4e8
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qdio: clean up usage of qdio_data (jsc#SLE-13690).
- s390/qdio: reduce SLSB writes during Input Queue processing
  (jsc#SLE-13690).
- s390/qdio: fine-tune SLSB update (jsc#SLE-13690).
- s390/qdio: remove q->first_to_kick (jsc#SLE-13690).
- s390/qdio: fix up qdio_start_irq() kerneldoc (jsc#SLE-13690).
- s390/qdio: add IRQ reduction for error SBALs (jsc#SLE-13690).
- s390/qdio: refactor ACK processing for primed SBALs
  (jsc#SLE-13690).
- commit 46b9562
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qdio: simplify overlap calculation on Input refill
  (jsc#SLE-13690).
- s390/qdio: remove always-true condition (jsc#SLE-13690).
- s390/qdio: de-duplicate tiqdio_inbound_processing()
  (jsc#SLE-13690).
- s390/qdio: keep track of allocated queue count (jsc#SLE-13690).
- s390/qdio: roll-back after queue allocation error
  (jsc#SLE-13690).
- s390/qdio: do more fine-grained allocation roll-back
  (jsc#SLE-13690).
- s390/qdio: consolidate thinint init/exit (jsc#SLE-13690).
- commit 26e1650
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: clean up Kconfig help text (jsc#SLE-13690).
- s390/qeth: return error when starting a reset fails
  (jsc#SLE-13690).
- s390/qeth: set TX IRQ marker on last buffer in a group
  (jsc#SLE-13690).
- s390/qeth: indicate contiguous TX buffer elements
  (jsc#SLE-13690).
- s390/qeth: merge TX skb mapping code (jsc#SLE-13690).
- s390/qeth: don't use restricted offloads for local traffic
  (jsc#SLE-13690).
- s390/qeth: extract helpers for next-hop lookup (jsc#SLE-13690).
- commit 6af340f
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: add debugfs file for local IP addresses
  (jsc#SLE-13690).
- s390/qeth: process local address events (jsc#SLE-13690).
- s390/qeth: keep track of LP2LP capability for csum offload
  (jsc#SLE-13690).
- s390/qeth: fix cancelling of TX timer on dev_close()
  (jsc#SLE-13690).
- s390/qdio: clear DSCI early for polling drivers (jsc#SLE-13690).
- s390/qdio: inline shared_ind() (jsc#SLE-13690).
- s390/qdio: remove cdev from init_data (jsc#SLE-13690).
- commit 35bdfba
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qdio: allow for non-contiguous SBAL array in init_data
  (jsc#SLE-13690).
- zfcp: inline zfcp_qdio_setup_init_data() (jsc#SLE-13690).
- s390/qdio: cleanly split alloc and establish (jsc#SLE-13690).
- s390/qdio: set qdio_irq->cdev at allocation time
  (jsc#SLE-13690).
- Refresh
  patches.suse/s390-qdio-consistently-restore-the-irq-handler.
- s390/qdio: remove unused function declarations (jsc#SLE-13690).
- s390/qdio: pass ISC as parameter to chsc_sadc() (jsc#SLE-13690).
- s390/qdio: export SSQD via debugfs (jsc#SLE-13690).
- commit b19b3bd
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qdio: simplify debugfs code (jsc#SLE-13690).
- s390/qdio: use QDIO_IRQ_STATE_INACTIVE instead of 0
  (jsc#SLE-13690).
- s390/qdio: reduce access to cdev->private->qdio_data
  (jsc#SLE-13690).
- Refresh
  patches.suse/s390-qdio-consistently-restore-the-irq-handler.
- s390/qdio: clean up cdev access in qdio_setup_irq()
  (jsc#SLE-13690).
- Refresh
  patches.suse/s390-qdio-consistently-restore-the-irq-handler.
- s390/qeth: make OSN / OSX support configurable (jsc#SLE-13690).
- Update config files.
- s390/qeth: remove fake_broadcast attribute (jsc#SLE-13690).
- s390/qeth: modernize two list helpers (jsc#SLE-13690).
- commit c754a84
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: keep track of fixed prio-queue configuration
  (jsc#SLE-13690).
- s390/qeth: fine-tune MAC Address-related errnos (jsc#SLE-13690).
- s390/qeth: add TX IRQ coalescing support for IQD devices
  (jsc#SLE-13690).
- s390/qeth: collect more TX statistics (jsc#SLE-13690).
- s390/qeth: clean up the mac_bits (jsc#SLE-13690).
- s390/qeth: simplify L3 dev_id logic (jsc#SLE-13690).
- s390/qdio: extend polling support to multiple queues
  (jsc#SLE-13690).
- Refresh
  patches.suse/s390-qdio-put-thinint-indicator-after-early-error.
- Refresh
  patches.suse/s390-qeth-integrate-rx-refill-worker-with-napi.
- s390/qeth: remove redundant if-clause in RX poll code
  (jsc#SLE-13690).
- Refresh
  patches.suse/s390-qeth-integrate-rx-refill-worker-with-napi.
- Refresh patches.suse/s390-qeth-tolerate-pre-filled-rx-buffer.
- commit a459172
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: split out RX poll code (jsc#SLE-13690).
- Refresh
  patches.suse/s390-qeth-integrate-rx-refill-worker-with-napi.
- s390/qeth: simplify RX buffer tracking (jsc#SLE-13690).
- Refresh
  patches.suse/s390-qeth-integrate-rx-refill-worker-with-napi.
- Refresh patches.suse/s390-qeth-tolerate-pre-filled-rx-buffer.
- s390/qeth: use dev->reg_state (jsc#SLE-13690).
- s390/qeth: remove gratuitous NULL checks (jsc#SLE-13690).
- s390/qeth: add phys_to_virt() translation for AOB
  (jsc#SLE-13690).
- s390/qeth: don't report hard-coded driver version
  (jsc#SLE-13690).
- s390/qeth: add SW timestamping support for IQD devices
  (jsc#SLE-13690).
- commit 475757c
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: balance the TX queue selection for IQD devices
  (jsc#SLE-13690).
- s390/qeth: allow configuration of TX queues for IQD devices
  (jsc#SLE-13690).
- s390/qeth: allow configuration of TX queues for z/VM NICs
  (jsc#SLE-13690).
- s390/qeth: remove prio-queueing support for z/VM NICs
  (jsc#SLE-13690).
- s390/qeth: use memory reserves in TX slow path (jsc#SLE-13690).
- s390/qeth: use memory reserves to back RX buffers
  (jsc#SLE-13690).
- s390/qeth: remove VNICC callback parameter struct
  (jsc#SLE-13690).
- commit 85386f2
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qdio: add tighter controls for IRQ polling (jsc#SLE-13690).
- Refresh
  patches.suse/s390-qeth-integrate-rx-refill-worker-with-napi.
- s390/qeth: support configurable RX copybreak (jsc#SLE-13690).
- s390/qeth: don't check for IFF_UP when scheduling napi
  (jsc#SLE-13690).
- s390/qeth: don't re-start read cmd when IDX has terminated
  (jsc#SLE-13690).
- s390/qeth: reset seqnos on connection startup (jsc#SLE-13690).
- s390/qeth: remove unused cmd definitions (jsc#SLE-13690).
- s390/qeth: validate device-provided MAC address (jsc#SLE-13690).
- commit 3cac482
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: clean up CREATE_ADDR cmd code (jsc#SLE-13690).
- s390/qeth: remove dead code in qeth_l3_iqd_read_initial_mac()
  (jsc#SLE-13690).
- s390/qdio: fill SL with absolute addresses (jsc#SLE-13690).
- s390/qdio: don't allocate *aob array with GFP_ATOMIC
  (jsc#SLE-13690).
- s390/qdio: simplify ACK tracking (jsc#SLE-13690).
- s390/qeth: remove HARDSETUP state (jsc#SLE-13690).
- Refresh patches.suse/s390-qeth-cancel-rx-reclaim-work-earlier.
- Refresh
  patches.suse/s390-qeth-implement-smarter-resizing-of-the-rx-buffer-pool.
- Refresh
  patches.suse/s390-qeth-integrate-rx-refill-worker-with-napi.
- s390/qeth: make cmd/reply matching more flexible
  (jsc#SLE-13690).
- commit 3e7992c
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: consolidate online/offline code (jsc#SLE-13690).
- s390/qeth: shift some bridgeport code around (jsc#SLE-13690).
- s390/qeth: remove QETH_RX_PULL_LEN (jsc#SLE-13690).
- Refresh
  patches.suse/s390-qeth-handle-error-when-backing-rx-buffer.
- s390/qeth: use napi_gro_frags() for SG skbs (jsc#SLE-13690).
- s390/qeth: consolidate RX code (jsc#SLE-13690).
- Refresh
  patches.suse/s390-qdio-fill-sbales-with-absolute-addresses.
- Refresh
  patches.suse/s390-qeth-don-t-warn-for-napi-with-0-budget.
- Refresh
  patches.suse/s390-qeth-integrate-rx-refill-worker-with-napi.
- s390/qeth: make use of napi_schedule_irqoff() (jsc#SLE-13690).
- s390/qeth: consolidate helpers for capability checking
  (jsc#SLE-13690).
- commit cd47e53
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qeth: stop yielding the ip_lock during IPv4 registration
  (jsc#SLE-13690).
- s390/qeth: don't raise NETDEV_REBOOT event from L3 offline path
  (jsc#SLE-13690).
- s390/qeth: remove open-coded inet_make_mask() (jsc#SLE-13690).
- s390/qeth: clean up L3 sysfs code (jsc#SLE-13690).
- s390/qeth: overhaul L3 IP address dump code (jsc#SLE-13690).
- s390/qeth: wake up all waiters from qeth_irq() (jsc#SLE-13690).
- s390/qeth: only handle IRQs while device is online
  (jsc#SLE-13690).
- Refresh patches.suse/s390-qeth-refactor-buffer-pool-code.
- commit 2028bef
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/qdio: don't attempt IRQ avoidance on Output SBALs
  (jsc#SLE-13690).
- s390/qdio: simplify thinint device registration (jsc#SLE-13690).
- Refresh
  patches.suse/s390-qdio-put-thinint-indicator-after-early-error.
- s390/qdio: add statistics helper macro (jsc#SLE-13690).
- s390/qdio: remove a forward declaration (jsc#SLE-13690).
- s390/qdio: reduce log level for EQBS partial (jsc#SLE-13690).
- s390/qdio: use QDIO_BUFNR() (jsc#SLE-13690).
- commit e493d37
* Fri Nov  6 2020 tiwai@suse.de
- pinctrl: intel: Add Intel Alder Lake-S pin controller support
  (jsc#SLE-13489).
- Update config files.
- supported.conf: Add pinctrl-alderlake
- commit 46e1f39
* Fri Nov  6 2020 ohering@suse.de
- hyperv_fb: Update screen_info after removing old framebuffer
  (bsc#1175306).
- x86/kexec: Use up-to-dated screen_info copy to fill boot params
  (bsc#1175306).
- video: hyperv: hyperv_fb: Use physical memory for fb on HyperV
  Gen 1 VMs (bsc#1175306).
- video: hyperv: hyperv_fb: Support deferred IO for Hyper-V
  frame buffer driver (bsc#1175306).
- video: hyperv: hyperv_fb: Obtain screen resolution from Hyper-V
  host (bsc#1175306).
- commit 6359015
* Fri Nov  6 2020 tiwai@suse.de
- pinctrl: intel: Add Intel Elkhart Lake pin controller support
  (jsc#SLE-12730).
- Update config files.
- supported.conf: Add pinctrl-elkhartlake
- commit 564fbfd
* Fri Nov  6 2020 tiwai@suse.de
- pinctrl: intel: Add Intel Lakefield pin controller support
  (jsc#SLE-12730).
- Update config files.
- supported.conf: add pinctrl-lakefield
- commit 5f4ba59
* Fri Nov  6 2020 tiwai@suse.de
- pinctrl: intel: Add blank line before endif in Kconfig
  (jsc#SLE-12730).
- commit 320f56c
* Fri Nov  6 2020 ohering@suse.de
- KVM: x86: hyper-v: disallow configuring SynIC timers with no
  SynIC (jsc#sle-12891).
- PCI: hv: Fix hibernation in case interrupts are not re-created
  (jsc#sle-12891).
- Drivers: hv: vmbus: Add parsing of VMbus interrupt in ACPI DSDT
  (jsc#sle-12891).
- hv: clocksource: Add notrace attribute to
  read_hv_sched_clock_*() functions (jsc#sle-12891).
- PCI: hv: Document missing hv_pci_protocol_negotiation()
  parameter (jsc#sle-12891).
- scsi: storvsc: Support PAGE_SIZE larger than 4K (jsc#sle-12891).
- Driver: hv: util: Use VMBUS_RING_SIZE() for ringbuffer sizes
  (jsc#sle-12891).
- HID: hyperv: Use VMBUS_RING_SIZE() for ringbuffer sizes
  (jsc#sle-12891).
- Input: hyperv-keyboard: Use VMBUS_RING_SIZE() for ringbuffer
  sizes (jsc#sle-12891).
- hv_netvsc: Use HV_HYP_PAGE_SIZE for Hyper-V communication
  (jsc#sle-12891).
- hv: hyperv.h: Introduce some hvpfn helper functions
  (jsc#sle-12891).
- Drivers: hv: vmbus: Move virt_to_hvpfn() to hyperv header
  (jsc#sle-12891).
- Drivers: hv: Use HV_HYP_PAGE in hv_synic_enable_regs()
  (jsc#sle-12891).
- Drivers: hv: vmbus: Introduce types of GPADL (jsc#sle-12891).
- Drivers: hv: vmbus: Move __vmbus_open() (jsc#sle-12891).
- Drivers: hv: vmbus: Always use HV_HYP_PAGE_SIZE for gpadl
  (jsc#sle-12891).
- drivers: hv: remove cast from hyperv_die_event (jsc#sle-12891).
- x86/hyperv: Remove aliases with X64 in their name
  (jsc#sle-12891).
- commit b986d8b
* Fri Nov  6 2020 yousaf.kaukab@suse.com
- rtc: pcf2127: fix alarm handling (jsc#SLE-12251).
- rtc: pcf2127: add alarm support (jsc#SLE-12251).
- rtc: pcf2127: add pca2129 device id (jsc#SLE-12251).
- rtc: pcf2127: watchdog: handle nowayout feature (jsc#SLE-12251).
- rtc: fsl-ftm-alarm: fix freeze(s2idle) failed to wake
  (jsc#SLE-12251).
- rtc: pcf2127: report battery switch over (jsc#SLE-12251).
- rtc: pcf2127: set regmap max_register (jsc#SLE-12251).
- rtc: pcf2127: remove unnecessary #ifdef (jsc#SLE-12251).
- rtc: pcf2127: let the core handle rtc range (jsc#SLE-12251).
- rtc: add new VL flag for backup switchover (jsc#SLE-12251).
- rtc: fsl-ftm-alarm: report alarm to core (jsc#SLE-12251).
- rtc: make definitions in include/uapi/linux/rtc.h actually
  useful for user space (jsc#SLE-12251).
- rtc: fsl-ftm-alarm: enable acpi support (jsc#SLE-12251).
- rtc: rx8010: return meaningful value for RTC_VL_READ
  (jsc#SLE-12251).
- rtc: rx8010: remove RTC_VL_CLR handling (jsc#SLE-12251).
- rtc: rv8803: return meaningful value for RTC_VL_READ
  (jsc#SLE-12251).
- rtc: rv8803: avoid clearing RV8803_FLAG_V2F in RTC_VL_CLR
  (jsc#SLE-12251).
- rtc: rv3028: return meaningful value for RTC_VL_READ
  (jsc#SLE-12251).
- rtc: rv3028: remove RTC_VL_CLR handling (jsc#SLE-12251).
- rtc: pcf85063: return meaningful value for RTC_VL_READ
  (jsc#SLE-12251).
- rtc: pcf85063: remove RTC_VL_CLR handling (jsc#SLE-12251).
- rtc: pcf8563: return meaningful value for RTC_VL_READ
  (jsc#SLE-12251).
- rtc: pcf8563: stop caching voltage_low (jsc#SLE-12251).
- rtc: pcf8563: remove conditional compilation (jsc#SLE-12251).
- rtc: pcf8563: remove RTC_VL_CLR handling (jsc#SLE-12251).
- rtc: pcf8523: return meaningful value for RTC_VL_READ
  (jsc#SLE-12251).
- rtc: pcf2127: return meaningful value for RTC_VL_READ
  (jsc#SLE-12251).
- rtc: abx80x: return meaningful value for RTC_VL_READ
  (jsc#SLE-12251).
- rtc: Document RTC_VL_READ and RTC_VL_CLR ioctls (jsc#SLE-12251).
- rtc: define RTC_VL_READ values (jsc#SLE-12251).
- rtc: fsl-ftm-alarm: avoid struct rtc_time conversions
  (jsc#SLE-12251).
- rtc: fsl-ftm-alarm: switch to rtc_time64_to_tm/rtc_tm_to_time64
  (jsc#SLE-12251).
- rtc: fsl-ftm-alarm: switch to ktime_get_real_seconds
  (jsc#SLE-12251).
- rtc: pcf2127: handle boot-enabled watchdog feature
  (jsc#SLE-12251).
- rtc: pcf2127: bugfix: watchdog build dependency (jsc#SLE-12251).
- rtc: pcf2127: add tamper detection support (jsc#SLE-12251).
- rtc: pcf2127: add watchdog feature support (jsc#SLE-12251).
- rtc: pcf2127: cleanup register and bit defines (jsc#SLE-12251).
- rtc: pcf2127: convert to devm_rtc_allocate_device
  (jsc#SLE-12251).
- commit 7f138ed
* Fri Nov  6 2020 yousaf.kaukab@suse.com
- spi: fsl-dspi: fix NULL pointer dereference (jsc#SLE-12251).
- commit 536efbf
* Fri Nov  6 2020 yousaf.kaukab@suse.com
- spi: fsl-dspi: fix use-after-free in remove path
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: use XSPI mode instead of DMA for DPAA2 SoCs
  (jsc#SLE-12251).
- dmaengine: Extend NXP QDMA driver to check transmission errors
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Initialize completion before possible
  interrupt (jsc#SLE-12251).
- spi: spi-fsl-dspi: Fix external abort on interrupt in resume
  or exit paths (jsc#SLE-12251).
- spi: spi-fsl-dspi: Fix lockup if device is shutdown during
  SPI transfer (jsc#SLE-12251).
- spi: spi-fsl-dspi: Fix lockup if device is removed during SPI
  transfer (jsc#SLE-12251).
- spi: spi-fsl-dspi: Free DMA memory with matching function
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: fix native data copy (jsc#SLE-12251).
- spi: spi-fsl-dspi: Adding shutdown hook (jsc#SLE-12251).
- spi: spi-fsl-qspi: Fix return value check of devm_ioremap()
  in probe (jsc#SLE-12251).
- spi: spi-fsl-qspi: Reduce devm_ioremap size to 4 times AHB
  buffer size (jsc#SLE-12251).
- spi: spi-fsl-dspi: Add support for LS1028A (jsc#SLE-12251).
- spi: spi-fsl-dspi: Move invariant configs out of
  dspi_transfer_one_message (jsc#SLE-12251).
- spi: spi-fsl-dspi: Fix interrupt-less DMA mode taking an XSPI
  code path (jsc#SLE-12251).
- spi: spi-fsl-dspi: Avoid NULL pointer in dspi_slave_abort for
  non-DMA mode (jsc#SLE-12251).
- spi: spi-fsl-dspi: Replace interruptible wait queue with a
  simple completion (jsc#SLE-12251).
- spi: spi-fsl-dspi: Protect against races on
  dspi->words_in_flight (jsc#SLE-12251).
- spi: spi-fsl-dspi: Avoid reading more data than written in
  EOQ mode (jsc#SLE-12251).
- spi: spi-fsl-dspi: Fix bits-per-word acceleration in DMA mode
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Fix little endian access to PUSHR CMD and
  TXDATA (jsc#SLE-12251).
- spi: spi-fsl-dspi: Don't access reserved fields in SPI_MCR
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: fix DMA mapping (jsc#SLE-12251).
- spi: spi-fsl-dspi: Take software timestamp in dspi_fifo_write
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Use EOQ for last word in buffer even for
  XSPI mode (jsc#SLE-12251).
- spi: spi-fsl-dspi: Optimize dspi_setup_accel for lowest
  interrupt count (jsc#SLE-12251).
- spi: spi-fsl-dspi: Accelerate transfers using larger word size
  if possible (jsc#SLE-12251).
- spi: spi-fsl-dspi: Convert TCFQ users to XSPI FIFO mode
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Implement .max_message_size method for EOQ
  mode (jsc#SLE-12251).
- spi: spi-fsl-dspi: Rename fifo_{read,write} and
  {tx,cmd}_fifo_write (jsc#SLE-12251).
- spi: spi-fsl-dspi: Add comments around dspi_pop_tx and
  dspi_push_rx functions (jsc#SLE-12251).
- spi: spi-fsl-dspi: Don't mask off undefined bits
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Remove unused chip->void_write_data
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Simplify bytes_per_word gymnastics
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Make bus-num property optional
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Add specific compatibles for all Layerscape
  SoCs (jsc#SLE-12251).
- spi: spi-fsl-dspi: Convert the instantiations that support it
  to DMA (jsc#SLE-12251).
- spi: spi-fsl-dspi: Support SPI software timestamping in all
  non-DMA modes (jsc#SLE-12251).
- spi: spi-fsl-dspi: LS2080A and LX2160A support XSPI mode
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Parameterize the FIFO size and DMA buffer
  size (jsc#SLE-12251).
- spi: spi-fsl-dspi: Use specific compatible strings for all
  SoC instantiations (jsc#SLE-12251).
- spi: spi-fsl-dspi: Use dma_request_chan() instead
  dma_request_slave_channel() (jsc#SLE-12251).
- spi: spi-fsl-dspi: Fix 16-bit word order in 32-bit XSPI mode
  (jsc#SLE-12251).
- spi: Don't look at TX buffer for PTP system timestamping
  (jsc#SLE-12251).
- spi: nxp-fspi: Use devm API to fix missed unregistration of
  controller (jsc#SLE-12251).
- spi: use new `spi_transfer_delay_exec` helper where
  straightforward (jsc#SLE-12251).
- spi: spi-fsl-dspi: Implement the PTP system timestamping for
  TCFQ mode (jsc#SLE-12251).
- spi: Add a PTP system timestamp to the transfer structure
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Always use the TCFQ devices in poll mode
  (jsc#SLE-12251).
- spi: Introduce dspi_slave_abort() function for NXP's dspi SPI
  driver (jsc#SLE-12251).
- spi: Use an abbreviated pointer to ctlr->cur_msg in
  __spi_pump_messages (jsc#SLE-12251).
- spi: spi-fsl-dspi: Fix race condition in TCFQ/EOQ interrupt
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Use poll mode in case the platform IRQ is
  missing (jsc#SLE-12251).
- spi: spi-fsl-dspi: Remove impossible to reach error check
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Exit the ISR with IRQ_NONE when it's not ours
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Reduce indentation level in dspi_interrupt
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Move dspi_interrupt above
  dspi_transfer_one_message (jsc#SLE-12251).
- spi: spi-fsl-dspi: Fix typos (jsc#SLE-12251).
- spi: spi-fsl-dspi: Use reverse Christmas tree declaration order
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Replace legacy spi_master names with
  spi_controller (jsc#SLE-12251).
- spi: spi-fsl-dspi: Remove pointless assignment of
  master->transfer to NULL (jsc#SLE-12251).
- spi: spi-fsl-dspi: Remove unused initialization of 'ret'
  in dspi_probe (jsc#SLE-12251).
- spi: spi-fsl-dspi: Reduce indentation in dspi_release_dma()
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Change usage pattern of SPI_MCR_* and
  SPI_CTAR_* macros (jsc#SLE-12251).
- spi: spi-fsl-dspi: Demistify magic value in SPI_SR_CLEAR
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Use BIT() and GENMASK() macros
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Remove unused defines and includes
  (jsc#SLE-12251).
- spi: spi-fsl-dspi: Fix code alignment (jsc#SLE-12251).
- commit 99395cb
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/dasd: Process FCES path event notification (jsc#SLE-13767
  bsc#1178420 LTC#185092).
- s390/dasd: Prepare for additional path event handling
  (jsc#SLE-13767 bsc#1178420 LTC#185092).
- s390/dasd: Display FC Endpoint Security information via sysfs
  (jsc#SLE-13767 bsc#1178420 LTC#185092).
- s390/dasd: Fix operational path inconsistency (jsc#SLE-13767
  bsc#1178420 LTC#185092).
- s390/dasd: Store path configuration data during path handling
  (jsc#SLE-13767 bsc#1178420 LTC#185092).
- s390/dasd: Move duplicate code to separate function
  (jsc#SLE-13767 bsc#1178420 LTC#185092).
- s390/dasd: Remove unused parameter from dasd_generic_probe()
  (jsc#SLE-13767 bsc#1178420 LTC#185092).
- s390/cio: Add support for FCES status notification
  (jsc#SLE-13767 bsc#1178420 LTC#185092).
- s390/cio: Provide Endpoint-Security Mode per CU (jsc#SLE-13767
  bsc#1178420 LTC#185092).
- s390/cio: Export information about Endpoint-Security
  (jsc#SLE-13767 bsc#1178420 LTC#185092).
- commit 539be3e
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/kvm: diagnose 0x318 sync and reset (jsc#SLE-13746).
- s390/setup: diag 318: refactor struct (jsc#SLE-13746).
- commit 3fd9e36
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/zcrypt: fix wrong format specifications (git-fixes).
- commit a98dc9e
* Fri Nov  6 2020 mkoutny@suse.com
- memcg: fix NULL pointer dereference in
  __mem_cgroup_usage_unregister_event (bsc#1177703).
- commit 676737e
* Fri Nov  6 2020 ptesarik@suse.cz
- s390/zcrypt: Introduce Failure Injection feature (jsc#SLE-13815
  bsc#1178402 LTC#186349).
- s390/zcrypt: move ap_msg param one level up the call chain
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/ap/zcrypt: revisit ap and zcrypt error handling
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/ap: Support AP card SCLP config and deconfig operations
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/sclp: Add support for SCLP AP adapter config/deconfig
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/ap: add card/queue deconfig state (jsc#SLE-13815
  bsc#1178402 LTC#186349).
- s390/ap: add error response code field for ap queue devices
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/ap: split ap queue state machine state from device state
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/zcrypt: New config switch CONFIG_ZCRYPT_DEBUG
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/zcrypt: introduce msg tracking in zcrypt functions
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/zcrypt: remove set_fs() invocation in zcrypt device driver
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/ap: rework crypto config info and default domain code
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/zcrypt: provide cex4 cca sysfs attributes for cex3
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/ap: rename and clarify ap state machine related stuff
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/zcrypt: split ioctl function into smaller code units
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/zcrypt: code beautification and struct field renames
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/zcrypt: fix smatch warnings (jsc#SLE-13815 bsc#1178402
  LTC#186349).
- s390/ap: introduce new ap function ap_get_qdev() (jsc#SLE-13815
  bsc#1178402 LTC#186349).
- s390/zcrypt: replace snprintf/sprintf with scnprintf
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/zcrypt: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/zcrypt: Support for CCA protected key block version 2
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/zcrypt: fix card and queue total counter wrap
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/zcrypt: move ap device reset from bus to driver code
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- s390/zcrypt: handle new reply code FILTERED_BY_HYPERVISOR
  (jsc#SLE-13815 bsc#1178402 LTC#186349).
- commit 2c71d4a
* Fri Nov  6 2020 glin@suse.com
- bpf: Fix sysfs export of empty BTF section (bsc#1177028).
- bpf: Do not use bucket_lock for hashmap iterator (bsc#1177028).
- bpf: Avoid visit same object multiple times (bsc#1177028).
- bpf: Fix a rcu_sched stall issue with bpf task/task_file
  iterator (bsc#1177028).
- bpf: Iterate through all PT_NOTE sections when looking for
  build id (bsc#1177028).
- bpf: Delete repeated words in comments (bsc#1177028).
- bpf: Change uapi for bpf iterator map elements (bsc#1177028).
- bpf: Add support for forced LINK_DETACH command (bsc#1177028).
- bpf: Add missing newline characters in verifier error messages
  (bsc#1177028).
- bpf: Fix build without CONFIG_NET when using BPF XDP link
  (bsc#1177028).
- bpf: Fix swapped arguments in calls to check_buffer_access
  (bsc#1177028).
- bpf: Implement BPF XDP link-specific introspection APIs
  (bsc#1177028).
- bpf, xdp: Implement LINK_UPDATE for BPF XDP link (bsc#1177028).
- bpf, xdp: Add bpf_link-based XDP attachment API (bsc#1177028).
- bpf, xdp: Extract common XDP program attachment logic
  (bsc#1177028).
- bpf, xdp: Maintain info on attached XDP BPF programs in
  net_device (bsc#1177028).
- bpf: Fix build on architectures with special bpf_user_pt_regs_t
  (bsc#1177028).
- bpf/local_storage: Fix build without CONFIG_CGROUP
  (bsc#1177028).
- bpf: Make cgroup storages shared between programs on the same
  cgroup (bsc#1177028).
- bpf: Fail PERF_EVENT_IOC_SET_BPF when bpf_get_[stack|stackid]
  cannot work (bsc#1177028).
- bpf: Separate bpf_get_[stack|stackid] for perf events BPF
  (bsc#1177028).
- bpf: Implement bpf iterator for sock local storage map
  (bsc#1177028).
- bpf: Implement bpf iterator for array maps (bsc#1177028).
- bpf: Implement bpf iterator for hash maps (bsc#1177028).
- bpf: Implement bpf iterator for map elements (bsc#1177028).
- bpf: Support readonly/readwrite buffers in verifier
  (bsc#1177028).
- bpf: Refactor to provide aux info to bpf_iter_init_seq_priv_t
  (bsc#1177028).
- bpf: Refactor bpf_iter_reg to have separate seq_info member
  (bsc#1177028).
- bpf: Add bpf_prog iterator (bsc#1177028).
- bpf: net: Use precomputed btf_id for bpf iterators (bsc#1177028).
  Refresh patches.suse/bpf-Fix-pos-computation-for-bpf_iter-seq_ops-start.patch
- bpf: Make btf_sock_ids global (bsc#1177028).
- bpf: Add BTF_ID_LIST_GLOBAL in btf_ids.h (bsc#1177028).
- tools/bpf: Sync btf_ids.h to tools (bsc#1177028).
- bpf: Compute bpf_skc_to_*() helper socket btf ids at build time
  (bsc#1177028).
- bpf: cpumap: Fix possible rcpu kthread hung (bsc#1177028).
- bpf, netns: Fix build without CONFIG_INET (bsc#1177028).
- inet: Run SK_LOOKUP BPF program on socket lookup (bsc#1177028).
- inet: Extract helper for selecting socket from reuseport group
  (bsc#1177028).
- bpf: Introduce SK_LOOKUP program type with a dedicated attach
  point (bsc#1177028).
- bpf, netns: Handle multiple link attachments (bsc#1177028).
- bpf: cpumap: Implement XDP_REDIRECT for eBPF programs attached
  to map entries (bsc#1177028).
- bpf: cpumap: Add the possibility to attach an eBPF program to
  cpumap (bsc#1177028).
- cpumap: Formalize map value as a named struct (bsc#1177028).
- net: Refactor xdp_convert_buff_to_frame (bsc#1177028).
- bpf: Fix cross build for CONFIG_DEBUG_INFO_BTF option
  (bsc#1177028).
- bpf: Fix build for disabled CONFIG_DEBUG_INFO_BTF option
  (bsc#1177028).
- tools headers: Adopt verbatim copy of btf_ids.h from kernel
  sources (bsc#1177028).
- bpf: Use BTF_ID to resolve bpf_ctx_convert struct (bsc#1177028).
- bpf: Remove btf_id helpers resolving (bsc#1177028).
- bpf: Resolve BTF IDs in vmlinux image (bsc#1177028).
- bpf: Add BTF_ID_LIST/BTF_ID/BTF_ID_UNUSED macros (bsc#1177028).
- bpf: Add resolve_btfids tool to resolve BTF IDs in ELF object
  (bsc#1177028).
- libbpf: Add support for BPF_CGROUP_INET_SOCK_RELEASE
  (bsc#1177028).
- bpf: Add BPF_CGROUP_INET_SOCK_RELEASE hook (bsc#1177028).
- bpf: Fix build without CONFIG_STACKTRACE (bsc#1177028).
- bpf: Introduce helper bpf_get_task_stack() (bsc#1177028).
- perf: Expose get/put_callchain_entry() (bsc#1177028).
- bpf: Remove redundant synchronize_rcu (bsc#1177028).
- bpf: Add bpf_skc_to_udp6_sock() helper (bsc#1177028).
- net: bpf: Implement bpf iterator for udp (bsc#1177028).
- net: bpf: Add bpf_seq_afinfo in udp_iter_state (bsc#1177028).
- bpf: Add bpf_skc_to_{tcp, tcp_timewait, tcp_request}_sock()
  helpers (bsc#1177028).
- bpf: Add bpf_skc_to_tcp6_sock() helper (bsc#1177028).
- bpf: Allow tracing programs to use bpf_jiffies64() helper
  (bsc#1177028).
- net: bpf: Implement bpf iterator for tcp (bsc#1177028).
- net: bpf: Add bpf_seq_afinfo in tcp_iter_state (bsc#1177028).
- bpf: Set map_btf_{name, id} for all map types (bsc#1177028).
- bpf: Support access to bpf map fields (bsc#1177028).
- bpf: Switch btf_parse_vmlinux to btf_find_by_name_kind
  (bsc#1177028).
- bpf: Avoid verifier failure for 32bit pointer arithmetic
  (bsc#1177028).
- bpf: Support llvm-objcopy for vmlinux BTF (bsc#1177028).
- powerpc: Include .BTF section (bsc#1177028).
- commit 7b79280
* Fri Nov  6 2020 tiwai@suse.de
- regulator: defer probe when trying to get voltage from
  unresolved supply (git-fixes).
- usb: cdc-acm: fix cooldown mechanism (git-fixes).
- drivers: watchdog: rdc321x_wdt: Fix race condition bugs
  (git-fixes).
- power: supply: test_power: add missing newlines when printing
  parameters by sysfs (git-fixes).
- uio: free uio id after uio file node is freed (git-fixes).
- usb: xhci: omit duplicate actions when suspending a runtime
  suspended host (git-fixes).
- USB: adutux: fix debugging (git-fixes).
- usb: typec: tcpm: During PR_SWAP, source caps should be sent
  only after tSwapSourceStart (git-fixes).
- commit 87c92c0
* Fri Nov  6 2020 tiwai@suse.de
- PM: runtime: Drop runtime PM references to supplier on link
  removal (git-fixes).
- staging: octeon: Drop on uncorrectable alignment or FCS error
  (git-fixes).
- staging: octeon: repair "fixed-link" support (git-fixes).
- power: supply: bq27xxx: report "not charging" on all types
  (git-fixes).
- p54: avoid accessing the data mapped to streaming DMA
  (git-fixes).
- PCI/ACPI: Whitelist hotplug ports for D3 if power managed by
  ACPI (git-fixes).
- media: uvcvideo: Fix dereference of out-of-bound list iterator
  (git-fixes).
- media: uvcvideo: Fix uvc_ctrl_fixup_xu_info() not having any
  effect (git-fixes).
- media: imx274: fix frame interval handling (git-fixes).
- commit abe310e
* Fri Nov  6 2020 tiwai@suse.de
- staging: comedi: cb_pcidas: Allow 2-channel commands for AO
  subdevice (git-fixes).
- ath10k: fix VHT NSS calculation when STBC is enabled
  (git-fixes).
- ath10k: start recovery process when payload length exceeds
  max htc length for sdio (git-fixes).
- leds: bcm6328, bcm6358: use devres LED registering function
  (git-fixes).
- ACPI / extlog: Check for RDMSR failure (git-fixes).
- ACPI: video: use ACPI backlight for HP 635 Notebook (git-fixes).
- media: tw5864: check status of tw5864_frameinterval_get
  (git-fixes).
- media: platform: Improve queue set up flow for bug fixing
  (git-fixes).
- commit 12c4dfb
* Thu Nov  5 2020 ptesarik@suse.cz
- s390/ipl: add support to control memory clearing for nvme re-IPL
  (jsc#SLE-13778).
- commit 693472e
* Thu Nov  5 2020 tonyj@suse.de
- perf/x86/intel/uncore: Support PCIe3 unit on Snow Ridge
  (jsc#SLE-13340).
- perf/x86/intel/uncore: Generic support for the PCI sub driver
  (jsc#SLE-13340).
- perf/x86/intel/uncore: Factor out uncore_pci_pmu_unregister()
  (jsc#SLE-13340).
- perf/x86/intel/uncore: Factor out uncore_pci_pmu_register()
  (jsc#SLE-13340).
- perf/x86/intel/uncore: Factor out uncore_pci_find_dev_pmu()
  (jsc#SLE-13340).
- perf/x86/intel/uncore: Factor out uncore_pci_get_dev_die_info()
  (jsc#SLE-13340).
- perf/x86/intel/uncore: Remove PCIe3 unit for SNR
  (jsc#SLE-13340).
- commit 03fe2f4
* Thu Nov  5 2020 lduncan@suse.com
- scsi: be2iscsi: Fix a theoretical leak in beiscsi_create_eqs()
  (jsc#SLE-15082).
- scsi: be2iscsi: Correct misdocumentation of function param 'ep'
  (jsc#SLE-15082).
- scsi: be2iscsi: Add missing function parameter description
  (jsc#SLE-15082).
- scsi: be2iscsi: Fix misdocumentation of 'pcontext'
  (jsc#SLE-15082).
- scsi: be2iscsi: Fix API/documentation slip (jsc#SLE-15082).
- scsi: be2iscsi: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-15082).
- commit 9b829c2
* Thu Nov  5 2020 tonyj@suse.de
- perf/x86/msr: Add Jasper Lake support (jsc#SLE-12983).
- perf/x86/intel: Add Jasper Lake support (jsc#SLE-12983).
- perf/x86/msr: Add Tremont support (jsc#SLE-12983).
- commit e3b491b
* Thu Nov  5 2020 yousaf.kaukab@suse.com
- spi: spi-fsl-dspi: remove fixes to prepare for complete driver update
- commit e69ea7a
* Thu Nov  5 2020 nsaenzjulienne@suse.de
- usb: chipidea: msm: Ensure proper controller reset using role
  switch API (jsc#SLE-16106).
- commit 3c0e524
* Thu Nov  5 2020 nsaenzjulienne@suse.de
- usb: chipidea: ci_hdrc_imx: restore pinctrl (jsc#SLE-16106).
- usb: chipidea: imx: add two samsung picophy parameters tuning
  implementation (jsc#SLE-16106).
- usb: chipidea: imx: get available runtime dr mode for wakeup
  setting (jsc#SLE-16106).
- usb: chipidea: add query_available_role interface
  (jsc#SLE-16106).
- drivers/perf: Prevent forced unbinding of PMU drivers
  (jsc#SLE-16106).
- drivers/perf: Fix kernel panic when rmmod PMU modules during
  perf sampling (jsc#SLE-16106).
- mtd: rawnand: gpmi: Fix runtime PM imbalance in gpmi_nand_probe
  (jsc#SLE-16106).
- mtd: rawnand: gpmi: Stop using nand_release() (jsc#SLE-16106).
- usb: chipidea: Enable user-space triggered role-switching
  (jsc#SLE-16106).
- usb: chipidea: udc: add software sg list support
  (jsc#SLE-16106).
- usb: chipidea: usbmisc_imx: using different ops for imx7d and
  imx7ulp (jsc#SLE-16106).
- usb: chipidea: pull down dp for possible charger detection
  operation (jsc#SLE-16106).
- usb: chipidea: introduce imx7d USB charger detection
  (jsc#SLE-16106).
- usb: chipidea: introduce CI_HDRC_CONTROLLER_VBUS_EVENT glue
  layer use (jsc#SLE-16106).
- usb: chipidea: core: show the real pointer value for register
  (jsc#SLE-16106).
- mtd: rawnand: gpmi: Use dma_request_chan() instead
  dma_request_slave_channel() (jsc#SLE-16106).
- usb: chipidea: otg: handling vbus disconnect event occurred
  during system suspend (jsc#SLE-16106).
- usb: chipidea: udc: using structure ci_hdrc device for runtime
  PM (jsc#SLE-16106).
- usb: chipidea: udc: fix sleeping function called from invalid
  context (jsc#SLE-16106).
- drivers/perf: fsl_imx8_ddr: Correct the CLEAR bit definition
  (jsc#SLE-16106).
- usb: chipidea: add inline for ci_hdrc_host_driver_init if host
  is not defined (jsc#SLE-16106).
- usb: chipidea: handle single role for usb role class
  (jsc#SLE-16106).
- PM / devfreq: imx8m-ddrc: Fix inconsistent IS_ERR and PTR_ERR
  (jsc#SLE-16106).
- PM / devfreq: imx8m-ddrc: Remove unused defines (jsc#SLE-16106).
- PM / devfreq: Add dynamic scaling for imx8m ddr controller (jsc#SLE-16106).
- supported.conf: Add imx8m-ddrc
- Update config files.
- perf/imx_ddr: Fix cpu hotplug state cleanup (jsc#SLE-16106).
- usb: chipidea: imx: pinctrl for HSIC is optional
  (jsc#SLE-16106).
- usb: chipidea: imx: refine the error handling for hsic
  (jsc#SLE-16106).
- usb: chipidea: imx: change hsic power regulator as optional
  (jsc#SLE-16106).
- usb: chipidea: imx: check data->usbmisc_data against NULL
  before access (jsc#SLE-16106).
- usb: chipidea: core: change vbus-regulator as optional
  (jsc#SLE-16106).
- usb: chipidea: imx: enable vbus and id wakeup only for OTG
  events (jsc#SLE-16106).
- usb: chipidea: udc: protect usb interrupt enable
  (jsc#SLE-16106).
- usb: chipidea: udc: add new API ci_hdrc_gadget_connect
  (jsc#SLE-16106).
- usb: chipidea: debug: create debugfs directory under usb root
  (jsc#SLE-16106).
- perf/imx_ddr: Dump AXI ID filter info to userspace
  (jsc#SLE-16106).
- perf/imx_ddr: Add driver for DDR PMU in i.MX8MPlus
  (jsc#SLE-16106).
- perf/imx_ddr: Add enhanced AXI ID filter support
  (jsc#SLE-16106).
- usb: chipidea: add role switch class support (jsc#SLE-16106).
- Refresh: patches.suse/usb-chipidea-tegra-Add-USB_TEGRA_PHY-to-driver-s-dep.patch
- usb: chipidea: msm: Use device-managed registration API
  (jsc#SLE-16106).
- USB: chipidea: convert platform driver to use dev_groups
  (jsc#SLE-16106).
- usb: chipidea: udc: remove redundant assignment to variable
  retval (jsc#SLE-16106).
- perf/imx_ddr: Add support for AXI ID filtering (jsc#SLE-16106).
- commit 1b4316b
* Thu Nov  5 2020 mbenes@suse.cz
- Do not create null.i000.ipa-clones file (bsc#1178330)
  Kbuild cc-option compiles /dev/null file to test for an option
  availability. Filter out -fdump-ipa-clones so that null.i000.ipa-clones
  file is not generated in the process.
- commit 1425d4e
* Thu Nov  5 2020 varad.gautam@suse.com
- net: mscc: ocelot: fix race condition with TX timestamping
  (bsc#1178461).
- commit 9045c8f
* Thu Nov  5 2020 nsaenzjulienne@suse.de
- tty: serial: imx: fix link error with
  CONFIG_SERIAL_CORE_CONSOLE=n (jsc#SLE-16106).
- commit d3ac1b4
* Thu Nov  5 2020 nsaenzjulienne@suse.de
- crypto: caam/qi2 - add support for XTS with 16B IV
  (jsc#SLE-16106).
- crypto: caam/qi - add support for XTS with 16B IV
  (jsc#SLE-16106).
- crypto: caam/jr - add support for XTS with 16B IV
  (jsc#SLE-16106).
- crypto: caam - add xts check for block length equal to zero
  (jsc#SLE-16106).
- crypto: caam/qi2 - add support for more XTS key lengths
  (jsc#SLE-16106).
- crypto: caam/qi - add support for more XTS key lengths
  (jsc#SLE-16106).
- crypto: caam/jr - add support for more XTS key lengths
  (jsc#SLE-16106).
- crypto: caam/qi2 - add fallback for XTS with more than 8B IV
  (jsc#SLE-16106).
- crypto: caam/qi - add fallback for XTS with more than 8B IV
  (jsc#SLE-16106).
- crypto: caam/jr - add fallback for XTS with more than 8B IV
  (jsc#SLE-16106).
- crypto: caam - Convert to DEFINE_SHOW_ATTRIBUTE (jsc#SLE-16106).
- crypto: caam - Fix kerneldoc (jsc#SLE-16106).
- crypto: caam - use traditional error check pattern
  (jsc#SLE-16106).
- crypto: caam - Move debugfs fops into standalone file
  (jsc#SLE-16106).
- i2c: mediatek: Fix generic definitions for bus frequency
  (jsc#SLE-16106).
- commit a0a06cb
* Thu Nov  5 2020 oneukum@suse.com
- crypto: sparc/des - switch to new verification routines
  (jsc#SLE-14454).
  Refresh
  patches.suse/crypto-safexcel-des-switch-to-new-verification-routines.patch.
- commit e1e456b
* Thu Nov  5 2020 jslaby@suse.cz
- efi/x86: move UV_SYSTAB handling into arch/x86 (bnc#1177710
  jsc#SLE-13285).
- Refresh
  patches.suse/x86-platform-uv-Add-UV-Hubbed-Hubless-Proc-FS-Files.patch.
- Refresh
  patches.suse/x86-platform-uv-Add-return-code-to-UV-BIOS-Init-func.patch.
- Refresh
  patches.suse/x86-platform-uv-Return-UV-Hubless-System-Type.patch.
- commit 80f42a1
* Thu Nov  5 2020 oneukum@suse.com
- crypto: inside-secure - Remove redundant DES ECB & CBC keysize
  check (jsc#SLE-14454).
- commit 715e0ad
* Thu Nov  5 2020 oneukum@suse.com
- crypto: inside-secure - added support for rfc3686(ctr(aes))
  (jsc#SLE-14454).
- commit 46ca062
* Thu Nov  5 2020 oneukum@suse.com
- crypto: inside-secure - add support for
  authenc(hmac(sha1),cbc(des3_ede)) (jsc#SLE-14454).
- commit 4c58dd2
* Thu Nov  5 2020 oneukum@suse.com
- crypto: inside-secure - fix EINVAL error (buf overflow) for
  AEAD decrypt (jsc#SLE-14454).
- commit 966437f
* Thu Nov  5 2020 oneukum@suse.com
- crypto: inside-secure - fix scatter/gather list to descriptor
  conversion (jsc#SLE-14454).
- commit 20d947f
* Thu Nov  5 2020 oneukum@suse.com
- crypto: inside-secure - fix incorrect skcipher output IV
  (jsc#SLE-14454).
- commit d250bc9
* Thu Nov  5 2020 glin@suse.com
- s390/bpf: Tolerate not converging code shrinking (bsc#1177028).
- s390/bpf: Use brcl for jumping to exit_ip if necessary
  (bsc#1177028).
- s390/bpf: Fix sign extension in branch_ku (bsc#1177028).
- bpf: revert "test_bpf: Flag tests that cannot be jited on s390"
  (bsc#1177028).
- commit 487e300
* Thu Nov  5 2020 glin@suse.com
- s390/bpf: Use bcr 0,%%0 as tail call nop filler (bsc#1177028).
- commit bdd749d
* Wed Nov  4 2020 ailiop@suse.com
- xfs: don't update mtime on COW faults (bsc#1167030).
- commit cbce094
* Wed Nov  4 2020 ailiop@suse.com
- xfs: complain if anyone tries to create a too-large buffer
  log item (bsc#1166146).
- commit 293e483
* Wed Nov  4 2020 msuchanek@suse.de
- kABI: revert use_mm name change (MM Functionality, bsc#1178426).
- commit abb50be
* Wed Nov  4 2020 ailiop@suse.com
- xfs: remove unused variable 'done' (bsc#1166166).
- commit 61fcffc
* Wed Nov  4 2020 ailiop@suse.com
- xfs: truncate should remove all blocks, not just to the end
  of the page cache (bsc#1166166).
- commit e2d039c
* Wed Nov  4 2020 ailiop@suse.com
- xfs: introduce XFS_MAX_FILEOFF (bsc#1166166).
- commit 76c1570
* Wed Nov  4 2020 lduncan@suse.com
- mpt3sas: Bump driver version to 35.101.00.00 (jsc#SLE-16914).
- mpt3sas: add module parameter multipath_on_hba (jsc#SLE-16914).
- mpt3sas: Handle vSES vphy object during HBA reset
  (jsc#SLE-16914).
- mpt3sas: Add bypass_dirty_port_flag parameter (jsc#SLE-16914).
- mpt3sas: Handling HBA vSES device (jsc#SLE-16914).
- mpt3sas: Set valid PhysicalPort in SMPPassThrough
  (jsc#SLE-16914).
- mpt3sas: Update hba_port objects after host reset
  (jsc#SLE-16914).
- mpt3sas: Get sas_device objects using device's rphy
  (jsc#SLE-16914).
- mpt3sas: Rename transport_del_phy_from_an_existing_port
  (jsc#SLE-16914).
- mpt3sas: Get device objects using sas_address & portID
  (jsc#SLE-16914).
- mpt3sas: Update hba_port's sas_address & phy_mask
  (jsc#SLE-16914).
- mpt3sas: Rearrange _scsih_mark_responding_sas_device()
  (jsc#SLE-16914).
- mpt3sas: Allocate memory for hba_port objects (jsc#SLE-16914).
- mpt3sas: Define hba_port structure (jsc#SLE-16914).
- scsi: mpt3sas: A small correction in _base_process_reply_queue
  (jsc#SLE-16914).
- scsi: mpt3sas: Fix sync irqs (jsc#SLE-16914).
- scsi: mpt3sas: Detect tampered Aero and Sea adapters
  (jsc#SLE-16914).
- scsi: mpt3sas: Remove pci-dma-compat wrapper API
  (jsc#SLE-16914).
- scsi: mpt3sas: Remove superfluous memset() (jsc#SLE-16914).
- scsi: mpt3sas: Update driver version to 35.100.00.00
  (jsc#SLE-16914).
- scsi: mpt3sas: Postprocessing of target and LUN reset
  (jsc#SLE-16914).
- scsi: mpt3sas: Add functions to check if any cmd is outstanding
  on Target and LUN (jsc#SLE-16914).
- scsi: mpt3sas: Rename and export interrupt mask/unmask functions
  (jsc#SLE-16914).
- scsi: mpt3sas: Cancel the running work during host reset
  (jsc#SLE-16914).
- scsi: mpt3sas: Dump system registers for debugging
  (jsc#SLE-16914).
- scsi: mpt3sas: Memset config_cmds.reply buffer with zeros
  (jsc#SLE-16914).
- scsi: mpt3sas: Don't call disable_irq from IRQ poll handler
  (jsc#SLE-16914).
- scsi: mpt3sas: Fix set but unused variable (jsc#SLE-16914).
- scsi: mpt3sas: Fix error returns in BRM_status_show
  (jsc#SLE-16914).
- scsi: mpt3sas: Fix unlock imbalance (jsc#SLE-16914).
- scsi: mpt3sas: Fix memset() in non-RDPQ mode (jsc#SLE-16914).
- scsi: mpt3sas: Fix reply queue count in non RDPQ mode
  (jsc#SLE-16914).
- scsi: mpt3sas: Fix double free warnings (jsc#SLE-16914).
- scsi: mpt3sas: Disable DIF when prot_mask set to zero
  (jsc#SLE-16914).
- scsi: mpt3sas: Capture IOC data for debugging purposes
  (jsc#SLE-16914).
- scsi: mpt3sas: Use true, false for ioc->use_32bit_dma
  (jsc#SLE-16914).
- scsi: mpt3sas: Remove NULL check before freeing function
  (jsc#SLE-16914).
- scsi: mpt3sas: Update mpt3sas version to 33.101.00.00
  (jsc#SLE-16914).
- scsi: mpt3sas: Handle RDPQ DMA allocation in same 4G region
  (jsc#SLE-16914).
- scsi: mpt3sas: Separate out RDPQ allocation to new function
  (jsc#SLE-16914).
- scsi: mpt3sas: Rename function name is_MSB_are_same
  (jsc#SLE-16914).
- scsi: mpt3sas: Don't change the DMA coherent mask after
  allocations (jsc#SLE-16914).
- scsi: mpt3sas: use true,false for bool variables
  (jsc#SLE-16914).
- commit fb319df
* Wed Nov  4 2020 nsaenzjulienne@suse.de
- net: fec: Fix phy_device lookup for phy_reset_after_clk_enable()
  (jsc#SLE-16106).
- net: fec: Fix PHY init after phy_reset_after_clk_enable()
  (jsc#SLE-16106).
- net: fec_mpc52xx: Replace in_interrupt() usage (jsc#SLE-16106).
- net: fec: ptp: remove unused variable 'ns' in fec_time_keep()
  (jsc#SLE-16106).
- net: ethernet: fec: remove redundant null check before
  clk_disable_unprepare() (jsc#SLE-16106).
- net: fec: replace snprintf() with strlcpy() in fec_ptp_init()
  (jsc#SLE-16106).
- net: fec: get rid of redundant code in fec_ptp_set()
  (jsc#SLE-16106).
- net: fec: initialize clock with 0 rather than current kernel
  time (jsc#SLE-16106).
- net: fec: enable to use PPS feature without time stamping
  (jsc#SLE-16106).
- net: fec: Set max MTU size to allow the MTU to be changed
  (jsc#SLE-16106).
- net: tso: cache transport header length (jsc#SLE-16106).
- net: fec: fix hardware time stamping by external devices
  (jsc#SLE-16106).
- net: ethernet: fec: prevent tx starvation under high rx load
  (jsc#SLE-16106).
- net: fec: disable correct clk in the err path of
  fec_enet_clk_enable (jsc#SLE-16106).
- net: ethernet: fec: move GPR register offset and bit into DT
  (jsc#SLE-16106).
- net: ethernet: fec: Replace interrupt driven MDIO with polled IO
  (jsc#SLE-16106).
- net: ethernet: fec: Allow the MDIO preamble to be disabled
  (jsc#SLE-16106).
- net: ethernet: fec: Allow configuration of MDIO bus speed
  (jsc#SLE-16106).
- net: fec: set GPR bit on suspend by DT configuration
  (jsc#SLE-16106).
- net: fec: reject unsupported coalescing params (jsc#SLE-16106).
- freescale: Replace zero-length array with flexible-array member
  (jsc#SLE-16106).
- net: fec: Prevent unbind operation (jsc#SLE-16106).
- net: convert suitable network drivers to use phy_do_ioctl
  (jsc#SLE-16106).
- net: fec: remove redundant assignment to pointer bdp
  (jsc#SLE-16106).
- net: fec: add C45 MDIO read/write support (jsc#SLE-16106).
- net: fec: use devm_platform_ioremap_resource() to simplify code
  (jsc#SLE-16106).
- commit bcd4fcc
* Wed Nov  4 2020 yousaf.kaukab@suse.com
- Delete
  patches.suse/spi-spi-fsl-dspi-Exit-the-ISR-with-IRQ_NONE-when-it-.patch.
  It will be replaced by following patch:
  37b410018064 spi: spi-fsl-dspi: Exit the ISR with IRQ_NONE when it's not ours
- commit abf3980
* Wed Nov  4 2020 nsaenzjulienne@suse.de
- mmc: sdhci-msm: Introduce new ops to dump vendor specific
  registers (jsc#SLE-16106).
- spi: spi-nxp-fspi: Fix a NULL vs IS_ERR() check in probe
  (jsc#SLE-16106).
- spi: spi-nxp-fspi: Enable the Octal Mode in MCR0
  (jsc#SLE-16106).
- spi: fspi: dynamically alloc AHB memory (jsc#SLE-16106).
- spi: fspi: enable fspi on imx8qxp and imx8mm (jsc#SLE-16106).
- pinctrl: core: Add pinctrl_select_default_state() and export it
  (jsc#SLE-16106).
- commit 9a5f984
* Wed Nov  4 2020 vbabka@suse.cz
- powerpc/64s/radix: Fix mm_cpumask trimming race vs
  kthread_use_mm (MM Functionality, bsc#1178426).
- commit 7298443
* Wed Nov  4 2020 nsaenzjulienne@suse.de
- mmc: sdhci-esdhc-imx: remove unused code (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: Reset before sending tuning command for
  manual tuning (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: dump internal IC debug status during error
  (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: disable the CMD CRC check for standard
  tuning (jsc#SLE-16106).
- mmc: host: sdhci-esdhc-imx: add wakeup feature for GPIO CD pin
  (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: Add HS400 support for i.MX6SLL
  (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: restore pin state when resume back
  (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: clear DMA_SEL when disable DMA mode
  (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: clear pending interrupt and halt cqhci
  (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: Add an new esdhc_soc_data for i.MX8MM
  (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: add flag ESDHC_FLAG_BROKEN_AUTO_CMD23
  (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: optimize the strobe dll setting
  (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: optimize the clock setting
  (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: add strobe-dll-delay-target support
  (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: restore the per_clk rate in PM_RUNTIME
  (jsc#SLE-16106).
- mmc: sdhci-esdhci-imx: retune needed for Mega/Mix enabled SoCs
  (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: no fail when no pinctrl available
  (jsc#SLE-16106).
- mmc: sdhci-esdhc-imx: Convert to pinctrl_select_default_state()
  (jsc#SLE-16106).
- mmc: sdhci: Drop redundant code for SDIO IRQs (jsc#SLE-16106).
- i2c: core: Provide generic definitions for bus frequencies
  (jsc#SLE-16106).
- commit 1da2a90
* Wed Nov  4 2020 vbabka@suse.cz
- powerpc: select ARCH_WANT_IRQS_OFF_ACTIVATE_MM (MM
  Functionality, bsc#1178426).
- Update config files. Select the new option for ppc64le.
- commit 39e4bbd
* Wed Nov  4 2020 vbabka@suse.cz
- mm: fix exec activate_mm vs TLB shootdown and lazy tlb switching
  race (MM Functionality, bsc#1178426).
- commit bae6aac
* Wed Nov  4 2020 vbabka@suse.cz
- mm: fix kthread_use_mm() vs TLB invalidate (MM Functionality,
  bsc#1178426).
- commit ebe1e96
* Wed Nov  4 2020 nsaenzjulienne@suse.de
- mailbox: imx: Mark PM functions as __maybe_unused
  (jsc#SLE-16106).
- mailbox: imx: ONLY IPC MU needs IRQF_NO_SUSPEND flag
  (jsc#SLE-16106).
- mailbox: imx: Add runtime PM callback to handle MU clocks
  (jsc#SLE-16106).
- mailbox: imx: Add context save/restore for suspend/resume
  (jsc#SLE-16106).
- mailbox: imx-mailbox: fix scu msg header size check
  (jsc#SLE-16106).
- mailbox: imx: Disable the clock on
  devm_mbox_controller_register() failure (jsc#SLE-16106).
- mailbox: imx: Fix return in imx_mu_scu_xlate() (jsc#SLE-16106).
- mailbox: imx: Support runtime PM (jsc#SLE-16106).
- i2c: drivers: Use generic definitions for bus frequencies (jsc#SLE-16106).
- Refresh: patches.suse/i2c-altera-use-proper-variable-to-hold-errno.patch
- Refresh: patches.suse/i2c-imx-Fix-external-abort-on-interrupt-in-exit-path.patch
- Refresh: patches.suse/i2c-tegra-Add-support-for-the-VI-I2C-on-Tegra210.patch
- Refresh: patches.suse/i2c-tegra-Remove-NULL-pointer-check-before-clk_enabl.patch
- Refresh: patches.suse/i2c-tegra-Use-FIELD_PREP-FIELD_GET-macros.patch
- i2c: imx: remove duplicate print after platform_get_irq()
  (jsc#SLE-16106).
- i2c: imx: implement master_xfer_atomic callback (jsc#SLE-16106).
- mailbox: imx: add SCU MU support (jsc#SLE-16106).
- mailbox: imx: restructure code to make easy for new MU
  (jsc#SLE-16106).
- mailbox: imx: add support for imx v1 mu (jsc#SLE-16106).
- commit 2dfd62c
* Wed Nov  4 2020 vbabka@suse.cz
- kernel: better document the use_mm/unuse_mm API contract
  (MM Functionality, bsc#1178426).
- Refresh patches.suse/amdgpu-a-NULL-mm-does-not-mean-a-thread-is-a-kthread.patch.
- kernel: better document the use_mm/unuse_mm API contract
  (MM Functionality, bsc#1178426).
- kernel: move use_mm/unuse_mm to kthread.c (MM Functionality,
  bsc#1178426).
- kernel: move use_mm/unuse_mm to kthread.c (MM Functionality,
  bsc#1178426).
- Refresh
  patches.suse/isolcpus-Affine-unbound-kernel-threads-to-housekeeping-cpus.patch.
  Single commit with multiple patches needed to prevent breaking the build.
- commit e0e83ba
* Wed Nov  4 2020 nsaenzjulienne@suse.de
- ASoC: fsl_sai: Set MCLK input or output direction
  (jsc#SLE-16106).
- ASoC: fsl_sai: Add fsl_sai_check_version function
  (jsc#SLE-16106).
- ASoC: fsl_sai: Add new added registers and new bit definition
  (jsc#SLE-16106).
- ASoC: fsl_sai: Set SAI Channel Mode to Output Mode
  (jsc#SLE-16106).
- ASoC: fsl_sai: Support multiple data channel enable bits
  (jsc#SLE-16106).
- ASoC: fsl_sai: Add -EPROBE_DEFER check for regmap init
  (jsc#SLE-16106).
- ASoC: fsl_sai: Replace synchronous check with
  fsl_sai_dir_is_synced (jsc#SLE-16106).
- ASoC: fsl_sai: Drop TMR/RMR settings for synchronous mode
  (jsc#SLE-16106).
- ASoC: fsl_sai: Refine enable/disable TE/RE sequence in trigger()
  (jsc#SLE-16106).
- commit 607af80
* Wed Nov  4 2020 jlee@suse.com
- Update config files. (jsc#SLE-15207)
  Set CONFIG_CRYPTO_CHACHA20POLY1305=m on x86_64, ppc64le and s390x
- commit 16889ba
* Wed Nov  4 2020 pjakobsson@suse.de
- blacklist.conf: Blacklist while doing DRM backport
- Delete
  patches.suse/drm-prime-use-dma-length-macro-when-mapping-sg.
- commit 727c877
* Wed Nov  4 2020 pjakobsson@suse.de
- blacklist.conf: temporarily blacklist while doing DRM backport
- Delete
  patches.suse/drm-prime-fix-extracting-of-the-dma-addresses-from-a-scatterlist.
- commit 2132948
* Wed Nov  4 2020 pjakobsson@suse.de
- Refresh
  patches.suse/1436-drm-i915-rename-intel_drv.h-to-display-intel_display.patch.
- commit 0281873
* Wed Nov  4 2020 denis.kirjanov@suse.com
- RDMA/iw_cxgb4: Disable delayed ack by default (jsc#SLE-15118).
- commit a82cef8
* Wed Nov  4 2020 jeyu@suse.de
- gpio: Fix the no return statement warning (bsc#1178431).
- commit 0959dc3
* Wed Nov  4 2020 jslaby@suse.cz
- tty: make FONTX ioctl use the tty pointer they were actually
  passed (bsc#1178123 CVE-2020-25668).
- commit fda631f
* Wed Nov  4 2020 nsaenzjulienne@suse.de
- soc: imx: gpcv2: Print the correct error code (jsc#SLE-16106).
- soc: imx-scu: Add SoC UID(unique identifier) support
  (jsc#SLE-16106).
- commit d4b2124
* Wed Nov  4 2020 glin@suse.com
- s390/bpf: Remove JITed image size limitations (bsc#1177028).
- s390/bpf: Use lg(f)rl when long displacement cannot be used
  (bsc#1177028).
- s390/bpf: Use lgrl instead of lg where possible (bsc#1177028).
- s390/bpf: Load literal pool register using larl (bsc#1177028).
- s390/bpf: Align literal pool entries (bsc#1177028).
  Update patches.suse/s390-bpf-maintain-8-byte-stack-alignment to adopt
  the change introduced by
  patches.suse/s390-bpf-Align-literal-pool-entries.patch
- s390/bpf: Use relative long branches (bsc#1177028).
  Refresh patches.suse/s390-bpf-maintain-8-byte-stack-alignment
- s390/bpf: Make sure JIT passes do not increase code size (bsc#1177028).
  Update patches.suse/s390-bpf-maintain-8-byte-stack-alignment to adopt
  the change introduced by
  patches.suse/s390-bpf-Make-sure-JIT-passes-do-not-increase-code-s.patch
- s390/bpf: Remove unused SEEN_RET0, SEEN_REG_AX and ret0_ip
  (bsc#1177028).
- s390/bpf: Wrap JIT macro parameter usages in parentheses
  (bsc#1177028).
- s390/bpf: Use kvcalloc for addrs array (bsc#1177028).
- bpf: s390: add JIT support for bpf line info (bsc#1177028).
- bpf: s390: add JIT support for multi-function programs (bsc#1177028).
  Update patches.suse/s390-bpf-maintain-8-byte-stack-alignment to adopt
  the change introduced by
  patches.suse/bpf-s390-add-JIT-support-for-multi-function-programs.patch
- commit d6ad6b9
* Wed Nov  4 2020 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section:
  patches.suse/powercap-Restrict-energy-meter-to-root-access.patch
- commit a552ff6
* Wed Nov  4 2020 tiwai@suse.de
- Updated Copyright line in rpm templates with SUSE LLC
- commit 39a1fcf
* Wed Nov  4 2020 tiwai@suse.de
- rpm/kernel-obs-build.spec.in: Add -q option to modprobe calls (bsc#1178401)
- commit 33ded45
* Wed Nov  4 2020 mkubecek@suse.cz
- icmp: randomize the global rate limiter (git-fixes).
- commit 3f6a76f
* Wed Nov  4 2020 glin@suse.com
- bpf: sockmap: Check value of unused args to BPF_PROG_ATTACH
  (bsc#1177028).
- bpf: Fix memlock accounting for sock_hash (bsc#1177028).
- bpf: tcp: Recv() should return 0 when the peer socket is closed
  (bsc#1177028).
- bpf/sockmap: Fix kernel panic at __tcp_bpf_recvmsg
  (bsc#1177028).
- bpf, i386: Remove unneeded conversion to bool (bsc#1177028).
- bpf, arm64: Optimize ADD,SUB,JMP BPF_K using arm64 add/sub
  immediates (bsc#1177028).
- bpf, arm64: Optimize AND,OR,XOR,JSET BPF_K using arm64 logical
  immediates (bsc#1177028).
- commit 7ede77e
* Wed Nov  4 2020 neilb@suse.de
- svcrdma: fix bounce buffers for unaligned offsets and multiple
  pages (git-fixes).
- commit 3c46e04
* Wed Nov  4 2020 neilb@suse.de
- NFSv4: Wait for stateid updates after CLOSE/OPEN_DOWNGRADE
  (bsc#1176180).
- NFSv4.x recover from pre-mature loss of openstateid
  (bsc#1176180).
- NFSv4: Handle NFS4ERR_OLD_STATEID in CLOSE/OPEN_DOWNGRADE
  (bsc#1176180).
- commit ae88090
* Wed Nov  4 2020 neilb@suse.de
- blacklist.conf:
- Delete
  patches.suse/SUNRPC-Revert-241b1f419f0e-SUNRPC-Remove-xdr_buf_tri.patch.
  This patch causes a regression - bsc1178304 - and "fixing" it properly
  requires backporting patches which break kabi.  So just drop for now.
- commit 548f6fe
* Tue Nov  3 2020 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix compressed module handling for in-tree KMP (jsc#SLE-10886)
  The in-tree KMP that is built with SLE kernels have a different scriptlet
  that is embedded in kernel-binary.spec.in rather than *.sh files.
- commit e32ee2c
* Tue Nov  3 2020 lduncan@suse.com
- scsi: iscsi: Perform connection failure entirely in kernel space
  (bsc#1178367).
- commit b913745
* Tue Nov  3 2020 jeyu@suse.de
- Revert "Disable module compression on SLE15 SP2 (bsc#1178307)"
  This reverts commit 6e769e1ed1932517b87eb1bccf15337a3b5f841f.
  While module compression is disabled on SLE15-SP2, it will remain
  enabled on SLE15-SP3. Therefore, revert this commit coming from
  SLE15-SP2.
- commit 6671e44
* Tue Nov  3 2020 yousaf.kaukab@suse.com
- serial: cpm_uart: call cpm_muram_init before registering console
  (jsc#SLE-12251).
- commit 1f45790
* Tue Nov  3 2020 pjakobsson@suse.de
- drm/amd/display: Make some functions static (bsc#1152489).
- blacklist.conf: Was blacklisted as duplicate but dup did not exist
- commit 850c070
* Tue Nov  3 2020 yousaf.kaukab@suse.com
- soc: fsl: qe: clean up an indentation issue (jsc#SLE-12251).
- soc: fsl: qe: Replace one-element array and use struct_size()
  helper (jsc#SLE-12251).
- soc: fsl: qe: fix sparse warnings for ucc_slow.c
  (jsc#SLE-12251).
- soc: fsl: qe: ucc_slow: remove 0 assignment for kzalloc'ed
  structure (jsc#SLE-12251).
- soc: fsl: qe: fix sparse warnings for qe_ic.c (jsc#SLE-12251).
- soc: fsl: qe: fix sparse warnings for ucc.c (jsc#SLE-12251).
- soc: fsl: qe: fix sparse warning for qe_common.c
  (jsc#SLE-12251).
- soc: fsl: qe: fix sparse warnings for qe.c (jsc#SLE-12251).
- soc: fsl: qe: remove set but not used variable 'mm_gc'
  (jsc#SLE-12251).
- soc: fsl: qe: remove PPC32 dependency from CONFIG_QUICC_ENGINE
  (jsc#SLE-12251).
- soc: fsl: qe: remove unused #include of asm/irq.h from ucc.c
  (jsc#SLE-12251).
- net: ethernet: freescale: make UCC_GETH explicitly depend on
  PPC32 (jsc#SLE-12251).
- net/wan/fsl_ucc_hdlc: reject muram offsets above 64K
  (jsc#SLE-12251).
- net/wan/fsl_ucc_hdlc: fix reading of __be16 registers
  (jsc#SLE-12251).
- net/wan/fsl_ucc_hdlc: avoid use of IS_ERR_VALUE()
  (jsc#SLE-12251).
- soc: fsl: qe: avoid IS_ERR_VALUE in ucc_fast.c (jsc#SLE-12251).
- soc: fsl: qe: drop pointless check in qe_sdma_init()
  (jsc#SLE-12251).
- soc: fsl: qe: drop use of IS_ERR_VALUE in qe_sdma_init()
  (jsc#SLE-12251).
- soc: fsl: qe: avoid IS_ERR_VALUE in ucc_slow.c (jsc#SLE-12251).
- soc: fsl: qe: refactor cpm_muram_alloc_common to prevent BUG
  on error path (jsc#SLE-12251).
- soc: fsl: qe: drop broken lazy call of cpm_muram_init()
  (jsc#SLE-12251).
- soc: fsl: qe: make cpm_muram_free() ignore a negative offset
  (jsc#SLE-12251).
- soc: fsl: qe: make cpm_muram_free() return void (jsc#SLE-12251).
- soc: fsl: qe: change return type of cpm_muram_alloc() to s32
  (jsc#SLE-12251).
- serial: ucc_uart: access __be32 field using be32_to_cpu
  (jsc#SLE-12251).
- serial: ucc_uart: limit brg-frequency workaround to PPC32
  (jsc#SLE-12251).
- serial: ucc_uart: use of_property_read_u32() in ucc_uart_probe()
  (jsc#SLE-12251).
- serial: ucc_uart: stub out soft_uart_init for !CONFIG_PPC32
  (jsc#SLE-12251).
- serial: ucc_uart: factor out soft_uart initialization
  (jsc#SLE-12251).
- serial: ucc_uart: replace ppc-specific IO accessors
  (jsc#SLE-12251).
- serial: ucc_uart: explicitly include soc/fsl/cpm.h
  (jsc#SLE-12251).
- soc/fsl/qe/qe.h: update include path for cpm.h (jsc#SLE-12251).
- soc: fsl: move cpm.h from powerpc/include/asm to include/soc/fsl
  (jsc#SLE-12251).
- soc: fsl: qe: qe_io.c: use of_property_read_u32() in
  par_io_init() (jsc#SLE-12251).
- soc: fsl: qe: qe_io.c: access device tree property using
  be32_to_cpu (jsc#SLE-12251).
- soc: fsl: qe: qe_io.c: don't open-code of_parse_phandle()
  (jsc#SLE-12251).
- soc: fsl: qe: qe.c: use of_property_read_* helpers
  (jsc#SLE-12251).
- soc: fsl: qe: merge qe_ic.h headers into qe_ic.c
  (jsc#SLE-12251).
- soc: fsl: qe: simplify qe_ic_init() (jsc#SLE-12251).
- soc: fsl: qe: make qe_ic_get_{low,high}_irq static
  (jsc#SLE-12251).
- soc: fsl: qe: don't use NO_IRQ in qe_ic.c (jsc#SLE-12251).
- soc: fsl: qe: remove unused qe_ic_set_* functions
  (jsc#SLE-12251).
- soc: fsl: qe: rename qe_ic_cascade_low_mpic -> qe_ic_cascade_low
  (jsc#SLE-12251).
- soc: fsl: qe: move qe_ic_cascade_* functions to qe_ic.c
  (jsc#SLE-12251).
- powerpc/83xx: remove mpc83xx_ipic_and_qe_init_IRQ
  (jsc#SLE-12251).
- soc: fsl: qe: move calls of qe_ic_init out of arch/powerpc/
  (jsc#SLE-12251).
- soc: fsl: qe: use qe_ic_cascade_{low, high}_mpic also on 83xx
  (jsc#SLE-12251).
- soc: fsl: qe: remove pointless sysfs registration in qe_ic.c
  (jsc#SLE-12251).
- soc: fsl: qe: drop assign-only high_active in qe_ic_init
  (jsc#SLE-12251).
- soc: fsl: qe: drop unneeded #includes (jsc#SLE-12251).
- soc: fsl: qe: qe.c: guard use of pvr_version_is() with
  CONFIG_PPC32 (jsc#SLE-12251).
- soc: fsl: qe: replace spin_event_timeout by
  readx_poll_timeout_atomic (jsc#SLE-12251).
- soc: fsl: qe: avoid ppc-specific io accessors (jsc#SLE-12251).
- soc: fsl: qe: introduce qe_io{read,write}* wrappers
  (jsc#SLE-12251).
- soc: fsl: qe: rename qe_(clr/set/clrset)bit* helpers
  (jsc#SLE-12251).
- soc: fsl: qe: drop volatile qualifier of struct qe_ic::regs
  (jsc#SLE-12251).
- soc: fsl: qe: remove space-before-tab (jsc#SLE-12251).
- serial: ucc_uart: remove redundant assignment to pointer bdp
  (jsc#SLE-12251).
- irqchip: Add support for Layerscape external interrupt lines
  (jsc#SLE-12251).
- powerpc/85xx: remove mostly pointless mpc85xx_qe_init()
  (jsc#SLE-12251).
- soc: fsl: qe: fold qe_get_num_of_snums into qe_snums_init
  (jsc#SLE-12251).
- soc: fsl: qe: support fsl,qe-snums property (jsc#SLE-12251).
- soc: fsl: qe: introduce qe_get_device_node helper
  (jsc#SLE-12251).
- soc: fsl: qe: reduce static memory footprint by 1.7K
  (jsc#SLE-12251).
- soc: fsl: qe: drop useless static qualifier (jsc#SLE-12251).
- commit f624471
* Tue Nov  3 2020 nborisov@suse.com
- btrfs: Account for merged patches upstream
  Move below patches to sorted section.
- Refresh patches.suse/btrfs-account-for-trans_block_rsv-in-may_commit_transaction.patch.
- Refresh atches.suse/btrfs-allow-us-to-use-up-to-90-of-the-global-rsv-for-unlink.patch.
- Refresh patches.suse/btrfs-force-chunk-allocation-if-our-global-rsv-is-larger-than-metadata.patch.
- Refresh patches.suse/btrfs-improve-global-reserve-stealing-logic.patch.
- Refresh patches.suse/btrfs-only-check-priority-tickets-for-priority-flushing.patch.
- Refresh patches.suse/btrfs-run-btrfs_try_granting_tickets-if-a-priority-ticket-fails.patch.
  Also add 3 new patches to follow upstream as much as possible, one of
  them is a git-fixes requirements the others are prerequisites for it:
  - patches.suse/btrfs-account-ticket-size-at-add-delete-time.patch
  - patches.suse/btrfs-fix-reclaim-counter-leak-of-space_info-objects.patch
  - patches.suse/btrfs-fix-reclaim_size-counter-leak-after-stealing-from-global-reserve.patch
- commit b193add
* Tue Nov  3 2020 fdmanana@suse.com
- btrfs: fix filesystem corruption after a device replace
  (bsc#1178395).
- commit ece2bc8
* Tue Nov  3 2020 fdmanana@suse.com
- btrfs: move btrfs_rm_dev_replace_free_srcdev outside of all
  locks (bsc#1178395).
- commit 9f5adb5
* Tue Nov  3 2020 fdmanana@suse.com
- btrfs: move btrfs_scratch_superblocks into
  btrfs_dev_replace_finishing (bsc#1178395).
- commit 8818530
* Tue Nov  3 2020 jslaby@suse.cz
- vt: keyboard, extend func_buf_lock to readers (bnc#1177766
  CVE-2020-25656).
- vt: keyboard, simplify vt_kdgkbsent (bnc#1177766
  CVE-2020-25656).
- commit d1af3a9
* Tue Nov  3 2020 denis.kirjanov@suse.com
- intel-ethernet: clean up W=1 warnings in kdoc (jsc#SLE-15373).
- commit 6a6b2da
* Tue Nov  3 2020 tiwai@suse.de
- Disable ipa-clones dump for KMP builds (bsc#1178330)
  The feature is not really useful for KMP, and rather confusing,
  so let's disable it at building out-of-tree codes
- commit ba5c338
* Tue Nov  3 2020 dbueso@suse.de
- time: Prevent undefined behaviour in timespec64_to_ns()
  (bsc#1164648).
- futex: Fix incorrect should_fail_futex() handling (bsc#1149032).
- futex: Adjust absolute futex timeouts with per time namespace
  offset (bsc#1164648).
- futex: Remove unused or redundant includes (bsc#1149032).
- futex: Consistently use fshared as boolean (bsc#1149032).
- futex: Remove put_futex_key() (bsc#1149032).
- commit a86c28d
* Mon Nov  2 2020 lduncan@suse.com
- scsi: core: Allow the state change from SDEV_QUIESCE to
  SDEV_BLOCK (jsc#SLE-15152).
- commit 687635a
* Mon Nov  2 2020 msuchanek@suse.de
- x86/efi: remove unused variables (jsc#SLE-15857 jsc#SLE-13618).
- commit 674c1a9
* Mon Nov  2 2020 msuchanek@suse.de
- Update config files.
  +CONFIG_LOAD_PPC_KEYS=y
- commit caba9b6
* Mon Nov  2 2020 msuchanek@suse.de
- powerpc: Load firmware trusted keys/hashes into kernel keyring
  (jsc#SLE-15857 jsc#SLE-13618).
- x86/efi: move common keyring handler functions to new file
  (jsc#SLE-15857 jsc#SLE-13618).
- commit 060cd29
* Mon Nov  2 2020 jlee@suse.com
- ACPI: fan: Expose fan performance state information
  (jsc#SLE-13078).
- commit 1c52bce
* Mon Nov  2 2020 msuchanek@suse.de
- Align secure boot configs (jsc#SLE-15857 jsc#SLE-13618 bsc#1176918 ltc#186474).
  ppc64le:
  +CONFIG_INTEGRITY_PLATFORM_KEYRING=y
  +CONFIG_IMA_APPRAISE_BOOTPARAM=y
  +CONFIG_SYSTEM_BLACKLIST_KEYRING=y
  +CONFIG_SYSTEM_BLACKLIST_HASH_LIST=""
  s390x:
  +CONFIG_INTEGRITY_PLATFORM_KEYRING=y
  +CONFIG_LOAD_IPL_KEYS=y
  +CONFIG_SYSTEM_BLACKLIST_KEYRING=y
  +CONFIG_SYSTEM_BLACKLIST_HASH_LIST=""
- commit 7b5f1e7
* Mon Nov  2 2020 msuchanek@suse.de
- ima: move APPRAISE_BOOTPARAM dependency on ARCH_POLICY to
  runtime (jsc#SLE-15857 jsc#SLE-13618 bsc#1176918 ltc#186474).
- ima: use struct_size() in kzalloc() (jsc#SLE-15857 jsc#SLE-13618
  bsc#1176918 ltc#186474).
- commit e301a0a
* Mon Nov  2 2020 ohering@suse.de
- kbuild: enforce -Werror=return-type (bsc#1177281).
- commit 1efe79d
* Mon Nov  2 2020 mbrugger@suse.com
- blacklist.conf: ignore LLVM toolchain fix
- commit e9af9fb
* Mon Nov  2 2020 ptesarik@suse.cz
- s390/dasd: Fix zero write for FBA devices (bsc#1177801
  LTC#188735).
- s390/cio: add cond_resched() in the slow_eval_known_fn() loop
  (bsc#1177799 LTC#188733).
- commit 8d8c67c
* Mon Nov  2 2020 mkubecek@suse.cz
- update patch metadata
- update Patch-mainline:
  patches.suse/ibmveth-Fix-use-of-ibmveth-in-a-bridge.patch
- commit 32664f1
* Mon Nov  2 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/scsi-ibmvscsi-Fix-potential-race-after-loss-of-trans.patch
- commit a1665a9
* Mon Nov  2 2020 glin@suse.com
- Update patches.suse/bpf-Fix-scalar32_min_max_or-bounds-tracking.patch
  Add the bug references: bsc#1177889 and CVE-2020-27194.
- commit 948c903
* Sat Oct 31 2020 lduncan@suse.com
- scsi: aacraid: Add a missing iounmap call (jsc#SLE-15152).
- scsi: aacraid: Make some symbols static in aachba.c
  (jsc#SLE-15152).
- scsi: aacraid: Remove erroneous fallthrough annotation
  (jsc#SLE-15152).
- scsi: aacraid: Remove pci-dma-compat wrapper API
  (jsc#SLE-15152).
- scsi: core: Add missing scsi_device_put() in scsi_host_block()
  (jsc#SLE-15152).
- scsi: aacraid: Fix logical bug when !DBG (jsc#SLE-15152).
- scsi: aacraid: Provide suggested curly braces around empty
  body of if() (jsc#SLE-15152).
- scsi: aacraid: Fix an oops in error handling (jsc#SLE-15152).
- scsi: aacraid: Use memdup_user() as a cleanup (jsc#SLE-15152).
- scsi: aacraid: Make some symbols static (jsc#SLE-15152).
- scsi: core: Remove 'list' entry from struct scsi_cmnd
  (jsc#SLE-15152).
- scsi: aacraid: Fix error handling paths in aac_probe_one()
  (jsc#SLE-15152).
- scsi: core: Avoid calling synchronize_rcu() for each device
  in scsi_host_block() (jsc#SLE-15152).
- scsi: aacraid: do not overwrite retval in aac_reset_adapter()
  (jsc#SLE-15152).
- scsi: aacraid: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-15152).
- scsi: aacraid: clean up warning cast-function-type
  (jsc#SLE-15152).
- scsi: aacraid: Disabling TM path and only processing IOP reset
  (jsc#SLE-15152).
- scsi: core: Remove cmd_list functionality (jsc#SLE-15152).
- scsi: aacraid: use scsi_host_busy_iter() in
  get_num_of_incomplete_fibs() (jsc#SLE-15152).
- scsi: aacraid: use scsi_host_busy_iter() to wait for outstanding
  commands (jsc#SLE-15152).
- scsi: core: add scsi_host_busy_iter() (jsc#SLE-15152).
- scsi: aacraid: use scsi_host_(block,unblock) to block I/O
  (jsc#SLE-15152).
- scsi: core: add scsi_host_(block,unblock) helper function
  (jsc#SLE-15152).
- scsi: aacraid: move scsi_(block,unblock)_requests out of
  _aac_reset_adapter() (jsc#SLE-15152).
- scsi: aacraid: replace aac_flush_ios() with midlayer helper
  (jsc#SLE-15152).
- scsi: aacraid: use scsi_host_complete_all_commands() to
  terminate outstanding commands (jsc#SLE-15152).
- scsi: aacraid: Do not wait for outstanding write commands on
  synchronize_cache (jsc#SLE-15152).
- scsi: dpt_i2o: use scsi_host_complete_all_commands() to abort
  outstanding commands (jsc#SLE-15152).
- scsi: core: add scsi_host_complete_all_commands() helper
  (jsc#SLE-15152).
- scsi: aacraid: bump version (jsc#SLE-15152).
- scsi: aacraid: send AIF request post IOP RESET (jsc#SLE-15152).
- scsi: aacraid: check adapter health (jsc#SLE-15152).
- scsi: aacraid: setting different timeout for src and thor
  (jsc#SLE-15152).
- scsi: aacraid: fixed firmware assert issue (jsc#SLE-15152).
- scsi: aacraid: fixed IO reporting error (jsc#SLE-15152).
- scsi: aacraid: fix illegal IO beyond last LBA (jsc#SLE-15152).
- commit f6c27f0
* Sat Oct 31 2020 denis.kirjanov@suse.com
- Update
  patches.suse/0001-net-Take-common-prefetch-code-structure-into-a-funct.patch
  (jsc#SLE-13536).
- Update
  patches.suse/0001-net-aquantia-PTP-skeleton-declarations-and-callbacks.patch
  (jsc#SLE-15148).
- Update patches.suse/0002-igb-add-XDP-support.patch
  (jsc#SLE-13536).
- Update
  patches.suse/0002-net-aquantia-unify-styling-of-bit-enums.patch
  (jsc#SLE-15148).
- Update patches.suse/0003-igb-read-PBA-number-from-flash.patch
  (jsc#SLE-13536).
- Update
  patches.suse/0003-net-aquantia-add-basic-ptp_clock-callbacks.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0004-net-aquantia-add-PTP-rings-infrastructure.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0004-net-intel-Remove-in_interrupt-warnings.patch
  (jsc#SLE-13536).
- Update
  patches.suse/0005-net-aquantia-styling-fixes-on-ptp-related-functions.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0006-net-aquantia-implement-data-PTP-datapath.patch
  (jsc#SLE-15148).
- Update patches.suse/0007-net-aquantia-rx-filters-for-ptp.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0008-net-aquantia-add-support-for-ptp-ioctls.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0009-net-aquantia-implement-get_ts_info-ethtool.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0010-net-aquantia-add-support-for-Phy-access.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0011-net-aquantia-add-support-for-PIN-funcs.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0012-net-aquantia-fix-var-initialization-warning.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0013-net-aquantia-fix-warnings-on-endianness.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0014-net-aquantia-disable-ptp-object-build-if-no-config.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0015-net-aquantia-fix-spelling-mistake-tx_queus-tx_queues.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0016-net-aquantia-fix-unintention-integer-overflow-on-lef.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0017-net-aquantia-make-two-symbols-be-static.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0018-net-aquantia-remove-unused-including-linux-version.h.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0019-net-aquantia-fix-error-handling-in-aq_ptp_poll.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0020-net-aquantia-fix-return-value-check-in-aq_ptp_init.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0021-net-atlantic-update-firmware-interface.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0022-net-atlantic-implement-wake_phy-feature.patch
  (jsc#SLE-15148).
- Update patches.suse/0023-net-atlantic-refactoring-pm-logic.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0024-net-atlantic-add-msglevel-configuration.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0025-net-atlantic-adding-ethtool-physical-identification.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0026-net-atlantic-add-fw-configuration-memory-area.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0027-net-atlantic-loopback-tests-via-private-flags.patch
  (jsc#SLE-15148).
- Update patches.suse/0028-net-atlantic-code-style-cleanup.patch
  (jsc#SLE-15148).
- Update patches.suse/0029-net-atlantic-stylistic-renames.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0030-net-atlantic-update-flow-control-logic.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0031-net-atlantic-implement-UDP-GSO-offload.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0032-net-atlantic-change-email-domains-to-Marvell.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0033-net-atlantic-make-symbol-aq_pm_ops-static.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0034-net-atlantic-make-function-aq_ethtool_get_priv_flags.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0035-net-atlantic-Signedness-bug-in-aq_vec_isr_legacy.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0036-net-atlantic-broken-link-status-on-old-fw.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0037-net-atlantic-loopback-configuration-in-improper-plac.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0038-net-atlantic-remove-duplicate-entries.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0039-net-atlantic-checksum-compat-issue.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0040-net-atlantic-check-rpc-result-and-wait-for-rpc-addre.patch
  (jsc#SLE-15148).
- Update patches.suse/0041-net-atlantic-ptp-gpio-adjustments.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0042-net-atlantic-better-loopback-mode-handling.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0043-net-atlantic-fix-use-after-free-kasan-warn.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0044-net-atlantic-fix-potential-error-handling.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0045-net-atlantic-possible-fault-in-transition-to-hiberna.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0046-net-atlantic-fix-out-of-range-usage-of-active_vlans-.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0047-net-aquantia-Delete-module-version.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0048-net-aquantia-reject-all-unsupported-coalescing-param.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0049-aquantia-Fix-the-media-type-of-AQC100-ethernet-contr.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0050-net-atlantic-update-company-name-in-the-driver-descr.patch
  (jsc#SLE-15148).
- Update patches.suse/0051-net-atlantic-add-A2-device-IDs.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0052-net-atlantic-add-defines-for-10M-and-EEE-100M-link-m.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0053-net-atlantic-add-hw_soft_reset-hw_prepare-to-hw_ops.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0054-net-atlantic-simplify-hw_get_fw_version-usage.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0055-net-atlantic-make-hw_get_regs-optional.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0056-net-atlantic-move-IS_CHIP_FEATURE-to-aq_hw.h.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0057-net-atlantic-A2-driver-firmware-interface.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0058-net-atlantic-minimal-A2-HW-bindings-required-for-fw_.patch
  (jsc#SLE-15148).
- Update patches.suse/0059-net-atlantic-minimal-A2-fw_ops.patch
  (jsc#SLE-15148).
- Update patches.suse/0060-net-atlantic-A2-hw_ops-skeleton.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0061-net-atlantic-HW-bindings-for-A2-RFP.patch
  (jsc#SLE-15148).
- Update patches.suse/0062-net-atlantic-add-A2-RPF-hw_ops.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0063-net-atlantic-HW-bindings-for-basic-A2-init-deinit-hw.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0064-net-atlantic-common-functions-needed-for-basic-A2-in.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0065-net-atlantic-basic-A2-init-deinit-hw_ops.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0066-net-atlantic-A2-ingress-egress-hw-configuration.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0067-net-atlantic-rename-AQ_NIC_RATE_2GS-to-AQ_NIC_RATE_2.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0068-net-atlantic-remove-TPO2-check-from-A0-code.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0069-net-atlantic-remove-hw_atl_b0_hw_rss_set-call-from-A.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0070-net-atlantic-remove-check-for-boot-code-survivabilit.patch
  (jsc#SLE-15148).
- Update patches.suse/0071-net-atlantic-unify-MAC-generation.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0072-net-atlantic-changes-for-multi-TC-support.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0073-net-atlantic-move-PTP-TC-initialization-to-a-separat.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0074-net-atlantic-changes-for-multi-TC-support.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0075-net-atlantic-QoS-implementation-multi-TC-support.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0076-net-atlantic-A2-half-duplex-support.patch
  (jsc#SLE-15148).
- Update patches.suse/0077-net-atlantic-remove-baseX-usage.patch
  (jsc#SLE-15148).
- Update patches.suse/0078-net-atlantic-A2-EEE-support.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0079-net-atlantic-A2-flow-control-support.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0080-net-atlantic-A2-report-link-partner-capabilities.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0081-net-atlantic-A2-phy-loopback-support.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0082-net-atlantic-fix-variable-type-in-aq_ethtool_get_pau.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0083-net-atlantic-Replace-ENOTSUPP-usage-to-EOPNOTSUPP.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0084-net-atlantic-make-aq_pci_func_init-static.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0085-net-atlantic-fix-typo-in-aq_ring_tx_clean.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0086-net-atlantic-missing-space-in-a-comment-in-aq_nic.h.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0087-net-atlantic-add-alignment-checks-in-hw_atl2_utils_f.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0088-net-atlantic-put-ptp-code-under-IS_REACHABLE-check.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0089-net-aquantia-fix-aq_ndev_start_xmit-s-return-type.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0090-net-atlantic-fix-ip-dst-and-ipv6-address-filters.patch
  (jsc#SLE-15148).
- Update
  patches.suse/0091-net-atlantic-disable-PTP-on-AQC111-AQC112.patch
  (jsc#SLE-15148).
- Update
  patches.suse/btrfs-enumerate-the-type-of-exclusive-operation-in-progress.patch
  (JSC#SLE-13586).
- Update
  patches.suse/btrfs-sysfs-export-currently-running-exclusive-operation.patch
  (JSC#SLE-13586).
- Update patches.suse/net-atlantic-A0-ntuple-filters.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-QoS-implementation-max_rate.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-QoS-implementation-min_rate.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-Use-readx_poll_timeout-for-large-timeou.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-add-hwmon-getter-for-MAC-temperature.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-add-support-for-64-bit-reads-writes.patch
  (jsc#SLE-15148).
- Update patches.suse/net-atlantic-add-support-for-FW-4.x.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-align-return-value-of-ver_match-functio.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-always-use-random-TC-queue-mapping-for-.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-automatically-downgrade-the-number-of-q.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-change-the-order-of-arguments-for-TC-we.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-enable-ipv6-support-for-TCP-LSO-and-UDP.patch
  (jsc#SLE-15148).
- Update patches.suse/net-atlantic-fix-PTP-on-AQC10X.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-make-TCVEC2RING-accept-nic_cfg.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-move-FRAC_PER_NS-to-aq_hw.h.patch
  (jsc#SLE-15148).
- Update patches.suse/net-atlantic-per-TC-queue-statistics.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-proper-rss_ctrl1-54c0-initialization.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-use-U32_MAX-in-aq_hw_utils.c.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-use-intermediate-variable-to-improve-re.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-atlantic-use-simple-assignment-in-_get_stats-and.patch
  (jsc#SLE-15148).
- Update
  patches.suse/net-ethernet-aquantia-Fix-wrong-return-value.patch
  (jsc#SLE-15148).
  Update patch metadata to point to SLE-Epic
- commit 33bcfbb
* Fri Oct 30 2020 ptesarik@suse.cz
- Delete
  patches.suse/s390-pci-Mark-all-VFs-as-not-implementing-PCI_COMMAN.patch
  (jsc#SLE-13818 bsc#1177117 LTC#186574).
- commit 9329461
* Fri Oct 30 2020 msuchanek@suse.de
- Disable module compression on SLE15 SP2 (bsc#1178307)
- commit 6e769e1
* Fri Oct 30 2020 ptesarik@suse.cz
- s390/pci: fix leak of DMA tables on hard unplug (jsc#SLE-13818
  bsc#1177117 LTC#186574).
- s390/pci: fix PF/VF linking on hot plug (jsc#SLE-13818
  bsc#1177117 LTC#186574).
- s390/pci: re-introduce zpci_remove_device() (jsc#SLE-13818
  bsc#1177117 LTC#186574).
- s390/pci: fix zpci_bus_link_virtfn() (jsc#SLE-13818 bsc#1177117
  LTC#186574).
- s390/pci: ignore stale configuration request event
  (jsc#SLE-13818 bsc#1177117 LTC#186574).
- s390/pci: fix enabling a reserved PCI function (jsc#SLE-13818
  bsc#1177117 LTC#186574).
- s390/pci: create links between PFs and VFs (jsc#SLE-13818
  bsc#1177117 LTC#186574).
- PCI/IOV: Introduce pci_iov_sysfs_link() function (jsc#SLE-13818
  bsc#1177117 LTC#186574).
- s390/pci: removes wrong PCI multifunction assignment
  (jsc#SLE-13818 bsc#1177117 LTC#186574).
- s390/pci: Do not disable PF when VFs exist (jsc#SLE-13818
  bsc#1177117 LTC#186574).
- s390/pci: Handling multifunctions (jsc#SLE-13818 bsc#1177117
  LTC#186574).
- s390/pci: Adding bus resource (jsc#SLE-13818 bsc#1177117
  LTC#186574).
- s390/pci: adapt events for zbus (jsc#SLE-13818 bsc#1177117
  LTC#186574).
- s390/pci: create zPCI bus (jsc#SLE-13818 bsc#1177117
  LTC#186574).
- s390/pci: define RID and RID available (jsc#SLE-13818
  bsc#1177117 LTC#186574).
- s390/pci: define kernel parameters for PCI multifunction
  (jsc#SLE-13818 bsc#1177117 LTC#186574).
- s390/pci: Improve handling of unset UID (jsc#SLE-13818
  bsc#1177117 LTC#186574).
- s390/pci: Fix zpci_alloc_domain() over allocation (jsc#SLE-13818
  bsc#1177117 LTC#186574).
- s390/pci: embedding hotplug_slot in zdev (jsc#SLE-13818
  bsc#1177117 LTC#186574).
- commit a593f0e
* Fri Oct 30 2020 msuchanek@suse.de
- Refresh patches.suse/ibmveth-Fix-use-of-ibmveth-in-a-bridge.patch.
  Update to upstream version.
- commit 69ab55e
* Fri Oct 30 2020 msuchanek@suse.de
- ibmvnic: fix ibmvnic_set_mac (bsc#1066382 ltc#160943 git-fixes).
- commit 4e8525b
* Fri Oct 30 2020 mbrugger@suse.com
- arm64/cpufeature: Add remaining feature bits in ID_AA64ISAR0
  register (jsc#SLE-13697 jsc#SLE-10565).
- commit 2472603
* Fri Oct 30 2020 denis.kirjanov@suse.com
- net: intel: Remove in_interrupt() warnings (jsc#SLE-14166).
- commit 8b50ca7
* Fri Oct 30 2020 denis.kirjanov@suse.com
- igb: read PBA number from flash (jsc#SLE-14166).
- commit dd0798b
* Fri Oct 30 2020 denis.kirjanov@suse.com
- igb: add XDP support (jsc#SLE-14166).
- commit c5d94b1
* Fri Oct 30 2020 denis.kirjanov@suse.com
- net: Take common prefetch code structure into a function
  (jsc#SLE-14166).
- commit 703b714
* Fri Oct 30 2020 denis.kirjanov@suse.com
- net: tg3: tidy up loop, remove need to compute off with a
  multiply (jsc#SLE-14859).
- commit 3f285d7
* Fri Oct 30 2020 denis.kirjanov@suse.com
- net: tg3: reject unsupported coalescing params (jsc#SLE-14859).
- commit 0d525c5
* Fri Oct 30 2020 nsaenzjulienne@suse.de
- clk: bcm: dvp: Select the reset framework (jsc#SLE-15318).
- commit 8ade961
* Fri Oct 30 2020 nsaenzjulienne@suse.de
- drivers: provide devm_platform_get_and_ioremap_resource()
  (jsc#SLE-15318).
- clk: Pass correct arguments to __clk_hw_register_gate()
  (jsc#SLE-15318).
- clk: gate: Add support for specifying parents via DT/pointers
  (jsc#SLE-15318).
- clk: Zero init clk_init_data in helpers (jsc#SLE-15318).
- commit 59c9d80
* Fri Oct 30 2020 nsaenzjulienne@suse.de
- reset: simple: Add reset callback (jsc#SLE-15318).
- reset: Move reset-simple header out of drivers/reset
  (jsc#SLE-15318).
- commit 54b23f0
* Fri Oct 30 2020 mbrugger@suse.com
- tlb: mmu_gather: add tlb_flush_*_range APIs (jsc#SLE-10565).
- commit bc343ad
* Fri Oct 30 2020 mbrugger@suse.com
- arm64: Detect the ARMv8.4 TTL feature (jsc#SLE-10565).
- Refresh
  patches.suse/arm64-tlb-Detect-the-ARMv8.4-TLBI-RANGE-feature.patch.
- Refresh
  patches.suse/kabi-arm64-reserve-space-in-cpu_hwcaps-and-cpu_hwcap.patch.
- commit ab20cd9
* Fri Oct 30 2020 nsaenzjulienne@suse.de
- clk: bcm: rpi: Add register to control pixel bvb clk
  (jsc#SLE-15318).
- clk: bcm: dvp: Add missing module informations (jsc#SLE-15318).
- clk: bcm: rpi: Remove the quirks for the CPU clock
  (jsc#SLE-15318).
- clk: bcm: rpi: Give firmware clocks a name (jsc#SLE-15318).
- clk: bcm: rpi: Discover the firmware clocks (jsc#SLE-15318).
- clk: bcm: rpi: Add an enum for the firmware clocks
  (jsc#SLE-15318).
- clk: bcm: rpi: Add DT provider for the clocks (jsc#SLE-15318).
- clk: bcm: rpi: Make the PLLB registration function return a
  clk_hw (jsc#SLE-15318).
- clk: bcm: rpi: Split pllb clock hooks (jsc#SLE-15318).
- clk: bcm: rpi: Rename is_prepared function (jsc#SLE-15318).
- clk: bcm: rpi: Pass the clocks data to the firmware function
  (jsc#SLE-15318).
- clk: bcm: rpi: Add clock id to data (jsc#SLE-15318).
- clk: bcm: rpi: Create a data structure for the clocks
  (jsc#SLE-15318).
- clk: bcm: rpi: Use CCF boundaries instead of rolling our own
  (jsc#SLE-15318).
- clk: bcm: rpi: Make sure the clkdev lookup is removed
  (jsc#SLE-15318).
- clk: bcm: rpi: Switch to clk_hw_register_clkdev (jsc#SLE-15318).
- clk: bcm: rpi: Remove pllb_arm_lookup global pointer
  (jsc#SLE-15318).
- clk: bcm: rpi: Make sure pllb_arm is removed (jsc#SLE-15318).
- clk: bcm: rpi: Remove global pllb_arm clock pointer
  (jsc#SLE-15318).
- clk: bcm: rpi: Use clk_hw_register for pllb_arm (jsc#SLE-15318).
- clk: bcm: rpi: Statically init clk_init_data (jsc#SLE-15318).
- clk: bcm: rpi: Allow the driver to be probed by DT
  (jsc#SLE-15318).
- clk: bcm: Add BCM2711 DVP driver (jsc#SLE-15318).
- Update config files
- supported.conf: Add clk-bcm2711-dvp
- commit 3864121
* Fri Oct 30 2020 jslaby@suse.cz
- blacklist.conf: add two more
- commit 4c2096a
* Fri Oct 30 2020 jslaby@suse.cz
- tipc: fix memory leak caused by tipc_buf_append() (git-fixes).
- commit 22daff6
* Fri Oct 30 2020 jslaby@suse.cz
- KVM: x86/mmu: Commit zap of remaining invalid pages when
  recovering lpages (git-fixes).
- net/core: check length before updating Ethertype in
  skb_mpls_{push,pop} (git-fixes).
- bnxt_en: Protect bnxt_set_eee() and bnxt_set_pauseparam()
  with mutex (git-fixes).
- block: Set same_page to false in __bio_try_merge_page if ret
  is false (git-fixes).
- selftests/timers: Turn off timeout setting (git-fixes).
- mm: madvise: fix vma user-after-free (git-fixes).
- commit ba14726
* Fri Oct 30 2020 mbrugger@suse.com
- Update
  patches.suse/arm64-Add-level-hinted-TLB-invalidation-helper.patch
  (jsc#SLE-13697 jsc#SLE-10565).
- Update
  patches.suse/arm64-tlb-Set-the-TTL-field-in-flush_-_tlb_range.patch
  (jsc#SLE-13697 jsc#SLE-10565).
- Update
  patches.suse/arm64-tlb-Set-the-TTL-field-in-flush_tlb_range.patch
  (jsc#SLE-13697 jsc#SLE-10565).
- Update
  patches.suse/arm64-tlb-don-t-set-the-ttl-value-in-flush_tlb_page_.patch
  (jsc#SLE-13697 jsc#SLE-10565).
- commit 45984e7
* Fri Oct 30 2020 tiwai@suse.de
- usb: cdc-acm: add quirk to blacklist ETAS ES58X devices
  (git-fixes).
- usb: gadget: f_ncm: allow using NCM in SuperSpeed Plus gadgets
  (git-fixes).
- usb: gadget: function: printer: fix use-after-free in
  __lock_acquire (git-fixes).
- usb: dwc3: simple: add support for Hikey 970 (git-fixes).
- USB: cdc-wdm: Make wdm_flush() interruptible and add wdm_fsync()
  (git-fixes).
- USB: cdc-acm: handle broken union descriptors (git-fixes).
- usb: ohci: Default to per-port over-current protection
  (git-fixes).
- usb: core: Solve race condition in anchor cleanup functions
  (git-fixes).
- commit 3a141c3
* Fri Oct 30 2020 tiwai@suse.de
- r8169: fix issue with forced threading in combination with
  shared interrupts (git-fixes).
- rtw88: increse the size of rx buffer size (git-fixes).
- rtl8xxxu: prevent potential memory leak (git-fixes).
- tty: serial: fsl_lpuart: fix lpuart32_poll_get_char (git-fixes).
- tty: ipwireless: fix error handling (git-fixes).
- PM: hibernate: remove the bogus call to get_gendisk() in
  software_resume() (git-fixes).
- spi: spi-s3c64xx: Check return values (git-fixes).
- spi: spi-s3c64xx: swap s3c64xx_spi_set_cs() and
  s3c64xx_enable_datapath() (git-fixes).
- net: usb: rtl8150: set random MAC address when
  set_ethernet_addr() fails (git-fixes).
- commit 53b1fbc
* Fri Oct 30 2020 tiwai@suse.de
- mwifiex: don't call del_timer_sync() on uninitialized timer
  (git-fixes).
- mic: vop: copy data to kernel space then write to io memory
  (git-fixes).
- misc: vop: add round_up(x,4) for vring_size to avoid kernel
  panic (git-fixes).
- misc: rtsx: Fix memory leak in rtsx_pci_probe (git-fixes).
- media: firewire: fix memory leak (git-fixes).
- media: ati_remote: sanity check for both endpoints (git-fixes).
- media: st-delta: Fix reference count leak in delta_run_work
  (git-fixes).
- media: sti: Fix reference count leaks (git-fixes).
- mmc: sdio: Check for CISTPL_VERS_1 buffer size (git-fixes).
- net: usb: qmi_wwan: add Cellient MPL200 card (git-fixes).
- commit 9642953
* Fri Oct 30 2020 tiwai@suse.de
- media: exynos4-is: Fix several reference count leaks due to
  pm_runtime_get_sync (git-fixes).
- media: exynos4-is: Fix a reference count leak due to
  pm_runtime_get_sync (git-fixes).
- media: exynos4-is: Fix a reference count leak (git-fixes).
- media: vsp1: Fix runtime PM imbalance on error (git-fixes).
- media: platform: s3c-camif: Fix runtime PM imbalance on error
  (git-fixes).
- media: platform: sti: hva: Fix runtime PM imbalance on error
  (git-fixes).
- media: bdisp: Fix runtime PM imbalance on error (git-fixes).
- media: media/pci: prevent memory leak in bttv_probe (git-fixes).
- media: rcar_drif: Allocate v4l2_async_subdev dynamically
  (git-fixes).
- media: rcar_drif: Fix fwnode reference leak when parsing DT
  (git-fixes).
- commit ff98d93
* Fri Oct 30 2020 tiwai@suse.de
- mailbox: avoid timer start from callback (git-fixes).
- mac80211: handle lack of sband->bitrates in rates (git-fixes).
- HID: ite: Add USB id match for Acer One S1003 keyboard dock
  (git-fixes).
- eeprom: at25: set minimum read/write access stride to 1
  (git-fixes).
- media: i2c: ov5640: Enable data pins on poweron for DVP mode
  (git-fixes).
- media: i2c: ov5640: Separate out mipi configuration from s_power
  (git-fixes).
- media: i2c: ov5640: Remain in power down for DVP mode unless
  streaming (git-fixes).
- media: uvcvideo: Ensure all probed info is returned to v4l2
  (git-fixes).
- media: saa7134: avoid a shift overflow (git-fixes).
- media: venus: core: Fix runtime PM imbalance in venus_probe
  (git-fixes).
- commit 1c003ee
* Fri Oct 30 2020 tiwai@suse.de
- Bluetooth: Only mark socket zapped after unlocking (git-fixes).
- Bluetooth: btusb: Fix memleak in btusb_mtk_submit_wmt_recv_urb
  (git-fixes).
- ath9k: hif_usb: fix race condition between usb_get_urb()
  and usb_kill_anchored_urbs() (git-fixes).
- can: flexcan: flexcan_chip_stop(): add error handling and
  propagate error value (git-fixes).
- brcmsmac: fix memory leak in wlc_phy_attach_lcnphy (git-fixes).
- ath10k: check idx validity in __ath10k_htt_rx_ring_fill_n()
  (git-fixes).
- brcm80211: fix possible memleak in brcmf_proto_msgbuf_attach
  (git-fixes).
- dmaengine: dw: Activate FIFO-mode for memory peripherals only
  (git-fixes).
- crypto: ccp - fix error handling (git-fixes).
- commit faa1609
* Fri Oct 30 2020 tiwai@suse.de
- ahci: Add Intel Rocket Lake PCH-H RAID PCI IDs (jsc#SLE-16742).
- commit 272dae5
* Fri Oct 30 2020 glin@suse.com
- libbpf: Fix build failure from uninitialized variable warning
  (bsc#1177028).
- selftests/bpf: Remove test_align leftovers (bsc#1177028).
- libbpf: Fix BTF-defined map-in-map initialization on 32-bit
  host arches (bsc#1177028).
- commit bd71fe7
* Fri Oct 30 2020 glin@suse.com
- tools, bpftool: Add ringbuf map type to map command docs
  (bsc#1177028).
- commit 2cec4e1
* Fri Oct 30 2020 glin@suse.com
- tools/bpftool: Add ringbuf map to a list of known map types
  (bsc#1177028).
- tools/bpftool: Fix skeleton codegen (bsc#1177028).
- tools, bpftool: Exit on error in function codegen (bsc#1177028).
- tools, bpftool: Fix memory leak in codegen error cases
  (bsc#1177028).
- tools, bpf: Do not force gcc as CC (bsc#1177028).
- tools/bpf: Don't use $(COMPILE.c) (bsc#1177028).
- bpftool: Support link show for netns-attached links
  (bsc#1177028).
- bpftool: Extract helpers for showing link attach type
  (bsc#1177028).
- tools/bpf: sync bpf.h (bsc#1177028).
- tools, bpftool: Print correct error message when failing to
  load BTF (bsc#1177028).
- tools, bpftool: Make capability check account for new BPF caps
  (bsc#1177028).
- tools, bpftool: Clean subcommand help messages (bsc#1177028).
- tools/bpf: sync bpf.h (bsc#1177028).
- bpf, bpftool: Enable get{peer, sock}name attach types
  (bsc#1177028).
- samples, bpf: Refactor kprobe, tail call kern progs map
  definition (bsc#1177028).
- samples, bpf: Add tracex7 test file to .gitignore (bsc#1177028).
- samples, bpf: Refactor tail call user progs with libbpf
  (bsc#1177028).
- samples, bpf: Refactor kprobe tracing user progs with libbpf
  (bsc#1177028).
- samples, bpf: Refactor pointer error check with libbpf
  (bsc#1177028).
- bpf, bpftool: Allow probing for CONFIG_HZ from kernel config
  (bsc#1177028).
- samples/bpf: xdp_redirect_cpu: Set MAX_CPUS according to NR_CPUS (bsc#1177028).
  Update patches.suse/bpf-xdp-samples-Fix-null-pointer-dereference-in-_use.patch
- samples/bpf: Remove compiler warnings (bsc#1177028).
- tools, bpftool: Minor fixes for documentation (bsc#1177028).
- tools, bpftool: Poison and replace kernel integer typedefs
  (bsc#1177028).
- bpf, runqslower: include proper uapi/bpf.h (bsc#1177028).
- commit d2d5b93
* Fri Oct 30 2020 tiwai@suse.de
- dmaengine: idxd: Merge definition of dsa_batch_desc into
  dsa_hw_desc (jsc#SLE-12866).
- commit 7fcf034
* Fri Oct 30 2020 glin@suse.com
- tools/bpftool: Add bpf_iter support for bptool (bsc#1177028).
- tools: bpftool: Make libcap dependency optional (bsc#1177028).
- tools: bpftool: Allow unprivileged users to probe features
  (bsc#1177028).
- tools: bpftool: For "feature probe" define "full_mode" bool
  as global (bsc#1177028).
- bpftool: Add link bash completions (bsc#1177028).
- bpftool: Add bpftool-link manpage (bsc#1177028).
- bpftool: Add bpf_link show and pin support (bsc#1177028).
- bpftool: Expose attach_type-to-string array to non-cgroup code
  (bsc#1177028).
- tools/bpf/bpftool: Remove duplicate headers (bsc#1177028).
- commit 3fdccaf
* Fri Oct 30 2020 glin@suse.com
- bpf: Fix too large copy from user in bpf_test_init
  (bsc#1177028).
- bpf: Add xdp.frame_sz in bpf_prog_test_run_xdp() (bsc#1177028).
- commit 3a2d58c
* Fri Oct 30 2020 glin@suse.com
- selftests/bpf: Extend map-in-map selftest to detect memory leaks
  (bsc#1177028).
- libbpf: Fix libbpf hashmap on (I)LP32 architectures
  (bsc#1177028).
- bpf: Add tests for PTR_TO_BTF_ID vs. null comparison
  (bsc#1177028).
- selftests: bpf: Pass program to bpf_prog_detach in
  flow_dissector (bsc#1177028).
- selftests: bpf: Pass program and target_fd in
  flow_dissector_reattach (bsc#1177028).
- selftests/bpf: Test updating flow_dissector link with same
  program (bsc#1177028).
- bpf, sockmap: Add ingres skb tests that utilize merge skbs
  (bsc#1177028).
- libbpf: Adjust SEC short cut for expected attach type
  BPF_XDP_DEVMAP (bsc#1177028).
- libbpf: Fix CO-RE relocs against .text section (bsc#1177028).
- libbpf: Forward-declare bpf_stats_type for systems with outdated
  UAPI headers (bsc#1177028).
- selftests/bpf: Add cgroup_skb/egress test for
  load_bytes_relative (bsc#1177028).
- libbpf: Handle GCC noreturn-turned-volatile quirk (bsc#1177028).
- libbpf: Define __WORDSIZE if not available (bsc#1177028).
- bpf: Selftests and tools use struct bpf_devmap_val from uapi
  (bsc#1177028).
- selftests/bpf: Fix ringbuf selftest sample counting
  undeterminism (bsc#1177028).
- selftests/bpf: Add a default $(CXX) value (bsc#1177028).
- bpf, selftests: Use bpf_probe_read_kernel (bsc#1177028).
- selftests/bpf: Fix sample_cnt shared between two threads
  (bsc#1177028).
- bpf, selftests: Adapt cls_redirect to call csum_level helper
  (bsc#1177028).
- selftests/bpf: Extend test_flow_dissector to cover link creation
  (bsc#1177028).
- selftests/bpf: Convert test_flow_dissector to use BPF skeleton
  (bsc#1177028).
- selftests/bpf: Add tests for attaching bpf_link to netns
  (bsc#1177028).
- libbpf: Add support for bpf_link-based netns attachment
  (bsc#1177028).
- libbpf: Add _GNU_SOURCE for reallocarray to ringbuf.c
  (bsc#1177028).
- selftests/bpf: Add test for SO_BINDTODEVICE opt of
  bpf_setsockopt (bsc#1177028).
- bpf, selftests: Add test for ktls with skb bpf ingress policy
  (bsc#1177028).
- selftest: Add tests for XDP programs in devmap entries
  (bsc#1177028).
- libbpf: Add SEC name for xdp programs attached to device map
  (bsc#1177028).
- selftests/bpf: Add BPF ringbuf selftests (bsc#1177028).
- libbpf: Add BPF ring buffer support (bsc#1177028).
- selftests/bpf: Add tests for write-only stacks/queues
  (bsc#1177028).
- selftests/bpf: Cleanup comments in test_maps (bsc#1177028).
- selftests/bpf: Cleanup some file descriptors in test_maps
  (bsc#1177028).
- selftests/bpf: Fix a typo in test_maps (bsc#1177028).
- bpf, selftests: Test probe_* helpers from SCHED_CLS
  (bsc#1177028).
- bpf, selftests: Add sk_msg helpers load and attach test
  (bsc#1177028).
- libbpf: Use .so dynamic symbols for abi check (bsc#1177028).
- libbpf: Install headers as part of make install (bsc#1177028).
- libbpf: Add API to consume the perf ring buffer content
  (bsc#1177028).
- selftests/bpf: Add general instructions for test execution
  (bsc#1177028).
- bpf: Selftests, add printk to test_sk_lookup_kern to encode
  null ptr check (bsc#1177028).
- bpf: Selftests, verifier case for non null pointer map value
  branch (bsc#1177028).
- bpf: Selftests, verifier case for non null pointer check branch
  taken (bsc#1177028).
- selftests/bpf: Convert bpf_iter_test_kern{3, 4}.c to define
  own bpf_iter_meta (bsc#1177028).
- selftest/bpf: Make bpf_iter selftest compilable against old
  vmlinux.h (bsc#1177028).
- bpf, testing: Add get{peer, sock}name selftests to test_progs
  (bsc#1177028).
- bpf, libbpf: Enable get{peer, sock}name attach types
  (bsc#1177028).
- bpf: Selftests, add ktls tests to test_sockmap (bsc#1177028).
- bpf: Selftests, add blacklist to test_sockmap (bsc#1177028).
- bpf: Selftests, add whitelist option to test_sockmap
  (bsc#1177028).
- bpf: Selftests, provide verbose option for selftests execution
  (bsc#1177028).
- bpf: Selftests, break down test_sockmap into subtests
  (bsc#1177028).
- bpf: Selftests, improve test_sockmap total bytes counter
  (bsc#1177028).
- bpf: Selftests, print error in test_sockmap error cases
  (bsc#1177028).
- bpf: Selftests, sockmap test prog run without setting cgroup
  (bsc#1177028).
- bpf: Selftests, remove prints from sockmap tests (bsc#1177028).
- bpf: Selftests, move sockmap bpf prog header into progs
  (bsc#1177028).
- selftests/bpf: Move test_align under test_progs (bsc#1177028).
- libbpf, hashmap: Fix signedness warnings (bsc#1177028).
- libbpf, hashmap: Remove unused #include (bsc#1177028).
- selftests/bpf: Use CAP_BPF and CAP_PERFMON in tests
  (bsc#1177028).
- selftests/bpf: Xdp_adjust_tail add grow tail tests
  (bsc#1177028).
- selftests/bpf: Adjust BPF selftest for xdp_adjust_tail
  (bsc#1177028).
- selftests/bpf: Test for sk helpers in cgroup skb (bsc#1177028).
- selftests/bpf: Add connect_fd_to_fd, connect_wait net helpers
  (bsc#1177028).
- selftest/bpf: Fix spelling mistake "SIGALARM" -> "SIGALRM"
  (bsc#1177028).
- selftests/bpf: Test narrow loads for bpf_sock_addr.user_port
  (bsc#1177028).
- bpf: Change btf_iter func proto prefix to "bpf_iter_"
  (bsc#1177028).
- tools/bpf: selftests : Explain bpf_iter test failures with
  llvm 10.0.0 (bsc#1177028).
- selftests/bpf: Extract parse_num_list into generic
  testing_helpers.c (bsc#1177028).
- libbpf: Fix probe code to return EPERM if encountered
  (bsc#1177028).
- tools/bpf: selftests: Add bpf_iter selftests (bsc#1177028).
- tools/bpf: selftests: Add iter progs for bpf_map/task/task_file
  (bsc#1177028).
- tools/bpf: selftests: Add iterator programs for ipv6_route
  and netlink (bsc#1177028).
- tools/libpf: Add offsetof/container_of macro in bpf_helpers.h
  (bsc#1177028).
- tools/libbpf: Add bpf_iter support (bsc#1177028).
- selftests/bpf: Move existing common networking parts into
  network_helpers (bsc#1177028).
- selftests/bpf: Generalize helpers to control background listener
  (bsc#1177028).
- bpf: Add selftest for BPF_ENABLE_STATS (bsc#1177028).
- libbpf: Add support for command BPF_ENABLE_STATS (bsc#1177028).
- selftests/bpf: Test allowed maps for bpf_sk_select_reuseport
  (bsc#1177028).
- libbpf: Fix false uninitialized variable warning (bsc#1177028).
- selftests/bpf: Test that lookup on SOCKMAP/SOCKHASH is allowed
  (bsc#1177028).
- selftests/bpf: Disable ASAN instrumentation for mmap()'ed
  memory read (bsc#1177028).
- libbpf: Fix memory leak and possible double-free in
  hashmap__clear (bsc#1177028).
- selftests/bpf: Convert test_hashmap into test_progs test
  (bsc#1177028).
- selftests/bpf: Add SAN_CFLAGS param to selftests build to
  allow sanitizers (bsc#1177028).
- libbpf: Add BTF-defined map-in-map support (bsc#1177028).
- libbpf: Refactor map creation logic and fix cleanup leak
  (bsc#1177028).
- libbpf: Refactor BTF-defined map definition parsing logic
  (bsc#1177028).
- selftests/bpf: Test bpf_link's get_next_id, get_fd_by_id,
  and get_obj_info (bsc#1177028).
- libbpf: Add low-level APIs for new bpf_link commands
  (bsc#1177028).
- selftests/bpf: fix test_sysctl_prog with alu32 (bsc#1177028).
- libbpf: Remove unneeded semicolon in btf_dump_emit_type
  (bsc#1177028).
- libbpf: Return err if bpf_object__load failed (bsc#1177028).
- selftests/bpf: Add cls_redirect classifier (bsc#1177028).
- commit db2bf96
* Fri Oct 30 2020 glin@suse.com
- bpf_helpers.h: Add note for building with vmlinux.h or
  linux/types.h (bsc#1177028).
- commit 7f826c8
* Thu Oct 29 2020 mkubecek@suse.cz
- dm/dax: Fix table reference counts (bsc#1178246).
- commit 89a1d25
* Thu Oct 29 2020 oneukum@suse.com
- Documentation: fpga: dfl: add descriptions for interrupt
  related interfaces (jsc#SLE-13441).
- fpga: dfl: afu: add AFU interrupt support (jsc#SLE-13441).
- commit aa24f54
* Thu Oct 29 2020 oneukum@suse.com
- fpga: dfl: afu: add interrupt support for port error reporting
  (jsc#SLE-13441).
- commit 80189bc
* Thu Oct 29 2020 oneukum@suse.com
- fpga: dfl: fme: add performance reporting support
  (jsc#SLE-13441).
- Refresh
  patches.suse/fpga-dfl-afu-support-debug-access-to-memory-mapped-a.patch.
- Refresh
  patches.suse/fpga-dfl-parse-interrupt-info-for-feature-devices-on.patch.
- Refresh
  patches.suse/fpga-dfl-support-multiple-opens-on-feature-device-no.patch.
- commit ac35437
* Thu Oct 29 2020 oneukum@suse.com
- fpga: dfl: fme: remove set but not used variable 'fme'
  (jsc#SLE-13441).
- commit b2e5b38
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: Use readx_poll_timeout() for large timeout
  (jsc#SLE-16008).
- commit 61ad5ca
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: ethernet: aquantia: Fix wrong return value (jsc#SLE-16008).
- commit a9a6a7c
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: fix PTP on AQC10X (jsc#SLE-16008).
- commit 695ed80
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: add hwmon getter for MAC temperature
  (jsc#SLE-16008).
- commit 21d8f0f
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: A0 ntuple filters (jsc#SLE-16008).
- commit a9d8329
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: use intermediate variable to improve readability
  a bit (jsc#SLE-16008).
- commit a5cacbb
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: use U32_MAX in aq_hw_utils.c (jsc#SLE-16008).
- commit 81029eb
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: add support for 64-bit reads/writes
  (jsc#SLE-16008).
- commit ee4fca9
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: enable ipv6 support for TCP LSO and UDP GSO
  (jsc#SLE-16008).
- commit 2b6b5c1
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: use simple assignment in _get_stats and
  _get_sw_stats (jsc#SLE-16008).
- commit 5105a90
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: move FRAC_PER_NS to aq_hw.h (jsc#SLE-16008).
- commit 6850395
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: add support for FW 4.x (jsc#SLE-16008).
- commit 06dc4b7
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: align return value of ver_match function with
  function name (jsc#SLE-16008).
- commit c76e0df
* Thu Oct 29 2020 oneukum@suse.com
- fpga: dfl: fme: add power management support (jsc#SLE-13441).
- Refresh
  patches.suse/fpga-dfl-fme-add-global-error-reporting-support.patch.
- commit 51e1487
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: proper rss_ctrl1 (54c0) initialization
  (jsc#SLE-16008).
- commit 7108188
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: QoS implementation: min_rate (jsc#SLE-16008).
- Refresh
  patches.suse/0079-net-atlantic-A2-flow-control-support.patch.
- commit 2caba0d
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: change the order of arguments for TC
  weight/credit setters (jsc#SLE-16008).
- commit 70fba01
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: always use random TC-queue mapping for TX on A2
  (jsc#SLE-16008).
- commit 381aa34
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: automatically downgrade the number of queues
  if necessary (jsc#SLE-16008).
- commit b8f39b3
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: QoS implementation: max_rate (jsc#SLE-16008).
- Refresh
  patches.suse/0079-net-atlantic-A2-flow-control-support.patch.
- commit 19bafcd
* Thu Oct 29 2020 oneukum@suse.com
- fpga: dfl: fme: add thermal management support (jsc#SLE-13441).
- commit 8ac4e29
* Thu Oct 29 2020 oneukum@suse.com
- fpga: dfl: fme: add global error reporting support
  (jsc#SLE-13441).
- commit a46fd7e
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: make TCVEC2RING accept nic_cfg (jsc#SLE-16008).
- commit 40a7532
* Thu Oct 29 2020 denis.kirjanov@suse.com
- net: atlantic: per-TC queue statistics (jsc#SLE-16008).
- commit 541ba98
* Thu Oct 29 2020 oneukum@suse.com
- fpga: dfl: afu: add STP (SignalTap) support (jsc#SLE-13441).
- commit d5f1610
* Thu Oct 29 2020 oneukum@suse.com
- fpga: dfl: afu: add error reporting support (jsc#SLE-13441).
- commit a5b188f
* Thu Oct 29 2020 oneukum@suse.com
- fpga: dfl: afu: convert platform_driver to use dev_groups
  (jsc#SLE-13441).
- commit 4db51d8
* Thu Oct 29 2020 mhocko@suse.com
- mm: fix a race during THP splitting (bsc#1178255).
- commit d99807e
* Thu Oct 29 2020 oneukum@suse.com
- fpga: dfl: fme: convert platform_driver to use dev_groups
  (jsc#SLE-13441).
- commit 505b01a
* Thu Oct 29 2020 oneukum@suse.com
- fpga: dfl: use driver core functions, not sysfs ones
  (jsc#SLE-13441).
- Refresh
  patches.suse/fpga-dfl-add-id_table-for-dfl-private-feature-driver.patch.
- Refresh
  patches.suse/fpga-dfl-afu-add-AFU-state-related-sysfs-interfaces.patch.
- Refresh
  patches.suse/fpga-dfl-fme-add-DFL_FPGA_FME_PORT_RELEASE-ASSIGN-io.patch.
- Refresh
  patches.suse/fpga-dfl-fme-add-capability-sysfs-interfaces.patch.
- commit bedcd22
* Thu Oct 29 2020 nborisov@suse.com
- btrfs: don't force read-only after error in drop snapshot (bsc#1176354).
- commit 92bd157
* Thu Oct 29 2020 glin@suse.com
- bpf: Fix bpf_ringbuf_output() signature to return long
  (bsc#1177028).
- bpf: Fix formatting in documentation for BPF helpers
  (bsc#1177028).
- selftests/bpf: Fix verifier test (bsc#1177028).
- commit d66394d
* Thu Oct 29 2020 tiwai@suse.de
- rpm/kernel-module-subpackage: make Group tag optional (bsc#1163592)
- commit 552ec97
* Thu Oct 29 2020 lduncan@suse.com
- scsi: pm80xx: Driver version update (jsc#SLE-15151,
  bsc#1178226).
- scsi: pm80xx: Increase the number of outstanding I/O supported
  to 1024 (jsc#SLE-15151, bsc#1178226).
- scsi: pm80xx: Remove DMA memory allocation for ccb and device
  structures (jsc#SLE-15151, bsc#1178226).
- scsi: pm80xx: Increase number of supported queues
  (jsc#SLE-15151, bsc#1178226).
- scsi: pm8001: Fix memleak in pm8001_exec_internal_task_abort
  (jsc#SLE-15151, bsc#1178226).
- scsi: pm8001: Staticify 'pm80xx_pci_mem_copy' and
  'mpi_set_phy_profile_req' (jsc#SLE-15151, bsc#1178226).
- scsi: pm80xx: Introduce read and write length for IOCTL payload
  structure (jsc#SLE-15151, bsc#1178226).
- scsi: pm80xx: sysfs attribute for non fatal dump (jsc#SLE-15151,
  bsc#1178226).
- scsi: pm80xx: Cleanup initialization loading fail path
  (jsc#SLE-15151, bsc#1178226).
- scsi: pm80xx: Free the tag when mpi_set_phy_profile_resp is
  received (jsc#SLE-15151, bsc#1178226).
- scsi: pm80xx: Deal with kexec reboots (jsc#SLE-15151,
  bsc#1178226).
- scsi: pm80xx: Increase request sg length (jsc#SLE-15151,
  bsc#1178226).
- scsi: pm80xx: fix logic to break out of loop when register
  value is 2 or 3 (jsc#SLE-15151, bsc#1178226).
- scsi: pm80xx: Modified the logic to collect fatal dump
  (jsc#SLE-15151, bsc#1178226).
- scsi: pm80xx: Tie the interrupt name to the module instance
  (jsc#SLE-15151, bsc#1178226).
- scsi: pm80xx: Controller fatal error through sysfs
  (jsc#SLE-15151, bsc#1178226).
- scsi: pm80xx: Do not request 12G sas speeds (jsc#SLE-15151,
  bsc#1178226).
- scsi: pm80xx: Cleanup command when a reset times out
  (jsc#SLE-15151, bsc#1178226).
- scsi: pm80xx: Fix command issue sizing (jsc#SLE-15151,
  bsc#1178226).
- scsi: pm80xx: Fix dereferencing dangling pointer (jsc#SLE-15151,
  bsc#1178226).
- scsi: pm80xx: Increase timeout for pm80xx mpi_uninit_check
  (jsc#SLE-15151, bsc#1178226).
- scsi: pm80xx: Squashed logging cleanup changes (jsc#SLE-15151,
  bsc#1178226).
- scsi: pm80xx: Convert 'long' mdelay to msleep (jsc#SLE-15151,
  bsc#1178226).
- scsi: pm80xx: Initialize variable used as return status
  (jsc#SLE-15151, bsc#1178226).
- scsi: pm80xx: Make phy enable completion as NULL (jsc#SLE-15151,
  bsc#1178226).
- scsi: pm80xx: Fix for SATA device discovery (jsc#SLE-15151,
  bsc#1178226).
- scsi: pm8001: Fix Use plain integer as NULL pointer
  (jsc#SLE-15151, bsc#1178226).
- commit bec0ea0
* Wed Oct 28 2020 rgoldwyn@suse.com
- btrfs: sysfs: export currently running exclusive operation
  (JSC#SLE-15234).
- btrfs: enumerate the type of exclusive operation in progress
  (JSC#SLE-15234).
- commit e361c67
* Wed Oct 28 2020 bp@suse.de
- Refresh
  patches.suse/x86-powerpc-rename-memcpy_mcsafe-to-copy_mc_to_-user-kernel.patch.
- commit 344359b
* Wed Oct 28 2020 tiwai@suse.de
- i2c: i801: Add support for Intel Alder Lake PCH-S
  (jsc#SLE-13489).
- commit 2b8ef70
* Wed Oct 28 2020 tiwai@suse.de
- mtd: spi-nor: intel-spi: Add support for Intel Alder Lake-S
  SPI serial flash (jsc#SLE-13489).
- commit 4232cf5
* Wed Oct 28 2020 tiwai@suse.de
- intel_th: pci: Add Alder Lake CPU support (jsc#SLE-13489).
- intel_th: pci: Add Alder Lake-S support (jsc#SLE-13489).
- commit 6b5a823
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: disable PTP on AQC111, AQC112 (jsc#SLE-16008).
- commit 4a6c857
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: fix ip dst and ipv6 address filters
  (jsc#SLE-16008).
- commit b004437
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: aquantia: fix aq_ndev_start_xmit()'s return type
  (jsc#SLE-16008).
- commit b6021fa
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: put ptp code under IS_REACHABLE check
  (jsc#SLE-16008).
- commit 6c3d69d
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: add alignment checks in hw_atl2_utils_fw.c
  (jsc#SLE-16008).
- commit 9f73783
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: missing space in a comment in aq_nic.h
  (jsc#SLE-16008).
- commit ec38e51
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: fix typo in aq_ring_tx_clean (jsc#SLE-16008).
- commit 0e03f73
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: make aq_pci_func_init static (jsc#SLE-16008).
- commit 0be80bd
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: Replace ENOTSUPP usage to EOPNOTSUPP
  (jsc#SLE-16008).
- commit a5aa6d0
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: fix variable type in aq_ethtool_get_pauseparam
  (jsc#SLE-16008).
- commit 5c45ac8
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: A2: phy loopback support (jsc#SLE-16008).
- commit d0c91fe
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: A2: report link partner capabilities
  (jsc#SLE-16008).
- commit 2996ddf
* Wed Oct 28 2020 trenn@suse.com
- perf/x86/intel/rapl: Add Comet Lake support (jsc#jsc#SLE-13446).
- perf/x86/rapl: Add Ice Lake RAPL support (jsc#SLE-13446).
- perf/x86/rapl: Add support for Intel SPR platform
  (jsc#SLE-13445).
- perf/x86/rapl: Fix missing psys sysfs attributes
  (jsc#SLE-13445).
- perf/x86/rapl: Support multiple RAPL unit quirks
  (jsc#SLE-13445).
- Refresh
  patches.suse/perf-x86-rapl-add-amd-fam17h-rapl-support.patch.
- Refresh
  patches.suse/perf-x86-rapl-add-amd-fam19h-rapl-support.patch.
- Refresh
  patches.suse/perf-x86-rapl-add-hygon-fam18h-rapl-support.patch.
- Refresh
  patches.suse/perf-x86-rapl-move-rapl-support-to-common-x86-code.patch.
- Refresh
  patches.suse/x86-perf-events-convert-to-new-cpu-match-macros.patch.
- commit 47d5610
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: A2: flow control support (jsc#SLE-16008).
- commit 03d8c35
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: A2: EEE support (jsc#SLE-16008).
- commit 3614f71
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: remove baseX usage (jsc#SLE-16008).
- commit 478c8a1
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: A2: half duplex support (jsc#SLE-16008).
- commit f7a3218
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: QoS implementation: multi-TC support
  (jsc#SLE-16008).
- commit 5e8aa14
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: changes for multi-TC support (jsc#SLE-16008).
- commit 7447162
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: move PTP TC initialization to a separate function
  (jsc#SLE-16008).
- commit 202b4ce
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: changes for multi-TC support (jsc#SLE-16008).
- commit da0d411
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: unify MAC generation (jsc#SLE-16008).
- commit 5bf61f2
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: remove check for boot code survivability before
  reset request (jsc#SLE-16008).
- commit 9b4481d
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: remove hw_atl_b0_hw_rss_set call from A2 code
  (jsc#SLE-16008).
- commit f25f8fb
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: remove TPO2 check from A0 code (jsc#SLE-16008).
- commit 54cd169
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: rename AQ_NIC_RATE_2GS to AQ_NIC_RATE_2G5
  (jsc#SLE-16008).
- commit d260d28
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: A2 ingress / egress hw configuration
  (jsc#SLE-16008).
- commit bb8feac
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: basic A2 init/deinit hw_ops (jsc#SLE-16008).
- commit d8c7240
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: common functions needed for basic A2 init/deinit
  hw_ops (jsc#SLE-16008).
- commit a37eb39
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: HW bindings for basic A2 init/deinit hw_ops
  (jsc#SLE-16008).
- commit 5501020
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: add A2 RPF hw_ops (jsc#SLE-16008).
- commit d1f214e
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: HW bindings for A2 RFP (jsc#SLE-16008).
- commit 0770b88
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: A2 hw_ops skeleton (jsc#SLE-16008).
- commit 4646911
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: minimal A2 fw_ops (jsc#SLE-16008).
- commit b949a7a
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: minimal A2 HW bindings required for fw_ops
  (jsc#SLE-16008).
- commit 4e6e80d
* Wed Oct 28 2020 denis.kirjanov@suse.com
- net: atlantic: A2 driver-firmware interface (jsc#SLE-16008).
- commit 51fe62d
* Wed Oct 28 2020 ailiop@suse.com
- xfs: fix high key handling in the rt allocator's query_range
  function (git-fixes).
- commit cdff05f
* Wed Oct 28 2020 ailiop@suse.com
- xfs: limit entries returned when counting fsmap records
  (git-fixes).
- commit 6ab6787
* Wed Oct 28 2020 ailiop@suse.com
- xfs: fix xfs_bmap_validate_extent_raw when checking attr fork
  of rt files (git-fixes).
- commit 4c9c85b
* Wed Oct 28 2020 oneukum@suse.com
- fpga: dfl: introduce interrupt trigger setting API
  (jsc#SLE-13441).
- commit 3693890
* Wed Oct 28 2020 oneukum@suse.com
- fpga: dfl: Use struct_size() in kzalloc() (jsc#SLE-13441).
- commit ea5ff98
* Wed Oct 28 2020 oneukum@suse.com
- drivers/fpga/dfl-afu-dma-region.c: get rid of pointless
  access_ok() (jsc#SLE-13441).
- commit acf9bc5
* Wed Oct 28 2020 jgross@suse.com
- x86/alternative: Don't call text_poke() in lazy TLB mode
  (bsc#1175749).
- commit 50e105d
* Wed Oct 28 2020 oneukum@suse.com
- drivers/fpga/dfl-fme-pr.c: get rid of pointless access_ok()
  (jsc#SLE-13441).
- commit ca32f7a
* Wed Oct 28 2020 jgross@suse.com
- xen/gntdev.c: Mark pages as dirty (bsc#1065600).
- commit dbb5e22
* Wed Oct 28 2020 oneukum@suse.com
- fpga: dfl: afu: support debug access to memory-mapped afu
  regions (jsc#SLE-13441).
  Refresh
  patches.suse/fpga-dfl-parse-interrupt-info-for-feature-devices-on.patch.
- commit 455d30a
* Wed Oct 28 2020 oneukum@suse.com
- fpga: dfl.h: Replace zero-length array with flexible-array
  member (jsc#SLE-13441).
- commit 3eafa7e
* Wed Oct 28 2020 oneukum@suse.com
- fpga: dfl: support multiple opens on feature device node
  (jsc#SLE-13441).
- commit 4ef7392
* Wed Oct 28 2020 glin@suse.com
- bpf: Fix a buffer out-of-bound access when filling raw_tp
  link_info (bsc#1177028).
- bpf: Use get_file_rcu() instead of get_file() for task_file
  iterator (bsc#1177028).
- bpf: Fix pos computation for bpf_iter seq_ops->start()
  (bsc#1177028).
- commit 5d7e0cc
* Wed Oct 28 2020 glin@suse.com
- selftests/bpf: Fix cgroup sockopt verifier test (bsc#1177028).
- selftests: bpf: Fix detach from sockmap tests (bsc#1177028).
- bpf: Fix definition of bpf_ringbuf_output() helper in UAPI
  comments (bsc#1177028).
- scripts: Require pahole v1.16 when generating BTF (bsc#1177028).
- bpf: Use strncpy_from_unsafe_strict() in bpf_seq_printf()
  helper (bsc#1177028).
- sysctl: Fix unused function warning (bsc#1177028).
- bpf, btf: Always output invariant hit in pahole DWARF to BTF
  transform (bsc#1177028).
- commit 6d1f8a3
* Wed Oct 28 2020 shung-hsi.yu@suse.com
- staging: qlge: fix build breakage with dumping enabled
  (jsc#SLE-15139).
- commit 506d956
* Wed Oct 28 2020 glin@suse.com
- net/filter: Permit reading NET in load_bytes_relative when
  MAC not set (bsc#1177028).
- bpf: Fix unused-var without NETDEVICES (bsc#1177028).
- bpf: Add csum_level helper for fixing up csum levels
  (bsc#1177028).
- bpf: Fix up bpf_skb_adjust_room helper's skb csum setting
  (bsc#1177028).
- bpf: Allow SO_BINDTODEVICE opt in bpf_setsockopt (bsc#1177028).
- net: Make locking in sock_bindtoindex optional (bsc#1177028).
  Refresh patches.suse/udp_tunnel-add-central-NIC-RX-port-offload-infrastru.patch
  to reflect the change of sock_bindtoindex().
- bpf: Add rx_queue_mapping to bpf_sock (bsc#1177028).
- bpf, sk_msg: Add get socket storage helpers (bsc#1177028).
- bpf, sk_msg: Add some generic helpers that may be useful from
  sk_msg (bsc#1177028).
- net: add sock_bindtoindex (bsc#1177028).
  Update patches.suse/udp_tunnel-add-central-NIC-RX-port-offload-infrastru.patch
  since sock_bindtoindex() is available now.
- xdp: Clear grow memory in bpf_xdp_adjust_tail() (bsc#1177028).
- xdp: Allow bpf_xdp_adjust_tail() to grow packet size
  (bsc#1177028).
- bpf: Allow sk lookup helpers in cgroup skb (bsc#1177028).
- bpf: Support narrow loads from bpf_sock_addr.user_port
  (bsc#1177028).
- bpf: Allow any port in bpf_bind helper (bsc#1177028).
- net: Refactor arguments of inet{,6}_bind (bsc#1177028).
- net: bpf: Allow TC programs to call BPF_FUNC_skb_change_head
  (bsc#1177028).
- commit 450a84c
* Tue Oct 27 2020 oneukum@suse.com
- fpga: dfl: afu: expose __afu_port_enable/disable function.
- commit 5b0475c
* Tue Oct 27 2020 oneukum@suse.com
- fpga: dfl: make init callback optional (jsc#SLE-13441).
- commit b32d1c0
* Tue Oct 27 2020 oneukum@suse.com
- fpga: dfl: fme: add capability sysfs interfaces (jsc#SLE-13441).
- commit f07ee66
* Tue Oct 27 2020 oneukum@suse.com
- fpga: dfl: make uinit callback optional (jsc#SLE-13441).
- commit 97aba62
* Tue Oct 27 2020 oneukum@suse.com
- fpga: dfl: add id_table for dfl private feature driver
  (jsc#SLE-13441).
- Refresh
  patches.suse/fpga-dfl-parse-interrupt-info-for-feature-devices-on.patch.
- commit 1c32dd6
* Tue Oct 27 2020 hare@suse.de
- nvmet: cleanup nvmet_passthru_map_sg() (jsc#SLE-15608).
- nvmet: limit passthru MTDS by BIO_MAX_PAGES (jsc#SLE-15608).
- nvmet: fix uninitialized work for zero kato (jsc#SLE-15608).
- commit a81c892
* Tue Oct 27 2020 hare@suse.de
- nvme: fix error handling in nvme_ns_report_zones (sc#SLE-15608).
- nvme-core: put ctrl ref when module ref get fail (sc#SLE-15608).
- commit c2c3bd6
* Tue Oct 27 2020 oneukum@suse.com
- fpga: dfl: afu: add AFU state related sysfs interfaces
  (jsc#SLE-13441).
- commit 209190b
* Tue Oct 27 2020 oneukum@suse.com
- fpga: dfl: fme: add DFL_FPGA_FME_PORT_RELEASE/ASSIGN ioctl
  support (jsc#SLE-13441).
- commit ac00bca
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: fix overflow when copying corrupt csums for a message
  (bsc#1178191).
- commit c3fc339
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: fix NULL pointer dereference after failure to create
  snapshot (bsc#1178190).
- commit 28eef23
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: move IS_CHIP_FEATURE to aq_hw.h (jsc#SLE-16008).
- commit 9d450fe
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: make hw_get_regs optional (jsc#SLE-16008).
- commit 12a3b18
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: simplify hw_get_fw_version() usage
  (jsc#SLE-16008).
- commit 62e4c18
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: add hw_soft_reset, hw_prepare to hw_ops
  (jsc#SLE-16008).
- commit 45ab6fe
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: add defines for 10M and EEE 100M link mode
  (jsc#SLE-16008).
- commit 7480975
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: add A2 device IDs (jsc#SLE-16008).
- commit 0773274
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: update company name in the driver description
  (jsc#SLE-16008).
- commit 0f5d712
* Tue Oct 27 2020 denis.kirjanov@suse.com
- aquantia: Fix the media type of AQC100 ethernet controller in
  the driver (jsc#SLE-16008).
- commit 406dc29
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: reject all unsupported coalescing params
  (jsc#SLE-16008).
- commit 0eaa7d1
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net/aquantia: Delete module version (jsc#SLE-16008).
- commit 5186adf
* Tue Oct 27 2020 msuchanek@suse.de
- ibmveth: Identify ingress large send packets (bsc#1178185
  ltc#188897).
- commit 3aff6b0
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: fix out of range usage of active_vlans array
  (jsc#SLE-16008).
- commit 767b557
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: possible fault in transition to hibernation
  (jsc#SLE-16008).
- commit 9b7ca89
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: fix potential error handling (jsc#SLE-16008).
- commit 4de45e6
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: fix use after free kasan warn (jsc#SLE-16008).
- commit bd13c6d
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: better loopback mode handling (jsc#SLE-16008).
- commit 36a3c94
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: ptp gpio adjustments (jsc#SLE-16008).
- commit 9e4a93c
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: check rpc result and wait for rpc address
  (jsc#SLE-16008).
- commit f2ea36a
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: checksum compat issue (jsc#SLE-16008).
- commit 2c43929
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: remove duplicate entries (jsc#SLE-16008).
- commit 45fa5a5
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: loopback configuration in improper place
  (jsc#SLE-16008).
- commit 7542f00
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: broken link status on old fw (jsc#SLE-16008).
- commit 9963398
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: Signedness bug in aq_vec_isr_legacy()
  (jsc#SLE-16008).
- commit 51612bf
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: make function 'aq_ethtool_get_priv_flags',
  'aq_ethtool_set_priv_flags' static (jsc#SLE-16008).
- commit f34e741
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: make symbol 'aq_pm_ops' static (jsc#SLE-16008).
- commit 4288149
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: change email domains to Marvell (jsc#SLE-16008).
- commit dfda9f0
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: implement UDP GSO offload (jsc#SLE-16008).
- commit b6460d3
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: update flow control logic (jsc#SLE-16008).
- commit 26034f9
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: stylistic renames (jsc#SLE-16008).
- commit 004b28b
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: code style cleanup (jsc#SLE-16008).
- commit 5024da7
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: loopback tests via private flags (jsc#SLE-16008).
- commit 2dca0a3
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: add fw configuration memory area (jsc#SLE-16008).
- commit 8e8f518
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: adding ethtool physical identification
  (jsc#SLE-16008).
- commit ce37fb5
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: add msglevel configuration (jsc#SLE-16008).
- commit 04f6084
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: refactoring pm logic (jsc#SLE-16008).
- commit 845cebe
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: implement wake_phy feature (jsc#SLE-16008).
- commit 0d9f761
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: atlantic: update firmware interface (jsc#SLE-16008).
- commit 8d9f6f9
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: set the lockdep class for log tree extent buffers
  (bsc#1178186).
- commit bf70248
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: fix return value check in aq_ptp_init()
  (jsc#SLE-16008).
- commit 3b0bad1
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: fix error handling in aq_ptp_poll
  (jsc#SLE-16008).
- commit 43b1e12
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: remove unused including <linux/version.h>
  (jsc#SLE-16008).
- commit 299a2b3
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: make two symbols be static (jsc#SLE-16008).
- commit d18cdbe
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: fix unintention integer overflow on left shift
  (jsc#SLE-16008).
- commit 44ba640
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: fix spelling mistake: tx_queus -> tx_queues
  (jsc#SLE-16008).
- commit 2ea997c
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: disable ptp object build if no config
  (jsc#SLE-16008).
- commit b173f76
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: fix warnings on endianness (jsc#SLE-16008).
- commit 7e6bc4c
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: fix var initialization warning (jsc#SLE-16008).
- commit e9a1fed
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: add support for PIN funcs (jsc#SLE-16008).
- commit 9f3bc0a
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: add support for Phy access (jsc#SLE-16008).
- commit 6bf2fe4
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: implement get_ts_info ethtool (jsc#SLE-16008).
- commit fb9ebb2
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: add support for ptp ioctls (jsc#SLE-16008).
- commit 1031c19
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: rx filters for ptp (jsc#SLE-16008).
- commit f68e67d
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: implement data PTP datapath (jsc#SLE-16008).
- commit da13f73
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: styling fixes on ptp related functions
  (jsc#SLE-16008).
- commit bedc284
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: add PTP rings infrastructure (jsc#SLE-16008).
- commit ac5f9c4
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: add basic ptp_clock callbacks (jsc#SLE-16008).
- commit 0e40623
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: unify styling of bit enums (jsc#SLE-16008).
- commit f0d06c7
* Tue Oct 27 2020 denis.kirjanov@suse.com
- net: aquantia: PTP skeleton declarations and callbacks
  (jsc#SLE-16008).
- commit 12af199
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: set the correct lockdep class for new nodes
  (bsc#1178184).
- commit 986c67e
* Tue Oct 27 2020 jeyu@suse.de
- blacklist.conf: blacklist commit 7359608a271c ("scripts/gdb: fix
  lx-symbols 'gdb.error' while loading modules")
  This does not apply since CONFIG_GDB_SCRIPTS isn't enabled in our configs.
- commit 0c385df
* Tue Oct 27 2020 jeyu@suse.de
- module: Correctly truncate sysfs sections output (git-fixes).
- commit 65be42f
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: allocate scrub workqueues outside of locks (bsc#1178183).
- commit f9617fb
* Tue Oct 27 2020 oneukum@suse.com
- fpga: Fix dead store fpga-mgr.c (jsc#SLE-13441).
- commit d5219a7
* Tue Oct 27 2020 oneukum@suse.com
- fpga: remove redundant dev_err message (jsc#SLE-13441).
- commit d6ffca1
* Tue Oct 27 2020 lhenriques@suse.com
- libceph: clear con->out_msg on Policy::stateful_server faults
  (bsc#1178177).
- ceph: promote to unsigned long long before shifting
  (bsc#1178175).
- commit 0c4763b
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: drop path before adding new uuid tree entry
  (bsc#1178176).
- commit dd3432e
* Tue Oct 27 2020 jeyu@suse.de
- module: statically initialize init section freeing data (git-fixes).
- commit 22c6399
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: fix space cache memory leak after transaction abort
  (bsc#1178173).
- commit 980210c
* Tue Oct 27 2020 oneukum@suse.com
- fpga: Remove dev_err() usage after platform_get_irq()
  (jsc#SLE-13441).
- commit 08c5761
* Tue Oct 27 2020 jeyu@suse.de
- module: Do not expose section addresses to non-CAP_SYSLOG (git-fixes).
- commit a568add
* Tue Oct 27 2020 jeyu@suse.de
- module: Refactor section attr into bin attribute (git-fixes).
- commit c081e5b
* Tue Oct 27 2020 jeyu@suse.de
- kallsyms: Refactor kallsyms_show_value() to take cred (git-fixes).
- commit f113536
* Tue Oct 27 2020 oneukum@suse.com
- fpga: dfl: pci: add irq info for feature devices enumeration
  (jsc#SLE-13441).
- commit 630e15d
* Tue Oct 27 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/ipv4-Restore-flowi4_oif-update-before-call-to-xfrm_l.patch
  patches.suse/tipc-fix-the-skb_unshare-in-tipc_buf_append.patch
- commit 70545ba
* Tue Oct 27 2020 mkubecek@suse.cz
- Update kabi files.
- update to second October 2020 maintenance update (commit 78b2b83f5f09)
- commit f4767b1
* Tue Oct 27 2020 msuchanek@suse.de
- scsi: ibmvscsi: Fix potential race after loss of transport
  (bsc#1178166 ltc#188226).
- commit 45b7f66
* Tue Oct 27 2020 glin@suse.com
- bpf: Fix NULL pointer dereference in __btf_resolve_helper_id()
  (bsc#1177028).
- bpf: Fix an incorrect branch elimination by verifier
  (bsc#1177028).
- bpf, netns: Fix use-after-free in pernet pre_exit callback
  (bsc#1177028).
- bpf: sockmap: Require attach_bpf_fd when detaching a program
  (bsc#1177028).
- bpf: flow_dissector: Check value of unused flags to
  BPF_PROG_DETACH (bsc#1177028).
- bpf: flow_dissector: Check value of unused flags to
  BPF_PROG_ATTACH (bsc#1177028).
- bpf, netns: Keep a list of attached bpf_link's (bsc#1177028).
- bpf, netns: Keep attached programs in bpf_prog_array
  (bsc#1177028).
- flow_dissector: Pull BPF program assignment up to bpf-netns
  (bsc#1177028).
- bpf: Enforce BPF ringbuf size to be the power of 2
  (bsc#1177028).
- bpf: Restore behaviour of CAP_SYS_ADMIN allowing the loading
  of networking bpf programs (bsc#1177028).
- bpf: Set the number of exception entries properly for
  subprograms (bsc#1177028).
- bpf: Check correct cred for CAP_SYSLOG in bpf_dump_raw_ok()
  (bsc#1177028).
- kallsyms: Refactor kallsyms_show_value() to take cred
  (bsc#1177028).
- bpf: Devmap adjust uapi for attach bpf program (bsc#1177028).
- bpf: Reset data_meta before running programs attached to devmap
  entry (bsc#1177028).
- bpf: make bpf_check_uarg_tail_zero() use check_zeroed_user()
  (bsc#1177028).
- bpf: Add link-based BPF program attachment to network namespace
  (bsc#1177028).
- flow_dissector: Move out netns_bpf prog callbacks (bsc#1177028).
- net: Introduce netns_bpf for BPF programs attached to netns
  (bsc#1177028).
- bpf: Use tracing helpers for lsm programs (bsc#1177028).
- xdp: Rename convert_to_xdp_frame in xdp_convert_buff_to_frame (bsc#1177028).
  Update patches.suse/0002-igb-add-XDP-support.patch to use xdp_convert_buff_to_frame()
- xdp: Add xdp_txq_info to xdp_buff (bsc#1177028).
- bpf: Add support to attach bpf program to a devmap entry
  (bsc#1177028).
- devmap: Formalize map value as a named struct (bsc#1177028).
- bpf: Implement BPF ring buffer and verifier support for it
  (bsc#1177028).
- bpf: Extend bpf_base_func_proto helpers with probe_* and
  * current_task* (bsc#1177028).
- bpf: Fix spelling in comment explaining ARG1 in ___bpf_prog_run
  (bsc#1177028).
- bpf: Verifier track null pointer branch_taken with JNE and JEQ
  (bsc#1177028).
- bpf: Add get{peer, sock}name attach types for sock_addr
  (bsc#1177028).
- bpf: Fix check_return_code to only allow [0,1] in trace_iter
  progs (bsc#1177028).
- bpf: Implement CAP_BPF (bsc#1177028).
- bpf, capability: Introduce CAP_BPF (bsc#1177028).
- xdp: Cpumap redirect use frame_sz and increase skb_tailroom
  (bsc#1177028).
- bpf: Introduce bpf_sk_{, ancestor_}cgroup_id helpers
  (bsc#1177028).
- bpf: Fix bpf_iter's task iterator logic (bsc#1177028).
- bpf: Enable bpf_iter targets registering ctx argument types
  (bsc#1177028).
- bpf: Change func bpf_iter_unreg_target() signature
  (bsc#1177028).
- bpf: net: Refactor bpf_iter target registration (bsc#1177028).
- bpf: Add comments to interpret bpf_prog return values
  (bsc#1177028).
- tools, bpf: Synchronise BPF UAPI header with tools
  (bsc#1177028).
- bpf: Minor fixes to BPF helpers documentation (bsc#1177028).
- bpf, libbpf: Replace zero-length array with flexible-array
  (bsc#1177028).
- bpf: Support variable length array in tracing programs
  (bsc#1177028).
- bpf: Handle spilled PTR_TO_BTF_ID properly when checking
  stack_boundary (bsc#1177028).
- bpf: Add bpf_seq_printf and bpf_seq_write helpers (bsc#1177028).
- bpf: Add PTR_TO_BTF_ID_OR_NULL support (bsc#1177028).
- bpf: Add task and task/file iterator targets (bsc#1177028).
- net: bpf: Add netlink and ipv6_route bpf_iter targets
  (bsc#1177028).
- bpf: Add bpf_map iterator (bsc#1177028).
- bpf: Implement common macros/helpers for target iterators
  (bsc#1177028).
- bpf: Create file bpf iterator (bsc#1177028).
- bpf: Create anonymous bpf iterator (bsc#1177028).
- bpf: Implement bpf_seq_read() for bpf iterator (bsc#1177028).
- bpf: Support bpf tracing/iter programs for BPF_LINK_UPDATE
  (bsc#1177028).
- bpf: Support bpf tracing/iter programs for BPF_LINK_CREATE
  (bsc#1177028).
- bpf: Allow loading of a bpf_iter program (bsc#1177028).
- bpf: Implement an interface to register bpf_iter targets
  (bsc#1177028).
- selftests/bpf: Use reno instead of dctcp (bsc#1177028).
  Refresh patches.suse/selftests-bpf-CONFIG_LIRC-required-for-test_lirc_mod.patch
- bpf: Fix use-after-free of bpf_link when priming half-fails
  (bsc#1177028).
- bpf: Bpf_{g,s}etsockopt for struct bpf_sock_addr (bsc#1177028).
  Refresh patches.suse/selftests-bpf-CONFIG_LIRC-required-for-test_lirc_mod.patch
- bpf: Sharing bpf runtime stats with BPF_ENABLE_STATS
  (bsc#1177028).
- bpf: Fix unused variable warning (bsc#1177028).
- bpf: Allow bpf_map_lookup_elem for SOCKMAP and SOCKHASH
  (bsc#1177028).
- bpf: Add support for BPF_OBJ_GET_INFO_BY_FD for bpf_link
  (bsc#1177028).
- bpf: Support GET_FD_BY_ID and GET_NEXT_ID for bpf_link
  (bsc#1177028).
- bpf: Allocate ID for bpf_link (bsc#1177028).
- bpf, cgroup: Remove unused exports (bsc#1177028).
- bpf: Make verifier log more relevant by default (bsc#1177028).
- bpf: add bpf_ktime_get_boot_ns() (bsc#1177028).
- net: bpf: Make bpf_ktime_get_ns() available to non GPL programs
  (bsc#1177028).
- bpf: Fix missing bpf_base_func_proto in cgroup_base_func_proto
  for CGROUP_NET=n (bsc#1177028).
- bpf: Enable more helpers for
  BPF_PROG_TYPE_CGROUP_{DEVICE,SYSCTL,SOCKOPT} (bsc#1177028).
- bpf: Remove set but not used variable 'dst_known' (bsc#1177028).
- xdp: export the DEV_MAP_BULK_SIZE macro (bsc#1177028).
- capabilities: Introduce CAP_PERFMON to kernel and user space
  (bsc#1177028).
- commit 5c2c1af
* Tue Oct 27 2020 shung-hsi.yu@suse.com
- staging: qlge: qlge_dbg: removed comment repition
  (jsc#SLE-15139).
- staging: qlge: Use fallthrough pseudo-keyword (jsc#SLE-15139).
- staging: qlge/qlge_main.c: Replace depracated MSI API
  (jsc#SLE-15139).
- staging: qlge: qlge_ethtool: Remove one byte memset
  (jsc#SLE-15139).
- staging: qlge: qlge_mpi: Simplify while statements
  (jsc#SLE-15139).
- staging: qlge: qlge_dbg: Simplify while statements
  (jsc#SLE-15139).
- staging: qlge: qlge.h: Insert line after declaration
  (jsc#SLE-15139).
- staging: qlge: qlge.h: Function definition arguments should
  have names (jsc#SLE-15139).
- staging: qlge: Remove pci-dma-compat wrapper APIs
  (jsc#SLE-15139).
- staging: qlge: qlge_ethtool.c: Proper indentation
  (jsc#SLE-15139).
- staging: qlge: qlge.h: remove unnecessary spaces
  (jsc#SLE-15139).
- staging: qlge/qlge_main.c: use generic power management
  (jsc#SLE-15139).
- staging: qlge: replace pr_err with netdev_err (jsc#SLE-15139).
- staging: qlge: fix ql_sem_unlock (jsc#SLE-15139).
- staging: qlge: fix else after return or break (jsc#SLE-15139).
- staging: qlge: fix trailing */ in block comment (jsc#SLE-15139).
- staging: qlge: qlge_main.c: fixed spaces coding style issues
  (jsc#SLE-15139).
- staging: qlge: unmap dma when lock failed (jsc#SLE-15139).
- staging: qlge: Remove unnecessary spaces in qlge_main.c
  (jsc#SLE-15139).
- staging: qlge: Fix function argument alignment warning in
  ql_init_device (jsc#SLE-15139).
- staging: qlge: Fix suspect code indent warning in ql_init_device
  (jsc#SLE-15139).
- staging: qlge: Remove multi-line dereference from ql_request_irq
  (jsc#SLE-15139).
- staging: qlge: Remove goto statements from ql_get_mac_addr_reg
  (jsc#SLE-15139).
- staging: qlge: Fix indentation in ql_get_mac_addr_reg
  (jsc#SLE-15139).
- staging: qlge: Remove gotos from ql_set_mac_addr_reg
  (jsc#SLE-15139).
- staging: qlge: Fix indentation in ql_set_mac_addr_reg
  (jsc#SLE-15139).
- staging: qlge: Remove print statements for lbq_clean_idx and
  lbq_free_cnt (jsc#SLE-15139).
- staging: qlge: Remove print statement for vlgrp field
  (jsc#SLE-15139).
- staging: qlge: Remove unnecessary parentheses around struct
  field (jsc#SLE-15139).
- staging: qlge: qlge_dbg.c: Remove trailing semicolon from macro
  (jsc#SLE-15139).
- staging: qlge: replace deprecated apis pci_dma_*
  (jsc#SLE-15139).
- staging: qlge: cleanup indent in qlge_main.c (jsc#SLE-15139).
- staging: qlge: reject unsupported coalescing params
  (jsc#SLE-15139).
- Staging: qlge: Add a blank line after variable (jsc#SLE-15139).
- staging: qlge: qlge_ethtool.c: remove an unneeded variable
  (jsc#SLE-15139).
- staging: qlge: qlge_dbg.c: remove an unneeded variable
  (jsc#SLE-15139).
- staging: qlge: qlge_mpi.c: remove an unneeded variable
  (jsc#SLE-15139).
- staging: qlge: qlge_main.c: remove an unneeded variable
  (jsc#SLE-15139).
- staging: qlge: qlge_main: remove unused code (jsc#SLE-15139).
- staging: qlge: qlge_dbg: remove unneeded spaces (jsc#SLE-15139).
- staging: qlge: Fix WARNING: Missing a blank line after
  declarations (jsc#SLE-15139).
- staging: qlge: qlge.h: remove excess newlines (jsc#SLE-15139).
- staging: qlge: qlge.h: add spaces around operators
  (jsc#SLE-15139).
- staging: qlge: qlge.h: remove spaces before tabs and align code
  (jsc#SLE-15139).
- staging: qlge: remove blank line (jsc#SLE-15139).
- staging: qlge: emit debug and dump at same level
  (jsc#SLE-15139).
- staging: qlge: add braces around macro arguments
  (jsc#SLE-15139).
- staging: qlge: add braces on all arms of if-else
  (jsc#SLE-15139).
- staging: qlge: qlge_main.c: fix style issues (jsc#SLE-15139).
- staging: qlge: remove spaces at the start of a line
  (jsc#SLE-15139).
- staging: qlge: Fix CHECK: Alignment should match open
  parenthesis (jsc#SLE-15139).
- staging: qlge: Fix CHECK extra blank lines in many files
  (jsc#SLE-15139).
- staging: qlge: Fix CamelCase in qlge.h and qlge_dbg.c
  (jsc#SLE-15139).
- staging/qlge: fix block comment coding style (jsc#SLE-15139).
- staging/qlge: remove braces in conditional statement
  (jsc#SLE-15139).
- staging/qlge: add braces to conditional statement
  (jsc#SLE-15139).
- staging/qlge: add blank lines after declarations
  (jsc#SLE-15139).
- staging/qlge: remove initialising of static local variable
  (jsc#SLE-15139).
- staging: qlge: fix comparison to NULL warning (jsc#SLE-15139).
- staging: qlge: add space to fix check warning (jsc#SLE-15139).
- staging: qlge: Fix multiple assignments warning by replacing
  integer variables to bool (jsc#SLE-15139).
- staging: qlge: fix "alignment should match open parenthesis"
  checks (jsc#SLE-15139).
- staging: qlge: correct a misspelled word (jsc#SLE-15139).
- staging: qlge: Removed unnecessary variable (jsc#SLE-15139).
- commit b26a44b
* Tue Oct 27 2020 tonyj@suse.de
- tools headers UAPI: Update tools's copy of linux/perf_event.h to add support
  for PERF_SAMPLE_BRANCH_HW_INDEX (dependent fix for jsc#SLE-12718).
- commit 83b34f7
* Mon Oct 26 2020 jroedel@suse.de
- x86/boot: Reload GDTR after copying to the end of the buffer
  (jsc#SLE-14337).
- blacklist.conf: Add c98a76eabbb6 x86/boot/compressed: Fix reloading of GDTR post-relocation
- commit ef841e9
* Mon Oct 26 2020 jroedel@suse.de
- x86/sev-es: Check required CPU features for SEV-ES
  (jsc#SLE-14337).
- Refresh
  patches.suse/0003-x86-KASLR-public-the-function-for-getting-random-lon.patch.
- Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- commit 5feb5c7
* Mon Oct 26 2020 jroedel@suse.de
- x86/kvm: Add KVM-specific VMMCALL handling under SEV-ES
  (jsc#SLE-14337).
- Refresh
  patches.suse/0001-kvm-Reintroduce-nopvspin-kernel-parameter.patch.
- commit a237bee
* Mon Oct 26 2020 dwagner@suse.de
- nvme-rdma: fix crash due to incorrect cqe (bsc#1174748).
- nvme-rdma: fix crash when connect rejected (bsc#1174748).
- commit 066b1e6
* Mon Oct 26 2020 jroedel@suse.de
- x86/boot/compressed/64: Rename kaslr_64.c to ident_map_64.c
  (jsc#SLE-14337).
- Refresh
  patches.suse/0003-x86-KASLR-public-the-function-for-getting-random-lon.patch.
- commit 775a47e
* Mon Oct 26 2020 oneukum@suse.com
- fpga: dfl: parse interrupt info for feature devices on
  enumeration (jsc#SLE-13441).
- commit 9e7db43
* Mon Oct 26 2020 bp@suse.de
- blacklist.conf: 66077adb70a2 EDAC/ti: Fix handling of platform_get_irq() error
- commit 911a955
* Mon Oct 26 2020 bp@suse.de
- blacklist.conf: afce6996943b EDAC/aspeed: Fix handling of platform_get_irq() error
- commit 7a481a8
* Mon Oct 26 2020 jroedel@suse.de
- x86/boot/64: Initialize 5-level paging variables earlier
  (jsc#SLE-14337).
- x86/sev-es: Use GHCB accessor for setting the MMIO scratch
  buffer (jsc#SLE-14337).
- x86/efi: Add GHCB mappings when SEV-ES is active
  (jsc#SLE-14337).
- x86/sev-es: Handle NMI State (jsc#SLE-14337).
- x86/sev-es: Support CPU offline/online (jsc#SLE-14337).
- x86/head/64: Don't call verify_cpu() on starting APs
  (jsc#SLE-14337).
- x86/smpboot: Load TSS and getcpu GDT entry before loading IDT
  (jsc#SLE-14337).
- x86/realmode: Setup AP jump table (jsc#SLE-14337).
- x86/realmode: Add SEV-ES specific trampoline entry point
  (jsc#SLE-14337).
- x86/vmware: Add VMware-specific handling for VMMCALL under
  SEV-ES (jsc#SLE-14337).
- x86/paravirt: Allow hypervisor-specific VMMCALL handling under
  SEV-ES (jsc#SLE-14337).
- x86/sev-es: Handle #DB Events (jsc#SLE-14337).
- x86/sev-es: Handle #AC Events (jsc#SLE-14337).
- x86/sev-es: Handle VMMCALL Events (jsc#SLE-14337).
- x86/sev-es: Handle MWAIT/MWAITX Events (jsc#SLE-14337).
- x86/sev-es: Handle MONITOR/MONITORX Events (jsc#SLE-14337).
- x86/sev-es: Handle INVD Events (jsc#SLE-14337).
- x86/sev-es: Handle RDPMC Events (jsc#SLE-14337).
- x86/sev-es: Handle RDTSC(P) Events (jsc#SLE-14337).
- x86/sev-es: Handle WBINVD Events (jsc#SLE-14337).
- x86/sev-es: Handle DR7 read/write events (jsc#SLE-14337).
- x86/sev-es: Handle MSR events (jsc#SLE-14337).
- x86/sev-es: Handle MMIO String Instructions (jsc#SLE-14337).
- x86/sev-es: Handle MMIO events (jsc#SLE-14337).
- x86/sev-es: Handle instruction fetches from user-space
  (jsc#SLE-14337).
- x86/sev-es: Wire up existing #VC exit-code handlers
  (jsc#SLE-14337).
- x86/sev-es: Add a Runtime #VC Exception Handler (jsc#SLE-14337).
- x86/entry/64: Add entry code for #VC handler (jsc#SLE-14337).
- x86/dumpstack/64: Add noinstr version of get_stack_info()
  (jsc#SLE-14337).
- x86/sev-es: Adjust #VC IST Stack on entering NMI handler
  (jsc#SLE-14337).
- x86/sev-es: Allocate and map an IST stack for #VC handler
  (jsc#SLE-14337).
- x86/sev-es: Setup per-CPU GHCBs for the runtime handler
  (jsc#SLE-14337).
- x86/sev-es: Setup GHCB-based boot #VC handler (jsc#SLE-14337).
- x86/sev-es: Setup an early #VC handler (jsc#SLE-14337).
- x86/sev-es: Compile early handler code into kernel image
  (jsc#SLE-14337).
- x86/sev-es: Print SEV-ES info into the kernel log
  (jsc#SLE-14337).
- x86/sev-es: Add SEV-ES Feature Detection (jsc#SLE-14337).
- x86/head/64: Move early exception dispatch to C code
  (jsc#SLE-14337).
- x86/idt: Make IDT init functions static inlines (jsc#SLE-14337).
- x86/head/64: Install a CPU bringup IDT (jsc#SLE-14337).
- x86/head/64: Switch to initial stack earlier (jsc#SLE-14337).
- x86/head/64: Load segment registers earlier (jsc#SLE-14337).
- x86/head/64: Load GDT after switch to virtual addresses
  (jsc#SLE-14337).
- x86/head/64: Install startup GDT (jsc#SLE-14337).
- x86/idt: Split idt_data setup out of set_intr_gate()
  (jsc#SLE-14337).
- x86/sev-es: Add CPUID handling to #VC handler (jsc#SLE-14337).
- x86/fpu: Move xgetbv()/xsetbv() into a separate header
  (jsc#SLE-14337).
- x86/sev-es: Add support for handling IOIO exceptions
  (jsc#SLE-14337).
- x86/boot/compressed/64: Unmap GHCB page before booting the
  kernel (jsc#SLE-14337).
- x86/boot/compressed/64: Setup a GHCB-based VC Exception handler
  (jsc#SLE-14337).
- x86/boot/compressed/64: Add set_page_en/decrypted() helpers
  (jsc#SLE-14337).
- x86/boot/compressed/64: Check return value of
  kernel_ident_mapping_init() (jsc#SLE-14337).
- x86/boot/compressed/64: Call set_sev_encryption_mask() earlier
  (jsc#SLE-14337).
- x86/boot/compressed/64: Add stage1 #VC handler (jsc#SLE-14337).
- x86/boot/compressed/64: Change add_identity_map() to take
  start and end (jsc#SLE-14337).
- x86/boot/compressed/64: Don't pre-map memory in KASLR code
  (jsc#SLE-14337).
- x86/boot/compressed/64: Always switch to own page table
  (jsc#SLE-14337).
- x86/boot/compressed/64: Add page-fault handler (jsc#SLE-14337).
- x86/boot/compressed/64: Add IDT Infrastructure (jsc#SLE-14337).
- x86/boot/compressed/64: Disable red-zone usage (jsc#SLE-14337).
- x86/insn: Add insn_has_rep_prefix() helper (jsc#SLE-14337).
- x86/insn: Add insn_get_modrm_reg_off() (jsc#SLE-14337).
- x86/umip: Factor out instruction decoding (jsc#SLE-14337).
- x86/umip: Factor out instruction fetch (jsc#SLE-14337).
- x86/insn: Make inat-tables.c suitable for pre-decompression code
  (jsc#SLE-14337).
- x86/traps: Move pf error codes to <asm/trap_pf.h>
  (jsc#SLE-14337).
- x86/cpufeatures: Add SEV-ES CPU feature (jsc#SLE-14337).
- KVM: SVM: Use __packed shorthand (jsc#SLE-14337).
- KVM: SVM: Add GHCB Accessor functions (jsc#SLE-14337).
- KVM: SVM: Add GHCB definitions (jsc#SLE-14337).
- x86/traps: Split trap numbers out in a separate header
  (jsc#SLE-14337).
- x86/boot/compressed/64: Switch to __KERNEL_CS after GDT is
  loaded (jsc#SLE-14337).
- x86/insn-eval: Add support for 64-bit kernel mode
  (jsc#SLE-14337).
- commit 51e85e3
* Mon Oct 26 2020 tiwai@suse.de
- clk: tegra: Drop !provider check in tegra210_clk_emc_set_rate()
  (bsc#1177399).
- devlink: Protect devlink port list traversal (bsc#1177399).
- devlink: Fix per port reporter fields initialization
  (bsc#1177399).
- gpio: pca953x: Correctly initialize registers 6 and 7 for
  PCA957x (bsc#1177399).
- gpio: pca953x: Fix uninitialized pending variable (bsc#1177399).
- clk: tegra: Fix missing prototype for
  tegra210_clk_register_emc() (bsc#1177399).
- commit fccb5a7
* Mon Oct 26 2020 tiwai@suse.de
- ata: sata_rcar: Fix DMA boundary mask (git-fixes).
- reset: sti: reset-syscfg: fix struct description warnings
  (git-fixes).
- soc: fsl: qbman: Fix return value on success (git-fixes).
- memory: fsl-corenet-cf: Fix handling of platform_get_irq()
  error (git-fixes).
- memory: omap-gpmc: Fix build error without CONFIG_OF
  (git-fixes).
- memory: omap-gpmc: Fix a couple off by ones (git-fixes).
- docs: driver-api: remove a duplicated index entry (git-fixes).
- ACPI: debug: don't allow debugging when ACPI is disabled
  (git-fixes).
- acpi-cpufreq: Honor _PSD table setting on new AMD CPUs
  (git-fixes).
- Input: sun4i-ps2 - fix handling of platform_get_irq() error
  (git-fixes).
- Input: twl4030_keypad - fix handling of platform_get_irq()
  error (git-fixes).
- Input: omap4-keypad - fix handling of platform_get_irq() error
  (git-fixes).
- Input: ep93xx_keypad - fix handling of platform_get_irq()
  error (git-fixes).
- Input: stmfts - fix a & vs && typo (git-fixes).
- Input: imx6ul_tsc - clean up some errors in imx6ul_tsc_resume()
  (git-fixes).
- nfc: Ensure presence of NFC_ATTR_FIRMWARE_NAME attribute in
  nfc_genl_fw_download() (git-fixes).
- r8169: fix operation under forced interrupt threading
  (git-fixes).
- commit 7585044
* Mon Oct 26 2020 tiwai@suse.de
- ntb: intel: Fix memleak in intel_ntb_pci_probe (git-fixes).
- NTB: hw: amd: fix an issue about leak system resources
  (git-fixes).
- i2c: core: Restore acpi_walk_dep_device_list() getting called
  after registering the ACPI i2c devs (git-fixes).
- commit cb55b2a
* Mon Oct 26 2020 mbenes@suse.cz
- ring-buffer: Return 0 on success from ring_buffer_resize()
  (git-fixes).
- commit 720b2ea
* Mon Oct 26 2020 tiwai@suse.de
- supported.conf: Preliminary sort before Leap feature enablement (jsc#SLE-11796)
  No functional changes.
- commit 0f7124d
* Mon Oct 26 2020 mhocko@suse.com
- Refresh
  patches.suse/0001-kernel-allow-to-configure-PREEMPT_NONE-PREEMPT_VOLUN.patch.
  compile fix for s390 which needs to include jump_label.h explicitly at
  many places for zfcpdump config. It seems that the arch code is pulling
  some headers in a different order than for other config. I didn't drill
  down to find the change but I have found out that including jump_label.h
  from list.h fixes all the problematic dependencies. This is quite ugly
  but I didn't find a better way than pushing an explicit jump_label.h
  include to many places which would be more disruptive and potentially
  open different header dependencies.
- commit 4de44eb
* Mon Oct 26 2020 ptesarik@suse.cz
- s390/pkey/zcrypt: Support EP11 AES secure keys (jsc#SLE-13750).
- s390/zcrypt: extend EP11 card and queue sysfs attributes
  (jsc#SLE-13750).
- s390/zcrypt: add new low level ep11 functions support file
  (jsc#SLE-13750).
- s390/zcrypt: ep11 structs rework, export zcrypt_send_ep11_cprb
  (jsc#SLE-13750).
- s390/zcrypt: enable card/domain autoselect on ep11 cprbs
  (jsc#SLE-13750).
- commit 36252af
* Mon Oct 26 2020 ptesarik@suse.cz
- s390: nvme reipl (jsc#SLE-13731).
- s390: nvme ipl (jsc#SLE-13731).
- commit 249ffe5
* Mon Oct 26 2020 ptesarik@suse.cz
- s390/ipl: add support to control memory clearing for FCP and
  CCW re-IPL (jsc#SLE-13740).
- commit 16d5877
* Mon Oct 26 2020 glin@suse.com
- Update patches.suse/bpf-Enforce-returning-0-for-fentry-fexit-progs.patch (bsc#1154353 bsc#1177028).
- commit 4882d03
* Mon Oct 26 2020 msuchanek@suse.de
- powerpc/powernv/dump: Fix race while processing OPAL dump
  (bsc#1065729).
- commit b42269b
* Mon Oct 26 2020 msuchanek@suse.de
- cxl: Rework error message for incompatible slots (bsc#1055014
  git-fixes).
- commit 2fd3e91
* Mon Oct 26 2020 mhocko@suse.com
- mm/hugetlb: fix a race between hugetlb sysctl handlers
  (bsc#1176485, CVE-2020-25285).
- commit 2afa8d8
* Mon Oct 26 2020 msuchanek@suse.de
- powerpc/64s: Remove TM from Power10 features (jsc#SLE-13521
  git-fixes).
- commit 8d9325b
* Mon Oct 26 2020 msuchanek@suse.de
- powerpc/pseries: Avoid using addr_to_pfn in real mode
  (jsc#SLE-9246 git-fixes).
- commit 2dc2a0c
* Mon Oct 26 2020 tiwai@suse.de
- PM: hibernate: Batch hibernate and resume IO requests
  (bsc#1178079).
- commit 3742aaa
* Mon Oct 26 2020 msuchanek@suse.de
- Refresh patches.suse/powerpc-Fix-undetected-data-corruption-with-P9N-DD2..patch.
  refresh patch metadata
- commit 006e264
* Mon Oct 26 2020 msuchanek@suse.de
- ibmvnic: save changed mac address to adapter->mac_addr
  (bsc#1134760 ltc#177449 git-fixes).
- commit 1e71262
* Mon Oct 26 2020 glin@suse.com
- bpf: sockmap: Don't attach programs to UDP sockets
  (bsc#1177028).
- bpf, sockhash: Synchronize delete from bucket list on map free
  (bsc#1177028).
- bpf, sockhash: Fix memory leak when unlinking sockets in
  sock_hash_free (bsc#1177028).
- commit 87ab30a
* Sun Oct 25 2020 mkubecek@suse.cz
- kernel-binary.spec.in: pack scripts/module.lds into kernel-$flavor-devel
  Since mainline commit 596b0474d3d9 ("kbuild: preprocess module linker
  script") in 5.10-rc1, scripts/module.lds linker script is needed to build
  out of tree modules. Add it into kernel-$flavor-devel subpackage.
- commit fe37c16
* Sun Oct 25 2020 jlee@suse.com
- kABI: Fix kABI after add CodeSigning extended key usage
  (bsc#1177353).
- commit b9f566d
* Sun Oct 25 2020 jlee@suse.com
- PKCS#7: Check codeSigning EKU for kernel module and kexec pe
  verification (bsc#1177353).
- PKCS#7: Check codeSigning EKU for kernel module and kexec pe
  verification.
- Add CONFIG_CHECK_CODESIGN_EKU
- X.509: Add CodeSigning extended key usage parsing (bsc#1177353).
- commit 4dbabee
* Sat Oct 24 2020 bp@suse.de
- x86/ioapic: Unbreak check_timer() (bsc#1152489).
- commit 520671d
* Sat Oct 24 2020 bp@suse.de
- blacklist.conf: 5fa9a98fb103 bpf, x86_32: Fix incorrect encoding in BPF_LDX zero-extension
- commit 7f6fdc7
* Sat Oct 24 2020 tiwai@suse.de
- ALSA: hda/ca0132: make some const arrays static, makes object
  smaller (git-fixes).
- commit 8afe17a
* Sat Oct 24 2020 tiwai@suse.de
- ALSA: hda - Fix the return value if cb func is already
  registered (git-fixes).
- ALSA: usb-audio: Line6 Pod Go interface requires static clock
  rate quirk (git-fixes).
- ALSA: sparc: dbri: fix repeated word 'the' (git-fixes).
- commit ac47bec
* Fri Oct 23 2020 mkubecek@suse.cz
- blacklist.conf: commit 9def3b1a07c4 not needed
  Mainline commit 9def3b1a07c4 ("iommu/vt-d: Don't dereference iommu_device
  if IOMMU_API is not built") is a build fix which is only needed for config
  with CONFIG_IOMMU_API disabled. As both SLE15-SP2 and openSUSE-15.2 have
  CONFIG_IOMMU_API=y in all configs where applicable, we don't need this
  build fix.
- commit 28bc04c
* Fri Oct 23 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/powerpc-numa-Offline-memoryless-cpuless-node-0.patch
  patches.suse/powerpc-numa-Prefer-node-id-queried-from-vphn.patch
  patches.suse/powerpc-numa-Set-numa_node-for-all-possible-cpus.patch
- commit b2e8401
* Fri Oct 23 2020 yousaf.kaukab@suse.com
- bus: fsl-mc: probe the allocatable objects first
  (jsc#SLE-12251).
- bus: fsl-mc: use raw spin lock to serialize mc cmds
  (jsc#SLE-12251).
- bus: fsl-mc: add missing device types (jsc#SLE-12251).
- bus: fsl-mc: Add ACPI support for fsl-mc (jsc#SLE-12251).
- bus/fsl-mc: Refactor the MSI domain creation in the DPRC driver
  (jsc#SLE-12251).
- of/irq: Make of_msi_map_rid() PCI bus agnostic (jsc#SLE-12251).
- of/irq: make of_msi_map_get_device_domain() bus agnostic
  (jsc#SLE-12251).
- dt-bindings: arm: fsl: Add msi-map device-tree binding for
  fsl-mc bus (jsc#SLE-12251).
- of/device: Add input id to of_dma_configure() (jsc#SLE-12251).
- of/iommu: Make of_map_rid() PCI agnostic (jsc#SLE-12251).
- ACPI/IORT: Add an input ID to acpi_dma_configure()
  (jsc#SLE-12251).
- ACPI/IORT: Remove useless PCI bus walk (jsc#SLE-12251).
- ACPI/IORT: Make iort_msi_map_rid() PCI agnostic (jsc#SLE-12251).
- ACPI/IORT: Make iort_get_device_domain IRQ domain agnostic
  (jsc#SLE-12251).
- ACPI/IORT: Make iort_match_node_callback walk the ACPI namespace
  for NC (jsc#SLE-12251).
- soc: fsl: dpio: Remove unused inline function
  qbman_write_eqcr_am_rt_register (jsc#SLE-12251).
- soc: fsl: dpio: Prefer the CPU affine DPIO (jsc#SLE-12251).
- soc: fsl: qbman: Remove unused inline function
  qm_eqcr_get_ci_stashing (jsc#SLE-12251).
- soc: fsl: dpio: properly compute the consumer index
  (jsc#SLE-12251).
- ACPI/IORT: Remove the unused __get_pci_rid() (jsc#SLE-12251).
- ACPI: IORT: Add comments for not calling acpi_put_table()
  (jsc#SLE-12251).
- ACPI: GTDT: Put GTDT table after parsing (jsc#SLE-12251).
- ACPI: IORT: Add extra message "applying workaround" for off-by-1
  issue (jsc#SLE-12251).
- ACPI/IORT: work around num_ids ambiguity (jsc#SLE-12251).
- ACPI/IORT: take _DMA methods into account for named components
  (jsc#SLE-12251).
- soc: fsl: dpio: avoid stack usage warning (jsc#SLE-12251).
- soc: fsl: dpio: fix incorrect pointer conversions
  (jsc#SLE-12251).
- soc: fsl: dpio: fix dereference of pointer p before null check
  (jsc#SLE-12251).
- soc: fsl: dpio: Replace QMAN array mode with ring mode enqueue
  (jsc#SLE-12251).
- soc: fsl: dpio: QMAN performance improvement with function
  pointer indirection (jsc#SLE-12251).
- soc: fsl: dpio: Adding QMAN multiple enqueue interface
  (jsc#SLE-12251).
- bus: fsl-mc: add api to retrieve mc version (jsc#SLE-12251).
- bus: fsl-mc: properly empty-initialize structure
  (jsc#SLE-12251).
- bus: fsl-mc: add the fsl_mc_get_endpoint function
  (jsc#SLE-12251).
- bus: fsl-mc: export device types present on the bus
  (jsc#SLE-12251).
- bus: fsl-mc: remove explicit device_link_del (jsc#SLE-12251).
- soc: fsl: dpio: remove explicit device_link_remove
  (jsc#SLE-12251).
- soc: fsl: fix spelling mistake "Firmaware" -> "Firmware"
  (jsc#SLE-12251).
- ACPI/IORT: Rename arm_smmu_v3_set_proximity() 'node' local
  variable (jsc#SLE-12251).
- commit d927b04
* Fri Oct 23 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/tracing-check-return-value-of-_create_val_fields-before-using-its-result.patch
  patches.suse/tracing-save-normal-string-variables.patch
- commit 164cdc8
* Fri Oct 23 2020 bp@suse.de
- perf/x86/rapl: Add AMD Fam19h RAPL support (jsc#SLE-16869).
- commit aec12eb
* Fri Oct 23 2020 shung-hsi.yu@suse.com
- compiler.h: Enforce that READ_ONCE_NOCHECK() access size is sizeof(long) (bsc#1177591 jsc#SLE-15848).
- commit b23589e
* Fri Oct 23 2020 bp@suse.de
- perf/x86/rapl: Fix RAPL config variable bug (jsc#SLE-16869).
- commit d328740
* Fri Oct 23 2020 bp@suse.de
- perf/x86/rapl: Make perf_probe_msr() more robust and flexible
  (jsc#SLE-16869).
- commit 4e5d9f2
* Fri Oct 23 2020 bp@suse.de
- perf/x86/rapl: Add Hygon Fam18h RAPL support (jsc#SLE-16869).
- commit 6a72ee5
* Fri Oct 23 2020 bp@suse.de
- perf/x86/rapl: Add AMD Fam17h RAPL support (jsc#SLE-16869).
- commit bfb5274
* Fri Oct 23 2020 ptesarik@suse.cz
- btrfs: use larger zlib buffer for s390 hardware compression
  (jsc#SLE-13766).
- lib/zlib: add zlib_deflate_dfltcc_enabled() function
  (jsc#SLE-13766).
- s390/boot: add dfltcc= kernel command line parameter
  (jsc#SLE-13766).
- lib/zlib: add s390 hardware support for kernel zlib_inflate
  (jsc#SLE-13766).
- s390/boot: rename HEAP_SIZE due to name collision
  (jsc#SLE-13766).
- lib/zlib: add s390 hardware support for kernel zlib_deflate
  (jsc#SLE-13766).
- commit 04bdac2
* Fri Oct 23 2020 bp@suse.de
- perf/x86/rapl: Flip logic on default events visibility
  (jsc#SLE-16869).
- commit 5e90ced
* Fri Oct 23 2020 bp@suse.de
- perf/x86/rapl: Refactor to share the RAPL code between Intel
  and AMD CPUs (jsc#SLE-16869).
- commit fdd0caa
* Fri Oct 23 2020 bp@suse.de
- perf/x86/rapl: Move RAPL support to common x86 code
  (jsc#SLE-16869).
- commit 1ff01f0
* Fri Oct 23 2020 glin@suse.com
- arm64: bpf: optimize modulo operation (bsc#1177028).
- commit 81b5b85
* Fri Oct 23 2020 ptesarik@suse.cz
- crypto/testmgr: enable selftests for paes-s390 ciphers
  (jsc#SLE-13722, bsc#1177116, LTC#185152).
- s390/crypto: enable clear key values for paes ciphers
  (jsc#SLE-13722, bsc#1177116, LTC#185152).
- s390/pkey: Add support for key blob with clear key value
  (jsc#SLE-13722, bsc#1177116, LTC#185152).
- s390/crypto: Rework on paes implementation (jsc#SLE-13722,
  bsc#1177116, LTC#185152).
- crypto: s390/paes - convert to skcipher API (jsc#SLE-13722,
  bsc#1177116, LTC#185152).
- commit 43d6ca5
* Fri Oct 23 2020 glin@suse.com
- bpf, x86_32: Fix logic error in BPF_LDX zero-extension
  (bsc#1177028).
- bpf, x86_32: Fix clobbering of dst for BPF_JSET (bsc#1177028).
- bpf, x86_32: Fix incorrect encoding in BPF_LDX zero-extension
  (bsc#1177028).
- bpf, x86: Fix encoding for lower 8-bit registers in BPF_STX
  BPF_B (bsc#1177028).
- bpf, x32: Fix bug with JMP32 JSET BPF_X checking upper bits
  (bsc#1177028).
- bpf, x86: Small optimization in comparing against imm0
  (bsc#1177028).
- commit 37449ae
* Fri Oct 23 2020 ptesarik@suse.cz
- Update patch references
- patches.suse/vfio-ccw-enable-transparent-ccw-ipl-from-dasd
  (bsc#1175713, jsc#SLE-13665).
- commit fecea13
* Fri Oct 23 2020 glin@suse.com
- tools: Sync uapi/linux/if_link.h (bsc#1177028).
- commit 049f93a
* Fri Oct 23 2020 ptesarik@suse.cz
- s390: support KPROBES_ON_FTRACE (jsc#SLE-13726).
- commit 62c2432
* Fri Oct 23 2020 tiwai@suse.de
- serial: 8250_pci: Implement MSI(-X) support (jsc#SLE-15898).
- commit f391149
* Fri Oct 23 2020 glin@suse.com
- bpf: Use migrate_disable/enable in array macros and cgroup/lirc
  code (bsc#1177028).
- bpf: Use bpf_prog_run_pin_on_cpu() at simple call sites
  (bsc#1177028).
- bpf: Replace cant_sleep() with cant_migrate() (bsc#1177028).
- perf/bpf: Remove preempt disable around BPF invocation
  (bsc#1177028).
- bpf/trace: Remove redundant preempt_disable from
  trace_call_bpf() (bsc#1177028).
- bpf: disable preemption for bpf progs attached to uprobe
  (bsc#1177028).
- bpf/trace: Remove EXPORT from trace_call_bpf() (bsc#1177028).
- bpf/tracing: Remove redundant preempt_disable() in
  __bpf_trace_run() (bsc#1177028).
- sched: Provide cant_migrate() (bsc#1177028).
- bpf: Fix deadlock with rq_lock in bpf_send_signal()
  (bsc#1177028).
- commit 3827970
* Fri Oct 23 2020 tiwai@suse.de
- clk: bcm2835: add missing release if devm_clk_hw_register fails
  (git-fixes).
- clk: qcom: gcc-sdm660: Fix wrong parent_map (git-fixes).
- clk: imx8mq: Fix usdhc parents order (git-fixes).
- clk: at91: clk-main: update key before writing AT91_CKGR_MOR
  (git-fixes).
- clk: at91: remove the checking of parent_name (git-fixes).
- clk: keystone: sci-clk: fix parsing assigned-clock data during
  probe (git-fixes).
- clk: meson: g12a: mark fclk_div2 as critical (git-fixes).
- pwm: img: Fix null pointer access in probe (git-fixes).
- PCI: aardvark: Check for errors from pci_bridge_emul_init()
  call (git-fixes).
- watchdog: sp5100: Fix definition of EFCH_PM_DECODEEN3
  (git-fixes).
- watchdog: Use put_device on error (git-fixes).
- watchdog: Fix memleak in watchdog_cdev_register (git-fixes).
- rtc: rx8010: don't modify the global rtc ops (git-fixes).
- i2c: imx: Fix external abort on interrupt in exit paths
  (git-fixes).
- i2c: rcar: Auto select RESET_CONTROLLER (git-fixes).
- ida: Free allocated bitmap in error path (git-fixes).
- commit affb66d
* Fri Oct 23 2020 glin@suse.com
- bpf, sockmap: bpf_tcp_ingress needs to subtract bytes from
  sg.size (bsc#1177028).
- bpf: Add bpf_sk_storage support to bpf_tcp_ca (bsc#1177028).
- bpf, tcp: Make tcp_bpf_recvmsg static (bsc#1177028).
- bpf, tcp: Fix unused function warnings (bsc#1177028).
- commit fd5b8a2
* Fri Oct 23 2020 jslaby@suse.cz
- ipv4: Restore flowi4_oif update before call to xfrm_lookup_route
  (git-fixes).
- tipc: fix the skb_unshare() in tipc_buf_append() (git-fixes).
- commit 1834339
* Fri Oct 23 2020 glin@suse.com
- bpf: sockmap: Add UDP support (bsc#1177028).
- bpf: Add sockmap hooks for UDP sockets (bsc#1177028).
- bpf: sockmap: Simplify sock_map_init_proto (bsc#1177028).
- bpf: sockmap: Move generic sockmap hooks from BPF TCP
  (bsc#1177028).
- bpf: tcp: Guard declarations with CONFIG_NET_SOCK_MSG
  (bsc#1177028).
- bpf: tcp: Move assertions into tcp_bpf_get_proto (bsc#1177028).
- skmsg: Update saved hooks only once (bsc#1177028).
- bpf: sockmap: Only check ULP for TCP sockets (bsc#1177028).
- bpf, sk_msg: Don't clear saved sock proto on restore
  (bsc#1177028).
- bpf, sk_msg: Let ULP restore sk_proto and write_space callback
  (bsc#1177028).
- bpf, sockmap: Replace zero-length array with flexible-array
  member (bsc#1177028).
- bpf, sockmap: Remove bucket->lock from sock_{hash|map}_free
  (bsc#1177028).
- commit 66ade7e
* Thu Oct 22 2020 mbrugger@suse.com
- arm64: tlb: Use the TLBI RANGE feature in arm64 (jsc#SLE-13697).
- commit 77608e2
* Thu Oct 22 2020 mbrugger@suse.com
- arm64: enable tlbi range instructions (jsc#SLE-13697).
- Update config file.
- commit 040e15c
* Thu Oct 22 2020 mbrugger@suse.com
- arm64: tlb: Detect the ARMv8.4 TLBI RANGE feature
  (jsc#SLE-13697).
- Refresh
  patches.suse/kabi-arm64-reserve-space-in-cpu_hwcaps-and-cpu_hwcap.patch.
- commit 8e95b94
* Thu Oct 22 2020 mbrugger@suse.com
- arm64: tlb: don't set the ttl value in flush_tlb_page_nosync
  (jsc#SLE-13697).
- commit ea02817
* Thu Oct 22 2020 mbrugger@suse.com
- arm64: Shift the __tlbi_level() indentation left
  (jsc#SLE-13697).
- commit 8434482
* Thu Oct 22 2020 mbrugger@suse.com
- arm64: tlb: Set the TTL field in flush_*_tlb_range
  (jsc#SLE-13697).
- commit 223e4ec
* Thu Oct 22 2020 mbrugger@suse.com
- arm64: tlb: Set the TTL field in flush_tlb_range
  (jsc#SLE-13697).
- commit 1f88247
* Thu Oct 22 2020 mbrugger@suse.com
- arm64: Add tlbi_user_level TLB invalidation helper
  (jsc#SLE-13697).
- commit 78ea77e
* Thu Oct 22 2020 mbrugger@suse.com
- arm64: Add level-hinted TLB invalidation helper (jsc#SLE-13697).
- commit 4310a61
* Thu Oct 22 2020 yousaf.kaukab@suse.com
- firmware: smccc: Fix missing prototype warning for arm_smccc_version_init (jsc#SLE-12251).
- firmware: psci: Export functions to manage the OSI mode (jsc#SLE-12251).
- PSCI: cpuidle: Refactor CPU suspend power_state parameter
  handling (jsc#SLE-12251).
- ARM: psci: cpuidle: Enable PSCI CPUidle driver (jsc#SLE-12251).
- commit e84f31f
* Thu Oct 22 2020 yousaf.kaukab@suse.com
- ARM: psci: cpuidle: Introduce PSCI CPUidle driver
  (jsc#SLE-12251).
- drivers: firmware: psci: Decouple checker from generic ARM
  CPUidle (jsc#SLE-12251).
- ARM: cpuidle: Remove overzealous error logging (jsc#SLE-12251).
- ARM: cpuidle: Remove useless header include (jsc#SLE-12251).
- commit 24f2a6e
* Thu Oct 22 2020 hare@suse.de
- nvme: don't call revalidate_disk from nvme_set_queue_dying
  (jsc#SLE-15608).
- block: fix locking for struct block_device size updates
  (jsc#SLE-15608).
- block: replace bd_set_size with bd_set_nr_sectors
  (jsc#SLE-15608).
- block: Make request_queue.rpm_status an enum (jsc#SLE-15608).
- commit 6150733
* Thu Oct 22 2020 hare@suse.de
- nvme-core: don't use NVME_NSID_ALL for command effects and
  supported log (jsc#SLE-15608).
- nvme-fc: fail new connections to a deleted host or remote port
  (jsc#SLE-15608).
- nvme-pci: fix NULL req in completion handler (jsc#SLE-15608).
- nvme: return errors for hwmon init (jsc#SLE-15608).
- nvmet: get transport reference for passthru ctrl
  (jsc#SLE-15608).
- nvme-core: get/put ctrl and transport module in
  nvme_dev_open/release() (jsc#SLE-15608).
- nvme-tcp: fix kconfig dependency warning when !CRYPTO
  (jsc#SLE-15608).
- nvme-pci: disable the write zeros command for Intel 600P/P3100
  (jsc#SLE-15608).
- commit 436fefe
* Thu Oct 22 2020 hare@suse.de
- nvme-fabrics: allow to queue requests for live queues
  (jsc#SLE-15608).
- nvme-tcp: cancel async events before freeing event struct
  (jsc#SLE-15608).
- nvme-rdma: cancel async events before freeing event struct
  (jsc#SLE-15608).
- nvme-fc: cancel async events before freeing event struct
  (jsc#SLE-15608).
- nvme: Revert: Fix controller creation races with teardown
  (jsc#SLE-15608).
- commit 3811d9f
* Thu Oct 22 2020 hare@suse.de
- nvme-pci: cancel nvme device request before disabling
  (jsc#SLE-15608).
- nvme: only use power of two io boundaries (jsc#SLE-15608).
- nvme: fix controller instance leak (jsc#SLE-15608).
- nvmet-fc: Fix a missed _irqsave version of spin_lock in
  (jsc#SLE-15608).
- nvme: Fix NULL dereference for pci nvme controllers
  (jsc#SLE-15608).
- nvme-rdma: fix reset hang if controller died in the middle of
  (jsc#SLE-15608).
- nvme-rdma: fix timeout handler (jsc#SLE-15608).
- nvme-rdma: serialize controller teardown sequences
  (jsc#SLE-15608).
- nvme-tcp: fix reset hang if controller died in the middle of
  (jsc#SLE-15608).
- nvme-tcp: fix timeout handler (jsc#SLE-15608).
- nvme-tcp: serialize controller teardown sequences
  (jsc#SLE-15608).
- nvme: have nvme_wait_freeze_timeout return if it timed out
  (jsc#SLE-15608).
- nvme-fabrics: don't check state NVME_CTRL_NEW for request
  (jsc#SLE-15608).
- nvmet-tcp: Fix NULL dereference when a connect data comes in
  (jsc#SLE-15608).
- commit 7d52496
* Thu Oct 22 2020 hare@suse.de
- nvmet: Disable keep-alive timer when kato is cleared to 0h
  (jsc#SLE-15608).
- nvme: redirect commands on dying queue (jsc#SLE-15608).
- nvme: just check the status code type in nvme_is_path_error
  (jsc#SLE-15608).
- commit 2d2d113
* Thu Oct 22 2020 hare@suse.de
- nvme: refactor command completion (jsc#SLE-15608).
- Delete
  patches.suse/nvme-multipath-retry-commands-for-dying-queues.patch.
- commit f555779
* Thu Oct 22 2020 hare@suse.de
- nvme: rename and document nvme_end_request (jsc#SLE-15608).
- commit 4e6b152
* Thu Oct 22 2020 hare@suse.de
- nvme: skip noiob for zoned devices (jsc#SLE-15608).
- nvme-pci: fix PRP pool size (jsc#SLE-15608).
- nvme-pci: Use u32 for nvme_dev.q_depth and nvme_queue.q_depth
  (jsc#SLE-15608).
- nvme: Use spin_lock_irq() when taking the ctrl->lock
  (jsc#SLE-15608).
- nvmet: call blk_mq_free_request() directly (jsc#SLE-15608).
- nvmet: fix oops in pt cmd execution (jsc#SLE-15608).
- nvmet: add ns tear down label for pt-cmd handling
  (jsc#SLE-15608).
- commit 84e93f3
* Thu Oct 22 2020 hare@suse.de
- nvme-fc: Fix wrong return value in __nvme_fc_init_request()
  (jsc#SLE-15608).
- nvmet-passthru: Reject commands with non-sgl flags set
  (jsc#SLE-15608).
- nvmet: fix a memory leak (jsc#SLE-15608).
- commit bf90d38
* Thu Oct 22 2020 hare@suse.de
- nvme-loop: remove extra variable in create ctrl (jsc#SLE-15608).
- nvme-loop: set ctrl state connecting after init (jsc#SLE-15608).
- commit c8ebefa
* Thu Oct 22 2020 yousaf.kaukab@suse.com
- arm64: perf: Expose some new events via sysfs (jsc#SLE-12251).
- arm64: perf: Correct the event index in sysfs (jsc#SLE-12251).
- dt-bindings: ARM: Clean up PMU compatible list (jsc#SLE-12251).
- dt-bindings: ARM: Add recent Cortex/Neoverse PMUs
  (jsc#SLE-12251).
- dt-bindings: ARM: Add recent Cortex/Neoverse CPUs
  (jsc#SLE-12251).
- arm64: perf: Clean up enable/disable calls (jsc#SLE-12251).
- arm64: perf: Support new DT compatibles (jsc#SLE-12251).
- arm64: perf: Refactor PMU init callbacks (jsc#SLE-12251).
- arm64: perf: Simplify the ARMv8 PMUv3 event attributes
  (jsc#SLE-12251).
- arm64: perf_event: Add missing header needed for
  smp_processor_id() (jsc#SLE-12251).
- arm64: perf: Remove unused macro (jsc#SLE-12251).
- commit 749ce19
* Thu Oct 22 2020 hare@suse.de
- nvmet: introduce the passthru Kconfig option (jsc#SLE-15608).
- Update config files.
- commit 080c346
* Thu Oct 22 2020 mhocko@suse.com
- Refresh
  patches.suse/0001-kernel-allow-to-configure-PREEMPT_NONE-PREEMPT_VOLUN.patch.
  fix compile issue with CONFIG_PREEMPT=y. might_resched should be noop
  for this config.
- commit 7a7b87e
* Thu Oct 22 2020 hare@suse.de
- nvmet: introduce the passthru configfs interface
  (jsc#SLE-15608).
- nvmet: Add passthru enable/disable helpers (jsc#SLE-15608).
- nvmet: add passthru code to process commands (jsc#SLE-15608).
- commit c84d296
* Thu Oct 22 2020 hare@suse.de
- nvme: export nvme_find_get_ns() and nvme_put_ns()
  (jsc#SLE-15608).
- nvme: introduce nvme_ctrl_get_by_path() (jsc#SLE-15608).
- nvme: introduce nvme_execute_passthru_rq to call
  nvme_passthru_[start|end]() (jsc#SLE-15608).
- nvme: create helper function to obtain command effects
  (jsc#SLE-15608).
- commit 10d11d8
* Thu Oct 22 2020 hare@suse.de
- Refresh
  patches.suse/0031-export-avoid-code-duplication-in-include-linux-expor.patch.
- commit b17f73b
* Thu Oct 22 2020 mhocko@suse.com
- mm: don't panic when links can't be created in sysfs
  (bsc#1178002).
- mm: don't rely on system state to detect hot-plug operations
  (bsc#1178002).
- mm: replace memmap_context by meminit_context (bsc#1178002).
- commit 77a655e
* Thu Oct 22 2020 mbrugger@suse.com
- Update reference for GIC v4.1 support
- Update
  patches.suse/KVM-arm64-vgic-v4-Move-the-GICv4-residency-flow-to-b.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/KVM-arm64-vgic-v4-Plug-race-between-non-residency-an.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/PCI-Remove-unused-includes-and-superfluous-struct-de.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/arm64-Relax-ICC_PMR_EL1-accesses-when-ICC_CTLR_EL1.P.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-Remove-redundant-semicolon-after-while.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-Prepare-for-more-than-16-PPIs.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-Rework-gic_configure_irq-to-take-the-ful.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-Skip-DT-quirks-when-evaluating-IIDR-base.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update patches.suse/irqchip-gic-v3-Add-EPPI-range-support.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update patches.suse/irqchip-gic-v3-Add-ESPI-range-support.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-Add-GICv4.1-VPEID-size-discovery.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-Add-INTID-range-and-convertion-primit.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-Add-quirks-for-HIP06-07-invalid-GICD_.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-Detect-GICv4.1-supporting-RVPEID.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-Dynamically-allocate-PPI-NMI-refcount.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-Dynamically-allocate-PPI-partition-de.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-Fix-GIC_LINE_NR-accessor.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-Fix-missing-__init-for-gic_smp_init.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-Move-irq_domain_update_bus_token-to-a.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-Use-SGIs-without-active-state-if-offe.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-Warn-about-inconsistent-implementatio.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-Workaround-Cavium-erratum-38539-when-.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Add-its_vlpi_map-helpers.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Allow-LPI-invalidation-via-the-Di.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Balance-initial-LPI-affinity-acro.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Factor-out-wait_for_syncr-primiti.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Fix-access-width-for-gicr_syncr.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Fix-get_vlpi_map-breakage-with-do.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Fix-u64-to-__le64-warnings.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Free-collection-mapping-on-device.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Kill-its-device_ids-and-use-TYPER.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Kill-its-ite_size-and-use-TYPER-c.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Lock-VLPI-map-array-before-transl.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Make-is_v4-use-a-TYPER-copy.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Make-vlpi_lock-a-spinlock.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Probe-ITS-page-size-for-all-GITS_.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Remove-superfluous-WARN_ON.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Remove-the-redundant-set_bit-for-.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Rename-VPENDBASER-VPROPBASER-acce.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Synchronise-INT-CLEAR-commands-ta.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Synchronise-INV-command-targettin.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v3-its-Track-LPI-distribution-on-a-per-C.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4-Use-Inner-Shareable-attributes-for-vi.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Add-VPE-INVALL-callback.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Add-VPE-eviction-callback.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Add-VPE-residency-callback.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Add-VSGI-allocation-teardown.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Add-VSGI-property-setup.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Add-initial-SGI-configuration.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Add-mask-unmask-doorbell-callbacks.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Add-support-for-VPENDBASER-s-Dirty-.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Advertise-support-v4.1-to-KVM.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Allow-direct-invalidation-of-VLPIs.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Avoid-64bit-division-for-the-sake-o.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Don-t-use-the-VPE-proxy-if-RVPEID-i.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Drop-tmp-in-inherit_vpe_l1_table_fr.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update patches.suse/irqchip-gic-v4.1-Eagerly-vmap-vPEs.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Ensure-L2-vPE-table-is-allocated-at.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Ensure-accessing-the-correct-RD-whe.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Ensure-mutual-exclusion-between-vPE.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Ensure-mutual-exclusion-betwen-inva.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Fix-programming-of-GICR_VPROPBASER_.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Implement-the-v4.1-flavour-of-VMAPP.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Implement-the-v4.1-flavour-of-VMOVP.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Map-the-ITS-SGIR-register-page.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Move-doorbell-management-to-the-GIC.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Plumb-get-set_irqchip_state-SGI-cal.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Plumb-mask-unmask-SGI-callbacks.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Plumb-set_vcpu_affinity-SGI-callbac.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Plumb-skeletal-VPE-irqchip.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Plumb-skeletal-VSGI-irqchip.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Set-vpe_l1_base-for-all-redistribut.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Skip-absent-CPUs-while-iterating-ov.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Suppress-per-VLPI-doorbell.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Update-effective-affinity-of-virtua.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Use-GFP_ATOMIC-flag-in-allocate_vpe.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Use-readx_poll_timeout_atomic-to-fi.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-VPE-table-aka-GICR_VPROPBASER-alloc.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- Update
  patches.suse/irqchip-gic-v4.1-Wait-for-completion-of-redistributo.patch
  (jsc#SLE-14773 jsc#SLE-14763).
- commit 58e1089
* Thu Oct 22 2020 hare@suse.de
- nvme: clear any SGL flags in passthru commands (jsc#SLE-15608).
- nvmet-fc: remove redundant del_work_active flag (jsc#SLE-15608).
- nvmet-fc: check successful reference in
  nvmet_fc_find_target_assoc (jsc#SLE-15608).
- nvme-hwmon: log the controller device name (jsc#SLE-15608).
- nvme: fix deadlock in disconnect during scan_work and/or
  ana_work (jsc#SLE-15608).
- nvme: document nvme controller states (jsc#SLE-15608).
- nvmet: use xarray for ctrl ns storing (jsc#SLE-15608).
- nvmet-rdma: use new shared CQ mechanism (jsc#SLE-15608).
- nvme-rdma: use new shared CQ mechanism (jsc#SLE-15608).
- nvme-pci: add support for ACPI StorageD3Enable property
  (jsc#SLE-15608).
- nvme-pci: use max of PRP or SGL for iod size (jsc#SLE-15608).
- nvme-core: replace ctrl page size with a macro (jsc#SLE-15608).
- nvme: remove redundant validation in nvme_start_ctrl()
  (jsc#SLE-15608).
- nvme: remove an unnecessary condition (jsc#SLE-15608).
- commit 21d9aa1
* Thu Oct 22 2020 hare@suse.de
- nvme: remove ns->disk checks (jsc#SLE-15608).
- nvme-pci: use standard block status symbolic names
  (jsc#SLE-15608).
- nvme-pci: use the consistent return type of
  nvme_pci_iod_alloc_size() (jsc#SLE-15608).
- nvme-pci: add a blank line after declarations (jsc#SLE-15608).
- nvme-pci: fix some comments issues (jsc#SLE-15608).
- nvme-pci: remove redundant segment validation (jsc#SLE-15608).
- nvme: document quirked Intel models (jsc#SLE-15608).
- nvme: expose reconnect_delay and ctrl_loss_tmo via sysfs
  (jsc#SLE-15608).
- commit feb4139
* Thu Oct 22 2020 hare@suse.de
- nvme: support for zoned namespaces (jsc#SLE-15608).
- nvme: support for multiple Command Sets Supported and Effects
  (jsc#SLE-15608).
- nvme: implement multiple I/O Command Set support
  (jsc#SLE-15608).
- commit 2c62e4c
* Thu Oct 22 2020 hare@suse.de
- null_blk: introduce zone capacity for zoned device
  (jsc#SLE-15608).
- block: add capacity field to zone descriptors (jsc#SLE-15608).
- commit 652b3d0
* Thu Oct 22 2020 hare@suse.de
- nvme: use USEC_PER_SEC instead of magic numbers (jsc#SLE-15608).
- nvmet-tcp: simplify nvmet_process_resp_list (jsc#SLE-15608).
- nvme-tcp: optimize network stack with setting msg flags
  according to batch size (jsc#SLE-15608).
- nvme-tcp: leverage request plugging (jsc#SLE-15608).
- nvme-tcp: have queue prod/cons send list become a llist
  (jsc#SLE-15608).
- nvme-fcloop: verify wwnn and wwpn format (jsc#SLE-15608).
- nvmet: use unsigned type for u64 (jsc#SLE-15608).
- nvmet: introduce flags member in nvmet_fabrics_ops
  (jsc#SLE-15608).
- nvmet-tcp: remove has_keyed_sgls initialization (jsc#SLE-15608).
- nvmet-loop: remove unused 'target_ctrl' in nvme_loop_ctrl
  (jsc#SLE-15608).
- nvme-pci: remove the empty line at the beginning of
  nvme_should_reset() (jsc#SLE-15608).
- nvme-pci: code cleanup for nvme_alloc_host_mem()
  (jsc#SLE-15608).
- nvme-pci: use unsigned for io queue depth (jsc#SLE-15608).
- nvme-core: use u16 type for ctrl->sqsize (jsc#SLE-15608).
- nvme-core: use u16 type for directives (jsc#SLE-15608).
- commit 3cbebd4
* Thu Oct 22 2020 hare@suse.de
- nvme-rdma: fix a missing completion with remove invalidation
  (jsc#SLE-15608).
- nvme: use blk_mq_complete_request_remote to avoid an indirect
  (jsc#SLE-15608).
- commit 46ffbe6
* Thu Oct 22 2020 yousaf.kaukab@suse.com
- clk: composite: add _register_composite_pdata() variants
  (jsc#SLE-12251).
- commit fc35561
* Thu Oct 22 2020 jslaby@suse.cz
- blacklist.conf: add a cleanup
- commit 5a26435
* Thu Oct 22 2020 tzimmermann@suse.de
- supported.conf: Support drm_ttm_helper
- commit 095c607
* Thu Oct 22 2020 hare@suse.de
- nvme-pci: prevent SK hynix PC400 from using Write Zeroes command
  (jsc#SLE-15608).
- nvme-tcp: fix possible hang waiting for icresp response
  (jsc#SLE-15608).
- commit 9bee2f5
* Thu Oct 22 2020 tzimmermann@suse.de
- blacklist.conf: Append 'kbuild: fix 'No such file or directory' warning when cleaning'
- commit dc85c97
* Thu Oct 22 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm: call drm_gem_object_funcs.mmap with fake offset'
- commit 59ce174
* Thu Oct 22 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vram: remove unused declaration'
- commit fcd7497
* Thu Oct 22 2020 tzimmermann@suse.de
- blacklist.conf: Append 'media: meson/ao-cec: move cec_notifier_cec_adap_register after hw setup'
- commit c0b9412
* Thu Oct 22 2020 mgorman@suse.de
- mm, fadvise: improve the expensive remote LRU cache draining
  after FADV_DONTNEED (bnc#1177788 (VM/FS performance-related
  backports)).
- commit 075f23c
* Thu Oct 22 2020 hare@suse.de
- nvme: explicitly update mpath disk capacity on revalidation
  (jsc#SLE-15608).
- nvme-multipath: fix bogus request queue reference put
  (jsc#SLE-15608).
- nvme-multipath: fix deadlock due to head->lock (jsc#SLE-15608).
- nvme: don't protect ns mutation with ns->head->lock
  (jsc#SLE-15608).
- nvme-multipath: fix deadlock between ana_work and scan_work
  (jsc#SLE-15608).
- nvme: fix possible deadlock when I/O is blocked (jsc#SLE-15608).
- nvme-rdma: assign completion vector correctly (jsc#SLE-15608).
- nvme-loop: initialize tagset numa value to the value of the ctrl
  (jsc#SLE-15608).
- nvme-tcp: initialize tagset numa value to the value of the ctrl
  (jsc#SLE-15608).
- nvme-pci: initialize tagset numa value to the value of the ctrl
  (jsc#SLE-15608).
- nvme: set initial value for controller's numa node
  (jsc#SLE-15608).
- commit 43dd2cc
* Thu Oct 22 2020 jslaby@suse.cz
- net: bridge: br_vlan_get_pvid_rcu() should dereference the
  VLAN group under RCU (networking-stable-20_09_24).
- net/mlx5e: TLS, Do not expose FPGA TLS counter if not supported
  (networking-stable-20_09_24).
- net/mlx5e: Enable adding peer miss rules only if merged eswitch
  is supported (networking-stable-20_09_24).
- net/mlx5: Fix FTE cleanup (networking-stable-20_09_24).
- net: sctp: Fix IPv6 ancestor_size calc in sctp_copy_descendant
  (networking-stable-20_09_24).
- net: ipv6: fix kconfig dependency warning for IPV6_SEG6_HMAC
  (networking-stable-20_09_24).
- nfp: use correct define to return NONE fec
  (networking-stable-20_09_24).
- net: phy: Do not warn in phy_stop() on PHY_DOWN
  (networking-stable-20_09_24).
- net: phy: Avoid NPD upon phy_detach() when driver is unbound
  (networking-stable-20_09_24).
- cxgb4: fix memory leak during module unload
  (networking-stable-20_09_24).
- ipv4: Update exception handling for multipath routes via same
  device (networking-stable-20_09_24).
- tipc: use skb_unshare() instead in tipc_buf_append()
  (networking-stable-20_09_24).
- tipc: Fix memory leak in tipc_group_create_member()
  (networking-stable-20_09_24).
- ipv4: Initialize flowi4_multipath_hash in data path
  (networking-stable-20_09_24).
- net: lantiq: Disable IRQs only if NAPI gets scheduled
  (networking-stable-20_09_24).
- net: lantiq: Use napi_complete_done()
  (networking-stable-20_09_24).
- net: lantiq: use netif_tx_napi_add() for TX NAPI
  (networking-stable-20_09_24).
- net: lantiq: Wake TX queue again (networking-stable-20_09_24).
- taprio: Fix allowing too small intervals
  (networking-stable-20_09_24).
- net: DCB: Validate DCB_ATTR_DCB_BUFFER argument
  (networking-stable-20_09_24).
- net: Fix bridge enslavement failure
  (networking-stable-20_09_24).
- tipc: fix shutdown() of connection oriented socket
  (networking-stable-20_09_24).
- ip: fix tos reflection in ack and reset packets
  (networking-stable-20_09_24).
- ipv6: avoid lockdep issue in fib6_del()
  (networking-stable-20_09_24).
- net: dsa: rtl8366: Properly clear member config
  (networking-stable-20_09_24).
- cxgb4: Fix offset when clearing filter byte counters
  (networking-stable-20_09_24).
- act_ife: load meta modules before tcf_idr_check_alloc()
  (networking-stable-20_09_24).
- tipc: fix shutdown() of connectionless socket
  (networking-stable-20_09_11).
- ipv6: Fix sysctl max for fib_multipath_hash_policy
  (networking-stable-20_09_11).
- net: usb: dm9601: Add USB ID of Keenetic Plus DSL
  (networking-stable-20_09_11).
- net: disable netpoll on fresh napis
  (networking-stable-20_09_11).
- gtp: add GTPA_LINK info to msg sent to userspace
  (networking-stable-20_09_11).
- netlabel: fix problems with mapping removal
  (networking-stable-20_09_11).
- sctp: not disable bh in the whole sctp_get_port_local()
  (networking-stable-20_09_11).
- net: systemport: Fix memleak in bcm_sysport_probe
  (networking-stable-20_09_11).
- net: hns: Fix memleak in hns_nic_dev_probe
  (networking-stable-20_09_11).
- net: dsa: b53: check for timeout (networking-stable-20_08_24).
- net/sched: act_ct: Fix skb double-free
  in tcf_ct_handle_fragments() error flow
  (networking-stable-20_08_24).
- net: sctp: Fix negotiation of the number of data streams
  (networking-stable-20_08_24).
- gre6: Fix reception with IP6_TNL_F_RCV_DSCP_COPY
  (networking-stable-20_08_24).
- net/smc: Prevent kernel-infoleak in __smc_diag_dump()
  (networking-stable-20_08_24).
- net: qrtr: fix usage of idr in port assignment to socket
  (networking-stable-20_08_24).
- tipc: fix uninit skb->data in tipc_nl_compat_dumpit()
  (networking-stable-20_08_24).
- net: Fix potential wrong skb->protocol in skb_vlan_untag()
  (networking-stable-20_08_24).
- ipvlan: fix device features (networking-stable-20_08_24).
- bonding: show saner speed for broadcast mode
  (networking-stable-20_08_24).
- net: fec: correct the error path for regulator disable in probe
  (networking-stable-20_08_24).
- commit 913985f
* Thu Oct 22 2020 hare@suse.de
- nvmet: fail outstanding host posted AEN req (jsc#SLE-15608).
- nvme-pci: use simple suspend when a HMB is enabled
  (jsc#SLE-15608).
- nvmet-tcp: constify nvmet_tcp_ops (jsc#SLE-15608).
- nvme-tcp: constify nvme_tcp_mq_ops and nvme_tcp_admin_mq_ops
  (jsc#SLE-15608).
- nvme: do not call del_gendisk() on a disk that was never added
  (jsc#SLE-15608).
- commit 61826ec
* Thu Oct 22 2020 hare@suse.de
- nvme: set dma alignment to qword (jsc#SLE-15608).
- nvmet: cleanups the loop in nvmet_async_events_process
  (jsc#SLE-15608).
- nvmet: fix memory leak when removing namespaces and controllers
  concurrently (jsc#SLE-15608).
- nvmet-rdma: add metadata/T10-PI support (jsc#SLE-15608).
- nvmet: add metadata support for block devices (jsc#SLE-15608).
- nvmet: add metadata/T10-PI support (jsc#SLE-15608).
- nvme: add Metadata Capabilities enumerations (jsc#SLE-15608).
- nvmet: rename nvmet_check_data_len to nvmet_check_transfer_len
  (jsc#SLE-15608).
- nvmet: rename nvmet_rw_len to nvmet_rw_data_len (jsc#SLE-15608).
- nvmet: add metadata characteristics for a namespace
  (jsc#SLE-15608).
- nvme-rdma: add metadata/T10-PI support (jsc#SLE-15608).
- nvme-rdma: introduce nvme_rdma_sgl structure (jsc#SLE-15608).
- nvme: introduce NVME_INLINE_METADATA_SG_CNT (jsc#SLE-15608).
- nvme: enforce extended LBA format for fabrics metadata
  (jsc#SLE-15608).
- nvme: introduce max_integrity_segments ctrl attribute
  (jsc#SLE-15608).
- nvme: make nvme_ns_has_pi accessible to transports
  (jsc#SLE-15608).
- nvme: introduce NVME_NS_METADATA_SUPPORTED flag (jsc#SLE-15608).
- nvme: introduce namespace features flag (jsc#SLE-15608).
- block: always define struct blk_integrity in genhd.h
  (jsc#SLE-15608).
- nvmet: revalidate-ns & generate AEN from configfs
  (jsc#SLE-15608).
- nvmet: generate AEN for ns revalidate size change
  (jsc#SLE-15608).
- nvmet: add helper to revalidate bdev and file ns
  (jsc#SLE-15608).
- nvmet: add async event tracing support (jsc#SLE-15608).
- nvme: delete an unnecessary declaration (jsc#SLE-15608).
- nvme: replace zero-length array with flexible-array
  (jsc#SLE-15608).
- nvme: fix io_opt limit setting (jsc#SLE-15608).
- nvme: disable streams when get stream params failed
  (jsc#SLE-15608).
- nvme-pci: make sure write/poll_queues less or equal then cpu
  count (jsc#SLE-15608).
- nvmet-tcp: move send/recv error handling in the send/recv
  methods instead of call-sites (jsc#SLE-15608).
- nvmet-tcp: set MSG_EOR if we send last payload in the batch
  (jsc#SLE-15608).
- nvmet-tcp: set MSG_SENDPAGE_NOTLAST with MSG_MORE when we have
  more to send (jsc#SLE-15608).
- nvme-tcp: set MSG_SENDPAGE_NOTLAST with MSG_MORE when we have
  more to send (jsc#SLE-15608).
- nvmet: mark nvmet_ana_state static (jsc#SLE-15608).
- nvmet: replace kstrndup() with kmemdup_nul() (jsc#SLE-15608).
- commit 4b287a4
* Thu Oct 22 2020 hare@suse.de
- nvmet: align addrfam list to spec (jsc#SLE-15608).
- nvmet: centralize port enable access for configfs
  (jsc#SLE-15608).
- nvmet: use type-name map for address treq (jsc#SLE-15608).
- nvmet: use type-name map for ana states (jsc#SLE-15608).
- nvmet: use type-name map for address family (jsc#SLE-15608).
- nvmet: add generic type-name mapping (jsc#SLE-15608).
- nvme-tcp: try to send request in queue_rq context
  (jsc#SLE-15608).
- nvme-tcp: avoid scheduling io_work if we are already polling
  (jsc#SLE-15608).
- nvme-tcp: use bh_lock in data_ready (jsc#SLE-15608).
- nvme-pci: align io queue count with allocted nvme_queue in
  nvme_probe (jsc#SLE-15608).
- nvme-pci: remove last_sq_tail (jsc#SLE-15608).
- nvme-pci: remove volatile cqes (jsc#SLE-15608).
- nvme: flush scan work on passthrough commands (jsc#SLE-15608).
- nvme: clean up error handling in nvme_init_ns_head
  (jsc#SLE-15608).
- nvmet: add ns revalidation support (jsc#SLE-15608).
- commit 805e456
* Thu Oct 22 2020 hare@suse.de
- nvmet-fc: slight cleanup for kbuild test warnings
  (jsc#SLE-15608).
- nvmet-rdma: use SRQ per completion vector (jsc#SLE-15608).
- nvme-pci: avoid race between nvme_reap_pending_cqes() and
  nvme_poll() (jsc#SLE-15608).
- commit 343b6c9
* Thu Oct 22 2020 hare@suse.de
- nvme-pci: dma read memory barrier for completions
  (jsc#SLE-15608).
- nvme-pci: fix "slimmer CQ head update" (jsc#SLE-15608).
- commit c96c09c
* Thu Oct 22 2020 hare@suse.de
- nvmet-rdma: fix double free of rdma queue (jsc#SLE-15608).
- nvme-tcp: fix possible crash in recv error flow (jsc#SLE-15608).
- nvme-tcp: don't poll a non-live queue (jsc#SLE-15608).
- commit d7df222
* Thu Oct 22 2020 hare@suse.de
- nvme: fix compat address handling in several ioctls
  (jsc#SLE-15608).
- Delete
  patches.suse/Revert-nvme-allow-64-bit-results-in-passthru-command.patch.
- commit 906a866
* Thu Oct 22 2020 hare@suse.de
- nvme: Use nvme_state_terminal helper (jsc#SLE-15608).
- nvme: Add compat_ioctl handler for NVME_IOCTL_SUBMIT_IO
  (jsc#SLE-15608).
- nvmet-tcp: optimize tcp stack TX when data digest is used
  (jsc#SLE-15608).
- nvmet-rdma: allocate RW ctxs according to mdts (jsc#SLE-15608).
- nvmet-rdma: Implement get_mdts controller op (jsc#SLE-15608).
- nvmet: Add get_mdts op for controllers (jsc#SLE-15608).
- nvme-pci: properly print controller address (jsc#SLE-15608).
- nvme-tcp: break from io_work loop if recv failed
  (jsc#SLE-15608).
- nvme-tcp: move send failure to nvme_tcp_try_send
  (jsc#SLE-15608).
- nvmet-tcp: fix maxh2cdata icresp parameter (jsc#SLE-15608).
- nvme-tcp: optimize queue io_cpu assignment for multiple queue
  maps (jsc#SLE-15608).
- nvme-pci: Simplify nvme_poll_irqdisable (jsc#SLE-15608).
- nvme-pci: Remove two-pass completions (jsc#SLE-15608).
- nvme-pci: Remove tag from process cq (jsc#SLE-15608).
- nvme-pci: slimmer CQ head update (jsc#SLE-15608).
- nvmet: check ncqr & nsqr for set-features cmd (jsc#SLE-15608).
- nvme: Don't deter users from enabling hwmon support
  (jsc#SLE-15608).
- nvmet: Pass lockdep expression to RCU lists (jsc#SLE-15608).
- commit fb6185e
* Thu Oct 22 2020 glin@suse.com
- bpf, sockmap: msg_pop_data can incorrecty set an sge length
  (bsc#1177028).
- bpf: Don't refcount LISTEN sockets in sk_assign() (bsc#1177028).
  Refresh patches.suse/bpf-Fix-use-of-sk-sk_reuseport-from-sk_assign.patch
- net: Track socket refcounts in skb_steal_sock() (bsc#1177028).
- bpf: Enable retrival of pid/tgid/comm from bpf cgroup hooks
  (bsc#1177028).
- net: Remove unneeded export of a couple of xdp generic functions
  (bsc#1177028).
- net: Generate reuseport group ID on group creation (bsc#1177028).
  Refresh patches.suse/bpf-net-Avoid-copying-sk_user_data-of-reuseport_arra.patch
  Refresh patches.suse/bpf-net-Avoid-incorrect-bpf_sk_reuseport_detach-call.patch
- bpf, sockmap: Let all kernel-land lookup values in
  SOCKMAP/SOCKHASH (bsc#1177028).
- bpf, sockmap: Return socket cookie on lookup from syscall
  (bsc#1177028).
- bpf, sockmap: Don't set up upcalls and progs for listening
  sockets (bsc#1177028).
- tcp_bpf: Don't let child socket inherit parent protocol ops
  on copy (bsc#1177028).
- bpf: Return -EBADRQC for invalid map type in __bpf_tx_xdp_map
  (bsc#1177028).
- xdp: Simplify __bpf_tx_xdp_map() (bsc#1177028).
  Refresh patches.suse/xdp-Use-bulking-for-non-map-XDP_REDIRECT-and-consoli.patch
- commit f05cc3f
* Thu Oct 22 2020 tiwai@suse.de
- i2c: ismt: Add support for Intel Emmitsburg PCH (jsc#SLE-13361).
- commit 3971591
* Thu Oct 22 2020 glin@suse.com
- blacklist.conf: b8c50df0cb3eb selftests/bpf: test_progs avoid minus shell exit codes
  Temporarily blacklisted until setns is backported to BPF selftests
- commit b97c3d1
* Thu Oct 22 2020 glin@suse.com
- selftests/bpf: Fix endianness issue in sk_assign (bsc#1177028).
- commit 4f2371e
* Thu Oct 22 2020 tzimmermann@suse.de
- mm: Add a walk_page_mapping() function to the pagewalk code (bsc#1152489)
- commit c62189f
* Thu Oct 22 2020 glin@suse.com
- selftests/bpf: Fix two minor compilation warnings reported by
  GCC 4.9 (bsc#1177028).
- selftests/bpf: Use SOCKMAP for server sockets in bpf_sk_assign test (bsc#1177028).
  Refresh patches.suse/selftests-bpf-Fix-silent-Makefile-output.patch
- selftests/bpf: Fix bpf_link leak in ns_current_pid_tgid selftest
  (bsc#1177028).
- commit e312940
* Thu Oct 22 2020 glin@suse.com
- bpf, selftests: Add a verifier test for assigning 32bit reg
  states to 64bit ones (bsc#1177028).
- commit 0bb2650
* Thu Oct 22 2020 glin@suse.com
- bpf, selftests: Verifier bounds tests need to be updated
  (bsc#1177028).
- samples: bpf: Fix build error (bsc#1177028).
- tools/runqslower: Ensure own vmlinux.h is picked up first
  (bsc#1177028).
- bpftool: Respect the -d option in struct_ops cmd (bsc#1177028).
- selftests/bpf: Add test for freplace program with
  expected_attach_type (bsc#1177028).
- bpf, selftests: Add test for BPF_STX BPF_B storing R10
  (bsc#1177028).
- selftests/bpf: Check for correct program attach/detach in
  xdp_attach test (bsc#1177028).
- tools, bpftool: Fix struct_ops command invalid pointer free
  (bsc#1177028).
- selftests/bpf: Add test for bpf_get_link_xdp_id (bsc#1177028).
- bpf, lsm: Fix the file_mprotect LSM test (bsc#1177028).
- bpf: Fix spelling mistake "arithmatic" -> "arithmetic" in
  test_verifier (bsc#1177028).
- selftests/bpf: Test FD-based cgroup attachment (bsc#1177028).
- bpf: Test_verifier, add alu32 bounds tracking tests
  (bsc#1177028).
- bpf: Test_verifier, #65 error message updates for trunc of
  boundary-cross (bsc#1177028).
- bpf: Test_verifier, bpf_get_stack return value add <0
  (bsc#1177028).
- bpf: Test_progs, add test to catch retval refine error handling
  (bsc#1177028).
- selftests: bpf: Extend sk_assign tests for UDP (bsc#1177028).
- selftests: bpf: Add test for sk_assign (bsc#1177028).
- bpf: lsm: Add selftests for BPF_PROG_TYPE_LSM (bsc#1177028).
  Refresh patches.suse/selftests-bpf-CONFIG_LIRC-required-for-test_lirc_mod.patch
- selftests: Add test for overriding global data value before load
  (bsc#1177028).
- selftests/bpf: Add tests for attaching XDP programs
  (bsc#1177028).
- bpf: Add selftest cases for ctx_or_null argument type
  (bsc#1177028).
- bpf: Test_verifier, #70 error message updates for 32-bit right
  shift (bsc#1177028).
- samples, bpf: Refactor perf_event user program with libbpf
  bpf_link (bsc#1177028).
- samples, bpf: Move read_trace_pipe to trace_helpers
  (bsc#1177028).
- bpf: Add tests for bpf_sk_storage to bpf_tcp_ca (bsc#1177028).
- selftests/bpf: Fix mix of tabs and spaces (bsc#1177028).
- bpftool: Add struct_ops support (bsc#1177028).
- bpftool: Translate prog_id to its bpf prog_name (bsc#1177028).
- bpftool: Print as a string for char array (bsc#1177028).
- bpftool: Print the enum's name instead of value (bsc#1177028).
- selftests/bpf: Reset process and thread affinity after each
  test/sub-test (bsc#1177028).
- selftests/bpf: Fix nanosleep for real this time (bsc#1177028).
- selftest/bpf: Fix compilation warning in sockmap_parse_prog.c
  (bsc#1177028).
- selftests/bpf: Ensure consistent test failure output (bsc#1177028).
  Refresh patches.suse/selftests-bpf-Fix-memory-leak-in-test-selector.patch
- selftests/bpf: Fix spurious failures in accept due to EAGAIN
  (bsc#1177028).
- tools/bpf: Move linux/types.h for selftests and bpftool
  (bsc#1177028).
- selftests/bpf: Fix usleep() implementation (bsc#1177028).
- selftests/bpf: Guarantee that useep() calls nanosleep() syscall
  (bsc#1177028).
- tools: bpftool: Restore message on failure to guess program type
  (bsc#1177028).
- tools/testing/selftests/bpf: Add self-tests for new helper
  bpf_get_ns_current_pid_tgid (bsc#1177028).
- tools: bpftool: Fix minor bash completion mistakes
  (bsc#1177028).
- tools: bpftool: Allow all prog/map handles for pinning objects
  (bsc#1177028).
- bpftool: Add _bpftool and profiler.skel.h to .gitignore
  (bsc#1177028).
- bpftool: Skeleton should depend on libbpf (bsc#1177028).
- bpftool: Only build bpftool-prog-profile if supported by clang
  (bsc#1177028).
- bpftool: Use linux/types.h from source tree for profiler build
  (bsc#1177028).
- tools/runqslower: Add BPF_F_CURRENT_CPU for running selftest
  on older kernels (bsc#1177028).
- bpftool: Bash completion for "bpftool prog profile"
  (bsc#1177028).
- bpftool: Documentation for bpftool prog profile (bsc#1177028).
- bpftool: Introduce "prog profile" command (bsc#1177028).
- selftests: bpf: Enable UDP sockmap reuseport tests
  (bsc#1177028).
- selftests: bpf: Add tests for UDP sockets in sockmap
  (bsc#1177028).
- selftests: bpf: Don't listen() on UDP sockets (bsc#1177028).
- tools/runqslower: Drop copy/pasted BPF_F_CURRENT_CPU definiton
  (bsc#1177028).
- selftests/bpf: Test new __sk_buff field gso_size (bsc#1177028).
- selftests/bpf: Add link pinning selftests (bsc#1177028).
- bpftool: Add header guards to generated vmlinux.h (bsc#1177028).
- selftests/bpf: Add test for "bpftool feature" command
  (bsc#1177028).
- bpftool: Update bash completion for "bpftool feature" command
  (bsc#1177028).
- bpftool: Update documentation of "bpftool feature" command
  (bsc#1177028).
- bpftool: Make probes which emit dmesg warnings optional
  (bsc#1177028).
- bpftool: Move out sections to separate functions (bsc#1177028).
- bpftool: Support struct_ops, tracing, ext prog types
  (bsc#1177028).
- selftests/bpf: Print backtrace on SIGSEGV in test_progs
  (bsc#1177028).
- selftests/bpf: Tests for sockmap/sockhash holding listening
  sockets (bsc#1177028).
- bpf, sockmap: Allow inserting listening TCP sockets into sockmap
  (bsc#1177028).
- selftests/bpf: Fix build of sockmap_ktls.c (bsc#1177028).
- selftests/bpf: Test unhashing kTLS socket after removing from
  map (bsc#1177028).
- commit 3dc4bef
* Thu Oct 22 2020 glin@suse.com
- xdp: Reset prog in dev_change_xdp_fd when fd is negative
  (bsc#1177028).
- bpf: Fix use of sk->sk_reuseport from sk_assign (bsc#1177028).
- bpf: Fix bpf_prog_test_run_tracing for !CONFIG_NET
  (bsc#1177028).
- commit 7440544
* Wed Oct 21 2020 bp@suse.de
- blacklist.conf: 66077adb70a2 EDAC/ti: Fix handling of platform_get_irq() error
- commit d4a0b74
* Wed Oct 21 2020 msuchanek@suse.de
- blacklist.conf: add unnecessary fix
  5b905d77987d powerpc/watchpoint: Fix exception handling for
  CONFIG_HAVE_HW_BREAKPOINT=N
- commit 900b37a
* Wed Oct 21 2020 msuchanek@suse.de
- powerpc/perf/hv-gpci: Fix starting index value (bsc#1065729).
- powerpc/powernv/elog: Fix race while processing OPAL error
  log event (bsc#1065729).
- powerpc/irq: Drop forward declaration of struct irqaction
  (bsc#1065729).
- powerpc/hwirq: Remove stale forward irq_chip declaration
  (bsc#1065729).
- powerpc/icp-hv: Fix missing of_node_put() in success path
  (bsc#1065729).
- powerpc/pseries: Fix missing of_node_put() in rng_init()
  (bsc#1065729).
- commit eb769ab
* Wed Oct 21 2020 msuchanek@suse.de
- powerpc: Warn about use of smt_snooze_delay (bsc#1065729).
- commit 74047a6
* Wed Oct 21 2020 msuchanek@suse.de
- blacklist.conf: Requires powerpc-utils fix.
  a02f6d42357a powerpc: Warn about use of smt_snooze_delay
- commit 3c3b02c
* Wed Oct 21 2020 msuchanek@suse.de
- blacklist.conf: add fixes for unused sensor driver
  66943005cc41 powerpc/tau: Use appropriate temperature sample interval
  5e3119e15fed powerpc/tau: Check processor type before enabling TAU interrupt
  e63d6fb5637e powerpc/tau: Disable TAU between measurements
- commit a434fe6
* Wed Oct 21 2020 yousaf.kaukab@suse.com
- clk: qoriq: add LS1021A core pll mux options (jsc#SLE-12251).
- clk: qoriq: add ls1088a hwaccel clocks support (jsc#SLE-12251).
- clk: fsl-sai: new driver (jsc#SLE-12251).
- commit c256681
* Wed Oct 21 2020 msuchanek@suse.de
- blacklist.conf: Add config fix
  8659a0e0efdd powerpc/64s: Disable STRICT_KERNEL_RWX
  only applies to config, and we don't even have the patch to enable
  STRICT_KERNEL_RWX in config
- commit f4e1850
* Wed Oct 21 2020 tzimmermann@suse.de
- mm: Add write-protect and clean utilities for address space ranges (bsc#1152489)
- commit fe1828a
* Wed Oct 21 2020 msuchanek@suse.de
- powerpc/pseries: explicitly reschedule during drmem_lmb list
  traversal (bsc#1077428 ltc#163882 FATE#324825 git-fixes).
- commit f96b864
* Wed Oct 21 2020 msuchanek@suse.de
- powerpc/papr_scm: Fix warning triggered by perf_stats_show()
  (bsc#1175052 jsc#SLE-13823 bsc#1174969 jsc#SLE-12769 git-fixes).
- commit e9b4893
* Wed Oct 21 2020 tzimmermann@suse.de
- drm/r128: drop use of drmP.h (bsc#1152472)
- commit cd02ef8
* Wed Oct 21 2020 msuchanek@suse.de
- powerpc/book3s64/radix: Make radix_mem_block_size 64bit
  (bsc#1055186 ltc#153436 FATE#323286 git-fixes).
- commit 1f2d815
* Wed Oct 21 2020 msuchanek@suse.de
- powerpc: PPC_SECURE_BOOT should not require PowerNV
  (jsc#SLE-15857 jsc#SLE-13618 git-fixes).
- commit f9c6c03
* Wed Oct 21 2020 msuchanek@suse.de
- powerpc/64: fix irq replay pt_regs->softe value (jsc#SLE-9246
  git-fixes).
- powerpc/64: fix irq replay missing preempt (jsc#SLE-9246
  git-fixes).
- powerpc/xive: Make debug routines static (jsc#SLE-13294
  git-fixes).
- commit d3b1739
* Wed Oct 21 2020 jeyu@suse.de
- arm64: csum: Disable KASAN for do_csum() (bsc#1177591).
- commit 241690b
* Wed Oct 21 2020 jeyu@suse.de
- arm64: csum: Fix pathological zero-length calls (bsc#1177591).
- commit 79df1f5
* Wed Oct 21 2020 oneukum@suse.com
- blacklist.conf: already added
- commit ee45286
* Wed Oct 21 2020 oneukum@suse.com
- usblp: fix race between disconnect() and read() (git-fixes).
- commit 94633e7
* Wed Oct 21 2020 glin@suse.com
- bpf: Fix build warning regarding missing prototypes
  (bsc#1177028).
- bpf: Add selftests for BPF_MODIFY_RETURN (bsc#1177028).
- bpf: Add test ops for BPF_PROG_TYPE_TRACING (bsc#1177028).
- bpf: Add gso_size to __sk_buff (bsc#1177028).
- bpf/tests: Use migrate disable instead of preempt disable
  (bsc#1177028).
- bpf: Expose __sk_buff wire_len/gso_segs to BPF_PROG_TEST_RUN
  (bsc#1177028).
- bpf: Start using the BPF dispatcher in BPF_TEST_RUN
  (bsc#1177028).
- bpf: Switch to offsetofend in BPF_PROG_TEST_RUN (bsc#1177028).
- commit 96ebef6
* Wed Oct 21 2020 tzimmermann@suse.de
- drm/vmwgfx: Add surface dirty-tracking callbacks (bsc#1152489)
- commit 28f358c
* Wed Oct 21 2020 glin@suse.com
- bpf: Fix reStructuredText markup (bsc#1177028).
- bpf: Add socket assign support (bsc#1177028).
- bpf: Switch BPF UAPI #define constants used from BPF program
  side to enums (bsc#1177028).
- bpf: Sync uapi bpf.h to tools/ (bsc#1177028).
- bpf: Document BPF_F_QUERY_EFFECTIVE flag (bsc#1177028).
- commit 1bce83f
* Wed Oct 21 2020 tzimmermann@suse.de
- drm/vmwgfx: Implement an infrastructure for read-coherent resources (bsc#1152489)
- commit d8fb293
* Wed Oct 21 2020 tzimmermann@suse.de
- drm/vmwgfx: Use an RBtree instead of linked list for MOB resources (bsc#1152489)
- commit d109c7a
* Wed Oct 21 2020 tzimmermann@suse.de
- drm/vmwgfx: Implement an infrastructure for write-coherent resources (bsc#1152489)
- commit 3e97d82
* Wed Oct 21 2020 tzimmermann@suse.de
- drm/vmwgfx: Assign eviction priorities to resources (bsc#1152489)
- commit e1ca3e7
* Wed Oct 21 2020 tzimmermann@suse.de
- drm/vmwgfx: Kill unneeded legacy security features (bsc#1152489)
- commit 875b13b
* Wed Oct 21 2020 tzimmermann@suse.de
- drm/vmwgfx: Use VMW_DEBUG_KMS for vmwgfx mode-setting user errors (bsc#1152489)
- commit ccbe045
* Wed Oct 21 2020 tzimmermann@suse.de
- drm/vmwgfx: Add debug message for layout change ioctl (bsc#1152489)
- commit 54b970d
* Wed Oct 21 2020 glin@suse.com
- libbpf: Fix register naming in PT_REGS s390 macros
  (bsc#1177028).
- libbpf: Fix type of old_fd in bpf_xdp_set_link_opts
  (bsc#1177028).
- libbpf: Always specify expected_attach_type on program load
  if supported (bsc#1177028).
- libbpf: Initialize *nl_pid so gcc 10 is happy (bsc#1177028).
- libbpf: Add support for bpf_link-based cgroup attachment
  (bsc#1177028).
- tools/libbpf: Add support for BPF_PROG_TYPE_LSM (bsc#1177028).
- libbpf: Add setter for initial value for internal maps
  (bsc#1177028).
- libbpf: Add function to set link XDP fd while specifying old
  program (bsc#1177028).
- tools: Add EXPECTED_FD-related definitions in if_link.h
  (bsc#1177028).
- xdp: Support specifying expected existing program when attaching
  XDP (bsc#1177028).
- libbpf, xsk: Init all ring members in xsk_umem__create and
  xsk_socket__create (bsc#1177028).
- libbpf: Don't allocate 16M for log buffer by default
  (bsc#1177028).
- libbpf: Remove unused parameter `def` to get_map_field_int
  (bsc#1177028).
- bpf, libbpf: Fix ___bpf_kretprobe_args1(x) macro definition
  (bsc#1177028).
- libbpf: Provide CO-RE variants of PT_REGS macros (bsc#1177028).
- libbpf: Split BTF presence checks into libbpf- and
  kernel-specific parts (bsc#1177028).
- tools/libbpf: Add support for BPF_MODIFY_RETURN (bsc#1177028).
- libbpf: Assume unsigned values for BTF_KIND_ENUM (bsc#1177028).
- libbpf: Add bpf_link pinning/unpinning (bsc#1177028).
- libbpf: Merge selftests' bpf_trace_helpers.h into libbpf's bpf_tracing.h (bsc#1177028).
  Refresh patches.suse/bpf-Add-bpf_xdp_output-helper.patch
- libbpf: Fix use of PT_REGS_PARM macros with vmlinux.h
  (bsc#1177028).
- libbpf: Add support for dynamic program attach target
  (bsc#1177028).
- libbpf: Bump libpf current version to v0.0.8 (bsc#1177028).
- libbpf: Relax check whether BTF is mandatory (bsc#1177028).
- commit 2dacf28
* Wed Oct 21 2020 glin@suse.com
- selftests/bpf: Run reuseport tests only with supported socket types (bsc#1177028).
  Refresh patches.suse/selftests-bpf-Run-SYN-cookies-with-reuseport-BPF-tes.patch
- commit 2eae1ba
* Wed Oct 21 2020 jgross@suse.com
- xen/events: block rogue events for some time (XSA-332
  bsc#1177411).
- commit 014f26b
* Wed Oct 21 2020 jgross@suse.com
- xen/events: defer eoi in case of excessive number of events
  (XSA-332 bsc#1177411).
- commit 956b6f3
* Wed Oct 21 2020 glin@suse.com
- bpf: tcp: bpf_cubic: fix spurious HYSTART_DELAY exit upon drop
  in min RTT (bsc#1177028).
- selftests/bpf: Fix memory leak in test selector (bsc#1177028).
- bpftool: Fix typo in bash-completion (bsc#1177028).
- selftests/bpf: Run SYN cookies with reuseport BPF test only
  for TCP (bsc#1177028).
- selftests/bpf: Extend SK_REUSEPORT tests to cover
  SOCKMAP/SOCKHASH (bsc#1177028).
- selftests/bpf: Fix trampoline_count clean up logic
  (bsc#1177028).
- commit f259c15
* Wed Oct 21 2020 jgross@suse.com
- xen/events: use a common cpu hotplug hook for event channels
  (XSA-332 bsc#1177411).
- commit b9ecbeb
* Wed Oct 21 2020 jgross@suse.com
- xen/events: switch user event channels to lateeoi model
  (XSA-332 bsc#1177411).
- commit 0b00983
* Wed Oct 21 2020 jgross@suse.com
- xen/pciback: use lateeoi irq binding (XSA-332 bsc#1177411).
- commit 47100e6
* Wed Oct 21 2020 jgross@suse.com
- xen/pvcallsback: use lateeoi irq binding (XSA-332 bsc#1177411).
- commit ec73318
* Wed Oct 21 2020 jgross@suse.com
- xen/scsiback: use lateeoi irq binding (XSA-332 bsc#1177411).
- commit 76fa7f0
* Wed Oct 21 2020 jgross@suse.com
- xen/netback: use lateeoi irq binding (XSA-332 bsc#1177411).
- commit 8631138
* Wed Oct 21 2020 jgross@suse.com
- xen/blkback: use lateeoi irq binding (XSA-332 bsc#1177411).
- commit 2689ef1
* Wed Oct 21 2020 jgross@suse.com
- xen/events: add a new "late EOI" evtchn framework (XSA-332
  bsc#1177411).
- commit cd230ce
* Wed Oct 21 2020 jgross@suse.com
- xen/events: fix race in evtchn_fifo_unmask() (XSA-332
  bsc#1177411).
- commit bd30bae
* Wed Oct 21 2020 jgross@suse.com
- xen/events: add a proper barrier to 2-level uevent unmasking
  (XSA-332 bsc#1177411).
- commit e9a9556
* Wed Oct 21 2020 jgross@suse.com
- xen/events: avoid removing an event channel while handling it
  (XSA-331 bsc#1177410).
- commit 0dd2046
* Tue Oct 20 2020 bp@suse.de
- perf/x86: Fix n_pair for cancelled txn (bsc#1152489).
- commit adef112
* Tue Oct 20 2020 bp@suse.de
- perf/x86/amd: Fix sampling Large Increment per Cycle events
  (bsc#1152489).
- commit c8a7d34
* Tue Oct 20 2020 bp@suse.de
- blacklist.conf: eb3621798bcd x86/entry/64: Do not include inst.h in calling.h
- commit 364d4bc
* Tue Oct 20 2020 bp@suse.de
- x86/fpu: Allow multiple bits in clearcpuid= parameter
  (bsc#1152489).
- commit 3d42971
* Tue Oct 20 2020 msuchanek@suse.de
- powerpc: Fix undetected data corruption with P9N DD2.1 VSX CI
  load emulation (bsc#1065729).
- commit d2da200
* Tue Oct 20 2020 bp@suse.de
- blacklist.conf: 0b2c605fa4ee x86/entry/64: Correct the comment over SAVE_AND_SET_GSBASE
- commit b5725a3
* Tue Oct 20 2020 bp@suse.de
- blacklist.conf: 5da8e4a65810 x86/copy_mc: Introduce copy_mc_enhanced_fast_string()
- commit 579d619
* Tue Oct 20 2020 mhocko@suse.com
- perf/core: Fix race in the perf_mmap_close() function
  (bsc#1177086, CVE-2020-14351).
- commit 1ee0e96
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/i915: Expand subslice mask (bsc#1152489)
- commit 15abd22
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/i915: Protect request peeking with RCU (bsc#1152489)
- commit c92f17a
* Tue Oct 20 2020 tiwai@suse.de
- Move upstreamed BT patch into sorted section
- commit 27a1c18
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/i915/gen8+: Add RC6 CTX corruption WA
- commit 088a3fd
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/etnaviv: fix missing unlock on error in (bsc#1152489)
- commit f2d81fc
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amd/display: remove unused function (bsc#1152489)
- commit 7e5efa0
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amd/display: Add Logging for Gamma Related information (bsc#1152489)
- commit 7ce29b7
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amd/display: memory leak (bsc#1152489)
- commit 3b1bb19
* Tue Oct 20 2020 bp@suse.de
- Update config files.
- commit dfb8f01
* Tue Oct 20 2020 jdelvare@suse.de
- blacklist.conf: add duplicate commit 3514521ccbd2
  Same as a39d0d7bdf8c21ac7645c02e9676b5cb2b804c31 ("drm/amdgpu: restore
  proper ref count in amdgpu_display_crtc_set_config).
- commit e083639
* Tue Oct 20 2020 bp@suse.de
- x86/mce: Allow for copy_mc_fragile symbol checksum to be
  generated (jsc#SLE-13447).
- commit ab8154b
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amd/powerplay: update smu11_driver_if_navi10.h (bsc#1152489)
- commit 7924071
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amdgpu/dm: Resume short HPD IRQs before resuming MST topology (bsc#1152489)
- commit ea68d72
* Tue Oct 20 2020 bp@suse.de
- x86/copy_mc: Introduce copy_mc_enhanced_fast_string()
  (jsc#SLE-13447).
- commit 90562e9
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amdgpu: add multiple instances support for Arcturus
- commit ec7e86c
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amdgpu: add DRIVER_SYNCOBJ_TIMELINE to amdgpu (bsc#1152472)
- commit fc7705d
* Tue Oct 20 2020 bp@suse.de
- x86, powerpc: Rename memcpy_mcsafe() to copy_mc_to_{user,
  kernel}() (jsc#SLE-13447).
- commit b65fb19
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amdgpu: fix memory leak (bsc#1152472)
- commit 8cdb0eb
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amdgpu: Default disable GDS for compute+gfx
- commit ce2c047
* Tue Oct 20 2020 glin@suse.com
- bpftool: Remove redundant "HAVE" prefix from the large INSN
  limit check (bsc#1177028).
- tools/bpf: Allow overriding llvm tools for runqslower
  (bsc#1177028).
- bpftool: Print function linkage in BTF dump (bsc#1177028).
- bpftool: Support dumping a map with btf_vmlinux_value_type_id
  (bsc#1177028).
- bpftool: Add struct_ops map name (bsc#1177028).
- bpftool: Fix missing BTF output for json during map dump
  (bsc#1177028).
- bpftool: Fix a leak of btf object (bsc#1177028).
- bpftool: Apply preserve_access_index attribute to all types
  in BTF dump (bsc#1177028).
- bpftool: Add misc section and probe for large INSN limit
  (bsc#1177028).
- bpf: Print error message for bpftool cgroup show (bsc#1177028).
- bpftool: Simplify format string to not use positional args
  (bsc#1177028).
- bpftool: Add `gen skeleton` BASH completions (bsc#1177028).
- bpftool: Match maps by name (bsc#1177028).
- bpftool: Match programs by name (bsc#1177028).
- bpftool: Match several programs with same tag (bsc#1177028).
  Refresh patches.suse/bpftool-Don-t-crash-on-missing-xlated-program-instru.patch
- commit 213f6b4
* Tue Oct 20 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/gfx10: update gfx golden settings for navi14'
- commit 3f81279
* Tue Oct 20 2020 jroedel@suse.de
- iommu/vt-d: Gracefully handle DMAR units with no supported address widths (bsc#1177739).
- commit 8780752
* Tue Oct 20 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/gfx10: update gfx golden settings'
- commit ee919e0
* Tue Oct 20 2020 glin@suse.com
- selftests/bpf: Add test for the packed enum member in
  struct/union (bsc#1177028).
- selftests: bpf: Add test for JMP32 JSET BPF_X with upper bits
  set (bsc#1177028).
- selftests/bpf: Add send_signal_sched_switch test (bsc#1177028).
- selftests/bpf: Mark SYN cookie test skipped for UDP sockets
  (bsc#1177028).
- selftests/bpf: Fix error checking on reading the tcp_fastopen
  sysctl (bsc#1177028).
- bpf: Selftests build error in sockmap_basic.c (bsc#1177028).
- selftests/bpf: Test freeing sockmap/sockhash with a socket in it
  (bsc#1177028).
- selftests/bpf: Fix trampoline_count.c selftest compilation
  warning (bsc#1177028).
- selftests/bpf: Add test based on port range for BPF flow
  dissector (bsc#1177028).
- selftest/bpf: Add test for allowed trampolines count
  (bsc#1177028).
- selftests: bpf: Reset global state between reuseport test runs
  (bsc#1177028).
- selftests: bpf: Make reuseport test output more legible
  (bsc#1177028).
- selftests: bpf: Ignore FIN packets for reuseport tests
  (bsc#1177028).
- selftests: bpf: Use a temporary file in test_sockmap
  (bsc#1177028).
- selftests/bpf: Improve bpftool changes detection (bsc#1177028).
  Refresh patches
- patches.suse/selftests-bpf-Add-test-for-resolve_btfids.patch
- patches.suse/selftests-bpf-Prevent-runqslower-from-racing-on-buil.patch
- selftests/bpf: Initialize duration variable before using
  (bsc#1177028).
- bpf: tcp: Add bpf_cubic example (bsc#1177028).
- selftests/bpf: Add tests for program extensions (bsc#1177028).
- selftests/bpf: Skip perf hw events test if the setup disabled it
  (bsc#1177028).
- selftests/bpf: Fix test_progs send_signal flakiness with nmi
  mode (bsc#1177028).
- selftests/bpf: Add whitelist/blacklist of test names to
  test_progs (bsc#1177028).
- selftests/bpf: Add batch ops testing to array bpf map
  (bsc#1177028).
- selftests/bpf: Add batch ops testing for htab and htab_percpu
  map (bsc#1177028).
- tools/bpf: Add self tests for bpf_send_signal_thread() (bsc#1177028).
  Refresh patches.suse/selftests-Use-consistent-include-paths-for-libbpf.patch
- selftests/bpf: Modify a test to check global functions
  (bsc#1177028).
- selftests/bpf: Add a test for a large global function
  (bsc#1177028).
- selftests/bpf: Restore original comm in test_overhead (bsc#1177028).
  Refresh patches
- patches.suse/selftest-bpf-Fmod_ret-prog-and-implement-test_overhe.patch
- patches.suse/selftests-Remove-fmod_ret-from-test_overhead.patch
- selftests/bpf: Preserve errno in test_progs CHECK macros
  (bsc#1177028).
- selftests/bpf: Test BPF_F_REPLACE in cgroup_attach_multi
  (bsc#1177028).
- selftests/bpf: Fix test_attach_probe (bsc#1177028).
- bpf: Allow to change skb mark in test_run (bsc#1177028).
- selftests/bpf: Add flexible array relocation tests
  (bsc#1177028).
- selftests/bpf: Test wire_len/gso_segs in BPF_PROG_TEST_RUN
  (bsc#1177028).
- selftests: bpf: Add xdp_perf test (bsc#1177028).
- selftests/bpf: Switch reuseport tests for test_progs framework
  (bsc#1177028).
- selftests/bpf: Move reuseport tests under prog_tests/ (bsc#1177028).
  Refresh patches.suse/selftests-bpf-Convert-test_cgroup_attach-to-prog_tes.patch
- selftests/bpf: Pull up printing the test name into test runner
  (bsc#1177028).
- selftests/bpf: Propagate errors during setup for reuseport tests
  (bsc#1177028).
- selftests/bpf: Run reuseport tests in a loop (bsc#1177028).
- selftests/bpf: Unroll the main loop in reuseport test
  (bsc#1177028).
- selftests/bpf: Add helpers for getting socket family & type name
  (bsc#1177028).
- selftests/bpf: Use sa_family_t everywhere in reuseport tests
  (bsc#1177028).
- selftests/bpf: Let libbpf determine program type from section
  name (bsc#1177028).
- commit 0d2a7ec
* Tue Oct 20 2020 glin@suse.com
- samples/bpf: Set -fno-stack-protector when building BPF programs
  (bsc#1177028).
- commit 83051c8
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: update gfx golden settings for navi14 (bsc#1152472)
- commit 237aa6b
* Tue Oct 20 2020 glin@suse.com
- libbpf: Sanitise internal map names so they are not rejected
  by the kernel (bsc#1177028).
- libbpf: Improve handling of failed CO-RE relocations
  (bsc#1177028).
- libbpf: Simplify BTF initialization logic (bsc#1177028).
- libbpf: Fix unneeded extra initialization in
  bpf_map_batch_common (bsc#1177028).
- libbpf: Add libbpf support to batch ops (bsc#1177028).
- libbpf: Support .text sub-calls relocations (bsc#1177028).
- libbpf: Clean up bpf_helper_defs.h generation output
  (bsc#1177028).
- libbpf: Sanitize global functions (bsc#1177028).
- libbpf: Support CO-RE relocations for LDX/ST/STX instructions
  (bsc#1177028).
- libbpf: Fix printing of ulimit value (bsc#1177028).
- libbpf: Allow to augment system Kconfig through extra optional config (bsc#1177028).
  Refresh patches
- patches.suse/bpf-libbpf-Add-STRUCT_OPS-support.patch
- patches.suse/libbpf-Load-btf_vmlinux-only-once-per-object.patch
- libbpf: Remove BPF_EMBED_OBJ macro from libbpf.h (bsc#1177028).
- libbpf: Reduce log level for custom section names (bsc#1177028).
- libbpf: Fix libbpf_common.h when installing libbpf through
  'make install' (bsc#1177028).
- libbpf: Print hint about ulimit when getting permission denied error (bsc#1177028).
  Refresh patches.suse/libbpf-Fix-unintentional-success-return-code-in-bpf_.patch
- libbpf: Support flexible arrays in CO-RE (bsc#1177028).
- libbpf: Reduce log level of supported section names dump
  (bsc#1177028).
- libbpf: Extract common user-facing helpers (bsc#1177028).
- commit ecbca78
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: update gfx golden settings for navi14 (bsc#1152472)
- commit c34217a
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: update gfx golden settings for navi14 (bsc#1152489)
- commit 7947e23
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: update gfx golden settings (bsc#1152472)
- commit 3d7c611
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: update gfx golden settings (bsc#1152472)
- commit ed16503
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: update gfx golden settings (bsc#1152489)
- commit 6d6113d
* Tue Oct 20 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: update gfx golden settings (bsc#1152472)
- commit dc1b836
* Tue Oct 20 2020 jslaby@suse.cz
- MAINTAINERS: Update maintainers for pmc_core driver
  (jsc#SLE-13398 jsc#SLE-13503).
- platform/x86: intel_pmc_core: fix: Replace dev_dbg macro with
  dev_info() (jsc#SLE-13398 jsc#SLE-13503).
- platform/x86: intel_pmc_core: Add Intel RocketLake (RKL)
  support (jsc#SLE-13398 jsc#SLE-13503).
- platform/x86: intel_pmc_core: Clean up: Remove the duplicate
  comments and reorganize (jsc#SLE-13398 jsc#SLE-13503).
- commit 63a532d
* Tue Oct 20 2020 glin@suse.com
- tools, bpftool: Fix warning on ignored return value for 'read'
  (bsc#1177028).
- tools, bpf_asm: Warn when jumps are out of range (bsc#1177028).
- tools: bpftool: add "bpftool map freeze" subcommand
  (bsc#1177028).
- tools: bpftool: show frozen status for maps (bsc#1177028).
- tools: bpftool: add documentation for net attach/detach
  (bsc#1177028).
- tools: bpftool: add bash-completion for net attach/detach
  (bsc#1177028).
- tools: bpftool: add net detach command to detach XDP on
  interface (bsc#1177028).
- tools: bpftool: add net attach command to attach XDP on
  interface (bsc#1177028).
- tools: bpftool: add support for reporting the effective cgroup
  progs (bsc#1177028).
- commit 8a14710
* Tue Oct 20 2020 glin@suse.com
- samples: bpf: Update outdated error message (bsc#1177028).
- samples/bpf: adjust Makefile and README.rst (bsc#1177028).
- samples/bpf: Add preparation steps and sysroot info to readme
  (bsc#1177028).
- samples/bpf: Add sysroot support (bsc#1177028).
- samples/bpf: Provide C/LDFLAGS to libbpf (bsc#1177028).
- samples/bpf: Use target CC environment for HDR_PROBE
  (bsc#1177028).
- samples/bpf: Use own flags but not HOSTCFLAGS (bsc#1177028).
  Refresh patches.suse/samples-bpf-Use-consistent-include-paths-for-libbpf.patch
- samples/bpf: Add makefile.target for separate CC target build
  (bsc#1177028).
- samples/bpf: Use --target from cross-compile (bsc#1177028).
- samples/bpf: Fix cookie_uid_helper_example obj build
  (bsc#1177028).
- samples/bpf: Fix HDR_PROBE "echo" (bsc#1177028).
- samples: bpf: Add max_pckt_size option at xdp_adjust_tail (bsc#1177028).
  Refresh patches
- patches.suse/samples-bpf-update-map-definition-to-new-syntax-BTF-.patch
- patches.suse/samples-bpf-Use-consistent-include-paths-for-libbpf.patch
- samples/bpf: Add a workaround for asm_inline (bsc#1177028).
- samples/bpf: Fix build for task_fd_query_user.c (bsc#1177028).
  Refresh patches.suse/samples-bpf-Use-consistent-include-paths-for-libbpf.patch
- samples: bpf: syscall_nrs: use mmap2 if defined (bsc#1177028).
- samples/bpf: xdp_fwd explain bpf_fib_lookup return codes
  (bsc#1177028).
- commit 51b6e62
* Tue Oct 20 2020 osalvador@suse.de
- Refresh
  patches.suse/mm-hwpoison-refactor-soft_offline_huge_page-and-__so.patch.
  Remove unused variable
- commit 4c47ec6
* Tue Oct 20 2020 glin@suse.com
- libbpf: Only check mode flags in get_xdp_id (bsc#1177028).
- selftests/bpf: Fix race in tcp_rtt test (bsc#1177028).
- commit fc0c050
* Tue Oct 20 2020 glin@suse.com
- libbpf: Fix unintentional success return code in
  bpf_object__load (bsc#1177028).
- libbpf: Fix bpf_get_link_xdp_id flags handling (bsc#1177028).
- selftests/bpf: Make tcp_rtt test more robust to failures
  (bsc#1177028).
- tools, bpf: Fix build for 'make -s tools/bpf O=<dir>'
  (bsc#1177028).
- commit 8bb3ea8
* Tue Oct 20 2020 glin@suse.com
- bpf: Add further test_verifier cases for record_func_key
  (bsc#1177028).
- selftests/bpf: Test function_graph tracer and bpf trampoline
  together (bsc#1177028).
- selftests/bpf: De-flake test_tcpbpf (bsc#1177028).
- selftests/bpf: Add verifier tests for better jmp32 register
  bounds (bsc#1177028).
- net-af_xdp: Use correct number of channels from ethtool
  (bsc#1177028).
- selftests, bpf: Workaround an alu32 sub-register spilling issue
  (bsc#1177028).
- bpf, testing: Workaround a verifier failure for test_progs
  (bsc#1177028).
- libbpf: Allow for creating Rx or Tx only AF_XDP sockets
  (bsc#1177028).
- libbpf: Support XDP_SHARED_UMEM with external XDP program
  (bsc#1177028).
- libbpf: Add bpf_get_link_xdp_info() function to get more XDP
  information (bsc#1177028).
- libbpf: Propagate EPERM to caller on program load (bsc#1177028).
- selftests/bpf: Add tests for automatic map unpinning on load
  failure (bsc#1177028).
- libbpf: Simplify BPF_CORE_READ_BITFIELD_PROBED usage
  (bsc#1177028).
- selftests: bpf: log direct file writes (bsc#1177028).
- selftests/bpf: Test narrow load from bpf_sysctl.write
  (bsc#1177028).
- libbpf: Use implicit XSKMAP lookup from AF_XDP XDP program
  (bsc#1177028).
- scripts/bpf: Print an error when known types list needs updating
  (bsc#1177028).
- selftests/bpf: Teach test_progs to cd into subdir (bsc#1177028).
- selftests/bpf: Restore the netns after flow dissector reattach
  test (bsc#1177028).
- scripts/bpf: Emit an #error directive known types list needs
  updating (bsc#1177028).
- selftests: bpf: Add selftest for __sk_buff tstamp (bsc#1177028).
- libbpf: Handle invalid typedef emitted by old GCC (bsc#1177028).
- selftests/bpf: Check that flow dissector can be re-attached
  (bsc#1177028).
- selftests/bpf: add test for BPF flow dissector in the root
  namespace (bsc#1177028).
- bpf: Add loop test case with 32 bit reg comparison against 0
  (bsc#1177028).
- selftests/bpf: Correct path to include msg + path (bsc#1177028).
- selftests/bpf: test_progs: Don't leak server_fd in tcp_rtt
  (bsc#1177028).
- tools: bpf: Use !building_out_of_srctree to determine srctree
  (bsc#1177028).
- selftests/bpf: delete unused variables in test_sysctl
  (bsc#1177028).
- selftests/bpf: test_progs: fix client/server race in tcp_rtt
  (bsc#1177028).
- selftests/bpf: precision tracking tests (bsc#1177028).
- selftests/bpf: Fix a typo in test_offload.py (bsc#1177028).
- selftests/bpf: remove wrong nhoff in flow dissector test
  (bsc#1177028).
- selftests/bpf: add precision tracking test (bsc#1177028).
- selftests/bpf: verifier precise tests (bsc#1177028).
- selftests/bpf: add test for bpf_tcp_gen_syncookie (bsc#1177028).
- commit 119cf5d
* Mon Oct 19 2020 tiwai@suse.de
- crypto: af_alg - Work around empty control messages without
  MSG_MORE (git-fixes).
- crypto: algif_aead - fix uninitialized ctx->init (git-fixes).
- crypto: af_alg - Fix regression on empty requests (git-fixes).
- commit b837b90
* Mon Oct 19 2020 tiwai@suse.de
- rtw88: Fix probe error handling race with firmware loading
  (git-fixes).
- ASoC: topology: disable size checks for bytes_ext controls if
  needed (git-fixes).
- staging: rtl8192e: fix kconfig dependency warning for
  RTLLIB_CRYPTO_CCMP (git-fixes).
- PM: runtime: Fix timer_expires data type on 32-bit arches
  (git-fixes).
- mmc: sdhci-pci: Fix SDHCI_RESET_ALL for CQHCI for Intel
  GLK-based controllers (git-fixes).
- crypto: algif_aead - Only wake up when ctx->more is zero
  (git-fixes).
- Input: add `SW_MACHINE_COVER` (git-fixes).
- crypto: af_alg - fix use-after-free in af_alg_accept() due to
  bh_lock_sock() (git-fixes).
- HID: usbhid: Fix race between usbhid_close() and usbhid_stop()
  (git-fixes).
- mmc: cqhci: Add cqhci_deactivate() (git-fixes).
- mmc: mmci: Support any block sizes for ux500v2 and qcom variant
  (git-fixes).
- commit d8de7b3
* Mon Oct 19 2020 msuchanek@suse.de
- scsi: ibmvfc: Fix error return in ibmvfc_probe() (bsc#1065729).
- commit a848d53
* Mon Oct 19 2020 tiwai@suse.de
- Bluetooth: Re-order clearing suspend tasks (git-fixes).
- commit 1fa8fc1
* Mon Oct 19 2020 tiwai@suse.de
- ASoC: Intel: sof_sdw: add version_id to avoid rt714/rt715
  confusion (git-fixes).
- ASoC: Intel: sof_sdw_rt1308: add extra check on init
  (git-fixes).
- ALSA: hda: fix jack detection with Realtek codecs when in D3
  (git-fixes).
- ALSA: compress_offload: dereference after checking for NULL
  pointer (git-fixes).
- ALSA: core: pcm_memory: dereference pointer after NULL checks
  (git-fixes).
- ALSA: core: memalloc: fix fallthrough position (git-fixes).
- ALSA: HDA: Early Forbid of runtime PM (git-fixes).
- commit 954abe4
* Mon Oct 19 2020 tiwai@suse.de
- regmap: debugfs: Fix more error path regressions (git-fixes).
- commit d9296bd
* Mon Oct 19 2020 tiwai@suse.de
- nl80211: docs: add a description for s1g_cap parameter
  (git-fixes).
- iwlwifi: dbg: run init_cfg function once per driver load
  (git-fixes).
- iwlwifi: dbg: remove no filter condition (git-fixes).
- nl80211: fix OBSS PD min and max offset validation (git-fixes).
- Bluetooth: Fix auto-creation of hci_conn at Conn Complete event
  (git-fixes).
- Bluetooth: Fix memory leak in read_adv_mon_features()
  (git-fixes).
- Bluetooth: Clear suspend tasks on unregister (git-fixes).
- mt76: mt7915: fix possible memory leak in mt7915_mcu_add_beacon
  (git-fixes).
- mt76: mt7663u: fix dma header initialization (git-fixes).
- mt76: fix a possible NULL pointer dereference in
  mt76_testmode_dump (git-fixes).
- mt76: mt7615: fix a possible NULL pointer dereference in
  mt7615_pm_wake_work (git-fixes).
- mt76: mt7615: fix possible memory leak in mt7615_tm_set_tx_power
  (git-fixes).
- mt76: mt7663s: fix unable to handle kernel paging request
  (git-fixes).
- mt76: mt7663s: fix resume failure (git-fixes).
- mt76: mt7663s: use NULL instead of 0 in sdio code (git-fixes).
- mt76: mt7615: release mutex in mt7615_reset_test_set
  (git-fixes).
- mt76: mt7615: hold mt76 lock queueing wd in
  mt7615_queue_key_update (git-fixes).
- rtw88: Fix potential probe error handling race with wow firmware
  loading (git-fixes).
- rtw88: fix compile warning: [-Wignored-qualifiers] (git-fixes).
- rtw88: don't treat NULL pointer as an array (git-fixes).
- ASoC: Intel: sof_sdw_rt1316: add missing component string
  (git-fixes).
- ASoC: tas2562: Remove duplicate code for I/V sense (git-fixes).
- ASoC: tas2770: Fix unbalanced calls to pm_runtime (git-fixes).
- ASoC: mediatek: mt8183-da7219: fix wrong ops for I2S3
  (git-fixes).
- ASoC: wm_adsp: Pass full name to snd_ctl_notify (git-fixes).
- ASoC: tas2770: Fix error handling with update_bits (git-fixes).
- ASoC: tas2770: Fix required DT properties in the code
  (git-fixes).
- ASoC: tas2770: Add missing bias level power states (git-fixes).
- ASoC: tas2770: Fix calling reset in probe (git-fixes).
- ASoC: tlv320adcx140: Fix digital gain range (git-fixes).
- ALSA: hda/i915 - fix list corruption with concurrent probes
  (git-fixes).
- staging: rtl8712: Fix enqueue_reorder_recvframe() (git-fixes).
- pinctrl: tigerlake: Fix register offsets for TGL-H variant
  (git-fixes).
- commit 4c203f8
* Mon Oct 19 2020 tiwai@suse.de
- Blacklist already cherry-picked ASoC fix
- commit d99febe
* Mon Oct 19 2020 bp@suse.de
- perf/amd/uncore: Inform the user how many counters each uncore
  PMU has (jsc#SLE-16756).
- perf/amd/uncore: Allow F19h user coreid, threadmask, and
  sliceid specification (jsc#SLE-16756).
- perf/amd/uncore: Allow F17h user threadmask and slicemask
  specification (jsc#SLE-16756).
- perf/amd/uncore: Prepare to scale for more attributes that
  vary per family (jsc#SLE-16756).
- commit 11a04bd
* Mon Oct 19 2020 bp@suse.de
- perf/x86/amd/ibs: Support 27-bit extended Op/cycle counter
  (jsc#SLE-16756).
- perf/x86/amd/ibs: Fix raw sample data accumulation
  (jsc#SLE-16756).
- perf/x86/amd/ibs: Don't include randomized bits in
  get_ibs_op_count() (jsc#SLE-16756).
- perf/x86/amd: Fix sampling Large Increment per Cycle events
  (jsc#SLE-16756).
- commit a56dacb
* Mon Oct 19 2020 bp@suse.de
- perf/amd/uncore: Set all slices and threads to restore perf
  stat -a behaviour (jsc#SLE-16756).
- perf/amd/uncore: Add support for Family 19h L3 PMU
  (jsc#SLE-16756).
- commit 0e860a4
* Mon Oct 19 2020 bp@suse.de
- perf/amd/uncore: Prepare L3 thread mask code for Family 19h
  (jsc#SLE-16756).
- commit 251809a
* Mon Oct 19 2020 bp@suse.de
- x86: Expose SERIALIZE for supported cpuid (jsc#SLE-13557).
- Refresh
  patches.suse/x86-kvm-expose-tsx-suspend-load-tracking-feature.patch.
- commit d8f2106
* Mon Oct 19 2020 tzimmermann@suse.de
- gpiolib: introduce fwnode_gpiod_get_index() (bsc#1152489)
- commit ab09f78
* Mon Oct 19 2020 vbabka@suse.cz
- percpu: fix first chunk size calculation for populated bitmap
  (git-fixes (mm/percpu)).
- commit fc914cf
* Mon Oct 19 2020 vbabka@suse.cz
- mm/rmap: fixup copying of soft dirty and uffd ptes (git-fixes
  (mm/rmap)).
- commit 57e33c0
* Mon Oct 19 2020 tiwai@suse.de
- rpm/split-modules: Avoid errors even if Module.* are not present
- commit 752fbc6
* Mon Oct 19 2020 vbabka@suse.cz
- mm/huge_memory.c: use head to check huge zero page (git-fixes
  (mm/thp)).
- commit b768968
* Mon Oct 19 2020 vbabka@suse.cz
- mm/mempolicy.c: fix out of bounds write in mpol_parse_str()
  (git-fixes (mm/mempolicy)).
- commit af27a44
* Mon Oct 19 2020 vbabka@suse.cz
- mm/page-writeback.c: improve arithmetic divisions (git-fixes
  (mm/writeback)).
- commit 0efed25
* Mon Oct 19 2020 vbabka@suse.cz
- mm/page-writeback.c: avoid potential division by zero in
  wb_min_max_ratio() (git-fixes (mm/writeback)).
- commit 3e8dbda
* Mon Oct 19 2020 vbabka@suse.cz
- mm/zsmalloc.c: fix the migrated zspage statistics (git-fixes
  (mm/zsmalloc)).
- commit 0aec7d2
* Mon Oct 19 2020 mbenes@suse.cz
- tracing: Check return value of __create_val_fields() before
  using its result (git-fixes).
- commit 340fd0d
* Mon Oct 19 2020 mbenes@suse.cz
- blacklist.conf: 10819e25799a ("tracing: Handle synthetic event array field type checking correctly")
  CONFIG_SYNTH_EVENTS is not enabled anywhere.
- commit dfcbd72
* Mon Oct 19 2020 mbenes@suse.cz
- blacklist.conf: 9bbb33291f8e ("tracing: Check that the synthetic event and field names are legal")
  CONFIG_SYNTH_EVENTS is not enabled anywhere.
- commit 2bf6e8b
* Mon Oct 19 2020 tiwai@suse.de
- overflow: Include header file with SIZE_MAX declaration
  (git-fixes).
- i3c: master: Fix error return in cdns_i3c_master_probe()
  (git-fixes).
- i3c: master add i3c_master_attach_boardinfo to preserve
  boardinfo (git-fixes).
- mtd: spinand: gigadevice: Add QE Bit (git-fixes).
- mtd: spinand: gigadevice: Only one dummy byte in QUADIO
  (git-fixes).
- mtd: rawnand: vf610: disable clk on error handling path in probe
  (git-fixes).
- mtd: rawnand: stm32_fmc2: fix a buffer overflow (git-fixes).
- mtd: mtdoops: Don't write panic data twice (git-fixes).
- mtd: lpddr: fix excessive stack usage with clang (git-fixes).
- mtd: lpddr: Fix bad logic in print_drs_error (git-fixes).
- rapidio: fix the missed put_device() for rio_mport_add_riodev
  (git-fixes).
- lib/crc32.c: fix trivial typo in preprocessor condition
  (git-fixes).
- Bluetooth: MGMT: Fix not checking if BT_HS is enabled
  (git-fixes).
- VMCI: check return value of get_user_pages_fast() for errors
  (git-fixes).
- USB: serial: option: add Cellient MPL200 card (git-fixes).
- USB: serial: option: Add Telit FT980-KS composition (git-fixes).
- USB: serial: pl2303: add device-id for HP GC device (git-fixes).
- USB: serial: ftdi_sio: add support for FreeCalypso JTAG+UART
  adapters (git-fixes).
- staging: comedi: check validity of wMaxPacketSize of usb
  endpoints found (git-fixes).
- ACPI: Always build evged in (git-fixes).
- commit 88d1ef8
* Mon Oct 19 2020 mbenes@suse.cz
- tracing: Save normal string variables (git-fixes).
- commit 91eb341
* Mon Oct 19 2020 mbenes@suse.cz
- blacklist.conf: 8fbeb52a598c ("tracing: Fix parse_synth_field() error handling")
  CONFIG_SYNTH_EVENTS is not enabled anywhere.
- commit c4d0c48
* Mon Oct 19 2020 bp@suse.de
- blacklist.conf: afce6996943b EDAC/aspeed: Fix handling of platform_get_irq() error
- commit 4d7f300
* Mon Oct 19 2020 yousaf.kaukab@suse.com
- mmc: sdhci: fix an issue of mixing different types
  (jsc#SLE-15847).
- mmc: core: Fix size overflow for mmc partitions (jsc#SLE-15847).
- commit cf78cbc
* Mon Oct 19 2020 bp@suse.de
- EDAC/i5100: Fix error handling order in i5100_init_one()
  (bsc#1152489).
- commit ef65426
* Mon Oct 19 2020 glin@suse.com
- libbpf: Support stripping modifiers for btf_dump (bsc#1177028).
  Refresh patches.suse/tools-bpftool-Strip-away-modifiers-from-global-varia.patch.
- commit 607d46d
* Mon Oct 19 2020 msuchanek@suse.de
- ibmvnic: set up 200GBPS speed (bsc#1129923 git-fixes).
- commit e87977b
* Mon Oct 19 2020 msuchanek@suse.de
- ibmveth: Switch order of ibmveth_helper calls (bsc#1061843
  git-fixes).
- commit e6ac1a9
* Mon Oct 19 2020 wqu@suse.com
- btrfs: tree-checker: fix false alert caused by legacy btrfs
  root item (bsc#1177861).
- commit 5302053
* Mon Oct 19 2020 wqu@suse.com
- btrfs: qgroup: fix qgroup meta rsv leak for subvolume
  operations (bsc#1177856).
- commit 4456f07
* Mon Oct 19 2020 wqu@suse.com
- btrfs: qgroup: fix wrong qgroup metadata reserve for delayed
  inode (bsc#1177855).
- btrfs: add owner and fs_info to alloc_state io_tree
  (bsc#1177854).
- commit e4394c2
* Mon Oct 19 2020 mgorman@suse.de
- series.conf: cleanup
- refresh, update upstream references and move into sorted section:
  patches.suse/sched-fair-Ignore-cache-hotness-for-SMT-migration.patch
  patches.suse/sched-fair-Use-dst-group-while-checking-imbalance-for-NUMA-balancer.patch
  patches.suse/sched-numa-Use-runnable_avg-to-classify-node.patch
- commit 715ffac
* Mon Oct 19 2020 glin@suse.com
- blacklist.conf: f7b12b6fea009 bpf: verifier: refactor check_attach_btf_id()
  The sleepable BPF patches are not backported yet.
- commit 3c7320e
* Mon Oct 19 2020 glin@suse.com
- selftests: Remove fmod_ret from test_overhead (bsc#1177028).
- commit 9f699fe
* Mon Oct 19 2020 glin@suse.com
- bpf: disallow attaching modify_return tracing functions to
  other BPF programs (bsc#1177028).
- selftests/bpf: Fix test_vmlinux test to use
  bpf_probe_read_user() (bsc#1177028).
- selftests/bpf: Prevent runqslower from racing on building
  bpftool (bsc#1177028).
- selftests/bpf: Copy runqslower to OUTPUT directory
  (bsc#1177028).
- selftests/bpf: Enforce returning 0 for fentry/fexit programs
  (bsc#1177028).
  Refresh patches.suse/selftest-bpf-Fmod_ret-prog-and-implement-test_overhe.patch
- selftests/bpf: Fix BPF_KRETPROBE macro and use it in
  attach_probe test (bsc#1177028).
- tools/bpf/runqslower: Rebuild libbpf.a on libbpf source change
  (bsc#1177028).
- runqslower: Fix Makefile (bsc#1177028).
- runsqslower: Support user-specified libbpf include and object
  paths (bsc#1177028).
- tools/runqslower: Remove tools/lib/bpf from include path
  (bsc#1177028).
- tools/bpf/runqslower: Fix override option for VMLINUX_BTF
  (bsc#1177028).
- commit 2a528e5
* Sat Oct 17 2020 bp@suse.de
- powercap: Restrict energy meter to root access (bsc#1170415
  CVE-2020-8694).
- commit 4deb70f
* Sat Oct 17 2020 tiwai@suse.de
- Move already upstreamed sound patches into sorted section
- commit d5803ae
* Fri Oct 16 2020 jack@suse.cz
- dax: Fix compilation for CONFIG_DAX && !CONFIG_FS_DAX
  (bsc#1177817).
- commit 3294fad
* Fri Oct 16 2020 jack@suse.cz
- dm: Call proper helper to determine dax support (bsc#1177817).
- commit 54f2e3f
* Fri Oct 16 2020 jeyu@suse.de
- Reinstate commit 418c424ed69204c3d503d524df9b593201d2cb0a:
  writeback: Fix sync livelock due to b_dirty_time processing (bsc#1177755).
  It appears merge commit 813a610cb3d98fba04d3ea4694260e04a3840ff8
  may have erroneously dropped this patch.
- commit 4849ffb
* Fri Oct 16 2020 jack@suse.cz
- writeback: Fix sync livelock due to b_dirty_time processing
  (bsc#1177755).
- commit 418c424
* Fri Oct 16 2020 jack@suse.cz
- writeback: Avoid skipping inode writeback (bsc#1177755).
- commit 977317c
* Fri Oct 16 2020 jack@suse.cz
- writeback: Protect inode->i_io_list with inode->i_lock
  (bsc#1177755).
  Refresh patches.suse/writeback-Export-inode_io_list_del.patch
- commit 5034dcb
* Fri Oct 16 2020 jack@suse.cz
- iomap: Make sure iomap_end is called after iomap_begin
  (bsc#1177754).
- commit 1558ead
* Fri Oct 16 2020 jack@suse.cz
- block: ensure bdi->io_pages is always initialized (bsc#1177749).
- commit dbf3e7d
* Fri Oct 16 2020 jack@suse.cz
- block: Fix page_is_mergeable() for compound pages (bsc#1177814).
- commit 1fb5d9d
* Fri Oct 16 2020 jack@suse.cz
- blk-mq: order adding requests to hctx->dispatch and checking
  SCHED_RESTART (bsc#1177750).
- commit 3cc33db
* Fri Oct 16 2020 tzimmermann@suse.de
- drm/i915/gtt: Don't check PPGTT presence on PPGTT-only platforms (bsc#1152489)
- commit 9981e92
* Fri Oct 16 2020 tzimmermann@suse.de
- Revert "drm/i915: Introduce private PAT management" (bsc#1152489)
- commit 3ac1160
* Fri Oct 16 2020 tzimmermann@suse.de
- drm/virtio: drop (bsc#1152489)
- commit 162d275
* Fri Oct 16 2020 tzimmermann@suse.de
- drm/i915/gen8+: Add RC6 CTX corruption WA (bsc#1152489)
- commit 5f72eda
* Fri Oct 16 2020 tzimmermann@suse.de
- device_cgroup: Export devcgroup_check_permission (bsc#1152489)
- commit 53c9a2f
* Fri Oct 16 2020 tzimmermann@suse.de
- PCI: Add #defines for Enter Compliance, Transmit Margin (bsc#1152489)
- commit 2f83d32
* Fri Oct 16 2020 vbabka@suse.cz
- mm/mmu_notifier: silence PROVE_RCU_LIST warnings
  (jsc#SLE-16387).
- commit bd27572
* Fri Oct 16 2020 vbabka@suse.cz
- mm/mmu_notifiers: Use 'interval_sub' as the variable for
  mmu_interval_notifier (jsc#SLE-16387).
- commit fdc4ff3
* Fri Oct 16 2020 msuchanek@suse.de
- Refresh patches.suse/powerpc-dma-Fix-dma_map_ops-get_required_mask.patch.
  Refresh to upstream version.
- commit 86022df
* Fri Oct 16 2020 msuchanek@suse.de
- blacklist.conf: Remove commits that are already merged into SP3.
- commit 208f9e1
* Fri Oct 16 2020 vbabka@suse.cz
- mm/mmu_notifiers: Use 'subscription' as the variable name for
  mmu_notifier (jsc#SLE-16387).
- commit efd51c6
* Fri Oct 16 2020 vbabka@suse.cz
- mm/mmu_notifier: Rename struct mmu_notifier_mm to
  mmu_notifier_subscriptions (jsc#SLE-16387).
- commit f87478b
* Fri Oct 16 2020 tiwai@suse.de
- ALSA: fireworks: use semicolons rather than commas to separate
  statements (git-fixes).
- ALSA: hdspm: Fix typo arbitary (git-fixes).
- ALSA: portman2x4: fix repeated word 'if' (git-fixes).
- ALSA: asihpi: fix spellint typo in comments (git-fixes).
- ALSA: vx: vx_pcm: remove redundant assignment (git-fixes).
- ALSA: vx: vx_core: clarify operator precedence (git-fixes).
- ALSA: atmel: ac97: clarify operator precedence (git-fixes).
- ALSA: ac97: (cosmetic) align argument names (git-fixes).
- ALSA: aoa: i2sbus: use DECLARE_COMPLETION_ONSTACK() macro
  (git-fixes).
- commit 1b0d435
* Fri Oct 16 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/Bluetooth-A2MP-Fix-not-initializing-all-members.patch
  patches.suse/Bluetooth-L2CAP-Fix-calling-sk_filter-on-non-socket-.patch
- commit b739656
* Fri Oct 16 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/ovl-call-secutiry-hook-in-ovl_real_ioctl.patch
  patches.suse/ovl-check-permission-to-open-real-file.patch
  patches.suse/ovl-pass-correct-flags-for-opening-real-directory.patch
  patches.suse/ovl-switch-to-mounter-creds-in-readdir.patch
  patches.suse/ovl-verify-permissions-in-ovl_path_open.patch
- commit 8e33a6e
* Fri Oct 16 2020 tiwai@suse.de
- ALSA: hda: use semicolons rather than commas to separate
  statements (git-fixes).
- ALSA: usb-audio: endpoint.c: fix repeated word 'there'
  (git-fixes).
- ALSA: usb-audio: fix spelling mistake "Frequence" -> "Frequency"
  (git-fixes).
- ALSA: usb-audio: Add mixer support for Pioneer DJ DJM-250MK2
  (git-fixes).
- ALSA: ctl: Workaround for lockdep warning wrt
  card->ctl_files_rwlock (git-fixes).
- ALSA: rawmidi: (cosmetic) align function parameters (git-fixes).
- ALSA: usb: scarless_gen2: fix endianness issue (git-fixes).
- ALSA: hda: (cosmetic) align function parameters (git-fixes).
- ALSA: hda: auto_parser: remove shadowed variable declaration
  (git-fixes).
- ALSA: core: init: use DECLARE_COMPLETION_ONSTACK() macro
  (git-fixes).
- ALSA: compress_offload: remove redundant initialization
  (git-fixes).
- ALSA: core: timer: clarify operator precedence (git-fixes).
- ALSA: core: timer: remove redundant assignment (git-fixes).
- ALSA: core: pcm: simplify locking for timers (git-fixes).
- ALSA: hda/realtek - The front Mic on a HP machine doesn't work
  (git-fixes).
- ALSA: hda/realtek: Enable audio jacks of ASUS D700SA with ALC887
  (git-fixes).
- ALSA: hda/realtek - Add mute Led support for HP Elitebook 845 G7
  (git-fixes).
- ALSA: hda - Don't register a cb func if it is registered already
  (git-fixes).
- ALSA: hda/realtek - set mic to auto detect on a HP AIO machine
  (git-fixes).
- commit f02408a
* Fri Oct 16 2020 tiwai@suse.de
- wcn36xx: Fix reported 802.11n rx_highest rate wcn3660/wcn3680
  (git-fixes).
- w1: mxc_w1: Fix timeout resolution problem leading to bus error
  (git-fixes).
- USB: serial: qcserial: fix altsetting probing (git-fixes).
- usb: dwc2: Fix INTR OUT transfers in DDMA mode (git-fixes).
- usb: dwc3: ep0: Fix ZLP for OUT ep0 requests (git-fixes).
- usb: dwc3: core: add phy cleanup for probe error handling
  (git-fixes).
- usb: dwc3: core: don't trigger runtime pm when remove driver
  (git-fixes).
- usb: gadget: u_ether: enable qmult on SuperSpeed Plus as well
  (git-fixes).
- usb: gadget: f_ncm: fix ncm_bitrate for SuperSpeed and above
  (git-fixes).
- xhci: don't create endpoint debugfs entry before ring buffer
  is set (git-fixes).
- commit 3de826d
* Fri Oct 16 2020 glin@suse.com
- selftests/bpf: Fix silent Makefile output (bsc#1177028).
- selftests/bpf: Add test for resolve_btfids (bsc#1177028).
- selftests/bpf: Allow substituting custom vmlinux.h for selftests
  build (bsc#1177028).
- bpf: Add BPF ringbuf and perf buffer benchmarks (bsc#1177028).
- bpf: Fix returned error sign when link doesn't support updates
  (bsc#1177028).
- selftest/bpf: Add BPF triggering benchmark (bsc#1177028).
- selftest/bpf: Fmod_ret prog and implement test_overhead as
  part of bench (bsc#1177028).
- selftests/bpf: Add benchmark runner infrastructure
  (bsc#1177028).
- selftests/bpf: Add runqslower binary to .gitignore
  (bsc#1177028).
- selftests/bpf: Add vmlinux.h selftest exercising tracing of
  syscalls (bsc#1177028).
- selftests/bpf: Support out-of-tree vmlinux builds for
  VMLINUX_BTF (bsc#1177028).
- selftests/bpf: Declare bpf_log_buf variables as static
  (bsc#1177028).
- selftests/bpf: Change llvm flag -mcpu=probe to -mcpu=v3
  (bsc#1177028).
- selftests/bpf: Build urandom_read with LDFLAGS and LDLIBS
  (bsc#1177028).
- selftests: Refactor build to remove tools/lib/bpf from include
  path (bsc#1177028).
- samples/bpf: Use consistent include paths for libbpf
  (bsc#1177028).
- bpftool: Use consistent include paths for libbpf (bsc#1177028).
- selftests: Use consistent include paths for libbpf (bsc#1177028).
  Refresh patches.suse/bpf-Add-bpf_xdp_output-helper.patch
- tools/runqslower: Use consistent include paths for libbpf
  (bsc#1177028).
- selftests: Pass VMLINUX_BTF to runqslower Makefile
  (bsc#1177028).
- libbpf: Revert bpf_helper_defs.h inclusion regression
  (bsc#1177028).
- selftests/bpf: Build runqslower from selftests (bsc#1177028).
- tools/bpf: Add runqslower tool to tools/bpf (bsc#1177028).
- selftests/bpf: Add BPF_PROG, BPF_KPROBE, and BPF_KRETPROBE
  macros (bsc#1177028).
- selftests/bpf: Add unit tests for global functions
  (bsc#1177028).
- selftests/bpf: Add fexit-to-skb test for global funcs
  (bsc#1177028).
- libbpf,selftests/bpf: Fix clean targets (bsc#1177028).
  Refresh patches.suse/selftests-bpf-Conform-selftests-bpf-Makefile-output-.patch
- bpf: Add bpf_dctcp example (bsc#1177028).
- bpftool: Work-around rst2man conversion bug (bsc#1177028).
- bpftool: Add gen subcommand manpage (bsc#1177028).
- samples/bpf: Reintroduce missed build targets (bsc#1177028).
- libbpf: Move non-public APIs from libbpf.h to libbpf_internal.h
  (bsc#1177028).
- selftests/bpf: Fix perf_buffer test on systems w/ offline CPUs
  (bsc#1177028).
- selftests/bpf: Add CPU mask parsing tests (bsc#1177028).
- selftests/bpf: Add a fexit/bpf2bpf test with target bpf prog
  no callees (bsc#1177028).
- bpf, testing: Add various tail call test cases (bsc#1177028).
- libbpf: Use pr_warn() when printing netlink errors (bsc#1177028).
  Refresh patches.suse/libbpf-Poison-kernel-only-integer-types.patch
- bpftool: Allow to read btf as raw data (bsc#1177028).
- samples/bpf: Use own EXTRA_CFLAGS for clang commands
  (bsc#1177028).
- tools: bpftool: implement "bpftool btf show|list" (bsc#1177028).
- selftests/bpf: add loop test 5 (bsc#1177028).
- selftests/bpf: add loop test 4 (bsc#1177028).
- commit 142b063
* Fri Oct 16 2020 tiwai@suse.de
- qtnfmac: fix resource leaks on unsupported iftype error return
  path (git-fixes).
- slimbus: qcom-ngd-ctrl: disable ngd in qmi server down callback
  (git-fixes).
- slimbus: core: do not enter to clock pause mode in core
  (git-fixes).
- slimbus: core: check get_addr before removing laddr ida
  (git-fixes).
- usb: dwc3: pci: Allow Elkhart Lake to utilize DSM method for
  PM functionality (git-fixes).
- usb: dwc2: Fix parameter type in function pointer prototype
  (git-fixes).
- usb: dwc3: gadget: Resume pending requests after CLEAR_STALL
  (git-fixes).
- usb: xhci-mtk: Fix typo (git-fixes).
- staging: rtl8192u: Do not use GFP_KERNEL in atomic context
  (git-fixes).
- commit 40d8c20
* Fri Oct 16 2020 bp@suse.de
- x86/{mce,mm}: Unmap the entire page if the whole page is
  affected and poisoned (bsc#1177765).
- commit d250460
* Fri Oct 16 2020 tiwai@suse.de
- mwifiex: fix double free (git-fixes).
- iwlwifi: mvm: split a print to avoid a WARNING in ROC
  (git-fixes).
- nl80211: fix non-split wiphy information (git-fixes).
- mwifiex: remove function pointer check (git-fixes).
- mwifiex: Remove unnecessary braces from
  HostCmd_SET_SEQ_NO_BSS_INFO (git-fixes).
- mwifiex: Do not use GFP_KERNEL in atomic context (git-fixes).
- ima: Remove semicolon at the end of
  ima_get_binary_runtime_size() (git-fixes).
- pwm: lpss: Add range limit check for the base_unit register
  value (git-fixes).
- pwm: lpss: Fix off by one error in base_unit math in
  pwm_lpss_prepare() (git-fixes).
- misc: mic: scif: Fix error handling path (git-fixes).
- commit 0a90922
* Fri Oct 16 2020 tiwai@suse.de
- ima: Don't ignore errors from crypto_shash_update() (git-fixes).
- iio: adc: gyroadc: fix leak of device node iterator (git-fixes).
- iio: adc: stm32-adc: fix runtime autosuspend delay when slow
  polling (git-fixes).
- iio:adc:ti-adc12138 Fix alignment issue with timestamp
  (git-fixes).
- iio:adc:ti-adc0832 Fix alignment issue with timestamp
  (git-fixes).
- iio:light:si1145: Fix timestamp alignment and prevent data leak
  (git-fixes).
- iio:gyro:itg3200: Fix timestamp alignment and prevent data leak
  (git-fixes).
- iio:accel:bma180: Fix use of true when should be iio_shared_by
  enum (git-fixes).
- iio:magn:hmc5843: Fix passing true where iio_shared_by enum
  required (git-fixes).
- iio:dac:ad5592r: Fix use of true for IIO_SHARED_BY_TYPE
  (git-fixes).
- commit 7b8694c
* Fri Oct 16 2020 tiwai@suse.de
- can: flexcan: remove ack_grp and ack_bit handling from driver
  (git-fixes).
- can: c_can: reg_map_{c,d}_can: mark as __maybe_unused
  (git-fixes).
- can: softing: softing_card_shutdown(): add  braces around
  empty body in an 'if' statement (git-fixes).
- brcmfmac: check ndev pointer (git-fixes).
- HID: hid-input: fix stylus battery reporting (git-fixes).
- HID: wacom: Avoid entering wacom_wac_pen_report for pad /
  battery (git-fixes).
- HID: roccat: add bounds checking in kone_sysfs_write_settings()
  (git-fixes).
- dmaengine: dma-jz4780: Fix race in jz4780_dma_tx_status
  (git-fixes).
- dmaengine: dmatest: Check list for emptiness before access
  its last entry (git-fixes).
- extcon: ptn5150: Fix usage of atomic GPIO with sleeping GPIO
  chips (git-fixes).
- commit f5c71cc
* Fri Oct 16 2020 tiwai@suse.de
- Bluetooth: hci_uart: Cancel init work before unregistering
  (git-fixes).
- ath6kl: wmi: prevent a shift wrapping bug in
  ath6kl_wmi_delete_pstream_cmd() (git-fixes).
- ath10k: Fix the size used in a 'dma_free_coherent()' call in
  an error handling path (git-fixes).
- ath9k: Fix potential out of bounds in
  ath9k_htc_txcompletion_cb() (git-fixes).
- ath9k_htc: Use appropriate rs_datalen type (git-fixes).
- ath6kl: prevent potential array overflow in ath6kl_add_new_sta()
  (git-fixes).
- ath10k: provide survey info as accumulated data (git-fixes).
- ALSA: hda/hdmi: fix incorrect locking in hdmi_pcm_close
  (git-fixes).
- ASoC: fsl: imx-es8328: add missing put_device() call in
  imx_es8328_probe() (git-fixes).
- ASoC: qcom: lpass-cpu: fix concurrency issue (git-fixes).
- ASoC: qcom: lpass-platform: fix memory leak (git-fixes).
- ASoC: sun50i-codec-analog: Fix duplicate use of ADC enable bits
  (git-fixes).
- ASoC: fsl_sai: Instantiate snd_soc_dai_driver (git-fixes).
- ASoC: tlv320aic32x4: Fix bdiv clock rate derivation (git-fixes).
- ALSA: seq: oss: Avoid mutex lock for a long-time ioctl
  (git-fixes).
- ALSA: mixart: Correct comment wrt obsoleted tasklet usage
  (git-fixes).
- ALSA: bebob: potential info leak in hwdep_read() (git-fixes).
- commit 42377f3
* Fri Oct 16 2020 jgross@suse.com
- x86/xen: disable Firmware First mode for correctable memory
  errors (bsc#1176713).
- commit f91015e
* Thu Oct 15 2020 mkubecek@suse.cz
- Update kabi files.
- update to resubmitted October 2020 OOB maintenance update submission (commit 29977655832a)
- commit 01071b5
* Thu Oct 15 2020 rgoldwyn@suse.com
- ovl: check permission to open real file  (bsc#1177470,
  CVE-2020-16120).
- ovl: call secutiry hook in ovl_real_ioctl()  (bsc#1177470,
  CVE-2020-16120).
- ovl: verify permissions in ovl_path_open()  (bsc#1177470,
  CVE-2020-16120).
- ovl: switch to mounter creds in readdir  (bsc#1177470,
  CVE-2020-16120).
- ovl: pass correct flags for opening real directory
  (bsc#1177470, CVE-2020-16120).
- commit 86bcb3f
* Thu Oct 15 2020 osalvador@suse.de
- mm,hwpoison: Try to narrow window race for free pages
  (bsc#1177686).
- mm,hwpoison: double-check page count in __get_any_page()
  (bsc#1177686).
- mm,hwpoison: introduce MF_MSG_UNSPLIT_THP (bsc#1177686).
- mm,hwpoison: return 0 if the page is already poisoned in
  soft-offline (bsc#1177686).
- mm,hwpoison: refactor soft_offline_huge_page and
  __soft_offline_page (bsc#1177686).
- mm,hwpoison: rework soft offline for in-use pages (bsc#1177686).
- mm,hwpoison: rework soft offline for free pages (bsc#1177686).
- mm,hwpoison: unify THP handling for hard and soft offline
  (bsc#1177686).
- mm,hwpoison: kill put_hwpoison_page (bsc#1177686).
- mm,hwpoison: refactor madvise_inject_error (bsc#1177686).
- mm,hwpoison: unexport get_hwpoison_page and make it static
  (bsc#1177686).
- mm,hwpoison-inject: don't pin for hwpoison_filter (bsc#1177686).
- mm, hwpoison: remove recalculating hpage (bsc#1177686).
- mm,hwpoison: cleanup unused PageHuge() check (bsc#1177686).
- commit c4ae95a
* Thu Oct 15 2020 tiwai@suse.de
- backlight: sky81452-backlight: Fix refcount imbalance on error
  (git-fixes).
- mfd: sm501: Fix leaks in probe() (git-fixes).
- pinctrl: mcp23s08: Fix mcp23x17 precious range (git-fixes).
- pinctrl: mcp23s08: Fix mcp23x17_regmap initialiser (git-fixes).
- leds: mt6323: move period calculation (git-fixes).
- ipmi_si: Fix wrong return value in try_smi_init() (git-fixes).
- ACPI: button: fix handling lid state changes when input device
  closed (git-fixes).
- ACPI: configfs: Add missing config_item_put() to fix refcount
  leak (git-fixes).
- platform/x86: mlx-platform: Remove PSU EEPROM configuration
  (git-fixes).
- net: wireless: nl80211: fix out-of-bounds access in
  nl80211_del_key() (git-fixes).
- Input: ati_remote2 - add missing newlines when printing module
  parameters (git-fixes).
- commit e531d97
* Thu Oct 15 2020 ddiss@suse.de
- patches.suse/target-rbd-detect-stripe_unit-SCSI-block-size-misali.patch:
  (bsc#1177090).
- patches.suse/target-rbd-support-COMPARE_AND_WRITE.patch:
  (fate#318836, bsc#1177090).
- patches.suse/target-compare-and-write-backend-driver-sense-handli.patch:
  (bsc#1177719).
- commit 3918814
* Thu Oct 15 2020 ailiop@suse.com
- xfs: force the log after remapping a synchronous-writes file
  (git-fixes).
- commit 600980e
* Thu Oct 15 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/scsi-ibmvfc-Avoid-link-down-on-FS9100-canister-reboo.patch
  patches.suse/scsi-ibmvfc-Use-compiler-attribute-defines-instead-o.patch
  patches.suse/scsi-qla2xxx-Add-IOCB-resource-tracking.patch
  patches.suse/scsi-qla2xxx-Add-SLER-and-PI-control-support.patch
  patches.suse/scsi-qla2xxx-Add-rport-fields-in-debugfs.patch
  patches.suse/scsi-qla2xxx-Allow-dev_loss_tmo-setting-for-FC-NVMe-.patch
  patches.suse/scsi-qla2xxx-Correct-the-check-for-sscanf-return-val.patch
  patches.suse/scsi-qla2xxx-Fix-I-O-errors-during-LIP-reset-tests.patch
  patches.suse/scsi-qla2xxx-Fix-I-O-failures-during-remote-port-tog.patch
  patches.suse/scsi-qla2xxx-Fix-MPI-reset-needed-message.patch
  patches.suse/scsi-qla2xxx-Fix-buffer-buffer-credit-extraction-err.patch
  patches.suse/scsi-qla2xxx-Fix-crash-on-session-cleanup-with-unloa.patch
  patches.suse/scsi-qla2xxx-Fix-inconsistent-format-argument-type-i-250bd009.patch
  patches.suse/scsi-qla2xxx-Fix-inconsistent-format-argument-type-i-72e813d9.patch
  patches.suse/scsi-qla2xxx-Fix-inconsistent-format-argument-type-i.patch
  patches.suse/scsi-qla2xxx-Fix-memory-size-truncation.patch
  patches.suse/scsi-qla2xxx-Fix-point-to-point-N2N-device-discovery.patch
  patches.suse/scsi-qla2xxx-Fix-reset-of-MPI-firmware.patch
  patches.suse/scsi-qla2xxx-Fix-the-return-value.patch
  patches.suse/scsi-qla2xxx-Fix-the-size-used-in-a-dma_free_coheren.patch
  patches.suse/scsi-qla2xxx-Fix-wrong-return-value-in-qla_nvme_regi.patch
  patches.suse/scsi-qla2xxx-Fix-wrong-return-value-in-qlt_chk_unres.patch
  patches.suse/scsi-qla2xxx-Honor-status-qualifier-in-FCP_RSP-per-s.patch
  patches.suse/scsi-qla2xxx-Log-calling-function-name-in-qla2x00_ge.patch
  patches.suse/scsi-qla2xxx-Make-tgt_port_database-available-in-ini.patch
  patches.suse/scsi-qla2xxx-Performance-tweak.patch
  patches.suse/scsi-qla2xxx-Reduce-duplicate-code-in-reporting-spee.patch
  patches.suse/scsi-qla2xxx-Remove-pci-dma-compat-wrapper-API.patch
  patches.suse/scsi-qla2xxx-Remove-redundant-variable-initializatio.patch
  patches.suse/scsi-qla2xxx-Remove-superfluous-memset.patch
  patches.suse/scsi-qla2xxx-Remove-unneeded-variable-rval.patch
  patches.suse/scsi-qla2xxx-Setup-debugfs-entries-for-remote-ports.patch
  patches.suse/scsi-qla2xxx-Simplify-return-value-logic-in-qla2x00_.patch
  patches.suse/scsi-qla2xxx-Update-version-to-10.02.00.102-k.patch
  patches.suse/scsi-qla2xxx-Update-version-to-10.02.00.103-k.patch
  patches.suse/scsi-qla2xxx-Warn-if-done-or-free-are-called-on-an-a.patch
  patches.suse/scsi-smartpqi-add-id-support-for-smartraid-3152-8i.patch
  patches.suse/scsi-smartpqi-add-raid-bypass-counter.patch
  patches.suse/scsi-smartpqi-avoid-crashing-kernel-for-controller-issues.patch
  patches.suse/scsi-smartpqi-bump-version-to-1-2-16-010.patch
  patches.suse/scsi-smartpqi-identify-physical-devices-without-issuing-inquiry.patch
  patches.suse/scsi-smartpqi-support-device-deletion-via-sysfs.patch
  patches.suse/scsi-smartpqi-update-logical-volume-size-after-expansion.patch
  No effect on expanded tree.
- commit cd0c079
* Thu Oct 15 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/Bluetooth-A2MP-Fix-not-initializing-all-members.patch
  patches.suse/Bluetooth-L2CAP-Fix-calling-sk_filter-on-non-socket-.patch
- commit a607d96
* Thu Oct 15 2020 jslaby@suse.cz
- x86/unwind/orc: Fix inactive tasks with stack pointer in %%sp
  on GCC 10 compiled kernels (bsc#1176907).
- commit 4f3bd2e
* Thu Oct 15 2020 tzimmermann@suse.de
- PCI: Add PCI_STD_NUM_BARS for the number of standard BARs (bsc#1152489)
- commit 851c8bb
* Thu Oct 15 2020 tiwai@suse.de
- kABI workaround for bluetooth l2cap_ops filter addition
  (CVE-2020-12351 bsc#1177724).
- commit 7c053a8
* Thu Oct 15 2020 tiwai@suse.de
- Bluetooth: L2CAP: Fix calling sk_filter on non-socket based
  channel (CVE-2020-12351 bsc#1177724).
- commit f0ba0e3
* Thu Oct 15 2020 tiwai@suse.de
- Update the patch reference for bluetooth security fix (CVE-2020-24490 bsc#1177726)
- commit 2a88ef6
* Thu Oct 15 2020 jslaby@suse.cz
- PCI/AER: Add RCEC AER error injection support (jsc#SLE-13736
  jsc#SLE-14845).
- PCI/PME: Add pcie_walk_rcec() to RCEC PME handling
  (jsc#SLE-13736 jsc#SLE-14845).
- PCI/AER: Add pcie_walk_rcec() to RCEC AER handling
  (jsc#SLE-13736 jsc#SLE-14845).
- PCI/RCEC: Add RCiEP's linked RCEC to AER/ERR (jsc#SLE-13736
  jsc#SLE-14845).
- PCI/RCEC: Add pcie_link_rcec() to associate RCiEPs
  (jsc#SLE-13736 jsc#SLE-14845).
- PCI/AER: Apply Function Level Reset to RCiEP on fatal error
  (jsc#SLE-13736 jsc#SLE-14845).
- PCI/ERR: Limit AER resets in pcie_do_recovery() (jsc#SLE-13736
  jsc#SLE-14845).
- PCI/ERR: Add pci_walk_bridge() to pcie_do_recovery()
  (jsc#SLE-13736 jsc#SLE-14845).
- PCI/ERR: Avoid negated conditional for clarity (jsc#SLE-13736
  jsc#SLE-14845).
- PCI/ERR: Use "bridge" for clarity in pcie_do_recovery()
  (jsc#SLE-13736 jsc#SLE-14845).
- PCI/ERR: Simplify by computing pci_pcie_type() once
  (jsc#SLE-13736 jsc#SLE-14845).
- PCI/ERR: Simplify by using pci_upstream_bridge() (jsc#SLE-13736
  jsc#SLE-14845).
- PCI/ERR: Rename reset_link() to reset_subordinates()
  (jsc#SLE-13736 jsc#SLE-14845).
- PCI/RCEC: Cache RCEC capabilities in pci_init_capabilities()
  (jsc#SLE-13736 jsc#SLE-14845).
- PCI/RCEC: Bind RCEC devices to the Root Port driver
  (jsc#SLE-13736 jsc#SLE-14845).
- PCI/RCEC: Add RCEC class code and extended capability
  (jsc#SLE-13736 jsc#SLE-14845).
- commit d935dcb
* Thu Oct 15 2020 tiwai@suse.de
- Move upstreamed intel-vbtn patch into sorted section
- commit cf1a58d
* Thu Oct 15 2020 tiwai@suse.de
- Bluetooth: A2MP: Fix not initializing all members
  (CVE-2020-12352 bsc#1177725).
- commit 099cb6b
* Thu Oct 15 2020 glin@suse.com
- bpf: Fix scalar32_min_max_or bounds tracking (bsc#1177028).
- tools/bpftool: Make skeleton code C++17-friendly by dropping
  typeof() (bsc#1177028).
- tools/bpftool: Fix error handing in do_skeleton() (bsc#1177028).
- tools/bpftool: Strip away modifiers from global variables
  (bsc#1177028).
- libbpf: Prevent loading vmlinux BTF twice (bsc#1177028).
- security: Fix hook iteration and default value for
  inode_copy_up_xattr (bsc#1177028).
- libbpf: Support pre-initializing .bss global variables
  (bsc#1177028).
- bpf: cgroup: Allow multi-attach program to replace itself
  (bsc#1177028).
- bpf, cgroup: Return ENOLINK for auto-detached links on update
  (bsc#1177028).
- selftests/bpf: Fix test_align verifier log patterns
  (bsc#1177028).
- selftests/bpf: Install generated test progs (bsc#1177028).
- libbpf: Fix huge memory leak in libbpf_find_vmlinux_btf_id()
  (bsc#1177028).
- selftests/bpf: Ensure test flavors use correct skeletons
  (bsc#1177028).
- bpf: Refactor bpf_link update handling (bsc#1177028).
- selftests/bpf: Convert test_cgroup_attach to prog_tests (bsc#1177028).
  Refresh patches.suse/selftests-bpf-Further-clean-up-Makefile-output.patch
- commit 5fa0d3e
* Wed Oct 14 2020 tbogendoerfer@suse.de
- Refresh
  patches.suse/bonding-Add-helper-function-to-get-the-xmit-slave-in.patch.
  Added missing changes from merge
  commit 76cd622fe2c2b10c1f0a7311ca797feccacc329d (bsc#1177678)
- commit 1950c34
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: restore initial kmem_cache flags (mm/slub
  bsc#1165692).
- commit 8972663
* Wed Oct 14 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/NFS-Don-t-move-layouts-to-plh_return_segs-list-while.patch
  patches.suse/NFS-Don-t-return-layout-segments-that-are-in-use.patch
  patches.suse/NFS-Fix-flexfiles-read-failover.patch
  patches.suse/NFSv4.2-fix-client-s-attribute-cache-management-for-.patch
  patches.suse/SUNRPC-Revert-241b1f419f0e-SUNRPC-Remove-xdr_buf_tri.patch
  patches.suse/nfs-ensure-correct-writeback-errors-are-returned-on-.patch
  patches.suse/nfs-nfs_file_write-should-check-for-writeback-errors.patch
  patches.suse/nfsd4-fix-NULL-dereference-in-nfsd-clients-display-c.patch
  patches.suse/pNFS-flexfiles-Ensure-we-initialise-the-mirror-bsize.patch
  patches.suse/svcrdma-Fix-page-leak-in-svc_rdma_recv_read_chunk.patch
  patches.suse/xprtrdma-fix-incorrect-header-size-calculations.patch
- commit 90be310
* Wed Oct 14 2020 mkubecek@suse.cz
- series.conf: cleanup
- rename Other drivers / Intel IOMMU subsection to IOMMU
- whitespace cleanup
- commit 263c1bd
* Wed Oct 14 2020 mkubecek@suse.cz
- series.conf: cleanup
- fix Patch-mainline and move to "almost mainline" section:
  patches.suse/qla2xxx-return-ebusy-on-fcport-deletion.patch
- create Storage / NVMe subsection
- move to Storage / NVMe:
  patches.suse/Revert-nvme-allow-64-bit-results-in-passthru-command.patch
  patches.suse/nvme-multipath-retry-commands-for-dying-queues.patch
- drop Storage / bsc#1171688 subsection
  No effect on expanded tree.
- commit 1b55020
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slab/slub: move and improve cache_from_obj() (mm/slub
  bsc#1165692).
  mm, slab/slub: improve error reporting and overhead of
  cache_from_obj() (mm/slub bsc#1165692).
  Squashed to prevent build error after first patch.
- commit ed35ad2
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: extend checks guarded by slub_debug static key
  (mm/slub bsc#1165692).
- commit 95cf5cc
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: introduce kmem_cache_debug_flags() (mm/slub
  bsc#1165692).
- commit 4f68bb2
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: introduce static key for slub_debug() (mm/slub
  bsc#1165692).
- commit 592afaf
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: make reclaim_account attribute read-only (mm/slub
  bsc#1165692).
- commit 749a7fc
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: make remaining slub_debug related attributes read-only
  (mm/slub bsc#1165692).
- commit 0a2f646
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: remove runtime allocation order changes (mm/slub
  bsc#1165692).
- commit d6227f6
* Wed Oct 14 2020 mkoutny@suse.com
- blacklist.conf: a87425a36fb2 mm, memcg: fix build error around the usage of kmem_caches
- commit b5fde68
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: check the right error variable in
  btrfs_del_dir_entries_in_log (bsc#1177687).
- commit d17c6ed
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: do not set the full sync flag on the inode during page
  release (bsc#1177687).
- commit 8954d4a
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: release old extent maps during page release
  (bsc#1177687).
- commit c79f281
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: fix race between page release and a fast fsync
  (bsc#1177687).
- commit 2893955
* Wed Oct 14 2020 ddiss@suse.de
- patches.suse/rbd-add-support-for-COMPARE_AND_WRITE-CMPEXT.patch:
  (fate#318836, bsc#1177090).
- patches.suse/libceph-add-support-for-CMPEXT-compare-extent-reques.patch:
  (fate#318836, bsc#1177090).
- patches.suse/rbd-add-rbd_img_fill_cmp_and_write_from_bvecs.patch:
  (bsc#1177090).
- patches.suse/target-rbd-add-WRITE-SAME-support.patch:
  (bsc#1177090).
- patches.suse/target-rbd-fix-unmap-handling-with-unmap_zeroes_data.patch:
  (bsc#1177271).
- patches.suse/target-rbd-fix-unmap-discard-block-size-conversion.patch:
  (bsc#1177271).
- patches.suse/target-rbd-conditionally-fix-off-by-one-bug-in-get_b.patch:
  (bsc#1177109).
- patches.suse/target-rbd-add-emulate_legacy_capacity-dev-attribute.patch:
  (bsc#1177109).
- commit 613f6b5
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: reduce contention on log trees when logging checksums
  (bsc#1177687).
- commit 449441e
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: make some slub_debug related attributes read-only
  (mm/slub bsc#1165692).
- commit 3730c96
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: remove no longer needed use of log_writers for the log
  root tree (bsc#1177687).
- commit aa9b267
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: extend slub_debug syntax for multiple blocks
  (mm/slub bsc#1165692).
- commit db5b44a
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: stop incremening log_batch for the log root tree when
  syncing log (bsc#1177687).
- commit 0fccfec
* Wed Oct 14 2020 vbabka@suse.cz
- mm: call cond_resched() from deferred_init_memmap() (git fixes
  (mm/init), bsc#1177697).
- commit 30c0b50
* Wed Oct 14 2020 vbabka@suse.cz
- mm: initialize deferred pages with interrupts enabled (git fixes
  (mm/init), bsc#1177697).
- commit ea99f65
* Wed Oct 14 2020 vbabka@suse.cz
- mm/pagealloc.c: call touch_nmi_watchdog() on max order
  boundaries in deferred init (git fixes (mm/init), bsc#1177697).
- commit 3c12134
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: only commit delayed items at fsync if we are logging
  a directory (bsc#1177687).
- commit 6999ba9
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: only commit the delayed inode when doing a full fsync
  (bsc#1177687).
- commit 7ac015a
* Wed Oct 14 2020 yousaf.kaukab@suse.com
- arm64: Enable PCI write-combine resources under sysfs
  (bsc#1175807).
- commit 97c0c04
* Wed Oct 14 2020 mkoutny@suse.com
- mm/memcontrol.c: lost css_put in memcg_expand_shrinker_maps()
  (bsc#1177694).
- commit a848eca
* Wed Oct 14 2020 oneukum@suse.com
- crypto: qat - drop input parameter from adf_enable_aer()
  (jsc#SLE-14454).
- commit cd6d9e4
* Wed Oct 14 2020 yousaf.kaukab@suse.com
- config: arm64: enable CONFIG_SENSORS_ACPI_POWER
  References: jsc#SLE-15070
- commit 3beaf0c
* Wed Oct 14 2020 oneukum@suse.com
- crypto: qat - fix function parameters descriptions
  (jsc#SLE-14454).
- commit fc3fb5b
* Wed Oct 14 2020 oneukum@suse.com
- crypto: qat - remove unnecessary mutex_init() (jsc#SLE-14454).
- commit 457a2aa
* Wed Oct 14 2020 tzimmermann@suse.de
- Update configs for DRM v5.5
- commit 66d3242
* Wed Oct 14 2020 oneukum@suse.com
- crypto: qat - convert to use DEFINE_SEQ_ATTRIBUTE macro
  (jsc#SLE-14454).
- crypto: qat - use PCI_VDEVICE (jsc#SLE-14454).
- crypto: qat - replace device ids defines (jsc#SLE-14454).
- crypto: qat - add delay before polling mailbox (jsc#SLE-14454).
- PCI: Add Intel QuickAssist device IDs (jsc#SLE-14454).
- include/linux/seq_file.h: introduce DEFINE_SEQ_ATTRIBUTE()
  helper macro (jsc#SLE-14454).
- commit f3991a9
* Wed Oct 14 2020 msuchanek@suse.de
- powerpc/pkeys: Fix build error with PPC_MEM_KEYS disabled
  (jsc#SLE-16556 bsc#1078248 FATE#322447).
- powerpc/pkeys: Fix boot failures with Nemo board (A-EON AmigaOne
  X1000) (jsc#SLE-16556 bsc#1078248 FATE#322447).
- powerpc/book3s64/pkey: Disable pkey on POWER6 and before
  (jsc#SLE-16556 bsc#1078248 FATE#322447).
- powerpc/book3s64/pkeys: Remove is_pkey_enabled() (jsc#SLE-16556
  bsc#1078248 FATE#322447).
- powerpc/book3s64/kuap: Move UAMOR setup to key init function
  (jsc#SLE-16556 bsc#1078248 FATE#322447).
- powerpc/book3s64/keys: Print information during boot
  (jsc#SLE-16556 bsc#1078248 FATE#322447).
- powerpc/book3s64/pkeys: Use MMU_FTR_PKEY instead of
  pkey_disabled static key (jsc#SLE-16556 bsc#1078248
  FATE#322447).
- powerpc/book3s64/pkeys: Use pkey_execute_disable_supported
  (jsc#SLE-16556 bsc#1078248 FATE#322447).
- powerpc/book3s64/kuep: Add MMU_FTR_KUEP (jsc#SLE-16556
  bsc#1078248 FATE#322447).
- powerpc/book3s64/pkeys: Add MMU_FTR_PKEY (jsc#SLE-16556
  bsc#1078248 FATE#322447).
- powerpc/book3s64/pkeys: Mark all the pkeys above max pkey as
  reserved (jsc#SLE-16556 bsc#1078248 FATE#322447).
- powerpc/book3s64/pkeys: Make initial_allocation_mask static
  (jsc#SLE-16556 bsc#1078248 FATE#322447).
- powerpc/book3s64/pkeys: Convert pkey_total to num_pkey
  (jsc#SLE-16556 bsc#1078248 FATE#322447).
- powerpc/book3s64/pkeys: Simplify pkey disable branch
  (jsc#SLE-16556 bsc#1078248 FATE#322447).
- powerpc/book3s64/pkeys: kill cpu feature key CPU_FTR_PKEY
  (jsc#SLE-16556 bsc#1078248 FATE#322447).
- Refresh patches.suse/powerpc-dt_cpu_ftrs-Add-feature-for-2nd-DAWR.patch.
- Refresh patches.suse/powerpc-watchpoint-Enable-watchpoint-functionality-o.patch.
- powerpc/book3s64/pkeys: Prevent key 1 modification from
  userspace (jsc#SLE-16556 bsc#1078248 FATE#322447).
- powerpc/book3s64/pkeys: Simplify the key initialization
  (jsc#SLE-16556 bsc#1078248 FATE#322447).
- powerpc/book3s64/pkeys: Explain key 1 reservation details
  (jsc#SLE-16556 bsc#1078248 FATE#322447).
- powerpc/book3s64/pkeys: pkeys are supported only on hash on
  book3s (jsc#SLE-16556 bsc#1078248 FATE#322447).
- commit 3ac8bee
* Wed Oct 14 2020 vbabka@suse.cz
- mm: move_pages: return valid node id in status if the page
  is already on the target node (git fixes (mm/move_pages),
  bsc#1177683).
- commit e8cf54d
* Wed Oct 14 2020 vbabka@suse.cz
- mm: move_pages: report the number of non-attempted pages
  (git fixes (mm/move_pages), bsc#1177683).
- commit e140195
* Wed Oct 14 2020 vbabka@suse.cz
- mm/migrate.c: also overwrite error when it is bigger than zero
  (git fixes (mm/move_pages), bsc#1177683).
- commit 32c9cae
* Wed Oct 14 2020 tiwai@suse.de
- ata: ahci: mvebu: Make SATA PHY optional for Armada 3720
  (git-fixes).
- hwmon: (mlxreg-fan) Fix double "Mellanox" (git-fixes).
- hwmon: (pmbus/max34440) Fix status register reads for
  MAX344{51,60,61} (git-fixes).
- pinctrl: bcm: fix kconfig dependency warning when !GPIOLIB
  (git-fixes).
- spi: omap2-mcspi: Improve performance waiting for CHSTAT
  (git-fixes).
- spi: dw-pci: free previously allocated IRQs if desc->setup()
  fails (git-fixes).
- spi: sprd: Release DMA channel also on probe deferral
  (git-fixes).
- regulator: resolve supply after creating regulator (git-fixes).
- media: usbtv: Fix refcounting mixup (git-fixes).
- media: ti-vpe: Fix a missing check and reference count leak
  (git-fixes).
- media: stm32-dcmi: Fix a reference count leak (git-fixes).
- media: s5p-mfc: Fix a reference count leak (git-fixes).
- media: camss: Fix a reference count leak (git-fixes).
- media: platform: fcp: Fix a reference count leak (git-fixes).
- media: rockchip/rga: Fix a reference count leak (git-fixes).
- media: rcar-vin: Fix a reference count leak (git-fixes).
- media: tc358743: cleanup tc358743_cec_isr (git-fixes).
- media: tc358743: initialize variable (git-fixes).
- media: mx2_emmaprp: Fix memleak in emmaprp_probe (git-fixes).
- media: rcar-csi2: Allocate v4l2_async_subdev dynamically
  (git-fixes).
- media: v4l2-async: Document asd allocation requirements
  (git-fixes).
- media: omap3isp: Fix memleak in isp_probe (git-fixes).
- media: staging/intel-ipu3: css: Correctly reset some memory
  (git-fixes).
- media: uvcvideo: Silence shift-out-of-bounds warning
  (git-fixes).
- media: uvcvideo: Set media controller entity functions
  (git-fixes).
- media: m5mols: Check function pointer in m5mols_sensor_power
  (git-fixes).
- media: ov5640: Correct Bit Div register in clock tree diagram
  (git-fixes).
- media: Revert "media: exynos4-is: Add missed check for
  pinctrl_lookup_state()" (git-fixes).
- media: tuner-simple: fix regression in simple_set_radio_freq
  (git-fixes).
- mmc: sdhci-acpi: AMDI0040: Set SDHCI_QUIRK2_PRESET_VALUE_BROKEN
  (git-fixes).
- mmc: sdhci: Add LTR support for some Intel BYT based controllers
  (git-fixes).
- crypto: bcm - Verify GCM/CCM key length in setkey (git-fixes).
- cypto: mediatek - fix leaks in mtk_desc_ring_alloc (git-fixes).
- crypto: omap-sham - fix digcnt register handling with
  export/import (git-fixes).
- crypto: qat - check cipher length for aead AES-CBC-HMAC-SHA
  (git-fixes).
- crypto: picoxcell - Fix potential race condition bug
  (git-fixes).
- crypto: ixp4xx - Fix the size used in a 'dma_free_coherent()'
  call (git-fixes).
- crypto: mediatek - Fix wrong return value in
  mtk_desc_ring_alloc() (git-fixes).
- crypto: algif_aead - Do not set MAY_BACKLOG on the async path
  (git-fixes).
- crypto: algif_skcipher - EBUSY on aio should be an error
  (git-fixes).
- regulator: axp20x: fix LDO2/4 description (git-fixes).
- spi: stm32: Rate-limit the 'Communication suspended' message
  (git-fixes).
- media: rc: do not access device via sysfs after
  rc_unregister_device() (git-fixes).
- media: rc: uevent sysfs file races with rc_unregister_device()
  (git-fixes).
- commit ac3a9ee
* Wed Oct 14 2020 vbabka@suse.cz
- mm, compaction: make capture control handling safe wrt
  interrupts (git fixes (mm/compaction), bsc#1177681).
- commit c13fd55
* Wed Oct 14 2020 vbabka@suse.cz
- mm, compaction: fully assume capture is not NULL in
  compact_zone_order() (git fixes (mm/compaction), bsc#1177681).
- commit 5fcf485
* Wed Oct 14 2020 ddiss@suse.de
- Update
  patches.suse/target-add-rbd-backend.patch: (fate#318836).
  (simplify block to byte calculations and use consistent error paths)
- commit f576f9b
* Wed Oct 14 2020 mkoutny@suse.com
- blacklist.conf: POSIX timers fixup
- commit bc6b00f
* Wed Oct 14 2020 vbabka@suse.cz
- mm/debug.c: always print flags in dump_page() (git fixes
  (mm/debug)).
- commit 5fed0d2
* Wed Oct 14 2020 glin@suse.com
- security: Fix hook iteration for secid_to_secctx (bsc#1177028).
- security: Fix the default value of secid_to_secctx hook
  (bsc#1177028).
- security: Fix the default value of fs_context_parse_param hook
  (bsc#1177028).
- bpf, lsm: Make BPF_LSM depend on BPF_EVENTS (bsc#1177028).
- bpf, net: Fix build issue when net ns not configured
  (bsc#1177028).
- bpf_helpers_doc.py: Fix warning when compiling bpftool
  (bsc#1177028).
- bpf: Fix trampoline generation for fmod_ret programs
  (bsc#1177028).
- libbpf: Fix handling of optional field_name in
  btf_dump__emit_type_decl (bsc#1177028).
- selftests/bpf: Don't check for btf fd in test_btf (bsc#1177028).
- libbpf: Fix error handling bug in btf_dump__new (bsc#1177028).
- selftests/bpf: Conform selftests/bpf Makefile output to libbpf
  and bpftool (bsc#1177028).
- selftests/bpf: Further clean up Makefile output (bsc#1177028).
- selftests/bpf: Ensure bpf_helper_defs.h are taken from selftests
  dir (bsc#1177028).
- libbpf: Make bpf_map order and indices stable (bsc#1177028).
- bpftool: Make skeleton C code compilable with C++ compiler
  (bsc#1177028).
- libbpf: Fix another __u64 printf warning (bsc#1177028).
- selftests/bpf: More succinct Makefile output (bsc#1177028).
- libbpf: Add zlib as a dependency in pkg-config template
  (bsc#1177028).
- samples/bpf: Add missing -lz to TPROGS_LDLIBS (bsc#1177028).
- irq_work: Fix IRQ_WORK_BUSY bit clearing (bsc#1177028).
- perf/core: Fix !CONFIG_PERF_EVENTS build warnings and failures
  (bsc#1177028).
- samples/bpf: Base target programs rules on Makefile.target (bsc#1177028).
  Refresh patches.suse/samples-bpf-Add-XDP_SHARED_UMEM-support-to-xdpsock.patch
- samples/bpf: Drop unnecessarily inclusion for bpf_load
  (bsc#1177028).
- samples/bpf: Use __LINUX_ARM_ARCH__ selector for arm
  (bsc#1177028).
- selftests/bpf: test_progs: Don't leak server_fd in
  test_sockopt_inherit (bsc#1177028).
- commit 3ae141b
* Wed Oct 14 2020 msuchanek@suse.de
- blacklist.conf: Add a few of SP3 only fixes.
  f1565c24b596 powerpc: use the generic dma_ops_bypass mode
  d02f6b7dab82 powerpc/uaccess: Evaluate macro arguments once, before user
  access is allowed
  c44dc6323cd4 powerpc/64s/kuap: Restore AMR in fast_interrupt_return
- commit 862373b
* Wed Oct 14 2020 msuchanek@suse.de
- powerpc/dma: Fix dma_map_ops::get_required_mask (bsc#1065729).
- commit 0cddc1e
* Wed Oct 14 2020 tbogendoerfer@suse.de
- RDMA/hfi1: Correct an interlock issue for TID RDMA WRITE request
  (bsc#1175621).
- commit 45b1b9d
* Tue Oct 13 2020 neilb@suse.de
- pNFS/flexfiles: Ensure we initialise the mirror bsizes correctly
  on read (git-fixes).
- commit 80d81a4
* Tue Oct 13 2020 jroedel@suse.de
- x86/mm: unencrypted non-blocking DMA allocations use coherent pools (bsc#1175898, ECO-2743).
- Update config files.
- commit 3ded3cd
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: Fix an uninitialized variable bug in atomic_pool_expand() (bsc#1175898, ECO-2743).
- commit c3028f9
* Tue Oct 13 2020 jroedel@suse.de
- scsi: mptfusion: Don't use GFP_ATOMIC for larger DMA allocations (bsc#1175898, ECO-2743).
- commit 4e5bc96
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: Only allocate from CMA when in same memory zone (bsc#1175898, ECO-2743).
- commit 13beda8
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: fix coherent pool allocations for IOMMU mappings (bsc#1175898, ECO-2743).
- commit 0786759
* Tue Oct 13 2020 tzimmermann@suse.de
- supported.conf: Unsupport drm_mipi_dpi
- commit 2cb62d5
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: do not allocate pool memory from CMA (bsc#1175898, ECO-2743).
- commit 52c7389
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: make sure atomic pool suits device (bsc#1175898, ECO-2743).
- commit 2d3cf4a
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: introduce dma_guess_pool() (bsc#1175898, ECO-2743).
- commit 077f93b
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: get rid of dma_in_atomic_pool() (bsc#1175898, ECO-2743).
- commit ed85a15
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: provide function to check physical memory area validity (bsc#1175898, ECO-2743).
- commit 69658a0
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: warn when coherent pool is depleted (bsc#1175898, ECO-2743).
- commit b21257b
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: DMA_COHERENT_POOL should select GENERIC_ALLOCATOR (bsc#1175898, ECO-2743).
- commit 0d0760a
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: add missing set_memory_decrypted() for coherent mapping (bsc#1175898, ECO-2743).
- commit 15a3e46
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: check return value when encrypting or decrypting memory (bsc#1175898, ECO-2743).
- commit 7c6f515
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: re-encrypt memory if dma_direct_alloc_pages() fails (bsc#1175898, ECO-2743).
- commit 671af96
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: always align allocation size in dma_direct_alloc_pages() (bsc#1175898, ECO-2743).
- commit 9262343
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: decouple DMA_REMAP from DMA_COHERENT_POOL (bsc#1175898, ECO-2743).
- refresh config files (reorder only)
- commit 6f0618d
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: fix too large DMA pools on medium memory size systems (bsc#1175898, ECO-2743).
- commit ad5deb3
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: scale the default DMA coherent pool size with memory capacity (bsc#1175898, ECO-2743).
- commit 3ad55af
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: add pool sizes to debugfs (bsc#1175898, ECO-2743).
- commit 5711a8a
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: atomic allocations must come from atomic coherent pools (bsc#1175898, ECO-2743).
- commit 4155def
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: dynamically expanding atomic pools (bsc#1175898, ECO-2743).
- commit 2ab8c98
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: add additional coherent pools to map to gfp mask (bsc#1175898, ECO-2743).
- commit 9e21a34
* Tue Oct 13 2020 jroedel@suse.de
- dma-remap: separate DMA atomic pools from direct remap code (bsc#1175898, ECO-2743).
- Update config files.
- commit 4b9b447
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: make uncached_kernel_address more general (bsc#1175898, ECO-2743).
- commit ca630f5
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: consolidate the error handling in dma_direct_alloc_pages (bsc#1175898, ECO-2743).
- commit 2102fd9
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: merge the generic remapping helpers into dma-direct (bsc#1175898, ECO-2743).
- commit e15d818
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: provide mmap and get_sgtable method overrides (bsc#1175898, ECO-2743).
- Update config files.
- Refresh
  patches.suse/dma-direct-relax-addressability-checks-in-dma_direct_supported.patch.
- commit 4e7185d
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: remove the dma_handle argument to __dma_direct_alloc_pages (bsc#1175898, ECO-2743).
- commit d6d3450
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: remove __dma_direct_free_pages (bsc#1175898, ECO-2743).
- commit bdd6897
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: always use VM_DMA_COHERENT for generic DMA remap (bsc#1175898, ECO-2743).
- commit a8aa6f1
* Tue Oct 13 2020 jack@suse.cz
- Documentation/dax: Update DAX enablement for ext4
  (jsc#SLE-12982).
- commit fa8d7fc
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: add a dma_can_mmap helper (bsc#1175898, ECO-2743).
- commit 36bbe32
* Tue Oct 13 2020 jack@suse.cz
- fs/ext4: Introduce DAX inode flag (jsc#SLE-12982).
- commit c533fc3
* Tue Oct 13 2020 jack@suse.cz
- fs/ext4: Remove jflag variable (jsc#SLE-12982).
- commit fedd6ee
* Tue Oct 13 2020 jack@suse.cz
- fs/ext4: Make DAX mount option a tri-state (jsc#SLE-12982).
  Refresh patches.suse/ext4-dont-warn-when-enabling-DAX.patch
- commit 6f1c66f
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: make dma_atomic_pool_init self-contained (bsc#1175898, ECO-2743).
- commit fc7b6a3
* Tue Oct 13 2020 jack@suse.cz
- fs/ext4: Only change S_DAX on inode load (jsc#SLE-12982).
- commit 57cbd22
* Tue Oct 13 2020 jack@suse.cz
- fs/ext4: Update ext4_should_use_dax() (jsc#SLE-12982).
- commit 1e655fd
* Tue Oct 13 2020 jack@suse.cz
- fs/ext4: Change EXT4_MOUNT_DAX to EXT4_MOUNT_DAX_ALWAYS
  (jsc#SLE-12982).
- commit 40e04bd
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: remove arch_dma_mmap_pgprot (bsc#1175898, ECO-2743).
- refresh configs (drop ARCH_HAS_DMA_MMAP_PGPROT)
- commit 237c20c
* Tue Oct 13 2020 jack@suse.cz
- fs/ext4: Narrow scope of DAX check in setflags (jsc#SLE-12982).
- commit 0d5515b
* Tue Oct 13 2020 tiwai@suse.de
- Add the support for kernel-FLAVOR-optional subpackage (jsc#SLE-11796)
  This change allows to create kernel-*-optional subpackage containing
  the modules that are not shipped on SLE but only on Leap.  Those
  modules are marked in the new "-!optional" marker in supported.conf.
  Flip split_optional definition in kernel-binaries.spec.in for the
  branch that needs the splitting.
- commit 1fa25f8
* Tue Oct 13 2020 jack@suse.cz
- fs: Introduce DCACHE_DONTCACHE (jsc#SLE-13451).
- commit c480aea
* Tue Oct 13 2020 jack@suse.cz
- fs: Lift XFS_IDONTCACHE to the VFS layer (jsc#SLE-13451).
- commit 49cffd4
* Tue Oct 13 2020 jack@suse.cz
- Documentation/dax: Update Usage section (jsc#SLE-13451).
- commit 8979f5d
* Tue Oct 13 2020 jack@suse.cz
- fs/stat: Define DAX statx attribute (jsc#SLE-13451).
- commit d100666
* Tue Oct 13 2020 jack@suse.cz
- fs: Remove unneeded IS_DAX() check in io_is_direct()
  (jsc#SLE-13451).
- commit 6426840
* Tue Oct 13 2020 tzimmermann@suse.de
- supported.conf: Rename tinydrm/ to tiny/
  The DRM subdirectory tinydrm/ got renamed to tiny/ in v5.4. Update
  supported.conf accordingly.
- commit a7da6c5
* Tue Oct 13 2020 jack@suse.cz
- fs/xfs: Update xfs_ioctl_setattr_dax_invalidate()
  (jsc#SLE-13451).
- commit 39d81b8
* Tue Oct 13 2020 jack@suse.cz
- fs/xfs: Combine xfs_diflags_to_linux() and
  xfs_diflags_to_iflags() (jsc#SLE-13451).
- commit 9e9b24a
* Tue Oct 13 2020 jack@suse.cz
- fs/xfs: Create function xfs_inode_should_enable_dax()
  (jsc#SLE-13451).
- commit 1b91811
* Tue Oct 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'driver core: platform: use the correct callback type for bus_find_device'
- commit f0888d5
* Tue Oct 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'spi: pxa2xx: Set controller->max_transfer_size in dma mode'
- commit cacd01e
* Tue Oct 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'ARM: imx_v6_v7_defconfig: Enable CONFIG_DRM_MSM'
- commit 9c597d2
* Tue Oct 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'docs/driver-api: Catch up with dma_buf file-name changes'
- commit 69a739c
* Tue Oct 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'dma-buf/resv: fix exclusive fence get'
- commit 6a3c464
* Tue Oct 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/shmem: Use mutex_trylock in drm_gem_shmem_purge'
- commit 359ef77
* Tue Oct 13 2020 jack@suse.cz
- fs/xfs: Make DAX mount option a tri-state (jsc#SLE-13451).
- commit 82735fe
* Tue Oct 13 2020 jack@suse.cz
- fs/xfs: Change XFS_MOUNT_DAX to XFS_MOUNT_DAX_ALWAYS
  (jsc#SLE-13451).
  Refresh patches.suse/xfs-remove-experimental-tag-for-dax-support.patch
- commit dbe2196
* Tue Oct 13 2020 jack@suse.cz
- fs/xfs: Remove unnecessary initialization of i_rwsem
  (jsc#SLE-13451).
- commit 2988e92
* Tue Oct 13 2020 tzimmermann@suse.de
- blacklist.conf: Temporarily add graphics modules
- commit da306df
* Tue Oct 13 2020 mgorman@suse.de
- Delete
  patches.suse/sched-fair-update_pick_idlest-Select-group-with-lowest-group_util-when-idle_cpus-are-equal.patch.
  Bisections indicated that this may be problematic in some cases even
  though it benefits in others. This is being temporarily reverted
  until it can be addressed upstream.
- commit 759de68
* Tue Oct 13 2020 jroedel@suse.de
- iommu/vt-d: Correctly calculate agaw in domain_init() (bsc#1176400).
- commit 6cf371a
* Tue Oct 13 2020 oneukum@suse.com
- crypto: algapi - introduce the flag CRYPTO_ALG_ALLOCATES_MEMORY
  (jsc#SLE-14454).
- commit be284fd
* Tue Oct 13 2020 ddiss@suse.de
- kabi/severities: ignore kABI for target_core_rbd
  Match behaviour for all other Ceph specific modules.
- commit 1b6ac49
* Tue Oct 13 2020 pvorel@suse.cz
- ima: extend boot_aggregate with kernel measurements
  (bsc#1177617).
- commit c4cca48
* Tue Oct 13 2020 oneukum@suse.com
- crypto: drivers - set the flag CRYPTO_ALG_ALLOCATES_MEMORY
  (jsc#SLE-14454).
  (partial backport)
- commit 77c8b6b
* Tue Oct 13 2020 tbogendoerfer@suse.de
- virtio-net: don't disable guest csum when disable LRO
  (git-fixes).
- commit 45b7a4d
* Tue Oct 13 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Use GFP_ATOMIC flag in allocate_vpe_l1_table()
  (jsc#SLE-14773).
- commit c4351ca
* Tue Oct 13 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Ensure accessing the correct RD when writing
  INVALLR (jsc#SLE-14773).
- commit 5c612b1
* Tue Oct 13 2020 neilb@suse.de
- kabi fix for NFS: Fix flexfiles read failover (git-fixes).
- commit 4923518
* Tue Oct 13 2020 neilb@suse.de
- NFSv4.2: fix client's attribute cache management for
  copy_file_range (git-fixes).
- NFS: Fix flexfiles read failover (git-fixes).
- NFS: Don't return layout segments that are in use (git-fixes).
- NFS: Don't move layouts to plh_return_segs list while in use
  (git-fixes).
- nfs: nfs_file_write() should check for writeback errors
  (git-fixes).
- nfs: ensure correct writeback errors are returned on close()
  (git-fixes).
- svcrdma: Fix page leak in svc_rdma_recv_read_chunk()
  (git-fixes).
- nfsd4: fix NULL dereference in nfsd/clients display code
  (git-fixes).
- xprtrdma: fix incorrect header size calculations (git-fixes).
- SUNRPC: Revert 241b1f419f0e ("SUNRPC: Remove xdr_buf_trim()")
  (git-fixes).
- commit 5c55a8f
* Mon Oct 12 2020 tiwai@suse.de
- i2c: owl: Clear NACK and BUS error bits (git-fixes).
- i2c: meson: fixup rate calculation with filter delay
  (git-fixes).
- i2c: meson: fix clock setting overwrite (git-fixes).
- mmc: core: don't set limits.discard_granularity as 0
  (git-fixes).
- macsec: avoid use-after-free in macsec_handle_frame()
  (git-fixes).
- r8169: fix data corruption issue on RTL8402 (bsc#1174098).
- i2c: cpm: Fix i2c_ram structure (git-fixes).
- commit c1d4f9c
* Mon Oct 12 2020 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/amdgpu: dont schedule jobs while in reset"'
- commit 9f383fe
* Mon Oct 12 2020 tiwai@suse.de
- r8169: fix data corruption issue on RTL8402 (bsc#1174098).
- commit 71e95cd
* Mon Oct 12 2020 tiwai@suse.de
- r8169: consider that PHY reset may still be in progress after
  applying firmware (git-fixes).
- net: phy: introduce phy_read_poll_timeout macro (git-fixes).
- commit f94052b
* Mon Oct 12 2020 ohering@suse.de
- hv_balloon partial request debug (bsc#1151927).
- commit 446a75f
* Mon Oct 12 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Preload LUTs if the hw isn't currently using them'
- commit 7e3b6fe
* Mon Oct 12 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Don't oops in dumb_create ioctl if we have no crtcs'
- commit 0dbe0fa
* Mon Oct 12 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Change Navi14's DWB flag to 1'
- commit bc1ff93
* Mon Oct 12 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Iterate through DRM connectors correctly'
- commit d6b3d39
* Mon Oct 12 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/panfrost: Remove NULL check for regulator'
- commit bdb5def
* Mon Oct 12 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: don't increment vram lost if we are in hibernation'
- commit 7ff3ef6
* Mon Oct 12 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Add missing HBM support and raise Vega20's uclk.'
- commit e08b9dc
* Mon Oct 12 2020 tbogendoerfer@suse.de
- net: fix fraglist segmentation reference count leak
  (bsc#1176447).
- commit 40053c9
* Mon Oct 12 2020 msuchanek@suse.de
- powerpc/hv-gpci: Add sysfs files inside hv-gpci device to show
  cpumask (bsc#1177075 ltc#186099 jsc#SLE-13661).
- powerpc/perf/hv-gpci: Add cpu hotplug support (bsc#1177075
  ltc#186099 jsc#SLE-13661).
- Documentation/ABI: Add ABI documentation for hv-gpci format
  (bsc#1177075 ltc#186099 jsc#SLE-13661).
- Documentation/ABI: Add ABI documentation for hv-24x7 format
  (bsc#1177075 ltc#186099 jsc#SLE-13661).
- powerpc/perf/hv-gpci: Fix starting index value (bsc#1177075
  ltc#186099 jsc#SLE-13661).
- commit 6f9dd6c
* Mon Oct 12 2020 tzimmermann@suse.de
- media: tegra-cec: use cec_notifier_cec_adap_(un)register (bsc#1152489)
- commit bf754d1
* Mon Oct 12 2020 tzimmermann@suse.de
- media: stih-cec: use cec_notifier_cec_adap_(un)register (bsc#1152489)
- commit 1b3ad10
* Mon Oct 12 2020 tzimmermann@suse.de
- media: seco-cec: use cec_notifier_cec_adap_(un)register (bsc#1152489)
- commit 4d34454
* Mon Oct 12 2020 tzimmermann@suse.de
- media: s5p-cec: use cec_notifier_cec_adap_(un)register (bsc#1152489)
- commit 6f6da87
* Mon Oct 12 2020 tzimmermann@suse.de
- media: meson/ao-cec: use cec_notifier_cec_adap_(un)register (bsc#1152489)
- commit e256510
* Mon Oct 12 2020 msuchanek@suse.de
- powerpc/security: Fix link stack flush instruction (bsc#1177547
  ltc#188629 jsc#SLE-14727).
- powerpc/pseries: add new branch prediction security bits for
  link stack (bsc#1177547 ltc#188629 jsc#SLE-14727).
- commit 4d475cb
* Mon Oct 12 2020 tzimmermann@suse.de
- media: cros-ec-cec: use cec_notifier_cec_adap_(un)register (bsc#1152489)
- commit 11ef351
* Mon Oct 12 2020 tbogendoerfer@suse.de
- net: core: document two new elements of struct net_device
  (bsc#1176447).
- netdevice.h: fix xdp_state kernel-doc warning (bsc#1176447).
- netdevice.h: fix proto_down_reason kernel-doc warning
  (bsc#1176447).
- rtnetlink: add support for protodown reason (bsc#1176447).
- net: netdevice.h: add a description for napi_defer_hard_irqs
  (bsc#1176447).
- net: add a new ndo_tunnel_ioctl method (bsc#1176447).
- net: napi: add hard irqs deferral feature (bsc#1176447).
- netdevice: Replace zero-length array with flexible-array member
  (bsc#1176447).
- netdevice.h: fix all kernel-doc and Sphinx warnings
  (bsc#1176447).
- net: Support GRO/GSO fraglist chaining (bsc#1176447).
- net: remove the check argument from __skb_gro_checksum_convert
  (bsc#1176447).
- commit b41d430
* Mon Oct 12 2020 tzimmermann@suse.de
- blacklist.conf: Append 'dma-buf/resv: fix exclusive fence get'
- commit 6040948
* Mon Oct 12 2020 dwagner@suse.de
- qla2xxx: Return EBUSY on fcport deletion (bsc#1171688).
- commit a63944e
* Mon Oct 12 2020 tbogendoerfer@suse.de
- net/mlx5e: Fix race condition on nhe->n pointer in neigh update
  (jsc#SLE-15172).
- net/mlx5e: Fix VLAN create flow (jsc#SLE-15172).
- net/mlx5e: Fix VLAN cleanup flow (jsc#SLE-15172).
- net/mlx5e: Fix return status when setting unsupported FEC mode
  (jsc#SLE-15172).
- net/mlx5e: Fix driver's declaration to support GRE offload
  (jsc#SLE-15172).
- net/mlx5e: CT, Fix coverity issue (jsc#SLE-15172).
- net/mlx5e: Add resiliency in Striding RQ mode for packets
  larger than MTU (jsc#SLE-15172).
- net/mlx5e: Fix error path for RQ alloc (jsc#SLE-15172).
- net/mlx5: Fix request_irqs error flow (jsc#SLE-15172).
- net/mlx5: cmdif, Avoid skipping reclaim pages if FW is not
  accessible (jsc#SLE-15172).
- net/mlx5: Add retry mechanism to the command entry index
  allocation (jsc#SLE-15172).
- net/mlx5: poll cmd EQ in case of command timeout
  (jsc#SLE-15172).
- net/mlx5: Avoid possible free of command entry while timeout
  comp handler (jsc#SLE-15172).
- net/mlx5: Fix a race when moving command interface to polling
  mode (jsc#SLE-15172).
- ice: preserve NVM capabilities in safe mode (jsc#SLE-12878).
- ice: increase maximum wait time for flash write commands
  (jsc#SLE-12878).
- ethtool: mark netlink family as __ro_after_init (bsc#1176447).
- net: core: add nested_level variable in net_device
  (bsc#1176447).
- net: core: introduce struct netdev_nested_priv for nested
  interface infrastructure (bsc#1176447).
- net: core: add __netdev_upper_dev_unlink() (bsc#1176447).
- espintcp: restore IP CB before handing the packet to xfrm
  (bsc#1176447).
- mlxsw: spectrum_acl: Fix mlxsw_sp_acl_tcam_group_add()'s error
  path (bsc#1176774).
- ice: fix memory leak in ice_vsi_setup (jsc#SLE-12878).
- ice: fix memory leak if register_netdev_fails (jsc#SLE-12878).
- ice: Fix call trace on suspend (jsc#SLE-12878).
- iavf: Fix incorrect adapter get in iavf_resume (jsc#SLE-12877).
- net/ethernet/broadcom: fix spelling typo (jsc#SLE-13628).
- net: Fix bridge enslavement failure (bsc#1176447).
- net: explain the lockdep annotations for dev_uc_unsync()
  (bsc#1176447).
- commit 678a223
* Mon Oct 12 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Don't mix srcu tag and negative error codes'
- commit 8cbeeb2
* Mon Oct 12 2020 dwagner@suse.de
- scsi: qla2xxx: Fix inconsistent format argument type in
  qla_dbg.c (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix inconsistent format argument type in qla_os.c
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix inconsistent format argument type in
  tcm_qla2xxx.c (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Update version to 10.02.00.103-k (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix point-to-point (N2N) device discovery issue
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix crash on session cleanup with unload
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix reset of MPI firmware (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix MPI reset needed message (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix buffer-buffer credit extraction error
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Correct the check for sscanf() return value
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Update version to 10.02.00.102-k (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Add SLER and PI control support (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Add IOCB resource tracking (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Add rport fields in debugfs (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Make tgt_port_database available in initiator
  mode (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix I/O errors during LIP reset tests
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Performance tweak (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix memory size truncation (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Reduce duplicate code in reporting speed
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Honor status qualifier in FCP_RSP per spec
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Allow dev_loss_tmo setting for FC-NVMe devices
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Setup debugfs entries for remote ports
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix I/O failures during remote port toggle
  testing (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Remove unneeded variable 'rval' (bsc#1171688
  bsc#1174003).
- commit 4dbce29
* Mon Oct 12 2020 ohering@suse.de
- clocksource/drivers/hyper-v: Reserve PAGE_SIZE space for tsc
  page (jsc#sle-12891).
- commit af793d1
* Mon Oct 12 2020 ohering@suse.de
- clocksource/drivers/hyper-v: Suspend/resume Hyper-V clocksource
  for hibernation (jsc#sle-12891).
- commit 743a304
* Sun Oct 11 2020 neilb@suse.de
- Update
  patches.suse/nfs-Fix-getxattr-kernel-panic-and-memory-overflow.patch
  (bsc#1176381 CVE-2020-25212).
- Update
  patches.suse/nfs-Fix-security-label-length-not-being-reset.patch
  (bsc#1176381 CVE-2020-25212).
  Fix CVE number
- commit 73b5ecf
* Sun Oct 11 2020 tzimmermann@suse.de
- drm/msm/mdp5: Remove direct access of dev->iommu_fwspec (bsc#1152489)
- commit 550e331
* Sun Oct 11 2020 tzimmermann@suse.de
- media: uapi: Add MEDIA_BUS_FMT_RGB888_3X8 media bus format (bsc#1152472)
- commit cebeafb
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gvt: Update force-to-nonpriv register whitelist'
- commit c69979d
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/amd/display: enable S/G for RAVEN chip"'
- commit 6347407
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: disable gfxoff on original raven'
- commit 7b4877a
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: remove experimental flag for Navi14'
- commit 4548797
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: disable gfxoff when using register read interface'
- commit e5610da
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: correct fine grained dpm force level setting'
- commit 9313154
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: issue no PPSMC_MSG_GetCurrPkgPwr on unsupported ASICs'
- commit f775cd1
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/fbdev: Restore physical addresses for fb_mmap()'
- commit cdaed7d
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/userptr: Try to acquire the page lock around set_page_dirty()'
- commit 9d6c6d6
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/pmu: "Frequency" is reported as accumulated cycles'
- commit 50d9de0
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/radeon: fix si_enable_smc_cac() failed issue'
- commit 5ac7aa0
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/renoir: move gfxoff handling into gfx9 module'
- commit ff0d917
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: add warning for GRBM 1-cycle delay issue in gfx9'
- commit 0045124
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: add dummy read by engines for some GCVM status registers in gfx10'
- commit 86f351e
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: register gpu instance before fan boost feature enablment'
- commit ad6f462
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/swSMU: fix smu workload bit map error'
- commit 5048b87
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/amd/display: setting the DIG_MODE to the correct value."'
- commit 4ee3514
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Add ENGINE_ID_DIGD condition check for Navi14'
- commit 29e309f
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: add navi14 PCI ID'
- commit b593e66
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: dont schedule jobs while in reset'
- commit 4a11201
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/arcturus: properly set BANK_SELECT and FRAGMENT_SIZE'
- commit edbb53e
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: remove redundant null pointer check before kfree'
- commit ea08bb1
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/gmc10: properly set BANK_SELECT and FRAGMENT_SIZE'
- commit eefce5b
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/radeon: Fix EEH during kexec'
- commit 80ce726
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/powerplay/vega10: allow undervolting in p7'
- commit 1fb7dab
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'dc.c:use kzalloc without test'
- commit 14a30ec
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: If amdgpu_ib_schedule fails return back the error.'
- commit 3861d8d
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/sched: Set error to s_fence if HW job submission failed.'
- commit b8ced50
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/gfx10: update gfx golden settings for navi12'
- commit 8fb1881
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/sdma5: do not execute 0-sized IBs (v2)'
- commit 3a7155a
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Fix SDMA hang when performing VKexample test'
- commit 5f9dc9c
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: do not synchronize "drr" displays'
- commit 394dc73
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Passive DP->HDMI dongle detection fix'
- commit e9c6b03
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Allow inverted gamma'
- commit d99e82a
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: add 50us buffer as WA for pstate switch in active'
- commit 00fd40a
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: setting the DIG_MODE to the correct value.'
- commit 5ba51cc
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/dp: Do not switch aux to TBT mode for non-TC ports'
- commit 49b9597
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Avoid HPD poll detect triggering a new detect cycle'
- commit 9e5df92
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix PCH reference clock for FDI on HSW/BDW'
- commit 69a1e24
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/tgl: Fix doc not corresponding to code'
- commit 534ee08
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/panfrost: Handle resetting on timeout better'
- commit d2fc4bc
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/vce: fix allocation size in enc ring test'
- commit df355e3
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/vcn: fix allocation size in enc ring test'
- commit 553f47f
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/uvd7: fix allocation size in enc ring test (v2)'
- commit 16ee5e8
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/uvd6: fix allocation size in enc ring test (v2)'
- commit f76fd50
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/radeon: Fix EEH during kexec"'
- commit a921741
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: user pages array memory leak fix'
- commit 4886acf
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix potential VM faults'
- commit 50a4a78
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix error handling in amdgpu_bo_list_create'
- commit 43f1a1c
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Bail earlier when amdgpu.cik_/si_support is not set to 1'
- commit 6b66d2a
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/sdma5: fix mask value of POLL_REGMEM packet for pipe sync'
- commit dfb196e
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/powerplay: fix typo in mvdd table setup'
- commit 77d474c
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix memory leak'
- commit dcad0f4
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Make some functions static'
- commit 35f0d31
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: display_mode_vba_21: remove uint typedef'
- commit 89e1906
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: hide another #warning'
- commit fa50b3b
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: make pmu support optional, again'
- commit 05c1d87
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix multiple memory leaks in acp_hw_init'
- commit b3f9959
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: return tcc_disabled_mask to userspace'
- commit 2238747
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/amdgpu: disable stutter mode for renoir"'
- commit 1e81647
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: add sensor lock support for smu'
- commit 528afc1
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: change metrics update period from 1ms to 100ms'
- commit 80f49ac
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: prevent memory leak'
- commit d9fc8b4
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/display: include slab.h in dcn21_resource.c'
- commit dd46f22
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/display: fix 64 bit divide'
- commit dbb5949
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/gfx10: add support for wks firmware loading'
- commit e1efda1
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: hide an unused variable'
- commit d612a95
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: flag navi12 and 14 as experimental for 5.4'
- commit 30ab7bf
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Restore backlight brightness after system resume'
- commit a5fa75b
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: add navi12 pci id'
- commit 37c8583
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: revert "disable bulk moves for now"'
- commit e2db581
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: remove program of lbpw for renoir'
- commit 0ae708f
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdkfd: Swap trap temporary registers in gfx10 trap handler'
- commit 2d60b46
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Check for valid number of registers to read'
- commit 96939be
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/radeon: Bail earlier when radeon.cik_/si_support=0 is passed'
- commit 000f484
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/amdgpu: power up sdma engine when S3 resume back'
- commit c156abd
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Fix KFD-related kernel oops on Hawaii'
- commit 3ce469d
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Implement voltage limitation for dali'
- commit b0728ef
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: add Asic ID for Dali'
- commit 2ab7f3c
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: update smu11_driver_if_arcturus.h'
- commit b9f9bab
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: add navi14 PCI ID for work station SKU'
- commit e7a3ce3
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix null pointer deref in firmware header printing'
- commit 27e63b7
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: dce11.x /dce12 update formula input'
- commit 9d18fa0
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Remove clock gating restore.'
- commit 0c77c8a
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Add smu lock around in pp_smu_i2c_bus_access'
- commit 461b979
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Add stereo mux and dig programming calls for dcn21'
- commit b1c3b1d
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: disable stutter mode for renoir'
- commit 52f6c5c
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: update renoir_ip_offset.h'
- commit c289c0c
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: implement sysfs for getting dpm clock'
- commit 55732a0
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/tiny: Kconfig: Remove always-y THERMAL dep. from TINYDRM_REPAPER'
- commit 3415799
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/ingenic: Hardcode panel type to DPI'
- commit 52310ed
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/panfrost: Use mutex_trylock in panfrost_gem_purge'
- commit 08a0317
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/shmem: Use mutex_trylock in drm_gem_shmem_purge'
- commit 585d1af
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/shmem: Do dma_unmap_sg before purging pages'
- commit 8269596
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/panfrost: Fix possible suspend in panfrost_remove'
- commit da2e7d8
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/panfrost: Add missing check for pfdev->regulator'
- commit 7ebe667
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Favor last VBT child device with conflicting AUX ch/DDC pin'
- commit 8253496
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gt: execlists->active is serialised by the tasklet'
- commit 62c50c7
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/execlists: Protect peeking at execlists->active'
- commit 89f886d
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix g4x sprite scaling stride check with GTT remapping'
- commit ec34856
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/userptr: Never allow userptr into the mappable GGTT'
- commit 78c95b8
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/dp: Fix dsc bpp calculations, v5.'
- commit 92149fb
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Mark contents as dirty on a write fault'
- commit c362d47
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Prevent bonded requests from overtaking each other on preemption'
- commit f71491b
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fixup preempt-to-busy vs reset of a virtual request'
- commit 1258164
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fixup preempt-to-busy vs resubmission of a virtual request'
- commit 0d11c41
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/execlists: Refactor -EIO markup of hung requests'
- commit 537e4b0
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Only enqueue already completed requests'
- commit 2ae24cd
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/execlists: Drop redundant list_del_init(&rq->sched.link)'
- commit dfa5722
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Bump skl+ max plane width to 5k for linear/x-tiled'
- commit 1ffb475
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Verify the engine after acquiring the active.lock'
- commit f14b3ce
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Extend Haswell GT1 PSMI workaround to all'
- commit 47e58ba
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/cml: Add second PCH ID for CMP'
- commit 58b9bc4
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Whitelist COMMON_SLICE_CHICKEN2'
- commit b8c0681
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Perform GGTT restore much earlier during resume'
- commit 1fb524d
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/execlists: Remove incorrect BUG_ON for schedule-out'
- commit aac5621
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/i915: Fix DP-MST crtc_mask"'
- commit 4f03a11
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Restore relaxed padding (OCL_OOB_SUPPRES_ENABLE) for skl+'
- commit 8e3d3e0
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Limit MST to <= 8bpc once again'
- commit 7ae55b6
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Use NOEVICT for first pass on attemping to pin a GGTT mmap'
- commit fcc2bc9
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Call dma_set_max_seg_size() in i915_driver_hw_probe()'
- commit 5797fe8
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: to make vgpu ppgtt notificaiton as atomic operation'
- commit 7a1a547
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Flush the existing fence before GGTT read/write'
- commit e0fd71d
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Hold irq-off for the entire fake lock period'
- commit 35e0eb7
* Sat Oct 10 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/dp: Fix DSC enable code to use cpu_transcoder instead of encoder->type'
- commit 348ce31
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove the experimental flag for renoir (bsc#1152472)
- commit b84800e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Align engine->uabi_class/instance with i915_drm.h (bsc#1152489)
- commit 488c846
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/userptr: fix size calculation (bsc#1152489)
- commit f5a71dc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panfrost: Add the panfrost_gem_mapping concept (bsc#1152489)
- commit 9ab874d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Handle SST-only branch device case (bsc#1152489)
- commit f746729
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Have DP_Tx send one msg at a time (bsc#1152472)
- commit 6b88aba
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: clear time slots for ports invalid (bsc#1152472)
- commit 2d06880
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/rockchip: fix integer type used for storing dp data rate (bsc#1152472)
- commit 771a9b7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: add missing virtio_gpu_array_lock_resv call (bsc#1152472)
- commit d2226ec
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/pmu: Do not use colons or dashes in PMU names (bsc#1152489)
- commit 2021b6d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Mark ring->vma as active while pinned (bsc#1152489)
- commit 4d93a28
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Mark context->state vma as active while pinned (bsc#1152489)
- commit 67e2387
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Skip trying to unbind in restore_ggtt_mappings (bsc#1152489)
- commit 911e45e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add missing include file <linux/math64.h> (bsc#1152489)
- commit a5b1bd2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Reorder detect_edp_sink_caps before link settings (bsc#1152472)
- commit 66406ba
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: update goldensetting for renoir (bsc#1152472)
- commit 704c90a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gen9: Clear residual context state on context switch (bsc#1152489)
- commit 3b713a1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dp: Disable Port sync mode correctly on teardown (bsc#1152489)
- commit bb3a365
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add Wa_1407352427:icl,ehl (bsc#1152489)
- commit a7cb086
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add Wa_1408615072 and Wa_1407596294 to icl,ehl (bsc#1152489)
- commit 2a0c184
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Restore coarse power gating (bsc#1152489)
- commit 681a576
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Do not restore invalid RS state (bsc#1152489)
- commit 467c1a2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Limit audio CDCLK>=2*BCLK constraint back to GLK only (bsc#1152489)
- commit 52c427c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Mark up virtual engine uabi_instance (bsc#1152489)
- commit 4ce4b29
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Reduce HDMI pixel encoding if max clock is exceeded (bsc#1152472)
- commit 09c1aaf
* Sat Oct 10 2020 tzimmermann@suse.de
- Revert "drm/amdgpu: Set no-retry as default." (bsc#1152472)
- commit ccf3913
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/fb-helper: Round up bits_per_pixel if possible (bsc#1152472)
- commit 1912d3c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sun4i: tcon: Set RGB DCLK min. divider based on hardware model (bsc#1152472)
- commit 853f237
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: correct the shifting in DP_REMOTE_I2C_READ (bsc#1152489)
- commit 8d5db9b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: correct RLC firmwares loading sequence (bsc#1152472)
- commit 02b899a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: enable gfxoff for raven1 refresh (bsc#1152472)
- commit 8599cb6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/smu: add metrics table lock for vega20 (v2) (bsc#1152472)
- commit 3f8dc56
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/smu: add metrics table lock for navi (v2) (bsc#1152472)
- commit c57eddc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/smu: add metrics table lock for arcturus (v2) (bsc#1152472)
- commit 3a24619
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/smu: add metrics table lock (bsc#1152472)
- commit 4239fef
* Sat Oct 10 2020 tzimmermann@suse.de
- Revert "drm/amdgpu: simplify ATPX detection" (bsc#1152472)
- commit 676540a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/arm/mali: make malidp_mw_connector_helper_funcs static (bsc#1152472)
- commit 3aab1d9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sun4i: hdmi: Remove duplicate cleanup calls (bsc#1152472)
- commit e8523f7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: reduce the hbp and hfp for phy timing (bsc#1152472)
- commit 20928f0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: Fix can't get component for external display plane. (bsc#1152472)
- commit 436c894
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: Check return value of mtk_drm_ddp_comp_for_plane. (bsc#1152472)
- commit 5cf638b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Hold reference to intel_frontbuffer as we track activity (bsc#1152489)
- commit 3767d63
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Ratelimit display power w/a (bsc#1152489)
- commit 5505a57
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/pmu: Ensure monotonic rc6 (bsc#1152489)
- commit 9b10ac8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gvt: Fix guest boot warning (bsc#1152489)
- commit 86a0daf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gvt: Pin vgpu dma address before using (bsc#1152489)
- commit da821e1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gvt: set guest display buffer as readonly (bsc#1152489)
- commit 337e8ed
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gvt: use vgpu lock for active state setting (bsc#1152489)
- commit 02275c8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix pid leak with banned clients (bsc#1152489)
- commit 14031dd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gem: Keep request alive while attaching fences (bsc#1152489)
- commit c0e8a96
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix WARN_ON condition for cursor plane ddb allocation (bsc#1152489)
- commit 2228d89
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Drop Wa#1178 (bsc#1152489)
- commit e0f9934
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/ehl: Define EHL powerwells independently of ICL (bsc#1152489)
- commit 37c705a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Set fence_work.ops before dma_fence_init (bsc#1152489)
- commit 623b758
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Copy across scheduler behaviour flags across submit fences (bsc#1152489)
- commit 183431c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dsb: Fix in mmio offset calculation of DSB instance (bsc#1152489)
- commit 9784b2c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/exynos: gsc: add missed component_del (bsc#1152472)
- commit 85f0588
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add invalidate semaphore limit for SRIOV in gmc10 (bsc#1152472)
- commit 1d38fe0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add invalidate semaphore limit for SRIOV and picasso in (bsc#1152472)
- commit c6a1e0c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: avoid using invalidate semaphore for picasso (bsc#1152472)
- commit dd11703
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix license on Kconfig and Makefiles (bsc#1152472)
- commit bfa79c5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: include linux/slab.h where needed (bsc#1152472)
- commit d453f8d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix undefined struct member reference (bsc#1152472)
- commit 0a5f6e0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Compare clock state member to determine (bsc#1152472)
- commit 04384ba
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/display: add fallthrough comment (bsc#1152472)
- commit 6d2e46a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Increase the number of retries after AUX DEFER (bsc#1152472)
- commit f12ab51
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: update dispclk and dppclk vco frequency (bsc#1152472)
- commit 1715b4d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Fix screen tearing on vrr tests (bsc#1152472)
- commit 4c95a5a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Reset steer fifo before unblanking the stream (bsc#1152472)
- commit 5105533
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fixed that I2C over AUX didn't read data issue (bsc#1152472)
- commit c029c11
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Change the delay time before enabling FEC (bsc#1152472)
- commit 3d83d5c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: have two different sr and pstate latency tables for (bsc#1152472)
- commit fe1c1ea
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Fixed kernel panic when booting with DP-to-HDMI (bsc#1152472)
- commit 62e8c5b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: populate bios integrated info for renoir (bsc#1152472)
- commit efb69d7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix DalDramClockChangeLatencyNs override (bsc#1152472)
- commit 0c6d76b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Map DSC resources 1-to-1 if numbers of OPPs and DSCs (bsc#1152472)
- commit 3707e18
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: update sr and pstate latencies for Renoir (bsc#1152472)
- commit 14714bd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add cache flush workaround to gfx8 emit_fence (bsc#1152472)
- commit 71f7660
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add header line for power profile on Arcturus (bsc#1152472)
- commit 6b0da6f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add check before enabling/disabling broadcast mode (bsc#1152472)
- commit 047a57f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Serialise with remote retirement (bsc#1152489)
- commit d2de977
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Detect if we miss WaIdleLiteRestore (bsc#1152489)
- commit b7738c8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/hdcp: Nuke intel_hdcp_transcoder_config() (bsc#1152489)
- commit 06ee209
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/fbc: Disable fbc by default on all glk+ (bsc#1152489)
- commit a02d791
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: Configure OAR for specific context (bsc#1152489)
- commit ec7fd57
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: Allow non-privileged access when OA buffer is not (bsc#1152489)
- commit a1e615e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Save irqstate around virtual_context_destroy (bsc#1152489)
- commit ef4ef22
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panfrost: Open/close the perfcnt BO (bsc#1152489)
- commit 99ea743
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panfrost: Fix a race in panfrost_gem_free_object() (bsc#1152489)
- commit a8e9aff
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panfrost: Fix a BO leak in panfrost_ioctl_mmap_bo() (bsc#1152489)
- commit b1076af
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panfrost: Fix a race in panfrost_ioctl_madvise() (bsc#1152489)
- commit 0cfff81
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panfrost: devfreq: Round frequencies to OPPs (bsc#1152489)
- commit 25430b2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mgag200: Flag all G200 SE A machines as broken wrt <startadd> (bsc#1152489)
- commit 7ba5d7f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/nouveau/kms/nv50-: fix panel scaling (bsc#1152472)
- commit 68e45d3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/nouveau/kms/nv50-: Limit MST BPC to 8 (bsc#1152472)
- commit e77a795
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/nouveau/kms/nv50-: Store the bpc we're using in nv50_head_atom (bsc#1152472)
- commit 5f5f3c7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/nouveau/kms/nv50-: Call outp_atomic_check_view() before handling (bsc#1152472)
- commit 67ccf6a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/nouveau: Fix drm-core using atomic code-paths on pre-nv50 (bsc#1152472)
- commit 2920aeb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/nouveau: Move the declaration of struct nouveau_conn_atom up a (bsc#1152472)
- commit 92c7adc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: meson: venc: cvbs: fix CVBS mode matching (bsc#1152489)
- commit 63bc116
* Sat Oct 10 2020 tzimmermann@suse.de
- dma-buf: Fix memory leak in sync_file_merge() (bsc#1152472)
- commit ae47ad4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mcde: dsi: Fix invalid pointer dereference if panel cannot be (bsc#1152472)
- commit bc6aaef
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/ehl: Make icp_digital_port_connected() use phy instead of (bsc#1152489)
- commit 5fd16da
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gvt: Fix cmd length check for MI_ATOMIC (bsc#1152489)
- commit f460efa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gvt: Refine non privilege register address calucation (bsc#1152489)
- commit 7d61a8b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gem: Take timeline->mutex to walk list-of-requests (bsc#1152489)
- commit 992d19e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Correct the bug in drm_dp_update_payload_part1() (bsc#1152472)
- commit f670ef2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: fix dma_addr refcounting (bsc#1152472)
- commit ddda3c9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Fix build on systems with STACKTRACE_SUPPORT=n (bsc#1152472)
- commit c5e2c52
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mgag200: Add workaround for HW that does not support 'startadd' (bsc#1152489)
- commit 656cd39
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mgag200: Store flags from PCI driver data in device structure (bsc#1152489)
- commit f18dbcf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mgag200: Extract device type from flags (bsc#1152489)
- commit 8c7d3c9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Run hub cleanup on ->remove() (bsc#1152489)
- commit 52b1a73
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Make the +5V HDMI supply optional (bsc#1152489)
- commit dd2eff8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Silence expected errors on IOMMU attach (bsc#1152489)
- commit 9480c0b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: vic: Export module device table (bsc#1152489)
- commit 7c51a6e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Implement system suspend/resume (bsc#1152489)
- commit 6247653
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Use proper IOVA address for cursor image (bsc#1152489)
- commit aedd103
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: gem: Remove premature import restrictions (bsc#1152489)
- commit 670f5c4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: gem: Properly pin imported buffers (bsc#1152489)
- commit 7198560
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: hub: Remove bogus connection mutex check (bsc#1152489)
- commit 8e62b95
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/radeon: fix r1xx/r2xx register checker for POT textures (bsc#1152489)
- commit 9884aa7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix GFX10 missing CSIB set(v3) (bsc#1152489)
- commit 80f96ce
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: should stop GFX ring in hw_fini (bsc#1152489)
- commit e8020bf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: do autoload right after MEC loaded for SRIOV VF (bsc#1152489)
- commit b847405
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: skip rlc ucode loading for SRIOV gfx10 (bsc#1152489)
- commit 7b510eb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix calltrace during kmd unload(v3) (bsc#1152489)
- commit 826af82
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: unlock srbm_mutex after queue programming finish (bsc#1152489)
- commit 651ae9a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Added ASIC specific checks in gfxhub V1.1 get XGMI info (bsc#1152489)
- commit cf72468
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: unify smu send message function (bsc#1152489)
- commit 5935c1e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: re-enable wait in pipelock, but add timeout (bsc#1152489)
- commit f9a257f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Get NV14 specific ip params as needed (bsc#1152489)
- commit 6dfa653
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Adding NV14 IP Parameters (bsc#1152489)
- commit 513cc20
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Include num_vmid and num_dsc within NV14's resource (bsc#1152489)
- commit 0c33544
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: use CPU to flush vmhub if sched stopped (bsc#1152489)
- commit b62d9f7
* Sat Oct 10 2020 tzimmermann@suse.de
- amdgpu: Enable KFD on POWER systems (bsc#1152489)
- commit f450076
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Optimize KFD page table reservation (bsc#1152489)
- commit 323c19f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: flag vram lost on baco reset for VI/CIK (bsc#1152489)
- commit 076788b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Resolved offchip EEPROM I/O issue (bsc#1152489)
- commit bd2fe70
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add default clocks if not able to fetch them (bsc#1152489)
- commit 0a618ab
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Reduce nested prepare_remote_context() to a trylock (bsc#1152489)
- commit 48d8dc2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Default to a more lenient forced preemption timeout (bsc#1152489)
- commit b4c6086
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Make intel_ring_unpin() safe for concurrent pint (bsc#1152489)
- commit b634551
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Schedule request retirement when timeline idles (bsc#1152489)
- commit 2212dca
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Adapt engine_park synchronisation rules for (bsc#1152489)
- commit aa93b3f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Fixup cancel_port_requests() (bsc#1152489)
- commit 1dfd818
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Mark the execlists->active as the primary volatile (bsc#1152489)
- commit e0d76e4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Unlock engine-pm after queuing the kernel context switch (bsc#1152489)
- commit 1783b48
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Close race between engine_park and (bsc#1152489)
- commit b323230
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Mark up the calling context for intel_wakeref_put() (bsc#1152489)
- commit 03a6533
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Wait until the intel_wakeref idle callback is complete (bsc#1152489)
- commit 1c70177
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Fixup config ifdeffery for pm_suspend_target_state (bsc#1152489)
- commit f088a69
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/query: Align flavour of engine data lookup (bsc#1152489)
- commit ba8d280
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add DKL PHY vswing table for HDMI (bsc#1152489)
- commit 34236b1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/ehl: Update voltage level checks (bsc#1152489)
- commit 0995c22
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/adreno: Add support for Adreno 510 GPU (bsc#1152489)
- commit 7817295
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dsi: Add configuration for 8x76 (bsc#1152489)
- commit 689cb17
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dsi: Add configuration for 28nm PLL on family B (bsc#1152489)
- commit b5c9645
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/mdp5: Add configuration for msm8x76 (bsc#1152489)
- commit 4e62bc3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/mdp5: Add optional TBU and TBU_RT clocks (bsc#1152489)
- commit a19cc7b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm: always dump buffer base/size (bsc#1152489)
- commit be3ea8e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm: fix rd dumping for split-IB1 (bsc#1152489)
- commit 4e7b281
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/hdmi: silence -EPROBE_DEFER warning (bsc#1152489)
- commit 60b0da9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dsi: Implement qcom, dsi-phy-regulator-ldo-mode for 28nm PHY (bsc#1152489)
- commit ab18b3d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/mdp5: make config variables static (bsc#1152489)
- commit fdf8809
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm: make a5xx_show and a5xx_gpu_state_put static (bsc#1152489)
- commit d131a40
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/mdp5: Remove set but not used variable 'hw_cfg' in (bsc#1152489)
- commit ea03ca1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dsi: Remove set but not used variable 'lp' (bsc#1152489)
- commit 4483a8f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dsi: Remove set but not used variable 'lpx' (bsc#1152489)
- commit d9eff3a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/mdp5: Remove set but not used variable 'hw_cfg' in (bsc#1152489)
- commit 5d2a7d4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/mdp5: Remove set but not used variable 'fmt' (bsc#1152489)
- commit a9f645d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm: Sanitize the modeset_is_locked checks in dpu (bsc#1152489)
- commit baf8197
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dpu: Remove set but not used variables 'mode', 'dpu_kms', (bsc#1152489)
- commit c0fec4b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dpu: Remove set but not used variables 'cmd_enc', 'priv' (bsc#1152489)
- commit f5eeff1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dpu: Remove set but not used variables 'dpu_cstate', 'priv' (bsc#1152489)
- commit 8e465ec
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dpu: Remove set but not used variable 'priv' in (bsc#1152489)
- commit 2a634a9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dpu: Remove set but not used variable 'priv' in (bsc#1152489)
- commit 225dacd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dpu: Remove set but not used variable 'priv' in dpu_kms.c (bsc#1152489)
- commit 89b959f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm: include linux/sched/task.h (bsc#1152489)
- commit 2d2eb00
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dsi: Move static keyword to the front of declarations (bsc#1152489)
- commit 31edaf8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm: Remove unused function arguments (bsc#1152489)
- commit e5ba563
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dpu: Remove unnecessary NULL checks (bsc#1152489)
- commit d5f883f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dpu: Remove unnecessary NULL checks (bsc#1152489)
- commit 3c7a39e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dpu: Remove unnecessary NULL checks (bsc#1152489)
- commit 9dec412
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dpu: Remove unnecessary NULL checks (bsc#1152489)
- commit a3914f5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dpu: Remove unused macro (bsc#1152489)
- commit da5ec2d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/dpu: Remove unused variables (bsc#1152489)
- commit 2e19c4e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm/gpu: add ocmem init/cleanup functions (bsc#1152489)
- commit f08fef6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: limit to INT_MAX in create_blob ioctl (bsc#1152489)
- commit b1dbca5
* Sat Oct 10 2020 tzimmermann@suse.de
- PCI/PM: Avoid exporting __pci_complete_power_transition() (bsc#1152489)
- commit 3aa720a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/radeon: Prefer pcie_capability_read_word() (bsc#1152489)
- commit b45125d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/radeon: Replace numbers with PCI_EXP_LNKCTL2 definitions (bsc#1152489)
- commit 96735eb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/radeon: Correct Transmit Margin masks (bsc#1152489)
- commit 78eb672
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Prefer pcie_capability_read_word() (bsc#1152489)
- commit 9071ffe
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Replace numbers with PCI_EXP_LNKCTL2 definitions (bsc#1152489)
- commit 0c7e05e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Correct Transmit Margin masks (bsc#1152489)
- commit 5e28bff
* Sat Oct 10 2020 tzimmermann@suse.de
- kbuild: remove header compile test (bsc#1152489)
- commit 1f622d5
* Sat Oct 10 2020 tzimmermann@suse.de
- video/logo: move pnmtologo tool to drivers/video/logo/ from scripts/ (bsc#1152489)
- commit fec2662
* Sat Oct 10 2020 tzimmermann@suse.de
- video/logo: simplify cmd_logo (bsc#1152489)
- commit 835f9f5
* Sat Oct 10 2020 tzimmermann@suse.de
- video: fbdev: matrox: convert to i2c_new_scanned_device (bsc#1152489)
- commit 8ceb8a6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: ti-tfp410: switch to using fwnode_gpiod_get_index() (bsc#1152489)
- commit dd43b1b
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: qcom-wled: Fix spelling mistake "trigged" -> "triggered" (bsc#1152489)
- commit bac72a8
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: gpio: Pull gpio_backlight_initial_power_state() into probe (bsc#1152489)
- commit e0e34e8
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: gpio: Use a helper variable for &pdev->dev (bsc#1152489)
- commit b0a452b
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: gpio: Simplify the platform data handling (bsc#1152489)
- commit d764e04
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: gpio: Explicitly set the direction of the GPIO (bsc#1152489)
- commit 9ec7a4e
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: gpio: Remove stray newline (bsc#1152489)
- commit 9cca29c
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: gpio: Remove unneeded include (bsc#1152489)
- commit 5639a40
* Sat Oct 10 2020 tzimmermann@suse.de
- video: backlight: tosa: Use GPIO lookup table (bsc#1152489)
- commit 2bc80f1
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: qcom-wled: Add auto string detection logic (bsc#1152489)
- commit f798ce4
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: qcom-wled: Add support for short circuit handling (bsc#1152489)
- commit aa8b9c2
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: qcom-wled: Add support for WLED4 peripheral (bsc#1152489)
- commit fe338c4
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: qcom-wled: Restructure the driver for WLED3 (bsc#1152489)
- commit 45e68f7
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: qcom-wled: Rename PM8941* to WLED3 (bsc#1152489)
- commit 8398ce4
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: qcom-wled: Rename pm8941-wled.c to qcom-wled.c (bsc#1152489)
- commit f120fd4
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: Kconfig: jornada720: Use CONFIG_PREEMPTION (bsc#1152489)
- commit 65b1a9b
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: pwm_bl: Switch to power-of-2 base for fixed-point math (bsc#1152489)
- commit e5a2caf
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: pwm_bl: Drop use of int_pow() (bsc#1152489)
- commit 4016ba4
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: pwm_bl: Eliminate a 64/32 division (bsc#1152489)
- commit cbc340c
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: pwm_bl: Fix cie1913 comments and constant (bsc#1152489)
- commit 8c76451
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: pwm_bl: Add missing curly branches in else branch (bsc#1152489)
- commit 972eae6
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: pwm_bl: Don't assign levels table repeatedly (bsc#1152489)
- commit d0979c0
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: lm3630a: Add an enable gpio for the HWEN pin (bsc#1152489)
- commit 6229853
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: ipaq_micro: Make structure micro_bl_props constant (bsc#1152489)
- commit 4144e2d
* Sat Oct 10 2020 tzimmermann@suse.de
- backlight: lm3630a: Fix module aliases (bsc#1152489)
- commit 6691745
* Sat Oct 10 2020 tzimmermann@suse.de
- compat_ioctl: move ATYFB_CLK handling to atyfb driver (bsc#1152489)
- commit 0fde320
* Sat Oct 10 2020 tzimmermann@suse.de
- compat_ioctl: move more drivers to compat_ptr_ioctl (bsc#1152489)
- commit 3253878
* Sat Oct 10 2020 tzimmermann@suse.de
- video: hyperv: hyperv_fb: Support deferred IO for Hyper-V frame (bsc#1152489)
- commit 7140197
* Sat Oct 10 2020 tzimmermann@suse.de
- video: hyperv: hyperv_fb: Obtain screen resolution from Hyper-V host (bsc#1152489)
- commit 9c89788
* Sat Oct 10 2020 tzimmermann@suse.de
- video: hyperv_fb: Add the support of hibernation (bsc#1152489)
- commit e636016
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Use mmu_interval_notifier instead of hmm_mirror (bsc#1152489)
- commit 4d5c4a1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Use mmu_interval_insert instead of hmm_mirror (bsc#1152489)
- commit 2ede871
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Call find_vma under mmap_sem (bsc#1152489)
- commit 01754b3
* Sat Oct 10 2020 tzimmermann@suse.de
- nouveau: use mmu_interval_notifier instead of hmm_mirror (bsc#1152489)
- commit c995eee
* Sat Oct 10 2020 tzimmermann@suse.de
- nouveau: use mmu_notifier directly for invalidate_range_start (bsc#1152489)
- commit ea1a960
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/radeon: use mmu_interval_notifier_insert (bsc#1152489)
- commit cae2cc1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: Convert vm callbacks to helpers (bsc#1152489)
- commit 84bbf9e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: Remove explicit typecasts of vm_private_data (bsc#1152489)
- commit 2668e85
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: invalidate mmhub semaphore workaround in gmc9/gmc10 (bsc#1152472)
- commit 171ff77
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: initialize vm_inv_eng0_sem for gfxhub and mmhub (bsc#1152472)
- commit cbb6b1e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/amdgpu/sriov skip RLCG s/r list for arcturus VF. (bsc#1152472)
- commit 10a8922
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/amdgpu/sriov temporarily skip ras,dtm,hdcp for arcturus VF (bsc#1152472)
- commit ba7b2e7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: re-init clear state buffer after gpu reset (bsc#1152472)
- commit f66366a
* Sat Oct 10 2020 tzimmermann@suse.de
- merge fix for "ftrace: Rework event_create_dir()" (bsc#1152472)
- commit 5e8796b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Update Arcturus golden registers (bsc#1152472)
- commit 564da1b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: fix out-of-bound mqd_backup array access (bsc#1152472)
- commit 92d93b5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: explicitly wait for cp idle after halt/unhalt (bsc#1152472)
- commit cd968a0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: properly set PP_GFXOFF_MASK (v2) (bsc#1152472)
- commit 26f774c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix bad DMA from INTERRUPT_CNTL2 (bsc#1152472)
- commit 370bdbf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/radeon: fix bad DMA from INTERRUPT_CNTL2 (bsc#1152472)
- commit 8962c27
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Fix debugfs on MST connectors (bsc#1152472)
- commit 6b53721
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/nv: add asic func for fetching vbios from rom directly (bsc#1152472)
- commit 8442680
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: put flush_delayed_work at first (bsc#1152472)
- commit 0b16378
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/vcn2.5: fix the enc loop with hw fini (bsc#1152472)
- commit f49d42e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: issue BTC on Navi during SMU setup (bsc#1152472)
- commit dbffe1c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: avoid DPM reenable process on Navi1x ASICs V2 (bsc#1152472)
- commit 52a0520
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: fix mqd backup/restore for gfx rings (v2) (bsc#1152472)
- commit 3ff6b96
* Sat Oct 10 2020 tzimmermann@suse.de
- Revert "drm/i915/gt: Wait for new requests in (bsc#1152489)
- commit cd9156e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: fix mmap refcounting (bsc#1152489)
- commit 80d2376
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gvt: Stop initializing pvinfo through reading mmio (bsc#1152489)
- commit e86be68
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Split i915_active.mutex into an irq-safe spinlock for the (bsc#1152489)
- commit d7d5848
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: fix accidental static variable use (bsc#1152489)
- commit 292cf99
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/guc: Skip suspend/resume GuC action on platforms w/o GuC (bsc#1152489)
- commit 283cfa0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Wait for new requests in intel_gt_retire_requests() (bsc#1152489)
- commit cedc366
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Restore GT coarse power gating workaround (bsc#1152489)
- commit 291f98b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: don't forget noa wait after oa config (bsc#1152489)
- commit 4be953d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Avoid atomic context for error capture (bsc#1152489)
- commit 1fbeb5e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Fix TRANS_DDI_MST_TRANSPORT_SELECT definition (bsc#1152489)
- commit 041c785
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix detection for a CMP-V PCH (bsc#1152489)
- commit 39dda06
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Flush context free work on cleanup (bsc#1152489)
- commit fd70224
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/vcn: finish delay work before release resources (bsc#1152489)
- commit a254c73
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: read pcie speed/width info (v2) (bsc#1152489)
- commit 58c5480
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/smu_v11: Unify and fix power limits (bsc#1152489)
- commit 62cae9f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/navi10: Implement od clk printing (bsc#1152489)
- commit adcc44c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/navi10: implement GFXCLK_CURVE overdrive (bsc#1152489)
- commit b1e278e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/navi10: implement sclk/mclk OD via pp_od_clk_voltage (bsc#1152489)
- commit 04e2072
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/amdgpu: finish delay works before release resources (bsc#1152489)
- commit fd4080a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/radeon: Clean up code in radeon_pci_shutdown() (bsc#1152489)
- commit df124f2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay/smu7: fix AVFS handling with custom powerplay (bsc#1152489)
- commit a8d7d95
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: avoid upload corrupted ta ucode to psp (bsc#1152489)
- commit 22a8b33
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vmwgfx: remove set but not used variable 'srf' (bsc#1152489)
- commit c1aa59e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm, drm/vmwgfx: Use a configuration option for the TTM dma page (bsc#1152489)
- commit fe24ef0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Split a setting of MSA to MST and SST (bsc#1152489)
- commit e5aa713
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Move reset_active() from schedule-out to (bsc#1152489)
- commit 98a4a3b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Protect context while grabbing its name for the request (bsc#1152489)
- commit 02ca858
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: always consider holding preemption a privileged op (bsc#1152489)
- commit 43dbf1c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Leave the aliasing-ppgtt size alone (bsc#1152489)
- commit 3054586
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: only include intel_dp_link_training.h where needed (bsc#1152489)
- commit edb6218
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gem: Fix error path to unlock if the GEM context is closed (bsc#1152489)
- commit e430db5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Only drop heartbeat.systole if the sole owner (bsc#1152489)
- commit 4aff543
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/arcpgu: rework encoder search (bsc#1152489)
- commit dae7470
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm: fix memleak on release (bsc#1152472)
- commit e4c79fe
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: fix AVFS handling with custom powerplay table (bsc#1152489)
- commit f61037b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: dynamically disable ds and ulv for compute (bsc#1152489)
- commit ccd5e51
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: correct Arcturus OD support (bsc#1152489)
- commit ed7c4da
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: allow direct upload save restore list for raven2 (bsc#1152489)
- commit 4fac1a8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sched: struct completion requires linux/completion.h inclusion (bsc#1152489)
- commit 1acb7c5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Avoid accidental thread reactivation. (bsc#1152489)
- commit 82e5646
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sched: Avoid job cleanup if sched thread is parked. (bsc#1152489)
- commit 9d2eec4
* Sat Oct 10 2020 tzimmermann@suse.de
- Revert "drm/amdgpu: dont schedule jobs while in reset" (bsc#1152489)
- commit 5cb7be5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sched: Use completion to wait for sched->thread idle v2. (bsc#1152489)
- commit 97958d2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix vega20 pstate status change (bsc#1152489)
- commit b6b6182
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix sysfs interface pcie_replay_count error on navi asic (bsc#1152489)
- commit 53b9961
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Need to disable msix when unloading driver (bsc#1152489)
- commit 21d8b95
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Add comments to gmc structure (bsc#1152489)
- commit 74c2ce8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Improve RAS documentation (v2) (bsc#1152489)
- commit be14423
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix double reference dropping (bsc#1152489)
- commit 0119119
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: fix struct init in renoir_print_clk_levels (bsc#1152489)
- commit 651989a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix potential double drop fence reference (bsc#1152489)
- commit 26debdf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: change read of GPU clock counter on Vega10 VF (bsc#1152489)
- commit 96f6377
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: fix deadlock on setting (bsc#1152489)
- commit 4796c41
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: perform p-state switch after the whole hive initialized (bsc#1152489)
- commit ad15830
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix possible pstate switch race condition (bsc#1152489)
- commit d4588ba
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: update Arcturus driver-smu interface header (bsc#1152489)
- commit f0b5600
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: disallow direct upload save restore list from gfx driver (bsc#1152489)
- commit b1a928a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sched:  Fix passing zero to 'PTR_ERR' warning v2 (bsc#1152489)
- commit 30cbae1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/discovery: Need to free discovery memory (bsc#1152489)
- commit 73be106
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: print the pptable provider (bsc#1152489)
- commit 787790f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Show resolution correctly in mode validation debug output (bsc#1152489)
- commit a696cf6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/gpuvm: add some additional comments in (bsc#1152489)
- commit 28f8299
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: enable VCN DPG on Raven and Raven2 (bsc#1152489)
- commit 0c68e81
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: support xgmi pstate setting on powerplay routine (bsc#1152489)
- commit 8c6e873
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: update is_sw_smu_xgmi check (bsc#1152489)
- commit 9f3ddb5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: change pstate only after all XGMI device initialized (bsc#1152489)
- commit 9d7f844
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mst: Fix up u64 division (bsc#1152472)
- commit 1d16de6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: msm: a6xx: fix debug bus register configuration (bsc#1152472)
- commit c7ac3ee
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Add intel_gt_suspend_prepare (bsc#1152489)
- commit fa0f548
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Drop false assertion on user_forcewake (bsc#1152489)
- commit 9fe9646
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Defer rc6 shutdown to suspend_late (bsc#1152489)
- commit ed877a5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Move user_forcewake application to GT (bsc#1152489)
- commit 7cd6516
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gem: Leave reloading kernel context on resume to GT (bsc#1152489)
- commit aa1cd73
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Call intel_gt_sanitize() directly (bsc#1152489)
- commit 3205ef8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: Support 180 degree rotation (bsc#1152472)
- commit 208fb12
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: Support reflect-x plane rotation (bsc#1152472)
- commit 32bf5b2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: Support reflect-y plane rotation (bsc#1152472)
- commit 2d6d4cf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: Plumb supported rotation values from components to (bsc#1152472)
- commit 9a21088
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: Add plumbing for layer_check hook (bsc#1152472)
- commit cc0eb77
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: Add helper to get component for a plane (bsc#1152472)
- commit 4d03bb4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: Refactor plane init (bsc#1152472)
- commit 6ff5190
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: Add RGB[A] variants to published plane formats (bsc#1152472)
- commit 5fd553f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Don't select BROKEN (bsc#1152472)
- commit db6189c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: fix gcc compile error (bsc#1152472)
- commit 24ae5b6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add a conversion function for transmitter and phy_id (bsc#1152472)
- commit 8dcc725
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix no ACK from LDS read during stress test for Arcturus (bsc#1152472)
- commit 91f60d7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix gfx VF FLR test fail on navi (bsc#1152472)
- commit 81390c5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: bypass some cleanup work after err_event_athub (v2) (bsc#1152472)
- commit e5987e4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: clear UVD VCPU buffer when err_event_athub generated (bsc#1152472)
- commit b9d1303
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/SRIOV: SRIOV VF doesn't support BACO (bsc#1152472)
- commit 5ef0536
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Remove superfluous void * cast in debugfs_create_file() (bsc#1152472)
- commit 176b9a6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove set but not used variable 'adev' (bsc#1152472)
- commit db1a6bd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: bug fix for out of bounds mem on gpu cache filling info (bsc#1152472)
- commit 2b3272e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Delete duplicated queue bit map reservation (bsc#1152472)
- commit cbf2814
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Delete unnecessary pr_fmt switch (bsc#1152472)
- commit c005f22
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: Make two functions static (bsc#1152472)
- commit c48653e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd: correct "_LENTH" mispelling in constant (bsc#1152472)
- commit f3b20b0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd: declare amdgpu_exp_hw_support in amdgpu.h (bsc#1152472)
- commit ec0a82e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Make calculate_integer_scaling static (bsc#1152472)
- commit 0f9635f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: Disable gfx CGPG when suspend smu (bsc#1152472)
- commit ecc800f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/radeon: remove assignment for return value (bsc#1152472)
- commit 7bfce21
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: remove gcc warning Wunused-but-set-variable (bsc#1152472)
- commit cbd0dbe
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: modify the parameters of SMU_MSG_PowerUpVcn to (bsc#1152472)
- commit 30d82c5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: correct current clock level label for Arcturus (bsc#1152472)
- commit 604130f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: skip unsupported clock limit settings on Arcturus (bsc#1152472)
- commit 1533791
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Allow reading more status registers on si/cik (bsc#1152472)
- commit 89efc58
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Move amdgpu_ras_recovery_init to after SMU ready. (bsc#1152472)
- commit 6d900c5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Use ARCTURUS in RAS EEPROM. (bsc#1152472)
- commit ea13681
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: Add EEPROM I2C read/write support to Arcturus. (bsc#1152472)
- commit 8876724
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: Add interface for I2C transactions to SMU. (bsc#1152472)
- commit ac4a27a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Add DC feature mask to disable fractional pwm (bsc#1152472)
- commit ce155b9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove unused parameter in amdgpu_gfx_kiq_free_ring (bsc#1152472)
- commit b0c55ed
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/vcn: Enable VCN2.5 encoding (bsc#1152472)
- commit ebc329a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: define macros for retire page reservation (bsc#1152472)
- commit a342990
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: refine reboot debugfs operation in ras case (v3) (bsc#1152472)
- commit 8d387cc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: don't use dqm lock during device reset/suspend/resume (bsc#1152472)
- commit 1108608
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/display: add dc feature mask for psr enablement (bsc#1152472)
- commit 237246e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: clear the swSMU code layer (bsc#1152472)
- commit 812f414
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: split out those internal used swSMU APIs V2 (bsc#1152472)
- commit 5d7fb89
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: add lock protection for swSMU APIs V2 (bsc#1152472)
- commit d471ef0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add VCN0 and VCN1 needed headers (bsc#1152472)
- commit 9ecaf77
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Apply vactive dram clock change workaround to dcn2 (bsc#1152472)
- commit 78c800a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix hubbub deadline programing (bsc#1152472)
- commit 77aeed2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix avoid_split for dcn2+ validation (bsc#1152472)
- commit 72972a1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Do not call update bounding box on dc create (bsc#1152472)
- commit edd5260
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add center mode for integer scaling in DC (bsc#1152472)
- commit 6c7c23f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: take signal type from link (bsc#1152472)
- commit 57bc0a2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.56 (bsc#1152472)
- commit bb0247f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Make clk mgr the only dto update point (bsc#1152472)
- commit dc2f4f7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Only use EETF when maxCL > max display (bsc#1152472)
- commit 7523d77
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: move wm ranges reporting to end of init hw (bsc#1152472)
- commit fb9b827
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Proper return of result when aux engine acquire (bsc#1152472)
- commit 3224b47
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Disable force_single_disp_pipe_split on DCN2+ (bsc#1152472)
- commit 6ebbdb5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: map TRANSMITTER_UNIPHY_x to LINK_REGS_x (bsc#1152472)
- commit 108835b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add flag to allow diag to force enumerate edp (bsc#1152472)
- commit 0f21d57
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add embedded flag to dml (bsc#1152472)
- commit 3744b2b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix number of dcn21 dpm clock levels (bsc#1152472)
- commit a27a414
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: enable vm by default for rn. (bsc#1152472)
- commit 82fe1f6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Update min dcfclk (bsc#1152472)
- commit 5407592
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: audio endpoint cannot switch (bsc#1152472)
- commit 6c459b2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Fix MPO & pipe split on 3-pipe dcn2x (bsc#1152472)
- commit 1544752
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: remove unnecessary assert (bsc#1152472)
- commit ae840ba
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: move dispclk vco freq to clk mgr base (bsc#1152472)
- commit d2f116c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: correctly initialize dml odm variables (bsc#1152472)
- commit f3e8dfe
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: split dcn20 fast validate into more functions (bsc#1152472)
- commit a6cfb38
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: correctly populate dpp refclk in fpga (bsc#1152472)
- commit 3140d4f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Enable PSR (bsc#1152472)
- commit 2eca43c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add debugfs entry for reading psr state (bsc#1152472)
- commit 74db65e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.55 (bsc#1152472)
- commit 61762e4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: remove unused code (bsc#1152472)
- commit 576325d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Remove superfluous assert (bsc#1152472)
- commit b0b47e8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Don't use optimized gamma22 with eetf (bsc#1152472)
- commit 66e5640
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add unknown clk state. (bsc#1152472)
- commit 4990da1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add odm visual confirm (bsc#1152472)
- commit 6e59da8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Avoid sending abnormal VSIF (bsc#1152472)
- commit cb31b17
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: update Arcturus driver smu interface XGMI link (bsc#1152472)
- commit 98d0031
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/psp: fix spelling mistake "initliaze" -> "initialize" (bsc#1152472)
- commit 16e0871
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Free gamma after calculating legacy transfer (bsc#1152472)
- commit 6395866
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/psp11: fix typo in comment (bsc#1152472)
- commit be87c0b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/psp11: wait for sOS ready for ring creation (bsc#1152472)
- commit 575dc8a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Update DRIVER_DATE to 20191101 (bsc#1152489)
- commit ab74b97
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Start kthreads before stopping (bsc#1152489)
- commit 8e6835c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/lmem: Check against i915_selftest only under CONFIG_SELFTEST (bsc#1152489)
- commit 31ea310
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gem: Refine occupancy test in kill_context() (bsc#1152489)
- commit 9486ae0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Update DRIVER_DATE to 20191101 (bsc#1152489)
- commit d2388fc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/lmem: add the fake lmem region (bsc#1152489)
- commit 2ffb0e0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/guc: drop guc shared area (bsc#1152489)
- commit 06b817b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: drop lrc header page (bsc#1152489)
- commit 1e78f78
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Split detaching and removing the vma (bsc#1152489)
- commit 9badcee
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Pretty print the i915_active (bsc#1152489)
- commit cd5ad90
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Assert that the idle_pulse is sent (bsc#1152489)
- commit 5bae314
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/mst: Document the userspace fail with possible_crtcs (bsc#1152489)
- commit 937847c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Simplify pipe_mask setup even further (bsc#1152489)
- commit d648d5b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Allow ICL+ DSI on any pipe (bsc#1152489)
- commit 010f6f1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: s/crtc_mask/pipe_mask/ (bsc#1152489)
- commit 50fa397
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Simplify LVDS crtc_mask setup (bsc#1152489)
- commit 122e9b4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/uc: define GuC and HuC binaries for TGL (bsc#1152489)
- commit 4b87e1b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Stop frobbing crtc->base.mode (bsc#1152489)
- commit ce4f8c3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Nuke 'mode' argument to intel_get_load_detect_pipe() (bsc#1152489)
- commit 91efbb2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Always track callers to intel_rps_mark_interactive() (bsc#1152489)
- commit 2d4f628
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add gam instdone (bsc#1152489)
- commit 85b7cde
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add SFC instdone to error state (bsc#1152489)
- commit 6e133ed
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: add support to one DP-MST stream (bsc#1152489)
- commit 4005615
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gem: Make context persistence optional (bsc#1152489)
- commit 67d8cc0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Provide more information on DP AUX failures (bsc#1152489)
- commit bf99002
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display/cnl+: Handle fused off DSC (bsc#1152489)
- commit 2fbe292
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display/icl+: Check if DMC is fused off (bsc#1152489)
- commit 24879ca
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Check if FBC is fused off (bsc#1152489)
- commit f268768
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Handle fused off HDCP (bsc#1152489)
- commit 7740eee
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add two spaces before the SKL_DFSM registers (bsc#1152489)
- commit af88624
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: ensure selftests select valid format (bsc#1152489)
- commit 22b53f6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add AUX B & C to DC_OFF_POWER_DOMAINS (bsc#1152489)
- commit 17d6168
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Drop unused AUX register offsets (bsc#1152489)
- commit 76cb1ff
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Make timeslice duration configurable (bsc#1152489)
- commit 6da745c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Rename "inject_load_failure" module parameter (bsc#1152489)
- commit 0111708
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix i915_inject_load_error() name to read *_probe_* (bsc#1152489)
- commit eb305c5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix i845/i865 cursor width (bsc#1152489)
- commit f79ec16
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add perf support on TGL (bsc#1152489)
- commit 82d4f40
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: Add helper macros for comparing with whitelisted (bsc#1152489)
- commit c180313
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: check for missing aperture (bsc#1152489)
- commit d086558
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: don't allocate the ring in stolen if we lack aperture (bsc#1152489)
- commit 739142e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Don't try to place HWS in non-existing mappable region (bsc#1152489)
- commit b8c745b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: error capture with no ggtt slot (bsc#1152489)
- commit 4d40840
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: set num_fence_regs to 0 if there is no aperture (bsc#1152489)
- commit 1cd8efa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: do not map aperture if it is not available. (bsc#1152489)
- commit 1c71246
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: define i915_ggtt_has_aperture (bsc#1152489)
- commit ee3e7bd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/blt: fixup block_size rounding (bsc#1152489)
- commit cd30763
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gem: Limit the blitter sizes to ensure low preemption (bsc#1152489)
- commit a8799fd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Use vfunc to check engine submission mode (bsc#1152489)
- commit c71f545
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Mark conn as initialised by iterator (bsc#1152489)
- commit 2641ec4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Initialise ret (bsc#1152489)
- commit 97476e5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Initialise err in case there are no engines! (bsc#1152489)
- commit 465f726
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Simply walk back along request timeline on reset (bsc#1152489)
- commit 77f67fb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Check a few more fixed locations within the (bsc#1152489)
- commit 701d935
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Handle AUX interrupts for TC ports (bsc#1152489)
- commit 42350a3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Exercise adjusting rpcs over all render-class (bsc#1152489)
- commit e586d72
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Select a random engine for testing memory regions (bsc#1152489)
- commit 7e65c10
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Tidy up rps irq handler to use intel_gt (bsc#1152489)
- commit 7e5841d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Use a random engine for GEM coherency tests (bsc#1152489)
- commit 17f19e4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/bios: add compression parameter block definition (bsc#1152489)
- commit 54a40fd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Check all blitter engines for client blt (bsc#1152489)
- commit f40a131
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Drop global engine lookup for gt selftests (bsc#1152489)
- commit a990182
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Measure basic throughput of blit routines (bsc#1152489)
- commit fe48a00
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add CHICKEN_TRANS_D (bsc#1152489)
- commit 949a886
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use _PICK() for CHICKEN_TRANS() (bsc#1152489)
- commit 59b4cc2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/rps: Flip interpretation of ips fmin/fmax to max rps (bsc#1152489)
- commit aeb05d6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Put future HW and their uAPIs under STAGING & BROKEN (bsc#1152489)
- commit badb683
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Split memory_region initialisation into its own file (bsc#1152489)
- commit 05209e3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Extract the GuC interrupt handlers (bsc#1152489)
- commit 9b0807e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Extract GT render power state management (bsc#1152489)
- commit 98147b5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Adjust the location of RING_MI_MODE in the context (bsc#1152489)
- commit d8c55b0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Encapsulate kconfig constant values inside boolean (bsc#1152489)
- commit 6a0d10a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tc: Clear DKL_TX_PMD_LANE_SUS before program voltage swing (bsc#1152489)
- commit 84cc5d0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/pmu: Initialise the spinlock before registering (bsc#1152489)
- commit cfd9e64
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests/blt: add some kthreads into the mix (bsc#1152489)
- commit f3c5589
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: add sanity selftest for huge-GTT-pages (bsc#1152489)
- commit d7be8bf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: prefer random sizes for the huge-GTT-page smoke (bsc#1152489)
- commit 7e2ddda
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: extend coverage to include LMEM huge-pages (bsc#1152489)
- commit f399eee
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: add write-dword test for LMEM (bsc#1152489)
- commit cd5da90
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/lmem: support kernel mapping (bsc#1152489)
- commit 301edcb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: setup io-mapping for LMEM (bsc#1152489)
- commit a3510de
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: support creating LMEM objects (bsc#1152489)
- commit ce4743c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: split gen11_irq_handler to make it shareable (bsc#1152489)
- commit abfd928
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: do not set MOCS control values on dgfx (bsc#1152489)
- commit d8cb554
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: add new gen12 dgfx platform macro (bsc#1152489)
- commit 83a6ec2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add is_dgfx to device info (bsc#1152489)
- commit db0a5fc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: capture aux page table error register (bsc#1152489)
- commit abbb9c9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Force ordering of context switches (bsc#1152489)
- commit b5ff3b0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Move intel_engine_context_in/out into intel_lrc.c (bsc#1152489)
- commit e3b2db0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Describe structure member in documentation (bsc#1152489)
- commit 31f94b5
* Sat Oct 10 2020 tzimmermann@suse.de
- doc: Update header files names (bsc#1152489)
- commit ffaa81c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Tweak the default subtest runtime (bsc#1152489)
- commit 91d088d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display/psr: Print in debugfs if PSR is not enabled because (bsc#1152489)
- commit 9b197a6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Catch GTT fault errors for gen11+ planes (bsc#1152489)
- commit 3ece7ad
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: whitelist PS_(DEPTH|INVOCATION)_COUNT (bsc#1152489)
- commit 90acf58
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove nonpriv flags when srm/lrm (bsc#1152489)
- commit ed9df46
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Making loglevel of PSR2/SU logs same. (bsc#1152489)
- commit 29ef9b3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add support for half float framebuffers on snb sprites (bsc#1152489)
- commit 6cfd33c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add support for half float framebuffers for ivb+ sprites (bsc#1152489)
- commit 1894d66
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add support for half float framebuffers for gen4+ primary (bsc#1152489)
- commit 11da090
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add support for half float framebuffers for skl+ (bsc#1152489)
- commit 2ada91b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Simplify skl_max_scale() (bsc#1152489)
- commit d6f6a16
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Eliminate skl_check_pipe_max_pixel_rate() (bsc#1152489)
- commit 0a7192b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Allow planes to declare their minimum acceptable cdclk (bsc#1152489)
- commit 3839ae0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Move check_digital_port_conflicts() earier (bsc#1152489)
- commit df9d17a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Rework global state locking (bsc#1152489)
- commit f09abd6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add debugs to distingiush a cd2x update from a full cdclk (bsc#1152489)
- commit d93782a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: Describe structure members in documentation (bsc#1152489)
- commit 72737ac
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Split intel_ring_submission (bsc#1152489)
- commit eb134eb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Convert PAT setup to uncore mmio (bsc#1152489)
- commit a2a1304
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Flush any i915_active callback work as well (bsc#1152489)
- commit 99da890
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Flush interrupts before disabling tasklets (bsc#1152489)
- commit 4a593f5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gvt: fix dead locking in early workload shadow (bsc#1152489)
- commit 15d5710
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Replace hangcheck by heartbeats (bsc#1152489)
- commit f74a4da
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gem: Cancel contexts when hangchecking is disabled (bsc#1152489)
- commit 31a1332
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Cancel banned contexts on schedule-out (bsc#1152489)
- commit 7d06917
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Force preemption (bsc#1152489)
- commit f34e7d3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Try to more gracefully quiesce the system before resets (bsc#1152489)
- commit fc61d1f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/guc: Update H2G enable logging action definition (bsc#1152489)
- commit 73009c5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/guc: Enable guc logging on guc log relay write (bsc#1152489)
- commit 7a6c42c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add new CNL PCH ID seen on a CML platform (bsc#1152489)
- commit 66d98fc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dsc: move crtc state dp_dsc_cfg member under dsc as config (bsc#1152489)
- commit ad5a14d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dsc: rename crtc state dsc_params member to dsc (bsc#1152489)
- commit 6ebdaf2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Release ctx->engine_mutex after iteration (bsc#1152489)
- commit 4d43509
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Synchronize checking active status with (bsc#1152489)
- commit 7fc90f5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Move uncore fw selftests to operate on intel_gt (bsc#1152489)
- commit 2ba69aa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Teach switch_to_context() to use the context (bsc#1152489)
- commit 7b3c901
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Teach record_defaults to operate on the intel_gt (bsc#1152489)
- commit d9cf815
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gem: Distinguish each object type (bsc#1152489)
- commit f397048
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/aml: Allow SPT PCH for all AML devices (bsc#1152489)
- commit 92d0005
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Drop assertion that ce->pin_mutex guards state updates (bsc#1152489)
- commit 95c7049
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Make the mman object busy everywhere (bsc#1152489)
- commit d3b003e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Use for_each_uabi_engine in contex selftests (bsc#1152489)
- commit feae0ec
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Use GT engines in igt_live_test (bsc#1152489)
- commit eba574f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Use GT engines in mock_gem_device (bsc#1152489)
- commit 01b6017
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Convert eviction selftests to gt/ggtt (bsc#1152489)
- commit 66a2344
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Split drop caches into GT and i915 parts (bsc#1152489)
- commit 18d7b67
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Pass intel_gt to intel_engines_verify_workarounds (bsc#1152489)
- commit aab8453
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Pass intel_gt to intel_engines_init (bsc#1152489)
- commit f5853a3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Pass intel_gt to intel_engines_setup (bsc#1152489)
- commit 126d8e0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Pass intel_gt to intel_engines_cleanup (bsc#1152489)
- commit 37bca3b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Pass intel_gt to intel_setup_engine_capabilities (bsc#1152489)
- commit 8aafa93
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Pass intel_gt to intel_engines_init_mmio (bsc#1152489)
- commit 6728f48
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Set vm->gt backpointer for mock_ppgtt (bsc#1152489)
- commit e775712
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove pm park/unpark notifications (bsc#1152489)
- commit 988af38
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Lift i915_vma_parked() onto the gt (bsc#1152489)
- commit 77d0953
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Introduce barrier pulses along engines (bsc#1152489)
- commit 38cd44f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Use all physical engines for i915_active (bsc#1152489)
- commit e61bf4d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Check some transcoder timing minimum limits (bsc#1152489)
- commit ea02504
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Don't set queue_priority_hint if we don't kick the (bsc#1152489)
- commit e1f61b0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Unconditionally select IOMMU_IOVA (bsc#1152472)
- commit a73cdc7
* Sat Oct 10 2020 tzimmermann@suse.de
- gpu: host1x: Unconditionally select IOMMU_IOVA (bsc#1152472)
- commit c88c30e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Optionally attach clients to the IOMMU (bsc#1152472)
- commit 73c6377
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Support DMA API for display controllers (bsc#1152472)
- commit 0e86b26
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: falcon: Clarify address usage (bsc#1152472)
- commit 24b5c84
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Remove memory allocation from Falcon library (bsc#1152472)
- commit 40af554
* Sat Oct 10 2020 tzimmermann@suse.de
- gpu: host1x: Set DMA mask based on IOMMU setup (bsc#1152472)
- commit e8072b0
* Sat Oct 10 2020 tzimmermann@suse.de
- gpu: host1x: Support DMA mapping of buffers (bsc#1152472)
- commit b93bd14
* Sat Oct 10 2020 tzimmermann@suse.de
- gpu: host1x: Allocate gather copy for host1x (bsc#1152472)
- commit 9d0c5d7
* Sat Oct 10 2020 tzimmermann@suse.de
- gpu: host1x: Add direction flags to relocations (bsc#1152472)
- commit 74881db
* Sat Oct 10 2020 tzimmermann@suse.de
- gpu: host1x: Clean up debugfs on removal (bsc#1152472)
- commit ae6653f
* Sat Oct 10 2020 tzimmermann@suse.de
- gpu: host1x: Overhaul host1x_bo_{pin,unpin}() API (bsc#1152472)
- commit 7e2d7de
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Simplify IOMMU group selection (bsc#1152472)
- commit 3a671aa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Do not use ->load() and ->unload() callbacks (bsc#1152472)
- commit ec21350
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Introduce audio enable/disable callbacks (bsc#1152472)
- commit 83c925d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Extract common audio enabling code (bsc#1152472)
- commit c2cf210
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Avoid timeouts on unplug events (bsc#1152472)
- commit bf3b3df
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Unify eDP and DP support (bsc#1152472)
- commit e7c2360
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Use correct I/O pad for DP (bsc#1152472)
- commit 0d6384e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Unify clock setup for eDP, HDMI and DP (bsc#1152472)
- commit ae0cb55
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Support DisplayPort on Tegra194 (bsc#1152472)
- commit 95676fb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Deduplicate connector type detection code (bsc#1152472)
- commit 46b909f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Implement pad clock for all SOR instances (bsc#1152472)
- commit 413caf6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Use correct SOR index on Tegra210 (bsc#1152472)
- commit 0e5e1ea
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Remove tegra186-sor1 support (bsc#1152472)
- commit f432088
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Add DisplayPort support (bsc#1152472)
- commit 9b51056
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Filter eDP rates (bsc#1152472)
- commit a5dd5d4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Stabilize eDP (bsc#1152472)
- commit e7599c7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Hook up I2C-over-AUX to output (bsc#1152472)
- commit a74f8fd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Use DP link training helpers (bsc#1152472)
- commit f717843
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Add DisplayPort link training helper (bsc#1152472)
- commit 12bb94f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Add support for eDP link rates (bsc#1152472)
- commit 543d01e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Add drm_dp_link_choose() helper (bsc#1152472)
- commit d571185
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Enable alternate scrambler reset when supported (bsc#1152472)
- commit 983c624
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Set channel coding on link configuration (bsc#1152472)
- commit 8718ced
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Read AUX read interval from DPCD (bsc#1152472)
- commit f90196d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Read eDP version from DPCD (bsc#1152472)
- commit 8f64bbc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Read alternate scrambler reset capability from sink (bsc#1152472)
- commit 33ff344
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Read channel coding capability from sink (bsc#1152472)
- commit 8ba8a32
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Read TPS3 capability from sink (bsc#1152472)
- commit 3be1d63
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Read fast training capability from link (bsc#1152472)
- commit 3129bd4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Probe link using existing parsing helpers (bsc#1152472)
- commit 46bef9b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Turn link capabilities into booleans (bsc#1152472)
- commit f367a07
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Track link capabilities alongside settings (bsc#1152472)
- commit fffdb36
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dp: Add drm_dp_link_reset() implementation (bsc#1152472)
- commit ec5b7f9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Add missing kerneldoc for struct drm_dp_link (bsc#1152472)
- commit e220b7e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dpaux: Parameterize CMH, DRVZ and DRVI (bsc#1152472)
- commit 35c6f68
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dpaux: Fix crash if VDD supply is absent (bsc#1152472)
- commit c2d9024
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dpaux: Retry on transfer size mismatch (bsc#1152472)
- commit 9dc1191
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: dpaux: Support monitor hotplugging (bsc#1152472)
- commit 3affd30
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: gem: Use sg_alloc_table_from_pages() (bsc#1152472)
- commit c9473f1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: gem: Always map SG tables for DMA-BUFs (bsc#1152472)
- commit b23785e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: gem: Use dma_get_sgtable() (bsc#1152472)
- commit be212b0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: gem: Rename paddr -> iova (bsc#1152472)
- commit 2c085c7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Move IOMMU group into host1x client (bsc#1152472)
- commit 4212ea5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: vic: Use common IOMMU attach/detach code (bsc#1152472)
- commit a77b4fc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: vic: Inherit DMA mask from host1x (bsc#1152472)
- commit 1edc941
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: vic: Skip stream ID programming without IOMMU (bsc#1152472)
- commit 3dc1230
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Use DRM_DEBUG_DRIVER for driver messages (bsc#1152472)
- commit 723086e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Inherit device DMA parameters from host1x (bsc#1152472)
- commit 0650d58
* Sat Oct 10 2020 tzimmermann@suse.de
- gpu: host1x: Make host1x_cdma_wait_pushbuffer_space() static (bsc#1152472)
- commit 7c10529
* Sat Oct 10 2020 tzimmermann@suse.de
- gpu: host1x: Request channels for clients, not devices (bsc#1152472)
- commit 71392d0
* Sat Oct 10 2020 tzimmermann@suse.de
- gpu: host1x: Explicitly initialize host1x_info structures (bsc#1152472)
- commit 981ceaf
* Sat Oct 10 2020 tzimmermann@suse.de
- gpu: host1x: Remove gratuitous blank line (bsc#1152472)
- commit bc70c26
* Sat Oct 10 2020 tzimmermann@suse.de
- gpu: host1x: Do not limit DMA segment size (bsc#1152472)
- commit fcf2a9d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Use cec_notifier_conn_(un)register() (bsc#1152472)
- commit 0fcf032
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Fix ordering of cleanup code (bsc#1152472)
- commit 30d89a6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: sor: Move register programming out of ->init() (bsc#1152472)
- commit e72f003
* Sat Oct 10 2020 tzimmermann@suse.de
- Revert "dma-buf: Add dma-buf heaps framework" (bsc#1152472)
- commit ce0fef2
* Sat Oct 10 2020 tzimmermann@suse.de
- Revert "dma-buf: heaps: Add heap helpers" (bsc#1152472)
- commit 8db7f15
* Sat Oct 10 2020 tzimmermann@suse.de
- Revert "dma-buf: heaps: Add system heap to dmabuf heaps" (bsc#1152472)
- commit 4920f23
* Sat Oct 10 2020 tzimmermann@suse.de
- Revert "dma-buf: heaps: Add CMA heap to dmabuf heaps" (bsc#1152472)
- commit d1daba4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/gem: Fix mmap fake offset handling for drm_gem_object_funcs.mmap (bsc#1152472)
- commit 1557fee
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panfrost: Simplify devfreq utilisation tracking (bsc#1152472)
- commit f68a5aa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panfrost: Use generic code for devfreq (bsc#1152472)
- commit ef82b7a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vboxvideo: Use drm_gem_fb_create_with_dirty instead of (bsc#1152472)
- commit 09d5da9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add independent DMA-buf import v9 (bsc#1152472)
- commit 127752c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add independent DMA-buf export v8 (bsc#1152472)
- commit 78e2db2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/todo: Clarify situation around fbdev and defio (bsc#1152472)
- commit 28a44ce
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/fb-helper: Remove drm_fb_helper_defio_init() and update docs (bsc#1152472)
- commit cf917a4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Don't free jobs in wait_event_interruptible() (bsc#1152472)
- commit dc5d7c7
* Sat Oct 10 2020 tzimmermann@suse.de
- dma-buf: heaps: Add CMA heap to dmabuf heaps (bsc#1152472)
- commit b758cf3
* Sat Oct 10 2020 tzimmermann@suse.de
- dma-buf: heaps: Add system heap to dmabuf heaps (bsc#1152472)
- commit c3cf897
* Sat Oct 10 2020 tzimmermann@suse.de
- dma-buf: heaps: Add heap helpers (bsc#1152472)
- commit e7bb7de
* Sat Oct 10 2020 tzimmermann@suse.de
- dma-buf: Add dma-buf heaps framework (bsc#1152472)
- commit 79549b0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: stop exporting ttm_mem_io_* functions (bsc#1152472)
- commit 9ca4531
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/qxl: stop using TTM to call driver internal functions (bsc#1152472)
- commit 72cab75
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: use the parent resv for ghost objects v3 (bsc#1152472)
- commit f89fe2a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: remove pointers to globals (bsc#1152472)
- commit 9596f7d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: always keep BOs on the LRU (bsc#1152472)
- commit 1f27a2e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm, drm/vmwgfx: move cpu_writers handling into vmwgfx (bsc#1152472)
- commit c690ca8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/gpu: Fix Memory barrier without comment Issue (bsc#1152472)
- commit c842f5e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/gpu: Fix Missing blank line after declarations (bsc#1152472)
- commit 7fab77b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Spelling s/connet/connect/ (bsc#1152472)
- commit 1ba4666
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vboxvideo: Replace prepare_fb()/cleanup_fb() with GEM VRAM (bsc#1152472)
- commit c3b487c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/hisilicon/hibmc: Use GEM VRAM's prepare_fb() and cleanup_fb() (bsc#1152472)
- commit 6cc72dd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bochs: Replace prepare_fb()/cleanup_fb() with GEM VRAM helpers (bsc#1152472)
- commit 7dc9120
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram-helpers: Add helpers for prepare_fb() and cleanup_fb() (bsc#1152472)
- commit 29ed01c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/gpu: Add comment for memory barrier (bsc#1152472)
- commit 2765485
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: remove cast to pointers passed to kfree (bsc#1152472)
- commit 1b04f5a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/simple-kms: Standardize arguments for callbacks (bsc#1152472)
- commit edad8ce
* Sat Oct 10 2020 tzimmermann@suse.de
- dma-buf: stop using the dmabuf->lock so much v2 (bsc#1152472)
- commit d29eed8
* Sat Oct 10 2020 tzimmermann@suse.de
- dma-buf: change DMA-buf locking convention v3 (bsc#1152472)
- commit e5bf569
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Add topology ref history tracking for debugging (bsc#1152489)
- commit 850d8a7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Add basic topology reprobing when resuming (bsc#1152489)
- commit 3c274a9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/nouveau: Resume hotplug interrupts earlier (bsc#1152489)
- commit 4aade5d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/nouveau: Don't grab runtime PM refs for HPD IRQs (bsc#1152489)
- commit 1856ba3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Lessen indenting in drm_dp_mst_topology_mgr_resume() (bsc#1152489)
- commit 6304515
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Don't forget to update port->input in (bsc#1152489)
- commit 94d4585
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Protect drm_dp_mst_port members with locking (bsc#1152489)
- commit ffe0098
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Add probe_lock (bsc#1152489)
- commit 0c3e0ef
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Handle UP requests asynchronously (bsc#1152489)
- commit bb19104
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Refactor pdt setup/teardown, add more locking (bsc#1152489)
- commit e092ba2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Remove PDT teardown in drm_dp_destroy_port() and refactor (bsc#1152489)
- commit 141d01f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Destroy MSTBs asynchronously (bsc#1152489)
- commit 7f1e92b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/exynos: Move static keyword to the front of declaration (bsc#1152472)
- commit 126ec42
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tegra: Move drm_dp_link helpers to Tegra DRM (bsc#1152472)
- commit 33601f6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/rockchip: Avoid drm_dp_link helpers (bsc#1152472)
- commit 8c89b4e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm: edp: Avoid drm_dp_link helpers (bsc#1152472)
- commit 392b329
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Use DP nomenclature (bsc#1152472)
- commit 8fc5ee5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Avoid drm_dp_link helpers (bsc#1152472)
- commit f0b9bb9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: analogix-anx78xx: Avoid drm_dp_link helpers (bsc#1152472)
- commit de9f244
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp: Add helper to get post-cursor adjustments (bsc#1152472)
- commit 5480315
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp: Do not busy-loop during link training (bsc#1152472)
- commit 5e05f04
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp: Add drm_dp_alternate_scrambler_reset_cap() helper (bsc#1152472)
- commit 7f8cdd3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp: Add drm_dp_channel_coding_supported() helper (bsc#1152472)
- commit 7a3bbd2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp: Add drm_dp_fast_training_cap() helper (bsc#1152472)
- commit 85f0306
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp: Remove a gratuituous blank line (bsc#1152472)
- commit 419d2a4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp: Sort includes alphabetically (bsc#1152472)
- commit 5aeaa4f
* Sat Oct 10 2020 tzimmermann@suse.de
- Revert "drm/omap: add OMAP_BO flags to affect buffer allocation" (bsc#1152472)
- commit e77a394
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/todo: Add levels (bsc#1152472)
- commit f860056
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/todo: Remove i915 device_link task (bsc#1152472)
- commit 7f11685
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/doc: Drop misleading comment on drm_mode_config_cleanup (bsc#1152472)
- commit 0708ec6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vc4: Use drm_hdmi_avi_infoframe_bars() (bsc#1152489)
- commit 3bde472
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/edid: Add drm_hdmi_avi_infoframe_bars() (bsc#1152489)
- commit eac9c06
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mipi_dbi: Use simple right shift instead of double negation (bsc#1152489)
- commit d51b37c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: move byteorder handling into (bsc#1152489)
- commit 5376ab9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: print a single line with device features (bsc#1152489)
- commit 7cfcbc6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/qxl: allocate small objects top-down (bsc#1152489)
- commit d3ffa6a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/qxl: use DEFINE_DRM_GEM_FOPS() (bsc#1152489)
- commit 3860969
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/qxl: drop verify_access (bsc#1152489)
- commit 4407c14
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/qxl: switch qxl to &drm_gem_object_funcs.mmap (bsc#1152489)
- commit d5e9718
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/qxl: drop qxl_ttm_fault (bsc#1152489)
- commit 129af52
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: remove unnecessary return variable (bsc#1152489)
- commit 82d8e1d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/gma500: fix memory disclosures due to uninitialized bytes (bsc#1152489)
- commit 57e322b
* Sat Oct 10 2020 tzimmermann@suse.de
- gma/gma500: fix a memory disclosure bug due to uninitialized bytes (bsc#1152489)
- commit 4e5aa97
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: Dump SC_ENH_* registers from scaler block (bsc#1152489)
- commit 6aab038
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: tda998x: use cec_notifier_conn_(un)register (bsc#1152489)
- commit d6360d8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/edid: Fix HDMI VIC handling (bsc#1152489)
- commit a5be939
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/edid: Extract drm_mode_cea_vic() (bsc#1152489)
- commit aa057cb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/edid: Make drm_get_cea_aspect_ratio() static (bsc#1152489)
- commit 7499b09
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/fourcc: Fix undefined left shift in DRM_FORMAT_BIG_ENDIAN macros (bsc#1152489)
- commit 9aefdf9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/syncobj: extend syncobj query ability v3 (bsc#1152489)
- commit 1d768dd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/arm: make undeclared items static (bsc#1152489)
- commit 5ef8c91
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/lima: add __GFP_NOWARN flag to all dma_alloc_wc (bsc#1152472)
- commit 594fe81
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/lima: use drm_gem_(un)lock_reservations (bsc#1152472)
- commit 41f4943
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/lima: use drm_gem_shmem_helpers (bsc#1152472)
- commit 07dbd19
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/qxl: Fix randbuild error (bsc#1152472)
- commit 2cfa7b3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/cirrus: Remove obsolete header file (bsc#1152472)
- commit afdbf07
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: drop DRM_VRAM_MM_FILE_OPERATIONS (bsc#1152472)
- commit 5903b12
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: drop verify_access (bsc#1152472)
- commit f2ea453
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: switch vram helper to &drm_gem_object_funcs.mmap() (bsc#1152472)
- commit bf71778
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: add drm_gem_ttm_mmap() (bsc#1152472)
- commit bf0b34e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: rename ttm_fbdev_mmap (bsc#1152472)
- commit 20d0821
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: factor out ttm_bo_mmap_vma_setup (bsc#1152472)
- commit 0b5610f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/shmem: drop DEFINE_DRM_GEM_SHMEM_FOPS (bsc#1152472)
- commit e697ee7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/shmem: drop VM_IO (bsc#1152472)
- commit cf7ebc2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/shmem: drop VM_DONTDUMP (bsc#1152472)
- commit d46d2c1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/shmem: switch shmem helper to &drm_gem_object_funcs.mmap (bsc#1152472)
- commit 324f364
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: add mmap() to drm_gem_object_funcs (bsc#1152472)
- commit b408a1a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Add TODO item for fbdev driver conversion (bsc#1152472)
- commit 367172c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i810: Refer to `PREEMPTION' in comment (bsc#1152472)
- commit 3e18f28
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: Adds output-color format support (bsc#1152472)
- commit 9009459
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: Set output color depth for output (bsc#1152472)
- commit a4bce72
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: Adds layer horizontal input size limitation check for D71 (bsc#1152472)
- commit 4bda719
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: Add line size support (bsc#1152472)
- commit 0241aed
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vboxvideo: Replace struct vram_framebuffer with generic (bsc#1152472)
- commit 5c705ec
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vboxvideo: Switch to drm_atomic_helper_dirty_fb() (bsc#1152472)
- commit 9de63bf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vboxvideo: Switch to generic fbdev emulation (bsc#1152472)
- commit a499eb7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Add LT-tunable PHY repeater mode operations (bsc#1152472)
- commit e2264fc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi: Restore audio when setting a mode (bsc#1152472)
- commit d2853aa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mxsfb: Read bus flags from bridge if present (bsc#1152489)
- commit e023cca
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mxsfb: Update mxsfb to support a bridge (bsc#1152489)
- commit b592bc6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp-mst: fix warning on unused var (bsc#1152489)
- commit 14c3b09
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: Remove set but not used variable 'err' in (bsc#1152489)
- commit 9a59c75
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: Remove set but not used variable 'err' in (bsc#1152489)
- commit d09d8d8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: Remove set but not used variable 'tclk_trail' (bsc#1152489)
- commit 187890e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: Remove set but not used variable 'plane' (bsc#1152489)
- commit a827858
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/rockchip: vop: add the definition of dclk_pol (bsc#1152489)
- commit 1202abd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/rockchip: make rockchip_gem_alloc_object static (bsc#1152489)
- commit 998c376
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/rockchip: include rockchip_drm_drv.h (bsc#1152489)
- commit b30106b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/rockchip: rk3066_hdmi: Use devm_platform_ioremap_resource() in (bsc#1152489)
- commit 006e84b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/atmel-hlcdc: Use swap() where appropriate (bsc#1152489)
- commit d018c50
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: add OMAP_BO flags to affect buffer allocation (bsc#1152489)
- commit c732ae9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: add omap_gem_validate_flags() (bsc#1152489)
- commit 227dc00
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: cleanup OMAP_BO_SCANOUT use (bsc#1152489)
- commit 35bf4f7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: remove OMAP_BO_TILED define (bsc#1152489)
- commit 3bf5cc4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: cleanup OMAP_BO flags (bsc#1152489)
- commit 730659b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: accept NULL for dma_addr in omap_gem_pin (bsc#1152489)
- commit f087045
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: add omap_gem_unpin_locked() (bsc#1152489)
- commit 69a06d0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: use refcount API to track the number of users of dma_addr (bsc#1152489)
- commit 56aa18c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/rockchip: Add optional support for CRTC gamma LUT (bsc#1152489)
- commit 4c43bc9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/scheduler: make unexported items static (bsc#1152489)
- commit d009c4f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/plane: Clarify our expectations for src/dst rectangles (bsc#1152489)
- commit 3dc4245
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vkms: Remove duplicated include from vkms_drv.c (bsc#1152489)
- commit 265e111
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp-mst: Drop connection_mutex check (bsc#1152489)
- commit dd28de1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sun4i: Enable DRM InfoFrame support on H6 (bsc#1152489)
- commit 03f3e06
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/meson: Enable DRM InfoFrame support on GXL, GXM and G12A (bsc#1152489)
- commit e9bfb6e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/rockchip: Enable DRM InfoFrame support on RK3328 and RK3399 (bsc#1152489)
- commit 6c47e71
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi: Add Dynamic Range and Mastering InfoFrame (bsc#1152489)
- commit e42fc4e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: analogix-anx78xx: add support for 7808 addresses (bsc#1152489)
- commit 8a8bec5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: sil_sii8620: make remote control optional. (bsc#1152489)
- commit d11a3fe
* Sat Oct 10 2020 tzimmermann@suse.de
- gpu: drm: bridge: sii9234: convert to devm_i2c_new_dummy_device (bsc#1152489)
- commit 19984d9
* Sat Oct 10 2020 tzimmermann@suse.de
- Documentation: Fix warning in drm-kms-helpers.rst (bsc#1152489)
- commit 572be11
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/rockchip: Round up _before_ giving to the clock framework (bsc#1152489)
- commit c163fa9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panfrost: Remove commented out call to panfrost_core_dump (bsc#1152489)
- commit 61dbdb3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: two planes with the same zpos have undefined ordering (bsc#1152489)
- commit 420e11d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vkms: Fix an undefined reference error in vkms_composer_worker (bsc#1152489)
- commit 253a3c6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/edid: Select DMT timing if EDID's display feature not support GTF (bsc#1152489)
- commit fdc8dad
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: remove redundant assignment to pointer disable_done (bsc#1152489)
- commit f05a472
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vkms: prime import support (bsc#1152489)
- commit 4fb71ab
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/drm_vblank: Change EINVAL by the correct errno (bsc#1152489)
- commit 28b1c04
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Add link training repeaters addresses (bsc#1152489)
- commit 4c1d1f8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: delete drmP.h + drm_os_linux.h (bsc#1152489)
- commit 5275bee
* Sat Oct 10 2020 tzimmermann@suse.de
- drm_dp_cec: drop use of drmP.h (bsc#1152489)
- commit 2f2839a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/arm/mali-dp: Add display QoS interface configuration for Mali (bsc#1152489)
- commit f746147
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: use local renoir array sizes for clock fetching (bsc#1152472)
- commit 261c6e0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: call amdgpu_vm_prt_fini before deleting the root PD (bsc#1152472)
- commit 4ec7e6a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/vi: silence an uninitialized variable warning (bsc#1152472)
- commit 608d027
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/vce: make some functions static (bsc#1152472)
- commit 78d065e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/psp: declare PSP TA firmware (bsc#1152472)
- commit 540469f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix amdgpu trace event print string format error (bsc#1152489)
- commit f2f696e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/psp: add psp memory training implementation(v3) (bsc#1152489)
- commit e5cbff2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: reserve vram for memory training(v4) (bsc#1152489)
- commit 2b99fc5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add psp memory training callbacks and macro (bsc#1152489)
- commit 42fe4f6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/atomfirmware: add memory training related helper (bsc#1152489)
- commit a17c380
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: update atomfirmware header with memory training related (bsc#1152489)
- commit 9a47d97
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: introduce psp_v11_0_is_sos_alive interface(v2) (bsc#1152489)
- commit b047db7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add a generic fb accessing helper function(v3) (bsc#1152489)
- commit f627772
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: update amdgpu_discovery to handle revision (bsc#1152489)
- commit f75b649
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: implement interface pp_power_profile_mode (bsc#1152489)
- commit 5ecb752
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/display: fix build when CONFIG_DRM_AMD_DC_DSC_SUPPORT=n (bsc#1152489)
- commit 3aa7077
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Make dc_link_detect_helper static (bsc#1152489)
- commit 3ce56b8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: null check pp_smu clock table before using it (bsc#1152489)
- commit 1f0641f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: handle dp is usb-c (bsc#1152489)
- commit f2f6d18
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: use requested_dispclk_khz instead of clk (bsc#1152489)
- commit ba20c36
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: enable smu set dcfclk (bsc#1152489)
- commit 3f30bad
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix header for RN clk mgr (bsc#1152489)
- commit 5331a95
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add sanity check for clk table from smu (bsc#1152489)
- commit df0f692
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Fix rn audio playback and video playback speed (bsc#1152489)
- commit c93c90c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: handle "18" case in TruncToValidBPP (bsc#1152489)
- commit 58ae513
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: update odm mode validation to be in line with policy (bsc#1152489)
- commit 2ed2a68
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add dummy functions to smu for Renoir Silicon Diags (bsc#1152489)
- commit 37c89ff
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: change PP_SM defs to 8 (bsc#1152489)
- commit d4f1ce2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: update renoir bounding box and res_caps (bsc#1152489)
- commit 2864034
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: update dcn21 hubbub registers (bsc#1152489)
- commit b3a9dab
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add detile buffer size for renoir (bsc#1152489)
- commit 3676eae
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: correct dcn21 NUM_VMID to 16 (bsc#1152489)
- commit 11584e2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: use dcn10 version of program tiling on Renoir (bsc#1152489)
- commit ad3ce58
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: initialize RN gpuvm context programming function (bsc#1152489)
- commit 7879e27
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Temporary workaround to toggle watermark setting (bsc#1152489)
- commit 75814c9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix incorrect page table address for renoir (bsc#1152489)
- commit a2dac36
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: enable hostvm based on roimmu active for dcn2.1 (bsc#1152489)
- commit 562a912
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: move the bounding box patch before calculate wm (bsc#1152489)
- commit 52467a1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add REFCYC_PER_TRIP_TO_MEMORY programming (bsc#1152489)
- commit 5397343
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: create dcn21_link_encoder files (bsc#1152489)
- commit a671d5f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add renoir hw_seq (bsc#1152489)
- commit b81dfb9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add DCN_BASE regs (bsc#1152489)
- commit 317cf33
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add DP_DPHY_INTERNAL_CTR regs (bsc#1152489)
- commit 599f8b4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: disable ext aux support for vega (bsc#1152489)
- commit 04a375a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: configurable aux timeout support (bsc#1152489)
- commit 909d5ed
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: update register field access mechanism (bsc#1152489)
- commit ef5a136
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: No need to check gfxoff status after enable gfxoff (bsc#1152489)
- commit 18535b7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: bug fix for memory clock request from display (bsc#1152489)
- commit 6933eac
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix S3 failed as RLC safe mode entry stucked in polloing (bsc#1152489)
- commit 60a99e8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add GFX_PIPELINE capacity check for updating gfx cgpg (bsc#1152489)
- commit 1de996f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add NULL checks for clock manager pointer (bsc#1152489)
- commit b512a7c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: enable BACO reset for SMU7 based dGPUs (v2) (bsc#1152489)
- commit cb62737
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: wire up BACO to powerplay API for smu7 (bsc#1152489)
- commit 30b6b8e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: split out common smu7 BACO code (bsc#1152489)
- commit f25d4fd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add support for BACO on CI (bsc#1152489)
- commit a065e43
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add support for BACO on Fiji (bsc#1152489)
- commit e225756
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add support for BACO on VegaM (bsc#1152489)
- commit 22fbf95
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add support for BACO on polaris (bsc#1152489)
- commit 1c7bd63
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add support for BACO on Iceland (bsc#1152489)
- commit e5202c4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add support for BACO on tonga (bsc#1152489)
- commit da960f8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add core support for pre-SOC15 baco (bsc#1152489)
- commit f2f40ae
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add new SMU 7.1.3 registers for BACO (bsc#1152489)
- commit 16d23ac
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add new SMU 7.1.2 registers for BACO (bsc#1152489)
- commit 464d0e0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add new SMU 7.0.1 registers for BACO (bsc#1152489)
- commit 9026ce6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add new BIF 5.0 register for BACO (bsc#1152489)
- commit 824485e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add new BIF 4.1 register for BACO (bsc#1152489)
- commit f77e83c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/soc15: add support for baco reset with swSMU (bsc#1152489)
- commit 491c698
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove in_baco_reset hack (bsc#1152489)
- commit 4baefdb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: simplify ATPX detection (bsc#1152489)
- commit bd96709
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move gpu reset out of amdgpu_device_suspend (bsc#1152489)
- commit 7ea6014
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move pci_save_state into suspend path (bsc#1152489)
- commit ab21059
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/display: fix build error casused by (bsc#1152489)
- commit fb5f2be
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/display: hook renoir dc to pplib funcs (bsc#1152489)
- commit b894f2e
* Sat Oct 10 2020 tzimmermann@suse.de
- dmr/amdgpu: Fix crash on SRIOV for ERREVENT_ATHUB_INTERRUPT (bsc#1152489)
- commit dcf6a24
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add renoir funcs to support dc (bsc#1152489)
- commit 8c302da
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: enable Arcturus runtime VCN dpm on/off (bsc#1152489)
- commit 45823cf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: bug fix for pcie parameters override (bsc#1152489)
- commit c99b7ae
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Fix tdr3 could hang with slow compute issue (bsc#1152489)
- commit dd225e7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add RAS support for VML2 and ATCL2 (bsc#1152489)
- commit 2b4d723
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/include: add register define for VML2 and ATCL2 (bsc#1152489)
- commit 9ee2bf6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: change to query the actual EDC counter (bsc#1152489)
- commit 1ff3b4a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: add BACO platformCaps for VEGA20 (bsc#1152489)
- commit febd519
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: send EnterBaco msg with argument as RAS recovery (bsc#1152489)
- commit 0e7aa72
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: avoid disabling ECC if RAS is enabled for VEGA20 (bsc#1152489)
- commit 4dbf336
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/soc15: disable doorbell interrupt as part of BACO entry (bsc#1152489)
- commit 729216b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/display: clean up dcn2*_pp_smu functions (bsc#1152489)
- commit 41a441e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: re-enable FW_DSTATE feature bit (bsc#1152489)
- commit b7b2706
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/discovery: reserve discovery data at the top of VRAM (bsc#1152489)
- commit 7732631
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/swSMU: custom UMD pstate peak clock for navi14 (bsc#1152489)
- commit 7e56a92
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: enable df cstate control on swSMU routine (bsc#1152489)
- commit 9499389
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: enable df cstate control on powerplay routine (bsc#1152489)
- commit 4107c01
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/swSMU/navi: add feature toggles for more things (bsc#1152489)
- commit 31f1018
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: Use swap() where appropriate (bsc#1152489)
- commit 448b6b0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Use swap() where appropriate (bsc#1152489)
- commit 93be2d1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Do not implement power-on for SDMA after do mode2 reset (bsc#1152489)
- commit ab43ad0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: add more feature bits (bsc#1152489)
- commit 71b34e4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: avoid ras error injection for retired page (bsc#1152489)
- commit fba9539
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Use the ALIGN() macro (bsc#1152489)
- commit 1cb3527
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/ras: document the reboot ras option (bsc#1152489)
- commit e158346
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/ras: fix typos in documentation (bsc#1152489)
- commit 8652832
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add renoir specific watermark range and clk helper (bsc#1152489)
- commit b3db7f7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: hook up notify watermark ranges and get clock table (bsc#1152489)
- commit cde36e3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Skip DIG Check if Link is Virtual for Display Count (bsc#1152489)
- commit 535ffe5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: correct stream LTE_340MCSC_SCRAMBLE value (bsc#1152489)
- commit 623914e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Fix dongle_caps containing stale information. (bsc#1152489)
- commit 3cc441c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add capability check for static ramp calc (bsc#1152489)
- commit 307bc39
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.54 (bsc#1152489)
- commit fefcf91
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: make aux defer delay and aux sw start delay seperate (bsc#1152489)
- commit 2f6a1f9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: use vbios message to call smu for dpm level (bsc#1152489)
- commit f47f7f7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Fix maybe-uninitialized warning (bsc#1152489)
- commit 319532d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add more checks to validate seamless boot timing (bsc#1152489)
- commit 5354584
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add new active dongle to existent w/a (bsc#1152489)
- commit 2030de1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Update number of dcn21 audio endpoints (bsc#1152489)
- commit 9067792
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add guard for SMU ver, for 48mhz clk (bsc#1152489)
- commit 38a0222
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix code to control 48mhz refclk (bsc#1152489)
- commit 5bd7dd2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: exit PSR during detection (bsc#1152489)
- commit 3546a5f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Program DWB watermarks from correct state (bsc#1152489)
- commit 462199f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.53 (bsc#1152489)
- commit 9d49ad8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Use dcn1 Optimal Taps Get (bsc#1152489)
- commit b927d8c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix bug with check for HPD Low in verify link cap (bsc#1152489)
- commit 3923b6a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: wait for set pipe mcp command completion (bsc#1152489)
- commit 38b75f4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add output bitrate to DML calculations (bsc#1152489)
- commit bb48a0a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Properly round nominal frequency for SPD (bsc#1152489)
- commit f2d6d9e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Restore should_update_pstate_support after bad (bsc#1152489)
- commit 88d64ce
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: check phy dpalt lane count config (bsc#1152489)
- commit 40825a3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: build up VSIF infopacket (bsc#1152489)
- commit fc90385
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.52 (bsc#1152489)
- commit 272773c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add missing shifts and masks for dpp registers on (bsc#1152489)
- commit 8337955
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add explicit comparator as default optimization (bsc#1152489)
- commit 6208a9e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add support for VSIP info packet (bsc#1152489)
- commit 14d0fb5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix hotplug during display off (bsc#1152489)
- commit 02e44a5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix pipe re-assignment when odm present (bsc#1152489)
- commit ef431cf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Reprogram FMT on pipe change (bsc#1152489)
- commit 3aa123f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Update V_UPDATE whenever VSTARTUP changes (bsc#1152489)
- commit 49d4cd2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: skip enable stream on disconnected display (bsc#1152489)
- commit f8fb285
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Correct values in AVI infoframe (bsc#1152489)
- commit 1382ffe
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Added pixel dynamic expansion control. (bsc#1152489)
- commit ea6acba
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Enable gfx cache probing on HDP write for arcturus (bsc#1152489)
- commit 297bbc8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Clean up gmc_v9_0_gart_enable (bsc#1152489)
- commit 29fa105
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: simplify gds_compute_max_wave_id computation (bsc#1152489)
- commit 20afc48
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: update for drmP.h removal (bsc#1152489)
- commit 78de92d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Check against device cgroup (bsc#1152489)
- commit 1f9f83a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: fix the build when CIK support is disabled (bsc#1152489)
- commit 27725a4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd: Fix Kconfig indentation (bsc#1152489)
- commit 40ac865
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Report vram vendor with sysfs (v3) (bsc#1152489)
- commit cedbbba
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Fix a && vs || typo (bsc#1152489)
- commit f113e54
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: Fix error handling in smu_init_fb_allocations() (bsc#1152489)
- commit 1979472
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: unlock on error in smu_resume() (bsc#1152489)
- commit 18a68e5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Remove set but not used variables 'pp_smu', (bsc#1152489)
- commit 7015e9f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Remove set but not used variable 'pixel_width' (bsc#1152489)
- commit 1681d99
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Remove set but not used variables 'h_ratio_chroma', (bsc#1152489)
- commit d9fdea5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Remove set but not used variable 'source_bpp' (bsc#1152489)
- commit b6f05db
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Make function wait_for_alt_mode static (bsc#1152489)
- commit 8a344dd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: add missing void argument to function kgd2kfd_init (bsc#1152489)
- commit 9746706
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove duplicated include from mmhub_v1_0.c (bsc#1152489)
- commit 40e5b4f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move amdgpu_device_get_job_timeout_settings (bsc#1152489)
- commit cefae48
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: remove set but not used variable 'core_freesync' (bsc#1152489)
- commit eebab66
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Fix typo in some comments (bsc#1152489)
- commit 1d135e6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Print more sdma engine hqds in debug fs (bsc#1152489)
- commit 0dd5341
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Fix MQD size calculation (bsc#1152489)
- commit 69f4a2a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Fix error handling in amdgpu_ras_recovery_init (bsc#1152489)
- commit ccbd03e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove redundant variable r and redundant return (bsc#1152489)
- commit 186c87b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix uninitialized variable pasid_mapping_needed (bsc#1152489)
- commit 5356f40
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix struct init in update_bounding_box (bsc#1152489)
- commit 81457ed
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add code comment in vcn_v2_5_hw_init (bsc#1152489)
- commit 1f0867d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/vcn: use amdgpu_ring_test_helper (bsc#1152489)
- commit 3e44009
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: improve MSI-X handling (v3) (bsc#1152489)
- commit 8636686
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix spelling mistake AUTHENICATED -> AUTHENTICATED (bsc#1152489)
- commit 998c421
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove set but not used variable 'pipe' (bsc#1152489)
- commit 64f9c3f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Drop unused variable and statement (bsc#1152489)
- commit a559157
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu : enable msix for amdgpu driver (bsc#1152489)
- commit 2e89934
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Improve KFD IOCTL printing (bsc#1152489)
- commit c3d7f66
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Export setup_vm_pt_regs() logic for mmhub 2.0 (bsc#1152489)
- commit 4393151
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Add the HDP flush support for Navi (bsc#1152489)
- commit 9cac111
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Use array to probe kfd2kgd_calls (bsc#1152489)
- commit 08c1496
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Delete unnecessary function declarations (bsc#1152489)
- commit 26a77c7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Delete useless header file reference (bsc#1152489)
- commit a9dd3a2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/amdgpu/sriov ip block setting of Arcturus (bsc#1152489)
- commit 879dc0d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/dm/mst: Use ->atomic_best_encoder (bsc#1152489)
- commit 93d4fe6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/dm/mst: Don't create MST topology managers for eDP ports (bsc#1152489)
- commit 76236af
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/dm/mst: Remove unnecessary NULL check (bsc#1152489)
- commit c1d25ea
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Iterate through DRM connectors correctly (bsc#1152489)
- commit 74426f4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/dm: Resume short HPD IRQs before resuming MST topology (bsc#1152489)
- commit 3ebf34e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: fix kgd2kfd_device_init() definition conflict error (bsc#1152489)
- commit 164bb53
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: initlialize smu->is_apu is false by default (bsc#1152489)
- commit 1c012c3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: update the interface for getting dpm full scale (bsc#1152489)
- commit 7b82843
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: implement the interface for setting sclk/uclk (bsc#1152489)
- commit 5f42858
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: implement interface set_power_profile_mode() (v2) (bsc#1152489)
- commit 90f7dab
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: add the interfaces for getting and setting (bsc#1152489)
- commit bf94b7b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: add interface for getting workload type (bsc#1152489)
- commit 109a810
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: add interface for forcing and unforcing dpm limit (bsc#1152489)
- commit 3e4d9b5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: implement the interface for setting soft freq (bsc#1152489)
- commit 1ba6fe6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: bypass dpm_context null pointer check guard for (bsc#1152489)
- commit 6a79f05
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/amdgpu: add IH cg support on soc15 project (bsc#1152489)
- commit ffdd870
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Fix race in gfx10 context restore handler (bsc#1152489)
- commit 7be9c34
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Use setup_vm_pt_regs function from base driver in KFD (bsc#1152489)
- commit e39c2f6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Export setup_vm_pt_regs() logic for gfxhub 2.0 (bsc#1152489)
- commit af1882e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Eliminate get_atc_vmid_pasid_mapping_valid (bsc#1152489)
- commit 13d68ce
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Query vmid pasid mapping through stored info for non HWS (bsc#1152489)
- commit 056e889
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Record vmid pasid mapping in the driver for non HWS mode (bsc#1152489)
- commit df7b5bc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Use hex print format for pasid (bsc#1152489)
- commit 74333ec
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Delete unused defines (bsc#1152489)
- commit 768870d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Move the control stack on GFX10 to userspace buffer (bsc#1152489)
- commit 6102f29
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd: Pass drm_device to kfd (bsc#1152489)
- commit 75fc1d9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Store kfd_dev in iolink and cache properties (bsc#1152489)
- commit c4e37a1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: use navi12 specific family id for navi12 code path (bsc#1152489)
- commit 2e12624
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Add SMUIO values for other I2C controller v2 (bsc#1152489)
- commit 7362803
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Use better name for sdma queue non HWS path (bsc#1152489)
- commit 018b39d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Delete useless SDMA register setting on non HWS path (bsc#1152489)
- commit ec2f372
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Add NAVI12 support from kfd side (bsc#1152489)
- commit e7f31df
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: restrict hotplug error message (bsc#1152489)
- commit d6f5664
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: once more fix amdgpu_bo_create_kernel_at (bsc#1152489)
- commit fa8b321
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: update arcturus smu-driver interaction header (bsc#1152489)
- commit 8a6ec47
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add comments in ras interrupt callback (bsc#1152489)
- commit c134caf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: implement common gmc_ras_late_init (bsc#1152489)
- commit c29e8d4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move xgmi ras fini to xgmi block (bsc#1152489)
- commit 557c1fb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move mmhub ras fini to mmhub block (bsc#1152489)
- commit 9e55abe
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move umc ras fini to umc block (bsc#1152489)
- commit 7e93305
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add ras fini for xgmi (bsc#1152489)
- commit a73590e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add ras fini for nbio (bsc#1152489)
- commit 5ee79d0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: simplify the access to eeprom_control struct (bsc#1152489)
- commit cefc7be
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove ih_info parameter of gfx_ras_late_init (bsc#1152489)
- commit 381b531
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove ih_info parameter of umc_ras_late_init (bsc#1152489)
- commit 84035f5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add common sdma_ras_fini function (bsc#1152489)
- commit 07c43b9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add common gfx_ras_fini function (bsc#1152489)
- commit 8b141ab
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add common gmc_ras_fini function (bsc#1152489)
- commit 77609cf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move mmhub_ras_if from gmc to mmhub block (bsc#1152489)
- commit c531842
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: replace mmhub_funcs with mmhub.funcs (bsc#1152489)
- commit fd36902
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add common mmhub member for adev (bsc#1152489)
- commit cfde8fb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move umc_ras_if from gmc to umc block (bsc#1152489)
- commit f96465b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: refine sdma4 ras_data_cb (bsc#1152489)
- commit 061dd6d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move sdma ecc functions to generic sdma file (bsc#1152489)
- commit dc22c97
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move gfx ecc functions to generic gfx file (bsc#1152489)
- commit 9f44e50
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move umc ras irq functions to umc block (bsc#1152489)
- commit 688faf0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: update parameter of ras_ih_cb (bsc#1152489)
- commit 295589f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix an UMC hw arbitrator bug(v3) (bsc#1152489)
- commit 485f417
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove gfx9 NGG (bsc#1152489)
- commit 5668845
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/atomfirmware: simplify the interface to get vram info (bsc#1152489)
- commit 19d36d4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/atomfirmware: use proper index for querying vram type (v3) (bsc#1152489)
- commit 0bab32d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/psp: silence response status warning (bsc#1152489)
- commit 4b318e4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: remove duplicate macro of smu_get_uclk_dpm_states (bsc#1152489)
- commit 566234d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/amdgpu:Fix compute ring unable to detect hang. (bsc#1152489)
- commit 73c4e17
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Use mode2 mode to perform GPU RESET for Renoir (bsc#1152489)
- commit 969e71e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: A workaround to GPU RESET on APU (bsc#1152489)
- commit c278e52
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: Add mode2 mode for GPU RESET in SMU (bsc#1152489)
- commit d275eba
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Sync gfx10 kfd2kgd_calls function pointers (bsc#1152489)
- commit 774e2b3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Fix NULL pointer dereference for set_scratch_backing_va() (bsc#1152489)
- commit b10138c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Remove unnecessary pm_init() for non HWS mode (bsc#1152489)
- commit 4c652a7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Remove excessive print when reserving doorbells (bsc#1152489)
- commit 7f34835
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Add an error print if SDMA RLC is not idle (bsc#1152489)
- commit 40efc3b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: correct condition check for psp rlc autoload (bsc#1152489)
- commit a86ad90
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add command id in psp response failure message (bsc#1152489)
- commit 4eed202
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: enable psp front door loading by default on Arcturus (bsc#1152489)
- commit 82645cd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: disable vcn ip block for front door loading on Arcturus (bsc#1152489)
- commit f170f33
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: fix a potential NULL pointer dereference (v2) (bsc#1152489)
- commit fc75a35
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/ras: fix and update the documentation for RAS (bsc#1152489)
- commit 2cfbd91
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix documentation for amdgpu_pm.c (bsc#1152489)
- commit 8789637
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/ih: fix documentation in amdgpu_irq_dispatch (bsc#1152489)
- commit f0f4edf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/vm: fix up documentation in amdgpu_vm.c (bsc#1152489)
- commit 781cd5d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/mn: fix documentation for amdgpu_mn_read_lock (bsc#1152489)
- commit 1c9ac6f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix documentation for amdgpu_gem_prime_export (bsc#1152489)
- commit be04f24
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display; Fix kernel doc warnings (bsc#1152489)
- commit 299fd73
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove excess function parameter description (bsc#1152489)
- commit b553792
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: enable full ras by default (bsc#1152489)
- commit 380237a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/SRIOV: add navi12 pci id for SRIOV (v2) (bsc#1152489)
- commit 0149e84
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/psp: invalidate the hdp read cache before reading the psp (bsc#1152489)
- commit d37290d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/psp: flush HDP write fifo after submitting cmds to the psp (bsc#1152489)
- commit 344c4e6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove redundant variable definition (bsc#1152489)
- commit 74f23ac
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: avoid null pointer dereference (bsc#1152489)
- commit 556d407
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add new mapping for APCC_DFLL feature (bsc#1152489)
- commit 17f4818
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: do not init mec2 jt for renoir (bsc#1152489)
- commit 7d872ae
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add psp ip block for arct (bsc#1152489)
- commit 1d4d5e5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/ras: use GPU PAGE_SIZE/SHIFT for reserving pages (bsc#1152489)
- commit a59761b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/discovery: get gpu info from ip discovery table (bsc#1152489)
- commit add2ca4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: use GPU PAGE SHIFT for umc retired page (bsc#1152489)
- commit 7e65408
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: implement VCN power gating control interface (bsc#1152489)
- commit d015596
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: replace DRM_ERROR with DRM_WARN in ras_reserve_bad_pages (bsc#1152489)
- commit 4f9cab4
* Sat Oct 10 2020 tzimmermann@suse.de
- docs: drm/amdgpu: Resolve build warnings (bsc#1152489)
- commit babc394
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/vm: fix documentation for amdgpu_vm_bo_param (bsc#1152489)
- commit 4540849
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Delete unused KFD_IS_* macro (bsc#1152489)
- commit bb08804
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add hdcp to Kconfig (bsc#1152489)
- commit 18d72d3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: only enable HDCP for DCN+ (bsc#1152489)
- commit d46974d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Update CP property based on HW query (bsc#1152489)
- commit e9e79b8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: handle DP cpirq (bsc#1152489)
- commit 2f7062f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Handle Content protection property changes (bsc#1152489)
- commit b2bc2db
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Initialize HDCP work queue (bsc#1152489)
- commit d5c8838
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Create dpcd and i2c packing functions (bsc#1152489)
- commit 24200a4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Create amdgpu_dm_hdcp (bsc#1152489)
- commit e074e4b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Update hdcp display config (bsc#1152489)
- commit 661f754
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add PSP block to verify hdcp steps (bsc#1152489)
- commit 25f5785
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add HDCP module (bsc#1152489)
- commit 34a1d0d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: psp DTM init (bsc#1152489)
- commit 1da565e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: psp HDCP init (bsc#1152489)
- commit c49b1f1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Improve LFC behaviour (bsc#1152489)
- commit 7c9dd17
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add detile buffer size for DCN20 (bsc#1152489)
- commit fb07de8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix use of uninitialized variable (bsc#1152489)
- commit 7e3f251
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.51.1 (bsc#1152489)
- commit 4f739d3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.51 (bsc#1152489)
- commit 14dcfea
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: enable single dp seamless boot (bsc#1152489)
- commit 6b1e362
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: update odm mode validation to be in line with policy (bsc#1152489)
- commit fd0aeb3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Optimize clocks on clock change (bsc#1152489)
- commit f6ae1da
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Set number of pipes to 1 if the second pipe was (bsc#1152489)
- commit 814bc00
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: set minimum abm backlight level (bsc#1152489)
- commit 6aef07e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Revert fixup DPP programming sequence (bsc#1152489)
- commit fdf9ddf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Do not double-buffer DTO adjustments (bsc#1152489)
- commit 64c7aae
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Separate hardware initialization from creation (bsc#1152489)
- commit f891184
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix i2c wtire mot incorrect issue (bsc#1152489)
- commit b792f34
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Handle virtual signal type in disable_link() (bsc#1152489)
- commit e687777
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: fix global sync param extraction indexing (bsc#1152489)
- commit 215db29
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add vtg update after global sync update (bsc#1152489)
- commit f4dea96
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add debugfs entry to force YUV420 output (bsc#1152489)
- commit c402306
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: add additional flag consideration for surface update (bsc#1152489)
- commit c93a718
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Replace for loop w/ function call (bsc#1152489)
- commit bab3dfa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Rebuild mapped resources after pipe split (bsc#1152489)
- commit c1b1cc9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.50 (bsc#1152489)
- commit 29ebaab
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: define parameters for abm 2.3 (bsc#1152489)
- commit a912579
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Fix HUBP secondary viewport programming (bsc#1152489)
- commit fd6a4ab
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: cleanup creating BOs at fixed location (v2) (bsc#1152489)
- commit 6cb0f82
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu:Fix EEPROM checksum calculation. (bsc#1152489)
- commit 0de352b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix ras ctrl debugfs node leak (bsc#1152489)
- commit 21ae0aa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: trace if a PD/PT update is done directly (bsc#1152489)
- commit 3c66928
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: drop double HDP flush in the VM code (bsc#1152489)
- commit 46b0c2c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: cleanup coding style in the VM code a bit (bsc#1152489)
- commit a6a4d4e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/SRIOV: Navi12 SRIOV VF gets GTT base (bsc#1152489)
- commit fd430b4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove the redundant null checks (bsc#1152489)
- commit 57f6ef7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/radeon: be quiet when no SAD block is found (bsc#1152489)
- commit bd19422
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd: be quiet when no SAD block is found (bsc#1152489)
- commit 0b96312
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: rename variable eanble -> enable (bsc#1152489)
- commit 4e2fb14
* Sat Oct 10 2020 tzimmermann@suse.de
- Revert "drm/amdgpu/nbio7.4: add hw bug workaround for vega20" (bsc#1152489)
- commit 0750d9c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add graceful VM fault handling v3 (bsc#1152489)
- commit cd524e1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: reserve the root PD while freeing PASIDs (bsc#1152489)
- commit dc41f01
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: allocate PDs/PTs with no_gpu_wait in a page fault (bsc#1152489)
- commit 44a8f3c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: allow direct submission of clears (bsc#1152489)
- commit 7006b89
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: allow direct submission of PTE updates (bsc#1152489)
- commit 86f1fd2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: allow direct submission of PDE updates v2 (bsc#1152489)
- commit 0123413
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: allow direct submission in the VM backends v2 (bsc#1152489)
- commit 20d9975
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: split the VM entity into direct and delayed (bsc#1152489)
- commit 7d43495
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: return -EBUSY on pipelining with no_gpu_wait (v2) (bsc#1152489)
- commit d55919a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: grab the id mgr lock while accessing passid_mapping (bsc#1152489)
- commit 727d3dd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/SRIOV: Navi12 SRIOV VF doesn't load TOC (bsc#1152489)
- commit a7b3271
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/SRIOV: Navi10/12 VF doesn't support SMU (bsc#1152489)
- commit df17e6d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: For Navi12 SRIOV VF, register mailbox functions (bsc#1152489)
- commit 9878f22
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/sriov: add ring_stop before ring_create in psp v11 code (bsc#1152489)
- commit 0ab8e64
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: check SMU engine readiness before proceeding on S3 (bsc#1152489)
- commit bc1e312
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: properly set mp1 state for SW SMU suspend/reset (bsc#1152489)
- commit cfdfe48
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Fix mutex lock from atomic context. (bsc#1152489)
- commit cd9b01b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Add SRIOV mailbox backend for Navi1x (bsc#1152489)
- commit c22a7c2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: implement ras query function for pcie bif (bsc#1152489)
- commit 874b126
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add pcie bif ras related registers (bsc#1152489)
- commit 313ac6b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: support pcie bif ras query and inject (bsc#1152489)
- commit 117764c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add ras error query count interface for nbio (bsc#1152489)
- commit c978522
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix CPDMA hang in PRT mode for VEGA10 (bsc#1152489)
- commit d2d169b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: enable error injection to XGMI block via debugfs (bsc#1152489)
- commit edbff7f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: initialize ras structures for xgmi block (v2) (bsc#1152489)
- commit 0b4db87
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: fix the missed asic name while inited renoir_device_info (bsc#1152489)
- commit 347dcd1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Allow to reset to EERPOM table. (bsc#1152489)
- commit 2be392c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Add amdgpu_ras_eeprom_reset_table (bsc#1152489)
- commit 5c45797
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: rename umc ras_init to err_cnt_init (bsc#1152489)
- commit bbe021e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move umc ras init to umc block (bsc#1152489)
- commit 778ffb1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move umc late init from gmc to umc block (bsc#1152489)
- commit 8bbd0f9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove duplicated header file include (bsc#1152489)
- commit 149bb73
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove needless usage of #ifdef (bsc#1152489)
- commit dc4830d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix build error without CONFIG_HSA_AMD (bsc#1152489)
- commit 9ec8456
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: issue DC-BTC for arcturus on SMU init (bsc#1152489)
- commit cf8300e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Avoid RAS recovery init when no RAS support. (bsc#1152489)
- commit 9c44c34
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: cleanup PTE flag generation v3 (bsc#1152489)
- commit 5eb367a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: cleanup mtype mapping (bsc#1152489)
- commit 7906f59
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: Add the interface for geting dpm current power (bsc#1152489)
- commit ec4e528
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: check if nbio->ras_if exist (bsc#1152489)
- commit 9bb3669
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: enable renoir while device probes (bsc#1152489)
- commit 796bed5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: disable gfxoff while use no H/W scheduling policy (bsc#1152489)
- commit 4b00f86
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: add renoir kfd topology (bsc#1152489)
- commit c0426fc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: add package manager for renoir (bsc#1152489)
- commit 5e52ec3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: init kernel queue for renoir (bsc#1152489)
- commit 5946834
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: init kfd apertures v9 for renoir (bsc#1152489)
- commit e9d283c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: add renoir type for the workaround of iommu v2 (v2) (bsc#1152489)
- commit fd01cbd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: enable kfd device queue manager v9 for renoir (bsc#1152489)
- commit 1d24f11
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: add renoir kfd device info (v2) (bsc#1152489)
- commit b6e6775
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: add renoir cache info for CRAT (v2) (bsc#1152489)
- commit 06e74ee
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Support Navi14 in KFD (bsc#1152489)
- commit 4d37da5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Disable retry faults in VMID0 (bsc#1152489)
- commit 85607dd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Add a kernel parameter for specifying the asic type (bsc#1152489)
- commit 53f9fb1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/irq: check if nbio funcs exist (bsc#1152489)
- commit 68eb1a9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: replace FIXME with TODO (bsc#1152489)
- commit c09bc34
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: verify stream link before link test (bsc#1152489)
- commit ea4f3e8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Isolate DSC module from driver dependencies (bsc#1152489)
- commit 1258815
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: OTC underflow fix (bsc#1152489)
- commit 408d781
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: remove hw access from dc_destroy (bsc#1152489)
- commit 4378691
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Reuse dcn2 registers (bsc#1152489)
- commit 2a2c43b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: remove temporary transition code (bsc#1152489)
- commit e5d8907
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: update navi to use new surface programming behaviour (bsc#1152489)
- commit 0ea0b41
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add missing surface address registers (bsc#1152489)
- commit 6c6f0cb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.49 (bsc#1152489)
- commit 223704d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: config to override DSC start slice height (bsc#1152489)
- commit e39f7fd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Add back support for DSC 4:2:2 Simple (bsc#1152489)
- commit 268c2ef
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Don't allocate payloads if link lost (bsc#1152489)
- commit ddc1b6f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Subsample mode suboptimal for YCbCr4:2:2 (bsc#1152489)
- commit 0e67ca8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: refine i2c over aux (bsc#1152489)
- commit 6d00579
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/display: Fix DML tests (bsc#1152489)
- commit 1c8e815
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Fix a building error when KFD_SUPPORT_IOMMU_V2 is turned (bsc#1152489)
- commit 61f4803
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: move the call of ras recovery_init and bad page reserve (bsc#1152489)
- commit 9722623
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: save umc error records (bsc#1152489)
- commit 6dc0149
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Hook EEPROM table to RAS (bsc#1152489)
- commit f399e13
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: change ras bps type to eeprom table record structure (bsc#1152489)
- commit c43b0de
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/madgpu: Fix EEPROM Checksum calculation. (bsc#1152489)
- commit d74b5ca
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdkfd: Query kfd device info by CHIP id instead of pci device id (bsc#1152489)
- commit 4cb4f4b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Disable page faults while reading user wptrs (bsc#1152489)
- commit 8ed6a86
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: clean up load TMR sequence (bsc#1152489)
- commit f919a2c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: enable TA load support in Arcturus (bsc#1152489)
- commit 9f15a7b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: change r type to int in gmc_v9_0_late_init (bsc#1152489)
- commit 3a0b166
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: replace smu->table_count with SMU_TABLE_COUNT in (bsc#1152489)
- commit 2b42485
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/amdgpu: add sw_fini interface for df_funcs (bsc#1152489)
- commit 013e359
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: init UMC & RSMU register base address (bsc#1152489)
- commit e98f117
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/nbio: switch to amdgpu_nbio_ras_late_init helper function (bsc#1152489)
- commit 812ba54
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/mmhub: switch to amdgpu_mmhub_ras_late_init helper (bsc#1152489)
- commit c75f987
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/sdma: switch to amdgpu_sdma_ras_late_init helper function (bsc#1152489)
- commit 1fddd52
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/gfx: switch to amdgpu_gfx_ras_late_init helper function (bsc#1152489)
- commit 383f8b4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/gmc: switch to amdgpu_gmc_ras_late_init helper function (bsc#1152489)
- commit 81e288b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: set ip specific ras interface pointer to NULL after free (bsc#1152489)
- commit dc1d85d
* Sat Oct 10 2020 tzimmermann@suse.de
- dmr/amdgpu: Add system auto reboot to RAS. (bsc#1152489)
- commit 57ae0cb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Avoid HW GPU reset for RAS. (bsc#1152489)
- commit 159acda
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Fix bugs in amdgpu_device_gpu_recover in XGMI case. (bsc#1152489)
- commit eed5b71
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: remove amdgpu_cs_try_evict (bsc#1152489)
- commit 5367d1d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: reserve at least 4MB of VRAM for page tables v2 (bsc#1152489)
- commit 6021d64
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: use moving fence instead of exclusive for VM updates (bsc#1152489)
- commit 968d183
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: do proper cleanups on hw_fini (bsc#1152489)
- commit bb17926
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: update cached feature enablement status V3 (bsc#1152489)
- commit cb43b68
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amd/powerplay: guard manual mode prerequisite for clock level (bsc#1152489)
- commit 583de5c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: only apply gds clearing workaround when ras is supported (bsc#1152489)
- commit 36d286a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: fix memory leak when ras is not supported on specific ip (bsc#1152489)
- commit 9580fbd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: check mmhub_funcs pointer before refering to it (bsc#1152489)
- commit 6dfaff3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Remove unnecessary TLB workaround (v2) (bsc#1152489)
- commit 7565c17
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Use optimal mtypes and PTE bits for Arcturus (bsc#1152489)
- commit 9b5be13
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Determing PTE flags separately for each mapping (v3) (bsc#1152489)
- commit 6ad4ff3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Support new arcturus mtype (bsc#1152489)
- commit 4dd7648
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: Extends amdgpu vm definitions (v2) (bsc#1152489)
- commit d931e83
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: switch to amdgpu_ras_late_init for nbio v7_4 (v2) (bsc#1152489)
- commit 656fc5b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add ras_late_init callback function for nbio v7_4 (v3) (bsc#1152489)
- commit 9937c65
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add mmhub ras_late_init callback function (v2) (bsc#1152489)
- commit 578ecf0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: switch to amdgpu_ras_late_init for gmc v9 block (v2) (bsc#1152489)
- commit 479fcbe
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: switch to amdgpu_ras_late_init for sdma v4 block (v2) (bsc#1152489)
- commit 9aa7e3f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: switch to amdgpu_ras_late_init for gfx v9 block (v2) (bsc#1152489)
- commit a683bb6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add helper function to do common ras_late_init/fini (v3) (bsc#1152489)
- commit ec48f04
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: poll ras_controller_irq and err_event_athub_irq status (bsc#1152489)
- commit 01264e2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add ras_controller and err_event_athub interrupt support (bsc#1152489)
- commit a00b73a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: update nbio v7_4 ip header files (bsc#1152489)
- commit fc40ac4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add nbif v7_4 irq source header for vega20 (bsc#1152489)
- commit baf776a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu/nbio: add functions to query ras specific interrupt status (bsc#1152489)
- commit cd2def9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: switch to new amdgpu_nbio structure (bsc#1152489)
- commit 6d573ca
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: add new amdgpu nbio header file (bsc#1152489)
- commit 7606c63
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: rcar-du: lvds: Add r8a774b1 support (bsc#1152489)
- commit fbf9dd4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: rcar-du: Add R8A774B1 support (bsc#1152489)
- commit 027632d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: rcar_lvds: Fix color mismatches on R-Car H2 ES2.0 and later (bsc#1152489)
- commit ae62fc4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: rcar-du: kms: Expand comment in vsps parsing routine (bsc#1152489)
- commit 8fcb480
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add no_clk into ddp private data (bsc#1152489)
- commit 81ab025
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add mutex sof register offset into ddp private data (bsc#1152489)
- commit 0595a69
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add mutex sof into ddp private data (bsc#1152489)
- commit db0e103
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add mutex mod register offset into ddp private data (bsc#1152489)
- commit 036aa80
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add mutex mod into ddp private data (bsc#1152489)
- commit 33e0e56
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add ovl0/ovl_2l0 usecase (bsc#1152489)
- commit d8233b6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: distinguish ovl and ovl_2l by layer_nr (bsc#1152489)
- commit ac8681c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add background color input select function for (bsc#1152489)
- commit b953abb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add function to background color input select for (bsc#1152489)
- commit 988cb8f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/medaitek: add layer_nr for ovl private data (bsc#1152489)
- commit 15d805d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add gmc_bits for ovl private data (bsc#1152489)
- commit 2350e61
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add component OVL_2L1 (bsc#1152489)
- commit 2b4c864
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add component OVL_2L0 (bsc#1152489)
- commit 93fcf7e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add component DITHER (bsc#1152489)
- commit a51f004
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add ddp component CCORR (bsc#1152489)
- commit bd85b71
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add dphy reset after setting lanes number (bsc#1152489)
- commit 4acf4a3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: adjust dsi and mipi_tx probe sequence (bsc#1152489)
- commit f030430
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: change the dsi phytiming calculate method (bsc#1152489)
- commit c577dae
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add mt8183 dsi driver support (bsc#1152489)
- commit 3f90390
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add frame size control (bsc#1152489)
- commit 95638d8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add dsi reg commit disable control (bsc#1152489)
- commit 360745e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: replace writeb() with mtk_dsi_mask() (bsc#1152489)
- commit 34c1422
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: fixes CMDQ reg address of mt8173 is different with (bsc#1152489)
- commit df55e9b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: move mipi_dsi_host_register to probe (bsc#1152489)
- commit 8dc33c1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: add mipi_tx driver for mt8183 (bsc#1152489)
- commit 7fdd3fa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mediatek: separate mipi_tx to different file (bsc#1152489)
- commit 49777be
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Update DRIVER_DATE to 20191021 (bsc#1152489)
- commit 4cb0018
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gvt: Wean off struct_mutex (bsc#1152489)
- commit 05de988
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Extract GT ring management (bsc#1152489)
- commit ac53375
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: fix oa config reconfiguration (bsc#1152489)
- commit da738f4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: prettify MST debug message (bsc#1152489)
- commit 53acd38
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: add pipe id/name to pipe mismatch logs (bsc#1152489)
- commit 845b4d7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: remove extra new line on pipe_config mismatch (bsc#1152489)
- commit 61b11cd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: fix port checks for MST support on gen >= 11 (bsc#1152489)
- commit 46b7c1c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: simplify setting of ddi_io_power_domain (bsc#1152489)
- commit 90eb7ba
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display/icl: In port sync mode disable slaves first then (bsc#1152489)
- commit 4347213
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display/icl: Disable transcoder port sync as part of (bsc#1152489)
- commit e479f10
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display/icl: Enable master-slaves in trans port sync (bsc#1152489)
- commit 9bf03aa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display/icl: HW state readout for transcoder port sync (bsc#1152489)
- commit b4d8a02
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display/icl: Enable TRANSCODER PORT SYNC for tiled displays (bsc#1152489)
- commit e060e4e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display/icl: Save Master transcoder in slave's crtc_state (bsc#1152489)
- commit 184d57a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Restore full symmetry in i915_driver_modeset_probe/remove (bsc#1152489)
- commit 7ad96d5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Correct the PCH type in irq postinstall (bsc#1152489)
- commit f2bcbfe
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Make hdcp2_msg_timeout.timeout u16 (bsc#1152489)
- commit c0d136c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove hdcp2_hdmi_msg_timeout.timeout2 (bsc#1152489)
- commit 15199cc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove dead weight from hdcp2_msg_timeout[] (bsc#1152489)
- commit 1156f10
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: s/hdcp2_hdmi_msg_data/hdcp2_hdmi_msg_timeout/ (bsc#1152489)
- commit 246ca63
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Shrink eDRAM ways/sets arrays (bsc#1152489)
- commit 166338f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Make dirty_pipes refer to pipes (bsc#1152489)
- commit 39286f0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Nuke 'realloc_pipes' (bsc#1152489)
- commit c0a6a30
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Nuke the useless changed param from (bsc#1152489)
- commit 35b8c99
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Refuse modes with hdisplay==4096 on pre-HSW DP (bsc#1152489)
- commit f68f99a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Polish possible_clones setup (bsc#1152489)
- commit 9bd68fd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Move the cursor rotation handling into (bsc#1152489)
- commit 58e5eac
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Convert the leftover for_each_engine(gt) (bsc#1152489)
- commit 17d24b7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Add the mock engine to the gt->engine[] (bsc#1152489)
- commit 15c5e0c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: treat stolen as a region (bsc#1152489)
- commit 212f343
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: treat shmem as a region (bsc#1152489)
- commit a625b2c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: enumerate and init each supported region (bsc#1152489)
- commit e421696
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Don't merely skip submission if maybe timeslicing (bsc#1152489)
- commit b69ef3a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/pmu: Fix uninitialized variable on error path (bsc#1152489)
- commit bb4bbc1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Pass in intel_gt at some for_each_engine sites (bsc#1152489)
- commit f66a6a1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Make for_each_engine_masked work on intel_gt (bsc#1152489)
- commit 7197935
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Don't disable interrupts independently of the lock (bsc#1152489)
- commit 30228d8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Teach requests to use all available engines (bsc#1152489)
- commit c94bcba
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/huc: improve documentation (bsc#1152489)
- commit ee9e076
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/guc: improve documentation (bsc#1152489)
- commit b72195d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add microcontrollers documentation section (bsc#1152489)
- commit 9cb2e52
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix MST oops due to MSA changes (bsc#1152489)
- commit fa517cc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/pmu: Support multiple GPUs (bsc#1152489)
- commit f603a54
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Enable DDI/Port G (bsc#1152489)
- commit 82fe1bb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Move swizzle_bit under i915_ggtt (bsc#1152489)
- commit 02a8987
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Store i915_ggtt as the backpointer on fence registers (bsc#1152489)
- commit 633f698
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Do initial mocs configuration directly (bsc#1152489)
- commit 972bf8e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Teach timelines to take intel_gt as its argument (bsc#1152489)
- commit 6013887
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Teach workarounds to take intel_gt as its (bsc#1152489)
- commit 7b79dcc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Teach guc to take intel_gt as its argument (bsc#1152489)
- commit 76a7adf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Teach execlists to take intel_gt as its argument (bsc#1152489)
- commit 2dfd84c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Introduce Jasper Lake PCH (bsc#1152489)
- commit 35cd5eb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/ehl: Don't forget to set TC long detect function (bsc#1152489)
- commit 141a986
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Prepare the mode readout for hw vs. uapi state split (bsc#1152489)
- commit f66f4a3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Prepare the connector/encoder mask readout for hw vs. uapi (bsc#1152489)
- commit 4dabba2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Switch intel_legacy_cursor_update() to intel_ types (bsc#1152489)
- commit d625b06
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Refactor timestamping constants update (bsc#1152489)
- commit 4a3760a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlist: Trim immediate timeslice expiry (bsc#1152489)
- commit b4cc39f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Drop stale struct_mutex (bsc#1152489)
- commit 335fce3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Wa_1607138340 (bsc#1152489)
- commit a0b519f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Wa_1607030317, Wa_1607186500, Wa_1607297627 (bsc#1152489)
- commit 5350bf2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Wa_1607138336 (bsc#1152489)
- commit 88c4cf8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Wa_1409600907 (bsc#1152489)
- commit d99f595
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Wa_1409170338 (bsc#1152489)
- commit 3f88242
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Wa_1409420604 (bsc#1152489)
- commit d15c335
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Keep FF dop clock enabled for A0 (bsc#1152489)
- commit be9c632
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add extra hdc flush workaround (bsc#1152489)
- commit 0f7f3de
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add HDC Pipeline Flush (bsc#1152489)
- commit 8b01455
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Include ro parts of l3 to invalidate (bsc#1152489)
- commit 14b7c01
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add IS_TGL_REVID (bsc#1152489)
- commit 4bb2757
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/icl: Wa_1607087056 (bsc#1152489)
- commit e3320f0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Flush tasklet submission before sleeping on (bsc#1152489)
- commit 540dfb0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use drm_rect_init() (bsc#1152489)
- commit ece67ff
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use drm_rect_translate_to() (bsc#1152489)
- commit f312c9e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Make .modeset_calc_cdclk() mandatory (bsc#1152489)
- commit 8954f6d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Stop using drm_atomic_helper_check_planes() (bsc#1152489)
- commit 975561c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Switch to using DP_MSA_MISC_* defines (bsc#1152489)
- commit 3610147
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dp: Attach HDR metadata property to DP connector (bsc#1152489)
- commit 819a29a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dp: Program an Infoframe SDP Header and DB for HDR Static (bsc#1152489)
- commit 5b1ad35
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add new GMP register size for GEN11 (bsc#1152489)
- commit c2893b2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dp: Attach colorspace property (bsc#1152489)
- commit 8d53471
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dp: Add support of BT.2020 Colorimetry to DP MSA (bsc#1152489)
- commit 6663348
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dp: Extend program of VSC Header and DB for Colorimetry (bsc#1152489)
- commit c86e49a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Clear semaphore immediately upon ELSP promotion (bsc#1152489)
- commit 373cb0e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove leftover vma->obj->pages_pin_count on insert/remove (bsc#1152489)
- commit 380b6b0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Drop obj.page_pin_count after a failed vma->set_pages() (bsc#1152489)
- commit 462f6dd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: damage_helper: Fix race checking plane->state->fb (bsc#1152489)
- commit c2710fe
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sun4i: dsi: Fix video start delay computation (bsc#1152489)
- commit 8e053d4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/tilcdc: plane: Make structure tilcdc_plane_funcs constant (bsc#1152489)
- commit f1116a4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi: Refuse DDC/CI transfers on the internal I2C (bsc#1152489)
- commit 5524700
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sun4i: sun6i_mipi_dsi: fix DCS long write packet length (bsc#1152489)
- commit 06aa89a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sun4i: dsi: fix the overhead of the horizontal front porch (bsc#1152489)
- commit b3f8759
* Sat Oct 10 2020 tzimmermann@suse.de
- cec: add cec_adapter to cec_notifier_cec_adap_unregister() (bsc#1152489)
- commit 1e96d55
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mcde: Fix reference to DOC comment (bsc#1152489)
- commit d92938c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/lima: Add support for multiple reset lines (bsc#1152489)
- commit 8fe45d3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i810: Prevent underflow in ioctl (bsc#1152489)
- commit cbb9e2f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/fourcc: Add Arm 16x16 block modifier (bsc#1152489)
- commit 375f2ab
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mm: Use clear_bit_unlock() for releasing the drm_mm_node() (bsc#1152489)
- commit e6a4fca
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mm: Convert drm_mm_node booleans to bitops (bsc#1152489)
- commit 95a5310
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mm: Use helpers for drm_mm_node booleans (bsc#1152489)
- commit c8eee48
* Sat Oct 10 2020 tzimmermann@suse.de
- dma-fence: Serialise signal enabling (dma_fence_enable_sw_signaling) (bsc#1152489)
- commit 9e048c9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: hdmi4: fix use of uninitialized var (bsc#1152489)
- commit 2abff5a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: hdmi5: automatically choose limited/full range output (bsc#1152489)
- commit e27a4c8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: dss: move platform_register_drivers() to dss.c and remove (bsc#1152489)
- commit dbebccb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: fix missing scaler pixel fmt limitations (bsc#1152489)
- commit dc345c0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: tweak HDMI DDC timings (bsc#1152489)
- commit 1d7791f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: avoid copy in mgr_fld_read/write (bsc#1152489)
- commit 9d89ec3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/omap: drop unneeded locking from mgr_fld_write() (bsc#1152489)
- commit f8064ff
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mgag200: Allocate cursor BOs at high end of video memory (bsc#1152489)
- commit 81d9479
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mgag200: Reserve video memory for cursor plane (bsc#1152489)
- commit a007061
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mgag200: Move cursor BO swapping into mgag200_show_cursor() (bsc#1152489)
- commit 1a72b9a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mgag200: Move cursor-image update to mgag200_show_cursor() (bsc#1152489)
- commit c844cab
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mgag200: Add separate move-cursor function (bsc#1152489)
- commit 82bb6a0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mgag200: Add init and fini functions for cursor handling (bsc#1152489)
- commit e188bda
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mgag200: Rename cursor functions to use mgag200_ prefix (bsc#1152489)
- commit 0f61647
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ast: Allocate cursor BOs at high end of video memory (bsc#1152489)
- commit 84df57f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ast: Move cursor offset swapping into ast_show_cursor() (bsc#1152489)
- commit ac219be
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ast: Move cursor update code to ast_show_cursor() (bsc#1152489)
- commit 6cc4120
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ast: Move ast_{show,hide}_cursor() within source file (bsc#1152489)
- commit 16299f6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ast: Don't call ast_show_cursor() from ast_cursor_move() (bsc#1152489)
- commit 3535a5c
* Sat Oct 10 2020 tzimmermann@suse.de
- Revert "drm/sun4i: dsi: Change the start delay calculation" (bsc#1152489)
- commit 78ce4b6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sun4i: dsi: Fix TCON DRQ set bits (bsc#1152489)
- commit 1e20c33
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sun4i: sun6i_mipi_dsi: Add VCC-DSI regulator support (bsc#1152489)
- commit eca9fe7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm: use drm_debug_enabled() to check for debug categories (bsc#1152489)
- commit 455093a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i2c/sil164: use drm_debug_enabled() to check for debug categories (bsc#1152489)
- commit 6653f3f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/etnaviv: use drm_debug_enabled() to check for debug categories (bsc#1152489)
- commit 1c12eee
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/print: add drm_debug_enabled() (bsc#1152489)
- commit 17df3b8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/print: move drm_debug variable to drm_print.[ch] (bsc#1152489)
- commit 3f7c680
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/rect: Add drm_rect_init() (bsc#1152489)
- commit 626ce5d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/rect: Add drm_rect_translate_to() (bsc#1152489)
- commit 543a258
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: Workaround for broken FLIP_COMPLETE timestamps (bsc#1152489)
- commit bb114de
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: Use IRQ_RETVAL shorthand in d71_irq_handler (bsc#1152489)
- commit 98ed968
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp/mst: Replace the fixed point thing with straight calculation (bsc#1152489)
- commit 5cd63fa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp/mst: Handle arbitrary DP_LINK_BW values (bsc#1152489)
- commit 2564b92
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp/mst: Reduce nested ifs (bsc#1152489)
- commit 3bb151b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Fix return type of crc .poll() (bsc#1152489)
- commit 8ddf8e9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/syncobj: Include the prototype for drm_timeout_abs_to_jiffies() (bsc#1152489)
- commit 50256a8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Include prototype for drm_need_swiotlb() (bsc#1152489)
- commit 116cdd6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dsc: Fix bogus cpu_to_be16() usage (bsc#1152489)
- commit 30af704
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/fb-helper: Include prototype for drm_fb_helper_modinit() (bsc#1152489)
- commit 014f557
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/meson: vclk: use the correct G12A frac max value (bsc#1152489)
- commit 350cdb7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: SW workaround for D71 doesn't flush shadow registers (bsc#1152489)
- commit ae32e92
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: Support top-down placement flag (bsc#1152489)
- commit c336955
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: Adds power management support (bsc#1152489)
- commit feaa518
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Destroy the correct mutex name in (bsc#1152489)
- commit 8279eaa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Remove lies in {up, down}_rep_recv documentation (bsc#1152489)
- commit b075c70
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Rename drm_dp_add_port and drm_dp_update_port (bsc#1152489)
- commit 9c522bd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Destroy topology_mgr mutexes (bsc#1152489)
- commit 6758cdf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge/synopsys: dsi: Use devm_platform_ioremap_resource() in (bsc#1152489)
- commit 97fd95b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: tweak drm_print_bits() (bsc#1152489)
- commit 307382f
* Sat Oct 10 2020 tzimmermann@suse.de
- Documentation/gpu: Fix no structured comments warning for (bsc#1152489)
- commit edf8460
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: panel-lvds: Potential Oops in probe error handling (bsc#1152489)
- commit 0798c54
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Remove redundant of_device_is_available check (bsc#1152489)
- commit 89a146c
* Sat Oct 10 2020 tzimmermann@suse.de
- video/hdmi: Fix AVI bar unpack (bsc#1152489)
- commit da9cef2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Add DisplayPort colorspace property creation function (bsc#1152489)
- commit 53f18ad
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Rename HDMI colorspace property creation function (bsc#1152489)
- commit f1acc5c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/v3d: clean caches at the end of render jobs on request from user (bsc#1152489)
- commit f926514
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/edid: Add CTA-861-G modes with VIC < 128 (bsc#1152489)
- commit 596587e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp: Add definitons for MSA MISC bits (bsc#1152489)
- commit dc0afa6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/atomic-helper: Make crtc helper funcs optional (bsc#1152489)
- commit ae48e25
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Add drm_modeset_lock_assert_held() (bsc#1152489)
- commit e619b2a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/v3d: don't leak bin job if v3d_job_init fails. (bsc#1152489)
- commit 5a9fbc4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/doc: Improve docs around connector (un)registration (bsc#1152489)
- commit cacedbf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: Adds register dump support for gcu, lup and dou (bsc#1152489)
- commit db0e2ce
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: Remove in-code use of ifdef (bsc#1152489)
- commit 44f560b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/encoder: Don't raise voice in drm_encoder_mask() documentation (bsc#1152489)
- commit 5ee08f8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/encoder: Fix possible_crtcs documentation (bsc#1152489)
- commit ecb67ee
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/encoder: Fix possible_clones documentation (bsc#1152489)
- commit 3158347
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/selftests: fix spelling mistake "misssing" -> "missing" (bsc#1152489)
- commit 23ef744
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mgag200: Use drm_gem_vram_{vmap, vunmap}() to map cursor source (bsc#1152489)
- commit dea2885
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ast: Use drm_gem_vram_{vmap,vunmap}() to map cursor source BO (bsc#1152489)
- commit 91dbad1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: Provide vmap and vunmap operations for GEM VRAM objects (bsc#1152489)
- commit 487333a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: Adds error event print functionality (bsc#1152489)
- commit 2306518
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/connector: Allow max possible encoders to attach to a connector (bsc#1152489)
- commit a971904
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/connector: Share with non-atomic drivers the function to get the (bsc#1152489)
- commit ae44e46
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/prime: Remove duplicate forward declaration (bsc#1152489)
- commit 161af32
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: fix warnings in DSC (bsc#1152489)
- commit 5335656
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: sti: fix W=1 warnings (bsc#1152489)
- commit 6d869e9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/stm: dsi: higher pll out only in video burst mode (bsc#1152489)
- commit 73b3f30
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: analogix-anx78xx: convert to i2c_new_dummy_device (bsc#1152489)
- commit aeedfbb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: analogix-anx78xx: silence -EPROBE_DEFER warnings (bsc#1152489)
- commit 3fdc107
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: analogix-anx78xx: add new variants (bsc#1152489)
- commit 5ac6ff8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: Fix references to drm_bridge_funcs in documentation (bsc#1152489)
- commit fb93088
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: bridge/dw_hdmi: add audio sample channel status setting (bsc#1152489)
- commit 4b45e3a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: Fix warning in virtio_gpu_queue_fenced_ctrl_buffer. (bsc#1152489)
- commit 520b245
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: enable prime mmap support (bsc#1152489)
- commit 71f7e5f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: Unconditonally set BO call-back functions (bsc#1152489)
- commit 92ecd02
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: Unexport internal functions of VRAM MM (bsc#1152489)
- commit ad80188
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: Have VRAM MM call GEM VRAM functions directly (bsc#1152489)
- commit 4d2f2fb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: Move VRAM memory manager to GEM VRAM implementation (bsc#1152489)
- commit 311342a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: Use vmalloc for command buffer allocations. (bsc#1152489)
- commit aa8237e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: Rewrite virtio_gpu_queue_ctrl_buffer using fenced (bsc#1152489)
- commit 2065d8c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: remove embedded vma_offset_manager (bsc#1152489)
- commit 669ca9e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vmwgfx: switch to own vma manager (bsc#1152489)
- commit f0aae1b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/qxl: switch to gem vma offset manager (bsc#1152489)
- commit 5d1fb40
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/amdgpu: switch to gem vma offset manager (bsc#1152489)
- commit 1d87432
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/radeon: switch to gem vma offset manager (bsc#1152489)
- commit c3151ff
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: switch to gem vma offset manager (bsc#1152489)
- commit bf0bff1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/nouveau: switch to gem vma offset manager (bsc#1152489)
- commit 942272a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: turn ttm_bo_device.vma_manager into a pointer (bsc#1152489)
- commit 79f56ff
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: fix Kconfig (bsc#1152489)
- commit dfee40c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/qxl: use drm_gem_ttm_print_info (bsc#1152489)
- commit a02ddcf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/qxl: use drm_gem_object_funcs callbacks (bsc#1152489)
- commit 40444de
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: add vram-mm debugfs file (bsc#1152489)
- commit 4b2be4a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: use drm_gem_ttm_print_info (bsc#1152489)
- commit d6b12b1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/ttm: add drm gem ttm helpers, starting with (bsc#1152489)
- commit beaec73
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: add drm_print_bits (bsc#1152489)
- commit 692ddb3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: Implement lazy unmapping for GEM VRAM buffers (bsc#1152489)
- commit dd9663c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: Add infrastructure for move_notify() (bsc#1152489)
- commit d52b6a5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: Acquire lock only once per call to vmap()/vunmap() (bsc#1152489)
- commit cca086a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vram: Add kmap ref-counting to GEM VRAM objects (bsc#1152489)
- commit d3d730f
* Sat Oct 10 2020 tzimmermann@suse.de
- tda9950: use cec_notifier_cec_adap_(un)register (bsc#1152489)
- commit cdae848
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: exynos: exynos_hdmi: use cec_notifier_conn_(un)register (bsc#1152489)
- commit f91e320
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sun4i/sun4i_hdmi_enc: call cec_s_conn_info() (bsc#1152489)
- commit 400dd0f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/stm: ltdc: add pinctrl for DPI encoder mode (bsc#1152489)
- commit 301e724
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panel: panel-simple: Set OSD070T1718 panel type (bsc#1152489)
- commit 6ec6586
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/bridge: panel: Infer connector type from panel by default (bsc#1152489)
- commit 14fc867
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panel: Add and fill drm_panel type field (bsc#1152489)
- commit d177b9f
* Sat Oct 10 2020 tzimmermann@suse.de
- fbdev/sa1100fb: Remove even more dead code (bsc#1152489)
- commit c9cc998
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/blend: Define the direction of Z position values (bsc#1152489)
- commit 2270aa1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Use EOPNOTSUPP, not ENOTSUPP (bsc#1152489)
- commit 069aeab
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: fix command submission with objects but without fence. (bsc#1152489)
- commit 2f9b402
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: add worker for object release (bsc#1152489)
- commit 1e257cc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: add fence sanity check (bsc#1152489)
- commit 8eb25d8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: drop virtio_gpu_object_{reserve, unreserve} (bsc#1152489)
- commit 01ebf2c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: drop virtio_gpu_object_{ref,unref} (bsc#1152489)
- commit f2de523
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: remove virtio_gpu_alloc_object (bsc#1152489)
- commit d0c1933
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: switch from ttm to gem shmem helpers (bsc#1152489)
- commit b3f48fd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: rework virtio_gpu_cmd_context_{attach, detach}_resource (bsc#1152489)
- commit f839514
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: rework virtio_gpu_transfer_to_host_ioctl fencing (bsc#1152489)
- commit 0367e76
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: rework virtio_gpu_transfer_from_host_ioctl fencing (bsc#1152489)
- commit 7546405
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: rework virtio_gpu_object_create fencing (bsc#1152489)
- commit 917227e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: rework virtio_gpu_execbuffer_ioctl fencing (bsc#1152489)
- commit 9c368d4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: add virtio_gpu_object_array & helpers (bsc#1152489)
- commit 9734afe
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: remove ttm calls from in virtio_gpu_object_{reserve, (bsc#1152489)
- commit eeeeeaa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: drop no_wait argument from virtio_gpu_object_reserve (bsc#1152489)
- commit 647839d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: remove virtio_gpu_object_wait (bsc#1152489)
- commit f1ff38c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: simplify cursor updates (bsc#1152489)
- commit 3f847cc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: switch virtio_gpu_wait_ioctl() to gem helper. (bsc#1152489)
- commit 3cebb81
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: pass gem reservation object to ttm init (bsc#1152489)
- commit 36d0d32
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Cleanup drm_dp_send_link_address() a bit (bsc#1152489)
- commit 88f181f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Refactor drm_dp_mst_handle_down_rep() (bsc#1152489)
- commit 6d1cc80
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Refactor drm_dp_mst_handle_up_req() (bsc#1152489)
- commit de1f2ad
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Constify guid in drm_dp_get_mst_branch_by_guid() (bsc#1152489)
- commit 93e15e5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Remove huge conditional in drm_dp_mst_handle_up_req() (bsc#1152489)
- commit 7f53963
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Refactor drm_dp_send_enum_path_resources (bsc#1152489)
- commit 43a9a7e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Add sideband down request tracing + selftests (bsc#1152489)
- commit c65751e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Combine redundant cases in drm_dp_encode_sideband_req() (bsc#1152489)
- commit 2a69fb9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/print: Add drm_err_printer() (bsc#1152489)
- commit da936c7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Move test_calc_pbn_mode() into an actual selftest (bsc#1152489)
- commit 80f3a53
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Get rid of list clear in destroy_connector_work (bsc#1152489)
- commit 7f92489
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp_mst: Move link address dumping into a function (bsc#1152489)
- commit bc6b4f3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vkms: Reduce critical section in vblank_simulate (bsc#1152489)
- commit 11031b0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vkms: Use wait_for_flip_done (bsc#1152489)
- commit 8f0a5f0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vblank: Document and fix vblank count barrier semantics (bsc#1152489)
- commit 86e3a08
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/komeda: Add ACLK rate to sysfs (bsc#1152489)
- commit 5e92472
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Add high-precision time to vblank trace event (bsc#1152489)
- commit e91e25a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/sti: Include the right header (bsc#1152489)
- commit affa71f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: sti: use cec_notifier_conn_(un)register (bsc#1152489)
- commit 172fd82
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: dw-hdmi-i2s: enable audio clock in audio_startup (bsc#1152489)
- commit a3a9321
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: mst: Fix query_payload ack reply struct (bsc#1152489)
- commit 224d66f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/msm: Use drm_attach_bridge() to attach a bridge to an encoder (bsc#1152489)
- commit 7b3543b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Stop including drm_bridge.h from drm_crtc.h (bsc#1152489)
- commit 5038be0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/meson: add resume/suspend hooks (bsc#1152489)
- commit b475278
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/meson: dw_hdmi: add resume/suspend hooks (bsc#1152489)
- commit ed9740b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: module_param_named() requires linux/moduleparam.h (bsc#1152489)
- commit 0b04bb6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: notify virtqueues without holding spinlock (bsc#1152489)
- commit 7777a8d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: cleanup queue functions (bsc#1152489)
- commit cfe0851
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: add plane check (bsc#1152489)
- commit 805a2d0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/vc4/vc4_hdmi: fill in connector info (bsc#1152489)
- commit de486db
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/intel_hdmi: use cec_notifier_conn_(un)register (bsc#1152489)
- commit 28c191e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm_dp_cec: add connector info support. (bsc#1152489)
- commit 6af4a5a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/virtio: make resource id workaround runtime switchable. (bsc#1152489)
- commit ad776a0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mcde: Fix an error handling path in 'mcde_probe()' (bsc#1152489)
- commit 7816d14
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/mipi-dbi: fix a loop in debugfs code (bsc#1152489)
- commit 55ac13b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panel: Initialise panel dev and funcs through drm_panel_init() (bsc#1152489)
- commit 73c7003
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panel: Add missing drm_panel_init() in panel drivers (bsc#1152489)
- commit e35d575
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/panfrost: Add errata descriptions from kbase (bsc#1152489)
- commit ac8a3c6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: switch to drm_fb_helper_remove_conflicting_pci_framebuffers (bsc#1152489)
- commit 8ea6dd7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: drop resource_id parameter from (bsc#1152489)
- commit b90c1b3
* Sat Oct 10 2020 tzimmermann@suse.de
- fbdev: drop res_id parameter from remove_conflicting_pci_framebuffers (bsc#1152489)
- commit 299f196
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: allow holding preemption on filtered ctx (bsc#1152489)
- commit ee7d8d0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: Allow dynamic reconfiguration of the OA stream (bsc#1152489)
- commit 4c032f3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: add support for perf configuration queries (bsc#1152489)
- commit 79b8788
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: introduce a versioning of the i915-perf uapi (bsc#1152489)
- commit 4791b32
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Assert tasklet is locked for process_csb() (bsc#1152489)
- commit fe2600f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/ehl: Port C's hotplug interrupt is associated with TC1 bits (bsc#1152489)
- commit 1e1eff9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Tweak virtual unsubmission (bsc#1152489)
- commit 3acd649
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Check that GPR are cleared for new contexts (bsc#1152489)
- commit c57b228
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Check known register values within the context (bsc#1152489)
- commit 2287ba3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Squelch kerneldoc warnings (bsc#1152489)
- commit e6e7390
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Fixup naked 64b divide (bsc#1152489)
- commit 71dd8a4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: Avoid polluting the i915_oa_config with error pointers (bsc#1152489)
- commit f55419c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: Prefer using the pinned_ctx for emitting delays on (bsc#1152489)
- commit 456a776
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: execute OA configuration from command stream (bsc#1152489)
- commit b79335c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: implement active wait for noa configurations (bsc#1152489)
- commit 223dc4e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: allow for CS OA configs to be created lazily (bsc#1152489)
- commit 111b7bb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Mark up "sentinel" requests (bsc#1152489)
- commit a675d64
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Prevent merging requests with conflicting flags (bsc#1152489)
- commit 6dddaaa
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: Replace global wakeref tracking with engine-pm (bsc#1152489)
- commit 3bd9820
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Serialise write to scratch with its vma binding (bsc#1152489)
- commit b72c231
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add an rcu_barrier option to i915_drop_caches (bsc#1152489)
- commit 9d612d1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Only mark incomplete requests as -EIO on (bsc#1152489)
- commit 8ab8872
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Leave tell-tales as to why pending[] is bad (bsc#1152489)
- commit abf23d0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Note the addition of timeslicing to the pretend scheduler (bsc#1152489)
- commit 5d34050
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Read SAGV block time from PCODE (bsc#1152489)
- commit 6d8feca
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Move SAGV block time to dev_priv (bsc#1152489)
- commit ad25584
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: Store shortcut to intel_uncore (bsc#1152489)
- commit f29e00d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: store the associated engine of a stream (bsc#1152489)
- commit 4907372
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove cursor use of properties for coordinates (bsc#1152489)
- commit 975d6cb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove begin/finish_crtc_commit, v4. (bsc#1152489)
- commit b94ef8b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use intel_plane_state in prepare and cleanup plane_fb (bsc#1152489)
- commit aab0c90
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Introduce and use (bsc#1152489)
- commit 4e28ce8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix for_each_intel_plane_mask definition (bsc#1152489)
- commit d699429
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Check that registers are preserved between (bsc#1152489)
- commit 65ec430
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Mark up expected state during reset (bsc#1152489)
- commit 086c12e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Warn CI about an unrecoverable wedge (bsc#1152489)
- commit 636be47
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: simplify the lrc register list for !RCS (bsc#1152489)
- commit e3c960a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: the BCS engine supports relative MMIO (bsc#1152489)
- commit e45b410
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Select DPLL's via mask (bsc#1152489)
- commit d701481
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/color: move check of gamma_enable to specific func/platform (bsc#1152489)
- commit eec02db
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/color: fix broken gamma state-checker during boot (bsc#1152489)
- commit 9b838a5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: fix null pointer dereference on pointer data (bsc#1152489)
- commit 33bf124
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Hold request reference over waits (bsc#1152489)
- commit 8ae74dc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Give engine->kernel_context distinct timeline lock (bsc#1152489)
- commit 9e5c8b9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/region: support volatile objects (bsc#1152489)
- commit 8a544e3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/region: support contiguous allocations (bsc#1152489)
- commit 914d98b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: introduce intel_memory_region (bsc#1152489)
- commit af1a5ec
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Flush submission tasklet before waiting/retiring (bsc#1152489)
- commit 2fb995e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: drop list of streams (bsc#1152489)
- commit df78072
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Assign the intel_runtime_pm pointer for (bsc#1152489)
- commit 205db24
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Assign the mock_engine->uncore shortcut (bsc#1152489)
- commit e41d3a3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Assign virtual_engine->uncore from first sibling (bsc#1152489)
- commit 3ade7d3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add DC3CO counter in i915_dmc_info (bsc#1152489)
- commit 1826bb4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Switch between dc3co and dc5 based on display idleness (bsc#1152489)
- commit 25f5fa0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Do modeset to enable and configure DC3CO exitline (bsc#1152489)
- commit 195602e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Enable DC3CO state in "DC Off" power well (bsc#1152489)
- commit c65acf0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add DC3CO mask to allowed_dc_mask and gen9_dc_mask (bsc#1152489)
- commit 8c2ce6b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add DC3CO required register and bits (bsc#1152489)
- commit 8f00b1e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: Set the exclusive stream under perf->lock (bsc#1152489)
- commit b1ae7b1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: Wean ourselves off dev_priv (bsc#1152489)
- commit ae05913
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix Kconfig indentation (bsc#1152489)
- commit 4c0a6cf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Treat a busy timeline as 'active' while waiting (bsc#1152489)
- commit 433627a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Appease lockdep (bsc#1152489)
- commit 21c4267
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Fix annotation for decoupling virtual request (bsc#1152489)
- commit c1bb4a5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Prefer local path to runtime powermanagement (bsc#1152489)
- commit 22508c2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: make array hw_engine_mask static, makes object smaller (bsc#1152489)
- commit b2f4a54
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/vbt: Child device size remains unchanged through VBT 229 (bsc#1152489)
- commit 4d75c9a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: move perf types to their own header (bsc#1152489)
- commit e05a3eb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Restore dropped 'interruptible' flag (bsc#1152489)
- commit aa66c86
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Update DRIVER_DATE to 20191007 (bsc#1152489)
- commit e355b00
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: move gmbus setup down to intel_modeset_init() (bsc#1152489)
- commit 9f0c055
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: split out i915_switcheroo.[ch] from i915_drv.c (bsc#1152489)
- commit 6bcd9e6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/vga: rename intel_vga_msr_write() to (bsc#1152489)
- commit c89f47c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/stolen: make the object creation interface consistent (bsc#1152489)
- commit 459252b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Implement a better i945gm vblank irq vs. C-states (bsc#1152489)
- commit 545cdd9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Drop struct_mutex from around GEM initialisation (bsc#1152489)
- commit 989c574
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Drop vestigal struct_mutex guards (bsc#1152489)
- commit 2ffa6f4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Drop struct_mutex from suspend state save/restore (bsc#1152489)
- commit 07156b1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove struct_mutex guard for debugfs/opregion (bsc#1152489)
- commit 15d1b2f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Drop struct_mutex guard from debugfs/framebuffer_info (bsc#1152489)
- commit 924e807
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/overlay: Drop struct_mutex guard (bsc#1152489)
- commit ada2780
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Move context management under GEM (bsc#1152489)
- commit 0abbcb0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove logical HW ID (bsc#1152489)
- commit 61e84e4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Move global activity tracking from GEM to GT (bsc#1152489)
- commit ac81109
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Move request runtime management onto gt (bsc#1152489)
- commit db12971
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gem: Retire directly for mmap-offset shrinking (bsc#1152489)
- commit e2812ee
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Merge wait_for_timelines with retire_request (bsc#1152489)
- commit 1803574
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove the GEM idle worker (bsc#1152489)
- commit d6aa7d7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Drop struct_mutex from around i915_retire_requests() (bsc#1152489)
- commit c415c2c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Move idle barrier cleanup into engine-pm (bsc#1152489)
- commit 3f3e13b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Coordinate i915_active with its own mutex (bsc#1152489)
- commit f6e4e9e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Push the i915_active.retire into a worker (bsc#1152489)
- commit 399cf38
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Pull i915_vma_pin under the vm->mutex (bsc#1152489)
- commit df092a0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Mark up address spaces that may need to allocate (bsc#1152489)
- commit 15c957b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Only track bound elements of the GTT (bsc#1152489)
- commit 7e8855b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use helpers for drm_mm_node booleans (bsc#1152489)
- commit f5e2374
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Restrict L3 remapping sysfs interface to dwords (bsc#1152489)
- commit 81a2e81
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: extend audio CDCLK>=2*BCLK constraint to more platforms (bsc#1152489)
- commit ac0ab21
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix audio power up sequence for gen10+ display (bsc#1152489)
- commit 781a9c6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dp: remove static variable for aux last status (bsc#1152489)
- commit 79e5598
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Skip redundant resubmission (bsc#1152489)
- commit 1ac899e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add the Thunderbolt PLL divider values (bsc#1152489)
- commit e98f0b8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: use DRM_DEBUG_KMS() instead of drm_dbg(DRM_UT_KMS, ...) (bsc#1152489)
- commit 09e7d07
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: use DRM_ERROR() instead of drm_err() (bsc#1152489)
- commit a391968
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Exercise potential false lite-restore (bsc#1152489)
- commit c9baf3e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/mg: Use tc_port instead of port parameter to MG registers (bsc#1152489)
- commit e048650
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Clean up encoder->crtc_mask setup (bsc#1152489)
- commit 0730079
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Populate possible_crtcs correctly (bsc#1152489)
- commit 15bb200
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gem: Refactor tests on obj->ops->flags (bsc#1152489)
- commit a7fc777
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Extract random_offset() for use with a prng (bsc#1152489)
- commit 5e76526
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Polish intel_tv_mode_valid() (bsc#1152489)
- commit de6dfef
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Limit MST modes based on plane size too (bsc#1152489)
- commit 9d7b922
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: abstract all vgaarb access to intel_vga.[ch] (bsc#1152489)
- commit 0a175b8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dp: Fix DP MST error after unplugging TypeC cable (bsc#1152489)
- commit 715f2a0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Initialise breadcrumb lists on the virtual engine (bsc#1152489)
- commit e3f585a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gt: Only unwedge if we can reset first (bsc#1152489)
- commit ab7168e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Exercise context switching in parallel (bsc#1152489)
- commit ae1f3b4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Provide a mock GPU reset routine (bsc#1152489)
- commit 5fcdc46
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Distinguish mock device from no wakeref (bsc#1152489)
- commit df45bcd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Pass intel_gt to has-reset? (bsc#1152489)
- commit 9a90f27
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Do not try to sanitize mock HW (bsc#1152489)
- commit e26ee2e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: simplify i915_gem_init_early (bsc#1152489)
- commit 069bc5c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: check for kernel_context (bsc#1152489)
- commit 2b85cb3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: initialize TC and TBT ports (bsc#1152489)
- commit 93176b8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Fix dkl link training (bsc#1152489)
- commit ce43b41
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add dkl phy programming sequences (bsc#1152489)
- commit 7fa75bc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tc: Update DP_MODE programming (bsc#1152489)
- commit 71d691d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dmc: Update ICL DMC version to v1.09 (bsc#1152489)
- commit d549729
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/huc: fix version parsing from CSS header (bsc#1152489)
- commit 96033fb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Update DRIVER_DATE to 20190927 (bsc#1152489)
- commit f6580d4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Extract GT render sleep (rc6) management (bsc#1152489)
- commit 3500c87
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Exercise concurrent submission to all engines (bsc#1152489)
- commit de51a96
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add definitions for MI_MATH command (bsc#1152489)
- commit 2a197ae
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: Fix use of kernel-doc format in structure members (bsc#1152489)
- commit b539db4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Don't disable interrupts for intel_engine_breadcrumbs_irq() (bsc#1152489)
- commit ccbdb3c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Drop the IRQ-off asserts (bsc#1152489)
- commit 3bb03d4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Adjust length of MI_LOAD_REGISTER_REG (bsc#1152489)
- commit d8d6ea6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Use per-process HWSP as scratch (bsc#1152489)
- commit c1e9160
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Define explicit wedged on init reset state (bsc#1152489)
- commit bae6265
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Small joiner RAM buffer size is platform-specific (bsc#1152489)
- commit bd569f8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add memory type decoding for bandwidth checking (bsc#1152489)
- commit b3003f5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Return the mg/dkl pll as DDI clock for new TC ports (bsc#1152489)
- commit 2f95174
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add dkl phy pll calculations (bsc#1152489)
- commit 5a34db0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: re-indent code to prepare for DKL changes (bsc#1152489)
- commit 9e43a30
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add support for dkl pll write (bsc#1152489)
- commit 1f0f1bc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add initial dkl pll support (bsc#1152489)
- commit ff34e45
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Simplify gen12_csb_parse (bsc#1152489)
- commit efa8b95
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Do not add all planes when checking scalers on glk+ (bsc#1152489)
- commit c6a2531
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Rename planar linked plane variables (bsc#1152489)
- commit 881d3f8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Get rid of crtc_state->fb_changed (bsc#1152489)
- commit 27fdd2d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add hardware readout for FEC (bsc#1152489)
- commit 5fd7764
* Sat Oct 10 2020 tzimmermann@suse.de
- Revert "drm/i915/color: Extract icl_read_luts()" (bsc#1152489)
- commit a6747d9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Swap engines for no rps (gpu reclocking) (bsc#1152489)
- commit 453c46d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add Pipe D cursor ctrl register for Gen12 (bsc#1152489)
- commit eb37602
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Verify the LRC register layout between init and (bsc#1152489)
- commit 93e5a63
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add TigerLake bandwidth checking (bsc#1152489)
- commit a8f0224
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Check the UC health of tc controllers after power on (bsc#1152489)
- commit ecbc0f2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/icl: Unify disable and enable phy clock gating functions (bsc#1152489)
- commit cd0f039
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add dkl phy registers (bsc#1152489)
- commit ee70660
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl/pll: Set update_active_dpll (bsc#1152489)
- commit 7963761
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Finish modular FIA support on registers (bsc#1152489)
- commit 7248c2b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add missing ddi clock select during DP init sequence (bsc#1152489)
- commit 5809cef
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Relax assertion for a pinned context image on (bsc#1152489)
- commit c0e5ef8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: pass i915 to intel_modeset_init() and (bsc#1152489)
- commit e6b05dd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: abstract intel_mode_config_init() from intel_modeset_init() (bsc#1152489)
- commit 86583bd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: abstract intel_panel_sanitize_ssc() from (bsc#1152489)
- commit 8a568a6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: pass i915 to intel_modeset_driver_remove() (bsc#1152489)
- commit 3042afe
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: pass i915 to i915_driver_modeset_probe() (bsc#1152489)
- commit 7cd5912
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: add i915_driver_modeset_remove() (bsc#1152489)
- commit f38a190
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: save AUD_FREQ_CNTRL state at audio domain suspend (bsc#1152489)
- commit ea7d84f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dsb: Documentation for DSB. (bsc#1152489)
- commit d3646bc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dsb: Enable DSB for gen12. (bsc#1152489)
- commit 4f44fa7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dsb: Enable gamma lut programming using DSB. (bsc#1152489)
- commit c220374
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dsb: function to trigger workload execution of DSB. (bsc#1152489)
- commit 6534f0b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dsb: functions to enable/disable DSB engine. (bsc#1152489)
- commit 4dded1d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dsb: Check DSB engine status. (bsc#1152489)
- commit 9debd2a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dsb: Indexed register write function for DSB. (bsc#1152489)
- commit d474ded
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dsb: single register write function for DSB. (bsc#1152489)
- commit fb179c3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dsb: DSB context creation. (bsc#1152489)
- commit 3324d72
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/dsb: feature flag added for display state buffer. (bsc#1152489)
- commit e03171a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/color: Extract icl_read_luts() (bsc#1152489)
- commit 61f78fd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/color: Fix formatting issues (bsc#1152489)
- commit 791ad5f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: s/ss/eu fuse reading support (bsc#1152489)
- commit fc9c424
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add PIPECONF YCbCr 4:4:4 programming for ILK-IVB (bsc#1152489)
- commit 7a4fcff
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Set up ILK/SNB csc unit properly for YCbCr output (bsc#1152489)
- commit cc1ae29
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Document ILK+ pipe csc matrix better (bsc#1152489)
- commit 3456fd4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add PIPECONF YCbCr 4:4:4 programming for HSW (bsc#1152489)
- commit 334ac3a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Simplify intel_get_crtc_ycbcr_config() (bsc#1152489)
- commit cd69e55
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Don't look at unrelated PIPECONF bits for interlaced (bsc#1152489)
- commit 745ba78
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Never set limited_color_range=true for YCbCr output (bsc#1152489)
- commit d73a279
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Extract intel_hdmi_limited_color_range() (bsc#1152489)
- commit 53c3c3e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix AVI infoframe quantization range for YCbCr output (bsc#1152489)
- commit b87c688
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix HSW+ DP MSA YCbCr colorspace indication (bsc#1152489)
- commit 229f2ea
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/uc: Update HuC firmware naming convention and load latest (bsc#1152489)
- commit c4d6417
* Sat Oct 10 2020 tzimmermann@suse.de
- Revert "drm/i915/tgl: Implement Wa_1406941453" (bsc#1152489)
- commit 8bc9df0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Protect timeline->hwsp dereferencing (bsc#1152489)
- commit d888c86
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Lock signaler timeline while navigating (bsc#1152489)
- commit ccc44c4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Mark i915_request.timeline as a volatile, rcu pointer (bsc#1152489)
- commit 517a7c6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Suspend pre-parser across GTT invalidations (bsc#1152489)
- commit cb84ad0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Don't advertise modes that exceed the max plane size (bsc#1152489)
- commit 03a716f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Implement Wa_1406941453 (bsc#1152489)
- commit f921541
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Implement Wa_1409142259 (bsc#1152489)
- commit faf711d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Unify ICP and MCC hotplug pin tables (bsc#1152489)
- commit 9f92280
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Future-proof DDC pin mapping (bsc#1152489)
- commit 4bbf6f8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Exercise CS TLB invalidation (bsc#1152489)
- commit d917d07
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: fix SFC reset flow (bsc#1152489)
- commit 5cda799
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Extend MI_SEMAPHORE_WAIT (bsc#1152489)
- commit 8657d96
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Only apply a rmw mmio update if the value changes (bsc#1152489)
- commit c285e91
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Show the logical context ring state on dumping (bsc#1152489)
- commit afb584f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: stop conflating HAS_DISPLAY() and disabled display (bsc#1152489)
- commit ce68e20
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: s/pipe_config/crtc_state/ in intel_crtc_atomic_check() (bsc#1152489)
- commit bc043d9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Extract intel_modeset_calc_cdclk() (bsc#1152489)
- commit a037bf7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Allow downscale factor of <3.0 on glk+ for all formats (bsc#1152489)
- commit 5cd5406
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Replace is_planar_yuv_format() with (bsc#1152489)
- commit 1e6da05
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: introduce INTEL_DISPLAY_ENABLED() (bsc#1152489)
- commit 0a95cf6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Re-enable rc6 (bsc#1152489)
- commit c81f692
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Introduce gen12 forcewake ranges (bsc#1152489)
- commit 9978e18
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Update Gen11 forcewake ranges (bsc#1152489)
- commit 76dffb3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Limit ourselves to just rcs0 (bsc#1152489)
- commit c8e89e0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display/icl: Bump up the plane/fb height (bsc#1152489)
- commit f857610
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display/icl: Bump up the hdisplay and vdisplay as per (bsc#1152489)
- commit 88ddb6e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gtt: Make sure the gen6 ppgtt is bound before first use (bsc#1152489)
- commit fdff5dd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Keep the engine awake while we keep for (bsc#1152489)
- commit 1d06634
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Get the correct wakeref for reading HOTPLUG_EN et al. (bsc#1152489)
- commit 6eadbe5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Disable preemption while being debugged (bsc#1152489)
- commit 1e4dcb9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/pmu: Use GT parked for estimating RC6 while asleep (bsc#1152489)
- commit 0dfed7f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: convert device info num_pipes to pipe_mask (bsc#1152489)
- commit 50a3c56
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/pmu: Skip busyness sampling when and where not needed (bsc#1152489)
- commit 2a05551
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Ensure the context is reloaded after a GPU reset (bsc#1152489)
- commit f9a60c2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Add a paranoid flush of the CSB pointers upon (bsc#1152489)
- commit 1a59374
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Disable FBC if BIOS reserved memory (stolen) is unavailable (bsc#1152489)
- commit 1f2994f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove duplicated bxt/cnl/icl .modeset_calc_cdclk() funcs (bsc#1152489)
- commit 932658e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Reuse cnl_modeset_calc_cdclk() on icl+ (bsc#1152489)
- commit f972b41
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix CD2X pipe select masking during cdclk sanitation (bsc#1152489)
- commit cdcf9a4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix cdclk bypass freq readout for tgl/bxt/glk (bsc#1152489)
- commit 88efb42
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: add INTEL_NUM_PIPES() and use it (bsc#1152489)
- commit e776ef0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Squeeze iommu status into debugfs/i915_capabilities (bsc#1152489)
- commit d85bf06
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Disable read-only ppgtt support (bsc#1152489)
- commit 85f5fed
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove pointless planes_changed=true assignment (bsc#1152489)
- commit 6c7e866
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use a high priority wq for nonblocking plane updates (bsc#1152489)
- commit fceae3d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Add glk_cdclk_table (bsc#1152489)
- commit 441e2f2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Make i915_vma.flags atomic_t for mutex reduction (bsc#1152489)
- commit 15206c6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Make shrink/unshrink be atomic (bsc#1152489)
- commit 2cc601f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Make pm_notify take intel_gt (bsc#1152489)
- commit 979a5d7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Avoid round-trip via i915 in intel_gt_park (bsc#1152489)
- commit 1d15521
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Make wait_for_timelines take struct intel_gt (bsc#1152489)
- commit 5746ac9
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Move GT init to intel_gt.c (bsc#1152489)
- commit 8084472
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Consolidate {bxt,cnl,icl}_init_cdclk (bsc#1152489)
- commit 6aaca23
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Enhance cdclk sanitization (bsc#1152489)
- commit 2b2b8b3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add calc_voltage_level display vfunc (bsc#1152489)
- commit c27ce03
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Consolidate {bxt,cnl,icl}_uninit_cdclk (bsc#1152489)
- commit 11c3e1a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Kill cnl_sanitize_cdclk() (bsc#1152489)
- commit e6af56e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Combine bxt_set_cdclk and cnl_set_cdclk (bsc#1152489)
- commit 68bea8a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use literal representation of cdclk tables (bsc#1152489)
- commit 3c75fba
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Consolidate bxt/cnl/icl cdclk readout (bsc#1152489)
- commit 4c311bf
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Disable rc6 for debugging (bsc#1152489)
- commit b60b1ac
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Tighten the timeout testing for partial mmaps (bsc#1152489)
- commit 9aecbd1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Take runtime wakeref for igt_ggtt_lowlevel (bsc#1152489)
- commit 9d2e492
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/ringbuffer: Flush writes before RING_TAIL update (bsc#1152489)
- commit db63cd7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Ignore lost completion events (bsc#1152489)
- commit 442250d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Extract chv_read_luts() (bsc#1152489)
- commit c83e564
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Extract i965_read_luts() (bsc#1152489)
- commit 938751a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Add gamma precision function for CHV (bsc#1152489)
- commit e02fd44
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Clear STOP_RING bit on reset (bsc#1152489)
- commit a5ab862
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: include GTT page-size info in error state (bsc#1152489)
- commit 239a320
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: cleanup cache-coloring (bsc#1152489)
- commit 139a142
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: s/i915_gtt_color_adjust/i915_ggtt_color_adjust (bsc#1152489)
- commit 3194c07
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: export color_differs (bsc#1152489)
- commit 9981b95
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/buddy: add missing call to i915_global_register (bsc#1152489)
- commit 5d772a0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Hook up GT power management (bsc#1152489)
- commit aebc92b
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Register state context definition for Gen12 (bsc#1152489)
- commit 4483ad1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use engine relative LRIs on context setup (bsc#1152489)
- commit 2456b6a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Use refclk/2 as bypass frequency (bsc#1152489)
- commit e6be8cb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: add immutable zpos plane properties (bsc#1152489)
- commit 6a66be2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Protect debugfs per_file_stats with RCU lock (bsc#1152489)
- commit bd554cd
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/mst: Do not hardcoded the crtcs that encoder can connect (bsc#1152489)
- commit de024b3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Apply FBC WA for TGL too (bsc#1152489)
- commit 94d9f2a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: add gen12 to stolen initialization (bsc#1152489)
- commit a6a2d49
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: disable SAGV temporarily (bsc#1152489)
- commit 147be73
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: move DP_TP_* to transcoder (bsc#1152489)
- commit 1d15c42
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: protect access to DP_TP_* on non-dp (bsc#1152489)
- commit 925fe81
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Access the right register when handling PSR (bsc#1152489)
- commit e5a6321
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/psr: Only handle interruptions of the transcoder in use (bsc#1152489)
- commit 3cf67f1
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: disable set/get_tiling ioctl on gen12+ (bsc#1152489)
- commit 30145a3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Extract glk_read_luts() (bsc#1152489)
- commit 2bf8d5e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Extract ilk_read_luts() (bsc#1152489)
- commit f9631ba
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Extract i9xx_read_luts() (bsc#1152489)
- commit 185c8da
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Add macro to compare gamma hw/sw lut (bsc#1152489)
- commit d59f7e4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Add func to compare hw/sw gamma lut (bsc#1152489)
- commit b8a67b6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Add func to get gamma bit precision (bsc#1152489)
- commit 793c185
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Add debug log for color parameters (bsc#1152489)
- commit ffff1d3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Refresh the errno to vmf_fault translations (bsc#1152489)
- commit 01292c6
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Remove unused __engines_name() (bsc#1152489)
- commit 52fef51
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Replace obj->pin_global with obj->frontbuffer (bsc#1152489)
- commit 31ac197
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Report aliasing ppgtt size as ggtt size (bsc#1152489)
- commit 729c069
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Restrict the aliasing-ppgtt to the size of the ggtt (bsc#1152489)
- commit b6f0c32
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Clean up HDMI deep color handling a bit (bsc#1152489)
- commit e1727eb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Prefer encoder->name over port_name() (bsc#1152489)
- commit 1aa5554
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/perf: Assert locking for i915_init_oa_perf_state() (bsc#1152489)
- commit e657c3a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add 324mhz and 326.4mhz cdclks for gen11+ (bsc#1152489)
- commit 0a98463
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Allow /2 CD2X divider on gen11+ (bsc#1152489)
- commit de05d7a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Fix regression with crtc disable ordering (bsc#1152489)
- commit 8e79a93
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use RCU for unlocked vm_idr lookup (bsc#1152489)
- commit a22d4e7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove ppgtt->dirty_engines (bsc#1152489)
- commit 9675dc2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gtt: Downgrade Cherryview back to aliasing-ppgtt (bsc#1152489)
- commit 3d07b9d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gtt: Downgrade gen7 (ivb, byt, hsw) back to aliasing-ppgtt (bsc#1152489)
- commit 647bb61
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: unify icp, tgp and mcc irq setup (bsc#1152489)
- commit 9c95039
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: parameterize SDE hotplug registers (bsc#1152489)
- commit 35f4991
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: unify icp, tgp and mcc irq handling (bsc#1152489)
- commit fdab0ed
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: parameterize south hpd macros (bsc#1152489)
- commit 8cf2c34
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Indent GuC/WOPCM documentation sections (bsc#1152489)
- commit 198b749
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Remove link to missing "Batchbuffer Pools" documentation (bsc#1152489)
- commit ca5eb24
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/hdcp: Enable HDCP 1.4 and 2.2 on Gen12+ (bsc#1152489)
- commit 3cf7d15
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/hdcp: update current transcoder into intel_hdcp (bsc#1152489)
- commit 3aa5e5f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Extend I915 mei interface for transcoder info (bsc#1152489)
- commit 0f4fc72
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Move port definition back to i915 header (bsc#1152489)
- commit 9942c74
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: mei_hdcp: I915 sends ddi index as per ME FW (bsc#1152489)
- commit 248788a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Try rearranging breadcrumb flush (bsc#1152489)
- commit cfb36ee
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Move the commit_tail() disable sequence to separate (bsc#1152489)
- commit 9329415
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/display: Rename update_crtcs() to commit_modeset_enables() (bsc#1152489)
- commit 38bf2a0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: s/for_each_sgt_dma/for_each_sgt_daddr/ (bsc#1152489)
- commit 1b46751
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/uc: Extract common code from GuC stop/disable comm (bsc#1152489)
- commit a8fe2e8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: cond_resched() within the longer buddy tests (bsc#1152489)
- commit ad581f5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: PSR link standby is not supported anymore (bsc#1152489)
- commit 3cb0991
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Gen-12 display loses Yf tiling and legacy CCS support (bsc#1152489)
- commit 93bc354
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Enabling DSC on Pipe A for TGL (bsc#1152489)
- commit cbfaa96
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Protect our local workers against I915_FENCE_TIMEOUT (bsc#1152489)
- commit d65266a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Align power domain names with port names (bsc#1152489)
- commit 6c244c2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Ignore coherency failures on Broadwater (bsc#1152489)
- commit 7579940
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Extend non readable mcr range (bsc#1152489)
- commit 602e16f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/execlists: Flush the post-sync breadcrumb write harder (bsc#1152489)
- commit 89e58f3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Try to recycle context allocations (bsc#1152489)
- commit b78b621
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Remove accidental serialization between gpu_fill (bsc#1152489)
- commit faa5255
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: use a separate context for gpu relocs (bsc#1152489)
- commit 7d4c434
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl/perf: use the same oa ctx_id format as icl (bsc#1152489)
- commit bd99b5a
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Do not apply WaIncreaseDefaultTLBEntries from GEN12 (bsc#1152489)
- commit a0757cc
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Implement TGL DisplayPort training sequence (bsc#1152489)
- commit 77865ce
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Disable pipes in reverse order (bsc#1152489)
- commit eb35315
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: Add for_each_oldnew_intel_crtc_in_state_reverse() (bsc#1152489)
- commit f8cb5f8
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Add maximum resolution supported by PSR2 HW (bsc#1152489)
- commit 3444a8e
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Do not read PSR2 register in transcoders without PSR2 (bsc#1152489)
- commit e448d63
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Guard and warn if more than one eDP panel is present (bsc#1152489)
- commit 6c22271
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Make engine's batch pool safe for use with virtual engines (bsc#1152489)
- commit d080192
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Only activate i915_active debugobject once (bsc#1152489)
- commit 9b03de7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Markup impossible error pointers (bsc#1152489)
- commit 3b64017
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Add the usual batch vma managements to (bsc#1152489)
- commit 5a0fc25
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/selftests: Teach igt_gpu_fill_dw() to take intel_context (bsc#1152489)
- commit 0de4633
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Keep drm_i915_file_private around under RCU (bsc#1152489)
- commit f0505e0
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/uc: define GuC and HuC FWs for EHL (bsc#1152489)
- commit b2945f2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/gtt: Preallocate Braswell top-level page directory (bsc#1152489)
- commit c35feb5
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use hweight8() for 8bit masks (bsc#1152489)
- commit f41d84c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: s/num_active_crtcs/num_active_pipes/ (bsc#1152489)
- commit e44f79d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use enum pipe consistently (bsc#1152489)
- commit 83f5608
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Unconfuse pipe vs. crtc->index in (bsc#1152489)
- commit 30177d7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use enum pipe instead of crtc index to track active pipes (bsc#1152489)
- commit ec1aeb2
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add new function to copy subslices for a slice (bsc#1152489)
- commit d39a475
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Refactor instdone loops on new subslice functions (bsc#1152489)
- commit d5241c7
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add function to determine if a slice has a subslice (bsc#1152489)
- commit 8bb9645
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use subslice stride to set subslices for a given slice (bsc#1152489)
- commit e41e00d
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add function to set subslices (bsc#1152489)
- commit 8d7ada3
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use local variables for subslice_mask for device info (bsc#1152489)
- commit 0a4ecbb
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add EU stride runtime parameter (bsc#1152489)
- commit a851342
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add subslice stride runtime parameter (bsc#1152489)
- commit e3fb2c4
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add function to set SSEU info per platform (bsc#1152489)
- commit 085cf4f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Use variable for debugfs device status (bsc#1152489)
- commit f1fa8ad
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Enable VD HCP/MFX sub-pipe power gating (bsc#1152489)
- commit 458c33c
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/tgl: Move GTCR register to cope with GAM MMIO address remap (bsc#1152489)
- commit 0a67a64
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/dp/dsc: Add Support for all BPCs supported by TGL (bsc#1152489)
- commit d6b2710
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Do not unmask PSR interruption in IRQ postinstall (bsc#1152489)
- commit cf16b11
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Add transcoder restriction to PSR2 (bsc#1152489)
- commit 2cc4c01
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915/psr: Make PSR registers relative to transcoders (bsc#1152489)
- commit c4d0100
* Sat Oct 10 2020 tzimmermann@suse.de
- drm: bridge: dw-hdmi: Report connector status using callback (bsc#1152489)
- commit 4b30872
* Sat Oct 10 2020 tzimmermann@suse.de
- locking/refcount: Consolidate implementations of refcount_t (bsc#1152489)
- commit 3fdbc14
* Sat Oct 10 2020 tzimmermann@suse.de
- locking/lockdep: Remove unused @nested argument from lock_release() (bsc#1152489)
- commit 630403f
* Sat Oct 10 2020 tzimmermann@suse.de
- drm/i915: Replace rcu_swap_protected() with rcu_replace_pointer() (bsc#1152489)
- commit 933c81e
* Sat Oct 10 2020 tzimmermann@suse.de
- vgacon: Use pr_warn instead of pr_warning (bsc#1152489)
- commit e8b32b1
* Fri Oct  9 2020 ohering@suse.de
- hv_netvsc: Add validation for untrusted Hyper-V values
  (jsc#sle-12891).
- hv_netvsc: Cache the current data path to avoid duplicate call
  and message (jsc#sle-12891).
- hv_netvsc: Switch the data path at the right time during
  hibernation (jsc#sle-12891).
- hv_netvsc: Fix hibernation for mlx5 VF driver (jsc#sle-12891).
- x86/hyperv: Make hv_setup_sched_clock inline (jsc#sle-12891).
- PCI: hv: Make some functions static (jsc#sle-12891).
- scsi: storvsc: Add validation for untrusted Hyper-V values
  (jsc#sle-12891).
- scsi: storvsc: Fix spelling mistake (jsc#sle-12891).
- hyperv: hyperv.h: drop a duplicated word (jsc#sle-12891).
- tools: hv: change http to https in hv_kvp_daemon.c
  (jsc#sle-12891).
- Drivers: hv: vmbus: Remove the lock field from the vmbus_channel
  struct (jsc#sle-12891).
- scsi: storvsc: Introduce the per-storvsc_device spinlock
  (jsc#sle-12891).
- Drivers: hv: vmbus: Remove unnecessary channel->lock critical
  sections (sc_list updaters) (jsc#sle-12891).
- Drivers: hv: vmbus: Use channel_mutex in
  channel_vp_mapping_show() (jsc#sle-12891).
- Drivers: hv: vmbus: Remove unnecessary channel->lock critical
  sections (sc_list readers) (jsc#sle-12891).
- Drivers: hv: vmbus: Replace cpumask_test_cpu(, cpu_online_mask)
  with cpu_online() (jsc#sle-12891).
- Drivers: hv: vmbus: Remove the numa_node field from the
  vmbus_channel struct (jsc#sle-12891).
- Drivers: hv: vmbus: Remove the target_vp field from the
  vmbus_channel struct (jsc#sle-12891).
- net: hyperv: dump TX indirection table to ethtool regs
  (jsc#sle-12891).
- hv_netvsc: add support for vlans in AF_PACKET mode
  (jsc#sle-12891).
- scsi: storvsc: Remove memset before memory freeing in
  storvsc_suspend() (jsc#sle-12891).
- uio_hv_generic: add missed sysfs_remove_bin_file
  (jsc#sle-12891).
- PCI: hv: Use struct_size() helper (jsc#sle-12891).
- commit 5c0cd66
* Fri Oct  9 2020 ohering@suse.de
- hv_netvsc: Add XDP frame size to driver (jsc#sle-12891).
- commit a5b22bb
* Fri Oct  9 2020 ohering@suse.de
- Drivers: hv: vmbus: Resolve more races involving init_vp_index()
  (jsc#sle-12891).
- Drivers: hv: vmbus: Resolve race between init_vp_index()
  and CPU hotplug (jsc#sle-12891).
- vmbus: Replace zero-length array with flexible-array
  (jsc#sle-12891).
- Driver: hv: vmbus: drop a no long applicable comment
  (jsc#sle-12891).
- hyper-v: Replace open-coded variant of %%*phN specifier
  (jsc#sle-12891).
- hyper-v: Supply GUID pointer to printf() like functions
  (jsc#sle-12891).
- hyper-v: Use UUID API for exporting the GUID (part 2)
  (jsc#sle-12891).
- x86/hyperv: Split hyperv-tlfs.h into arch dependent and
  independent files (jsc#sle-12891).
- x86/hyperv: Remove HV_PROCESSOR_POWER_STATE #defines
  (jsc#sle-12891).
- KVM: x86: hyperv: Remove duplicate definitions of Reference
  TSC Page (jsc#sle-12891).
- drivers: hv: remove redundant assignment to pointer
  primary_channel (jsc#sle-12891).
- scsi: storvsc: Re-init stor_chns when a channel interrupt is
  re-assigned (jsc#sle-12891).
- Drivers: hv: vmbus: Introduce the CHANNELMSG_MODIFYCHANNEL
  message type (jsc#sle-12891).
- Drivers: hv: vmbus: Synchronize init_vp_index() vs. CPU hotplug
  (jsc#sle-12891).
- Drivers: hv: vmbus: Remove the unused HV_LOCALIZED channel
  affinity logic (jsc#sle-12891).
- PCI: hv: Prepare hv_compose_msi_msg() for the
  VMBus-channel-interrupt-to-vCPU reassignment functionality
  (jsc#sle-12891).
- Drivers: hv: vmbus: Use a spin lock for synchronizing channel
  scheduling vs. channel removal (jsc#sle-12891).
- hv_utils: Always execute the fcopy and vss callbacks in a
  tasklet (jsc#sle-12891).
- hv_netvsc: Disable NAPI before closing the VMBus channel
  (jsc#sle-12891).
- Drivers: hv: vmbus: Replace the per-CPU channel lists with a
  global array of channels (jsc#sle-12891).
- Drivers: hv: vmbus: Don't bind the offer&rescind works to a
  specific CPU (jsc#sle-12891).
- Drivers: hv: vmbus: Always handle the VMBus messages on CPU0
  (jsc#sle-12891).
- Drivers: hv: check VMBus messages lengths (jsc#sle-12891).
- Drivers: hv: make sure that 'struct
  vmbus_channel_message_header' compiles correctly
  (jsc#sle-12891).
- Drivers: hv: avoid passing opaque pointer to vmbus_onmessage()
  (jsc#sle-12891).
- Drivers: hv: allocate the exact needed memory for messages
  (jsc#sle-12891).
- Drivers: hv: copy from message page only what's needed
  (jsc#sle-12891).
- x86/hyperv: Properly suspend/resume reenlightenment
  notifications (jsc#sle-12891).
- hyper-v: Remove internal types from UAPI header (jsc#sle-12891).
- hyper-v: Use UUID API for exporting the GUID (jsc#sle-12891).
- x86/hyperv: Suspend/resume the VP assist page for hibernation
  (jsc#sle-12891).
- Drivers: hv: Move AEOI determination to architecture dependent
  code (jsc#sle-12891).
- Drivers: hv: vmbus: Fix Suspend-to-Idle for Generation-2 VM
  (jsc#sle-12891).
- hv_debugfs: Make hv_debug_root static (jsc#sle-12891).
- hv: hyperv_vmbus.h: Replace zero-length array with
  flexible-array member (jsc#sle-12891).
- PCI: hv: Replace zero-length array with flexible-array member
  (jsc#sle-12891).
- PCI: hv: Add missing kfree(hbus) in hv_pci_probe()'s error
  handling path (jsc#sle-12891).
- PCI: hv: Remove unnecessary type casting from kzalloc
  (jsc#sle-12891).
- hv_netvsc: Remove unnecessary round_up for recv_completion_cnt
  (jsc#sle-12891).
- hv_netvsc: use new helper tcp_v6_gso_csum_prep (jsc#sle-12891).
- HID: hyperv: NULL check before some freeing functions is not
  needed (jsc#sle-12891).
- hv_netvsc: Fix XDP refcnt for synthetic and VF NICs
  (jsc#sle-12891).
- x86/hyper-v: Add "polling" bit to hv_synic_sint (jsc#sle-12891).
- commit 1ab51b9
* Fri Oct  9 2020 ohering@suse.de
- x86/hyperv: Suspend/resume the hypercall page for hibernation (jsc#sle-12891).
- commit 837a396
* Fri Oct  9 2020 ohering@suse.de
- hv_utils: Add the support of hibernation (jsc#sle-12891).
- hv_utils: Support host-initiated hibernation request
  (jsc#sle-12891).
- hv_utils: Support host-initiated restart request
  (jsc#sle-12891).
- Tools: hv: Reopen the devices if read() or write() returns
  errors (jsc#sle-12891).
- video: hyperv: hyperv_fb: Use physical memory for fb on HyperV
  Gen 1 VMs (jsc#sle-12891).
- Drivers: hv: vmbus: Ignore CHANNELMSG_TL_CONNECT_RESULT(23)
  (jsc#sle-12891).
- video: hyperv_fb: Fix hibernation for the deferred IO feature
  (jsc#sle-12891).
- Input: hyperv-keyboard: Add the support of hibernation
  (jsc#sle-12891).
- commit 9928da6
* Fri Oct  9 2020 ohering@suse.de
- hv_netvsc: Add XDP support (jsc#sle-12891).
- commit 85fce4e
* Fri Oct  9 2020 ohering@suse.de
- video: hyperv_fb: fix indentation issue (jsc#sle-12891).
- KVM: hyperv: Fix some typos in vcpu unimpl info (jsc#sle-12891).
- PCI: hv: Avoid a kmemleak false positive caused by the hbus
  buffer (jsc#sle-12891).
- commit fad9e46
* Fri Oct  9 2020 ohering@suse.de
- PCI: hv: Add hibernation support (jsc#sle-12891).
- commit 7b1f5fc
* Fri Oct  9 2020 ohering@suse.de
- drivers/hv: Replace binary semaphore with mutex (jsc#sle-12891).
- HID: hyperv: Add the support of hibernation (jsc#sle-12891).
- hv_balloon: Add the support of hibernation (jsc#sle-12891).
- hv_netvsc: make recording RSS hash depend on feature flag
  (jsc#sle-12891).
- commit 3adaf81
* Fri Oct  9 2020 ohering@suse.de
- x86/hyperv: Implement hv_is_hibernation_supported() (jsc#sle-12891).
- commit ef75f54
* Fri Oct  9 2020 ohering@suse.de
- x86: hv: Add function to allocate zeroed page for Hyper-V
  (jsc#sle-12891).
- Drivers: hv: util: Specify ring buffer size using Hyper-V page
  size (jsc#sle-12891).
- tools: hv: add vmbus testing tool (jsc#sle-12891).
- commit 5fb51bd
* Fri Oct  9 2020 ohering@suse.de
- drivers: hv: vmbus: Introduce latency testing (jsc#sle-12891).
- commit 13a6e68
* Fri Oct  9 2020 ohering@suse.de
- video: hyperv: hyperv_fb: Support deferred IO for Hyper-V
  frame buffer driver (jsc#sle-12891).
- video: hyperv: hyperv_fb: Obtain screen resolution from Hyper-V
  host (jsc#sle-12891).
- hv_netvsc: Add the support of hibernation (jsc#sle-12891).
- video: hyperv_fb: Add the support of hibernation
  (jsc#sle-12891).
- scsi: storvsc: Add the support of hibernation (jsc#sle-12891).
- Drivers: hv: vmbus: Add module parameter to cap the VMBus
  version (jsc#sle-12891).
- Drivers: hv: vmbus: Enable VMBus protocol versions 4.1, 5.1
  and 5.2 (jsc#sle-12891).
- Drivers: hv: vmbus: Introduce table of VMBus protocol versions
  (jsc#sle-12891).
- x86/hyperv: Initialize clockevents earlier in CPU onlining
  (jsc#sle-12891).
- x86/hyperv: Micro-optimize send_ipi_one() (jsc#sle-12891).
- hv_netvsc: record hardware hash in skb (jsc#sle-12891).
- commit 89088d3
* Fri Oct  9 2020 ohering@suse.de
- Delete patches.suse/suse-hv-kabi.patch.
- commit bee8fd0
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: block-group: fix free-space bitmap threshold
  (bsc#1176019).
- commit c27162b
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: remove no longer necessary chunk mutex locking cases
  (bsc#1176019).
- commit db60a0b
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: move the block group freeze/unfreeze helpers into
  block-group.c (bsc#1176019).
- commit 9efb8a2
* Fri Oct  9 2020 hare@suse.de
- block: only call sched requeue_request() for scheduled
  (bsc#1177434).
- block: ensure bdi->io_pages is always initialized (bsc#1177434).
- block: fix get_max_io_size() (bsc#1177434).
- blk-mq: insert request not through ->queue_rq into
  (bsc#1177434).
- block: respect queue limit of max discard segment (bsc#1177434).
- blk-mq: order adding requests to hctx->dispatch and checking
  (bsc#1177434).
- block: fix double account of flush request's driver tag
  (bsc#1177434).
- blk-mq: centralise related handling into blk_mq_get_driver_tag
  (bsc#1177434).
- Revert "blk-mq: put driver tag when this request is completed"
  (bsc#1177434).
- blk-mq: move blk_mq_put_driver_tag() into blk-mq.c
  (bsc#1177434).
- blktrace: Provide event for request merging (bsc#1177434).
- commit dfd2ab2
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: scrub, only lookup for csums if we are dealing with a
  data extent (bsc#1176019).
- commit d291964
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: rename member 'trimming' of block group to a more
  generic name (bsc#1176019).
- commit 23a7d0c
* Fri Oct  9 2020 mbrugger@suse.com
- KVM: arm64: vgic-v4: Plug race between non-residency and v4.1
  doorbell (jsc#SLE-14773).
- commit 6a85915
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Use readx_poll_timeout_atomic() to fix sleep
  in atomic (jsc#SLE-14773).
- commit 09981f9
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Balance initial LPI affinity across CPUs
  (jsc#SLE-14773).
- commit e0d0ba9
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Track LPI distribution on a per CPU basis
  (jsc#SLE-14773).
- commit 87823d7
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Fix missing "__init" for gic_smp_init()
  (jsc#SLE-14773).
- commit 5030876
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Update effective affinity of virtual SGIs
  (jsc#SLE-14773).
- commit f0d381f
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Add support for VPENDBASER's Dirty+Valid
  signaling (jsc#SLE-14773).
- commit 94d9651
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Eagerly vmap vPEs (jsc#SLE-14773).
- commit eaf0337
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Add VSGI property setup (jsc#SLE-14773).
- commit 6c3fbf5
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Add VSGI allocation/teardown (jsc#SLE-14773).
- commit d5d4872
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Move doorbell management to the GICv4
  abstraction layer (jsc#SLE-14773).
- commit 2f5f2d1
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Plumb set_vcpu_affinity SGI callbacks
  (jsc#SLE-14773).
- commit 973724b
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Plumb get/set_irqchip_state SGI callbacks
  (jsc#SLE-14773).
- commit 3f9198e
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Plumb mask/unmask SGI callbacks
  (jsc#SLE-14773).
- commit 9e35710
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Add initial SGI configuration (jsc#SLE-14773).
- commit c751f42
* Fri Oct  9 2020 mbenes@suse.cz
- Disable CONFIG_LIVEPATCH_IPA_CLONES where not needed
  Explicitly disable CONFIG_LIVEPATCH_IPA_CLONES in configs where it is
  not needed to avoid confusion and unwanted values due to fragment config
  files.
- commit 16f2ac3
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Plumb skeletal VSGI irqchip (jsc#SLE-14773).
- commit 8a5e7e6
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Map the ITS SGIR register page
  (jsc#SLE-14773).
- commit f71e4d3
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Advertise support v4.1 to KVM (jsc#SLE-14773).
- commit 3bc0458
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Ensure mutual exclusion betwen invalidations
  on the same RD (jsc#SLE-14773).
- commit c941d25
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Wait for completion of redistributor's INVALL
  operation (jsc#SLE-14773).
- commit fdd3d4b
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Ensure mutual exclusion between vPE affinity
  change and RD access (jsc#SLE-14773).
- commit a1a032a
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Skip absent CPUs while iterating over
  redistributors (jsc#SLE-14773).
- commit 21c5388
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Use SGIs without active state if offered
  (jsc#SLE-14773).
- commit 74bed69
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Move irq_domain_update_bus_token to after
  checking for NULL domain (jsc#SLE-14773).
- commit 98b0da8
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4: Use Inner-Shareable attributes for virtual
  pending tables (jsc#SLE-14773).
- commit 85dfee2
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Probe ITS page size for all GITS_BASERn
  registers (jsc#SLE-14773).
- commit 6cb2d90
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Fix access width for gicr_syncr
  (jsc#SLE-14773).
- commit 647d317
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Workaround Cavium erratum 38539 when reading
  GICD_TYPER2 (jsc#SLE-14773).
- commit 1358667
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Avoid 64bit division for the sake of 32bit
  ARM (jsc#SLE-14773).
- commit 1be6224
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Rename VPENDBASER/VPROPBASER accessors
  (jsc#SLE-14773).
- commit 6eac9d2
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Remove superfluous WARN_ON (jsc#SLE-14773).
- commit e0e6536
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Drop 'tmp' in inherit_vpe_l1_table_from_rd()
  (jsc#SLE-14773).
- commit f59ff61
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Ensure L2 vPE table is allocated at RD level
  (jsc#SLE-14773).
- commit dcbce6e
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Set vpe_l1_base for all redistributors
  (jsc#SLE-14773).
- commit 71acdf8
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Fix programming of GICR_VPROPBASER_4_1_SIZE
  (jsc#SLE-14773).
- commit 5fc2a5b
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Allow direct invalidation of VLPIs
  (jsc#SLE-14773).
- commit bb02f51
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Suppress per-VLPI doorbell (jsc#SLE-14773).
- commit 023e538
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Add VPE INVALL callback (jsc#SLE-14773).
- commit 4476e69
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Add VPE eviction callback (jsc#SLE-14773).
- commit e50f619
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Add VPE residency callback (jsc#SLE-14773).
- commit dd5c0ad
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Add mask/unmask doorbell callbacks
  (jsc#SLE-14773).
- commit 2621e93
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Plumb skeletal VPE irqchip (jsc#SLE-14773).
- commit c924a3b
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Implement the v4.1 flavour of VMOVP
  (jsc#SLE-14773).
- commit 2dc75cc
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Don't use the VPE proxy if RVPEID is set
  (jsc#SLE-14773).
- commit db68bce
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: Implement the v4.1 flavour of VMAPP
  (jsc#SLE-14773).
- commit 7191688
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v4.1: VPE table (aka GICR_VPROPBASER) allocation
  (jsc#SLE-14773).
- commit fc58412
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Add GICv4.1 VPEID size discovery
  (jsc#SLE-14773).
- commit e088146
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Detect GICv4.1 supporting RVPEID
  (jsc#SLE-14773).
- commit 340e4c1
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Fix get_vlpi_map() breakage with doorbells
  (jsc#SLE-14773).
- commit f24b917
* Fri Oct  9 2020 mbrugger@suse.com
- PCI: Remove unused includes and superfluous struct declaration
  (jsc#SLE-14773).
- Refresh
  patches.suse/iommu-of-take-a-ref-to-the-iommu-driver-during-of_xlate.
- commit 4209838
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Make vlpi_lock a spinlock (jsc#SLE-14773).
- commit 2ae7da2
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Lock VLPI map array before translating it
  (jsc#SLE-14773).
- commit f67a997
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Synchronise INT/CLEAR commands targetting
  a VLPI using VSYNC (jsc#SLE-14773).
- commit 03f3640
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Synchronise INV command targetting a VLPI
  using VSYNC (jsc#SLE-14773).
- commit 908ad92
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Add its_vlpi_map helpers (jsc#SLE-14773).
- commit e068684
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Kill its->device_ids and use TYPER copy
  instead (jsc#SLE-14773).
- commit 401be4e
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Kill its->ite_size and use TYPER copy
  instead (jsc#SLE-14773).
- commit eb42dac
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Make is_v4 use a TYPER copy (jsc#SLE-14773).
- commit 51c4898
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Allow LPI invalidation via the DirectLPI
  interface (jsc#SLE-14773).
- commit e2bbebb
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Factor out wait_for_syncr primitive
  (jsc#SLE-14773).
- commit ed72724
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Free collection mapping on device teardown
  (jsc#SLE-14773).
- commit 8e13baa
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Fix u64 to __le64 warnings (jsc#SLE-14773).
- commit 624193c
* Fri Oct  9 2020 hare@suse.de
- blk-mq: remove the BLK_MQ_REQ_INTERNAL flag (bsc#1177434).
- Refresh
  patches.suse/blk-mq-centralise-related-handling-into-blk_mq_get_d.patch.
- commit b67bb63
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip: Remove redundant semicolon after while (jsc#SLE-14773).
- commit 24bb615
* Fri Oct  9 2020 mbrugger@suse.com
- KVM: arm64: vgic-v4: Move the GICv4 residency flow to be driven
  by vcpu_load/put (jsc#SLE-14773).
- commit 2212e76
* Fri Oct  9 2020 mbrugger@suse.com
- arm64: Relax ICC_PMR_EL1 accesses when ICC_CTLR_EL1.PMHE is
  clear (jsc#SLE-14773).
- commit 05b8576
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Fix GIC_LINE_NR accessor (jsc#SLE-14773).
- commit 0c2d589
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3-its: Remove the redundant set_bit for lpi_map
  (jsc#SLE-14773).
- commit 88f8da8
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Add quirks for HIP06/07 invalid GICD_TYPER
  erratum 161010803 (jsc#SLE-14773).
- commit 2e9b4ee
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic: Skip DT quirks when evaluating IIDR-based quirks
  (jsc#SLE-14773).
- commit 5b87015
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Warn about inconsistent implementations of
  extended ranges (jsc#SLE-14773).
- commit f545763
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Add EPPI range support (jsc#SLE-14773).
- commit 6f59838
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Dynamically allocate PPI partition descriptors
  (jsc#SLE-14773).
- commit 42a531a
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Dynamically allocate PPI NMI refcounts
  (jsc#SLE-14773).
- commit c4acded
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic: Prepare for more than 16 PPIs (jsc#SLE-14773).
- commit 5bad432
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Add ESPI range support (jsc#SLE-14773).
- commit 65b68ee
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic-v3: Add INTID range and convertion primitives
  (jsc#SLE-14773).
- Refresh
  patches.suse/irqchip-gic-v2-v3-Drop-extra-IRQ_NOAUTOEN-setting-fo.patch.
- commit 59e419c
* Fri Oct  9 2020 mbrugger@suse.com
- irqchip/gic: Rework gic_configure_irq to take the full ICFGR
  base (jsc#SLE-14773).
- commit 8ce46f7
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: fix a race between scrub and block group
  removal/allocation (bsc#1176019).
- commit 71bd813
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: block-group: rename write_one_cache_group()
  (bsc#1176019).
- commit 24a6cec
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: block-group: refactor how we insert a block group item
  (bsc#1176019).
- commit 1cecb46
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: block-group: refactor how we delete one block group item
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-fix-a-block-group-ref-counter-leak-after-failu.patch.
- Refresh
  patches.suse/btrfs-fix-race-between-block-group-removal-and-block.patch.
- commit 1825f40
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: block-group: refactor how we read one block group item
  (bsc#1176019).
- commit 91ae416
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: block-group: don't set the wrong READA flag for
  btrfs_read_block_groups() (bsc#1176019).
- commit 6be354e
* Fri Oct  9 2020 tiwai@suse.de
- geneve: add transport ports in route lookup for geneve
  (CVE-2020-25645 bsc#1177511).
- commit 7ab9b46
* Fri Oct  9 2020 msuchanek@suse.de
- Refresh patches.suse/powerpc-papr_scm-Add-PAPR-command-family-to-pass-thr.patch.
- commit aeda59a
* Thu Oct  8 2020 msuchanek@suse.de
- kernel-binary.spec.in: Exclude .config.old from kernel-devel
  - use tar excludes for .kernel-binary.spec.buildenv
- commit 939a79b
* Thu Oct  8 2020 tiwai@suse.de
- r8169: fix handling ether_clk (git-fixes).
- r8169: fix RTL8168f/RTL8411 EPHY config (git-fixes).
- commit 31a1bbe
* Thu Oct  8 2020 tzimmermann@suse.de
- x86/cpu/vmware: Fix platform detection VMWARE_PORT macro (bsc#1152489)
- commit 65b396e
* Thu Oct  8 2020 tzimmermann@suse.de
- x86/cpu/vmware: Use the full form of INL in VMWARE_HYPERCALL, for (bsc#1152489)
- commit 459f07a
* Thu Oct  8 2020 tzimmermann@suse.de
- x86/vmware: Add a header file for hypercall definitions (bsc#1152489)
- commit 9a5e81f
* Thu Oct  8 2020 msuchanek@suse.de
- Fix order of patches in sorted section, fix JIRA references.
- Update patches.suse/x86-cpufeatures-enumerate-enqcmd-and-enqcmds-instructions.patch (jsc#SLE-13318).
- Update patches.suse/x86-resctrl-enumerate-per-thread-mba-controls.patch (jsc#SLE-13356).
- commit 6cfd5fd
* Thu Oct  8 2020 msuchanek@suse.de
- powerpc/rtas: Restrict RTAS requests from userspace
  (jsc#SLE-13644).
  Update config files.
- commit 1098a80
* Thu Oct  8 2020 jroedel@suse.de
- vfio/pci: Decouple PCI_COMMAND_MEMORY bit checks from is_virtfn
  (bsc#1176979).
- commit 3f68ac6
* Thu Oct  8 2020 jroedel@suse.de
- s390/pci: Mark all VFs as not implementing PCI_COMMAND_MEMORY
  (bsc#1176979).
- commit 1afc493
* Thu Oct  8 2020 jroedel@suse.de
- PCI/IOV: Mark VFs as not implementing PCI_COMMAND_MEMORY
  (bsc#1176979).
- commit 36a2c27
* Thu Oct  8 2020 afaerber@suse.com
- blacklist.conf: Realtek DHC Arm SoCs not supported in SLE or Leap
  In v5.3, Realtek Digital Home Center RTD129x and later chipsets are still
  lacking irqchip, clk and any other drivers to actually load a rootfs from.
- commit 2d5007a
* Thu Oct  8 2020 msuchanek@suse.de
- powerpc/xive: Do not expose a debugfs file when XIVE is disabled
  (bsc#1177437 ltc#188522 jsc#SLE-13294).
- powerpc/xive: Add a debugfs file to dump internal XIVE state
  (bsc#1177437 ltc#188522 jsc#SLE-13294).
- Refresh patches.suse/powerpc-xive-Clear-the-page-tables-for-the-ESB-IO-ma.patch
- commit c83741d
* Thu Oct  8 2020 glin@suse.com
- bpf: Fix a verifier issue when assigning 32bit reg states to
  64bit ones (bsc#1177028).
- bpf: Fix use-after-free in fmod_ret check (bsc#1177028).
- bpf: Add bpf_probe_read_{user, kernel}_str() to
  do_refine_retval_range (bsc#1177028).
- bpf: Make bpf_link_fops static (bsc#1177028).
- bpf: Fix leak in LINK_UPDATE and enforce empty old_prog_fd
  (bsc#1177028).
- cpumap: Avoid warning when CONFIG_DEBUG_PER_CPU_MAPS is enabled
  (bsc#1177028).
- bpf: remove unneeded conversion to bool in __mark_reg_unknown
  (bsc#1177028).
- bpf: Fix a typo "inacitve" -> "inactive" (bsc#1177028).
- bpf: Implement bpf_prog replacement for an active
  bpf_cgroup_link (bsc#1177028).
- bpf: Implement bpf_link-based cgroup BPF program attachment
  (bsc#1177028).
- bpf: Verifier, refine 32bit bound in do_refine_retval_range
  (bsc#1177028).
- bpf: Verifier, do explicit ALU32 bounds tracking (bsc#1177028).
- bpf: btf: Fix arg verification in btf_ctx_access()
  (bsc#1177028).
- tools/bpf: Sync uapi header bpf.h (bsc#1177028).
- bpf: add include guard to tnum.h (bsc#1177028).
- commit fc9ce4f
* Thu Oct  8 2020 tiwai@suse.de
- vmxnet3: fix cksum offload issues for non-udp tunnels
  (git-fixes).
- Input: i8042 - add nopnp quirk for Acer Aspire 5 A515
  (bsc#954532).
- clocksource/drivers/timer-gx6605s: Fixup counter reload
  (git-fixes).
- spi: fsl-espi: Only process interrupts for expected events
  (git-fixes).
- mac80211: do not allow bigger VHT MPDUs than the hardware
  supports (git-fixes).
- commit 76e08ef
* Thu Oct  8 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/i2c-i801-exclude-device-from-suspend-direct-complete.patch
- commit 9fbf63b
* Thu Oct  8 2020 glin@suse.com
- bpf: lsm: Implement attach, detach and execution (bsc#1177028).
  Refresh patches
- patches.suse/bpf-Prevent-mmap-ing-read-only-maps-as-writable.patch
- bpf: lsm: Provide attachment points for BPF LSM programs
  (bsc#1177028).
- security: Refactor declaration of LSM hooks (bsc#1177028).
  Update patches.suse/0001-security-lockdown-expose-a-hook-to-lock-the-kernel-down.patch
- Move the declaration of lock_kernel_down() from
  include/linux/lsm_hooks.h to include/linux/lsm_hook_defs.h
- perf_event: Add support for LSM and SELinux checks (bsc#1177028).
  Update patches
- patches.suse/powerpc-perf-Ignore-the-BHRB-kernel-address-filterin.patch
- patches.suse/0001-security-create-hidden-area-to-keep-sensitive-data.patch
- patches.suse/0001-security-lockdown-expose-a-hook-to-lock-the-kernel-down.patch
- fanotify, inotify, dnotify, security: add security hook for
  fs notifications (bsc#1177028).
- commit c8a9222
* Thu Oct  8 2020 glin@suse.com
- bpf: Introduce BPF_PROG_TYPE_LSM (bsc#1177028).
  Update config files for CONFIG_BPF_LSM
- libbpf: Add support for program extensions (bsc#1177028).
- libbpf: Load btf_vmlinux only once per object (bsc#1177028).
- libbpf: Fix potential multiplication overflow in mmap() size
  calculation (bsc#1177028).
- libbpf: Expose bpf_find_kernel_btf as a LIBBPF_API
  (bsc#1177028).
- libbpf: Poison kernel-only integer types (bsc#1177028).
- bpf: libbpf: Add STRUCT_OPS support (bsc#1177028).
- libbpf: BTF is required when externs are present (bsc#1177028).
- libbpf: Put Kconfig externs into .kconfig section (bsc#1177028).
- bpftool, selftests/bpf: Embed object file inside skeleton (bsc#1177028).
  Refresh patches.suse/selftests-bpf-Validate-frozen-map-contents-stays-fro.patch
- bpftool: Fix compilation warning on shadowed variable
  (bsc#1177028).
- bpftool: Generate externs datasec in BPF skeleton (bsc#1177028).
- libbpf: Support libbpf-provided extern variables (bsc#1177028).
  Refresh patches.suse/bpf-Introduce-function-by-function-verification.patch
- selftests/bpf: Add BPF skeletons selftests and convert
  attach_probe.c (bsc#1177028).
- libbpf: Fix build on read-only filesystems (bsc#1177028).
- selftests/bpf: Bring back c++ include/link test (bsc#1177028).
- selftests/bpf: Ensure no DWARF relocations for BPF object files
  (bsc#1177028).
- selftests/bpf: Enforce no-ALU32 for test_progs-no_alu32
  (bsc#1177028).
- selftests/bpf: Fix .gitignore to ignore no_alu32/ (bsc#1177028).
- bpf, doc: Add Andrii as official reviewer to BPF subsystem
  (bsc#1177028).
- commit 01dbecc
* Thu Oct  8 2020 lduncan@suse.com
- scsi: target: Fix lun lookup for TARGET_SCF_LOOKUP_LUN_FROM_TAG
  case (bsc#1177393).
- commit 70763bb
* Wed Oct  7 2020 msuchanek@suse.de
- kernel-binary.spec.in: Package the obj_install_dir as explicit filelist.
- commit 5587762
* Wed Oct  7 2020 lduncan@suse.com
- scsi: target: iscsi: Fix hang in iscsit_access_np() when
  getting tpg->np_login_sem (bsc#1177393).
- scsi: target: iscsi: Fix data digest calculation (bsc#1177393).
- scsi: target: Make iscsit_register_transport() return void
  (bsc#1177393).
- scsi: target: tcmu: Make TMR notification optional
  (bsc#1177393).
- scsi: target: tcmu: Implement tmr_notify callback (bsc#1177393).
- scsi: target: tcmu: Fix and simplify timeout handling
  (bsc#1177393).
- scsi: target: tcmu: Factor out new helper ring_insert_padding
  (bsc#1177393).
- scsi: target: tcmu: Do not queue aborted commands (bsc#1177393).
- scsi: target: tcmu: Use priv pointer in se_cmd (bsc#1177393).
- scsi: target: Add tmr_notify backend function (bsc#1177393).
- scsi: target: Modify core_tmr_abort_task() (bsc#1177393).
- scsi: target: iscsi: Fix inconsistent debug message
  (bsc#1177393).
- scsi: target: iscsi: Fix login error when receiving
  (bsc#1177393).
- scsi: target: Remove unused variable 'tpg' (bsc#1177393).
- scsi: target: Handle short iSIDs (bsc#1177393).
- scsi: target: Fix iscsi transport id buf len calculation
  (bsc#1177393).
- scsi: target: Fix iscsi transport id buffer setup (bsc#1177393).
- scsi: target: Fix iscsi transport id parsing (bsc#1177393).
- scsi: target: Fix crash during SPEC_I_PT handling (bsc#1177393).
- scsi: target: Fix xcopy sess release leak (bsc#1177393).
- scsi: target: Check enforce_pr_isids during registration
  (bsc#1177393).
- scsi: target: tcmu: Fix crash on ARM during cmd completion
  (bsc#1177393).
- scsi: target: tcmu: Fix crash in tcmu_flush_dcache_range on ARM
  (bsc#1177393).
- scsi: target: tcmu: Optimize use of flush_dcache_page
  (bsc#1177393).
- scsi: target: tcmu: Remove unnecessary bit TCMU_CMD_BIT_INFLIGHT
  (bsc#1177393).
- scsi: target: Rename target_setup_cmd_from_cdb() to
  target_cmd_parse_cdb() (bsc#1177393).
- scsi: target: Fix NULL pointer dereference (bsc#1177393).
- scsi: target: Initialize LUN in transport_init_se_cmd()
  (bsc#1177393).
- scsi: target: Factor out a new helper, target_cmd_init_cdb()
  (bsc#1177393).
- scsi: target: tcmu: Fix size in calls to tcmu_flush_dcache_range
  (bsc#1177393).
- scsi: target: tcmu: Fix a use after free in
  tcmu_check_expired_queue_cmd() (bsc#1177393).
- scsi: target: tcmu: Userspace must not complete queued commands
  (bsc#1177393).
- scsi: target: core: Add initiatorname to NON_EXISTENT_LUN error
  (bsc#1177393).
- scsi: target: loopback: Fix READ with data and sensebytes
  (bsc#1177393).
- scsi: target: tcmu: Make pgr_support and alua_support attributes
  writable (bsc#1177393).
- scsi: target: Make transport_flags per device (bsc#1177393).
- scsi: target: tcmu: Add attributes enforce_pr_isids and
  force_pr_aptpl (bsc#1177393).
- scsi: target: Add missing emulate_pr attribute to passthrough
  backends (bsc#1177393).
- scsi: target: iscsi: Remove the iscsi_data_count structure
  (bsc#1177393).
- scsi: target: Put lun_ref at end of tmr processing
  (bsc#1177393).
- scsi: target: tcmu: reset_ring should reset TCMU_DEV_BIT_BROKEN
  (bsc#1177393).
- scsi: target: fix PR IN / READ FULL STATUS for FC (bsc#1177393).
- scsi: target: Write NULL to *port_nexus_ptr if no ISID
  (bsc#1177393).
- scsi: target: iscsi: calling iscsit_stop_session() inside
  iscsit_close_session() has no effect (bsc#1177393).
- scsi: target: fix hang when multiple threads try to destroy
  the same iscsi session (bsc#1177393).
- scsi: target: remove boilerplate code (bsc#1177393).
- scsi: Revert "target: iscsi: Wait for all commands to finish
  before freeing a session" (bsc#1177393).
- scsi: Revert "RDMA/isert: Fix a recently introduced regression
  related to logout" (bsc#1177393).
- scsi: Revert "target/core: Inline transport_lun_remove_cmd()"
  (bsc#1177393).
- scsi: libfc: remove unnecessary assertion on ep variable
  (bsc#1177393).
- scsi: RDMA/isert: Fix a recently introduced regression related
  to logout (bsc#1177393).
- scsi: target/iblock: Fix protection error with blocks greater
  than 512B (bsc#1177393).
- scsi: target: core: Fix a pr_debug() argument (bsc#1177393).
- scsi: target: iscsi: Wait for all commands to finish before
  freeing a session (bsc#1177393).
- scsi: target: core: Release SPC-2 reservations when closing
  a session (bsc#1177393).
- scsi: target: core: Document target_cmd_size_check()
  (bsc#1177393).
- scsi: target: tcmu: Prevent memory reclaim recursion
  (bsc#1177393).
- scsi: target: Remove tpg_list and se_portal_group.se_tpg_node
  (bsc#1177393).
- scsi: target: tcmu: clean the nl_cmd of the udev when nl send
  fails (bsc#1177393).
- commit 0474abc
* Wed Oct  7 2020 jdelvare@suse.de
- i2c: i801: Exclude device from suspend direct complete
  optimization (git-fixes).
- commit cbf8a71
* Wed Oct  7 2020 tiwai@suse.de
- drm/radeon: revert "Prefer lower feedback dividers"
  (bsc#1177384).
- commit 502170c
* Wed Oct  7 2020 mbrugger@suse.com
- Refresh patches.suse/KVM-arm64-Annotate-hyp-NMI-related-functions-as-__al.patch
- commit 3239f9e
* Wed Oct  7 2020 nsaenzjulienne@suse.de
- usb: typec: intel_pmc_mux: Handle SCU IPC error conditions
  (git-fixes).
- usb: typec: ucsi: acpi: Increase command completion timeout
  value (git-fixes).
- commit 2522986
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf/resv: fix exclusive fence get (bsc#1152489)
- commit f347971
* Wed Oct  7 2020 tzimmermann@suse.de
- dmabuf: Mark up onstack timer for selftests (bsc#1152472)
- commit 5352a74
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf: Use %%zu for printing sizeof (bsc#1152472)
- commit 585460a
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf: Add selftests for dma-fence (bsc#1152472)
- commit 949306b
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf: Introduce selftesting framework (bsc#1152472)
- commit 44626c4
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-fence: Simply wrap dma_fence_signal_locked with dma_fence_signal (bsc#1152472)
- commit d0d8f02
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-fence: Avoid list_del during fence->cb_list iteration (bsc#1152472)
- commit 2a00bfd
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-fence: Shrink size of struct dma_fence (bsc#1152472)
- commit c160601
* Wed Oct  7 2020 tbogendoerfer@suse.de
- sfc: commonise PCI error handlers (jsc#SLE-16683).
- Refresh
  patches.suse/PCI-Use-pci_channel_state_t-instead-of-enum-pci_chan.patch.
- commit af50963
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf: nuke reservation_object seq number (bsc#1152472)
- commit c12b427
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf/sw_sync: Synchronize signal vs syncpt free (bsc#1152472)
- commit df2da01
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-fence: Report the composite sync_file status (bsc#1152472)
- commit b4a797c
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-fence: Propagate errors to dma-fence-array container (bsc#1152472)
- commit 85e9ccb
* Wed Oct  7 2020 tbogendoerfer@suse.de
- xsk: Remove a double pool->dev assignment in xp_dma_map
  (bsc#1176447).
- Refresh
  patches.suse/xsk-use-dma_need_sync-instead-of-reimplenting-it.
- commit cbb55ac
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf: add reservation_object_fences helper (bsc#1152472)
- commit 9038919
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf: make dma_fence structure a bit smaller v2 (bsc#1152472)
- commit 756d934
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf: simplify reservation_object_get_fences_rcu a bit (bsc#1152472)
- commit 90a1fe4
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf: fix shared fence list handling in (bsc#1152472)
- commit fb7c63d
* Wed Oct  7 2020 tbogendoerfer@suse.de
- xsk: Explicitly inline functions and move definitions
  (bsc#1176447).
- Refresh
  patches.suse/xsk-replace-the-cheap_dma-flag-with-a-dma_need_sync-flag.
- commit ecbba08
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf: fix busy wait for new shared fences (bsc#1152472)
- commit b161669
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf: fix stack corruption in dma_fence_chain_release (bsc#1152472)
- commit c9fc706
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf: Relax the write-seqlock for reallocating the shared fence (bsc#1152472)
- commit b40ad2e
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf: Expand reservation_list to fill allocation (bsc#1152472)
- commit 40d44b0
* Wed Oct  7 2020 tzimmermann@suse.de
- dma-buf: cleanup reservation_object_init/fini (bsc#1152472)
- commit 1d9015b
* Wed Oct  7 2020 tbogendoerfer@suse.de
- xsk: Add overflow check for u64 division, stored into u32
  (bsc#1176447).
- Refresh
  patches.suse/xsk-Introduce-AF_XDP-buffer-allocation-API.patch.
- commit c06291a
* Wed Oct  7 2020 tbogendoerfer@suse.de
- xsk: Support allocations of large umems (bsc#1176447).
- Refresh
  patches.suse/xsk-Introduce-AF_XDP-buffer-allocation-API.patch.
- commit ebf030b
* Wed Oct  7 2020 mhocko@suse.com
- kernel: allow to configure PREEMPT_NONE, PREEMPT_VOLUNTARY on
  kernel command line (jsc#SLE-16775).
- commit 6bd2001
* Wed Oct  7 2020 tbogendoerfer@suse.de
- sfc: Fix error code in probe (jsc#SLE-16683).
- xsk: Fix number of pinned pages/umem size discrepancy
  (bsc#1176447).
- sfc: fix boolreturn.cocci warning and rename function
  (jsc#SLE-16683).
- sfc: fix build warnings on 32-bit (jsc#SLE-16683).
- sfc: don't free_irq()s if they were never requested
  (jsc#SLE-16683).
- sfc: null out channel->rps_flow_id after freeing it
  (jsc#SLE-16683).
- sfc: take correct lock in ef100_reset() (jsc#SLE-16683).
- sfc: really check hash is valid before using it (jsc#SLE-16683).
- sfc: check hash is valid before using it (jsc#SLE-16683).
- sfc: fix ef100 design-param checking (jsc#SLE-16683).
- net/mlx5: Add VDPA interface type to supported enumerations
  (jsc#SLE-15172).
- sfc: Fix build with CONFIG_RFS_ACCEL disabled (jsc#SLE-16683).
- xdp: Prevent kernel-infoleak in xsk_getsockopt() (bsc#1176447).
- sfc_ef100: add nic-type for VFs, and bind to them
  (jsc#SLE-16683).
- sfc_ef100: read pf_index at probe time (jsc#SLE-16683).
- sfc_ef100: functions for selftests (jsc#SLE-16683).
- sfc_ef100: statistics gathering (jsc#SLE-16683).
- sfc_ef100: plumb in fini_dmaq (jsc#SLE-16683).
- sfc_ef100: RX path for EF100 (jsc#SLE-16683).
- sfc_ef100: RX filter table management and related gubbins
  (jsc#SLE-16683).
- sfc_ef100: TX path for EF100 NICs (jsc#SLE-16683).
- sfc_ef100: read Design Parameters at probe time (jsc#SLE-16683).
- sfc_ef100: fail the probe if NIC uses unsol_ev credits
  (jsc#SLE-16683).
- sfc_ef100: check firmware version at start-of-day
  (jsc#SLE-16683).
- tun: add missing rcu annotation in tun_set_ebpf() (bsc#1176447).
- sfc_ef100: remove duplicated include from ef100_netdev.c
  (jsc#SLE-16683).
- sfc_ef100: implement ndo_get_phys_port_{id,name}
  (jsc#SLE-16683).
- sfc_ef100: read device MAC address at probe time
  (jsc#SLE-16683).
- sfc_ef100: probe the PHY and configure the MAC (jsc#SLE-16683).
- sfc_ef100: actually perform resets (jsc#SLE-16683).
- sfc_ef100: extend ef100_check_caps to cover datapath_caps3
  (jsc#SLE-16683).
- sfc_ef100: read datapath caps, implement check_caps
  (jsc#SLE-16683).
- sfc_ef100: process events for MCDI completions (jsc#SLE-16683).
- sfc_ef100: implement ndo_open/close and EVQ probing
  (jsc#SLE-16683).
- sfc_ef100: implement MCDI transport (jsc#SLE-16683).
- sfc_ef100: don't call efx_reset_down()/up() on EF100
  (jsc#SLE-16683).
- sfc_ef100: PHY probe stub (jsc#SLE-16683).
- sfc_ef100: reset-handling stub (jsc#SLE-16683).
- sfc: skeleton EF100 PF driver (jsc#SLE-16683).
- sfc_ef100: register accesses on EF100 (jsc#SLE-16683).
- sfc_ef100: add EF100 register definitions (jsc#SLE-16683).
- sfc: remove efx_ethtool_nway_reset() (jsc#SLE-16683).
- sfc: drop unnecessary list_empty (jsc#SLE-16683).
- sfc: convert to new udp_tunnel infrastructure (jsc#SLE-16683).
- xsk: Add xdp statistics to xsk_diag (bsc#1176447).
- xsk: Add new statistics (bsc#1176447).
- net: switchdev: kerneldoc fixes (bsc#1176447).
- sfc_ef100: helper function to set default RSS table of given
  size (jsc#SLE-16683).
- sfc_ef100: NVRAM selftest support code (jsc#SLE-16683).
- sfc_ef100: populate BUFFER_SIZE_BYTES in INIT_RXQ
  (jsc#SLE-16683).
- sfc_ef100: add EF100 to NIC-revision enumeration
  (jsc#SLE-16683).
- sfc: get drvinfo driver name from outside the common code
  (jsc#SLE-16683).
- sfc: initialise RSS context ID to 'no RSS context' in
  efx_init_struct() (jsc#SLE-16683).
- sfc: commonise efx_fini_dmaq (jsc#SLE-16683).
- sfc: factor out efx_mcdi_filter_table_down() from _remove()
  (jsc#SLE-16683).
- sfc: don't call tx_limit_len if NIC type doesn't have one
  (jsc#SLE-16683).
- sfc: assign TXQs without gaps (jsc#SLE-16683).
- sfc: commonise netif_set_real_numx_queues calls (jsc#SLE-16683).
- sfc: make tx_queues_per_channel variable at runtime
  (jsc#SLE-16683).
- sfc: move modparam 'rss_cpus' out of common channel code
  (jsc#SLE-16683).
- sfc: move modparam 'interrupt_mode' out of common channel code
  (jsc#SLE-16683).
- sfc: remove max_interrupt_mode (jsc#SLE-16683).
- sfc: support setting MTU even if not privileged to configure
  MAC fully (jsc#SLE-16683).
- sfc: don't call tx_remove if there isn't one (jsc#SLE-16683).
- sfc: commonise initialisation of efx->vport_id (jsc#SLE-16683).
- sfc: commonise efx->xq_entries initialisation (jsc#SLE-16683).
- sfc: initialise max_[tx_]channels in efx_init_channels()
  (jsc#SLE-16683).
- sfc: move definition of EFX_MC_STATS_GENERATION_INVALID
  (jsc#SLE-16683).
- sfc: factor out efx_tx_tso_header_length() and understand
  encapsulation (jsc#SLE-16683).
- sfc: remove duplicate declaration of efx_enqueue_skb_tso()
  (jsc#SLE-16683).
- sfc: commonise TSO fallback code (jsc#SLE-16683).
- sfc: commonise efx_sync_rx_buffer() (jsc#SLE-16683).
- sfc: commonise some MAC configuration code (jsc#SLE-16683).
- sfc: commonise miscellaneous efx functions (jsc#SLE-16683).
- sfc: add missing licence info to mcdi_filters.c (jsc#SLE-16683).
- sfc: commonise MCDI MAC stats handling (jsc#SLE-16683).
- sfc: move NIC-specific mcdi_port declarations out of common
  header (jsc#SLE-16683).
- sfc: extend common GRO interface to support CHECKSUM_COMPLETE
  (jsc#SLE-16683).
- sfc: commonise ARFS handling (jsc#SLE-16683).
- sfc: commonise drain event handling (jsc#SLE-16683).
- sfc: track which BAR is mapped (jsc#SLE-16683).
- sfc: commonise FC advertising (jsc#SLE-16683).
- sfc: commonise other ethtool bits (jsc#SLE-16683).
- sfc: commonise ethtool NFC and RXFH/RSS functions
  (jsc#SLE-16683).
- sfc: commonise ethtool link handling functions (jsc#SLE-16683).
- sfc: split up nic.h (jsc#SLE-16683).
- sfc: refactor EF10 stats handling (jsc#SLE-16683).
- sfc: don't try to create more channels than we can have VIs
  (jsc#SLE-16683).
- sfc: extend bitfield macros up to POPULATE_DWORD_13
  (jsc#SLE-16683).
- sfc: determine flag word automatically in efx_has_cap()
  (jsc#SLE-16683).
- sfc: update MCDI protocol headers (jsc#SLE-16683).
- net/mlx5: Avoid RDMA file inclusion in core driver
  (jsc#SLE-15172).
- tun: implement header_ops->parse_protocol for AF_PACKET
  (bsc#1176447).
- xdp: Fix xsk_generic_xmit errno (bsc#1176447).
- net/xdp: use shift instead of 64 bit division (bsc#1176447).
- xdp: Introduce xdp_convert_frame_to_buff utility routine
  (bsc#1176447).
- sfc: add missing annotation for
  efx_ef10_try_update_nic_stats_vf() (jsc#SLE-16683).
- net/mlx5: IPSec: Fix incorrect type for spi (jsc#SLE-15172).
- sfc: avoid an unused-variable warning (jsc#SLE-16683).
- net: move devres helpers into a separate source file
  (bsc#1176447).
- xsk: Remove MEM_TYPE_ZERO_COPY and corresponding code
  (bsc#1176447).
- tun: Add XDP frame size (bsc#1176447).
- veth: Xdp using frame_sz in veth driver (bsc#1176447).
- veth: Adjust hard_start offset on redirect XDP frames
  (bsc#1176447).
- sfc: Add XDP frame size (jsc#SLE-16683).
- sfc: fix dereference of table before it is null checked
  (jsc#SLE-16683).
- sfc: siena_check_caps() can be static (jsc#SLE-16683).
- sfc: actually wire up siena_check_caps() (jsc#SLE-16683).
- sfc: make firmware-variant printing a nic_type function
  (jsc#SLE-16683).
- sfc: make filter table probe caller responsible for adding VLANs
  (jsc#SLE-16683).
- sfc: move rx_rss_context_exclusive into struct
  efx_mcdi_filter_table (jsc#SLE-16683).
- sfc: rework handling of (firmware) multicast chaining state
  (jsc#SLE-16683).
- sfc: move 'must restore' flags out of ef10-specific nic_data
  (jsc#SLE-16683).
- sfc: use efx_has_cap for capability checks outside of
  NIC-specific code (jsc#SLE-16683).
- sfc: make capability checking a nic_type function
  (jsc#SLE-16683).
- sfc: move vport_id to struct efx_nic (jsc#SLE-16683).
- net/mlx5: TX WQE Add trailer insertion field (jsc#SLE-15172).
- netfilter: nft_reject_bridge: enable reject with bridge vlan
  (bsc#1176447).
- net: bridge: vlan: Add a schedule point during VLAN processing
  (bsc#1176447).
- veth: rely on peer veth_rq for ndo_xdp_xmit accounting
  (bsc#1176447).
- veth: rely on veth_rq in veth_xdp_flush_bq signature
  (bsc#1176447).
- sfc: falcon: convert to use i2c_new_client_device()
  (jsc#SLE-16683).
- net: bridge: vlan options: move the tunnel command to the
  nested attribute (bsc#1176447).
- net: bridge: vlan options: nest the tunnel id into a tunnel
  info attribute (bsc#1176447).
- veth: remove atomic64_add from veth_xdp_xmit hotpath
  (bsc#1176447).
- veth: introduce more xdp counters (bsc#1176447).
- veth: distinguish between rx_drops and xdp_drops (bsc#1176447).
- veth: introduce more specialized counters in veth_stats
  (bsc#1176447).
- veth: move xdp stats in a dedicated structure (bsc#1176447).
- net: bridge: vlan: include stats in dumps if requested
  (bsc#1176447).
- net: bridge: vlan options: add support for tunnel mapping
  set/del (bsc#1176447).
- net: bridge: vlan options: add support for tunnel id dumping
  (bsc#1176447).
- net: bridge: vlan tunnel: constify bridge and port arguments
  (bsc#1176447).
- net: bridge: vlan options: rename br_vlan_opts_eq to
  br_vlan_opts_eq_range (bsc#1176447).
- net: sfc: reject unsupported coalescing params (jsc#SLE-16683).
- sfc: support configuring vf spoofchk on EF10 VFs
  (jsc#SLE-16683).
- sfc: ethtool: Refactor to remove fallthrough comments in case
  blocks (jsc#SLE-16683).
- net/mlx5: fix spelling mistake "reserverd" -> "reserved"
  (jsc#SLE-15172).
- tun: reject unsupported coalescing params (bsc#1176447).
- tun: drop TUN_DEBUG and tun_debug() (bsc#1176447).
- tun: replace tun_debug() by netif_info() (bsc#1176447).
- tun: drop useless debugging statements (bsc#1176447).
- tun: get rid of DBG1() macro (bsc#1176447).
- tun: fix misleading comment format (bsc#1176447).
- net: switchdev: do not propagate bridge updates across bridges
  (bsc#1176447).
- sfc: Replace zero-length array with flexible-array member
  (jsc#SLE-16683).
- tun: Remove unnecessary BUG_ON check in tun_net_xmit
  (bsc#1176447).
- sfc: elide assignment of skb (jsc#SLE-16683).
- net: switchdev: Replace zero-length array with flexible-array
  member (bsc#1176447).
- sfc: move some ARFS code out of headers (jsc#SLE-16683).
- sfc: only schedule asynchronous filter work if needed
  (jsc#SLE-16683).
- net: vlan: suppress "failed to kill vid" warnings (bsc#1176447).
- net: sfc: Use scnprintf() for avoiding potential buffer overflow
  (jsc#SLE-16683).
- veth: ignore peer tx_dropped when counting local rx_dropped
  (bsc#1176447).
- sfc: complete the next packet when we receive a timestamp
  (jsc#SLE-16683).
- sfc: fix timestamp reconstruction at 16-bit rollover points
  (jsc#SLE-16683).
- net: bridge: fix stale eth hdr pointer in br_dev_xmit
  (bsc#1176447).
- bridge: br_stp: Use built-in RCU list checking (bsc#1176447).
- net: bridge: vlan: add per-vlan state (bsc#1176447).
- net: bridge: vlan: add basic option setting support
  (bsc#1176447).
- net: bridge: vlan: add basic option dumping support
  (bsc#1176447).
- net: bridge: check port state before br_allowed_egress
  (bsc#1176447).
- net: bridge: vlan: notify on vlan add/delete/change flags
  (bsc#1176447).
- net: bridge: vlan: add rtnetlink group and notify support
  (bsc#1176447).
- net: bridge: vlan: add rtm range support (bsc#1176447).
- net: bridge: vlan: add del rtm message support (bsc#1176447).
- net: bridge: vlan: add new rtm message support (bsc#1176447).
- net: bridge: vlan: add rtm definitions and dump support
  (bsc#1176447).
- net: bridge: netlink: add extack error messages when processing
  vlans (bsc#1176447).
- net: bridge: vlan: add helpers to check for vlan id/range
  validity (bsc#1176447).
- net: sfc: use skb_list_walk_safe helper for gso segments
  (jsc#SLE-16683).
- net: tap: use skb_list_walk_safe helper for gso segments
  (bsc#1176447).
- xsk: Use struct_size() helper (bsc#1176447).
- net: bridge: add STP xstats (bsc#1176447).
- net: tap: clean up an indentation issue (bsc#1176447).
- commit defc9cf
* Wed Oct  7 2020 tzimmermann@suse.de
- Update configs for DRM v5.4
- commit a4b9b1e
* Wed Oct  7 2020 glin@suse.com
- bpf, testing: Add missing object file to TEST_FILES (bsc#1177028).
- selftests/bpf: Restore $(OUTPUT)/test_stub.o rule (bsc#1177028).
- selftest/bpf: Use -m{little, big}-endian for clang
  (bsc#1177028).
- selftests/bpf: Fix LDLIBS order (bsc#1177028).
- tools/bpf: Turn on llvm alu32 attribute by default (bsc#1177028).
  Refresh patches
- patches.suse/selftests-bpf-Move-test_section_names-into-test_prog.patch
- patches.suse/selftests-bpf-xdping-is-not-meant-to-be-run-standalo.patch
- selftest/bpf: Remove test_libbpf.sh and test_libbpf_open (bsc#1177028).
  Refresh patches.suse/selftests-bpf-xdping-is-not-meant-to-be-run-standalo.patch
- selftests/bpf: Move test_queue_stack_map.h into progs/ where
  it belongs (bsc#1177028).
- selftests/bpf: Replace test_progs and test_maps w/ general rule (bsc#1177028).
  Refresh patches.suse/selftests-bpf-xdping-is-not-meant-to-be-run-standalo.patch
- selftests/bpf: Add simple per-test targets to Makefile
  (bsc#1177028).
- selftests/bpf: Switch test_maps to test_progs' test.h format
  (bsc#1177028).
- selftests/bpf: Remove obsolete pahole/BTF support detection
  (bsc#1177028).
- selftests/bpf: Convert test_btf_dump into test_progs test (bsc#1177028).
  Refresh patches
- patches.suse/selftests-bpf-Move-test_section_names-into-test_prog.patch
- patches.suse/selftests-bpf-xdping-is-not-meant-to-be-run-standalo.patch
- commit 2889f18
* Wed Oct  7 2020 glin@suse.com
- libbpf: Add probe for large INSN limit (bsc#1177028).
- libbpf: Introduce bpf_prog_attach_xattr (bsc#1177028).
- libbpf: Add bpf_link__disconnect() API to preserve underlying
  BPF resource (bsc#1177028).
- libbpf: Fix build by renaming variables (bsc#1177028).
- selftests/bpf: Add tests for libbpf-provided externs
  (bsc#1177028).
- libbpf: Extract internal map names into constants (bsc#1177028).
- selftests/bpf: Add test validating data section to struct
  convertion layout (bsc#1177028).
- selftests/bpf: Convert few more selftest to skeletons (bsc#1177028).
  Refresh patches
- patches.suse/bpf-Prevent-mmap-ing-read-only-maps-as-writable.patch
- patches.suse/selftests-bpf-Validate-frozen-map-contents-stays-fro.patch
- bpftool: Add skeleton codegen command (bsc#1177028).
- libbpf: Add BPF object skeleton support (bsc#1177028).
- libbpf: Postpone BTF ID finding for TRACING programs to load
  phase (bsc#1177028).
- libbpf: Refactor global data map initialization (bsc#1177028).
- libbpf: Expose BPF program's function name (bsc#1177028).
- libbpf: Expose BTF-to-C type declaration emitting API
  (bsc#1177028).
- libbpf: Expose btf__align_of() API (bsc#1177028).
- libbpf: Add BPF_EMBED_OBJ macro for embedding BPF .o files
  (bsc#1177028).
- libbpf: Add generic bpf_program__attach() (bsc#1177028).
- libbpf: Don't require root for bpf_object__open() (bsc#1177028).
- libbpf: Recognize SK_REUSEPORT programs from section name
  (bsc#1177028).
- libbpf: Bump libpf current version to v0.0.7 (bsc#1177028).
- bpf, testing: Add selftest to read/write sockaddr from user
  space (bsc#1177028).
- libbpf: Add C/LDFLAGS to libbpf.so and test_libpf targets
  (bsc#1177028).
- libbpf: Don't use cxx to test_libpf target (bsc#1177028).
- selftests/bpf: test_progs: convert test_tcp_rtt (bsc#1177028).
  Refresh patches
- patches.suse/libbpf-Move-bpf_-helpers-helper_defs-endian-tracing-.patch
- patches.suse/libbpf-auto-generate-list-of-BPF-helper-definitions.patch
- patches.suse/selftests-bpf-Move-test_section_names-into-test_prog.patch
- patches.suse/selftests-bpf-xdping-is-not-meant-to-be-run-standalo.patch
- selftests/bpf: test_progs: convert test_sockopt_inherit (bsc#1177028).
  Refresh patches
- patches.suse/libbpf-Move-bpf_-helpers-helper_defs-endian-tracing-.patch
- patches.suse/libbpf-auto-generate-list-of-BPF-helper-definitions.patch
- patches.suse/selftests-bpf-Move-test_section_names-into-test_prog.patch
- patches.suse/selftests-bpf-xdping-is-not-meant-to-be-run-standalo.patch
- selftests/bpf: test_progs: convert test_sockopt_multi (bsc#1177028).
  Refresh patches
- patches.suse/libbpf-Move-bpf_-helpers-helper_defs-endian-tracing-.patch
- patches.suse/libbpf-auto-generate-list-of-BPF-helper-definitions.patch
- patches.suse/selftests-bpf-Move-test_section_names-into-test_prog.patch
- patches.suse/selftests-bpf-xdping-is-not-meant-to-be-run-standalo.patch
- selftests/bpf: test_progs: convert test_sockopt_sk (bsc#1177028).
  Refresh patches
- patches.suse/libbpf-Move-bpf_-helpers-helper_defs-endian-tracing-.patch
- patches.suse/libbpf-auto-generate-list-of-BPF-helper-definitions.patch
- patches.suse/selftests-bpf-Move-test_section_names-into-test_prog.patch
- patches.suse/selftests-bpf-xdping-is-not-meant-to-be-run-standalo.patch
- selftests/bpf: test_progs: convert test_sockopt (bsc#1177028).
  Refresh patches
- patches.suse/libbpf-Move-bpf_-helpers-helper_defs-endian-tracing-.patch
- patches.suse/libbpf-auto-generate-list-of-BPF-helper-definitions.patch
- patches.suse/selftests-bpf-Move-test_section_names-into-test_prog.patch
- patches.suse/selftests-bpf-xdping-is-not-meant-to-be-run-standalo.patch
- selftests/bpf: test_progs: add test__join_cgroup helper (bsc#1177028).
  Refresh patches.suse/selftests-bpf-Make-a-copy-of-subtest-name.patch
- selftests/bpf: add sockopt clone/inheritance test (bsc#1177028).
  Refresh patches
- patches.suse/selftests-bpf-Move-test_section_names-into-test_prog.patch
- patches.suse/selftests-bpf-xdping-is-not-meant-to-be-run-standalo.patch
- selftests/bpf: extend sockopt_sk selftest with TCP_CONGESTION
  use case (bsc#1177028).
- commit 588cf6d
* Wed Oct  7 2020 mkubecek@suse.cz
- Update kabi files.
- update to resubmitted October 2020 maintenance update (commit a291df1060d0)
- commit 04003b7
* Wed Oct  7 2020 tzimmermann@suse.de
- mm/hmm: remove superfluous arguments from hmm_range_register (bsc#1152489)
- commit 3cec60c
* Wed Oct  7 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/nfs-Fix-security-label-length-not-being-reset.patch
- commit ae3a19b
* Tue Oct  6 2020 neilb@suse.de
- nfs: Fix security label length not being reset (bsc#1176381).
- commit c73c639
* Tue Oct  6 2020 mgorman@suse.de
- intel_idle: Disable ACPI _CST on Haswell (bsc#1177399).
- commit 7b2bcff
* Tue Oct  6 2020 vbabka@suse.cz
- drm/nouveau/nouveau: fix incorrect sizeof on args.src an
  args.dst (jsc#SLE-16387, git-fixes).
- commit ac146f1
* Tue Oct  6 2020 lduncan@suse.com
- scsi: qedi: Staticify non-external function
  'qedi_get_iscsi_error' (bsc#1177385 jre#sle-15142).
- scsi: qedi: Demote seemingly unintentional kerneldoc header
  (bsc#1177385 jre#sle-15142).
- scsi: qedi: Remove set but unused variable 'tmp' (bsc#1177385
  jre#sle-15142).
- scsi: qedi: Remove 2 set but unused variables (bsc#1177385
  jre#sle-15142).
- scsi: qedi: Remove unused variable udev & uctrl (bsc#1177385
  jre#sle-15142).
- scsi: qedi: Remove comparison of 0/1 to bool variable
  (bsc#1177385 jre#sle-15142).
- scsi: qedi: Check for buffer overflow in qedi_set_path()
  (bsc#1177385 jre#sle-15142).
- scsi: qedi: make qedi_ll2_buf_size static (bsc#1177385
  jre#sle-15142).
- scsi: qedi: Fix termination timeouts in session logout
  (bsc#1177385 jre#sle-15142).
- scsi: qedi: Add modules param to enable qed iSCSI debug
  (bsc#1177385 jre#sle-15142).
- scsi: qedi: Do not flush offload work if ARP not resolved
  (bsc#1177385 jre#sle-15142).
- scsi: qedi: Use correct msix count for fastpath vectors
  (bsc#1177385 jre#sle-15142).
- scsi: qedi: Avoid unnecessary endpoint allocation on link down
  (bsc#1177385 jre#sle-15142).
- scsi: qedi: Remove additional char from boot target iqnname
  (bsc#1177385 jre#sle-15142).
- scsi: qedi: Add PCI shutdown handler support (bsc#1177385
  jre#sle-15142).
- scsi: qedi: Add MFW error recovery process (bsc#1177385
  jre#sle-15142).
- commit 3133eab
* Tue Oct  6 2020 mgorman@suse.de
- sched/fair: Reduce busy load balance interval (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Minimize concurrent LBs between domain level
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Reduce minimal imbalance threshold (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Relax constraint on task's load during load
  balance (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Remove the force parameter of update_tg_load_avg()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Fix wrong cpu selecting from isolated domain
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/rt: Disable RT_RUNTIME_SHARE by default (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Simplify the work when reweighting entity
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit 0a2eec7
* Tue Oct  6 2020 vbabka@suse.cz
- mm/hmm: remove hmm_range_dma_map and hmm_range_dma_unmap
  (jsc#SLE-16387).
- commit bc6f912
* Tue Oct  6 2020 vbabka@suse.cz
- mm/hmm: make full use of walk_page_range() (jsc#SLE-16387).
- commit fd66a94
* Tue Oct  6 2020 vbabka@suse.cz
- mm/hmm: remove hmm_mirror and related (jsc#SLE-16387).
- commit 74a8c0b
* Tue Oct  6 2020 tiwai@suse.de
- Refresh intel-vbtn patch from the upstream patch
- commit c3bd737
* Tue Oct  6 2020 tiwai@suse.de
- platform/x86: thinkpad_acpi: re-initialize ACPI buffer size
  when reuse (git-fixes).
- platform/x86: intel_pmc_core: do not create a static struct
  device (git-fixes).
- platform/x86: fix kconfig dependency warning for FUJITSU_LAPTOP
  (git-fixes).
- platform/x86: fix kconfig dependency warning for LG_LAPTOP
  (git-fixes).
- platform/x86: thinkpad_acpi: initialize tp_nvram_state variable
  (git-fixes).
- Platform: OLPC: Fix memleak in olpc_ec_probe (git-fixes).
- net: phy: realtek: fix rtl8211e rx/tx delay config (git-fixes).
- commit b64083a
* Tue Oct  6 2020 vbabka@suse.cz
- nouveau: use mmu_interval_notifier instead of hmm_mirror (jsc#SLE-16387).
- commit 9b1a3d6
* Tue Oct  6 2020 vbabka@suse.cz
- mm/hmm: define the pre-processor related parts of hmm.h even
  if disabled (jsc#SLE-16387).
- commit b4bea84
* Tue Oct  6 2020 vbabka@suse.cz
- mm/hmm: allow hmm_range to be used with a mmu_interval_notifier
  or hmm_mirror (jsc#SLE-16387).
- commit f8175c8
* Tue Oct  6 2020 vbabka@suse.cz
- Add jsc#SLE-16387 references.
- Update
  patches.suse/mm-mmu_notifier-add-an-interval-tree-notifier.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-mmu_notifier-define-the-header-pre-processor-part.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- commit 986a22e
* Tue Oct  6 2020 glin@suse.com
- bpf: Enable bpf cgroup hooks to retrieve cgroup v2 and ancestor
  id (bsc#1177028).
- bpf: Allow to retrieve cgroup v1 classid from v2 hooks
  (bsc#1177028).
- bpf: Add netns cookie and enable it for bpf cgroup hooks
  (bsc#1177028).
- bpf: Enable perf event rb output for bpf cgroup progs
  (bsc#1177028).
- bpf: Enable retrieval of socket cookie for bind/post-bind hook
  (bsc#1177028).
- bpf: Remove unused vairable 'bpf_xdp_link_lops' (bsc#1177028).
- bpf: Factor out attach_type to prog_type mapping for
  attach/detach (bsc#1177028).
- bpf: Factor out cgroup storages operations (bsc#1177028).
- bpf: Verifer, adjust_scalar_min_max_vals to always call
  update_reg_bounds() (bsc#1177028).
- bpf: Verifer, refactor adjust_scalar_min_max_vals (bsc#1177028).
- commit ed2cc54
* Tue Oct  6 2020 vbabka@suse.cz
- mm/hmm: allow snapshot of the special zero page (jsc#SLE-16387).
- commit 2c9afd2
* Tue Oct  6 2020 glin@suse.com
- bpf: Add missing annotations for __bpf_prog_enter() and
  __bpf_prog_exit() (bsc#1177028).
- bpf: Remove bpf_image tree (bsc#1177028).
- bpf: Add dispatchers to kallsyms (bsc#1177028).
- bpf: Add trampolines to kallsyms (bsc#1177028).
- bpf: Add bpf_ksym_add/del functions (bsc#1177028).
- bpf: Add prog flag to struct bpf_ksym object (bsc#1177028).
- bpf: Add bpf_ksym_find function (bsc#1177028).
- bpf: Move ksym_tnode to bpf_ksym (bsc#1177028).
- bpf: Move lnode list node to struct bpf_ksym (bsc#1177028).
- bpf: Add name to struct bpf_ksym (bsc#1177028).
- bpf: Add struct bpf_ksym (bsc#1177028).
- bpf: Add bpf_trampoline_ name prefix for DECLARE_BPF_DISPATCHER
  (bsc#1177028).
- bpf: Abstract away entire bpf_link clean up procedure
  (bsc#1177028).
- bpf: Add bpf_xdp_output() helper (bsc#1177028).
- bpf: Added new helper bpf_get_ns_current_pid_tgid (bsc#1177028).
- fs/nsfs.c: Added ns_match (bsc#1177028).
- bpf: Add bpf_link_new_file that doesn't install FD
  (bsc#1177028).
- bpf: Remove unnecessary CAP_MAC_ADMIN check (bsc#1177028).
- bpf: Provide bpf_prog_run_pin_on_cpu() helper (bsc#1177028).
- selftests/bpf: Update xdp_bpf2bpf test to use new
  set_attach_target API (bsc#1177028).
- selftests/bpf: Add bpf_read_branch_records() selftest
  (bsc#1177028).
- bpf: Add bpf_read_branch_records() helper (bsc#1177028).
- bpf: Allow bpf_perf_event_read_value in all BPF programs
  (bsc#1177028).
- bpf: Sync uapi bpf.h to tools/ (bsc#1177028).
- selftests/bpf: Add a test for attaching a bpf fentry/fexit
  trace to an XDP program (bsc#1177028).
- commit 0e152c5
* Tue Oct  6 2020 martin.wilck@suse.com
- Rename scsi-fnic-do-not-call-scsi_done-for-unhandled-commands.patch
  Fix typo in patch file name.
- commit 554d4c0
* Tue Oct  6 2020 martin.wilck@suse.com
- Refresh patches.suse/fnic-to-not-call-scsi_done-for-unhandled-commands.patch
  (bsc#1168468, bsc#1171675).
- commit c145aa9
* Tue Oct  6 2020 glin@suse.com
- bpf: Attachment verification for BPF_MODIFY_RETURN (bsc#1177028).
- Refresh patches.suse/bpf-Do-not-allow-btf_ctx_access-with-__int128-types.patch.
- commit 8af9bcd
* Tue Oct  6 2020 glin@suse.com
- bpf: Introduce BPF_MODIFY_RETURN (bsc#1177028).
- bpf: JIT helpers for fmod_ret progs (bsc#1177028).
- bpf, x86: Align dispatcher branch targets to 16B (bsc#1177028).
- commit ae6861b
* Tue Oct  6 2020 glin@suse.com
- bpf: Refactor trampoline update code (bsc#1177028).
- bpf: Introduce pinnable bpf_link abstraction (bsc#1177028).
- bpf: INET_DIAG support in bpf_sk_storage (bsc#1177028).
- bpf: Replace zero-length array with flexible-array member
  (bsc#1177028).
- bpf/stackmap: Dont trylock mmap_sem with PREEMPT_RT and
  interrupts disabled (bsc#1177028).
- bpf, lpm: Make locking RT friendly (bsc#1177028).
- bpf: Prepare hashtab locking for PREEMPT_RT (bsc#1177028).
- bpf: Factor out hashtab bucket lock operations (bsc#1177028).
- bpf: Replace open coded recursion prevention in sys_bpf()
  (bsc#1177028).
- bpf: Use recursion prevention helpers in hashtab code
  (bsc#1177028).
- bpf: Provide recursion prevention helpers (bsc#1177028).
- bpf: Use migrate_disable/enabe() in trampoline code
  (bsc#1177028).
- bpf: Dont iterate over possible CPUs with interrupts disabled
  (bsc#1177028).
- bpf: Remove recursion prevention from rcu free callback (bsc#1177028).
  Refresh patches.suse/bpf-Fix-map-leak-in-HASH_OF_MAPS-map.patch
- bpf: Update locking comment in hashtab code (bsc#1177028).
  Refresh patches.suse/bpf-Fix-map-leak-in-HASH_OF_MAPS-map.patch
- bpf: Enforce preallocation for instrumentation programs on RT
  (bsc#1177028).
- bpf: Tighten the requirements for preallocated hash maps
  (bsc#1177028).
- bpf: Allow selecting reuseport socket from a SOCKMAP/SOCKHASH
  (bsc#1177028).
- sched/rt: Provide migrate_disable/enable() inlines
  (bsc#1177028).
- irq_work: Slightly simplify IRQ_WORK_PENDING clearing
  (bsc#1177028).
- irq_work: Fix irq_work_claim() memory ordering (bsc#1177028).
- irq_work: Convert flags to atomic_t (bsc#1177028).
- commit 565a151
* Tue Oct  6 2020 glin@suse.com
- bpf: Change kvfree to kfree in generic_map_lookup_batch()
  (bsc#1177028).
- selftests/bpf: Fix a couple of broken test_btf cases
  (bsc#1177028).
- bpf: Propagate expected_attach_type when verifying freplace
  programs (bsc#1177028).
- bpf, uapi: Remove text about bpf_redirect_map() giving higher
  performance (bsc#1177028).
- commit 8228aac
* Mon Oct  5 2020 tbogendoerfer@suse.de
- Update config files.
  Enable ACPI_PCI_SLOT and HOTPLUG_PCI_ACPI (bsc#1177194).
- commit bc319f1
* Mon Oct  5 2020 tbogendoerfer@suse.de
- net: dsa: link interfaces with the DSA master to get rid of
  lockdep warnings (bsc#1176447).
- xfrm: esp6: fix the location of the transport header with
  encapsulation (bsc#1176447).
- xfrm: esp6: fix encapsulation header offset computation
  (bsc#1176447).
- net: get rid of lockdep_set_class_and_subclass() (bsc#1176447).
- ipv6: rpl: fix loop iteration (bsc#1176447).
- net: ipv6: rpl_iptunnel: Fix potential memory leak in
  rpl_do_srh_inline (bsc#1176447).
- socket: fix unused-function warning (bsc#1176447).
- commit d28d5e7
* Mon Oct  5 2020 tbogendoerfer@suse.de
- bnxt_en: Protect bnxt_set_eee() and bnxt_set_pauseparam()
  with mutex (jsc#SLE-15075).
- bnxt_en: return proper error codes in bnxt_show_temp
  (jsc#SLE-15075).
- net: hns: kerneldoc fixes (jsc#SLE-14777).
- nfp: use correct define to return NONE fec (bsc#1176447).
- cxgb4: fix memory leak during module unload (jsc#SLE-15131).
- net: hns: kerneldoc fixes (jsc#SLE-14777).
- lwtunnel: only keep the available bits when setting vxlan
  md->gbp (bsc#1176447).
- net: sched: only keep the available bits when setting vxlan
  md->gbp (bsc#1176447).
- igc: Fix not considering the TX delay for timestamps
  (jsc#SLE-13533).
- igc: Fix wrong timestamp latency numbers (jsc#SLE-13533).
- net: qed: RDMA personality shouldn't fail VF load
  (jsc#SLE-15143).
- net: qede: Disable aRFS for NPAR and 100G (jsc#SLE-15143).
- net: qed: Disable aRFS for NPAR and 100G (jsc#SLE-15143).
- bnxt_en: Fix NULL ptr dereference crash in bnxt_fw_reset_task()
  (jsc#SLE-15075).
- bnxt_en: Avoid sending firmware messages when AER error is
  detected (jsc#SLE-15075).
- cxgb4: Fix offset when clearing filter byte counters
  (jsc#SLE-15131).
- ip_tunnel_core: Fix build for archs without _HAVE_ARCH_IPV6_CSUM
  (bsc#1176447).
- virtio_net: Add XDP frame size in two code paths (bsc#1176447).
- vmxnet3: let core reject the unsupported coalescing parameters
  (bsc#1176447).
- virtio_net: reject unsupported coalescing params (bsc#1176447).
- virtio_net: Add XDP meta data support (bsc#1176447).
- virtio_net: Keep vnet header zeroed if XDP is loaded for small
  buffer (bsc#1176447).
- vmxnet3: use new helper tcp_v6_gso_csum_prep (bsc#1176447).
- arm64: csum: Optimise IPv6 header checksum (bsc#1176447).
- bpf, xdp: virtio_net use access ptr macro for xdp enable check
  (bsc#1176447).
- arm64: Implement optimised checksum routine (bsc#1176447).
- commit 55b9be4
* Mon Oct  5 2020 tbogendoerfer@suse.de
- net/mlx5: IPsec: Add HW crypto offload support (jsc#SLE-15172).
- Update config files.
- commit 2e4cdf4
* Mon Oct  5 2020 tbogendoerfer@suse.de
- net/mlx5e: Fix missing switch_id for representors
  (jsc#SLE-15172).
- blacklist.conf: removed temporary entry
- commit 09dc124
* Mon Oct  5 2020 tbogendoerfer@suse.de
- net/mlx5e: CT: Fix releasing ft entries (jsc#SLE-15172).
- blacklist.conf: removed temporary entry
- commit 80eac4c
* Mon Oct  5 2020 tbogendoerfer@suse.de
- esp, ah: consolidate the crypto algorithm selections
  (bsc#1176447).
- Update config files.
- commit 6b8aab0
* Mon Oct  5 2020 tbogendoerfer@suse.de
- net: ipv6: add rpl sr tunnel (bsc#1176447).
- Update config files.
- commit 18492b1
* Mon Oct  5 2020 tbogendoerfer@suse.de
- xfrm: add espintcp (RFC 8229) (bsc#1176447).
- Update config files.
- commit 4fbce7b
* Mon Oct  5 2020 tbogendoerfer@suse.de
- net/mlx5: Move helper to eswitch layer (jsc#SLE-15172).
- Refresh
  patches.suse/devlink-Replace-devlink_port_attrs_set-parameters-wi.patch.
- commit 7e738a7
* Mon Oct  5 2020 lduncan@suse.com
- scsi: qedf: Fix null ptr reference in qedf_stag_change_work
  (bsc#1177240 jre#sle-15141).
- scsi: qedf: Demote obvious misuse of kerneldoc to standard
  comment blocks (bsc#1177240 jre#sle-15141).
- scsi: qedf: Remove a whole host of unused variables (bsc#1177240
  jre#sle-15141).
- scsi: qedf: Remove set but not checked variable 'tmp'
  (bsc#1177240 jre#sle-15141).
- scsi: qedf: Demote obvious misuse of kerneldoc to standard
  comment blocks (bsc#1177240 jre#sle-15141).
- scsi: qedf: Remove redundant initialization of variable rc
  (bsc#1177240 jre#sle-15141).
- scsi: qedf: Get dev info after updating the params (bsc#1177240
  jre#sle-15141).
- scsi: qedf: Fix crash when MFW calls for protocol stats while
  function is still probing (bsc#1177240 jre#sle-15141).
- scsi: qedf: Add schedule recovery handler (bsc#1177240
  jre#sle-15141).
- scsi: qedf: Implement callback for bw_update (bsc#1177240
  jre#sle-15141).
- scsi: qedf: Honor status qualifier in FCP_RSP per spec
  (bsc#1177240 jre#sle-15141).
- scsi: qedf: Acquire rport_lock for resetting the delay_timestamp
  (bsc#1177240 jre#sle-15141).
- scsi: qedf: Increase the upper limit of retry delay (bsc#1177240
  jre#sle-15141).
- scsi: qedf: Keep track of num of pending flogi (bsc#1177240
  jre#sle-15141).
- scsi: qedf: Simplify mutex_unlock() usage (bsc#1177240
  jre#sle-15141).
- scsi: qedf: Use pci_get_dsn() (bsc#1177240 jre#sle-15141).
- commit 259b8dd
* Mon Oct  5 2020 tbogendoerfer@suse.de
- net/mlx5e: kTLS, Avoid kzalloc(GFP_KERNEL) under spinlock
  (jsc#SLE-15172).
- net/mlx5e: kTLS, Fix leak on resync error flow (jsc#SLE-15172).
- net/mlx5e: kTLS, Add missing dma_unmap in RX resync
  (jsc#SLE-15172).
- net/mlx5e: kTLS, Fix napi sync and possible use-after-free
  (jsc#SLE-15172).
- net/mlx5e: TLS, Do not expose FPGA TLS counter if not supported
  (jsc#SLE-15172).
- net/mlx5e: Fix using wrong stats_grps in
  mlx5e_update_ndo_stats() (jsc#SLE-15172).
- net/mlx5e: Fix multicast counter not up-to-date in "ip -s"
  (jsc#SLE-15172).
- net/mlx5e: Fix endianness when calculating pedit mask first bit
  (jsc#SLE-15172).
- net/mlx5e: Enable adding peer miss rules only if merged eswitch
  is supported (jsc#SLE-15172).
- net/mlx5e: CT: Fix freeing ct_label mapping (jsc#SLE-15172).
- net/mlx5e: Fix memory leak of tunnel info when rule under
  multipath not ready (jsc#SLE-15172).
- net/mlx5e: Use synchronize_rcu to sync with NAPI
  (jsc#SLE-15172).
- net/mlx5e: Use RCU to protect rq->xdp_prog (jsc#SLE-15172).
- net/mlx5: Fix FTE cleanup (jsc#SLE-15172).
- geneve: add transport ports in route lookup for geneve
  (bsc#1176447).
- net: disable netpoll on fresh napis (bsc#1176447).
- net: nexthop: don't allow empty NHA_GROUP (bsc#1176447).
- scsi: fcoe: Fix I/O path allocation (jsc#SLE-13706).
- net: bonding: bond_alb: Describe
  alb_handle_addr_collision_on_attach()'s 'bond' and 'addr'
  params (bsc#1176447).
- net: bonding: bond_main: Document 'proto' and rename
  'new_active' parameters (bsc#1176447).
- net: bonding: bond_3ad: Fix a bunch of kerneldoc parameter
  issues (bsc#1176447).
- bonding: show saner speed for broadcast mode (bsc#1176447).
- net/mlx5: Enable count action for rules with allow action
  (jsc#SLE-15172).
- net/mlx5: Support setting access rights of dma addresses
  (jsc#SLE-15172).
- net/mlx5: Enable QP number request when creating IPoIB underlay
  QP (jsc#SLE-15172).
- Revert "vxlan: fix tos value before xmit" (bsc#1176447).
- geneve: Support for PMTU discovery on directly bridged links
  (bsc#1176447).
- vxlan: Support for PMTU discovery on directly bridged links
  (bsc#1176447).
- tunnels: PMTU discovery support for directly bridged IP packets
  (jsc#SLE-15172).
- ipv4: route: Ignore output interface in FIB lookup for PMTU
  route (bsc#1176447).
- net/mlx5: Delete extra dump stack that gives nothing
  (jsc#SLE-15172).
- net/mlx5: convert to new udp_tunnel infrastructure
  (jsc#SLE-15172).
- net/mlx5e: Enable users to change VF/PF representors carrier
  state (jsc#SLE-15172).
- ixgbe: use eth_zero_addr() to clear mac address (jsc#SLE-13706).
- ixgbe: Remove unnecessary usages of memset (jsc#SLE-13706).
- ixgbevf: use generic power management (jsc#SLE-13706).
- ixgbe: use generic power management (jsc#SLE-13706).
- xfrm: Make the policy hold queue work with VTI (bsc#1176447).
- xfrm: interface: use IS_REACHABLE to avoid some compile errors
  (bsc#1176447).
- xfrm: interface: not xfrmi_ipv6/ipip_handler twice
  (bsc#1176447).
- xfrm interface: store xfrmi contexts in a hash by if_id
  (bsc#1176447).
- xfrm interface: avoid xi lookup in xfrmi_decode_session()
  (bsc#1176447).
- xfrm: interface: support IPIP and IPIP6 tunnels processing
  with .cb_handler (bsc#1176447).
- xfrm: interface: support IP6IP6 and IP6IP tunnels processing
  with .cb_handler (bsc#1176447).
- tunnel6: add tunnel6_input_afinfo for ipip and ipv6 tunnels
  (bsc#1176447).
- tunnel4: add cb_handler to struct xfrm_tunnel (bsc#1176447).
- xfrm: add is_ipip to struct xfrm_input_afinfo (bsc#1176447).
- xfrm: introduce oseq-may-wrap flag (bsc#1176447).
- net/mlx5: drop unnecessary list_empty (jsc#SLE-15172).
- net/mlx5: Use fallthrough pseudo-keyword (jsc#SLE-15172).
- net/mlx5: DR, Reduce print level for matcher print
  (jsc#SLE-15172).
- net/mlx5e: Add support for PCI relaxed ordering (jsc#SLE-15172).
- net/mlx5e: Use indirect call wrappers for RX post WQEs functions
  (jsc#SLE-15172).
- net/mlx5e: Move exposure of datapath function to txrx header
  (jsc#SLE-15172).
- net/mlx5e: RX, Re-work initializaiton of RX function pointers
  (jsc#SLE-15172).
- net/mlx5e: Link non uplink representors to PCI device
  (jsc#SLE-15172).
- net/mlx5: E-switch, Use eswitch total_vports (jsc#SLE-15172).
- net/mlx5: E-switch, Reuse total_vports and avoid duplicate
  nvports (jsc#SLE-15172).
- net/mlx5: E-switch, Consider maximum vf vports for steering init
  (jsc#SLE-15172).
- net/mlx5: Add function ID to reclaim pages debug log
  (jsc#SLE-15172).
- net/mlx5: Hold pages RB tree per VF (jsc#SLE-15172).
- bareudp: Reverted support to enable & disable rx metadata
  collection (jsc#SLE-15172).
- net/mlx5e: CT: Map 128 bits labels to 32 bit map ID
  (jsc#SLE-15172).
- net/mlx5e: Do not request completion on every single UMR WQE
  (jsc#SLE-15172).
- net/mlx5e: RX, Avoid indirect call in representor CQE handling
  (jsc#SLE-15172).
- net/mlx5e: XDP, Avoid indirect call in TX flow (jsc#SLE-15172).
- net/mlx5e: IPsec: Add Connect-X IPsec ESN update offload support
  (jsc#SLE-15172).
- net/mlx5e: IPsec: Add Connect-X IPsec Rx data path offload
  (jsc#SLE-15172).
- net/mlx5e: IPsec: Add IPsec steering in local NIC RX
  (jsc#SLE-15172).
- net/mlx5: Accel, Add core IPsec support for the Connect-X family
  (jsc#SLE-15172).
- net/mlx5: E-switch, Reduce dependency on num_vfs during mode
  set (jsc#SLE-15172).
- net/mlx5: E-switch, Avoid function change handler for non ECPF
  (jsc#SLE-15172).
- net/mlx5: Make MLX5_EN_TLS non-prompt (jsc#SLE-15172).
- net/mlx5e: Fix build break when CONFIG_XPS is not set
  (jsc#SLE-15172).
- net/mlx5e: Move devlink-health rx and tx reporters to devlink
  port (jsc#SLE-15172).
- net/mlx5e: Move devlink port register and unregister calls
  (jsc#SLE-15172).
- net/mlx5e: CT: Remove unused function param (jsc#SLE-15172).
- net/mlx5e: CT: Return err_ptr from internal functions
  (jsc#SLE-15172).
- net/mlx5e: CT: Expand tunnel register mappings (jsc#SLE-15172).
- net/mlx5e: CT: Use mapping for zone restore register
  (jsc#SLE-15172).
- net/mlx5e: CT: Re-use tuple modify headers for identical modify
  actions (jsc#SLE-15172).
- net/mlx5e: Export sharing of mod headers to a new file
  (jsc#SLE-15172).
- net/mlx5e: CT: Restore ct state from lookup in zone instead
  of tupleid (jsc#SLE-15172).
- net/mlx5e: CT: Don't offload tuple rewrites for established
  tuples (jsc#SLE-15172).
- net/mlx5e: Use netdev_info instead of pr_info (jsc#SLE-15172).
- net/mlx5e: CT: Allow header rewrite of 5-tuple and ct clear
  action (jsc#SLE-15172).
- net/mlx5e: CT: Save ct entries tuples in hashtables
  (jsc#SLE-15172).
- net/mlx5: E-switch, When eswitch is unsupported, return
  - EOPNOTSUPP (jsc#SLE-15172).
- ixgbe: convert to new udp_tunnel_nic infra (jsc#SLE-13706).
- ixgbe: don't clear UDP tunnel ports when RXCSUM is disabled
  (jsc#SLE-13706).
- bonding: don't need RTNL for ipsec helpers (bsc#1176447).
- bonding: deal with xfrm state in all modes and add more
  error-checking (bsc#1176447).
- net/mlx5: Added support for 100Gbps per lane link modes
  (jsc#SLE-15172).
- geneve: move all configuration under struct geneve_config
  (bsc#1176447).
- net/mlx5e: Enhance TX timeout recovery (jsc#SLE-15172).
- net/mlx5e: Enhance ICOSQ data on RX reporter's diagnose
  (jsc#SLE-15172).
- net/mlx5e: Add EQ info to TX/RX reporter's diagnose
  (jsc#SLE-15172).
- net/mlx5e: Enhance CQ data on diagnose output (jsc#SLE-15172).
- net/mlx5e: Rename reporter's helpers (jsc#SLE-15172).
- net/mlx5e: Add helper to get the RQ WQE counter (jsc#SLE-15172).
- net/mlx5e: Add helper to get RQ WQE's head (jsc#SLE-15172).
- net/mlx5e: Move RQ helpers to txrx.h (jsc#SLE-15172).
- net/mlx5e: Align RX/TX reporters diagnose output format
  (jsc#SLE-15172).
- net/mlx5e: Remove redundant RQ state query (jsc#SLE-15172).
- net/mlx5e: Add a flush timeout define (jsc#SLE-15172).
- net/mlx5e: Change reporters create functions to return void
  (jsc#SLE-15172).
- ixgbe: Add ethtool support to enable 2.5 and 5.0 Gbps support
  (jsc#SLE-13706).
- ixgbe: Cleanup unneeded delay in ethtool test (jsc#SLE-13706).
- bonding: allow xfrm offload setup post-module-load
  (bsc#1176447).
- ena_netdev: use generic power management (bsc#1176447).
- net: ethernet: ixgbe: don't call devm_mdiobus_free()
  (jsc#SLE-13706).
- net: ethernet: ixgbe: check the return value of
  ixgbe_mii_bus_init() (jsc#SLE-13706).
- net/mlx5e: fix memory leak of tls (jsc#SLE-15172).
- net/mlx5e: kTLS, Improve rx handler function call
  (jsc#SLE-15172).
- net/mlx5e: kTLS, Cleanup redundant capability check
  (jsc#SLE-15172).
- net/mlx5e: Increase Async ICO SQ size (jsc#SLE-15172).
- net/mlx5e: kTLS, Add kTLS RX stats (jsc#SLE-15172).
- net/mlx5e: kTLS, Add kTLS RX resync support (jsc#SLE-15172).
- net/mlx5e: kTLS, Add kTLS RX HW offload support (jsc#SLE-15172).
- net/mlx5e: kTLS, Use kernel API to extract private offload
  context (jsc#SLE-15172).
- net/mlx5e: kTLS, Improve TLS feature modularity (jsc#SLE-15172).
- net/mlx5e: Accel, Expose flow steering API for rules add/del
  (jsc#SLE-15172).
- net/mlx5e: Receive flow steering framework for accelerated
  TCP flows (jsc#SLE-15172).
- net/mlx5e: API to manipulate TTC rules destinations
  (jsc#SLE-15172).
- net/mlx5e: Refactor build channel params (jsc#SLE-15172).
- net/mlx5e: Turn XSK ICOSQ into a general asynchronous one
  (jsc#SLE-15172).
- net/mlx5: kTLS, Improve TLS params layout structures
  (jsc#SLE-15172).
- net/mlx5: Avoid eswitch header inclusion in fs core layer
  (jsc#SLE-15172).
- bareudp: Added attribute to enable & disable rx metadata
  collection (jsc#SLE-15172).
- bonding: Remove extraneous parentheses in bond_setup
  (bsc#1176447).
- net/mlx5e: vxlan: Return bool instead of opaque ptr in
  port_lookup() (jsc#SLE-15172).
- net/mlx5e: vxlan: Use RCU for vxlan table lookup
  (jsc#SLE-15172).
- net/mlx5e: Move TC-specific function definitions into
  MLX5_CLS_ACT (jsc#SLE-15172).
- net/mlx5e: Move including net/arp.h from en_rep.c to rep/neigh.c
  (jsc#SLE-15172).
- net/mlx5e: Remove unused mlx5e_xsk_first_unused_channel
  (jsc#SLE-15172).
- net/mlx5: Use kfree(ft->g) in arfs_create_groups()
  (jsc#SLE-15172).
- net/mlx5: FWTrace: Add missing space (jsc#SLE-15172).
- net/mlx5: Avoid eswitch header inclusion in fs core layer
  (jsc#SLE-15172).
- bonding/xfrm: use real_dev instead of slave_dev (bsc#1176447).
- bonding: support hardware encryption offload to slaves
  (bsc#1176447).
- mlx5: become aware of when running as a bonding slave
  (jsc#SLE-15172).
- ixgbe_ipsec: become aware of when running as a bonding slave
  (jsc#SLE-13706).
- xfrm: bail early on slave pass over skb (bsc#1176447).
- net/mlx5: E-switch, Supporting setting devlink port function
  mac address (jsc#SLE-15172).
- net/mlx5: Split mac address setting function for using
  state_lock (jsc#SLE-15172).
- net/mlx5: E-switch, Support querying port function mac address
  (jsc#SLE-15172).
- net/mlx5: E-switch, Introduce and use eswitch support check
  helper (jsc#SLE-15172).
- net/mlx5: Constify mac address pointer (jsc#SLE-15172).
- vxlan: fix memleak of fdb (bsc#1176447).
- espintcp: count packets dropped in espintcp_rcv (bsc#1176447).
- espintcp: handle short messages instead of breaking the encap
  socket (bsc#1176447).
- xfrm: Fix crash when the hold queue is used (bsc#1176447).
- xfrm: policy: fix IPv6-only espintcp compilation (bsc#1176447).
- espintcp: recv() should return 0 when the peer socket is closed
  (bsc#1176447).
- espintcp: support non-blocking sends (bsc#1176447).
- net: xfrmi: implement header_ops->parse_protocol for AF_PACKET
  (bsc#1176447).
- net: ip_tunnel: add header_ops for layer 3 devices
  (bsc#1176447).
- vxlan: fix last fdb index during dump of fdb with nhid
  (bsc#1176447).
- esp, ah: modernize the crypto algorithm selections
  (bsc#1176447).
- esp: select CRYPTO_SEQIV (bsc#1176447).
- xfrm: merge fixup for "remove output_finish indirection from
  xfrm_state_afinfo" (bsc#1176447).
- xfrm: Fix double ESP trailer insertion in IPsec crypto offload
  (bsc#1176447).
- vxlan: Remove access to nexthop group struct (bsc#1176447).
- nexthop: Fix fdb labeling for groups (bsc#1176447).
- net: change addr_list_lock back to static key (bsc#1176447).
- vxlan: fix dereference of nexthop group in nexthop update path
  (bsc#1176447).
- ipv4: nexthop: Fix deadcode issue by performing a proper NULL
  check (bsc#1176447).
- vxlan: few locking fixes in nexthop event handler (bsc#1176447).
- vxlan: add check to prevent use of remote ip attributes with
  NDA_NH_ID (bsc#1176447).
- xfrm: fix unused variable warning if CONFIG_NETFILTER=n
  (bsc#1176447).
- xfrm: remove output_finish indirection from xfrm_state_afinfo
  (bsc#1176447).
- xfrm: remove extract_output indirection from xfrm_state_afinfo
  (bsc#1176447).
- xfrm: place xfrm6_local_dontfrag in xfrm.h (bsc#1176447).
- xfrm: expose local_rxpmtu via ipv6_stubs (bsc#1176447).
- xfrm: move xfrm4_extract_header to common helper (bsc#1176447).
- xfrm: state: remove extract_input indirection from
  xfrm_state_afinfo (bsc#1176447).
- xfrm: avoid extract_output indirection for ipv4 (bsc#1176447).
- xfrm: add IPv6 support for espintcp (bsc#1176447).
- xfrm: add support for UDPv6 encapsulation of ESP (bsc#1176447).
- xfrm interface: don't take extra reference to netdev
  (bsc#1176447).
- nexthop: Fix type of event_type in call_nexthop_notifiers
  (bsc#1176447).
- vxlan: Do not assume RTNL is held in vxlan_fdb_info()
  (bsc#1176447).
- tunnel6: support for IPPROTO_MPLS (bsc#1176447).
- vxlan: support for nexthop notifiers (bsc#1176447).
- nexthop: add support for notifiers (bsc#1176447).
- vxlan: ecmp support for mac fdb entries (bsc#1176447).
- nexthop: support for fdb ecmp nexthops (bsc#1176447).
- ena: Add XDP frame size to amazon NIC driver (bsc#1176447).
- bonding: Implement ndo_get_xmit_slave (bsc#1176447).
- bonding: Add array of all slaves (bsc#1176447).
- bonding: Add function to get the xmit slave in active-backup
  mode (bsc#1176447).
- bonding: Add helper function to get the xmit slave in rr mode
  (bsc#1176447).
- bonding: Add helper function to get the xmit slave based on hash
  (bsc#1176447).
- bonding/alb: Add helper functions to get the xmit slave
  (bsc#1176447).
- bonding: Rename slave_arr to usable_slaves (bsc#1176447).
- bonding: Export skip slave logic to function (bsc#1176447).
- bonding: propagate transmit status (bsc#1176447).
- netpoll: accept NULL np argument in netpoll_send_skb()
  (bsc#1176447).
- netpoll: netpoll_send_skb() returns transmit status
  (bsc#1176447).
- netpoll: move netpoll_send_skb() out of line (bsc#1176447).
- netpoll: remove dev argument from netpoll_send_skb_on_dev()
  (bsc#1176447).
- bonding: remove useless stats_lock_key (bsc#1176447).
- netpoll: Fix use correct return type for ndo_start_xmit()
  (bsc#1176447).
- net: ipv4: add sysctl for nexthop api compatibility mode
  (bsc#1176447).
- net: ipv6: new arg skip_notify to ip6_rt_del (bsc#1176447).
- xfrm: fix a NULL-ptr deref in xfrm_local_error (bsc#1176447).
- xfrm interface: fix oops when deleting a x-netns interface
  (bsc#1176447).
- xfrm: call xfrm_output_gso when inner_protocol is set in
  xfrm_output (bsc#1176447).
- xfrm: espintcp: save and call old ->sk_destruct (bsc#1176447).
- xfrm: do pskb_pull properly in __xfrm_transport_prep
  (bsc#1176447).
- xfrm: allow to accept packets with ipv6 NEXTHDR_HOP in
  xfrm_input (bsc#1176447).
- bonding: Fix reference count leak in bond_sysfs_slave_add
  (bsc#1176447).
- nexthops: don't modify published nexthop groups (bsc#1176447).
- nexthops: Move code from remove_nexthop_from_groups to
  remove_nh_grp_entry (bsc#1176447).
- xfrm: add prep for esp beet mode offload (bsc#1176447).
- ESP: Export esp_output_fill_trailer function (bsc#1176447).
- xfrm: Use kmem_cache_zalloc() instead of kmem_cache_alloc()
  with flag GFP_ZERO (bsc#1176447).
- net: add net available in build_state (bsc#1176447).
- net: ipv6: add support for rpl sr exthdr (bsc#1176447).
- addrconf: add functionality to check on rpl requirements
  (bsc#1176447).
- include: uapi: linux: add rpl sr header definition
  (bsc#1176447).
- net: Fix typo of SKB_SGO_CB_OFFSET (bsc#1176447).
- Remove DST_HOST (bsc#1176447).
- net: ena: reject unsupported coalescing params (bsc#1176447).
- net: lwtunnel: Replace zero-length array with flexible-array
  member (bsc#1176447).
- net: datagram: drop 'destructor' argument from several helpers
  (bsc#1176447).
- unix: uses an atomic type for scm files accounting
  (bsc#1176447).
- bonding: Replace zero-length array with flexible-array member
  (bsc#1176447).
- af_unix: Add missing annotation for unix_wait_for_peer()
  (bsc#1176447).
- xfrm: policy: Fix doulbe free in xfrm_policy_timer
  (bsc#1176447).
- esp: remove the skb from the chain when it's enqueued in
  cryptd_wq (bsc#1176447).
- xfrm: add the missing verify_sec_ctx_len check in
  xfrm_add_acquire (bsc#1176447).
- xfrm: fix uctx len check in verify_sec_ctx_len (bsc#1176447).
- xfrm: handle NETDEV_UNREGISTER for xfrm device (bsc#1176447).
- unix: It's CONFIG_PROC_FS not CONFIG_PROCFS (bsc#1176447).
- unix: define and set show_fdinfo only if procfs is enabled
  (bsc#1176447).
- xfrm: interface: use icmp_ndo_send helper (bsc#1176447).
- esp4: split esp_output_udp_encap and introduce esp_output_encap
  (bsc#1176447).
- esp4: prepare esp_input_done2 for non-UDP encapsulation
  (bsc#1176447).
- xfrm: introduce xfrm_trans_queue_net (bsc#1176447).
- net: add queue argument to __skb_wait_for_more_packets and
  __skb_{,try_}recv_datagram (bsc#1176447).
- net: xfrm: use skb_list_walk_safe helper for gso segments
  (bsc#1176447).
- vxlan: Fix alignment and code style of vxlan.c (bsc#1176447).
- bonding: rename AD_STATE_* to LACP_STATE_* (bsc#1176447).
- bonding: move 802.3ad port state flags to uapi (bsc#1176447).
- unix: Show number of pending scm files of receive queue in
  fdinfo (bsc#1176447).
- net: Allow to show socket-specific information in
  /proc//fdinfo/[fd] (bsc#1176447).
- xfrm: interface: do not confirm neighbor when do pmtu update
  (bsc#1176447).
- xfrm: ifdef
  setsockopt(UDP_ENCAP_ESPINUDP/UDP_ENCAP_ESPINUDP_NON_IKE)
  (bsc#1176447).
- xfrm: remove the unnecessary .net_exit for xfrmi (bsc#1176447).
- Convert usage of IN_MULTICAST to ipv4_is_multicast
  (bsc#1176447).
- commit 61eba3d
* Mon Oct  5 2020 tiwai@suse.de
- platform/x86: intel-vbtn: Switch to an allow-list for
  SW_TABLET_MODE reporting (bsc#1175599).
- commit 677b36d
* Mon Oct  5 2020 mbenes@suse.cz
- ftrace: Move RCU is watching check after recursion check
  (git-fixes).
- commit 3837051
* Mon Oct  5 2020 yousaf.kaukab@suse.com
- r8152: Use MAC address from correct device tree node
  (jsc#SLE-15847).
- iommu/arm-smmu: Add global/context fault implementation hooks
  (jsc#SLE-15847).
- iommu/arm-smmu: add NVIDIA implementation for ARM MMU-500 usage
  (jsc#SLE-15847).
- iommu/arm-smmu: ioremap smmu mmio region before implementation
  init (jsc#SLE-15847).
- iommu/arm-smmu: move TLB timeout and spin count macros
  (jsc#SLE-15847).
- soc/tegra: fuse: Add Tegra186 and Tegra194 SoC IDs
  (jsc#SLE-15847).
- firmware: tegra: Update BPMP ABI (jsc#SLE-15847).
- r8152: Use MAC address from device tree if available
  (jsc#SLE-15847).
- nvmem: core: fix memory abort in cleanup path (jsc#SLE-15847).
- gpio: tegra186: Allow building on Tegra194-only configurations
  (jsc#SLE-15847).
- mmc: mmc_spi: Use proper debounce time for CD GPIO
  (jsc#SLE-15847).
- hwmon: pwm-fan: Use platform_get_irq_optional() (jsc#SLE-15847).
- commit 33ea3c2
* Mon Oct  5 2020 tbogendoerfer@suse.de
- ionic: add more ethtool stats (jsc#SLE-16649).
- Refresh patches.suse/ionic-centralize-queue-reset-code.patch.
- commit 3512559
* Mon Oct  5 2020 tbogendoerfer@suse.de
- ionic: fix txrx work accounting (jsc#SLE-16649).
- ionic_lif: Use devm_kcalloc() in ionic_qcq_alloc()
  (jsc#SLE-16649).
- ionic: separate interrupt for Tx and Rx (jsc#SLE-16649).
- ionic: tx separate servicing (jsc#SLE-16649).
- ionic: use fewer firmware doorbells on rx fill (jsc#SLE-16649).
- ionic: fix memory leak of object 'lid' (jsc#SLE-16649).
- ionic: interface file updates (jsc#SLE-16649).
- ionic: rearrange reset and bus-master control (jsc#SLE-16649).
- ionic: update eid test for overflow (jsc#SLE-16649).
- ionic: remove unused ionic_coal_hw_to_usec (jsc#SLE-16649).
- ionic: set netdev default name (jsc#SLE-16649).
- ionic: get MTU from lif identity (jsc#SLE-16649).
- ionic: more ionic name tweaks (jsc#SLE-16649).
- ionic: ionic_intr_free parameter change (jsc#SLE-16649).
- ionic: reset device at probe (jsc#SLE-16649).
- ionic: shorter dev cmd wait time (jsc#SLE-16649).
- ionic: add support for more xcvr types (jsc#SLE-16649).
- ionic: protect vf calls from fw reset (jsc#SLE-16649).
- ionic: updates to ionic FW api description (jsc#SLE-16649).
- ionic: support longer tx sg lists (jsc#SLE-16649).
- ionic: Use debugfs_create_bool() to export bool (jsc#SLE-16649).
- ionic: add device reset to fw upgrade down (jsc#SLE-16649).
- ionic: let core reject the unsupported coalescing parameters
  (jsc#SLE-16649).
- ionic: use new helper tcp_v6_gso_csum_prep (jsc#SLE-16649).
- commit 74144f5
* Mon Oct  5 2020 jroedel@suse.de
- iommu/amd: Fix IOMMU AVIC not properly update the is_run bit
  in IRTE (bsc#1177297).
- commit d4ca096
* Mon Oct  5 2020 glin@suse.com
- bpf: Sanitize the bpf_struct_ops tcp-cc name (bsc#1177028).
- bpf: Do not allow map_freeze in struct_ops map (bsc#1177028).
- bpf: Return better error value in delete_elem for struct_ops
  map (bsc#1177028).
- bpf: Fix a potential deadlock with bpf_map_do_batch
  (bsc#1177028).
- bpf: Do not grab the bucket spinlock by default on htab batch
  ops (bsc#1177028).
- bpf: Make btf_check_func_type_match() static (bsc#1177028).
- bpf: Reuse log from btf_prase_vmlinux() in btf_struct_ops_init()
  (bsc#1177028).
- bpf, xdp: Remove no longer required rcu_read_{un}lock()
  (bsc#1177028).
- bpf, xdp: Update devmap comments to reflect napi/rcu usage
  (bsc#1177028).
- bpf: Allow to resolve bpf trampoline and dispatcher in unwind
  (bsc#1177028).
- bpf: Allow BTF ctx access for string pointers (bsc#1177028).
- bpf, devmap: Pass lockdep expression to RCU lists (bsc#1177028).
- bpf: Add BPF_FUNC_jiffies64 (bsc#1177028).
- bpf: Introduce dynamic program extensions (bsc#1177028).
- bpf: Fix error path under memory pressure (bsc#1177028).
- bpf: Add bpf_send_signal_thread() helper (bsc#1177028).
- bpf: Synch uapi bpf.h to tools/ (bsc#1177028).
- bpf: Add BPF_FUNC_tcp_send_ack helper (bsc#1177028).
- commit e5c066f
* Mon Oct  5 2020 jroedel@suse.de
- drm/prime: fix extracting of the DMA addresses from a
  scatterlist (bsc#1177287).
- commit e4cdf1b
* Mon Oct  5 2020 jroedel@suse.de
- iommu/amd: Re-factor guest virtual APIC (de-)activation code
  (bsc#1177284).
- Refresh
  patches.suse/iommu-amd-restore-irte-remapen-bit-after-programming-irte.
- commit 9de73d9
* Mon Oct  5 2020 jroedel@suse.de
- iommu/exynos: add missing put_device() call in
  exynos_iommu_of_xlate() (bsc#1177286).
- iommu/amd: Restore IRTE.RemapEn bit for
  amd_iommu_activate_guest_mode (bsc#1177285).
- iommu/amd: Fix potential @entry null deref (bsc#1177283).
- commit 7766a97
* Mon Oct  5 2020 jroedel@suse.de
- iommu/amd: Fix the overwritten field in IVMD header
  (bsc#1177280).
- drm/radeon: fix scatter-gather mapping with user pages
  (bsc#1177279).
- drm/amdgpu: fix scatter-gather mapping with user pages
  (bsc#1177277).
- drm/prime: use dma length macro when mapping sg (bsc#1177278).
- commit c5a03ce
* Mon Oct  5 2020 jgross@suse.com
- xen/events: don't use chip_data for legacy IRQs (bsc#1065600).
- commit 1009a6a
* Mon Oct  5 2020 tiwai@suse.de
- phy: ti: am654: Fix a leak in serdes_am654_probe() (git-fixes).
- commit 91925ce
* Mon Oct  5 2020 tiwai@suse.de
- USB: gadget: f_ncm: Fix NDP16 datagram validation (git-fixes).
- commit 62e667f
* Mon Oct  5 2020 tiwai@suse.de
- Input: trackpoint - enable Synaptics trackpoints (git-fixes).
- commit e02fa5e
* Mon Oct  5 2020 tiwai@suse.de
- pinctrl: mvebu: Fix i2c sda definition for 98DX3236 (git-fixes).
- commit 9356b76
* Mon Oct  5 2020 tiwai@suse.de
- iio: adc: qcom-spmi-adc5: fix driver name (git-fixes).
- commit f78905d
* Mon Oct  5 2020 tiwai@suse.de
- gpio: mockup: fix resource leak in error path (git-fixes).
- commit bdd2ea9
* Mon Oct  5 2020 tiwai@suse.de
- gpio: siox: explicitly support only threaded irqs (git-fixes).
- commit 57c8150
* Mon Oct  5 2020 tiwai@suse.de
- gpio: tc35894: fix up tc35894 interrupt configuration
  (git-fixes).
- commit bcd4186
* Mon Oct  5 2020 tiwai@suse.de
- gpio: sprd: Clear interrupt when setting the type as edge
  (git-fixes).
- commit 3f5c502
* Mon Oct  5 2020 tiwai@suse.de
- mmc: sdhci: Workaround broken command queuing on Intel GLK
  based IRBIS models (git-fixes).
- commit ca933ab
* Mon Oct  5 2020 tiwai@suse.de
- clk: socfpga: stratix10: fix the divider for the
  emac_ptp_free_clk (git-fixes).
- commit f3d75fd
* Mon Oct  5 2020 tiwai@suse.de
- clk: samsung: exynos4: mark 'chipid' clock as CLK_IGNORE_UNUSED
  (git-fixes).
- commit e344453
* Mon Oct  5 2020 tiwai@suse.de
- clk: tegra: Always program PLL_E when enabled (git-fixes).
- commit bbc21a4
* Mon Oct  5 2020 glin@suse.com
- bpf: don't bother with getname/kern_path - use user_path_at
  (bsc#1177028).
- bpf: Fix memory leaks in generic update/delete batch ops
  (bsc#1177028).
- bpf: Remove set but not used variable 'first_key' (bsc#1177028).
- devmap: Adjust tracepoint for map-less queue flush
  (bsc#1177028).
- xdp: Use bulking for non-map XDP_REDIRECT and consolidate code paths (bsc#1177028).
  Refresh patches.suse/tun-Don-t-put_page-for-all-negative-return-values-fr.patch
- xdp: Move devmap bulk queue into struct net_device (bsc#1177028).
  Refresh patches.suse/net-partially-revert-dynamic-lockdep-key-changes.patch
- bpf: Add batch ops to all htab bpf map (bsc#1177028).
- bpf: Add lookup and update batch ops to arraymap (bsc#1177028).
- bpf: Add generic support for update and delete batch ops
  (bsc#1177028).
- bpf: Add generic support for lookup batch op (bsc#1177028).
- bpf: Add bpf_map_{value_size, update_value, map_copy_value}
  functions (bsc#1177028).
- bpf: Fix seq_show for BPF_MAP_TYPE_STRUCT_OPS (bsc#1177028).
- bpf: Introduce function-by-function verification (bsc#1177028).
- bpf: tcp: Support tcp_congestion_ops in bpf (bsc#1177028).
- bpf: Introduce BPF_MAP_TYPE_STRUCT_OPS (bsc#1177028).
  Refresh patches.suse/bpf-Fix-trampoline-usage-in-preempt.patch due to
  the change of arch_prepare_bpf_trampoline() parameters.
- bpf: Introduce BPF_PROG_TYPE_STRUCT_OPS (bsc#1177028).
  Refresh patches.suse/bpf-Fix-handling-of-XADD-on-BTF-memory.patch
- xdp: Remove map_to_flush and map swap detection (bsc#1177028).
- commit 1b26450
* Sun Oct  4 2020 lduncan@suse.com
- scsi: iscsi: iscsi_tcp: Avoid holding spinlock while calling
  getpeername() (bsc#1177258).
- commit ea50f56
* Sat Oct  3 2020 mgorman@suse.de
- sched/fair: Ignore cache hotness for SMT migration (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/numa: Use runnable_avg to classify node (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Use dst group while checking imbalance for NUMA
  balancer (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit a9a7020
* Sat Oct  3 2020 tiwai@suse.de
- clocksource/drivers/h8300_timer8: Fix wrong return value in
  h8300_8timer_init() (git-fixes).
- hwmon: (applesmc) check status earlier (git-fixes).
- 9p: Fix memory leak in v9fs_mount (git-fixes).
- yam: fix possible memory leak in yam_init_driver (git-fixes).
- airo: Fix read overflows sending packets (git-fixes).
- clk/ti/adpll: allocate room for terminating null (git-fixes).
- ASoC: kirkwood: fix IRQ error handling (git-fixes).
- commit 7091952
* Sat Oct  3 2020 tbogendoerfer@suse.de
- Stop the ad-hoc games with -Wno-maybe-initialized
  (jsc#SLE-15176).
- Update config files.
- commit 4e6fc9e
* Sat Oct  3 2020 tbogendoerfer@suse.de
- RDMA/mlx5: Fix flow destination setting for RDMA TX flow table
  (jsc#SLE-15175).
- blacklist.conf: removed from blacklist
- commit 54c5f83
* Sat Oct  3 2020 tbogendoerfer@suse.de
- IB/uverbs: Enable CQ ioctl commands by default (jsc#SLE-15176).
- Update config files.
- commit 4c62ead
* Sat Oct  3 2020 tbogendoerfer@suse.de
- RDMA/bnxt_re: Change wr posting logic to accommodate variable
  wqes (jsc#SLE-15076).
- Refresh
  patches.suse/RDMA-bnxt_re-Fix-the-qp-table-indexing.patch.
- commit f2be734
* Sat Oct  3 2020 tbogendoerfer@suse.de
- RDMA/bnxt_re: introduce a function to allocate swq
  (jsc#SLE-15076).
- Refresh
  patches.suse/RDMA-bnxt_re-Fix-the-qp-table-indexing.patch.
- commit 9d35d9b
* Sat Oct  3 2020 tbogendoerfer@suse.de
- RDMA/mlx5: Introduce ODP prefetch counter (jsc#SLE-15175).
- Refresh
  patches.suse/RDMA-mlx5-Add-missing-srcu_read_lock-in-ODP-implicit.patch.
- commit 47723a3
* Fri Oct  2 2020 tbogendoerfer@suse.de
- RDMA/core: Fix ordering of CQ pool destruction (jsc#SLE-15176).
- IB/isert: Fix unaligned immediate-data handling (jsc#SLE-15176).
- RDMA/rtrs-srv: Set .release function for rtrs srv device during
  device init (jsc#SLE-15176).
- RDMA/core: Fix reported speed and width (jsc#SLE-15176).
- RDMA/core: Fix unsafe linked list traversal after failing to
  allocate CQ (jsc#SLE-15176).
- RDMA/bnxt_re: Fix driver crash on unaligned PSN entry address
  (jsc#SLE-15076).
- RDMA/rxe: Fix panic when calling kmem_cache_create()
  (jsc#SLE-15176).
- RDMA/rxe: Fix memleak in rxe_mem_init_user (jsc#SLE-15176).
- RDMA/rxe: Fix the parent sysfs read when the interface has 15
  chars (jsc#SLE-15176).
- RDMA/rtrs-srv: Replace device_register with device_initialize
  and device_add (jsc#SLE-15176).
- Revert "RDMA/hns: Reserve one sge in order to avoid local
  length error" (jsc#SLE-14777).
- RDMA/hfi1: Correct an interlock issue for TID RDMA WRITE request
  (jsc#SLE-13208).
- RDMA/bnxt_re: Do not add user qps to flushlist (jsc#SLE-15076).
- RDMA/core: Fix spelling mistake "Could't" -> "Couldn't"
  (jsc#SLE-15176).
- RDMA/usnic: Fix spelling mistake "transistion" -> "transition"
  (jsc#SLE-15176).
- RDMA/hns: Fix spelling mistake "epmty" -> "empty"
  (jsc#SLE-14777).
- RDMA/rxe: Remove pkey table (jsc#SLE-15176).
- RDMA/umem: Add a schedule point in ib_umem_get()
  (jsc#SLE-15176).
- RDMA/hns: Fix the unneeded process when getting a general type
  of CQE error (jsc#SLE-14777).
- RDMA/hns: Fix error during modify qp RTS2RTS (jsc#SLE-14777).
- RDMA/hns: Delete unnecessary memset when allocating VF resource
  (jsc#SLE-14777).
- RDMA/hns: Remove redundant parameters in set_rc_wqe()
  (jsc#SLE-14777).
- RDMA/hns: Remove support for HIP08_A (jsc#SLE-14777).
- RDMA/hns: Refactor hns_roce_v2_set_hem() (jsc#SLE-14777).
- RDMA/hns: Remove redundant hardware opcode definitions
  (jsc#SLE-14777).
- RDMA/netlink: Remove CAP_NET_RAW check when dump a raw QP
  (jsc#SLE-15176).
- RDMA/include: Replace license text with SPDX tags
  (jsc#SLE-15176).
- RDMA/rtrs: remove WQ_MEM_RECLAIM for rtrs_wq (jsc#SLE-15176).
- RDMA/rtrs-clt: add an additional random 8 seconds before
  reconnecting (jsc#SLE-15176).
- RDMA/cma: Execute rdma_cm destruction from a handler properly
  (jsc#SLE-15176).
- RDMA/cma: Remove unneeded locking for req paths (jsc#SLE-15176).
- RDMA/cma: Using the standard locking pattern when delivering
  the removal event (jsc#SLE-15176).
- RDMA/cma: Simplify DEVICE_REMOVAL for internal_id
  (jsc#SLE-15176).
- RDMA/efa: Add EFA 0xefa1 PCI ID (jsc#SLE-15176).
- RDMA/efa: User/kernel compatibility handshake mechanism
  (jsc#SLE-15176).
- RDMA/efa: Expose minimum SQ size (jsc#SLE-15176).
- RDMA/efa: Expose maximum TX doorbell batch (jsc#SLE-15176).
- IB/srpt: use new shared CQ mechanism (jsc#SLE-15176).
- IB/isert: use new shared CQ mechanism (jsc#SLE-15176).
- IB/iser: use new shared CQ mechanism (jsc#SLE-15176).
- RDMA/mlx5: Delete unreachable code (jsc#SLE-15175).
- RDMA/core: Fix return error value in _ib_modify_qp() to negative
  (jsc#SLE-15176).
- RDMA/mlx5: Set mkey relaxed ordering by UMR with ConnectX-7
  (jsc#SLE-15175).
- RDMA/mlx5: Use MLX5_SET macro instead of local structure
  (jsc#SLE-15175).
- RDMA/mlx5: ConnectX-7 new capabilities to set relaxed ordering
  by UMR (jsc#SLE-15175).
- net/mlx5: Add interface changes required for VDPA
  (jsc#SLE-15175).
- IB/hfi1: Use fallthrough pseudo-keyword (jsc#SLE-13208).
- RDMA/uverbs: Silence shiftTooManyBitsSigned warning
  (jsc#SLE-15176).
- RDMA/uverbs: Remove redundant assignments (jsc#SLE-15176).
- RDMA/core: Update write interface to use automatic object
  lifetime (jsc#SLE-15176).
- RDMA/core: Align abort/commit object scheme for write() and
  ioctl() paths (jsc#SLE-15176).
- RDMA/mlx5: Allow SQ modification (jsc#SLE-15175).
- RDMA: rdma_user_ioctl.h: fix a duplicated word + clarify
  (jsc#SLE-15176).
- RDMA/bnxt_re: Add helper data structures (jsc#SLE-15076).
- RDMA/bnxt_re: Pull psn buffer dynamically based on prod
  (jsc#SLE-15076).
- RDMA/bnxt_re: introduce wqe mode to select execution path
  (jsc#SLE-15076).
- RDMA/qedr: Remove the query_pkey callback (jsc#SLE-15146).
- RDMA/i40iw: Remove the query_pkey callback (jsc#SLE-13537).
- RDMA/cxgb4: Remove the query_pkey callback (jsc#SLE-15118).
- RDMA/siw: Remove the query_pkey callback (jsc#SLE-15111).
- RDMA/core: Remove query_pkey from the mandatory ops
  (jsc#SLE-15176).
- RDMA/core: Allocate the pkey cache only if the pkey_tbl_len
  is set (jsc#SLE-15176).
- RDMA/core: Expose pkeys sysfs files only if pkey_tbl_len is set
  (jsc#SLE-15176).
- RDMA/rxe: Prevent access to wr->next ptr afrer wr is posted
  to send queue (jsc#SLE-15176).
- RDMA/qedr: Add EDPM max size to alloc ucontext response
  (jsc#SLE-15146).
- RDMA/qedr: Add EDPM mode type for user-fw compatibility
  (jsc#SLE-15146).
- RDMA/usnic: switch from 'pci_' to 'dma_' API (jsc#SLE-15176).
- IB/hfi1: Remove unnecessary fall-through markings
  (jsc#SLE-13208).
- RDMA/qedr: SRQ's bug fixes (jsc#SLE-15146).
- IB/isert: allocate RW ctxs according to max IO size
  (jsc#SLE-15176).
- RDMA/mlx5: Init dest_type when create flow (jsc#SLE-15175).
- RDMA/rxe: Remove rxe_link_layer() (jsc#SLE-15176).
- RDMA/rxe: Return void from rxe_mem_init_dma() (jsc#SLE-15176).
- RDMA/rxe: Return void from rxe_init_port_param()
  (jsc#SLE-15176).
- RDMA/rxe: Drop pointless checks in rxe_init_ports
  (jsc#SLE-15176).
- RDMA/counter: Allow manually bind QPs with different pids to
  same counter (jsc#SLE-15176).
- RDMA/counter: Only bind user QPs in auto mode (jsc#SLE-15176).
- RDMA/counter: Add PID category support in auto mode
  (jsc#SLE-15176).
- RDMA/mlx5: Remove unused to_mibmr function (jsc#SLE-15175).
- RDMA/mlx5: Delete one-time used functions (jsc#SLE-15175).
- RDMA/mlx5: Cleanup DEVX initialization flow (jsc#SLE-15175).
- RDMA/mlx5: Separate flow steering logic from main.c
  (jsc#SLE-15175).
- RDMA/mlx5: Separate counters from main.c (jsc#SLE-15175).
- RDMA/mlx5: Separate restrack callbacks initialization from
  main.c (jsc#SLE-15175).
- RDMA/mlx5: Limit the scope of mlx5_ib_enable_driver function
  (jsc#SLE-15175).
- RDMA/hns: Optimize MTR level-0 addressing to access huge page
  (jsc#SLE-14777).
- RDMA/rxe: Skip dgid check in loopback mode (jsc#SLE-15176).
- RDMA: Move XRCD to be under ib_core responsibility
  (jsc#SLE-15176).
- RDMA/core: Create and destroy counters in the ib_core
  (jsc#SLE-15176).
- IB/uverbs: Expose UAPI to query MR (jsc#SLE-15176).
- RDMA/mlx5: Introduce UAPI to query PD attributes
  (jsc#SLE-15175).
- RDMA/mlx5: Implement the query ucontext functionality
  (jsc#SLE-15175).
- RDMA/mlx5: Refactor mlx5_ib_alloc_ucontext() response
  (jsc#SLE-15175).
- IB/uverbs: Expose UAPI to query ucontext (jsc#SLE-15176).
- IB/uverbs: Set IOVA on IB MR in uverbs layer (jsc#SLE-15176).
- RDMA/core: Optimize XRC target lookup (jsc#SLE-15176).
- RDMA/core: Clean ib_alloc_xrcd() and reuse it to allocate XRC
  domain (jsc#SLE-15176).
- RDMA/mlx5: Get XRCD number directly for the internal use
  (jsc#SLE-15175).
- RDMA: Remove the udata parameter from alloc_mr callback
  (jsc#SLE-15176).
- RDMA/core: Remove ib_alloc_mr_user function (jsc#SLE-15176).
- RDMA/core: Check for error instead of success in alloc MR
  function (jsc#SLE-15176).
- RDMA/core: Clean up tracepoint headers (jsc#SLE-15176).
- RDMA/ipoib: Handle user-supplied address when creating child
  (jsc#SLE-15176).
- RDMA/core: Fix bogus WARN_ON during
  ib_unregister_device_queued() (jsc#SLE-15176).
- RDMA/ipoib: Fix ABBA deadlock with ipoib_reap_ah()
  (jsc#SLE-15176).
- IB/hfi1: Convert PCIBIOS_* errors to generic -E* errors
  (jsc#SLE-13208).
- RDMA/core: Delete not-used create RWQ table function
  (jsc#SLE-15176).
- IB/mad: Delete RMPP_STATE_CANCELING state (jsc#SLE-15176).
- IB/mad: Change atomics to refcount API (jsc#SLE-15176).
- IB/mad: Issue complete whenever decrements agent refcount
  (jsc#SLE-15176).
- RDMA/ipoib: Return void from ipoib_ib_dev_stop()
  (jsc#SLE-15176).
- RDMA/mlx5: Add support to get MR resource in RAW format
  (jsc#SLE-15175).
- RDMA/mlx5: Add support to get CQ resource in RAW format
  (jsc#SLE-15175).
- RDMA/mlx5: Add support to get QP resource in RAW format
  (jsc#SLE-15175).
- RDMA: Add support to dump resource tracker in RAW format
  (jsc#SLE-15176).
- RDMA: Add dedicated CM_ID resource tracker function
  (jsc#SLE-15176).
- RDMA: Add dedicated QP resource tracker function
  (jsc#SLE-15176).
- RDMA: Add a dedicated CQ resource tracker function
  (jsc#SLE-15176).
- RDMA: Add dedicated MR resource tracker function
  (jsc#SLE-15176).
- RDMA/core: Don't call fill_res_entry for PD (jsc#SLE-15176).
- RDMA/rxe: Remove unused rxe_mem_map_pages (jsc#SLE-15176).
- RDMA/hfi1: Remove hfi1_create_qp declaration (jsc#SLE-13208).
- RDMA/ipoib: Return void from ipoib_mcast_stop_thread()
  (jsc#SLE-15176).
- RDMA: Correct trivial kernel-doc inconsistencies
  (jsc#SLE-15176).
- IB/srpt: Remove WARN_ON from srpt_cm_req_recv (jsc#SLE-15176).
- qed: fix assignment of n_rq_elems to incorrect params field
  (jsc#SLE-15143).
- net/mlx5: Add IPsec related Flow steering entry's fields
  (jsc#SLE-15175).
- net/mlx5: Add support in query QP, CQ and MKEY segments
  (jsc#SLE-15175).
- net/mlx5: Export resource dump interface (jsc#SLE-15175).
- RDMA/core: Use offsetofend() instead of open coding
  (jsc#SLE-15176).
- IB/rdmavt: Replace zero-length array with flexible-array
  (jsc#SLE-15176).
- RDMA/ucma: Return stable IB device index as identifier
  (jsc#SLE-15176).
- commit d0e3d42
* Fri Oct  2 2020 jdelvare@suse.de
- drm/amdgpu: restore proper ref count in
  amdgpu_display_crtc_set_config (git-fixes).
- commit cb11410
* Fri Oct  2 2020 tiwai@suse.de
- supported.conf: add intel_th_msu_sink (jsc#SLE-12705)
- commit 4234fcb
* Fri Oct  2 2020 tiwai@suse.de
- intel_th: msu: Make stopping the trace optional (jsc#SLE-12705).
- intel_th: Disallow multi mode on devices where it's broken
  (jsc#SLE-12705).
- intel_th: msu: Fix the unexpected state warning (jsc#SLE-12705).
- intel_th: msu: Fix possible memory leak in mode_store()
  (jsc#SLE-12705).
- intel_th: msu: Fix overflow in shift of an unsigned int
  (jsc#SLE-12705).
- commit ddc2fa1
* Fri Oct  2 2020 tiwai@suse.de
- intel_th: msu: Fix missing allocation failure check on a
  kstrndup (jsc#SLE-12705).
- intel_th: msu: Fix an uninitialized mutex (jsc#SLE-12705).
- intel_th: msu: Preserve pre-existing buffer configuration
  (jsc#SLE-12705).
- intel_th: msu: Prevent freeing buffers while locked windows
  exist (jsc#SLE-12705).
- commit 4c38552
* Fri Oct  2 2020 tiwai@suse.de
- intel_th: msu: Get rid of the window size limit (jsc#SLE-12705).
- Refresh
  patches.suse/intel_th-msu-Fix-window-switching-without-windows.patch.
- commit c041e33
* Fri Oct  2 2020 tiwai@suse.de
- intel_th: msu-sink: An example msu buffer "sink"
  (jsc#SLE-12705).
- commit fc315a7
* Fri Oct  2 2020 yousaf.kaukab@suse.com
- usb: common: usb-conn-gpio: Register charger (jsc#SLE-15847).
- usb: common: usb-conn-gpio: Demote comment block which is
  clearly not kerneldoc (jsc#SLE-15847).
- regulator: pwm: Don't warn on probe deferral (jsc#SLE-15847).
- usb: common: usb-conn-gpio: Don't log an error on probe deferral
  (jsc#SLE-15847).
- usb: common: add USB GPIO based connection detection driver
  (jsc#SLE-15847).
- usb: common: create Kconfig file (jsc#SLE-15847).
- commit 0f500a3
* Fri Oct  2 2020 tiwai@suse.de
- intel_th: msu: Introduce buffer interface (jsc#SLE-12705).
- Refresh
  patches.suse/intel_th-Fix-user-visible-error-codes.patch.
- Refresh
  patches.suse/intel_th-msu-Fix-window-switching-without-windows.patch.
- commit feddf38
* Fri Oct  2 2020 tbogendoerfer@suse.de
- RDMA/rtrs: include client and server modules into kernel
  compilation (jsc#SLE-15176).
- Update config files.
- supported.conf: mark RTRS unsupported
- commit 362994a
* Fri Oct  2 2020 tbogendoerfer@suse.de
- IB/{rdmavt, hfi1}: Implement creation of accelerated UD QPs
  (jsc#SLE-13208).
- Refresh
  patches.suse/RDMA-rvt-Fix-potential-memory-leak-caused-by-rvt_all.patch.
- commit e11aad9
* Fri Oct  2 2020 tbogendoerfer@suse.de
- RDMA/mlx5: Update mlx5_ib driver name (jsc#SLE-15175).
- Refresh
  patches.suse/mlx5-add-parameter-to-disable-enhanced-IPoIB.patch.
- commit 5bdb26d
* Fri Oct  2 2020 tbogendoerfer@suse.de
- RDMA/mlx5: Add support in steering default miss (jsc#SLE-15175).
- Refresh patches.suse/RDMA-mlx5-Fix-typo-in-enum-name.patch.
- commit 50e6150
* Fri Oct  2 2020 tbogendoerfer@suse.de
- RDMA/bnxt_re: Reduce device page size detection code
  (jsc#SLE-15076).
- Refresh
  patches.suse/RDMA-bnxt_re-Fix-the-qp-table-indexing.patch.
- commit 98ba96b
* Fri Oct  2 2020 tbogendoerfer@suse.de
- qed: changes to ILT to support XRC (jsc#SLE-15143).
- Refresh
  patches.suse/qed-suppress-don-t-support-RoCE-iWARP-flooding-on-HW.patch.
- commit 86cbfdb
* Fri Oct  2 2020 tbogendoerfer@suse.de
- net: qed: invoke err notify on critical areas (jsc#SLE-15143).
- Refresh
  patches.suse/qed-suppress-false-positives-interrupt-error-message.patch.
- commit 6a277a5
* Fri Oct  2 2020 tbogendoerfer@suse.de
- RDMA/cm: Protect access to remote_sidr_table (jsc#SLE-15176).
- blacklist.conf: removed temporay blacklist
- commit 0bbbe36
* Fri Oct  2 2020 tbogendoerfer@suse.de
- net: qed: use eth_zero_addr() to clear mac address
  (jsc#SLE-15143).
- net: qede: use eth_zero_addr() to clear mac address
  (jsc#SLE-15143).
- qede: Use %%pM format specifier for MAC addresses
  (jsc#SLE-15143).
- qed: Use %%pM format specifier for MAC addresses (jsc#SLE-15143).
- qed: fix the allocation of the chains with an external PBL
  (jsc#SLE-15143).
- qede: add .ndo_xdp_xmit() and XDP_REDIRECT support
  (jsc#SLE-15143).
- qede: refactor XDP Tx processing (jsc#SLE-15143).
- qede: reformat net_device_ops declarations (jsc#SLE-15143).
- qede: reformat several structures in "qede.h" (jsc#SLE-15143).
- qed: introduce qed_chain_get_elem_used{,u32}() (jsc#SLE-15143).
- qed: optimize common chain accessors (jsc#SLE-15143).
- qed: add support for different page sizes for chains
  (jsc#SLE-15143).
- qed: simplify chain allocation with init params struct
  (jsc#SLE-15143).
- qed: simplify initialization of the chains with an external PBL
  (jsc#SLE-15143).
- qed: move chain initialization inlines next to allocation
  functions (jsc#SLE-15143).
- qed: sanitize PBL chains allocation (jsc#SLE-15143).
- qed: prevent possible double-frees of the chains
  (jsc#SLE-15143).
- qed: move chain methods to a separate file (jsc#SLE-15143).
- qed: reformat Makefile (jsc#SLE-15143).
- qed: reformat "qed_chain.h" a bit (jsc#SLE-15143).
- net: qed_hsi.h: Avoid the use of one-element array
  (jsc#SLE-15143).
- net: qed: Remove unneeded cast from memory allocation
  (jsc#SLE-15143).
- qed: Fix ILT and XRCD bitmap memory leaks (jsc#SLE-15143).
- qed: add support for the extended speed and FEC modes
  (jsc#SLE-15143).
- qed: populate supported link modes maps on module init
  (jsc#SLE-15143).
- qed: add missing loopback modes (jsc#SLE-15143).
- qed: add support for new port modes (jsc#SLE-15143).
- qed: remove unused qed_hw_info::port_mode and QED_PORT_MODE
  (jsc#SLE-15143).
- qed: reformat several structures a bit (jsc#SLE-15143).
- qede: introduce support for FEC control (jsc#SLE-15143).
- qede: format qede{,_vf}_ethtool_ops (jsc#SLE-15143).
- qed: add support for Forward Error Correction (jsc#SLE-15143).
- qed: reformat several structures a bit (jsc#SLE-15143).
- qed: use transceiver data to fill link partner's advertising
  speeds (jsc#SLE-15143).
- qed: add support for multi-rate transceivers (jsc#SLE-15143).
- qed: reformat public_port::transceiver_data a bit
  (jsc#SLE-15143).
- qede: populate supported link modes maps on module init
  (jsc#SLE-15143).
- qed, qede, qedf: convert link mode from u32 to ETHTOOL_LINK_MODE
  (jsc#SLE-15143).
- linkmode: introduce linkmode_intersects() (jsc#SLE-15143).
- net: qed: drop duplicate words in comments (jsc#SLE-15143).
- qede: convert to new udp_tunnel_nic infra (jsc#SLE-15143).
- net: qede: fix BE vs CPU comparison (jsc#SLE-15143).
- net: qede: fix kernel-doc for qede_ptp_adjfreq()
  (jsc#SLE-15143).
- net: qed: sanitize BE/LE data processing (jsc#SLE-15143).
- net: qed: use ptr shortcuts to dedup field accessing in some
  parts (jsc#SLE-15143).
- net: qed: improve indentation of some parts of code
  (jsc#SLE-15143).
- net: qed: address kernel-doc warnings (jsc#SLE-15143).
- net: qed: correct qed_hw_err_notify() prototype (jsc#SLE-15143).
- net: qed: cleanup global structs declarations (jsc#SLE-15143).
- net: qed: move static iro_arr out of header file
  (jsc#SLE-15143).
- qed: Make symbol 'qed_hw_err_type_descr' static (jsc#SLE-15143).
- net: qede: update copyright years (jsc#SLE-15143).
- net: qede: convert to SPDX License Identifiers (jsc#SLE-15143).
- net: qede: correct existing SPDX tags (jsc#SLE-15143).
- net: qed: update copyright years (jsc#SLE-15143).
- net: qed: convert to SPDX License Identifiers (jsc#SLE-15143).
- net: qed: correct existing SPDX tags (jsc#SLE-15143).
- RDMA/core: Free DIM memory in error unwind (jsc#SLE-15176).
- RDMA/core: Stop DIM before destroying CQ (jsc#SLE-15176).
- RDMA/mlx5: Initialize QP mutex for the debug kernels
  (jsc#SLE-15175).
- RDMA/mlx5: Allow providing extra scatter CQE QP flag
  (jsc#SLE-15175).
- RDMA/cm: Add min length checks to user structure copies
  (jsc#SLE-15176).
- qed: Disable "MFW indication via attention" SPAM every 5 minutes
  (jsc#SLE-15143).
- RDMA/hns: Fix wrong PBL offset when VA is not aligned to
  PAGE_SIZE (jsc#SLE-14777).
- RDMA/hns: Fix wrong assignment of lp_pktn_ini in QPC
  (jsc#SLE-14777).
- qed: Populate nvm-file attributes while reading nvm config
  partition (jsc#SLE-15143).
- net: qed: fix buffer overflow on ethtool -d (jsc#SLE-15143).
- RDMA/mlx5: Set PD pointers for the error flow unwind
  (jsc#SLE-15175).
- RDMA/mlx5: Fix legacy IPoIB QP initialization (jsc#SLE-15175).
- IB/hfi1: Add explicit cast OPA_MTU_8192 to 'enum ib_mtu'
  (jsc#SLE-13208).
- qed: add missing error test for
  DBG_STATUS_NO_MATCHING_FRAMING_MODE (jsc#SLE-15143).
- net: qed: fix "maybe uninitialized" warning (jsc#SLE-15143).
- net: qed: reset ILT block sizes before recomputing to fix
  crashes (jsc#SLE-15143).
- net: qede: fix use-after-free on recovery and AER handling
  (jsc#SLE-15143).
- net: qede: fix PTP initialization on recovery (jsc#SLE-15143).
- net: qed: fix excessive QM ILT lines consumption
  (jsc#SLE-15143).
- net: qed: fix NVMe login fails over VFs (jsc#SLE-15143).
- net: qede: stop adding events on an already destroyed workqueue
  (jsc#SLE-15143).
- net: qed: fix async event callbacks unregistering
  (jsc#SLE-15143).
- net: qed: fix left elements count calculation (jsc#SLE-15143).
- IB/hfi1: Add atomic triggered sleep/wakeup (jsc#SLE-13208).
- IB/hfi1: Correct -EBUSY handling in tx code (jsc#SLE-13208).
- IB/hfi1: Restore kfree in dummy_netdev cleanup (jsc#SLE-13208).
- RDMA/mlx5: Protect from kernel crash if XRC_TGT doesn't have
  udata (jsc#SLE-15175).
- RDMA/mlx5: Fix integrity enabled QP creation (jsc#SLE-15175).
- RDMA/mlx5: Remove ECE limitation from the RAW_PACKET QPs
  (jsc#SLE-15175).
- RDMA/mlx5: Fix remote gid value in query QP (jsc#SLE-15175).
- RDMA/mlx5: Don't access ib_qp fields in internal destroy QP path
  (jsc#SLE-15175).
- RDMA/hns: Fix an cmd queue issue when resetting (jsc#SLE-14777).
- RDMA/hns: Fix a calltrace when registering MR from userspace
  (jsc#SLE-14777).
- RDMA/mlx5: Add missed RST2INIT and INIT2INIT steps during ECE
  handshake (jsc#SLE-15175).
- RDMA/core: Annotate CMA unlock helper routine (jsc#SLE-15176).
- RDMA/hfi1: Fix trivial mis-spelling of 'descriptor'
  (jsc#SLE-13208).
- RDMA/mlx5: Fix -Wformat warning in check_ucmd_data()
  (jsc#SLE-15175).
- RDMA/mlx5: Remove duplicated assignment to resp.response_length
  (jsc#SLE-15175).
- net: qed: fixes crash while running driver in kdump kernel
  (jsc#SLE-15143).
- scsi: qed: Send BW update notifications to the protocol drivers
  (jsc#SLE-15143).
- RDMA/mlx5: Return ECE DC support (jsc#SLE-15175).
- RDMA/mlx5: Don't rely on FW to set zeros in ECE response
  (jsc#SLE-15175).
- RDMA/mlx5: Return an error if copy_to_user fails
  (jsc#SLE-15175).
- IB/hfi1: Use free_netdev() in hfi1_netdev_free()
  (jsc#SLE-13208).
- RDMA/hns: Uninitialized variable in modify_qp_init_to_rtr()
  (jsc#SLE-14777).
- IB/hfi1: Fix hfi1_netdev_rx_init() error handling
  (jsc#SLE-13208).
- RDMA: Remove 'max_map_per_fmr' (jsc#SLE-15176).
- RDMA: Remove 'max_fmr' (jsc#SLE-15176).
- RDMA/core: Remove FMR device ops (jsc#SLE-15176).
- RDMA/rdmavt: Remove FMR memory registration (jsc#SLE-15176).
- RDMA/mthca: Remove FMR support for memory registration
  (jsc#SLE-15176).
- RDMA/i40iw: Remove FMR leftovers (jsc#SLE-13537).
- RDMA/bnxt_re: Remove FMR leftovers (jsc#SLE-15076).
- RDMA/mlx5: Remove FMR leftovers (jsc#SLE-15175).
- RDMA/core: Remove FMR pool API (jsc#SLE-15176).
- RDMA/rds: Remove FMR support for memory registration
  (jsc#SLE-15176).
- RDMA/srp: Remove support for FMR memory registration
  (jsc#SLE-15176).
- RDMA/iser: Remove support for FMR memory registration
  (jsc#SLE-15176).
- RDMA/core: Introduce shared CQ pool API (jsc#SLE-15176).
- RDMA/core: Add protection for shared CQs used by ULPs
  (jsc#SLE-15176).
- RDMA/core: Fix several reference count leaks (jsc#SLE-15176).
- IB/hfi1: Fix spelling mistake "enought" -> "enough"
  (jsc#SLE-13208).
- RDMA/hns: remove duplicate assignment to pointer raq
  (jsc#SLE-14777).
- RDMA/mlx5: Support TX port affinity for VF drivers in LAG mode
  (jsc#SLE-15175).
- RDMA/srpt: Increase max_send_sge (jsc#SLE-15176).
- RDMA/srpt: Reduce max_recv_sge to 1 (jsc#SLE-15176).
- RDMA/srpt: Make debug output more detailed (jsc#SLE-15176).
- RDMA/srp: Make the channel count configurable per target
  (jsc#SLE-15176).
- RDMA/mlx5: Return ECE data after modify QP (jsc#SLE-15175).
- RDMA/mlx5: Set ECE options during modify QP (jsc#SLE-15175).
- RDMA/mlx5: Convert modify QP to use MLX5_SET macros
  (jsc#SLE-15175).
- RDMA/mlx5: Remove manually crafted QP context the query call
  (jsc#SLE-15175).
- RDMA/mlx5: Use direct modify QP implementation (jsc#SLE-15175).
- RDMA/mlx5: Set ECE options during QP create (jsc#SLE-15175).
- RDMA/mlx5: Get ECE options from FW during create QP
  (jsc#SLE-15175).
- RDMA/cma: Provide ECE reject reason (jsc#SLE-15176).
- RDMA/cma: Connect ECE to rdma_accept (jsc#SLE-15176).
- RDMA/cm: Send and receive ECE parameter over the wire
  (jsc#SLE-15176).
- RDMA/ucma: Deliver ECE parameters through UCMA events
  (jsc#SLE-15176).
- RDMA/ucma: Extend ucma_connect to receive ECE parameters
  (jsc#SLE-15176).
- RDMA/cm: Add Enhanced Connection Establishment (ECE) bits
  (jsc#SLE-15176).
- RDMA/core: Use sizeof_field() helper (jsc#SLE-15176).
- RDMA/ipoib: Remove can_sleep parameter from iboib_mcast_alloc
  (jsc#SLE-15176).
- RDMA/iw_cxgb4: cleanup device debugfs entries on ULD remove
  (jsc#SLE-15118).
- RDMA/hns: Make the end of sge process more clear
  (jsc#SLE-14777).
- RDMA/hns: Simplify process related to poll cq (jsc#SLE-14777).
- RDMA/hns: Remove redundant parameters from free_srq/qp_wrid()
  (jsc#SLE-14777).
- RDMA/hns: Remove redundant type cast for general pointers
  (jsc#SLE-14777).
- RDMA/hns: Optimize the usage of MTR (jsc#SLE-14777).
- RDMA/hns: Refactor the QP context filling process related to
  WQE buffer configure (jsc#SLE-14777).
- RDMA/hns: Change variables representing quantity to unsigned
  (jsc#SLE-14777).
- RDMA/hns: Change all page_shift to unsigned (jsc#SLE-14777).
- RDMA/hns: Rename QP buffer related function (jsc#SLE-14777).
- RDMA/hns: Remove unused code about assert (jsc#SLE-14777).
- RDMA/hns: Optimize post and poll process (jsc#SLE-14777).
- RDMA/hns: Add CQ flag instead of independent enable flag
  (jsc#SLE-14777).
- RDMA/hns: Let software PI/CI grow naturally (jsc#SLE-14777).
- RDMA/rtrs: Get rid of the do_next_path while_next_path macros
  (jsc#SLE-15176).
- RDMA/rtrs: server: Use already dereferenced rtrs_sess structure
  (jsc#SLE-15176).
- IB/uverbs: Introduce create/destroy QP commands over ioctl
  (jsc#SLE-15176).
- IB/uverbs: Introduce create/destroy WQ commands over ioctl
  (jsc#SLE-15176).
- IB/uverbs: Introduce create/destroy SRQ commands over ioctl
  (jsc#SLE-15176).
- IB/uverbs: Move QP, SRQ, WQ type and flags to UAPI
  (jsc#SLE-15176).
- IB/uverbs: Extend CQ to get its own asynchronous event FD
  (jsc#SLE-15176).
- IB/uverbs: Refactor related objects to use their own
  asynchronous event FD (jsc#SLE-15176).
- RDMA/core: Allow the ioctl layer to abort a fully created
  uobject (jsc#SLE-15176).
- IB/hfi1: Enable the transmit side of the datagram ipoib netdev
  (jsc#SLE-13208).
- IB/ipoib: Add capability to switch between datagram and
  connected mode (jsc#SLE-13208).
- IB/hfi1: Add packet histogram trace event (jsc#SLE-13208).
- IB/{hfi1, ipoib, rdma}: Broadcast ping sent packets which
  exceeded mtu size (jsc#SLE-13208).
- IB/hfi1: Activate the dummy netdev (jsc#SLE-13208).
- IB/hfi1: Add rx functions for dummy netdev (jsc#SLE-13208).
- IB/hfi1: Add interrupt handler functions for accelerated ipoib
  (jsc#SLE-13208).
- IB/hfi1: Add functions to receive accelerated ipoib packets
  (jsc#SLE-13208).
- IB/hfi1: Rename num_vnic_contexts as num_netdev_contexts
  (jsc#SLE-13208).
- IB/ipoib: Increase ipoib Datagram mode MTU's upper limit
  (jsc#SLE-13208).
- IB/hfi1: RSM rules for AIP (jsc#SLE-13208).
- IB/hfi1: Remove module parameter for KDETH qpns (jsc#SLE-13208).
- IB/hfi1: Add the transmit side of a datagram ipoib RDMA netdev
  (jsc#SLE-13208).
- IB/hfi1: Add functions to transmit datagram ipoib packets
  (jsc#SLE-13208).
- IB/hfi1: Add accelerated IP capability bit (jsc#SLE-13208).
- RDMA/efa: Report host information to the device (jsc#SLE-15176).
- RDMA/efa: Fix setting of wrong bit in get/set_feature commands
  (jsc#SLE-15176).
- RDMA/hns: Reserve one sge in order to avoid local length error
  (jsc#SLE-14777).
- RDMA/hns: Rename macro for defining hns hardware page size
  (jsc#SLE-14777).
- RDMA/hns: Remove redundant memcpy() (jsc#SLE-14777).
- RDMA/hns: Store mr len information into mr obj (jsc#SLE-14777).
- RDMA/hns: Fix error with to_hr_hem_entries_count()
  (jsc#SLE-14777).
- RDMA/hns: Fix wrong assignment of SRQ's max_wr (jsc#SLE-14777).
- RDMA/hns: Fix assignment to ba_pg_sz of eqe (jsc#SLE-14777).
- RDMA/siw: Replace one-element array and use struct_size()
  helper (jsc#SLE-15111).
- rnbd/rtrs: Pass max segment size from blk user to the rdma
  library (jsc#SLE-15176).
- RDMA/rtrs: server: Fix some error return code (jsc#SLE-15176).
- RDMA/rtrs: client: Fix function return on success
  (jsc#SLE-15176).
- RDMA/rtrs: Fix a couple off by one bugs in rtrs_srv_rdma_done()
  (jsc#SLE-15176).
- RDMA/rtrs: Fix some signedness bugs in error handling
  (jsc#SLE-15176).
- RDMA/srpt: Add a newline when printing parameter
  'srpt_service_guid' by sysfs (jsc#SLE-15176).
- RDMA/core: Consolidate ib_create_srq flows (jsc#SLE-15176).
- RDMA/uverbs: Cleanup wq/srq context usage from uverbs layer
  (jsc#SLE-15176).
- RDMA/rtrs: a bit of documentation (jsc#SLE-15176).
- RDMA/rtrs: server: sysfs interface functions (jsc#SLE-15176).
- RDMA/rtrs: server: statistics functions (jsc#SLE-15176).
- RDMA/rtrs: server: main functionality (jsc#SLE-15176).
- RDMA/rtrs: server: private header with server structs and
  functions (jsc#SLE-15176).
- RDMA/rtrs: client: sysfs interface functions (jsc#SLE-15176).
- RDMA/rtrs: client: statistics functions (jsc#SLE-15176).
- RDMA/rtrs: client: main functionality (jsc#SLE-15176).
- RDMA/rtrs: client: private header with client structs and
  functions (jsc#SLE-15176).
- RDMA/rtrs: core: lib functions shared between client and server
  modules (jsc#SLE-15176).
- RDMA/rtrs: private headers with rtrs protocol structs and
  helpers (jsc#SLE-15176).
- RDMA/rtrs: public interface header to establish RDMA connections
  (jsc#SLE-15176).
- sysfs: export sysfs_remove_file_self() (jsc#SLE-15176).
- RDMA/mlx5: Fix query_srq_cmd() function (jsc#SLE-15175).
- RDMA/mlx5: Add support for drop action in DV steering
  (jsc#SLE-15175).
- RDMA/mlx5: Refactor DV create flow (jsc#SLE-15175).
- RDMA/cm: Increment the refcount inside cm_find_listen()
  (jsc#SLE-15176).
- RDMA/cm: Remove needless cm_id variable (jsc#SLE-15176).
- RDMA/cm: Remove the cm_free_id() wrapper function
  (jsc#SLE-15176).
- RDMA/cm: Make find_remote_id() return a cm_id_private
  (jsc#SLE-15176).
- RDMA/cm: Add a note explaining how the timewait is eventually
  freed (jsc#SLE-15176).
- RDMA/cm: Pass the cm_id_private into cm_cleanup_timewait
  (jsc#SLE-15176).
- RDMA/cm: Pull duplicated code into cm_queue_work_unlock()
  (jsc#SLE-15176).
- RDMA/cm: Remove unused store to ret in cm_rej_handler
  (jsc#SLE-15176).
- RDMA/cm: Remove return code from add_cm_id_to_port_list
  (jsc#SLE-15176).
- RDMA/addr: Mark addr_resolve as might_sleep() (jsc#SLE-15176).
- RDMA/hns: Combine enable flags of qp (jsc#SLE-14777).
- RDMA/hns: Extend capability flags for HIP08_C (jsc#SLE-14777).
- RDMA/mlx5: Remove duplicated assignment to variable rcqe_sz
  (jsc#SLE-15175).
- RDMA/mlx5: Allow only raw Ethernet QPs when RoCE isn't enabled
  (jsc#SLE-15175).
- RDMA/mlx5: Assign profile before calling stages (jsc#SLE-15175).
- RDMA/mlx5: Move all WR logic from qp.c to separate file
  (jsc#SLE-15175).
- RDMA/mlx5: Refactor mlx5_post_send() to improve readability
  (jsc#SLE-15175).
- RDMA/mlx5: Update mlx5_ib to use new cmd interface
  (jsc#SLE-15175).
- RDMA/hns: Remove redundant assignment of caps (jsc#SLE-14777).
- RDMA/hns: Adjust lp_pktn_ini dynamically (jsc#SLE-14777).
- RDMA/hns: Fix comments with non-English symbols (jsc#SLE-14777).
- RDMA/hns: Optimize SRQ buffer size calculating process
  (jsc#SLE-14777).
- RDMA/hns: Move SRQ code to the reasonable place (jsc#SLE-14777).
- RDMA/hns: Optimize WQE buffer size calculating process
  (jsc#SLE-14777).
- RDMA/hns: Remove unused MTT functions (jsc#SLE-14777).
- RDMA/hns: Optimize PBL buffer allocation process
  (jsc#SLE-14777).
- RDMA/mlx5: Set UDP source port based on the grh.flow_label
  (jsc#SLE-15175).
- RDMA/cma: Initialize the flow label of CM's route path record
  (jsc#SLE-15176).
- RDMA/mlx5: Define RoCEv2 udp source port when set path
  (jsc#SLE-15175).
- RDMA/core: Consider flow label when building skb
  (jsc#SLE-15176).
- RDMA/core: Add hash functions to calculate RoCEv2 flowlabel
  and UDP source port (jsc#SLE-15176).
- RDMA: Allow ib_client's to fail when add() is called
  (jsc#SLE-15176).
- RDMA/mad: Remove snoop interface (jsc#SLE-15176).
- RDMA/efa: Count admin commands errors (jsc#SLE-15176).
- RDMA/efa: Count mmap failures (jsc#SLE-15176).
- RDMA/efa: Report create CQ error counter (jsc#SLE-15176).
- RDMA/mlx5: Set lag tx affinity according to slave
  (jsc#SLE-15175).
- RDMA/mlx5: Refactor affinity related code (jsc#SLE-15175).
- RDMA/core: Get xmit slave for LAG (jsc#SLE-15176).
- RDMA/core: Add LAG functionality (jsc#SLE-15176).
- RDMA: Group create AH arguments in struct (jsc#SLE-15176).
- RDMA/mlx5: Consolidate into special function all create QP calls
  (jsc#SLE-15175).
- RDMA/mlx5: Remove redundant destroy QP call (jsc#SLE-15175).
- RDMA/mlx5: Copy response to the user in one place
  (jsc#SLE-15175).
- RDMA/mlx5: Handle udate outlen checks in one place
  (jsc#SLE-15175).
- RDMA/mlx5: Promote RSS RAW QP flags check to higher level
  (jsc#SLE-15175).
- RDMA/mlx5: Group all create QP parameters to simplify in-kernel
  interfaces (jsc#SLE-15175).
- RDMA/mlx5: Reduce amount of duplication in QP destroy
  (jsc#SLE-15175).
- RDMA/mlx5: Separate to user/kernel create QP flows
  (jsc#SLE-15175).
- RDMA/mlx5: Separate XRC_TGT QP creation from common flow
  (jsc#SLE-15175).
- RDMA/mlx5: Globally parse DEVX UID (jsc#SLE-15175).
- RDMA/mlx5: Delete impossible inlen check (jsc#SLE-15175).
- RDMA/mlx5: Rely on existence of udata to separate kernel/user
  flows (jsc#SLE-15175).
- RDMA/mlx5: Remove second user copy in create_user_qp
  (jsc#SLE-15175).
- RDMA/mlx5: Combine copy of create QP command in RSS RAW QP
  (jsc#SLE-15175).
- RDMA/mlx5: Promote RSS RAW QP attribute check in higher level
  (jsc#SLE-15175).
- RDMA/mlx5: Store QP type in the vendor QP structure
  (jsc#SLE-15175).
- RDMA/mlx5: Delete unsupported QP types (jsc#SLE-15175).
- RDMA/mlx5: Process all vendor flags in one place
  (jsc#SLE-15175).
- RDMA/mlx5: Return all configured create flags through query QP
  (jsc#SLE-15175).
- RDMA/mlx5: Change scatter CQE flag to be set like other vendor
  flags (jsc#SLE-15175).
- RDMA/mlx5: Use flags_en mechanism to mark QP created with WQE
  signature (jsc#SLE-15175).
- RDMA/mlx5: Process create QP flags in one place (jsc#SLE-15175).
- RDMA/mlx5: Delete create QP flags obfuscation (jsc#SLE-15175).
- RDMA/mlx5: Initial separation of RAW_PACKET QP from common flow
  (jsc#SLE-15175).
- RDMA/mlx5: Remove second copy from user for non RSS RAW QPs
  (jsc#SLE-15175).
- RDMA/mlx5: Move DRIVER QP flags check into separate function
  (jsc#SLE-15175).
- RDMA/mlx5: Update all DRIVER QP places to use QP subtype
  (jsc#SLE-15175).
- RDMA/mlx5: Split scatter CQE configuration for DCT QP
  (jsc#SLE-15175).
- RDMA/mlx5: Separate create QP flows to be based on type
  (jsc#SLE-15175).
- RDMA/mlx5: Set QP subtype immediately when it is known
  (jsc#SLE-15175).
- RDMA/mlx5: Avoid setting redundant NULL for XRC QPs
  (jsc#SLE-15175).
- RDMA/mlx5: Prepare QP allocation for future removal
  (jsc#SLE-15175).
- RDMA/mlx5: Perform check if QP creation flow is valid
  (jsc#SLE-15175).
- RDMA/mlx5: Delete impossible GSI port check (jsc#SLE-15175).
- RDMA/mlx5: Organize QP types checks in one place
  (jsc#SLE-15175).
- RDMA/hns: Simplify the status judgment code of
  hns_roce_v1_m_qp() (jsc#SLE-14777).
- RDMA/hns: Simplify the state judgment code of qp
  (jsc#SLE-14777).
- RDMA/hns: Simplify the cqe code of poll cq (jsc#SLE-14777).
- RDMA/hns: Simplify the qp state convert code (jsc#SLE-14777).
- RDMA/hns: Optimize hns_roce_v2_set_mac() (jsc#SLE-14777).
- RDMA/hns: Optimize hns_roce_config_link_table() (jsc#SLE-14777).
- RDMA/bnxt: Delete 'nq_ptr' variable which is not used
  (jsc#SLE-15076).
- RDMA/hns: Support 0 hop addressing for CQE buffer
  (jsc#SLE-14777).
- RDMA/hns: Support 0 hop addressing for SRQ buffer
  (jsc#SLE-14777).
- RDMA/hns: Support 0 hop addressing for WQE buffer
  (jsc#SLE-14777).
- RDMA/hns: Optimize 0 hop addressing for EQE buffer
  (jsc#SLE-14777).
- RDMA/hns: Optimize hns buffer allocation flow (jsc#SLE-14777).
- RDMA/hns: Add support for addressing when hopnum is 0
  (jsc#SLE-14777).
- RDMA/rw: use DIV_ROUND_UP to calculate nr_ops (jsc#SLE-15176).
- RDMA/cma: Limit the scope of rdma_is_consumer_reject function
  (jsc#SLE-15176).
- RDMA/bnxt_re: Simplify obtaining queue entry from hw ring
  (jsc#SLE-15076).
- RDMA/bnxt_re: Update missing hsi data structures
  (jsc#SLE-15076).
- IB/qib: Remove unused variable ret (jsc#SLE-15176).
- IB: Fix some documentation warnings (jsc#SLE-15176).
- RDMA: Remove a few extra calls to ib_get_client_data()
  (jsc#SLE-15176).
- qed: Add EDPM mode type for user-fw compatibility
  (jsc#SLE-15143).
- qed: Add XRC to RoCE (jsc#SLE-15143).
- qlogic/qede: Add XDP frame size to driver (jsc#SLE-15143).
- net: qed: introduce critical hardware error handler
  (jsc#SLE-15143).
- net: qed: introduce critical fan failure handler
  (jsc#SLE-15143).
- net: qede: Implement ndo_tx_timeout (jsc#SLE-15143).
- net: qede: optional hw recovery procedure (jsc#SLE-15143).
- net: qed: attention clearing properties (jsc#SLE-15143).
- net: qed: cleanup debug related declarations (jsc#SLE-15143).
- net: qed: critical err reporting to management firmware
  (jsc#SLE-15143).
- net: qede: add hw err scheduled handler (jsc#SLE-15143).
- net: qed: adding hw_err states and handling (jsc#SLE-15143).
- net: qed: Disable SRIOV functionality inside kdump kernel
  (jsc#SLE-15143).
- net: qed*: Reduce RX and TX default ring count when running
  inside kdump kernel (jsc#SLE-15143).
- net/core: Introduce netdev_get_xmit_slave (jsc#SLE-15176).
- net: qede: Use true for bool variable in qede_init_fp()
  (jsc#SLE-15143).
- RDMA/mlx5: Delete Q counter allocations command (jsc#SLE-15175).
- qed: Make ll2_cbs static (jsc#SLE-15143).
- qede: Add support for handling the pcie errors (jsc#SLE-15143).
- qed: Enable device error reporting capability (jsc#SLE-15143).
- qed: use true,false for bool variables (jsc#SLE-15143).
- net: qed: Remove unneeded cast from memory allocation
  (jsc#SLE-15143).
- hfi1: get rid of pointless access_ok() (jsc#SLE-13208).
- qed: remove redundant assignment to variable 'rc'
  (jsc#SLE-15143).
- qed: Fix use after free in qed_chain_free (jsc#SLE-15143).
- qed: Fix race condition between scheduling and destroying the
  slowpath workqueue (jsc#SLE-15143).
- qede: remove some unused code in function
  qede_selftest_receive_traffic (jsc#SLE-15143).
- net: qede: reject unsupported coalescing params (jsc#SLE-15143).
- net/smc: check for valid ib_client_data (jsc#SLE-15176).
- qed: Remove set but not used variable 'p_link' (jsc#SLE-15143).
- qed: Fix a error code in qed_hw_init() (jsc#SLE-15143).
- qed: FW 8.42.2.0 debug features (jsc#SLE-15143).
- qed: rt init valid initialization changed (jsc#SLE-15143).
- qed: Debug feature: ilt and mdump (jsc#SLE-15143).
- qed: FW 8.42.2.0 Add fw overlay feature (jsc#SLE-15143).
- qed: FW 8.42.2.0 HSI changes (jsc#SLE-15143).
- qed: FW 8.42.2.0 iscsi/fcoe changes (jsc#SLE-15143).
- qed: Add abstraction for different hsi values per chip
  (jsc#SLE-15143).
- qed: FW 8.42.2.0 Additional ll2 type (jsc#SLE-15143).
- qed: Use dmae to write to widebus registers in fw_funcs
  (jsc#SLE-15143).
- qed: FW 8.42.2.0 Parser offsets modified (jsc#SLE-15143).
- qed: FW 8.42.2.0 Queue Manager changes (jsc#SLE-15143).
- qed: FW 8.42.2.0 Expose new registers and change windows
  (jsc#SLE-15143).
- qed: FW 8.42.2.0 Internal ram offsets modifications
  (jsc#SLE-15143).
- net/rds: Handle ODP mr registration/unregistration
  (jsc#SLE-15176).
- infiniband: add a Documentation driver-api chapter for
  Infiniband (jsc#SLE-15176).
- net/rds: Remove unnecessary null check (jsc#SLE-15176).
- net/rds: Add missing include file (jsc#SLE-15176).
- net/rds: Use DMA memory pool allocation for rds_header
  (jsc#SLE-15176).
- commit 4380c02
* Fri Oct  2 2020 tiwai@suse.de
- mwifiex: Increase AES key storage size to 256 bits (git-fixes).
- commit dcd5ff6
* Fri Oct  2 2020 tiwai@suse.de
- mac802154: tx: fix use-after-free (git-fixes).
- ieee802154/adf7242: check status of adf7242_read_reg
  (git-fixes).
- ieee802154: fix one possible memleak in ca8210_dev_com_init
  (git-fixes).
- i2c: core: Call i2c_acpi_install_space_handler() before
  i2c_acpi_register_devices() (git-fixes).
- i2c: aspeed: Mask IRQ status to relevant bits (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for MPMAN Converter9 2-in-1
  (git-fixes).
- ASoC: wm8994: Ensure the device is resumed in wm89xx_mic_detect
  functions (git-fixes).
- ASoC: wm8994: Skip setting of the WM8994_MICBIAS register for
  WM1811 (git-fixes).
- mac80211: skip mpath lookup also for control port tx
  (git-fixes).
- i2c: tegra: Restore pinmux on system resume (git-fixes).
- mtd: rawnand: omap_elm: Fix runtime PM imbalance on error
  (git-fixes).
- mtd: rawnand: gpmi: Fix runtime PM imbalance on error
  (git-fixes).
- power: supply: max17040: Correct voltage reading (git-fixes).
- drivers: char: tlclk.c: Avoid data race between init and
  interrupt handler (git-fixes).
- staging:r8188eu: avoid skb_clone for amsdu to msdu conversion
  (git-fixes).
- serial: uartps: Wait for tx_empty in console setup (git-fixes).
- usb: dwc3: Increase timeout for CmdAct cleared by device
  controller (git-fixes).
- USB: EHCI: ehci-mv: fix less than zero comparison of an unsigned
  int (git-fixes).
- USB: EHCI: ehci-mv: fix error handling in mv_ehci_probe()
  (git-fixes).
- PCI: tegra: Fix runtime PM imbalance on error (git-fixes).
- PCI: tegra194: Fix runtime PM imbalance on error (git-fixes).
- gpio: rcar: Fix runtime PM imbalance on error (git-fixes).
- ASoC: img-i2s-out: Fix runtime PM imbalance on error
  (git-fixes).
- wlcore: fix runtime pm imbalance in wlcore_regdomain_config
  (git-fixes).
- wlcore: fix runtime pm imbalance in wl1271_tx_work (git-fixes).
- e1000: Do not perform reset in reset_task if we are already down
  (git-fixes).
- Bluetooth: Handle Inquiry Cancel error after Inquiry Complete
  (git-fixes).
- thermal: rcar_thermal: Handle probe error gracefully
  (git-fixes).
- rtc: ds1374: fix possible race condition (git-fixes).
- rtc: sa1100: fix possible race condition (git-fixes).
- bus: hisi_lpc: Fixup IO ports addresses to avoid use-after-free
  in host removal (git-fixes).
- dmaengine: tegra-apb: Prevent race conditions on channel's
  freeing (git-fixes).
- dmaengine: stm32-dma: use vchan_terminate_vdesc() in
  .terminate_all (git-fixes).
- dmaengine: stm32-mdma: use vchan_terminate_vdesc() in
  .terminate_all (git-fixes).
- brcmfmac: Fix double freeing in the fmac usb data path
  (git-fixes).
- ath10k: use kzalloc to read for ath10k_sdio_hif_diag_read
  (git-fixes).
- Bluetooth: L2CAP: handle l2cap config request during open state
  (git-fixes).
- Bluetooth: guard against controllers sending zero'd events
  (git-fixes).
- Bluetooth: prefetch channel before killing sock (git-fixes).
- Bluetooth: Fix refcount use-after-free issue (git-fixes).
- mt76: fix handling full tx queues in mt76_dma_tx_queue_skb_raw
  (git-fixes).
- mt76: clear skb pointers from rx aggregation reorder buffer
  during cleanup (git-fixes).
- serial: 8250: 8250_omap: Terminate DMA before pushing data on
  RX timeout (git-fixes).
- serial: 8250_omap: Fix sleeping function called from invalid
  context during probe (git-fixes).
- serial: 8250_port: Don't service RX FIFO if throttled
  (git-fixes).
- i2c: tegra: Prevent interrupt triggering after transfer timeout
  (git-fixes).
- media: ti-vpe: cal: Restrict DMA to avoid memory corruption
  (git-fixes).
- ar5523: Add USB ID of SMCWUSBT-G2 wireless adapter (git-fixes).
- ACPI: EC: Reference count query handlers under lock (git-fixes).
- dmaengine: zynqmp_dma: fix burst length configuration
  (git-fixes).
- mmc: core: Rework wp-gpio handling (git-fixes).
- mt76: fix LED link time failure (git-fixes).
- PCI: Avoid double hpmemsize MMIO window assignment (git-fixes).
- dmaengine: mediatek: hsdma_probe: fixed a memory leak when
  devm_request_irq fails (git-fixes).
- mfd: mfd-core: Protect against NULL call-back function pointer
  (git-fixes).
- leds: mlxreg: Fix possible buffer overflow (git-fixes).
- dma-fence: Serialise signal enabling
  (dma_fence_enable_sw_signaling) (git-fixes).
- media: smiapp: Fix error handling at NVM reading (git-fixes).
- media: mc-device.c: fix memleak in media_device_register_entity
  (git-fixes).
- mt76: add missing locking around ampdu action (git-fixes).
- mt76: do not use devm API for led classdev (git-fixes).
- ath10k: fix memory leak for tpc_stats_final (git-fixes).
- ath10k: fix array out-of-bounds access (git-fixes).
- mtd: cfi_cmdset_0002: don't free cfi->cfiq in error path of
  cfi_amdstd_setup() (git-fixes).
- commit 6283339
* Fri Oct  2 2020 tiwai@suse.de
- drm/bochs: downgrade pci_request_region failure from error to
  warning (bsc#1177185).
- commit 50b44ef
* Fri Oct  2 2020 yousaf.kaukab@suse.com
- usb: phy: tegra: Fix unnecessary check in tegra_usb_phy_probe()
  (jsc#SLE-15847).
- usb: host: ehci-tegra: Remove superfluous dev_err() message
  (jsc#SLE-15847).
- usb: phy: tegra: Include proper GPIO consumer header to fix
  compile testing (jsc#SLE-15847).
- usb: phy: tegra: Add clarifying comments about the shared
  registers (jsc#SLE-15847).
- usb: host: ehci-tegra: Remove unused fields from tegra_ehci_hcd
  (jsc#SLE-15847).
- usb: host: ehci-tegra: Stop managing PHY's power
  (jsc#SLE-15847).
- usb: chipidea: tegra: Add USB_TEGRA_PHY to driver's dependencies
  (jsc#SLE-15847).
- usb: chipidea: tegra: Stop managing PHY's power (jsc#SLE-15847).
- usb: phy: tegra: Keep CPU interrupts enabled (jsc#SLE-15847).
- usb: phy: tegra: Move utmip_pad_count checking under lock
  (jsc#SLE-15847).
- usb: phy: tegra: Disable VBUS regulator on tegra_usb_phy_init
  failure (jsc#SLE-15847).
- usb: phy: tegra: Use device-tree notion of reset-GPIO's
  active-state (jsc#SLE-15847).
- usb: phy: tegra: Use u32 for hardware register variables
  (jsc#SLE-15847).
- usb: phy: tegra: Use devm_otg_ulpi_create() (jsc#SLE-15847).
- usb: ulpi: Add resource-managed variant of otg_ulpi_create()
  (jsc#SLE-15847).
- usb: phy: tegra: Use generic stub for a missing VBUS regulator
  (jsc#SLE-15847).
- usb: phy: tegra: Use relaxed versions of readl/writel
  (jsc#SLE-15847).
- usb: phy: tegra: Clean up included headers (jsc#SLE-15847).
- usb: phy: tegra: Perform general clean up of the code
  (jsc#SLE-15847).
- usb: phy: tegra: Hook up init/shutdown callbacks
  (jsc#SLE-15847).
- usb: phy: tegra: Keep track of power on-off state
  (jsc#SLE-15847).
- usb: phy: tegra: Clean up ulpi_phy_power_off (jsc#SLE-15847).
- usb: host: ehci-tegra: Correct teardown order of driver's
  removal (jsc#SLE-15847).
- commit 6c135f1
* Fri Oct  2 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Kill the undead i915_gem_batch_pool.c'
- commit 3eb4207
* Fri Oct  2 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Don't deballoon unused ggtt drm_mm_node in linux guest'
- commit 854ff5d
* Thu Oct  1 2020 tbogendoerfer@suse.de
- net: hns3: Fix for geneve tx checksum bug (jsc#SLE-14777).
- net: hns: Fix memleak in hns_nic_dev_probe (jsc#SLE-14777).
- net: hns3: fix spelling mistake "could'nt" -> "couldn't"
  (jsc#SLE-14777).
- net: hix5hd2_gmac: Remove unneeded cast from memory allocation
  (jsc#SLE-14777).
- net: hns: use eth_broadcast_addr() to assign broadcast address
  (jsc#SLE-14777).
- net: hns3: streaming dma buffer sync between cpu and device
  (jsc#SLE-14777).
- net: hns3: replace disable_irq by IRQ_NOAUTOEN flag
  (jsc#SLE-14777).
- net: hns3: rename buffer-related functions (jsc#SLE-14777).
- net: hns3: pointer type of buffer should be void
  (jsc#SLE-14777).
- net: hns3: remove unnecessary devm_kfree (jsc#SLE-14777).
- net: hns3: fix for VLAN config when reset failed
  (jsc#SLE-14777).
- net: hns3: fix aRFS FD rules leftover after add a user FD rule
  (jsc#SLE-14777).
- net: hns3: add reset check for VF updating port based VLAN
  (jsc#SLE-14777).
- net: hns3: fix a TX timeout issue (jsc#SLE-14777).
- net: hns3: fix desc filling bug when skb is expanded or lineared
  (jsc#SLE-14777).
- net: hns3: fix for not unmapping TX buffer correctly
  (jsc#SLE-14777).
- net: hns3: fix use-after-free when doing self test
  (jsc#SLE-14777).
- net: hns3: add a missing uninit debugfs when unload driver
  (jsc#SLE-14777).
- net: hns3: fix for mishandle of asserting VF reset fail
  (jsc#SLE-14777).
- hns: do not cast return value of napi_gro_receive to null
  (jsc#SLE-14777).
- net: hns3: remove some unused codes in hns3_nic_set_features()
  (jsc#SLE-14777).
- net: hns3: fix two coding style issues in hclgevf_main.c
  (jsc#SLE-14777).
- net: hns3: fix an incorrect comment for num_tqps in struct
  hclgevf_dev (jsc#SLE-14777).
- net: hns3: remove two unused macros in hclgevf_cmd.c
  (jsc#SLE-14777).
- net: hns3: remove an unused macro hclge_is_csq (jsc#SLE-14777).
- net: hns3: fix a print format issue in hclge_mac_mdio_config()
  (jsc#SLE-14777).
- net: hns3: print out speed info when parsing speed fails
  (jsc#SLE-14777).
- net: hns3: remove some unused fields in struct hclge_dev
  (jsc#SLE-14777).
- net: hns3: remove two duplicated register macros in
  hclgevf_main.h (jsc#SLE-14777).
- net: hns3: remove unused struct hnae3_unic_private_info
  (jsc#SLE-14777).
- net: hns3; remove unused HNAE3_RESTORE_CLIENT in enum
  hnae3_reset_notify_type (jsc#SLE-14777).
- net: hns3: remove some unused fields in struct hns3_nic_priv
  (jsc#SLE-14777).
- net: hns3: modify an incorrect type in struct
  hclgevf_cfg_gro_status_cmd (jsc#SLE-14777).
- net: hns3: modify an incorrect type in struct
  hclge_cfg_gro_status_cmd (jsc#SLE-14777).
- net: hns3: refactor hclge_query_bd_num_cmd_send()
  (jsc#SLE-14777).
- net: hns3: refactor hclge_config_tso() (jsc#SLE-14777).
- net: hns3: add a missing mutex destroy in hclge_init_ad_dev()
  (jsc#SLE-14777).
- net: hns3: remove an unnecessary 'goto' in hclge_init_ae_dev()
  (jsc#SLE-14777).
- net: hns3: add a print for initializing CMDQ when reset pending
  (jsc#SLE-14777).
- net: hns3: remove unnecessary MAC enable in app loopback
  (jsc#SLE-14777).
- net: hns3: change the order of reinitializing RoCE and NIC
  client during reset (jsc#SLE-14777).
- net: hns3: add a resetting check in
  hclgevf_init_nic_client_instance() (jsc#SLE-14777).
- net: hns3: remove unnecessary frag list checking in
  hns3_nic_net_xmit() (jsc#SLE-14777).
- net: hns3: remove some unused macros (jsc#SLE-14777).
- net: hns3: modify an incorrect error log in hclge_mbx_handler()
  (jsc#SLE-14777).
- net: hns3: remove a duplicated printing in hclge_configure()
  (jsc#SLE-14777).
- net: hns3: modify some incorrect spelling (jsc#SLE-14777).
- net: hns3: disable auto-negotiation off with 1000M setting in
  ethtool (jsc#SLE-14777).
- net: hns3: optimized the judgment of the input parameters of
  dump ncl config (jsc#SLE-14777).
- net: hns3: provide .get_cmdq_stat interface for the client
  (jsc#SLE-14777).
- net: hns3: modify two uncorrect macro names (jsc#SLE-14777).
- net: hns3: remove a redundant register macro definition
  (jsc#SLE-14777).
- net: hns3: adds support for reading module eeprom info
  (jsc#SLE-14777).
- net: hns3: remove an unnecessary check in hclge_set_umv_space()
  (jsc#SLE-14777).
- net: hns3: optimize the filter table entries handling when
  resetting (jsc#SLE-14777).
- net: hns3: use mutex vport_lock instead of mutex umv_lock
  (jsc#SLE-14777).
- net: hns3: refactor the promisc mode setting (jsc#SLE-14777).
- net: hns3: add support for dumping UC and MC MAC list
  (jsc#SLE-14777).
- net: hns3: refactor the MAC address configure (jsc#SLE-14777).
- net: hns3: replace num_req_vfs with num_alloc_vport in
  hclge_reset_umv_space() (jsc#SLE-14777).
- net: hns3: remove unnecessary parameter 'is_alloc' in
  hclge_set_umv_space() (jsc#SLE-14777).
- net: hns3: refine for unicast MAC VLAN space management
  (jsc#SLE-14777).
- net: hns3: add trace event support for PF/VF mailbox
  (jsc#SLE-14777).
- net: hns3: add support for dumping MAC reg in debugfs
  (jsc#SLE-14777).
- net: hns3: add debug information for flow table when failed
  (jsc#SLE-14777).
- net: hns3: clean up some coding style issue (jsc#SLE-14777).
- net: hns3: modify some unsuitable type declaration
  (jsc#SLE-14777).
- net: hns3: remove two unused structures in hclge_cmd.h
  (jsc#SLE-14777).
- net: hns3: remove useless proto_support field in struct
  hclge_fd_cfg (jsc#SLE-14777).
- net: hns3: remove an unnecessary case 0 in
  hclge_fd_convert_tuple() (jsc#SLE-14777).
- net: hns3: split out hclge_get_fd_rule_info() (jsc#SLE-14777).
- net: hns3: split out hclge_fd_check_ether_tuple()
  (jsc#SLE-14777).
- net: hns: use true,false for bool variables (jsc#SLE-14777).
- net: hisilicon: Make CONFIG_HNS invisible (jsc#SLE-14777).
- net: hns3: fix set and get link ksettings issue (jsc#SLE-14777).
- net: hns3: fix RSS config lost after VF reset (jsc#SLE-14777).
- net: hns3: refactor mailbox response scheme between PF and VF
  (jsc#SLE-14777).
- net: hns3: refactor the mailbox message between PF and VF
  (jsc#SLE-14777).
- net: hns3: add a conversion for mailbox's response code
  (jsc#SLE-14777).
- net: hns3: reject unsupported coalescing params (jsc#SLE-14777).
- net: hns: reject unsupported coalescing params (jsc#SLE-14777).
- net: hns3: delete unnecessary logs after kzalloc fails
  (jsc#SLE-14777).
- net: hns3: synchronize some print relating to reset issue
  (jsc#SLE-14777).
- net: hns3: print out command code when dump fails in debugfs
  (jsc#SLE-14777).
- net: hns3: print out status register when VF receives unknown
  source interrupt (jsc#SLE-14777).
- net: hns3: add a check before PF inform VF to reset
  (jsc#SLE-14777).
- net: hns3: delete some reduandant code (jsc#SLE-14777).
- net: hns3: remove an unnecessary resetting check in
  hclge_handle_hw_ras_error() (jsc#SLE-14777).
- net: hns3: rename macro HCLGE_MAX_NCL_CONFIG_LENGTH
  (jsc#SLE-14777).
- net: hns3: fix some mixed type assignment (jsc#SLE-14777).
- hisilicon: let core reject the unsupported coalescing parameters
  (jsc#SLE-14777).
- net: hns: Replace zero-length array with flexible-array member
  (jsc#SLE-14777).
- net: hns3: remove redundant initialization of pointer 'client'
  (jsc#SLE-14777).
- net: hns3: add missing help info for QS shaper in debugfs
  (jsc#SLE-14777).
- net: hns3: add support for dump MAC ID and loopback status in
  debugfs (jsc#SLE-14777).
- net: hns3: add enabled TC numbers and DWRR weight info in
  debugfs (jsc#SLE-14777).
- net: hns3: modify an unsuitable print when setting unknown
  duplex to fibre (jsc#SLE-14777).
- net: hns3: clear port base VLAN when unload PF (jsc#SLE-14777).
- net: hns3: fix VF VLAN table entries inconsistent issue
  (jsc#SLE-14777).
- net: hns3: fix "tc qdisc del" failed issue (jsc#SLE-14777).
- commit b14f4ce
* Thu Oct  1 2020 mgorman@suse.de
- locking/rwsem: Disable reader optimistic spinning (bnc#1176588).
- cpuidle: Poll for a minimum of 30ns and poll for a tick if
  lower c-states are disabled (bnc#1176588).
- commit 978088f
* Thu Oct  1 2020 mgorman@suse.de
- sched/numa: Avoid creating large imbalances at task creation
  time (bnc#1176588).
- commit aa3fc2a
* Thu Oct  1 2020 mgorman@suse.de
- sched/numa: Check numa balancing information only when enabled
  (bnc#1176588).
- commit 576f70b
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix memory leak'
- commit 48bb0f7
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: memory leak'
- commit b4a1ce3
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/etnaviv: fix missing unlock on error in etnaviv_iommuv1_context_alloc()'
- commit cefd005
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: remove unused function'
- commit db065a8
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: remove duplicate macro smu_get_uclk_dpm_states in amdgpu_smu.h'
- commit 3bf4e7b
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: fix variable type errors in smu_v11_0_setup_pptable'
- commit 3376fe8
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/gfx9: update pg_flags after determining if gfx off is possible'
- commit d2d9457
* Thu Oct  1 2020 lduncan@suse.com
- scsi: bnx2i: Add parameter description and rename another
  (bsc#1177154 jre#sle-15134).
- scsi: bnx2i: Add, remove and edit some function parameter
  descriptions (bsc#1177154 jre#sle-15134).
- scsi: bnx2i: Fix a whole host of kerneldoc issues (bsc#1177154
  jre#sle-15134).
- scsi: bnx2i: Add missing descriptions for 'attr' parameter
  (bsc#1177154 jre#sle-15134).
- scsi: bnx2i: Fix parameter misnaming in function header
  (bsc#1177154 jre#sle-15134).
- commit 9ba4024
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/amdgpu/vcn_v2_0: Move VCN 2.0 specific dec ring test to vcn_v2_0'
- commit e92c6bf
* Thu Oct  1 2020 tiwai@suse.de
- Refresh patches.suse/ASoC-soc-use-asoc_rtd_to_cpu-asoc_rtd_to_codec-macro.patch
  Fix a typo in the backported patch
- commit bb5933d
* Thu Oct  1 2020 yousaf.kaukab@suse.com
- base: soc: Handle custom soc information sysfs entries
  (jsc#SLE-15847).
- base: soc: Add serial_number attribute to soc (jsc#SLE-15847).
- commit 648cb09
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: drop logs when we've aborted a transaction (bsc#1176019).
- commit 7345ceb
* Thu Oct  1 2020 tiwai@suse.de
- hdlc_ppp: add range checks in ppp_cp_parse_cr() (CVE-2020-25643
  bsc#1177206).
- commit 8a998ea
* Thu Oct  1 2020 tiwai@suse.de
- block: allow for_each_bvec to support zero len bvec
  (CVE-2020-25641 bsc#1177121).
- commit d4185c3
* Thu Oct  1 2020 fdmanana@suse.com
- Btrfs: fix crash during unmount due to race with delayed inode
  workers (bsc#1176019).
- commit 0dbe270
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: fix null pointer dereference around dpm state relates'
- commit 70094be
* Thu Oct  1 2020 yousaf.kaukab@suse.com
- soc/tegra: fuse: Fix typo in APB MISC warning (jsc#SLE-15847).
- soc/tegra: fuse: Update the SoC revision attribute to display
  a name (jsc#SLE-15847).
- soc/tegra: fuse: Trivial clean-up of tegra_init_revision()
  (jsc#SLE-15847).
- soc/tegra: fuse: Add custom SoC attributes (jsc#SLE-15847).
- soc/tegra: pmc: Cleanup whitespace usage (jsc#SLE-15847).
- soc/tegra: pmc: Add pins for Tegra194 (jsc#SLE-15847).
- soc/tegra: fuse: Unmap registers once they are not needed
  anymore (jsc#SLE-15847).
- soc/tegra: fuse: Warn if straps are not ready (jsc#SLE-15847).
- soc/tegra: fuse: Cache values of straps and Chip ID registers
  (jsc#SLE-15847).
- soc/tegra: fuse: Add Tegra194 support (jsc#SLE-15847).
- soc/tegra: fuse: Register cell lookups for compatibility
  (jsc#SLE-15847).
- soc/tegra: fuse: Add cell information (jsc#SLE-15847).
- soc/tegra: fuse: Implement nvmem device (jsc#SLE-15847).
- soc/tegra: fuse: Restore base on sysfs failure (jsc#SLE-15847).
- ARM: tegra: Use WFE for power-gating on Tegra30 (jsc#SLE-15847).
- commit 283cb45
* Thu Oct  1 2020 yousaf.kaukab@suse.com
- spi: document CS setup, hold & inactive times in header
  (jsc#SLE-15847).
- commit edacaf4
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: kill the subvol_srcu (bsc#1176019).
- commit 0920c6e
* Thu Oct  1 2020 tiwai@suse.de
- Remove duplicated entry in realtek phy due to stable backport
  Delete patches.suse/net-phy-realtek-fix-handling-of-RTL8105e-integrated-.patch
- commit 3bb764a
* Thu Oct  1 2020 tiwai@suse.de
- r8169: change driver data type (bsc#1175746).
- commit 01ff12d
* Thu Oct  1 2020 tiwai@suse.de
- r8169: improve rtl_remove_one (bsc#1175746).
- commit 86cbe7f
* Thu Oct  1 2020 tiwai@suse.de
- r8169: switch from netif_xxx message functions to netdev_xxx
  (bsc#1175746).
- commit af2bb83
* Thu Oct  1 2020 tiwai@suse.de
- r8169: improve error message if no dedicated PHY driver is found
  (bsc#1175746).
- commit 5bd3878
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: make btrfs_cleanup_fs_roots use the radix tree lock
  (bsc#1176019).
- commit c45ade0
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/gfx10: update gfx golden settings'
- commit 3f5f070
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: don't take an extra root ref at allocation time
  (bsc#1176019).
- commit 3454450
* Thu Oct  1 2020 oneukum@suse.com
- crypto: inside-secure - keep ivsize for DES ECB modes at 0
  (jsc#SLE-14454).
- commit 9a463d4
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix GFXOFF on Picasso and Raven2'
- commit 1712474
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Add APTX quirk for Dell Latitude 5495'
- commit 63f99be
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: correct Vega20 dpm level related settings'
- commit adfb522
* Thu Oct  1 2020 yousaf.kaukab@suse.com
- blacklist.conf: add Tegra PCI defconfig patch
- commit c670bbb
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/powerplay: Fix Vega20 power reading again'
- commit 5953963
* Thu Oct  1 2020 yousaf.kaukab@suse.com
- spi: use new `spi_transfer_delay_exec` helper where
  straightforward (jsc#SLE-15847).
- spi: spi-axi: extend support for the `delay` field
  (jsc#SLE-15847).
- spi: bcm63xx: extend error condition to `delay` as well
  (jsc#SLE-15847).
- spi: spi-falcon: extend warning to `delay` as well
  (jsc#SLE-15847).
- spi: spi-fsl-espi: convert transfer delay to `spi_delay` format
  (jsc#SLE-15847).
- spi: implement SW control for CS times (jsc#SLE-15847).
- spi: tegra114: change format for `spi_set_cs_timing()` function
  (jsc#SLE-15847).
- spi: spidev: use new `delay` field for spi transfers
  (jsc#SLE-15847).
- spi: spi-loopback-test: use new `delay` field (jsc#SLE-15847).
- spi: tegra20-sflash: use to new `spi_transfer_delay_exec`
  (jsc#SLE-15847).
- spi: tegra114: use `spi_transfer_delay_exec` helper
  (jsc#SLE-15847).
- spi: introduce `delay` field for `spi_transfer` +
  spi_transfer_delay_exec() (jsc#SLE-15847).
- spi: core,atmel: convert `word_delay_usecs` -> `word_delay`
  for spi_device (jsc#SLE-15847).
- spi: spidev: use new `word_delay` field for spi transfers
  (jsc#SLE-15847).
- spi: orion: use new `word_delay` field for SPI transfers
  (jsc#SLE-15847).
- spi: sprd: convert transfer word delay to spi_delay struct
  (jsc#SLE-15847).
- spi: make `cs_change_delay` the first user of the `spi_delay`
  logic (jsc#SLE-15847).
- spi: introduce spi_delay struct as "value + unit" &
  spi_delay_exec() (jsc#SLE-15847).
- spi: move `cs_change_delay` backwards compat logic outside
  switch (jsc#SLE-15847).
- iio: imu: adis: Add support for SPI transfer cs_change_delay
  (jsc#SLE-15847).
- commit ef03858
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix dma_fence_wait without reference'
- commit 3d06c60
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/powerplay: Fix Vega20 Average Power value v4'
- commit 9bc612b
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/powerplay: silence a warning in smu_v11_0_setup_pptable'
- commit 401aa7a
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: prevent memory leaks in AMDGPU_CS ioctl'
- commit af4e5eb
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/amdgpu: disable MMHUB PG for navi10'
- commit a11fe75
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Calculate bpc based on max_requested_bpc'
- commit a6dae47
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/scheduler: use job count instead of peek'
- commit 0717cb9
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: use kvmalloc for dc_state (v2)'
- commit c582568
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix gfx9 soft recovery'
- commit a188ecb
* Thu Oct  1 2020 lhenriques@suse.de
- fuse: don't ignore errors from fuse_writepages_fill()
  (bsc#1177193).
- commit 9d94f4c
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: update smu11_driver_if_navi10.h'
- commit 76fa48f
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/amdgpu: fix transform feedback GDS hang on gfx10 (v2)"'
- commit a20a0d1
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: hold a ref on the root on the dead roots list
  (bsc#1176019).
- commit 5e21616
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Do not create a new max_bpc prop for MST connectors'
- commit 3dd8035
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix HW readout for crtc_clock in HDMI mode'
- commit 4201925
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: make inodes hold a ref on their roots (bsc#1176019).
- commit 4ebbb08
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: move the root freeing stuff into btrfs_put_root
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch.
- Refresh
  patches.suse/btrfs-fix-corrupt-log-due-to-concurrent-fsync-of-ino.patch.
- commit 9621b6c
* Thu Oct  1 2020 tiwai@suse.de
- r8169: allow to enable ASPM on RTL8125A (bsc#1175746).
- r8169: add support for RTL8125B (bsc#1175746).
- net: phy: realtek: add support for RTL8125B-internal PHY
  (bsc#1175746).
- r8169: sync support for RTL8401 with vendor driver
  (bsc#1175746).
- commit 6a9023d
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix wrong escape clock divisor init for GLK'
- commit 0ddf444
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: fix possible memory leak in intel_hdcp_auth_downstream()'
- commit 6c90832
* Thu Oct  1 2020 tiwai@suse.de
- r8169: merge handling of RTL8101e and RTL8100e (bsc#1175746).
- r8169: rename RTL8125 to RTL8125A (bsc#1175746).
- r8169: improve rtl8169_runtime_resume (bsc#1175746).
- r8169: remove driver-specific mutex (bsc#1175746).
- r8169: use RTNL to protect critical sections (bsc#1175746).
- r8169: add rtl8169_up (bsc#1175746).
- r8169: remove no longer needed checks for device being
  runtime-active (bsc#1175746).
- r8169: mark device as not present when in PCI D3 (bsc#1175746).
- r8169: allow setting irq coalescing if link is down
  (bsc#1175746).
- r8169: fix firmware not resetting tp->ocp_base (bsc#1175746).
- commit e56866c
* Thu Oct  1 2020 tiwai@suse.de
- r8169: move switching optional clock on/off to pll power
  functions (bsc#1175746).
- r8169: move updating counters to rtl8169_down (bsc#1175746).
- r8169: move napi_disable call and rename rtl8169_hw_reset
  (bsc#1175746).
- r8169: replace synchronize_rcu with synchronize_net
  (bsc#1175746).
- r8169: improve setting WoL on runtime-resume (bsc#1175746).
- r8169: remove unused constant RsvdMask (bsc#1175746).
- r8169: add info for DASH being enabled (bsc#1175746).
- r8169: fix failing WoL (bsc#1175746).
- r8169: improve handling power management ops (bsc#1175746).
- commit 7f09749
* Thu Oct  1 2020 tiwai@suse.de
- r8169: make rtl8169_down central chip quiesce function
  (bsc#1175746).
- r8169: move some calls to rtl8169_hw_reset (bsc#1175746).
- r8169: don't reset tx ring indexes in rtl8169_tx_clear
  (bsc#1175746).
- r8169: enable WAKE_PHY as only WoL source when
  runtime-suspending (bsc#1175746).
- r8169: sync RTL8168f/RTL8411 hw config with vendor driver
  (bsc#1175746).
- r8169: sync RTL8168evl hw config with vendor driver
  (bsc#1175746).
- r8169: sync RTL8168h hw config with vendor driver (bsc#1175746).
- r8169: sync RTL8168g hw config with vendor driver (bsc#1175746).
- commit 5d3b949
* Thu Oct  1 2020 tiwai@suse.de
- r8169: fix OCP access on RTL8117 (bsc#1175746).
- Refresh
  patches.suse/r8169-use-fsleep-in-polling-functions.patch.
- commit 1548915
* Thu Oct  1 2020 tiwai@suse.de
- r8169: remove mask argument from r8168ep_ocp_read (bsc#1175746).
- r8169: remove mask argument from r8168dp_ocp_read (bsc#1175746).
- r8169: remove mask argument from rtl_w0w1_eri (bsc#1175746).
- realtek/8139cp: use generic power management (bsc#1175746).
- realtek/8139too: use generic power management (bsc#1175746).
- r8169: work around an irq coalescing related tx timeout
  (bsc#1175746).
- r8169: improve rtl8169_mark_to_asic (bsc#1175746).
- r8169: make rtl_rx better readable (bsc#1175746).
- commit 9e625c0
* Thu Oct  1 2020 tiwai@suse.de
- r8169: don't include linux/moduleparam.h (bsc#1175746).
- r8169: remove not needed checks in rtl8169_set_eee
  (bsc#1175746).
- r8169: improve reset handling for chips from RTL8168g
  (bsc#1175746).
- r8169: add helper rtl_wait_txrx_fifo_empty (bsc#1175746).
- r8169: add helper rtl_enable_rxdvgate (bsc#1175746).
- r8169: add helper r8168g_wait_ll_share_fifo_ready (bsc#1175746).
- r8169: use fsleep in polling functions (bsc#1175746).
- r8169: remove "out of memory" error message from
  rtl_request_firmware (bsc#1175746).
- commit 63f90bf
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vmwgfx: Assign eviction priorities to resources'
- commit 97e7b7c
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vmwgfx: Kill unneeded legacy security features'
- commit 52b4191
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vmwgfx: Use VMW_DEBUG_KMS for vmwgfx mode-setting user errors'
- commit 58ff0f3
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vmwgfx: Add debug message for layout change ioctl'
- commit dbde0e4
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: pin the csb buffer on hw init for gfx v8'
- commit af8d80e
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: correct navi10 vcn powergate'
- commit d3e844c
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: honor hw limit on fetching metrics data for navi10'
- commit 2b94be4
* Thu Oct  1 2020 tiwai@suse.de
- r8169: simplify counter handling (bsc#1175746).
- r8169: remove redundant driver message when entering promiscuous
  mode (bsc#1175746).
- r8169: remove not needed parameter in rtl8169_set_magic_reg
  (bsc#1175746).
- r8169: configure PME_SIGNAL for RTL8125 too (bsc#1175746).
- r8169: improve max jumbo packet size definition (bsc#1175746).
- r8169: add check for invalid parameter combination in
  rtl_set_coalesce (bsc#1175746).
- r8169: improve rtl_set_coalesce (bsc#1175746).
- r8169: improve interrupt coalescing parameter handling
  (bsc#1175746).
- r8169: improve rtl_coalesce_choose_scale (bsc#1175746).
- r8169: improve rtl_get_coalesce (bsc#1175746).
- commit 07e3627
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: Allow changing of fan_control in smu_v11_0'
- commit 0eaa430
* Thu Oct  1 2020 tiwai@suse.de
- r8169: merge scale for tx and rx irq coalescing (bsc#1175746).
- r8169: don't pass net_device to irq coalescing sub-functions
  (bsc#1175746).
- r8169: improve configuring RxConfig register (bsc#1175746).
- r8169: improve handling CPCMD_MASK (bsc#1175746).
- r8169: change wmb to smb_wmb in rtl8169_start_xmit
  (bsc#1175746).
- r8169: inline rtl8169_make_unusable_by_asic (bsc#1175746).
- r8169: inline rtl8169_mark_as_last_descriptor (bsc#1175746).
- r8169: remove PHY resume delay that is handled in the PHY
  driver now (bsc#1175746).
- commit 879143b
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: correct UVD/VCE/VCN power status retrieval'
- commit 4485290
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: correct Navi10 VCN powergate control (v2)'
- commit 619b343
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: support VCN powergate status retrieval for SW SMU'
- commit d924449
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: support VCN powergate status retrieval on Raven'
- commit 46101c7
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: add new sensor type for VCN powergate status'
- commit 6f196aa
* Thu Oct  1 2020 tiwai@suse.de
- net: phy: realtek: add delay to resume path of certain internal
  PHY's (bsc#1175746).
- r8169: add workaround for RTL8168evl TSO hw issues
  (bsc#1175746).
- r8169: improve rtl8169_tso_csum_v2 (bsc#1175746).
- r8169: use rtl8169_set_features in rtl8169_init_one
  (bsc#1175746).
- r8169: preserve VLAN setting on RTL8125 in rtl_init_rxcfg
  (bsc#1175746).
- r8169: remove NETIF_F_HIGHDMA from vlan_features (bsc#1175746).
- r8169: move setting OCP base to generic init code (bsc#1175746).
- r8169: change back SG and TSO to be disabled by default
  (bsc#1175746).
- r8169: factor out rtl8169_tx_map (bsc#1175746).
- r8169: improve handling of TD_MSS_MAX (bsc#1175746).
- commit 2b38e9c
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix a potential information leaking bug'
- commit d05bce7
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix error handling in amdgpu_cs_process_fence_dep'
- commit 200013a
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/amdgpu/vcn_v2_0: Mark RB commands as KMD commands'
- commit 230fb89
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/powerplay: use proper revision id for navi'
- commit 5f9312d
* Thu Oct  1 2020 tiwai@suse.de
- r8169: improve RTL8168b FIFO overflow workaround (bsc#1175746).
- r8169: improve rtl_schedule_task (bsc#1175746).
- r8169: simplify rtl_task (bsc#1175746).
- r8169: add new helper rtl8168g_enable_gphy_10m (bsc#1175746).
- net: phy: realtek: read actual speed to detect downshift
  (bsc#1175746).
- net: r8169: reject unsupported coalescing params (bsc#1175746).
- r8169: simplify getting stats by using netdev_stats_to_stats64
  (bsc#1175746).
- r8169: let rtl8169_mark_to_asic clear rx descriptor field opts2
  (bsc#1175746).
- r8169: remove now unneeded barrier in rtl_tx (bsc#1175746).
- r8169: simplify usage of rtl8169_unmap_tx_skb (bsc#1175746).
- commit 2d5180d
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: enable SW SMU reset functionality'
- commit 3abfeab
* Thu Oct  1 2020 tiwai@suse.de
- r8169: improve rtl8169_get_mac_version (bsc#1175746).
- commit 386ab62
* Thu Oct  1 2020 tiwai@suse.de
- r8169: ensure tx_skb is fully reset after calling
  rtl8169_unmap_tx_skb (bsc#1175746).
- r8169: convert while to for loop in rtl_tx (bsc#1175746).
- r8169: add PCI_STATUS_PARITY to PCI status error bits
  (bsc#1175746).
- r8169: improve rtl8169_start_xmit (bsc#1175746).
- r8169: remove RTL_EVENT_NAPI constants (bsc#1175746).
- r8169: improve statistics of missed rx packets (bsc#1175746).
- r8169: improve rtl_jumbo_config (bsc#1175746).
- commit 177a646
* Thu Oct  1 2020 tiwai@suse.de
- r8169: add helper rtl_pci_commit (bsc#1175746).
- r8169: simplify setting netdev features (bsc#1175746).
- r8169: remove setting PCI_CACHE_LINE_SIZE in rtl_hw_start_8169
  (bsc#1175746).
- r8169: remove unneeded check from rtl_link_chg_patch
  (bsc#1175746).
- r8169: fix performance regression related to PCIe max read
  request size (bsc#1175746).
- r8169: don't set min_mtu/max_mtu if not needed (bsc#1175746).
- r8169: factor out PHY configuration to r8169_phy_config.c
  (bsc#1175746).
- r8169: add r8169.h (bsc#1175746).
- r8169: rename rtl_apply_firmware (bsc#1175746).
- r8169: add phydev argument to rtl8168d_apply_firmware_cond
  (bsc#1175746).
- commit ae773bc
* Thu Oct  1 2020 tiwai@suse.de
- r8169: use phy_read/write instead of rtl_readphy/writephy
  (bsc#1175746).
- r8169: replace rtl_w0w1_phy (bsc#1175746).
- r8169: replace rtl_patchphy (bsc#1175746).
- r8169: move disabling MAC EEE for RTL8402/RTL8106e
  (bsc#1175746).
- r8169: move setting ERI register 0x1d0 for RTL8106
  (bsc#1175746).
- r8169: switch to phylib functions in rtl_writephy_batch
  (bsc#1175746).
- r8169: change argument type of RTL8168g-specific PHY config
  functions (bsc#1175746).
- r8169: change argument type of EEE PHY functions (bsc#1175746).
- r8169: move RTL8169scd Gigabyte PHY quirk (bsc#1175746).
- r8169: remove not needed debug print in rtl8169_init_phy
  (bsc#1175746).
- commit 472deb8
* Thu Oct  1 2020 tiwai@suse.de
- net: phy: realtek: add logging for the RGMII TX delay
  configuration (bsc#1175746).
- Refresh
  patches.suse/net-phy-realtek-add-support-for-configuring-the-RX-d.patch.
- commit bc4b3c3
* Thu Oct  1 2020 tiwai@suse.de
- r8169: prepare for exporting rtl_hw_phy_config (bsc#1175746).
- r8169: add constant EnAnaPLL (bsc#1175746).
- r8169: move enabling EEE to rtl8169_init_phy (bsc#1175746).
- r8169: remove MAC workaround in rtl8168e_2_hw_phy_config
  (bsc#1175746).
- r8169: factor out rtl8168h_2_get_adc_bias_ioffset (bsc#1175746).
- r8169: add missing RX enabling for WoL on RTL8125 (bsc#1175746).
- net: phy: realtek: fix using paged operations with RTL8105e /
  RTL8208 (bsc#1175746).
- r8169: disable TSO on a single version of RTL8168c to fix
  performance (bsc#1175746).
- commit e71fa48
* Thu Oct  1 2020 tiwai@suse.de
- blacklist.conf: remove r8169 entry to be backported
- commit 50daeab
* Thu Oct  1 2020 tiwai@suse.de
- Delete patches.suse/r8169-Revive-default-chip-version-for-r8168.patch
  The hack is no longer needed after the backport
- commit 6dda380
* Thu Oct  1 2020 tiwai@suse.de
- r8169: add check for PHY_MDIO_CHG to rtl_nic_fw_data_ok
  (bsc#1175746).
- r8169: use macro FIELD_SIZEOF in definition of FW_OPCODE_SIZE
  (bsc#1175746).
- r8169: change mdelay to msleep in rtl_fw_write_firmware
  (bsc#1175746).
- r8169: load firmware for RTL8168fp/RTL8117 (bsc#1175746).
- r8169: improve conditional firmware loading for RTL8168d
  (bsc#1175746).
- r8169: use r8168d_modify_extpage in rtl8168f_config_eee_phy
  (bsc#1175746).
- r8169: add support for RTL8117 (bsc#1175746).
- r8169: respect EEE user setting when restarting network
  (bsc#1175746).
- r8169: remove rtl8168c_4_hw_phy_config (bsc#1175746).
- r8169: add helper r8168d_modify_extpage (bsc#1175746).
- commit 689809f
* Thu Oct  1 2020 tiwai@suse.de
- r8169: switch to phylib functions in more places (bsc#1175746).
- r8169: add helper r8168d_phy_param (bsc#1175746).
- r8169: add helper r8168g_phy_param (bsc#1175746).
- r8169: use helper rtl_hw_aspm_clkreq_enable also in
  rtl_hw_start_8168g_2 (bsc#1175746).
- r8169: improve rtl8169_rx_fill (bsc#1175746).
- r8169: align fix_features callback with vendor driver
  (bsc#1175746).
- r8169: never set PCI_EXP_DEVCTL_NOSNOOP_EN (bsc#1175746).
- r8169: remove rtl_hw_start_8168bef (bsc#1175746).
- r8169: remove rtl_hw_start_8168dp (bsc#1175746).
- r8169: simplify setting PCI_EXP_DEVCTL_NOSNOOP_EN (bsc#1175746).
- commit 1e610e7
* Thu Oct  1 2020 tiwai@suse.de
- r8169: remove fiddling with the PCIe max read request size
  (bsc#1175746).
- r8169: don't set bit RxVlan on RTL8125 (bsc#1175746).
- r8169: add support for EEE on RTL8125 (bsc#1175746).
- r8169: add RTL8125 PHY initialization (bsc#1175746).
- r8169: add support for RTL8125 (bsc#1175746).
- r8169: don't use bit LastFrag in tx descriptor after send
  (bsc#1175746).
- r8169: factor out reading MAC address from registers
  (bsc#1175746).
- r8169: restrict rtl_is_8168evl_up to RTL8168 chip versions
  (bsc#1175746).
- r8169: change interrupt mask type to u32 (bsc#1175746).
- commit caedec7
* Thu Oct  1 2020 tiwai@suse.de
- r8169: use the generic EEE management functions (bsc#1175746).
- Refresh
  patches.suse/r8169-Revive-default-chip-version-for-r8168.patch.
- commit ee0769f
* Thu Oct  1 2020 tiwai@suse.de
- r8169: improve DMA handling in rtl_rx (bsc#1175746).
- r8169: sync EEE handling for RTL8168h with vendor driver
  (bsc#1175746).
- r8169: fix sporadic transmit timeout issue (bsc#1175746).
- r8169: inline rtl8169_free_rx_databuff (bsc#1175746).
- r8169: fix performance issue on RTL8168evl (bsc#1175746).
- r8169: allocate rx buffers using alloc_pages_node (bsc#1175746).
- r8169: sync PCIe PHY init with vendor driver 8.047.01
  (bsc#1175746).
- r8169: add helper r8168_mac_ocp_modify (bsc#1175746).
- r8169: remove access to legacy register MultiIntr (bsc#1175746).
- commit 03e1dc8
* Thu Oct  1 2020 tiwai@suse.de
- r8169: make use of xmit_more (bsc#1175746).
- r8169: enable HW csum and TSO (bsc#1175746).
- r8169: remove r8169_csum_workaround (bsc#1175746).
- r8169: implement callback ndo_features_check (bsc#1175746).
- r8169: set GSO size and segment limits (bsc#1175746).
- r8169: align setting PME with vendor driver (bsc#1175746).
- r8169: improve rtl_set_rx_mode (bsc#1175746).
- r8169: fix a typo in a comment (bsc#1175746).
- commit 30e5417
* Thu Oct  1 2020 tiwai@suse.de
- r8169: improve rtl_rx (bsc#1175746).
- Refresh patches.suse/r8169-fix-DMA-issue-on-MIPS-platform.patch.
- commit fbcfbaf
* Thu Oct  1 2020 mkubecek@suse.cz
- Update kabi files.
- update to October 2020 maintenance update submission (commit e037a4e18793)
- commit 05421e4
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/r128: drop use of drmP.h'
- commit ffe45ec
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Make sure cdclk is high enough for DP audio on VLV/CHV'
- commit f3b60dd
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/userptr: Acquire the page lock around set_page_dirty()'
- commit ebf6288
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Add a wakeref getter for iff the wakeref is already active'
- commit 763dd74
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: use VCN firmware offset for cache window'
- commit 23a25a5
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: fix temperature granularity error in smu11'
- commit e1e512c
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: free block groups after free'ing fs trees (bsc#1176019).
- commit 2c64d7b
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: move ino_cache_inode dropping out of btrfs_free_fs_root
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch.
- commit d9887ec
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: make the extent buffer leak check per fs info
  (bsc#1176019).
- commit 941b4ee
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: readd -msse2 to prevent Clang from emitting libcalls to undefined SW FP routines'
- commit 4b807be
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdkfd: Fix byte align on VegaM'
- commit 5d5d538
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: add callback function of get_thermal_temperature_range'
- commit 7eb0df5
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/smu: move fan rpm query into the asic specific code'
- commit 962f044
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: remove redundancy debug log in smu'
- commit 189b071
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: custom peak clock freq for navi10'
- commit 9262892
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: handle active dongle port type is DP++ or DP case'
- commit 06c7488
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: do not read link setting if edp not connected'
- commit 2ec613d
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Increase size of audios array'
- commit dbf11b5
* Thu Oct  1 2020 yousaf.kaukab@suse.com
- soc/tegra: bpmp: Update ABI header (jsc#SLE-15847).
- commit 71478fa
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: drop ASSERT() if eDP panel is not connected'
- commit 5751a1a
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Set enabled to false at start of audio disable'
- commit df7ebe2
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Fix dc_create failure handling and 666 color depths'
- commit 2a82459
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: allocate 4 ddc engines for RV2'
- commit e6c1093
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: put back front end initialization sequence'
- commit 6003188
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Wait for flip to complete'
- commit d3b00dd
* Thu Oct  1 2020 yousaf.kaukab@suse.com
- mmc: sdhci: Refactor sdhci_set_timeout() (jsc#SLE-15847).
- mmc: sdhci: Convert sdhci_set_timeout_irq() to non-static
  (jsc#SLE-15847).
- mmc: sdhci: add support for using external DMA devices
  (jsc#SLE-15847).
- mmc: sdhci: Factor out some operations set to their own
  functions (jsc#SLE-15847).
- commit 27ad6d4
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Change min_h_sync_width from 8 to 4'
- commit 48e4be5
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: use encoder's engine id to find matched free audio device'
- commit 484b212
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: fix DMCU hang when going into Modern Standby'
- commit d99b5ec
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Disable Audio on reinitialize hardware'
- commit 0d5d2ec
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Read max down spread'
- commit 0813faa
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Check for valid stream_encode'
- commit 9e44584
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Wait for backlight programming completion in set backlight level'
- commit 62ae57f
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Poll for GPUVM context ready (v2)'
- commit 59fb669
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: wait for the whole frame after global unlock'
- commit c6f61c2
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Copy max_clks_by_state after dce_clk_mgr_construct'
- commit 8db0624
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Clock does not lower in Updateplanes'
- commit abbe1b3
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: skip retrain in dc_link_set_preferred_link_settings() if using passive dongle'
- commit 9c1b84a
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: swap system aperture high/low'
- commit 6e8960e
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Set one 4:2:0-related PPS field as recommended by DSC spec'
- commit 94516fe
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Set default block_size, even in unexpected cases'
- commit be4db4b
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: No audio endpoint for Dell MST display'
- commit b641187
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: cap DCFCLK hardmin to 507 for NV10'
- commit 3890eb3
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: fix dsc disable'
- commit eefe5ae
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: fix up HUBBUB hw programming for VM'
- commit daf5fbe
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: initialize p_state to proper value'
- commit 7802292
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: use VCN firmware offset for cache window'
- commit e4c08aa
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/ttm: use the same attributes when freeing d_page->vaddr'
- commit 8d3e65f
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: change sysfs pp_dpm_xxx format for navi10'
- commit e7b0d4e
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: drop ras self test'
- commit 4375cca
* Thu Oct  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: only allow error injection to UMC IP block'
- commit f5d234f
* Wed Sep 30 2020 tbogendoerfer@suse.de
- igc: Add WOL support (jsc#SLE-13533).
- Refresh patches.suse/igc-Fix-PTP-initialization.patch.
- commit c48069c
* Wed Sep 30 2020 tbogendoerfer@suse.de
- e1000e: Add support for Alder Lake (jsc#SLE-13532).
- Refresh
  patches.suse/ethernet-intel-Convert-fallthrough-code-comments.patch.
- commit c0dca3e
* Wed Sep 30 2020 tbogendoerfer@suse.de
- e1000e: Remove unnecessary usages of memset (jsc#SLE-13532).
- e1000: Remove unnecessary usages of memset (jsc#SLE-13532).
- igc: Fix static checker warning (jsc#SLE-13533).
- igc: Clean up the hw_stats structure (jsc#SLE-13533).
- igc: Clean up the mac_info structure (jsc#SLE-13533).
- igc: Remove ledctl_ fields from the mac_info structure
  (jsc#SLE-13533).
- igc: Fix registers definition (jsc#SLE-13533).
- igc: Remove unneeded ICTXQMTC register (jsc#SLE-13533).
- igc: Add Receive Descriptor Minimum Threshold Count to clear
  HW counters (jsc#SLE-13533).
- igc: Remove unneeded variable (jsc#SLE-13533).
- fm10k: convert to new udp_tunnel_nic infra (jsc#SLE-13535).
- bnx2x: convert to new udp_tunnel_nic infra (jsc#SLE-13628).
- be2net: convert to new udp_tunnel_nic infra (jsc#SLE-15083).
- bnx2x: fix spelling mistake "occurd" -> "occurred"
  (jsc#SLE-13628).
- bnx2x: Perform Idlechk dump during the debug collection
  (jsc#SLE-13628).
- bnx2x: Add support for idlechk tests (jsc#SLE-13628).
- bnx2x: Add Idlechk related register definitions (jsc#SLE-13628).
- benet: use generic power management (jsc#SLE-15083).
- igc: Remove checking media type during MAC initialization
  (jsc#SLE-13533).
- igc: Remove unneeded check for copper media type
  (jsc#SLE-13533).
- igc: Refactor the igc_power_down_link() (jsc#SLE-13533).
- igc: Remove TCP segmentation TX fail counter (jsc#SLE-13533).
- igc: Add LPI counters (jsc#SLE-13533).
- igc: Fix Rx timestamp disabling (jsc#SLE-13533).
- igc: Refactor igc_ptp_set_timestamp_mode() (jsc#SLE-13533).
- igc: Remove UDP filter setup in PTP code (jsc#SLE-13533).
- igc: Check __IGC_PTP_TX_IN_PROGRESS instead of ptp_tx_skb
  (jsc#SLE-13533).
- igc: Remove duplicate code in Tx timestamp handling
  (jsc#SLE-13533).
- igc: Clean up Rx timestamping logic (jsc#SLE-13533).
- igc: Add initial LTR support (jsc#SLE-13533).
- igc: Add initial EEE support (jsc#SLE-13533).
- bnx2x: use generic power management (jsc#SLE-13628).
- e1000e: continue to init PHY even when failed to disable ULP
  (jsc#SLE-13532).
- e1000e: fix unused-function warning (jsc#SLE-13532).
- e1000: use generic power management (jsc#SLE-13532).
- e1000: Fix typo in the comment (jsc#SLE-13532).
- igc: Fix wrong register name (jsc#SLE-13533).
- igc: Remove Sequence Error Counter (jsc#SLE-13533).
- igc: Add Receive Error Counter (jsc#SLE-13533).
- igc: Remove symbol error counter (jsc#SLE-13533).
- igc: Fix IGC_MAX_RXNFC_RULES (jsc#SLE-13533).
- igc: Reject NFC rules with multiple matches (jsc#SLE-13533).
- igc: Remove unused flags (jsc#SLE-13533).
- bnx2x: allow bnx2x_bsc_read() to schedule (jsc#SLE-13628).
- e1000e: disable s0ix entry and exit flows for ME systems
  (jsc#SLE-13532).
- e1000e: Warn if disabling ULP failed (jsc#SLE-13532).
- igc: Remove unused descriptor's flags (jsc#SLE-13533).
- igc: Remove igc_nfc_rule_exit() (jsc#SLE-13533).
- igc: Change adapter->nfc_rule_lock to mutex (jsc#SLE-13533).
- igc: Change return type from igc_disable_nfc_rule()
  (jsc#SLE-13533).
- igc: Fix NFC rule validation (jsc#SLE-13533).
- igc: Fix NFC rules leak when driver is unloaded (jsc#SLE-13533).
- igc: Refactor igc_ethtool_update_nfc_rule() (jsc#SLE-13533).
- igc: Fix NFC rules restoration (jsc#SLE-13533).
- igc: Fix NFC rules with multicast addresses (jsc#SLE-13533).
- igc: Fix NFC rule overwrite cases (jsc#SLE-13533).
- igc: Fix locking issue when retrieving NFC rules
  (jsc#SLE-13533).
- igc: Fix 'sw_idx' type in struct igc_nfc_rule (jsc#SLE-13533).
- igc: Refactor igc_ethtool_add_nfc_rule() (jsc#SLE-13533).
- igc: Change byte order in struct igc_nfc_filter (jsc#SLE-13533).
- igc: Align terms used in NFC support code (jsc#SLE-13533).
- igc: Add 'igc_ethtool_' prefix to functions in igc_ethtool.c
  (jsc#SLE-13533).
- igc: Early return in igc_get_ethtool_nfc_entry()
  (jsc#SLE-13533).
- igc: Cleanup _get|set_rxnfc ethtool ops (jsc#SLE-13533).
- igc: Get rid of igc_max_channels() (jsc#SLE-13533).
- igc: Remove unused field from igc_nfc_filter (jsc#SLE-13533).
- igc: Remove per queue good transmited counter register
  (jsc#SLE-13533).
- igc: Remove header redirection register (jsc#SLE-13533).
- igc: Remove obsolete circuit breaker registers (jsc#SLE-13533).
- e1000: Do not perform reset in reset_task if we are already down
  (jsc#SLE-13532).
- igc: Enable NFC rules based source MAC address (jsc#SLE-13533).
- igc: Add support for source address filters in core
  (jsc#SLE-13533).
- igc: Remove mac_table from igc_adapter (jsc#SLE-13533).
- igc: Remove IGC_MAC_STATE_SRC_ADDR flag (jsc#SLE-13533).
- igc: Remove unused registers (jsc#SLE-13533).
- igc: Remove unused IGC_ICS_DRSTA define (jsc#SLE-13533).
- igc: Dump ETQF registers (jsc#SLE-13533).
- igc: Refactor ethertype filtering code (jsc#SLE-13533).
- igc: Fix MAX_ETYPE_FILTER value (jsc#SLE-13533).
- igc: Remove ethertype filter in PTP code (jsc#SLE-13533).
- igc: Remove duplicated IGC_RXPBS macro (jsc#SLE-13533).
- igc: Refactor VLAN priority filtering code (jsc#SLE-13533).
- igc: Return -EOPNOTSUPP when VLAN mask doesn't match
  (jsc#SLE-13533).
- igc: Dump VLANPQF register (jsc#SLE-13533).
- igc: Rename IGC_VLAPQF macro (jsc#SLE-13533).
- igc: Clean up obsolete NVM defines (jsc#SLE-13533).
- igc: remove IGC_REMOVED function (jsc#SLE-13533).
- igc: Remove PCIe Control register (jsc#SLE-13533).
- igc: Remove unneeded register (jsc#SLE-13533).
- igc: Remove unneeded definition (jsc#SLE-13533).
- igc: Use netdev log helpers in igc_base.c (jsc#SLE-13533).
- igc: Use netdev log helpers in igc_dump.c (jsc#SLE-13533).
- igc: Use netdev log helpers in igc_ptp.c (jsc#SLE-13533).
- igc: Use netdev log helpers in igc_ethtool.c (jsc#SLE-13533).
- igc: add support to eeprom, registers and link self-tests
  (jsc#SLE-13533).
- igc: Use netdev log helpers in igc_main.c (jsc#SLE-13533).
- igc: Add ECN support for TSO (jsc#SLE-13533).
- cnic: remove redundant assignment to variable ret
  (jsc#SLE-15135).
- bnx2x: Remove unused inline function bnx2x_vf_vlan_credit
  (jsc#SLE-13628).
- bnx2x: Remove Comparison to bool in bnx2x_dcb.c (jsc#SLE-13628).
- igc: Add debug messages to MAC filter code (jsc#SLE-13533).
- igc: Refactor igc_del_mac_filter() (jsc#SLE-13533).
- igc: Refactor igc_mac_entry_can_be_used() (jsc#SLE-13533).
- igc: Remove igc_*_mac_steering_filter() wrappers
  (jsc#SLE-13533).
- igc: Remove IGC_MAC_STATE_QUEUE_STEERING (jsc#SLE-13533).
- igc: Remove 'queue' check in igc_del_mac_filter()
  (jsc#SLE-13533).
- igc: Improve address check in igc_del_mac_filter()
  (jsc#SLE-13533).
- igc: Refactor igc_rar_set_index() (jsc#SLE-13533).
- igc: Fix igc_uc_unsync() (jsc#SLE-13533).
- igc: Change igc_add_mac_filter() returning value
  (jsc#SLE-13533).
- igc: Check unsupported flag in igc_add_mac_filter()
  (jsc#SLE-13533).
- igc: Remove duplicate code in MAC filtering logic
  (jsc#SLE-13533).
- e1000e: fix S0ix flows for cable connected case (jsc#SLE-13532).
- igc: Add new device IDs for i225 part (jsc#SLE-13533).
- igc: Fix default MAC address filter override (jsc#SLE-13533).
- igc: Remove dead code related to flower filter (jsc#SLE-13533).
- igc: Fix NFC queue redirection support (jsc#SLE-13533).
- igc: Remove copper fiber switch control (jsc#SLE-13533).
- igc: Enable NETIF_F_HW_TC flag (jsc#SLE-13533).
- igc: Fix double definition (jsc#SLE-13533).
- igc: Fix overwrites when dumping registers (jsc#SLE-13533).
- igc: Remove forward declaration (jsc#SLE-13533).
- igc: Remove unused CTRL_EXT_LINK_MODE_MASK (jsc#SLE-13533).
- igc: Remove unused MDIC_DEST mask (jsc#SLE-13533).
- igc: Add support for ETF offloading (jsc#SLE-13533).
- igc: Add support for taprio offloading (jsc#SLE-13533).
- igc: Add GSO partial support (jsc#SLE-13533).
- e1000: remove unneeded conversion to bool (jsc#SLE-13532).
- bnx2x: correct a comment mistake in grammar (jsc#SLE-13628).
- net: igc: let core reject the unsupported coalescing parameters
  (jsc#SLE-13533).
- net: fm10k: reject unsupported coalescing params
  (jsc#SLE-13535).
- net: e1000: reject unsupported coalescing params
  (jsc#SLE-13532).
- net: be2net: reject unsupported coalescing params
  (jsc#SLE-15083).
- net: bnx2x: reject unsupported coalescing params
  (jsc#SLE-13628).
- net: bnx2: reject unsupported coalescing params (jsc#SLE-15135).
- e1000e: reject unsupported coalescing params (jsc#SLE-13532).
- igc: Add comment (jsc#SLE-13533).
- igc: Add pcie error handler support (jsc#SLE-13533).
- igc: Complete to commit Add basic skeleton for PTP
  (jsc#SLE-13533).
- e1000e: Add support for Tiger Lake device (jsc#SLE-13532).
- igc: Fix the typo in comment (jsc#SLE-13533).
- igc: Add dump options (jsc#SLE-13533).
- igc: Complete to commit Add legacy power management support
  (jsc#SLE-13533).
- igc: make non-global functions static (jsc#SLE-13533).
- net: intel: e1000e: fix possible sleep-in-atomic-context bugs
  in e1000e_get_hw_semaphore() (jsc#SLE-13532).
- e1000e: fix missing cpu_to_le64 on buffer_addr (jsc#SLE-13532).
- e1000(e): use new helper tcp_v6_gso_csum_prep (jsc#SLE-13532).
- net: core: add helper tcp_v6_gso_csum_prep (jsc#SLE-13532).
- net: cnic: fix spelling mistake "reserverd" -> "reserved"
  (jsc#SLE-15135).
- fm10k: use txqueue parameter in fm10k_tx_timeout
  (jsc#SLE-13535).
- cnic: Explicitly initialize all reference counts to 0
  (jsc#SLE-15135).
- commit c9ceecc
* Wed Sep 30 2020 vbabka@suse.cz
- pagewalk: separate function pointers from iterator data
  (jsc#SLE-16387).
- Refresh
  patches.suse/0017-kvm-s390-protvirt-secure-memory-is-not-mergeable.
- Refresh
  patches.suse/0018-kvm-s390-mm-make-pages-accessible-before-destroying-the-guest.
- commit 522acd7
* Wed Sep 30 2020 vbabka@suse.cz
- Add references to jsc#SLE-16387
- Update patches.suse/kernel.h-Add-non_block_start-end.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-notifier-Catch-sleeping-blocking-for-blockable.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- commit 204d70b
* Wed Sep 30 2020 lduncan@suse.com
- scsi: bnx2fc: Demote obvious misuse of kerneldoc to standard
  comment blocks (bsc#1177142 jre#sle-15133).
- scsi: bnx2fc: Fix a couple of bitrotted function documentation
  headers (bsc#1177142 jre#sle-15133).
- scsi: bnx2fc: Repair a range of kerneldoc issues (bsc#1177142
  jre#sle-15133).
- scsi: bnx2fc: Removal of unused variables (bsc#1177142
  jre#sle-15133).
- scsi: bnx2fc: Remove unneeded semicolon in bnx2fc_fcoe.c
  (bsc#1177142 jre#sle-15133).
- scsi: bnx2fc: Add missing annotation for bnx2fc_abts_cleanup()
  (bsc#1177142 jre#sle-15133).
- scsi: bnx2fc: fix boolreturn.cocci warnings (bsc#1177142
  jre#sle-15133).
- scsi: bnx2fc: Update the driver version to 2.12.13 (bsc#1177142
  jre#sle-15133).
- scsi: bnx2fc: Fix SCSI command completion after cleanup is
  posted (bsc#1177142 jre#sle-15133).
- scsi: bnx2fc: Process the RQE with CQE in interrupt context
  (bsc#1177142 jre#sle-15133).
- scsi: bnx2fc: timeout calculation invalid for bnx2fc_eh_abort()
  (bsc#1177142 jre#sle-15133).
- commit 8bce5c3
* Wed Sep 30 2020 vbabka@suse.cz
- drm/radeon: guard against calling an unpaired
  radeon_mn_unregister() (jsc#SLE-16387).
- commit 4567f0f
* Wed Sep 30 2020 vbabka@suse.cz
- pagewalk: use lockdep_assert_held for locking validation
  (jsc#SLE-16387).
- commit 07ce7c2
* Wed Sep 30 2020 vbabka@suse.cz
- mm: split out a new pagewalk.h header from mm.h (jsc#SLE-16387).
- commit bee7bab
* Wed Sep 30 2020 vbabka@suse.cz
- mm/mmu_notifiers: annotate with might_sleep() (jsc#SLE-16387).
- commit a4feb2c
* Wed Sep 30 2020 vbabka@suse.cz
- Add references to jsc#SLE-16387
- Update
  patches.suse/mm-hmm-fix-hmm_range_fault-s-handling-of-swapped-out-pages.patch
  (git fixes (mm/hmm), jsc#SLE-16387).
- Update patches.suse/mm-hmm-hmm_range_fault-infinite-loop.patch
  (HMM Functionality, jsc#SLE-8176, jsc#SLE-16387).
- Update
  patches.suse/mm-hmm-hmm_range_fault-null-pointer-bug.patch
  (HMM Functionality, jsc#SLE-8176, jsc#SLE-16387).
- Update
  patches.suse/mm-mmu_notifiers-add-a-lockdep-map-for-invalidate_ra.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-mmu_notifiers-check-if-mmu-notifier-callbacks-are.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update patches.suse/mm-mmu_notifiers-prime-lockdep.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-mmu_notifiers-remove-the-__mmu_notifier_invalidat.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-mmu_notifiers-remove-unregister_no_release.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- commit f74975e
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: disable GFX RAS by default'
- commit b2b44f5
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: do not create ras debugfs/sysfs node for ASICs that don't have ras ability'
- commit db6e541
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: report bootup clock as max supported on dpm disabled'
- commit 0c6ce43
* Wed Sep 30 2020 vbabka@suse.cz
- mm: remove CONFIG_MIGRATE_VMA_HELPER (jsc#SLE-16387).
- Update config files.
- commit 7a1f655
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Default disable GDS for compute VMIDs'
- commit d843637
* Wed Sep 30 2020 vbabka@suse.cz
- mm: remove the unused MIGRATE_PFN_DEVICE flag (jsc#SLE-16387).
- commit 19c73bc
* Wed Sep 30 2020 vbabka@suse.cz
- mm: remove the unused MIGRATE_PFN_ERROR flag (jsc#SLE-16387).
- commit f69e741
* Wed Sep 30 2020 vbabka@suse.cz
- nouveau: simplify nouveau_dmem_migrate_vma (jsc#SLE-16387).
- commit fb24bf0
* Wed Sep 30 2020 vbabka@suse.cz
- nouveau: simplify nouveau_dmem_migrate_to_ram (jsc#SLE-16387).
- commit c1b99fc
* Wed Sep 30 2020 vbabka@suse.cz
- nouveau: remove a few function stubs (jsc#SLE-16387).
- commit 7daf904
* Wed Sep 30 2020 vbabka@suse.cz
- nouveau: factor out dmem fence completion (jsc#SLE-16387).
- commit c74288d
* Wed Sep 30 2020 vbabka@suse.cz
- nouveau: factor out device memory address calculation
  (jsc#SLE-16387).
- commit aa83c9d
* Wed Sep 30 2020 vbabka@suse.cz
- nouveau: reset dma_nr in nouveau_dmem_migrate_alloc_and_copy
  (jsc#SLE-16387).
- commit 2b18daf
* Wed Sep 30 2020 vbabka@suse.cz
- mm: turn migrate_vma upside down (jsc#SLE-16387).
- commit 918a73d
* Wed Sep 30 2020 vbabka@suse.cz
- Add references to jsc#SLE-16387.
- Update
  patches.suse/drm-amdkfd-fix-a-use-after-free-race-with-mmu_notife.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update patches.suse/drm-amdkfd-use-mmu_notifier_put.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- commit 6359fc8
* Wed Sep 30 2020 yousaf.kaukab@suse.com
- PCI: pci-epf-test: Add support to defer core initialization (jsc#SLE-15847).
- PCI: dwc: Add API to notify core initialization completion (jsc#SLE-15847).
- PCI: endpoint: Add notification for core init completion (jsc#SLE-15847).
- PCI: dwc: Refactor core initialization code for EP mode (jsc#SLE-15847).
- PCI: endpoint: Add core init notifying feature (jsc#SLE-15847).
- PCI: endpoint: Assign function number for each PF in EPC core (jsc#SLE-15847).
- PCI: endpoint: Replace spinlock with mutex (jsc#SLE-15847).
- PCI: endpoint: Use notification chain mechanism to notify EPC events to EPF (jsc#SLE-15847).
- commit dedde2d
* Wed Sep 30 2020 vbabka@suse.cz
- drm/radeon: use mmu_notifier_get/put for struct radeon_mn
  (jsc#SLE-16387).
- commit 3805587
* Wed Sep 30 2020 vbabka@suse.cz
- Add references to jsc#SLE-16387.
- Update
  patches.suse/hmm-use-mmu_notifier_get-put-for-struct-hmm.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-mmu_notifiers-add-a-get-put-scheme-for-the-regist.patch
  (jsc#SLE-8449, jsc#SLE-16387).
- Update
  patches.suse/mm-mmu_notifiers-do-not-speculatively-allocate-a-mmu.patch
  (jsc#SLE-8449, jsc#SLE-16387).
- Update
  patches.suse/mm-mmu_notifiers-hoist-do_mmu_notifier_register-down.patch
  (jsc#SLE-8449, jsc#SLE-16387).
- commit 9adc515
* Wed Sep 30 2020 tbogendoerfer@suse.de
- crypto: arm/aes-neonbs - provide a synchronous version of
  ctr(aes) (jsc#SLE-15129).
- crypto: arm/aes-neonbs - switch to library version of key
  expansion routine (jsc#SLE-15129).
- crypto: cesa/aes - switch to library version of key expansion
  routine (jsc#SLE-15129).
- commit d028852
* Wed Sep 30 2020 oneukum@suse.com
- crypto: qce - use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-14454).
- commit aa3b68e
* Wed Sep 30 2020 oneukum@suse.com
- crypto: ccree - fix spelling mistake "configration" ->
  "configuration" (jsc#SLE-14454).
- commit f3308fe
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/bochs: Use shadow buffer for bochs framebuffer console'
- commit 4342f31
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/fb-helper: Instanciate shadow FB if configured in device's mode_config'
- commit 1c54ec6
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/fb-helper: Map DRM client buffer only when required'
- commit d582dc7
* Wed Sep 30 2020 tbogendoerfer@suse.de
- crypto: safexcel/aes - switch to library version of key
  expansion routine (jsc#SLE-15129).
- commit 022b6a1
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/client: Support unmapping of DRM client buffers'
- commit 2d48f2d
* Wed Sep 30 2020 ohering@suse.de
- rpm/constraints.in: recognize also kernel-source-azure (bsc#1176732)
- commit 7214bbe
* Wed Sep 30 2020 tiwai@suse.de
- Restore patch reference from SLE15-SP2 for re-backported sound commits
- commit 0201b19
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix GEN8_MCR_SELECTOR programming'
- commit affd40a
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/vbt: Fix VBT parsing for the PSR section'
- commit 87a7539
* Wed Sep 30 2020 vbabka@suse.cz
- mm/hmm: make HMM_MIRROR an implicit option (jsc#SLE-16387).
- Update config files.
- commit 47db5ca
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Lock the engine while dumping the active request'
- commit 3c8761c
* Wed Sep 30 2020 vbabka@suse.cz
- mm/hmm: allow HMM_MIRROR on all architectures with MMU
  (jsc#SLE-16387).
- Update config files.
- commit 3b4eacd
* Wed Sep 30 2020 vbabka@suse.cz
- Add references to jsc#SLE-16387
- Update
  patches.suse/mm-hmm-cleanup-the-hmm_vma_handle_pmd-stub.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-hmm-cleanup-the-hmm_vma_walk_hugetlb_entry-stub.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-hmm-don-t-abuse-pte_index-in-hmm_vma_handle_pmd.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-hmm-only-define-hmm_vma_walk_pud-if-needed.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-hmm-remove-the-mask-variable-in-hmm_vma_walk_huge.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-hmm-remove-the-page_shift-member-from-struct-hmm_.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-hmm-remove-the-unused-vma-argument-to-hmm_range_d.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/nouveau-pass-struct-nouveau_svmm-to-nouveau_range_fa.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- commit 29fcd1d
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/perf: add missing delay for OA muxes configuration'
- commit 588959a
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/perf: ensure we keep a reference on the driver'
- commit 1f7c970
* Wed Sep 30 2020 vbabka@suse.cz
- amdgpu: don't initialize range->list in amdgpu_hmm_init_range
  (jsc#SLE-16387).
- commit 2799035
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gtt: Mark the freed page table entries with scratch'
- commit 25b1b5b
* Wed Sep 30 2020 vbabka@suse.cz
- amdgpu: remove -EAGAIN handling for hmm_range_fault
  (jsc#SLE-16387).
- Update
  patches.suse/mm-hmm-remove-superfluous-arguments-from-hmm_range_r.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- commit 6dbbbd3
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gtt: Defer the free for alloc error paths'
- commit c4f36af
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Deal with machines that expose less than three QGV points'
- commit b506731
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/i915: Introduce private PAT management"'
- commit 678301e
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix memleak in runtime wakeref tracking'
- commit e2d5b4e
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/icl: whitelist PS_(DEPTH|INVOCATION)_COUNT'
- commit d8e2dad
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: whitelist PS_(DEPTH|INVOCATION)_COUNT'
- commit 1b36ae2
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: fix whitelist selftests with readonly registers'
- commit 626f865
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix the TBT AUX power well enabling'
- commit 60b7e60
* Wed Sep 30 2020 vbabka@suse.cz
- Add references to SLE-16387 to already backported patches.
- Update
  patches.suse/mm-hmm-a-few-more-C-style-and-comment-clean-ups.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-hmm-comment-on-VM_FAULT_RETRY-semantics-in-handle.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-hmm-merge-hmm_range_snapshot-into-hmm_range_fault.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update patches.suse/mm-hmm-remove-hmm_range-vma.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-hmm-remove-hugetlbfs-check-in-hmm_vma_walk_pmd.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-hmm-replace-hmm_update-with-mmu_notifier_range.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/mm-hmm-replace-the-block-argument-to-hmm_range_fault.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- Update
  patches.suse/nouveau-return-EBUSY-when-hmm_range_wait_until_valid.patch
  (jsc#SLE-15176, jsc#SLE-16387).
- commit 572a983
* Wed Sep 30 2020 tbogendoerfer@suse.de
- crypto: ctr - add helper for performing a CTR encryption walk
  (jsc#SLE-15129).
- commit caba77c
* Wed Sep 30 2020 yousaf.kaukab@suse.com
- PCI: tegra: Use pci_host_probe() to register host (jsc#SLE-15847).
- PCI: tegra: Remove PLL power supplies (jsc#SLE-15847).
- mmc: sdhci-tegra: Add comment for PADCALIB and PAD_CONTROL NVQUIRKS (jsc#SLE-15847).
- PCI: tegra: Fix runtime PM imbalance on error (jsc#SLE-15847).
- PCI: tegra194: Fix runtime PM imbalance on error (jsc#SLE-15847).
- PCI: tegra: Fix reporting GPIO error value (jsc#SLE-15847).
- PCI: Check for platform_get_irq() failure consistently (jsc#SLE-15847).
- sdhci: tegra: Avoid reading autocal timeout values when not applicable (jsc#SLE-15847).
- spi: tegra114: Fix runtime PM imbalance on error (jsc#SLE-15847).
- PCI: tegra: Use pci_parse_request_of_pci_ranges() (jsc#SLE-15847).
- PCI: tegra: Print -EPROBE_DEFER error message at debug level (jsc#SLE-15847).
- PCI: tegra: Add support for PCIe endpoint mode in Tegra194 (jsc#SLE-15847).
- sdhci: tegra: Enable MMC_CAP_WAIT_WHILE_BUSY host capability
  (jsc#SLE-15847).
- sdhci: tegra: Implement Tegra specific set_timeout callback
  (jsc#SLE-15847).
- spi: tegra114: use true,false for bool variable (jsc#SLE-15847).
- spi: tegra114: Use dma_request_chan() directly for channel
  request (jsc#SLE-15847).
- commit 7fd5e12
* Wed Sep 30 2020 oneukum@suse.com
- crypto: qat - fallback for xts with 192 bit keys
  (jsc#SLE-14454).
- commit ac83642
* Wed Sep 30 2020 oneukum@suse.com
- crypto: qat - remove unused field in skcipher ctx
  (jsc#SLE14454).
- commit 318ce92
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Lift intel_engines_resume() to callers'
- commit 5d99a79
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Only recover active engines'
- commit 0abeea0
* Wed Sep 30 2020 oneukum@suse.com
- crypto: qat - validate xts key (jsc#SLE-14454).
- crypto: qat - allow xts requests not multiple of block
  (jsc#SLE-14454).
- crypto: qat - update timeout logic in put admin msg
  (jsc#SLE-14454).
- commit 1cf010e
* Wed Sep 30 2020 tbogendoerfer@suse.de
- crypto: arm64/aes-ce-cipher - use AES library as fallback
  (jsc#SLE-15129).
- crypto: aes - move sync ctr(aes) to AES library and generic
  helper (jsc#SLE-15129).
- crypto: arm64/aes-ce - switch to library version of key
  expansion routine (jsc#SLE-15129).
- crypto: arm64/aes-neonbs - switch to library version of key
  expansion routine (jsc#SLE-15129).
- crypto: arm64/aes-ccm - switch to AES library (jsc#SLE-15129).
- commit d407931
* Wed Sep 30 2020 vbabka@suse.cz
- mm/hmm: remove the legacy hmm_pfn_* APIs (jsc#SLE-16387).
- commit be4d4a4
* Wed Sep 30 2020 yousaf.kaukab@suse.com
- irq/irqdomain: Update __irq_domain_alloc_fwnode() function
  documentation (jsc#SLE-15847).
- commit 16526ea
* Wed Sep 30 2020 tbogendoerfer@suse.de
- crypto: s390/aes - fix name clash after AES library refactor
  (jsc#SLE-15129).
- crypto: arm64/ghash - switch to AES library (jsc#SLE-15129).
- commit a0f23df
* Wed Sep 30 2020 oneukum@suse.com
- crypto: qat - send admin messages to set of AEs (jsc#SLE-14454).
- commit e438b81
* Wed Sep 30 2020 oneukum@suse.com
- crypto: qat - update fw init admin msg (jsc#SLE14454).
- commit 6fd86fe
* Wed Sep 30 2020 oneukum@suse.com
- crypto: qat - remove packed attribute in etr structs
  (jsc#SLE-14454).
- commit f86be87
* Wed Sep 30 2020 oneukum@suse.com
- crypto: qat - replace user types with kernel ABI __u types
  (jsc#SLE-14454).
- commit 5431470
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix various tracepoints for gen2'
- commit 836ffb7
* Wed Sep 30 2020 glin@suse.com
- bpf: Support bitfield read access in btf_struct_access
  (bsc#1177028).
- bpf: Add enum support to btf_ctx_access() (bsc#1177028).
  Refresh patches.suse/bpf-Do-not-allow-btf_ctx_access-with-__int128-types.patch
- bpf: Avoid storing modifier to info->btf_id (bsc#1177028).
- bpf: Save PTR_TO_BTF_ID register state when spilling to stack
  (bsc#1177028).
- bpf: Support replacing cgroup-bpf program in MULTI mode (bsc#1177028).
  Refresh patches.suse/bpf-Initialize-storage-pointers-to-NULL-to-prevent-f.patch
- bpf: Remove unused new_flags in hierarchy_allows_attach()
  (bsc#1177028).
- bpf: Simplify __cgroup_bpf_attach (bsc#1177028).
  Refresh patches.suse/bpf-Initialize-storage-pointers-to-NULL-to-prevent-f.patch
- xdp: Make cpumap flush_list common for all map instances
  (bsc#1177028).
- xdp: Make devmap flush_list common for all map instances (bsc#1177028).
  Refresh patches.suse/devmap-Use-bpf_map_area_alloc-for-allocating-hash-bu.patch
- xdp: Fix graze->grace type-o in cpumap comments (bsc#1177028).
- xdp: Simplify cpumap cleanup (bsc#1177028).
- xdp: Simplify devmap cleanup (bsc#1177028).
- bpf: Remove unnecessary assertion on fp_old (bsc#1177028).
- bpf, xdp: Start using the BPF dispatcher for XDP (bsc#1177028).
- bpf: Introduce BPF dispatcher (bsc#1177028).
- bpf: Move trampoline JIT image allocation to a function
  (bsc#1177028).
- bpf, x86, arm64: Enable jit by default when not built as always-on (bsc#1177028).
  Update config files.
- bpf: Emit audit messages upon successful prog load and unload
  (bsc#1177028).
- commit 219add7
* Wed Sep 30 2020 oneukum@suse.com
- crypto: qat - replace user types with kernel u types
  (jsc#SLE-14454).
- commit 52daf14
* Wed Sep 30 2020 jroedel@suse.de
- kABI: Fix kABI for 12856e7acde4 PCI/IOV: Mark VFs as not
  implementing PCI_COMMAND_MEMORY (bsc#1176979).
- commit e374ebb
* Wed Sep 30 2020 oneukum@suse.com
- crypto: qat - convert to SPDX License Identifiers
  (jsc#SLE-14454).
- commit 3565458
* Wed Sep 30 2020 jdelvare@suse.de
- Enable the amd_energy driver (jsc#SLE-14262)
  This is a new driver for energy monitoring of the AMD Family 17h and
  future processors, based on RAPL MSR.
- commit f02ec70
* Wed Sep 30 2020 jdelvare@suse.de
- hwmon: (amd_energy) match for supported models (jsc#SLE-14262).
- hwmon: (amd_energy) Missing platform_driver_unregister()
  on error in amd_energy_init() (jsc#SLE-14262).
- hwmon: Add amd_energy driver to report energy counters
  (jsc#SLE-14262).
- commit 82ef4ee
* Wed Sep 30 2020 oneukum@suse.com
- crypto: qat - simplify the qat_crypto function (jsc#SLE-14454).
- commit 5a62d41
* Wed Sep 30 2020 yousaf.kaukab@suse.com
- irqchip/gic-v2, v3: Drop extra IRQ_NOAUTOEN setting for (E)PPIs
  (jsc#SLE-15847).
- irqdomain/debugfs: Use PAs to generate fwnode names
  (jsc#SLE-15847).
- gpio/ixp4xx: Register the base PA instead of its VA in fwnode
  (jsc#SLE-15847).
- irqchip/ixp4xx: Register the base PA instead of its VA in fwnode
  (jsc#SLE-15847).
- irqchip/gic-v2m: Register the frame's PA instead of its VA in
  fwnode (jsc#SLE-15847).
- irqchip/gic: Register the distributor's PA instead of its VA
  in fwnode (jsc#SLE-15847).
- irqchip/gic-v3-its: Register the ITS' PA instead of its VA in
  fwnode (jsc#SLE-15847).
- irqchip/gic-v3: Register the distributor's PA instead of its
  VA in fwnode (jsc#SLE-15847).
- commit 077e154
* Wed Sep 30 2020 oneukum@suse.com
- crypto: qat - spelling s/Decrytp/Decrypt/ (jsc#SLE-14454).
- commit 4580abc
* Wed Sep 30 2020 glin@suse.com
- ftrace: Return the first found result in lookup_rec()
  (bsc#1177028).
- bpf: Make BPF trampoline use register_ftrace_direct() API
  (bsc#1177028).
- ftrace: Add helper find_direct_entry() to consolidate code
  (bsc#1177028).
- ftrace: Add another check for match in register_ftrace_direct()
  (bsc#1177028).
- ftrace: Fix accounting bug with direct->count in
  register_ftrace_direct() (bsc#1177028).
- ftrace/samples: Add a sample module that implements
  modify_ftrace_direct() (bsc#1177028).
- ftrace: Add modify_ftrace_direct() (bsc#1177028).
- ftrace/x86: Add a counter to test function_graph with direct
  (bsc#1177028).
- ftrace/x86: Add register_ftrace_direct() for custom trampolines (bsc#1177028).
  Update config files.
- ftrace/selftests: Update the direct call selftests to test
  two direct calls (bsc#1177028).
- ftrace: Add another example of register_ftrace_direct() use case
  (bsc#1177028).
- ftrace/selftest: Add tests to test register_ftrace_direct()
  (bsc#1177028).
- ftrace: Add sample module that uses register_ftrace_direct()
  (bsc#1177028).
- ftrace: Add ftrace_find_direct_func() (bsc#1177028).
- ftrace: Add register_ftrace_direct() (bsc#1177028).
- ftrace: Separate out functionality from ftrace_location_range()
  (bsc#1177028).
- ftrace: Separate out the copying of a ftrace_hash from
  __ftrace_hash_move() (bsc#1177028).
- commit 6f27637
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/perf: fix ICL perf register offsets'
- commit 8771b48
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Disable SAMPLER_STATE prefetching on all Gen11 steppings.'
- commit c9d75ae
* Wed Sep 30 2020 dwagner@suse.de
- Drop patches.suse/scsi-qla2xxx-Handle-incorrect-entry_type-entries.patch
  The patch contains a bug which prevents device discovery. Drop it until
  we have a proper fix from upstream.
- commit d02a6d5
* Wed Sep 30 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Keep rings pinned while the context is active'
- commit 56d61dd
* Wed Sep 30 2020 hare@suse.de
- block: restore a specific error code in bdev_del_partition
  (bsc#1177095).
- commit 625aba8
* Wed Sep 30 2020 lduncan@suse.com
- scsi: libcxgbi: Remove unnecessary NULL checks for 'tdata'
  pointer (bsc#1177020 jre#sle-15121).
- scsi: cxgb4i: Remove an unnecessary NULL check for 'cconn'
  pointer (bsc#1177020 jre#sle-15121).
- scsi: cxgb4i: Clean up a debug printk (bsc#1177020
  jre#sle-15121).
- scsi: libcxgbi: fix NULL pointer dereference in
  cxgbi_device_destroy() (bsc#1177020 jre#sle-15121).
- scsi: libcxgbi: remove unused function to stop warning
  (bsc#1177020 jre#sle-15121).
- commit 6767872
* Tue Sep 29 2020 tiwai@suse.de
- Delete a doubly applied batman-adv patch
- commit edcea1c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/fbdev: Restore physical addresses for fb_mmap() (bsc#1152489)
- commit 0547af2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: make pool objects read-only (bsc#1152489)
- commit fd1ec4d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Protect request peeking with RCU (bsc#1152489)
- commit 8d90cb2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/userptr: Try to acquire the page lock around (bsc#1152489)
- commit 275dd88
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/pmu: "Frequency" is reported as accumulated cycles (bsc#1152489)
- commit 6ec3728
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Preload LUTs if the hw isn't currently using them (bsc#1152489)
- commit 6c4ce64
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Don't oops in dumb_create ioctl if we have no crtcs (bsc#1152489)
- commit 1cefb82
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/amd/display: enable S/G for RAVEN chip" (bsc#1152472)
- commit 5a169cb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: disable gfxoff on original raven (bsc#1152472)
- commit 46fa061
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: disable gfxoff when using register read interface (bsc#1152472)
- commit ab352c0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: correct fine grained dpm force level setting (bsc#1152472)
- commit 8775512
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: issue no PPSMC_MSG_GetCurrPkgPwr on unsupported (bsc#1152472)
- commit 51a646b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: remove experimental flag for Navi14 (bsc#1152472)
- commit bbd5497
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix null pointer deref in firmware header printing (bsc#1152472)
- commit 9405872
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/sun4i: tcon: Set min division of TCON0_DCLK to 1. (bsc#1152472)
- commit 1cb1da2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: MOCS table update (bsc#1152489)
- commit 9a0f681
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/i915/ehl: Update MOCS table for EHL" (bsc#1152489)
- commit 333aadd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gvt: fix dropping obj reference twice (bsc#1152489)
- commit 38d7e5a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: update rawclk also on resume (bsc#1152489)
- commit 3403b2f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/cmdparser: Fix jump whitelist clearing (bsc#1152489)
- commit 21501fb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gen8+: Add RC6 CTX corruption WA (bsc#1152489)
- commit 569e932
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Lower RM timeout to avoid DSI hard hangs (bsc#1152489)
- commit b736830
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/cmdparser: Ignore Length operands during command matching (bsc#1152489)
- commit 7d8c6b1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/cmdparser: Add support for backward jumps (bsc#1152489)
- commit 28b8c88
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/cmdparser: Use explicit goto for error paths (bsc#1152489)
- commit ee21942
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add gen9 BCS cmdparsing (bsc#1152489)
- commit 00e4185
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Allow parsing of unsized batches (bsc#1152489)
- commit ab44254
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Support ro ppgtt mapped cmdparser shadow buffers (bsc#1152489)
- commit e0d67a0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add support for mandatory cmdparsing (bsc#1152489)
- commit 0b58d68
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Remove Master tables from cmdparser (bsc#1152489)
- commit b0c3d33
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Disable Secure Batches for gen6+ (bsc#1152489)
- commit 5236b46
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Rename gen7 cmdparser tables (bsc#1152489)
- commit 280fef8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: fix si_enable_smc_cac() failed issue (bsc#1152472)
- commit 6e75df4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/renoir: move gfxoff handling into gfx9 module (bsc#1152472)
- commit 7a17358
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add warning for GRBM 1-cycle delay issue in gfx9 (bsc#1152472)
- commit d0e7818
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add dummy read by engines for some GCVM status registers (bsc#1152472)
- commit 9a432e9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: register gpu instance before fan boost feature enablment (bsc#1152472)
- commit 141751d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/swSMU: fix smu workload bit map error (bsc#1152472)
- commit 8966700
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add navi14 PCI ID (bsc#1152472)
- commit fb7e70f
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/amd/display: setting the DIG_MODE to the correct value." (bsc#1152472)
- commit 2098b6f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add ENGINE_ID_DIGD condition check for Navi14 (bsc#1152472)
- commit 132d8b3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: dont schedule jobs while in reset (bsc#1152472)
- commit f469074
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/arcturus: properly set BANK_SELECT and FRAGMENT_SIZE (bsc#1152472)
- commit f7fd8ff
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/dp: Do not switch aux to TBT mode for non-TC ports (bsc#1152489)
- commit c287c7d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Avoid HPD poll detect triggering a new detect cycle (bsc#1152489)
- commit 28eb9c0
* Tue Sep 29 2020 msuchanek@suse.de
- Rename patches to the same name as in SLE15-SP3.
- commit b538695
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/shmem: Add docbook comments for drm_gem_shmem_object madvise (bsc#1152472)
- commit 5654b7b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/atomic: fix self-refresh helpers crtc state dereference (bsc#1152472)
- commit d2cc543
* Tue Sep 29 2020 tzimmermann@suse.de
- fbdev: c2p: Fix link failure on non-inlining (bsc#1152472)
- commit ad93da2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable -msse2 for GCC 7.1+ users (bsc#1152472)
- commit b224e93
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix stack alignment ABI mismatch for GCC 7.1+ (bsc#1152472)
- commit 299096c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix stack alignment ABI mismatch for Clang (bsc#1152472)
- commit 1163295
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: Fix EEH during kexec (bsc#1152472)
- commit ce1fc4b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gmc10: properly set BANK_SELECT and FRAGMENT_SIZE (bsc#1152472)
- commit 633c231
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay/vega10: allow undervolting in p7 (bsc#1152472)
- commit 8908e45
* Tue Sep 29 2020 tzimmermann@suse.de
- dc.c:use kzalloc without test (bsc#1152472)
- commit ae9aa22
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: setting the DIG_MODE to the correct value. (bsc#1152472)
- commit 297809e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Passive DP->HDMI dongle detection fix (bsc#1152472)
- commit a00e651
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add 50us buffer as WA for pstate switch in active (bsc#1152472)
- commit 14d1d0f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Allow inverted gamma (bsc#1152472)
- commit 99b2db5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: do not synchronize "drr" displays (bsc#1152472)
- commit bb8fa52
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: If amdgpu_ib_schedule fails return back the error. (bsc#1152472)
- commit c2773dc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/sched: Set error to s_fence if HW job submission failed. (bsc#1152472)
- commit 7c04705
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: update gfx golden settings for navi12 (bsc#1152472)
- commit 5f72c5b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: update gfx golden settings for navi14 (bsc#1152472)
- commit ea3d401
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Change Navi14's DWB flag to 1 (bsc#1152472)
- commit bfb72c7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/sdma5: do not execute 0-sized IBs (v2) (bsc#1152472)
- commit fd73276
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Fix SDMA hang when performing VKexample test (bsc#1152472)
- commit 782c10e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Fix PCH reference clock for FDI on HSW/BDW (bsc#1152489)
- commit bf6e408
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Fix doc not corresponding to code (bsc#1152489)
- commit 83669ec
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Don't dereference bogus MMU pointers (bsc#1152472)
- commit 2b2703b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: fix -Wmissing-prototypes warnings (bsc#1152472)
- commit 3926321
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/v3d: Fix memory leak in v3d_submit_cl_ioctl (bsc#1152472)
- commit 59b64ed
* Tue Sep 29 2020 tzimmermann@suse.de
- panfrost: Properly undo pm_runtime_enable when deferring a probe (bsc#1152472)
- commit 366e621
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: fix dumping of iommuv2 (bsc#1152472)
- commit 85c9ce2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: reinstate MMUv1 command buffer window check (bsc#1152472)
- commit 5ea5b5f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: fix deadlock in GPU coredump (bsc#1152472)
- commit 2f8aeec
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/vce: fix allocation size in enc ring test (bsc#1152472)
- commit 0f86523
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix error handling in amdgpu_bo_list_create (bsc#1152472)
- commit d3650cf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix potential VM faults (bsc#1152472)
- commit c1e3b85
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: user pages array memory leak fix (bsc#1152472)
- commit 4b10428
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/vcn: fix allocation size in enc ring test (bsc#1152472)
- commit fcb8d2c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/uvd7: fix allocation size in enc ring test (v2) (bsc#1152472)
- commit b714584
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/uvd6: fix allocation size in enc ring test (v2) (bsc#1152472)
- commit e856ab7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/komeda: Fix typos in komeda_splitter_validate (bsc#1152489)
- commit 327ba42
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/komeda: Don't flush inactive pipes (bsc#1152489)
- commit e462ea4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Handle resetting on timeout better (bsc#1152472)
- commit c47b6ee
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Add missing GPU feature registers (bsc#1152489)
- commit 6ad20e4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ttm: fix handling in ttm_bo_add_mem_to_lru (bsc#1152489)
- commit 0c36d77
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ttm: Restore ttm prefaulting (bsc#1152489)
- commit bd95939
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ttm: fix busy reference in ttm_mem_evict_first (bsc#1152489)
- commit 537e838
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dsi: Implement reset correctly (bsc#1152489)
- commit fe02c9e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/edid: Add 6 bpc quirk for SDC panel in Lenovo G50 (bsc#1152489)
- commit 74806f4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tiny: Kconfig: Remove always-y THERMAL dep. from TINYDRM_REPAPER (bsc#1152489)
- commit 69c242b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/sdma5: fix mask value of POLL_REGMEM packet for pipe sync (bsc#1152472)
- commit a6f1fb7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Bail earlier when amdgpu.cik_/si_support is not set to 1 (bsc#1152472)
- commit 17d29cd
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/radeon: Fix EEH during kexec" (bsc#1152472)
- commit d70de84
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: fix typo in mvdd table setup (bsc#1152472)
- commit 38c2f3d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Fixup preempt-to-busy vs resubmission of a virtual request (bsc#1152489)
- commit 84d500a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/userptr: Never allow userptr into the mappable GGTT (bsc#1152489)
- commit e1b82bf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Favor last VBT child device with conflicting AUX ch/DDC pin (bsc#1152489)
- commit f1cc6c5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Refactor -EIO markup of hung requests (bsc#1152489)
- commit a6ea02f
* Tue Sep 29 2020 tzimmermann@suse.de
- xen: Stop abusing DT of_dma_configure API (bsc#1152489)
- commit 2d49c71
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: execlists->active is serialised by the tasklet (bsc#1152489)
- commit e94708b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Protect peeking at execlists->active (bsc#1152489)
- commit bc19779
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Fixup preempt-to-busy vs reset of a virtual request (bsc#1152489)
- commit 9b00561
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Only enqueue already completed requests (bsc#1152489)
- commit dc2adc0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Drop redundant list_del_init(&rq->sched.link) (bsc#1152489)
- commit 47a3115
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/cml: Add second PCH ID for CMP (bsc#1152489)
- commit ccceace
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Mark contents as dirty on a write fault (bsc#1152489)
- commit 3847539
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Prevent bonded requests from overtaking each other on (bsc#1152489)
- commit 5f86c68
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Bump skl+ max plane width to 5k for linear/x-tiled (bsc#1152489)
- commit 40ad69f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Verify the engine after acquiring the active.lock (bsc#1152489)
- commit e85b487
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Extend Haswell GT1 PSMI workaround to all (bsc#1152489)
- commit 072b7ce
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Don't mix srcu tag and negative error codes (bsc#1152489)
- commit 7f2a69f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Whitelist COMMON_SLICE_CHICKEN2 (bsc#1152489)
- commit 98477ea
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Perform GGTT restore much earlier during resume (bsc#1152489)
- commit a0f2aef
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Remove incorrect BUG_ON for schedule-out (bsc#1152489)
- commit 101a093
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: fix max_tu_symbol value (bsc#1152472)
- commit 6aa5791
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: tpo-td043mtea1: Fix SPI alias (bsc#1152489)
- commit 7357da9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: tpo-td028ttec1: Fix SPI alias (bsc#1152489)
- commit fc5adce
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: sony-acx565akm: Fix SPI alias (bsc#1152489)
- commit 08fac1f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: nec-nl8048hl11: Fix SPI alias (bsc#1152489)
- commit 2181342
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: lg-lb035q02: Fix SPI alias (bsc#1152489)
- commit 465244d
* Tue Sep 29 2020 tzimmermann@suse.de
- video/logo: do not generate unneeded logo C files (bsc#1152489)
- commit c48e6da
* Tue Sep 29 2020 tzimmermann@suse.de
- video/logo: remove unneeded *.o pattern from clean-files (bsc#1152489)
- commit 0f9878c
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/i915: Fix DP-MST crtc_mask" (bsc#1152489)
- commit c9a0e3a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Fix g4x sprite scaling stride check with GTT remapping (bsc#1152489)
- commit bd5549f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/dp: Fix dsc bpp calculations, v5. (bsc#1152489)
- commit 9e37e83
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tilcdc: include linux/pinctrl/consumer.h again (bsc#1152489)
- commit 69fd920
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/omap: fix max fclk divider for omap36xx (bsc#1152472)
- commit 9b94253
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/komeda: prevent memory leak in komeda_wb_connector_add (bsc#1152489)
- commit 1ecdca1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Clear the fence pointer when writeback job signaled (bsc#1152489)
- commit 651384c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Free the writeback_job when it with an empty fb (bsc#1152489)
- commit 820278f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix dcn21 Makefile for clang (bsc#1152472)
- commit a440b68
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: hide an unused variable (bsc#1152472)
- commit eb944ba
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: display_mode_vba_21: remove uint typedef (bsc#1152472)
- commit 89a0df6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: hide another #warning (bsc#1152472)
- commit 6b57333
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: make pmu support optional, again (bsc#1152472)
- commit 3c76d73
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix multiple memory leaks in acp_hw_init (bsc#1152472)
- commit c1b9168
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: return tcc_disabled_mask to userspace (bsc#1152472)
- commit 76b1b6e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: don't increment vram lost if we are in hibernation (bsc#1152472)
- commit 7b2c06f
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/amdgpu: disable stutter mode for renoir" (bsc#1152472)
- commit d03f552
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: add sensor lock support for smu (bsc#1152472)
- commit 326ccd7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: change metrics update period from 1ms to 100ms (bsc#1152472)
- commit b5aaa29
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: revert "disable bulk moves for now" (bsc#1152472)
- commit 2b6f70c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: prevent memory leak (bsc#1152489)
- commit a2bc2a2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: add support for wks firmware loading (bsc#1152489)
- commit d0a5042
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/display: include slab.h in dcn21_resource.c (bsc#1152489)
- commit 5c72bb3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/display: fix 64 bit divide (bsc#1152489)
- commit e69d6a3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: flag navi12 and 14 as experimental for 5.4 (bsc#1152489)
- commit 05cbd47
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add navi12 pci id (bsc#1152489)
- commit f17ee88
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add navi14 PCI ID for work station SKU (bsc#1152489)
- commit 8998b87
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Swap trap temporary registers in gfx10 trap handler (bsc#1152489)
- commit 41f6186
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: implement sysfs for getting dpm clock (bsc#1152489)
- commit 08e072c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Restore backlight brightness after system resume (bsc#1152489)
- commit 7ef2658
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Implement voltage limitation for dali (bsc#1152489)
- commit 099126c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add Asic ID for Dali (bsc#1152489)
- commit 25617d3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Fix KFD-related kernel oops on Hawaii (bsc#1152489)
- commit 7a5d538
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/amdgpu: power up sdma engine when S3 resume back (bsc#1152489)
- commit cd8b517
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Check for valid number of registers to read (bsc#1152489)
- commit c09503f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: Bail earlier when radeon.cik_/si_support=0 is passed (bsc#1152489)
- commit 81c8b77
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add missing HBM support and raise Vega20's uclk. (bsc#1152489)
- commit 30395a2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: dce11.x /dce12 update formula input (bsc#1152489)
- commit ae9d1e4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: remove program of lbpw for renoir (bsc#1152489)
- commit 5933cab
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Remove clock gating restore. (bsc#1152489)
- commit 08bb2c0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Add smu lock around in pp_smu_i2c_bus_access (bsc#1152489)
- commit f08928a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: update renoir_ip_offset.h (bsc#1152489)
- commit 883227c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: disable stutter mode for renoir (bsc#1152489)
- commit 370f26f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add stereo mux and dig programming calls for dcn21 (bsc#1152489)
- commit 5246ba7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Prevent race when handling page fault (bsc#1152489)
- commit bd6ada9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Remove NULL checks for regulator (bsc#1152489)
- commit 3a674d0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Fix regulator_get_optional() misuse (bsc#1152489)
- commit 95225e0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Measure Self Refresh Entry/Exit times to avoid thrashing (bsc#1152489)
- commit 48001bb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Fix kerneldoc and remove unused struct member in self_refresh (bsc#1152489)
- commit a94f99d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/atomic: Rename crtc_state->pageflip_flags to async_flip (bsc#1152489)
- commit 48a2e7c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/atomic: Reject FLIP_ASYNC unconditionally (bsc#1152489)
- commit 403b73e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/atomic: Take the atomic toys away from X (bsc#1152489)
- commit f8046ff
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/kms: Duct-tape for mode object lifetime checks (bsc#1152472)
- commit 99ec630
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/bridge: adv7511: Attach to DSI host at probe time" (bsc#1152489)
- commit 80e3de0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: untag user pointers in radeon_gem_userptr_ioctl (bsc#1152489)
- commit 866ff9c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: untag user pointers (bsc#1152489)
- commit 93f0086
* Tue Sep 29 2020 tzimmermann@suse.de
- i2c: replace i2c_new_secondary_device with an ERR_PTR variant (bsc#1152489)
- commit 2c03fe0
* Tue Sep 29 2020 tzimmermann@suse.de
- drivers/gpu/drm/via: convert put_page() to put_user_page*() (bsc#1152489)
- commit 616d76c
* Tue Sep 29 2020 tzimmermann@suse.de
- backlight: pwm_bl: Set scale type for brightness curves specified in (bsc#1152489)
- commit 9168251
* Tue Sep 29 2020 tzimmermann@suse.de
- backlight: pwm_bl: Set scale type for CIE 1931 curves (bsc#1152489)
- commit d5b30d4
* Tue Sep 29 2020 tzimmermann@suse.de
- backlight: Expose brightness curve type through sysfs (bsc#1152489)
- commit 0936955
* Tue Sep 29 2020 tzimmermann@suse.de
- backlight: gpio-backlight: Correct initial power state handling (bsc#1152489)
- commit e242b4b
* Tue Sep 29 2020 tzimmermann@suse.de
- video: backlight: tosa_lcd: drop check because (bsc#1152489)
- commit 0535dad
* Tue Sep 29 2020 tzimmermann@suse.de
- video: backlight: Drop default m for {LCD,BACKLIGHT_CLASS_DEVICE} (bsc#1152489)
- commit ff61f9b
* Tue Sep 29 2020 tzimmermann@suse.de
- backlight: lms283gf05: Fix a typo in the description passed to (bsc#1152489)
- commit 40c1175
* Tue Sep 29 2020 tzimmermann@suse.de
- backlight: lm3630a: Switch to use fwnode_property_count_uXX() (bsc#1152489)
- commit cb17358
* Tue Sep 29 2020 tzimmermann@suse.de
- backlight: rave-sp: Leave initial state and register with correct (bsc#1152489)
- commit 6e937b8
* Tue Sep 29 2020 tzimmermann@suse.de
- video/fbdev: Drop JZ4740 driver (bsc#1152489)
- commit 28a6ae0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: guard against calling an unpaired radeon_mn_unregister() (bsc#1152489)
- commit 5c43b71
* Tue Sep 29 2020 tzimmermann@suse.de
- mm: remove CONFIG_MIGRATE_VMA_HELPER (bsc#1152489)
- commit e328afa
* Tue Sep 29 2020 tzimmermann@suse.de
- mm: remove the unused MIGRATE_PFN_DEVICE flag (bsc#1152489)
- commit 006ebdf
* Tue Sep 29 2020 tzimmermann@suse.de
- nouveau: simplify nouveau_dmem_migrate_vma (bsc#1152489)
- commit 1fed516
* Tue Sep 29 2020 tzimmermann@suse.de
- nouveau: simplify nouveau_dmem_migrate_to_ram (bsc#1152489)
- commit 0bb4413
* Tue Sep 29 2020 tzimmermann@suse.de
- nouveau: remove a few function stubs (bsc#1152489)
- commit 83156ed
* Tue Sep 29 2020 tzimmermann@suse.de
- nouveau: factor out dmem fence completion (bsc#1152489)
- commit 334475f
* Tue Sep 29 2020 tzimmermann@suse.de
- nouveau: factor out device memory address calculation (bsc#1152489)
- commit 7bf0a53
* Tue Sep 29 2020 tzimmermann@suse.de
- nouveau: reset dma_nr in nouveau_dmem_migrate_alloc_and_copy (bsc#1152489)
- commit 673268a
* Tue Sep 29 2020 tzimmermann@suse.de
- mm: turn migrate_vma upside down (bsc#1152489)
- commit 6ae5d0a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: use mmu_notifier_put (bsc#1152489)
- commit b1c5e0f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: fix a use after free race with mmu_notifer unregister (bsc#1152489)
- commit 9066e76
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: use mmu_notifier_get/put for struct radeon_mn (bsc#1152489)
- commit 50a6d26
* Tue Sep 29 2020 tzimmermann@suse.de
- hmm: use mmu_notifier_get/put for 'struct hmm' (bsc#1152489)
- commit bdacf22
* Tue Sep 29 2020 tzimmermann@suse.de
- mm/hmm: make HMM_MIRROR an implicit option (bsc#1152489)
- commit d68df81
* Tue Sep 29 2020 tzimmermann@suse.de
- mm/hmm: remove the page_shift member from struct hmm_range (bsc#1152489)
- commit d1494b6
* Tue Sep 29 2020 tzimmermann@suse.de
- nouveau: pass struct nouveau_svmm to nouveau_range_fault (bsc#1152489)
- commit 7f805fc
* Tue Sep 29 2020 tzimmermann@suse.de
- amdgpu: don't initialize range->list in amdgpu_hmm_init_range (bsc#1152489)
- commit 0aabe72
* Tue Sep 29 2020 tzimmermann@suse.de
- amdgpu: remove -EAGAIN handling for hmm_range_fault (bsc#1152489)
- commit a3a4dd6
* Tue Sep 29 2020 tzimmermann@suse.de
- mm/hmm: remove hmm_range vma (bsc#1152489)
- commit 7a11310
* Tue Sep 29 2020 tzimmermann@suse.de
- mm/hmm: replace the block argument to hmm_range_fault with a flags (bsc#1152489)
- commit 9056209
* Tue Sep 29 2020 tzimmermann@suse.de
- mm/hmm: replace hmm_update with mmu_notifier_range (bsc#1152489)
- commit 0813cd7
* Tue Sep 29 2020 tzimmermann@suse.de
- mm/hmm: remove the legacy hmm_pfn_* APIs (bsc#1152489)
- commit 09854af
* Tue Sep 29 2020 tzimmermann@suse.de
- nouveau: return -EBUSY when hmm_range_wait_until_valid fails (bsc#1152489)
- commit 30d929c
* Tue Sep 29 2020 tzimmermann@suse.de
- kbuild: change *FLAGS_<basetarget>.o to take the path relative to (bsc#1152489)
- commit 691ec88
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/bar/gm20b: Avoid BAR1 teardown during init (bsc#1152472)
- commit b310a01
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: Fix ordering between TTM and GEM release (bsc#1152472)
- commit 2f4b7fa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/prime: Extend DMA reservation object lock (bsc#1152472)
- commit 0852645
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: Fix fallout from reservation object rework (bsc#1152472)
- commit bd81856
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/nv50-: Don't create MSTMs for eDP connectors (bsc#1152472)
- commit 3b6d507
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use NOEVICT for first pass on attemping to pin a GGTT mmap (bsc#1152489)
- commit 049a8de
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: to make vgpu ppgtt notificaiton as atomic operation (bsc#1152489)
- commit 17970c8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Flush the existing fence before GGTT read/write (bsc#1152489)
- commit 1942967
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Hold irq-off for the entire fake lock period (bsc#1152489)
- commit f64469b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gvt: update RING_START reg of vGPU when the context is (bsc#1152489)
- commit 066dca6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gvt: update vgpu workload head pointer correctly (bsc#1152489)
- commit 6bf208b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mcde: Fix DSI transfers (bsc#1152472)
- commit 5d556bd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Remove unnecessary hwaccess_lock spin_lock (bsc#1152489)
- commit 4dbc1eb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Flush and disable address space when freeing page (bsc#1152489)
- commit c0535b3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Add cache/TLB flush before switching address space (bsc#1152489)
- commit 5e9b7dd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Split mmu_hw_do_operation into locked and unlocked (bsc#1152489)
- commit 7e5393c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Rework page table flushing and runtime PM interaction (bsc#1152489)
- commit 87df48f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Remove unnecessary mmu->lock mutex (bsc#1152489)
- commit d931c92
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Hold runtime PM reference until jobs complete (bsc#1152489)
- commit 35bab67
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Rework runtime PM initialization (bsc#1152489)
- commit 71c6c04
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Use mutex_trylock in panfrost_gem_purge (bsc#1152489)
- commit e4bfd0b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/shmem: Use mutex_trylock in drm_gem_shmem_purge (bsc#1152489)
- commit eef99c9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/shmem: Do dma_unmap_sg before purging pages (bsc#1152489)
- commit b1e2e6e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Fix possible suspend in panfrost_remove (bsc#1152489)
- commit 7f83196
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Add missing check for pfdev->regulator (bsc#1152489)
- commit fb99509
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: Use the correct dma_sync calls harder (bsc#1152489)
- commit a25a5aa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: remove unlikely() from WARN_ON() conditions (bsc#1152489)
- commit c0fdd4c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dsi: Fix return value check for clk_get_parent (bsc#1152489)
- commit bfa307d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: add atomic traces (bsc#1152489)
- commit 972691d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dpu: async commit support (bsc#1152489)
- commit cf8282b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: async commit support (bsc#1152489)
- commit 9f89adb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: split power control from prepare/complete_commit (bsc#1152489)
- commit 71bf5bd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: add kms->flush_commit() (bsc#1152489)
- commit dae5d58
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: convert kms->complete_commit() to crtc_mask (bsc#1152489)
- commit 0a717b5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: add kms->wait_flush() (bsc#1152489)
- commit 7ace3ac
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dpu: handle_frame_done() from vblank irq (bsc#1152489)
- commit 98a3520
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dpu: add real wait_for_commit_done() (bsc#1152489)
- commit 3f48272
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dpu: unwind async commit handling (bsc#1152489)
- commit 3c352ef
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dpu: remove unused arg (bsc#1152489)
- commit 28ba4fb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dpu: remove some impossible error checking (bsc#1152489)
- commit 9189873
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dpu: add rotation property (bsc#1152489)
- commit cc79d7a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: Remove Kconfig default (bsc#1152489)
- commit ab000d0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dpu: remove stray "\n" (bsc#1152489)
- commit 37de023
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dpu: fix "frame done" timeouts (bsc#1152489)
- commit 976bde2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: Use struct_size() helper (bsc#1152489)
- commit 6704644
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: Use generic bulk clock function (bsc#1152489)
- commit d8179f2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/mdp5: Find correct node for creating gem address space (bsc#1152489)
- commit 1df2115
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/phy/dsi_phy: silence -EPROBE_DEFER warnings (bsc#1152489)
- commit 7c15c35
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/a6xx: add missing MODULE_FIRMWARE() (bsc#1152489)
- commit 87cdb5e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/mdp5: Add msm8998 support (bsc#1152489)
- commit 3b45b27
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dpu: remove dpu_mdss:hwversion (bsc#1152489)
- commit 9eaf06a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: Transition console to msm framebuffer (bsc#1152489)
- commit b0684f1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/hdmi: Convert to use GPIO descriptors (bsc#1152489)
- commit dd249b8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dpu: Drop unused GPIO code (bsc#1152489)
- commit 0350234
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/dsi: Drop unused GPIO includes (bsc#1152489)
- commit f98ff71
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm/mdp4: Drop unused GPIO include (bsc#1152489)
- commit 6592a1c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: drop use of drmP.h (bsc#1152489)
- commit 7cde3c1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Move null pointer dereference check (bsc#1152489)
- commit 2ba22bd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Fix undefined dm_ip_block for navi12 (bsc#1152489)
- commit 8590c11
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix no interrupt issue for renoir emu (v2) (bsc#1152489)
- commit 28ded89
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: update IH_CHICKEN in oss 4.0 IP header for VG/RV series (bsc#1152489)
- commit 92f0918
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: SMU_MSG_OverridePcieParameters is unsupport for (bsc#1152489)
- commit 615755e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Handle job is NULL use case in amdgpu_device_gpu_recover (bsc#1152489)
- commit ea70264
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Enable DC on Renoir (bsc#1152489)
- commit d3024c2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add DCN2.1 changes to DML (bsc#1152489)
- commit f187b21
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Correct order of RV family clk managers for Renoir (bsc#1152489)
- commit 0aba4d4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add Renoir to kconfig (bsc#1152489)
- commit d0c17a4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: build dcn21 blocks (bsc#1152489)
- commit ea7513b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add dcn21 core DC changes (bsc#1152489)
- commit cb3624b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add dal_asic_id for renoir (bsc#1152489)
- commit 258b8f0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: call update_bw_bounding_box (bsc#1152489)
- commit 7d58494
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Handle Renoir in amdgpu_dm (v2) (bsc#1152489)
- commit 84583c6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Handle Renoir in DC (bsc#1152489)
- commit fe6007d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Fix register names (bsc#1152489)
- commit 977f9a0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add Renoir DML (bsc#1152489)
- commit 94e3c39
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add Renoir GPIO (bsc#1152489)
- commit 369309a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add Renoir resource (v2) (bsc#1152489)
- commit 4cf7726
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add Renoir clock manager (bsc#1152489)
- commit 7b16ee2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add Renoir Hubbub (v2) (bsc#1152489)
- commit 366098a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add Renoir hubbub registers list (bsc#1152489)
- commit 5089598
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add hubp block for Renoir (v2) (bsc#1152489)
- commit b0bb92a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add Renoir irq_services (v2) (bsc#1152489)
- commit a1539cc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add pp_smu functions for Renoir (bsc#1152489)
- commit 3573654
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add Renoir hw_seq register list (bsc#1152489)
- commit 8adf6ae
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add Renoir clock registers list (bsc#1152489)
- commit 2f659d9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add Renoir registers (v3) (bsc#1152489)
- commit c5c3a82
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: add the interface for getting ultimate frequency (bsc#1152489)
- commit 3d07cac
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: enable populate DPM clocks table for swSMU APU (bsc#1152489)
- commit 14bad50
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: regards the APU always enable the dpm feature mask (bsc#1152489)
- commit 72413c5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Initialize and update SDMA power gating (bsc#1152489)
- commit 8e21192
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/psp: keep TMR in visible vram region for SRIOV (bsc#1152489)
- commit 7d2fb3a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: keep the stolen memory in visible vram region (bsc#1152489)
- commit 3d106a3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix spelling mistake "jumpimng" -> "jumping" (bsc#1152489)
- commit 59a8870
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/virtual_dce: drop error message in hw_init (bsc#1152489)
- commit 9b7af71
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/si: fix ASIC tests (bsc#1152489)
- commit eb73c34
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/amdgpu: hide voltage and power sensors on SI and KV parts (bsc#1152489)
- commit 5140377
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: introduce vram lost for reset (v2) (bsc#1152489)
- commit 753754d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: enable jpeg powergating for navi1x (bsc#1152489)
- commit f1c9df6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable athub powergating for navi12 (bsc#1152489)
- commit 7acb6fc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable vcn powergating for navi12 (bsc#1152489)
- commit 65d19ca
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: correct in_suspend setting for navi series (bsc#1152489)
- commit 6aa1662
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd: remove meaningless descending into amd/amdkfd/ (bsc#1152489)
- commit c79148c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: remove unused function setFieldWithMask (bsc#1152489)
- commit 56a75f3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: correct the pp_feature output on Arcturus (bsc#1152489)
- commit af7225a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Vega20 SMU I2C HW engine controller. (bsc#1152489)
- commit f479565
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: Add interface to lock SMU HW I2C. (bsc#1152489)
- commit 1de258a
* Tue Sep 29 2020 mhocko@suse.com
- Update config files - enable FORTIFY_SOURCE (jsc#SLE-11598)
- commit 4339218
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd: Import smuio_11_0 headers for EEPROM access on Vega20 (bsc#1152489)
- commit 7551b68
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Add RAS EEPROM table. (bsc#1152489)
- commit ef260e7
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/amdgpu: free up the first paging queue v2" (bsc#1152489)
- commit 82f3fa2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/display: fix build error without (bsc#1152489)
- commit 91e3fa9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: Fix an off by one in navi10_get_smu_msg_index() (bsc#1152489)
- commit 4416d3c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Fix error message (bsc#1152489)
- commit 9363a0f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add dummy read for some GCVM status registers (bsc#1152489)
- commit 3bfa476
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/exynos: drop use of drmP.h (bsc#1152489)
- commit 93c87a1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.48 (bsc#1152489)
- commit 73db657
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: flicking observed while installing driver on Navi10 (bsc#1152489)
- commit 4d49991
* Tue Sep 29 2020 mhocko@suse.com
- Update config files.
  Drop config leftovers after patches.suse/netfilter-nf_tables-make-sets-built-in.patch
- commit b670cd3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Properly read LVTMA_PWRSEQ_CNTL (bsc#1152489)
- commit 548ab67
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: revert wait in pipelock (bsc#1152489)
- commit 691de2d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Use res_cap to acquire i2c instead of pipe count (bsc#1152489)
- commit 3c1e179
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Expose OTG_V_TOTAL_MID for HW Diags (bsc#1152489)
- commit 6a2a16f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix DML not calculating delivery time (bsc#1152489)
- commit 3d9bfba
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: MST topology debugfs (bsc#1152489)
- commit 6b43116
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: set av_mute in hw_init for HDMI (bsc#1152489)
- commit 73acd5d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add Logging for Gamma Related information (bsc#1152489)
- commit 3f2adfa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Enable HW rotation (bsc#1152489)
- commit a5cf3ec
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add Cursor Degamma logic for DCN2 (bsc#1152489)
- commit 41d51f8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix odm validation (bsc#1152489)
- commit 360371c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix odm stream release (bsc#1152489)
- commit b3f1f12
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix dcn20 odm dpp programming (bsc#1152489)
- commit 86cbf80
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Fix number of slices not being checked for dsc (bsc#1152489)
- commit ec6df3c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix odm pipe copy (bsc#1152489)
- commit 43081f5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix trigger not generated for freesync (bsc#1152489)
- commit 442346f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix stuck test pattern on right half of display (bsc#1152489)
- commit 2837437
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: support spdif (bsc#1152489)
- commit 5c0f704
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Refactoring VTEM (bsc#1152489)
- commit c142850
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.47 (bsc#1152489)
- commit b185290
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: cleaned up coding error in init_hw (bsc#1152489)
- commit 1aae62a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add VM page fault handle implementation (bsc#1152489)
- commit f64e760
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: refactor Device ID for external chips (bsc#1152489)
- commit 037de27
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Zero-out dsc init regs (bsc#1152489)
- commit 0a26500
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Implement voltage limitation stub (bsc#1152489)
- commit 59b8f68
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add null checks before logging (bsc#1152489)
- commit 175ad5d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: set Hratio and VRatio in dml (bsc#1152489)
- commit 3fa14dc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix dp stream enable (bsc#1152489)
- commit def265d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: load iram for abm 2.3 (bsc#1152489)
- commit d6ff845
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix MPO HUBP underflow with Scatter Gather (bsc#1152489)
- commit 03af1ef
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix audio endpoint not getting disabled issue (bsc#1152489)
- commit 89be551
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Delete dead code in command_table_helper (bsc#1152489)
- commit db55286
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: re structure odm to allow 4 to 1 support (bsc#1152489)
- commit e1313ca
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: set adev->num_vmhubs for gmc6,7,8 (bsc#1152489)
- commit 3c714c2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/display: add flag for multi-display mclk switching (bsc#1152489)
- commit 9e34cb0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: update bw_calcs to take pipe sync into account (v3) (bsc#1152489)
- commit ba67e14
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay/vega10: enable mclk switching if monitors are (bsc#1152489)
- commit 3cad0a1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay/smu7: enable mclk switching if monitors are (bsc#1152489)
- commit 1d8433f
* Tue Sep 29 2020 tzimmermann@suse.de
- amd/amdkfd: add Arcturus vf DID support (bsc#1152489)
- commit 60523e3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerpaly: fix navi series custom peak level value error (bsc#1152489)
- commit 046cdd4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: correct ras error count type (bsc#1152489)
- commit fea7ec1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix calc_pll_max_vco_construct (bsc#1152489)
- commit efc69e4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable VCN DPG for Renoir (bsc#1152489)
- commit c42e93f
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/amdgpu: use direct loading on renoir vcn for the moment" (bsc#1152489)
- commit 6779cd1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: update gc/sdma goldensetting for rn (bsc#1152489)
- commit dc4f026
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: Disable renoir smu feature retrieve for the moment (bsc#1152489)
- commit b84e353
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: enable renoir dpm feature (bsc#1152489)
- commit 2cc02fd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable SDMA power gating for rn (bsc#1152489)
- commit c090189
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/sdma4: set sdma clock gating for rn (bsc#1152489)
- commit 99d4cb7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/mmhub1: set mmhub clock gating for rn (bsc#1152489)
- commit a932e94
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable DF clock gating for rn (bsc#1152489)
- commit 5dfc4b0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable athub clock gating for rn (bsc#1152489)
- commit d1bd800
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable IH clock gating for rn (bsc#1152489)
- commit 480fa05
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable vcn clock gating for rn (bsc#1152489)
- commit f64b0d3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable rom clock gating for rn (bsc#1152489)
- commit 03078bc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable HDP clock gating for rn (bsc#1152489)
- commit 4179e88
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable BIF clock gating for rn (bsc#1152489)
- commit 96ed1af
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable sdma clock gating for rn (bsc#1152489)
- commit 1d1023c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable mmhub clock gating for rn (bsc#1152489)
- commit 9644520
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable gfx clock gating for rn (bsc#1152489)
- commit 91ce5d5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: add DPMCLOCKS table implementation (bsc#1152489)
- commit 983a0c8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: init smu tables for rn (bsc#1152489)
- commit 86e7428
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: add smu tables for rn (bsc#1152489)
- commit d80677a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: using valid mapping check for rn (bsc#1152489)
- commit 26616fc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: fix checking gfxoff status for rn (bsc#1152489)
- commit eaddc34
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add and enable gfxoff feature (bsc#1152489)
- commit 0e09e3c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add set_gfx_cgpg implement (v2) (bsc#1152489)
- commit 66039e3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: udpate smu_v12_0_check_fw_version (v2) (bsc#1152489)
- commit 3b5759f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: powerup sdma/vcn for all apu series (bsc#1152489)
- commit e60f25c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add Renoir VCN power management (bsc#1152489)
- commit 72b0fd2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: skip dpm init for renoir (bsc#1152489)
- commit dcc74bf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add power up/down SDMA interfaces for renoir (bsc#1152489)
- commit 1b4ed5f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add smu ip block for renoir (v2) (bsc#1152489)
- commit ee3bfa9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add smu_v12_0.c & smu_v12_0.h for renoir (bsc#1152489)
- commit e65f13c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add initial renoir_ppt.c for renoir (v3) (bsc#1152489)
- commit 0d1b11c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: add smu12_driver_if.h (v3) (bsc#1152489)
- commit 88e5887
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: Add smu_v12_0_ppsmc.h (v2) (bsc#1152489)
- commit fdd76d1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix a potential null pointer dereference (bsc#1152489)
- commit bee4a29
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: remove redundant assignment to variable (bsc#1152489)
- commit 7dc3723
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Make deallocate_hiq_sdma_mqd static (bsc#1152489)
- commit 0d92f63
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/sdma5: fix number of sdma5 trap irq types for navi1x (bsc#1152489)
- commit ffb4b32
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Enable SST DSC in DM (bsc#1152489)
- commit 9fefe66
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/amd/display: Fix underscan not using proper scaling" (bsc#1152489)
- commit 407e882
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/amd/display: add global master update lock for DCN2" (bsc#1152489)
- commit 63d3c55
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/amd/display: navi10 bring up skip dsc encoder config" (bsc#1152489)
- commit fc29df3
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/amd/display: skip dsc config for navi10 bring up" (bsc#1152489)
- commit e5af6be
* Tue Sep 29 2020 tzimmermann@suse.de
- amd/amdgpu: add Arcturus vf DID support (bsc#1152489)
- commit c3b6495
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: unity mc base address for arcturus (bsc#1152489)
- commit 345bff2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: disable agp for sriov (bsc#1152489)
- commit 8b91d49
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: remove set but not used variable 'pdd' (bsc#1152489)
- commit 61cbbfb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: remove duplicated include from dc_link.c (bsc#1152489)
- commit 5f0e51f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: remove duplicated include from gfx_v9_0.c (bsc#1152489)
- commit a484df1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: remove set but not used variable 'psp_enabled' (bsc#1152489)
- commit 2c8b1e9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Fix 32-bit divide error in wait_for_alt_mode (bsc#1152489)
- commit 2983270
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Lock the CRTC when setting CRC source (bsc#1152489)
- commit 36def49
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Split out DC programming for CRC capture (bsc#1152489)
- commit 3e9636d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Use connector list for finding DPRX CRC aux (bsc#1152489)
- commit e83a877
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Check return code for CRC drm_crtc_vblank_get (bsc#1152489)
- commit 7e3611e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: correct typo (bsc#1152489)
- commit cc06fa9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: correct SW smu11 thermal range settings (bsc#1152489)
- commit b807b96
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: set Arcturus default fclk as bootup value on dpm (bsc#1152489)
- commit 01cbc0b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: get bootup fclk value (bsc#1152489)
- commit 73dfeb6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: expose supported clock domains only through sysfs (bsc#1152489)
- commit 36203b1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: update Arcturus smc fw and driver interface header (bsc#1152489)
- commit b705939
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: add smu_smc_read_sensor support for arcturus (bsc#1152489)
- commit 4419583
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Fix a typo in the include header guard of (bsc#1152489)
- commit 91705a2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/psp: move TMR to cpu invisible vram region (bsc#1152489)
- commit 468640a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: remove redundant argument for psp_funcs::cmd_submit (bsc#1152489)
- commit 1fa6c76
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Fill the name field in node topology with asic name v2 (bsc#1152489)
- commit bace489
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Set no-retry as default. (bsc#1152489)
- commit 79c2ecd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add firmware header printing for psp fw loading (v2) (bsc#1152489)
- commit b98a5c1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix debug level for ppt offset/size (bsc#1152489)
- commit 0463c11
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: remove special autoload handling for navi12 (bsc#1152489)
- commit cf9be04
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Use new mode2 reset interface for RV. (bsc#1152489)
- commit e8b53ee
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/poweplay: Add amd_pm_funcs callback for mode 2 (bsc#1152489)
- commit 7893398
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerpay: Implement mode2 reset callback for SMU10 (bsc#1152489)
- commit 3fe767b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: add mode2 reset callback for pp_smu_mgr (bsc#1152489)
- commit a65ead4
* Tue Sep 29 2020 lduncan@suse.com
- Ran series_sort.py, moving one patch, to make it happy
- commit 9be1933
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: Fix meaning of 0x1E PPSMC_MSG (bsc#1152489)
- commit 4fe220e
* Tue Sep 29 2020 tzimmermann@suse.de
- dmr/amdgpu: Fix compile error with CONFIG_DRM_AMDGPU_GART_DEBUGFS (bsc#1152489)
- commit 457f35f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay/smu7: enforce minimal VBITimeout (v2) (bsc#1152489)
- commit 4500233
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/amdgpu: Update VM function pointer (bsc#1152489)
- commit 91f9852
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Fill amdgpu_task_info for KFD VMs (bsc#1152489)
- commit 249bfb9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Set VM_L2_CNTL.PDE_FAULT_CLASSIFICATION to 0 for GFX10 (bsc#1152489)
- commit a0e8330
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Add more page fault info printing for GFX10 (bsc#1152489)
- commit 4417fcf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Add printing for RW extracted from (bsc#1152489)
- commit 7ed8c98
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd/gfx10: Calling amdgpu functions to invalidate TLB (bsc#1152489)
- commit 4ecd9b3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Export function to flush TLB of specific vm hub (bsc#1152489)
- commit a6d8393
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Load NV12 SOC BB from firmware (bsc#1152489)
- commit 483f4da
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Enable MPO with pre-blend color processing (RGB) (bsc#1152489)
- commit 592d849
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: audio cannot switch to internal when display turns (bsc#1152489)
- commit 08a1862
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: check hpd before retry verify link cap (bsc#1152489)
- commit c3bda9c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: enable dcn_mem_pwr as golden setting updates (bsc#1152489)
- commit 6e584ad
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.46 (bsc#1152489)
- commit 6bfef04
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix dcn20 global sync dml param extraction (bsc#1152489)
- commit bb0626c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.45 (bsc#1152489)
- commit 0b27a51
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add and refine DSC logs in enable sequence (bsc#1152489)
- commit d463cd9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add Logging for Gamma Related information (2/2) (bsc#1152489)
- commit 53b0bc1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Remove redundant definition of dwb_source enums (bsc#1152489)
- commit b504830
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add enum for H-timing divider mode (bsc#1152489)
- commit a68d8ee
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Register VUPDATE_NO_LOCK interrupts for DCN2 (bsc#1152489)
- commit 43633fd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: wake up ogam mem pwr before programming ocsc (bsc#1152489)
- commit 289ef28
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Correct DSC PPS log (bsc#1152489)
- commit a9aa786
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Check if set_blank_data_double_buffer exists before (bsc#1152489)
- commit 99195c9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Fix type of ODMCombineType field (bsc#1152489)
- commit fc239d7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add Logging for Gamma Related information (1/2) (bsc#1152489)
- commit 80e0179
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Remove 4:2:2 DSC support (bsc#1152489)
- commit d239eeb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: reprogram VM config when system resume (bsc#1152489)
- commit 8d2ba09
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Enable type C hotplug (bsc#1152489)
- commit 94757d7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: HUBP/HUBBUB register programming fixes (bsc#1152489)
- commit d1c82a0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: update optc odm interface for more than 2 opps (bsc#1152489)
- commit 5e616c3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Update DML parameters (bsc#1152489)
- commit 123802f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Remove duplicate interface for programming FB (bsc#1152489)
- commit a9d46ae
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix pipe selection logic in validate (bsc#1152489)
- commit 6254bbe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.44 (bsc#1152489)
- commit 65eda5c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Set DSC before DIG front-end is connected to its (bsc#1152489)
- commit b7aeddf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Change DSC policy from slices per column to minimum (bsc#1152489)
- commit 8172b36
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add HLG support in color module (bsc#1152489)
- commit 3e3d299
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: clean up DML for DCN2x (bsc#1152489)
- commit 96410fc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: enabling seamless boot sequence for dcn2 (bsc#1152489)
- commit 0dda027
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix dcn-specific clk_mgr init_clocks (bsc#1152489)
- commit b1c40e4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Make init_hw and init_pipes generic for seamless (bsc#1152489)
- commit b6dc0d9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.43 (bsc#1152489)
- commit 907d12d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: wait for pending complete when enabling a plane (bsc#1152489)
- commit 3590a82
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: refactor gpio to allocate hw_container in (bsc#1152489)
- commit f0d5bdd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add work-around option to skip DCN20 clock updates (bsc#1152489)
- commit 719ad5e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fixup DPP programming sequence (bsc#1152489)
- commit 67be259
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: make firmware info only load once during dc_bios (bsc#1152489)
- commit e249f75
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Synchronous DisplayPort Link Training (bsc#1152489)
- commit 0a0be5e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Improve sharing of HUBBUB register lists (bsc#1152489)
- commit 2d1a3b0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add 22, 24, and 26 degamma (bsc#1152489)
- commit 4deee5d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Fix frames_to_insert math (bsc#1152489)
- commit 3fa99a1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix issue where 252-255 values are clipped (bsc#1152489)
- commit 2fb323d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: reset hdmi tmds rate and data scramble on pipe reset (bsc#1152489)
- commit 4d74820
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: reset drr programming on pipe reset (bsc#1152489)
- commit 9f300d0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add DFS reference clock field (bsc#1152489)
- commit 0138d17
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add PIXEL_RATE control regs for more instances (bsc#1152489)
- commit 1f6ccc9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: MODULE_FIRMWARE requires linux/module.h (bsc#1152489)
- commit 586e331
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: fix spelling mistake "unsuported" -> (bsc#1152489)
- commit a5ed1e9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: implement querying ras error count for mmhub (bsc#1152489)
- commit 97a2a37
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: use exiting amdgpu_ctx_total_num_entities function (bsc#1152489)
- commit 5cbfc47
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix typo error amdgput -> amdgpu (bsc#1152489)
- commit d47dac1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: fix message of SetHardMinByFreq failed when (bsc#1152489)
- commit 7e65668
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: add arcturus_is_dpm_running function for arcturus (bsc#1152489)
- commit d605c56
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: remove redundancy debug log about smu unsupported (bsc#1152489)
- commit 5bad212
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: simplify and cleanup setting the dma mask (bsc#1152489)
- commit 4bb5779
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: simplify and cleanup setting the dma mask (bsc#1152489)
- commit ed08394
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: handle PCIe root ports with addressing limitations (bsc#1152489)
- commit ed4a817
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: handle PCIe root ports with addressing limitations (bsc#1152489)
- commit c4e221f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: flag renoir as experimental for now (bsc#1152489)
- commit bc201fc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: skip mec2 jump table loading for renoir (bsc#1152489)
- commit 4e00d91
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: use direct loading on renoir vcn for the moment (bsc#1152489)
- commit dfdb339
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: set fw default loading by psp for renoir (bsc#1152489)
- commit 26ae291
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: update lbpw for renoir (bsc#1152489)
- commit 7fb7cf4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable power gating for renoir (bsc#1152489)
- commit 80af723
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable clock gating for renoir (bsc#1152489)
- commit c0b5ce5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add VCN2.0 to Renoir IP blocks (bsc#1152489)
- commit c3198a4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable Doorbell support for Renoir (v2) (bsc#1152489)
- commit 0a16d10
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable Renoir VCN firmware loading (bsc#1152489)
- commit ce30b98
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add sdma golden settings for renoir (bsc#1152489)
- commit 7ae8995
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add gfx golden settings for renoir (v2) (bsc#1152489)
- commit 466db5c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add psp_v12_0 for renoir (v2) (bsc#1152489)
- commit b503a78
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: set rlc funcs for renoir (bsc#1152489)
- commit 40ad64c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add asic funcs for renoir (bsc#1152489)
- commit 1492026
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable dce virtual ip module for Renoir (bsc#1152489)
- commit 37a0deb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix no interrupt issue for renoir emu (bsc#1152489)
- commit 22c963e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add renoir pci id (bsc#1152489)
- commit 4afa4cc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: set ip blocks for renoir (bsc#1152489)
- commit fc7039a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add sdma support for renoir (bsc#1152489)
- commit 3aeaabf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add gfx support for renoir (bsc#1152489)
- commit 3a04615
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: set fw load type for renoir (bsc#1152489)
- commit ce39bdf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add gmc v9 supports for renoir (bsc#1152489)
- commit fc0b5a5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add soc15 common ip block support for renoir (bsc#1152489)
- commit e269d2a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add renoir support for gpu_info and ip block setting (bsc#1152489)
- commit 09c1104
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add renoir asic_type enum (bsc#1152489)
- commit d89b433
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add renoir header files (v2) (bsc#1152489)
- commit e7be2c4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: remove redundant duplicated return check (bsc#1152489)
- commit 14f6994
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Fix a typo - dce_aduio_mask --> dce_audio_mask (bsc#1152489)
- commit 24888b0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: update Arcturus smu version in new place (bsc#1152489)
- commit deae098
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable mmhub clock gating for Arcturus (bsc#1152489)
- commit bfcdac2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add mmhub clock gating for Arcturus (bsc#1152489)
- commit 60af5e4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: increase CGCG gfx idle threshold for Arcturus (bsc#1152489)
- commit 25d4a48
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add GFX_CP_LS flag to Arcturus (bsc#1152489)
- commit 6c4bb0f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: remove ras block's feature status info in sysfs (bsc#1152489)
- commit c9e5d86
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: change smu_read_sensor sequence in smu (bsc#1152489)
- commit 23a94b8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: split athub clock gating from mmhub (bsc#1152489)
- commit a944013
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable sdma clock gating for Arcturus (bsc#1152489)
- commit da7dba6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add sdma clock gating for Arcturus (bsc#1152489)
- commit 79f7836
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: support sdma clock gating for more instances (bsc#1152489)
- commit 95c4f88
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable hdp clock gating for Arcturus (bsc#1152489)
- commit 66d5f0d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add hdp clock gating for Arcturus (bsc#1152489)
- commit 961d4c0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable gfx clock gating for Arcturus (bsc#1152489)
- commit f07b2ea
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add gfx clock gating for Arcturus (bsc#1152489)
- commit 2757ead
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: create mmhub ras framework (bsc#1152489)
- commit 00d14a7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: support mmhub ras in amdgpu ras (bsc#1152489)
- commit f47e0c8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add amdgpu_mmhub_funcs definition (bsc#1152489)
- commit 589934b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add sub block parameter in ras inject command (bsc#1152489)
- commit 1f42680
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add check to avoid array bound issue (bsc#1152489)
- commit 084a071
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: re-define smu interface version for smu v11 (bsc#1152489)
- commit 5793007
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add navi14 PCI ID (bsc#1152489)
- commit aa61f02
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Update pitch on page flips without DC as well (bsc#1152489)
- commit 8b2a137
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Remove drm_dsc_dc.c (bsc#1152489)
- commit 0b1abb9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable vcn clock gating for navi12 (bsc#1152489)
- commit b168375
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable athub clock gating for navi12 (bsc#1152489)
- commit da41f69
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/athub2: set clock gating for navi12 (bsc#1152489)
- commit c79ba82
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable ih clock gating for navi12 (bsc#1152489)
- commit 8c3a973
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable mmhub clock gating for navi12 (bsc#1152489)
- commit 5cba8ab
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/mmhub2: set clock gating for navi12 (bsc#1152489)
- commit bc2a773
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable sdma clock gating for navi12 (bsc#1152489)
- commit d3f01e5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/sdma5: set sdma clock gating for navi12 (bsc#1152489)
- commit 04e7d6c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable hdp clock gating for navi12 (bsc#1152489)
- commit a81fdef
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable gfx clock gatings for navi12 (bsc#1152489)
- commit 90e709f
* Tue Sep 29 2020 tzimmermann@suse.de
- omapdrm: no need to check return value of debugfs_create functions (bsc#1152472)
- commit e5b3358
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/omap: Add 'alpha' and 'pixel blend mode' plane properties (bsc#1152472)
- commit b67436f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Fix sleeping while atomic in panfrost_gem_open (bsc#1152472)
- commit 4e6f89d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: meson: use match data to detect vpu compatibility (bsc#1152472)
- commit f5c3457
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: fix module name in edid_firmware log message (bsc#1152472)
- commit 116b004
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Move ade drm init to kirin drm drv (bsc#1152472)
- commit 0a07826
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Pass driver data to crtc init and plane init (bsc#1152472)
- commit 0430cf0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Add alloc_hw_ctx/clean_hw_ctx ops in driver data (bsc#1152472)
- commit fc8428e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Make driver_data variable non-global (bsc#1152472)
- commit aad6dfa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Fix dev->driver_data setting (bsc#1152472)
- commit 7cbb666
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Rename plane_init and crtc_init (bsc#1152472)
- commit 648d0e1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Add register connect helper functions in drm init (bsc#1152472)
- commit 0543c2d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Move drm driver to driver data (bsc#1152472)
- commit 429144e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Move config max_width and max_height to driver data (bsc#1152472)
- commit adaa447
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Move plane number and primay plane in driver data (bsc#1152472)
- commit 9914ace
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Move mode config function to driver_data (bsc#1152472)
- commit 31dda6e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Move channel formats to driver data (bsc#1152472)
- commit 374956e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Move ade crtc/plane help functions to driver_data (bsc#1152472)
- commit d6c5279
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Reanme dc_ops to kirin_drm_data (bsc#1152472)
- commit 815fa75
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Move kirin_crtc, kirin_plane, kirin_format to (bsc#1152472)
- commit 2e2cb04
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Move workqueue to ade_hw_ctx structure (bsc#1152472)
- commit d67d815
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Move request irq handle in ade hw ctx alloc (bsc#1152472)
- commit f0b739f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Dynamically allocate the hw_ctx (bsc#1152472)
- commit e44df1b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Rename ade_crtc to kirin_crtc (bsc#1152472)
- commit b2b8086
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Rename ade_plane to kirin_plane (bsc#1152472)
- commit b9fdf1b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Remove out_format from ade_crtc (bsc#1152472)
- commit 151b4d8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Remove uncessary parameter indirection (bsc#1152472)
- commit b111c26
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Remove unreachable return (bsc#1152472)
- commit 4d86952
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Remove HISI_KIRIN_DW_DSI config option (bsc#1152472)
- commit 60e4151
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: kirin: Fix for hikey620 display offset problem (bsc#1152472)
- commit 28c8724
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: Initialize GEM object before TTM object (bsc#1152472)
- commit 82bbc5e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/komeda: Add support for 'memory-region' DT node property (bsc#1152472)
- commit 0beef9b
* Tue Sep 29 2020 tzimmermann@suse.de
- dw-hdmi-cec: use cec_notifier_cec_adap_(un)register (bsc#1152472)
- commit fc0a63b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: dw-hdmi: use cec_notifier_conn_(un)register (bsc#1152472)
- commit 519820c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Select DMABUF_SELFTESTS for the default i915.ko debug build (bsc#1152472)
- commit f81d708
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/drv: Use // for comments in example code (bsc#1152472)
- commit e66cbf5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Remove opp table when unloading (bsc#1152472)
- commit 21f5028
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Enable devfreq to work without regulator (bsc#1152472)
- commit 565453b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Implement per FD address spaces (bsc#1152472)
- commit 06ab210
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Fix missing unlock on error in (bsc#1152472)
- commit 2fb59ef
* Tue Sep 29 2020 tzimmermann@suse.de
- udlfb: Make dlfb_ops constant (bsc#1152472)
- commit 93b0dd9
* Tue Sep 29 2020 tzimmermann@suse.de
- video: fbdev/mmp/core: Use struct_size() in kzalloc() (bsc#1152472)
- commit c53050f
* Tue Sep 29 2020 tzimmermann@suse.de
- video: fbdev: viafb: Remove dead code (bsc#1152472)
- commit 736618a
* Tue Sep 29 2020 tzimmermann@suse.de
- video: fbdev: aty[128]fb: Remove dead code (bsc#1152472)
- commit 7119835
* Tue Sep 29 2020 tzimmermann@suse.de
- video: fbdev: sh_mobile_lcdcfb: Mark expected switch fall-through (bsc#1152472)
- commit e7d1da1
* Tue Sep 29 2020 tzimmermann@suse.de
- video: fbdev: radeonfb: Use dev_get_drvdata (bsc#1152472)
- commit c12f66a
* Tue Sep 29 2020 tzimmermann@suse.de
- video: fbdev: sm712fb: Use dev_get_drvdata (bsc#1152472)
- commit f0a673c
* Tue Sep 29 2020 tzimmermann@suse.de
- video: fbdev: pvr2fb: remove unnecessary comparison of unsigned (bsc#1152472)
- commit e1cd33f
* Tue Sep 29 2020 tzimmermann@suse.de
- efifb: BGRT: Improve efifb_bgrt_sanity_check (bsc#1152472)
- commit e7b6da1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/hisilicon/hibmc: Make CONFIG_DRM_HISI_HIBMC depend on ARM64 (bsc#1152489)
- commit e37c214
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/hisilicon: Use dev_get_drvdata (bsc#1152489)
- commit d8caca1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/hisilicon/hibmc: Using module_pci_driver. (bsc#1152489)
- commit a925e83
* Tue Sep 29 2020 tzimmermann@suse.de
- gpu: ipu-v3: image-convert: only sample into the next tile if (bsc#1152489)
- commit 8358bc1
* Tue Sep 29 2020 tzimmermann@suse.de
- gpu: ipu-v3: image-convert: move tile burst alignment out of loop (bsc#1152489)
- commit dd93902
* Tue Sep 29 2020 tzimmermann@suse.de
- gpu: ipu-v3: image-convert: bail on invalid tile sizes (bsc#1152489)
- commit 54d81ec
* Tue Sep 29 2020 tzimmermann@suse.de
- gpu: ipu-v3: image-convert: fix image downsize coefficients and (bsc#1152489)
- commit bf9d8aa
* Tue Sep 29 2020 tzimmermann@suse.de
- gpu: ipu-v3: image-convert: limit input seam position to hardware (bsc#1152489)
- commit 256884a
* Tue Sep 29 2020 tzimmermann@suse.de
- gpu: ipu-v3: image-convert: fix output seam valid interval (bsc#1152489)
- commit bdeb94d
* Tue Sep 29 2020 tzimmermann@suse.de
- gpu: ipu-v3: image-convert: move output seam valid interval (bsc#1152489)
- commit 9558cf0
* Tue Sep 29 2020 tzimmermann@suse.de
- gpu: ipu-v3: image-convert: enable V4L2_PIX_FMT_BGRX32 and _RGBX32 (bsc#1152489)
- commit 7324713
* Tue Sep 29 2020 tzimmermann@suse.de
- gpu: ipu-v3: enable remaining 32-bit RGB V4L2 pixel formats (bsc#1152489)
- commit 9261b08
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/imx: Drop unused imx-ipuv3-crtc.o build (bsc#1152489)
- commit 46d1e6c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Update DRIVER_DATE to 20190822 (bsc#1152489)
- commit 66ee014
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Replace i915_vma_put_fence() (bsc#1152489)
- commit 7e240b6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Pull obj->userfault tracking under the ggtt->mutex (bsc#1152489)
- commit 85c1292
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Track ggtt fence reservations under its own mutex (bsc#1152489)
- commit 7349af1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Generalise the clflush dma-worker (bsc#1152489)
- commit e9efc96
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Fixup a couple of missing serialisation with vma (bsc#1152489)
- commit fc0cbdb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Add some range asserts (bsc#1152489)
- commit d670254
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Set priority hint prior to submission (bsc#1152489)
- commit 9e602f7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Replace PIN_NONFAULT with calls to PIN_NOEVICT (bsc#1152489)
- commit 92c4f42
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Include asm/smp.h (bsc#1152489)
- commit 46652b9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/hdmi: make hdcp2_msg_data const (bsc#1152489)
- commit f0b77d9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/hdmi: stylistic cleanup around hdcp2_msg_data (bsc#1152489)
- commit 5b996f5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/dp: make hdcp2_dp_msg_data const (bsc#1152489)
- commit 0305ebe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/dp: avoid shadowing variables (bsc#1152489)
- commit a54a2fd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/dp: stylistic cleanup around hdcp2_msg_data (bsc#1152489)
- commit 736840d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Relax assertion for pt_used (bsc#1152489)
- commit bfa13cf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Fix DP-MST crtc_mask (bsc#1152489)
- commit 7186966
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: update DMC firmware to 2.04 (bsc#1152489)
- commit 91c9dcc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Move transcoders to pipes' powerwells (bsc#1152489)
- commit e34c4f6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: add support for reading the timestamp frequency (bsc#1152489)
- commit adb2624
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: disable DDIC (bsc#1152489)
- commit aea7f63
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Update DRIVER_DATE to 20190820 (bsc#1152489)
- commit a726a9c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Relax pd_used assertion (bsc#1152489)
- commit 62b8d4b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Dynamically allocate s0ix struct for VLV (bsc#1152489)
- commit b9aba17
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Gen12 render context size (bsc#1152489)
- commit b2c6095
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Updated Private PAT programming (bsc#1152489)
- commit d0a9b99
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Introduce initial Tiger Lake workarounds (bsc#1152489)
- commit dbb5547
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Gen12 csb support (bsc#1152489)
- commit e2adb5e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: add GEN12_MAX_CONTEXT_HW_ID (bsc#1152489)
- commit 460ecd0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: add Gen12 default indirect ctx offset (bsc#1152489)
- commit 8f23cf6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Report valid VDBoxes with SFC capability (bsc#1152489)
- commit 772e899
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Be defensive when starting vma activity (bsc#1152489)
- commit e8feb89
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Serialize insertion into the file->mm.request_list (bsc#1152489)
- commit 3fa4103
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Sanitize PHY state during display core uninit (bsc#1152489)
- commit e4427ac
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Assume exclusive access to objects inside resume (bsc#1152489)
- commit 60d7aef
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use 0 for the unordered context (bsc#1152489)
- commit 2d78ee3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: i915_active.retire() is optional (bsc#1152489)
- commit e7c69b7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gen11: Allow usage of all GPIO pins (bsc#1152489)
- commit 6e17baf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Serialize against vma moves (bsc#1152489)
- commit bed5a90
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Only emit the 'send bug report' once for a GPU hang (bsc#1152489)
- commit 30a6052
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Mark up the nested engine-pm timeline lock as irqsafe (bsc#1152489)
- commit 79eea6e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Always wrap the ring offset before resetting (bsc#1152489)
- commit d6fd316
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Propagate fence errors (bsc#1152489)
- commit 2f57e5a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Never fail on HuC firmware errors (bsc#1152489)
- commit 5a8619d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Don't always fail on unavailable GuC firmware (bsc#1152489)
- commit e013402
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Don't open log relay if GuC is not running (bsc#1152489)
- commit e2384ba
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Never fail on uC preparation step (bsc#1152489)
- commit f18d50d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Cleanup fw fetch on every GuC/HuC init failure (bsc#1152489)
- commit 1877a40
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Cleanup fw fetch only if it was successful (bsc#1152489)
- commit 9b63ff8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Check the context size (bsc#1152489)
- commit 7791cfe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Fold gen8 insertions into one (bsc#1152489)
- commit 7224dce
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Add explicit DISABLED state for firmware (bsc#1152489)
- commit f9ef4f8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Wrappers for display register waits (bsc#1152489)
- commit 029b23f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move gmbus definitions out of i915_reg.h (bsc#1152489)
- commit 060bdd6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move engine IDs out of i915_reg.h (bsc#1152489)
- commit 27b256e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move i915_power_well_id out of i915_reg.h (bsc#1152489)
- commit cf7107a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Lift process_csb() out of the irq-off spinlock (bsc#1152489)
- commit 684883c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Markup expected timeline locks for i915_active (bsc#1152489)
- commit 56a1345
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Mark context->active_count as protected by (bsc#1152489)
- commit d7a5ad3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/wopcm: Fix SPDX tag location (bsc#1152489)
- commit e63e481
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/wopcm: Update error messages (bsc#1152489)
- commit 43dccb0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/wopcm: Try to use already locked WOPCM layout (bsc#1152489)
- commit 3315ed3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/wopcm: Check WOPCM layout separately from calculations (bsc#1152489)
- commit d432e4a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Move FW size sanity check back to fetch (bsc#1152489)
- commit e9a7bf4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/buddy: use kmemleak_update_trace (bsc#1152489)
- commit 8415236
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/buddy: tidy up i915_buddy_fini (bsc#1152489)
- commit c69ead9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use the associated uncore for the vm (bsc#1152489)
- commit c514165
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Extract intel_frontbuffer active tracking (bsc#1152489)
- commit 3e3333e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Protect request retirement with timeline->mutex (bsc#1152489)
- commit dd5ac3d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Guard timeline pinning without relying on struct_mutex (bsc#1152489)
- commit 7031169
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Convert timeline tracking to spinlock (bsc#1152489)
- commit 3fa81a9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Track timeline activeness in enter/exit (bsc#1152489)
- commit 0bcb809
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/cml: Add Missing PCI IDs (bsc#1152489)
- commit 2e3201e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move tasklet kicking to __i915_request_queue caller (bsc#1152489)
- commit 9a1acac
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Add gen11 specific render breadcrumbs (bsc#1152489)
- commit ff3b32c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Add command cache invalidate (bsc#1152489)
- commit f89debd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Implement gen11 flush including tile cache (bsc#1152489)
- commit f829d31
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftest/buddy: fixup igt_buddy_alloc_range (bsc#1152489)
- commit 3005e03
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Convert a few more bland dmesg info to be device specific (bsc#1152489)
- commit fead61d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Serialise read/write of the barrier's engine (bsc#1152489)
- commit 0f60434
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Print CCID for all renderCS (bsc#1152489)
- commit 77dc2a5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Disregard drm_mode_config.fb_base (bsc#1152489)
- commit 7568bd1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Include engine->mmio_base in the debug dump (bsc#1152489)
- commit 8245959
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Remove client->submissions (bsc#1152489)
- commit cb98dca
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Update DRIVER_DATE to 20190813 (bsc#1152489)
- commit 2b597b8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add _TRANS2() (bsc#1152489)
- commit d16ac33
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/bdw+: Move misc display IRQ handling to it own function (bsc#1152489)
- commit f7a591d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gvt: Double check batch buffer size after copy (bsc#1152489)
- commit 5888542
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gvt: Add valid length check for MI variable commands (bsc#1152489)
- commit cce4f06
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gvt: Add MI command valid length check (bsc#1152489)
- commit 548044e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gvt: Utility for valid command length check (bsc#1152489)
- commit fa43037
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gvt: factor out tlb and mocs register offset table (bsc#1152489)
- commit cc3202f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gvt: no need to check return value of debugfs_create (bsc#1152489)
- commit afe837c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gvt: Fix typo of VBLANK_TIMER_PERIOD (bsc#1152489)
- commit ae1bd46
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/kvmgt: Use struct_size() helper (bsc#1152489)
- commit a409221
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Save/restore interrupts around breadcrumb disable (bsc#1152489)
- commit 1c2ec3d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Push the wakeref->count deferral to the backend (bsc#1152489)
- commit c374484
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Fix missing parentheses on (bsc#1152489)
- commit 985b28d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Log fw status changes only under debug config (bsc#1152489)
- commit eccd909
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Use a local cancel_port_requests (bsc#1152489)
- commit e0f92d7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: drop engine_pin/unpin_breadcrumbs_irq (bsc#1152489)
- commit e95fc2e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: keep breadcrumb irq always enabled (bsc#1152489)
- commit cb5fbfe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/overlay: Switch to using i915_active tracking (bsc#1152489)
- commit 8b50a6f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Forgo last_fence active request tracking (bsc#1152489)
- commit 2492f45
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Extract general GT interrupt handlers (bsc#1152489)
- commit e8d7ade
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Extract GT powermanagement interrupt handling (bsc#1152489)
- commit cf21a3b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Use the local engine wakeref when checking RING (bsc#1152489)
- commit c45087a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Prevent the timeslice expiring during suppression (bsc#1152489)
- commit 2c995a5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Avoid sync calls during park (bsc#1152489)
- commit 40916c9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Update copyright and license (bsc#1152489)
- commit 9e7e846
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Fixing up list of PG3 power domains. (bsc#1152489)
- commit afff35b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Remove DDI IO power domain from PG3 power domains (bsc#1152489)
- commit 012a5e9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Use -EIO code for GuC initialization failures (bsc#1152489)
- commit ecad9cf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Update messages from fw upload step (bsc#1152489)
- commit d8d4a24
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Include HuC firmware version in summary (bsc#1152489)
- commit d7f3860
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Fail early if there is no GuC fw available (bsc#1152489)
- commit 6dbfd00
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Remove unused debugfs/i915_emon_status (bsc#1152489)
- commit a7eaf43
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: buddy allocator (bsc#1152489)
- commit 6ba3a1a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/blt: support copying objects (bsc#1152489)
- commit 2ab3aa5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: disable 2M pages for pre-gen11 (bsc#1152489)
- commit aa14527
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: enable GTT cache by default (bsc#1152489)
- commit 7d1481b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: move gpu-write-dw into utils (bsc#1152489)
- commit 9bbd412
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/blt: bump the size restriction (bsc#1152489)
- commit d91a98d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/blt: don't assume pinned intel_context (bsc#1152489)
- commit 4123d52
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: split out uncore_mmio_debug (bsc#1152489)
- commit 858f9ad
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Stop reconfiguring our shmemfs mountpoint (bsc#1152489)
- commit 0ec1263
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Lift timeline into intel_context (bsc#1152489)
- commit ced808a
* Tue Sep 29 2020 oneukum@suse.com
- crypto: qat - switch to skcipher API (jsc#SLE-14454).
- commit 0d922d0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Push the ring creation flags to the backend (bsc#1152489)
- commit fc88dc3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Make deferred context allocation explicit (bsc#1152489)
- commit 9855fac
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Remove i915_gem_context_create_gvt() (bsc#1152489)
- commit a1e36b7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Drop the fudge warning on ring restart for ctg/elk (bsc#1152489)
- commit f32fa59
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Generalise BSD default selection (bsc#1152489)
- commit 2bd99c8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Replace global bsd_dispatch_index with random seed (bsc#1152489)
- commit 4f316e2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Check for a second VCS engine more carefully (bsc#1152489)
- commit 456841e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Backtrack along timeline (bsc#1152489)
- commit 60d9feb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Free the imported shmemfs file for phys objects (bsc#1152489)
- commit 566edf8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: extract i915_gem_shrinker.h from i915_drv.h (bsc#1152489)
- commit 8765313
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: extract gem/i915_gem_stolen.h from i915_drv.h (bsc#1152489)
- commit 8986cad
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: extract i915_memcpy.h from i915_drv.h (bsc#1152489)
- commit 06a1270
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: extract i915_suspend.h from i915_drv.h (bsc#1152489)
- commit da63167
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: extract i915_sysfs.h from i915_drv.h (bsc#1152489)
- commit 86115ce
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: extract i915_perf.h from i915_drv.h (bsc#1152489)
- commit 5258e8b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: move printing and load error inject to i915_utils.[ch] (bsc#1152489)
- commit f75c075
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: move I915_STATE_WARN() and _ON() to intel_display.h (bsc#1152489)
- commit f66044c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: move add_taint_for_CI() to i915_utils.h (bsc#1152489)
- commit ac8747f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: remove unused dev_priv->no_aux_handshake (bsc#1152489)
- commit ddea05d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Make debugfs/per_file_stats scale better (bsc#1152489)
- commit cd1c636
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Only include active engines in the capture state (bsc#1152489)
- commit 1aef69f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Defer final intel_wakeref_put to process context (bsc#1152489)
- commit 9650b07
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Fixup a missing legacy_idx (bsc#1152489)
- commit b5a42d1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Fix the read of the DDI that transcoder is attached to (bsc#1152489)
- commit fcdabf0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Get transcoder power domain before reading its register (bsc#1152489)
- commit 0785759
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Fix up the inverse mapping for default ctx->engines[] (bsc#1152489)
- commit c533016
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Allocate kernel_contexts directly (bsc#1152489)
- commit 6f0ba92
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Pass intel_context to mock_request (bsc#1152489)
- commit 8337830
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl/dsi: Enable blanking packets during BLLP for video mode (bsc#1152489)
- commit 27b6811
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add mipi dsi support for TGL (bsc#1152489)
- commit 6cb36e8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl/dsi: Gate the ddi clocks after pll mapping (bsc#1152489)
- commit d5f2a28
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl/dsi: Do not override TA_SURE (bsc#1152489)
- commit a432073
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl/dsi: Set latency PCS_DW1 for tgl (bsc#1152489)
- commit c567f48
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl/dsi: Program TRANS_VBLANK register (bsc#1152489)
- commit e7c9f49
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: split out intel_pch.[ch] from i915_drv.[ch] (bsc#1152489)
- commit b16c3fd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Hardening firmware fetch (bsc#1152489)
- commit d0bcc9c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: WOPCM programming errors are not always real (bsc#1152489)
- commit c220f5d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Make wopcm_to_i915() private (bsc#1152489)
- commit d268e17
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Don't try to partition WOPCM without GuC firmware (bsc#1152489)
- commit 07d8848
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Don't fetch HuC fw if GuC fw fetch already failed (bsc#1152489)
- commit 535ca49
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: HuC firmware can't be supported without GuC (bsc#1152489)
- commit 26cd40a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Prefer dev_info for reporting options (bsc#1152489)
- commit 31b3b77
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/perf: Refactor oa object to better manage resources (bsc#1152489)
- commit 825a0f0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Isolate i915_getparam_ioctl() (bsc#1152489)
- commit 4e1cf01
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Include the DRIVER_DATE in the error state (bsc#1152489)
- commit d0af45c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Fix some NULL vs IS_ERR() conditions (bsc#1152489)
- commit 8c50a08
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use intel_engine_lookup_user for probing HAS_BSD etc (bsc#1152489)
- commit f728c3f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Rename engines to match their user interface (bsc#1152489)
- commit 8f4bc0d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Drop expectations of VM_IO from our GGTT mmappings (bsc#1152489)
- commit 8ab0467
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: abstract display suspend/resume operations (bsc#1152489)
- commit 3d27674
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: move property enums to intel_display_types.h (bsc#1152489)
- commit 0dd2a58
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: remove unnecessary includes of intel_display_types.h header (bsc#1152489)
- commit d4e1cc2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: rename intel_drv.h to display/intel_display_types.h (bsc#1152489)
- commit ea9cf01
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: avoid including intel_drv.h via i915_drv.h->i915_trace.h (bsc#1152489)
- commit 9469eee
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tc: un-inline intel_tc_port_ref_held() (bsc#1152489)
- commit fddb79f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/mst: un-inline intel_dp_mst_encoder_active_links() (bsc#1152489)
- commit 004c4d2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/bw: make intel_atomic_get_bw_state() static (bsc#1152489)
- commit dd6eb1d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/irq: un-inline functions to avoid i915_drv.h include (bsc#1152489)
- commit c2498dc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/sprite: un-inline icl_is_hdr_plane() (bsc#1152489)
- commit dedcbd4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: move intel_display.c function declarations (bsc#1152489)
- commit 9a8690b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/dmc: Load DMC on TGL (bsc#1152489)
- commit 380a8c1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Move the [class][inst] lookup for engines onto the GT (bsc#1152489)
- commit 4201e4a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gem: Make caps.scheduler static (bsc#1152489)
- commit dc0f095
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use drm_i915_private directly from drv_get_drvdata() (bsc#1152489)
- commit 4125cd6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Remove stale kerneldoc for internal MOCS functions (bsc#1152489)
- commit 1bf4be6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Don't fail on HuC early init errors (bsc#1152489)
- commit 10a4996
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Remove redundant GuC support checks (bsc#1152489)
- commit 31c95e5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/huc: Prefer intel_huc_is_supported (bsc#1152489)
- commit 63ca2d3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Prefer intel_guc_is_submission_supported (bsc#1152489)
- commit f9c085b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Replace struct_mutex for batch pool serialisation (bsc#1152489)
- commit 96d5d15
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Teach execbuffer to take the engine wakeref not GT (bsc#1152489)
- commit 4250089
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Flush the freed object list on file close (bsc#1152489)
- commit 701d655
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Hide unshrinkable context objects from the shrinker (bsc#1152489)
- commit 254187c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/wopcm: Don't fail on WOPCM partitioning failure (bsc#1152489)
- commit 0ec7677
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Inject probe errors into intel_uc_init_hw (bsc#1152489)
- commit 7012921
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Move GuC error log to uc and release it on fini (bsc#1152489)
- commit 8d3cf3a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Reorder firmware status codes (bsc#1152489)
- commit 0c7744f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Do full sanitize instead of pure reset (bsc#1152489)
- commit eef47ab
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add i915 to i915_inject_probe_failure (bsc#1152489)
- commit 5bc4618
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Report resv_obj allocation failure (bsc#1152489)
- commit 749ad00
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Fix documentation for __intel_wait_for_register_fw* (bsc#1152489)
- commit e3d293a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/oa: update the generated files (bsc#1152489)
- commit e334d83
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Allow sharing the idle-barrier from other kernel requests (bsc#1152489)
- commit 2b59a84
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Flush extra hard after writing relocations through the GTT (bsc#1152489)
- commit 0178979
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/pmu: Atomically acquire the gt_pm wakeref (bsc#1152489)
- commit 048517c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/pmu: Make get_rc6 take intel_gt (bsc#1152489)
- commit ae2b419
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/pmu: Convert sampling to gt (bsc#1152489)
- commit 9d2901f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/pmu: Convert engine sampling to uncore mmio (bsc#1152489)
- commit c80261c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/pmu: Make more struct i915_pmu centric (bsc#1152489)
- commit 1c5d6bc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: allow the reg_read ioctl to read the RCS TIMESTAMP (bsc#1152489)
- commit e9e4946
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add and use new DC5 and DC6 residency counter registers (bsc#1152489)
- commit e9792db
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Stop sanitizing enable_guc modparam (bsc#1152489)
- commit 1e925c8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Use dedicated flag to track submission mode (bsc#1152489)
- commit 781c74d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Consider enable_guc modparam during fw selection (bsc#1152489)
- commit 1cc4e2d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Rename intel_uc_is_using* into intel_uc_supports* (bsc#1152489)
- commit 9344170
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Introduce intel_gt_runtime_suspend/resume (bsc#1152489)
- commit a0384c2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Move uC early functions inside the GT ones (bsc#1152489)
- commit 278795a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Move gt_cleanup_early out of gem_cleanup_early (bsc#1152489)
- commit 6a163a5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Remove lrc default desc from GEM context (bsc#1152489)
- commit 3a96153
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl: Don't forget to handle port C's hotplug interrupts (bsc#1152489)
- commit 9ac458a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/oa: add content to Makefile (bsc#1152489)
- commit ff627ad
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Always clear pending&inflight requests on reset (bsc#1152489)
- commit 2722ecf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl: Ungate DDIC and DDID (bsc#1152489)
- commit 07c2f89
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move MOCS setup to intel_mocs.c (bsc#1152489)
- commit fef3686
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Tigerlake only has global MOCS registers (bsc#1152489)
- commit 6ab1dc7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Define MOCS entries for Tigerlake (bsc#1152489)
- commit 5ed81ec
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: stop using ERROR_GEN6 and DONE_REG (bsc#1152489)
- commit 0c19bdc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Move fault registers to their new offset (bsc#1152489)
- commit af00b4d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: remove dangling forward declaration (bsc#1152489)
- commit 0539001
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Move uC WOPCM setup in uc_init_hw (bsc#1152489)
- commit 3e197bc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Don't enable communication twice on resume (bsc#1152489)
- commit 14baba6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Pass intel_context to igt_spinner (bsc#1152489)
- commit 44ecded
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Avoid ce->gem_context->i915 (bsc#1152489)
- commit e489756
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: make i915_selftest.h self-contained (bsc#1152489)
- commit 0397e43
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: handle DP aux interrupts (bsc#1152489)
- commit ea93660
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Update north display hotplug detection to TGL (bsc#1152489)
- commit 6aae638
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add hpd interrupt handling (bsc#1152489)
- commit 2b2218b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/volt: Fix for some cards having 0 maximum voltage (bsc#1152489)
- commit a08af0f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/dispnv50: Fix runtime PM ref tracking for non-blocking (bsc#1152489)
- commit b31828a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/dispnv04: Remove runtime PM (bsc#1152489)
- commit e33c2d8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/gpio: check function 76 in the power check as well (bsc#1152489)
- commit f9cb204
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/gpio: check the gpio function 16 in the power check as (bsc#1152489)
- commit 2fdc9ef
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/gpio: fail if gpu external power is missing (bsc#1152489)
- commit 1305044
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/bios/gpio: sort gpios by values (bsc#1152489)
- commit 967956b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/therm: don't attempt fan control where PMU is already (bsc#1152489)
- commit 59056c0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/therm: skip probing for devices not specified in thermal (bsc#1152489)
- commit a2111c6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/gv100-: attach pixel blend mode property to planes (bsc#1152489)
- commit 34dd24a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/gv100-: attach alpha property to planes (bsc#1152489)
- commit d641f6e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/gv100-: add support for plane zpos property (bsc#1152489)
- commit a7a2801
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/nv50-: attach immutable zpos property to planes (bsc#1152489)
- commit c9764d9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/nv50-: create primary plane before overlay planes (bsc#1152489)
- commit 908374f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/nv50-: use __drm_atomic_helper_plane_reset() (bsc#1152489)
- commit f16a4e9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/gv100-: implement csc + enable modern colour (bsc#1152489)
- commit 6cd3bad
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/gv100-: use premultiplied alpha blending between (bsc#1152489)
- commit c62f5a2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/nv50-: enable modern color management properties (bsc#1152489)
- commit bc76cf5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/gf119-: add ctm property support (bsc#1152489)
- commit 82c68fe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/nv50-: remove overlay alpha formats (bsc#1152489)
- commit c741ac8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/fifo/gk104-: fix parsing of mmu fault data (bsc#1152489)
- commit 9bbf19f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/fifo/gf1xx: convert to using nvkm_fault_data (bsc#1152489)
- commit bbbf08c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/bios/init: handle INIT_RESET_END devinit opcode (bsc#1152489)
- commit ed83034
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/bios/init: handle INIT_RESET_BEGUN devinit opcode (bsc#1152489)
- commit 24d9a65
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/bios: downgrade absence of tmds table to info from an (bsc#1152489)
- commit 295e6c9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: Disable atomic support on a per-device basis (bsc#1152489)
- commit a12b116
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/nv50-: add fp16 scanout support (bsc#1152489)
- commit f270e2d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/nv50-: disable input lut harder (bsc#1152489)
- commit 929e025
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/tu102-: disable input lut when input is already FP16 (bsc#1152489)
- commit f5a332d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/kms/gv100: allow windows to use PACKED8BPP formats (bsc#1152489)
- commit cd3f715
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: fix nvif/device.h is included more than once (bsc#1152489)
- commit cf7e895
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/dispnv04: subdev/bios.h is included more than once (bsc#1152489)
- commit b1a6f31
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/mmu: use struct_size() helper (bsc#1152489)
- commit 5452016
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: drop use of drmp.h (bsc#1152489)
- commit 14cbb05
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: drop drmP.h from all header files (bsc#1152489)
- commit fcfa54a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: drop drmP.h from nouveau_drv.h (bsc#1152489)
- commit cb911b9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: drop use of DRM_UDELAY (bsc#1152489)
- commit e77c670
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/bios/init: fix spelling mistake "CONDITON" -> "CONDITION" (bsc#1152489)
- commit 44490b8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau/secboot: Make acr_r352_ls_gpccs_func static (bsc#1152489)
- commit dca66ca
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: implement softpin (bsc#1152489)
- commit 52fb552
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: allow to request specific virtual address for gem (bsc#1152489)
- commit 281db82
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: skip command stream validation on PPAS capable GPUs (bsc#1152489)
- commit e5d978f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: implement per-process address spaces on MMUv2 (bsc#1152489)
- commit b45fea7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: provide MMU context to etnaviv_gem_mapping_get (bsc#1152489)
- commit 046957a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: split out starting of FE idle loop (bsc#1152489)
- commit a601ab8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: rework MMU handling (bsc#1152489)
- commit 3d31bdd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: replace MMU flush marker with flush sequence (bsc#1152489)
- commit fae9872
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: share a single cmdbuf suballoc region across all GPUs (bsc#1152489)
- commit a67dc71
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: split out cmdbuf mapping into address space (bsc#1152489)
- commit 0c30e1c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: simplify unbind checks (bsc#1152489)
- commit df5a85c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: pass mmu pointer to etnaviv_core_dump_mmu (bsc#1152489)
- commit 54681cc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: dump only failing submit (bsc#1152489)
- commit 3862897
* Tue Sep 29 2020 tzimmermann@suse.de
- etnaviv: perfmon: fix total and idle HI cyleces readout (bsc#1152489)
- commit aebcfe2
* Tue Sep 29 2020 tzimmermann@suse.de
- etnaviv: fix whitespace errors (bsc#1152489)
- commit 525276f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: remove unused function etnaviv_gem_mapping_reference (bsc#1152489)
- commit e030cd0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: fix etnaviv_cmdbuf_suballoc_new return value (bsc#1152489)
- commit 91e3413
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: clean up includes (bsc#1152489)
- commit 3e73b94
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: Use devm_platform_ioremap_resource() (bsc#1152489)
- commit e0f7654
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: drop use of drmP.h (bsc#1152489)
- commit f3eda79
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: rcar-du: lvds: Fix bridge_to_rcar_lvds (bsc#1152489)
- commit f81d681
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Remove bridge support from legacy helpers (bsc#1152489)
- commit d151f00
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Don't include drm/drm_encoder_slave.h when not needed (bsc#1152489)
- commit b56db2f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/xen-front: Make structure fb_funcs constant (bsc#1152472)
- commit 8f3c48c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vboxvideo: Make structure vbox_fb_helper_funcs constant (bsc#1152472)
- commit 875c989
* Tue Sep 29 2020 tzimmermann@suse.de
- dma-fence: Store the timestamp in the same union as the cb_list (bsc#1152472)
- commit d37cf9b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: tpo-td043mtea1: remove redundant assignment (bsc#1152472)
- commit dec206d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/omap: displays: Remove unused panel drivers (bsc#1152472)
- commit ba886f1
* Tue Sep 29 2020 tzimmermann@suse.de
- video: omapfb2: Make standard and custom panel drivers mutually (bsc#1152472)
- commit 6f1e68c
* Tue Sep 29 2020 tzimmermann@suse.de
- dma-buf: Restore seqlock around dma_resv updates (bsc#1152472)
- commit 67e4191
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: Add driver for the Toppoly TD043MTEA1 panel (bsc#1152472)
- commit 4f44c01
* Tue Sep 29 2020 tbogendoerfer@suse.de
- cxgb4/chcr : Register to tls add and del callback
  (jsc#SLE-15131).
- Update config files.
- Refresh
  patches.suse/Crypto-chelsio-Fixes-a-deadlock-between-rtnl_lock-an.patch.
- commit ff5b8de
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: Add driver for the Toppoly TD028TTEC1 panel (bsc#1152472)
- commit 467d1ca
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: Add driver for the Sony ACX565AKM panel (bsc#1152472)
- commit 377991a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: Add driver for the Sharp LS037V7DW01 panel (bsc#1152472)
- commit ffa7ccd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: Add driver for the NEC NL8048HL11 panel (bsc#1152472)
- commit ade6e3d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: Add driver for the LG Philips LB035Q02 panel (bsc#1152472)
- commit 32a7044
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/aspeed: gfc_crtc: Make structure aspeed_gfx_funcs constant (bsc#1152472)
- commit 5cd2e69
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/arm: drop use of drmP.h (bsc#1152472)
- commit 37f5a32
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/armada: drop use of drmP.h (bsc#1152472)
- commit a7e7a2f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tegra: drop use of drmP.h (bsc#1152472)
- commit 916e8ee
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i2c/tda998x: drop use of drmP.h (bsc#1152472)
- commit fc66dd1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: dumb-vga-dac: Fix dereferencing -ENODEV DDC channel (bsc#1152472)
- commit a38637f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi-i2s: add .get_eld support (bsc#1152472)
- commit c58ac49
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi-i2s: enable only the required i2s lanes (bsc#1152472)
- commit a5106b9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi-i2s: reset audio fifo before applying new params (bsc#1152472)
- commit 7f84e9b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi-i2s: set the channel allocation (bsc#1152472)
- commit f2c7258
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi-i2s: enable lpcm multi channels (bsc#1152472)
- commit 67ea1a7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi: set channel count in the infoframes (bsc#1152472)
- commit ecb6f94
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi: move audio channel setup out of ahb (bsc#1152472)
- commit 37b7eb9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi-i2s: support more i2s format (bsc#1152472)
- commit ad6f43e
* Tue Sep 29 2020 tzimmermann@suse.de
- dma-buf: rename reservation_object to dma_resv (bsc#1152472)
- commit 781a1ab
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Bump driver version to 1.1 (bsc#1152472)
- commit f346063
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Add support for GPU heap allocations (bsc#1152472)
- commit 8eb4e25
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Convert MMU IRQ handler to threaded handler (bsc#1152472)
- commit 3f6e35e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Consolidate reset handling (bsc#1152472)
- commit df575d7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Add a no execute flag for BO allocations (bsc#1152472)
- commit e9f5fb8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Split panfrost_mmu_map SG list mapping to its own (bsc#1152472)
- commit ba77501
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Restructure the GEM object creation (bsc#1152472)
- commit 1fdb92b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/shmem: Put pages independent of a SG table being set (bsc#1152472)
- commit b32f65d
* Tue Sep 29 2020 tbogendoerfer@suse.de
- crypto: aes - create AES library based on the fixed time AES
  code (jsc#SLE-15131).
- Update config files.
- Refresh
  patches.suse/crypto-chacha-move-existing-library-code-into-lib-crypto.patch.
- Refresh
  patches.suse/crypto-lib-tidy-up-lib-crypto-kconfig-and-makefile.patch.
- commit 7697bd4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/gem: Allow sparsely populated page arrays in drm_gem_put_pages (bsc#1152472)
- commit 64171d0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: gm12u320: Add -ENODEV to list of errors to ignore (bsc#1152472)
- commit 46b1524
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: gm12u320: Do not take a mutex from a wait_event condition (bsc#1152472)
- commit 897a723
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: gm12u320: Use DRM_DEV_ERROR everywhere (bsc#1152472)
- commit 950f899
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: gm12u320: Some minor cleanups (bsc#1152472)
- commit cee992d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/syncobj: Add better overview documentation for syncobj (v2) (bsc#1152472)
- commit 18dc6af
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Fix kerneldoc warns in connector-related docs (bsc#1152472)
- commit a073778
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/komeda: Fix potential integer overflow in (bsc#1152472)
- commit 4ca222c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: sun4i: Add support for enabling DDC I2C bus to sun8i_dw_hdmi (bsc#1152472)
- commit 9b7d499
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: drop return code from drm_panel_detach() (bsc#1152472)
- commit 22fcefe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: use inline comments in drm_panel.h (bsc#1152472)
- commit 590fc7d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: move drm_panel functions to .c file (bsc#1152472)
- commit 42298b3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: ili9322: move bus_flags to get_modes() (bsc#1152472)
- commit e6fd024
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mxsfb: fix opencoded use of drm_panel_* (bsc#1152472)
- commit 9704496
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/fsl-dcu: fix opencoded use of drm_panel_* (bsc#1152472)
- commit aebcdbf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/imx: fix opencoded use of drm_panel_* (bsc#1152472)
- commit 4c37f96
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: fix opencoded use of drm_panel_* (bsc#1152472)
- commit b810723
* Tue Sep 29 2020 tzimmermann@suse.de
- dma-buf: further relax reservation_object_add_shared_fence (bsc#1152472)
- commit 64b6b31
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: use new reservation_object_fences helper (bsc#1152472)
- commit 2f59b0d
* Tue Sep 29 2020 hare@suse.de
- block: Fix type of first compat_put_{,u}long() argument
  (bsc#1175995,jsc#SLE-15608).
- commit ce3e546
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: meson: venc: set the correct macrovision max amplitude value (bsc#1152472)
- commit 05229cd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: meson: add macro used to enable HDMI PLL (bsc#1152472)
- commit 7496064
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: meson: global clean-up (bsc#1152472)
- commit d6c9ef6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: meson: venc: use proper macros instead of magic constants (bsc#1152472)
- commit 751e799
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: meson: viu: use proper macros instead of magic constants (bsc#1152472)
- commit 98ac8a2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: meson: vpp: use proper macros instead of magic constants (bsc#1152472)
- commit 0add0f7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: meson: drv: use macro when initializing vpu (bsc#1152472)
- commit 7081d39
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: meson: crtc: use proper macros instead of magic constants (bsc#1152472)
- commit e3628d9
* Tue Sep 29 2020 hare@suse.de
- pktcdvd: fix regression on 64-bit architectures
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/compat_ioctl-cdrom-handle-CDROM_LAST_WRITTEN.patch.
- commit 7fb2169
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: meson: mask value when writing bits relaxed (bsc#1152472)
- commit ecded09
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: simple: Support TI nspire panels (bsc#1152472)
- commit 51061b0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/pl111: Support grayscale (bsc#1152472)
- commit d590c78
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Add madvise and shrinker support (bsc#1152472)
- commit 540c558
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/shmem: Add madvise state and purge helpers (bsc#1152472)
- commit 028a5e1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Remove completed features still in TODO (bsc#1152472)
- commit e151425
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vmwgfx: drop reminaing users of drmP.h (bsc#1152489)
- commit 9acd6cd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vmwgfx: drop use of drmP.h in header files (bsc#1152489)
- commit fb8b891
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: remove RREG64/WREG64 (bsc#1152489)
- commit 405c792
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: implement UMC 64 bits REG operations (bsc#1152489)
- commit bb96286
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: replace readq/writeq with atomic64 operations (bsc#1152489)
- commit 0c8fc0a
* Tue Sep 29 2020 tbogendoerfer@suse.de
- crypto: chelsio - Use multiple txq/rxq per tfm to process the
  requests (jsc#SLE-15129).
- Refresh
  patches.suse/Crypto-chcr-fix-for-ccm-aes-failed-test.patch.
- commit 8922bc6
* Tue Sep 29 2020 tzimmermann@suse.de
- gpu: drm: amd: powerplay: Remove logically dead code (bsc#1152489)
- commit b7a7345
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: Zero initialize some variables (bsc#1152489)
- commit a11fa8c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Fix GPU reset crash regression. (bsc#1152489)
- commit 4289c4a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: check before issuing messages for max sustainable (bsc#1152489)
- commit 055f6c4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/discovery: move common discovery code out of (bsc#1152489)
- commit dd56d65
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/soc15: fix external_rev_id for navi14 (bsc#1152489)
- commit 519397e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: update ras sysfs feature info (bsc#1152489)
- commit 5cf0857
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: skip pcie params override on Arcturus V2 (bsc#1152489)
- commit 3336b6f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Fix panic during gpu reset (bsc#1152489)
- commit b6ab46d
* Tue Sep 29 2020 hare@suse.de
- random: don't forget compat_ioctl on urandom
  (bsc#1175995,jsc#SLE-15608).
- ppp: fix out-of-bounds access in bpf_prog_create()
  (bsc#1175995,jsc#SLE-15608).
- commit da7510d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Block immediate flips for non-fast updates (bsc#1152489)
- commit 273f2c4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Validate dc_plane_info and dc_plane_size in atomic (bsc#1152489)
- commit a59ecb3
* Tue Sep 29 2020 tbogendoerfer@suse.de
- cxgb4/chcr: Save tx keys and handle HW response (jsc#SLE-15131).
- Refresh
  patches.suse/Crypto-chelsio-Fixes-a-deadlock-between-rtnl_lock-an.patch.
- commit fcecd4d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable Navi12 kfd support for amdgpu (bsc#1152489)
- commit d27c320
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add missing NV12 asic IDs (bsc#1152489)
- commit 6a088fe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Add nv12 DC ip block (bsc#1152489)
- commit 18717d1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add ASICREV_IS_NAVI macros (bsc#1152489)
- commit 1f0a486
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable DPG mode for Navi12 (bsc#1152489)
- commit 16dbff3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add VCN ip block for Navi12 (bsc#1152489)
- commit f335abe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add Navi12 VCN firmware support (bsc#1152489)
- commit 4b28d07
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add psp ip block for navi12 (bsc#1152489)
- commit 4c90629
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add smu ip block for navi12 (bsc#1152489)
- commit d6e2a91
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: start autoload till RLCG fw for navi12 (bsc#1152489)
- commit 11156c9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/psp11: add psp support for navi12 (bsc#1152489)
- commit e68e921
* Tue Sep 29 2020 tbogendoerfer@suse.de
- crypto: chtls - Add support for AES256-GCM based ciphers
  (jsc#SLE-15129).
- Refresh patches.suse/crypto-chtls-Fixed-memory-leak.patch.
- commit 9ff6836
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/smu11: add smu support for navi12 (bsc#1152489)
- commit 387d8fd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: correct smu rlc handshake enablement bit (bsc#1152489)
- commit c12bfc5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add CGTT_GS_NGG_CLK_CTRL register to gc header (bsc#1152489)
- commit 6389e54
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/sdma5: add golden settings for navi12 (v2) (bsc#1152489)
- commit 2c00f85
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: add golden settings for navi12 (v2) (bsc#1152489)
- commit 2a262b5
* Tue Sep 29 2020 tiwai@suse.de
- blacklist.conf: Add already cherry-picked ASoC entry
- commit 04deebb
* Tue Sep 29 2020 tiwai@suse.de
- ASoC: dt-bindings: sun4i-spdif: Fix dma-names warning
  (git-fixes).
- commit 40854e0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable virtual display for navi12 (bsc#1152489)
- commit 3b53a98
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: set tcp harvest for navi12 (bsc#1152489)
- commit b92b3be
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add ip blocks for navi12 (bsc#1152489)
- commit 251c9e1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gmc10: set gart size and vm size for navi12 (bsc#1152489)
- commit 6e1ecdf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/sdma5: add placeholder for navi12 golden settings (bsc#1152489)
- commit 1393572
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/sdma5: declare sdma firmwares for navi12 (bsc#1152489)
- commit b813084
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: set rlc funcs for navi12 (bsc#1152489)
- commit 40d262e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: set number of me(c)/pipe/queue for navi12 (bsc#1152489)
- commit 3134182
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: add placeholder for navi12 golden settings (bsc#1152489)
- commit 0073939
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: declare cp/rlc firmwares for navi12 (bsc#1152489)
- commit d8d1fcc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: add gfx config for navi12 (bsc#1152489)
- commit 15d9214
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: set gfx cg for navi12 (bsc#1152489)
- commit 5252cea
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: set nbio/hdp cg for navi12 (bsc#1152489)
- commit edfea18
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: initialize cg/pg flags and external rev id for navi12 (bsc#1152489)
- commit 661cd19
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: use front door firmware loading for navi12 (bsc#1152489)
- commit 22fa14e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: set asic family and ip blocks for navi12 (bsc#1152489)
- commit f99a2ef
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add gpu_info firmware for navi12 (bsc#1152489)
- commit 45cbade
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add navi12 asic type (bsc#1152489)
- commit c813d17
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: initialize reg base for navi12 (bsc#1152489)
- commit 13ff35e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add ip offset header for navi12 (v2) (bsc#1152489)
- commit 93498e8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: update SDMA V4 microcode init (bsc#1152489)
- commit bb2236a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: extend PSP FW loading support to 8 SDMA instances (bsc#1152489)
- commit 8d9637e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: disable MEC2 JT context init for Arcturus (bsc#1152489)
- commit 7f3395a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: update PSP CMD fail response status print (bsc#1152489)
- commit 880de8c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add PSP KDB loading support for Arcturus (bsc#1152489)
- commit 066354b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add PSP SW init support for Arcturus (bsc#1152489)
- commit 9ba2a61
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: removed duplicate line (bsc#1152489)
- commit af886d8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: enable SW SMU power profile switch support in KFD (bsc#1152489)
- commit e75b12c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: support power profile retrieval and setting on (bsc#1152489)
- commit e7f2c96
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: guard consistency between CPU copy and local VRAM (bsc#1152489)
- commit 7dd43e4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: replace AMDGPU_RAS_UE with AMDGPU_RAS_SUCCESS (bsc#1152489)
- commit 94d2678
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: only uncorrectable error needs gpu reset (bsc#1152489)
- commit 1ed77ca
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: update the calc algorithm of umc ecc error count (bsc#1152489)
- commit eb9211c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: implement umc ras init function (bsc#1152489)
- commit c52e42f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: support ce interrupt in ras module (bsc#1152489)
- commit 4230875
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add error address query for umc ras (bsc#1152489)
- commit 267573e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: apply umc_for_each_channel macro to umc_6_1 (bsc#1152489)
- commit 3d42ae1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add macro of umc for each channel (bsc#1152489)
- commit 4e31cb3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: initialize new parameters and functions for amdgpu_umc (bsc#1152489)
- commit da419a0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add more parameters and functions to amdgpu_umc structure (bsc#1152489)
- commit d46e8f0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: remove the clear of MCA_ADDR (bsc#1152489)
- commit 716ad72
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Don't replace the dc_state for fast updates (bsc#1152489)
- commit 0394981
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Skip determining update type for async updates (bsc#1152489)
- commit d560ba5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Allow cursor async updates for framebuffer swaps (bsc#1152489)
- commit 87a3858
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix unsigned variable instance compared to less than zero (bsc#1152489)
- commit 77ee609
* Tue Sep 29 2020 tbogendoerfer@suse.de
- i40e: always propagate error value in i40e_set_vsi_promisc()
  (jsc#SLE-13701).
- i40e: fix return of uninitialized aq_ret in i40e_set_vsi_promisc
  (jsc#SLE-13701).
- cxgb4: Fix race between loopback and normal Tx path
  (jsc#SLE-15131).
- cxgb4: Fix work request size calculation for loopback test
  (jsc#SLE-15131).
- cxgb4: add TC-MATCHALL IPv6 support (jsc#SLE-15131).
- cxgb4: fix extracting IP addresses in TC-FLOWER rules
  (jsc#SLE-15131).
- cxgb4: fix check for running offline ethtool selftest
  (jsc#SLE-15131).
- cxgb4: add loopback ethtool self-test (jsc#SLE-15131).
- cxgb4: use eth_zero_addr() to clear mac address (jsc#SLE-15131).
- crypto/chtls: Enable tcp window scaling option (jsc#SLE-15129).
- cxgb4: convert to new udp_tunnel_nic infra (jsc#SLE-15131).
- cxgb4: add main VI to mirror VI config replication
  (jsc#SLE-15131).
- cxgb4: add support for mirror Rxqs (jsc#SLE-15131).
- cxgb4: add mirror action to TC-MATCHALL offload (jsc#SLE-15131).
- cxgb4vf: configure ports accessible by the VF (jsc#SLE-15131).
- cxgb4vf: fix t4vf_eth_xmit()'s return type (jsc#SLE-15131).
- cxgb4: move device dump arrays in header to C file
  (jsc#SLE-15131).
- cxgb4: always sync access when flashing PHY firmware
  (jsc#SLE-15131).
- cxgb4: Use struct_size() helper (jsc#SLE-15131).
- cxgb4: add action to steer flows to specific Rxq
  (jsc#SLE-15131).
- cxgb4: add support to fetch ethtool n-tuple filters
  (jsc#SLE-15131).
- cxgb4: add ethtool n-tuple filter deletion (jsc#SLE-15131).
- cxgb4: add ethtool n-tuple filter insertion (jsc#SLE-15131).
- cxgb4: add skeleton for ethtool n-tuple filters (jsc#SLE-15131).
- cxgb4: add support to read serial flash (jsc#SLE-15131).
- cxgb4: add support to flash boot cfg image (jsc#SLE-15131).
- cxgb4: add support to flash boot image (jsc#SLE-15131).
- cxgb4: add support to flash PHY image (jsc#SLE-15131).
- cxgb4: update set_flash to flash different images
  (jsc#SLE-15131).
- crypto: chelsio - Fix some pr_xxx messages (jsc#SLE-15129).
- crypto: chelsio - Avoid some code duplication (jsc#SLE-15129).
- crypto: chelsio - permit asynchronous skcipher as fallback
  (jsc#SLE-15129).
- cxgb4: add missing release on skb in uld_send() (jsc#SLE-15131).
- crypto/chtls: correct net_device reference count
  (jsc#SLE-15129).
- crypto/chtls: fix tls alert messages corrupted by tls data
  (jsc#SLE-15129).
- cxgb4: fix all-mask IP address comparison (jsc#SLE-15131).
- net: cxgb4: fix return error value in t4_prep_fw
  (jsc#SLE-15131).
- cxgb4vf: update kernel-doc line comments (jsc#SLE-15131).
- cxgb4: update kernel-doc line comments (jsc#SLE-15131).
- cxgb4: fix set but unused variable when DCB is disabled
  (jsc#SLE-15131).
- cxgb4: move DCB version extern to header file (jsc#SLE-15131).
- cxgb4: remove cast when saving IPv4 partial checksum
  (jsc#SLE-15131).
- cxgb4: fix SGE queue dump destination buffer context
  (jsc#SLE-15131).
- cxgb4: use correct type for all-mask IP address comparison
  (jsc#SLE-15131).
- cxgb4: fix endian conversions for L4 ports in filters
  (jsc#SLE-15131).
- cxgb4: parse TC-U32 key values and masks natively
  (jsc#SLE-15131).
- cxgb4: use unaligned conversion for fetching timestamp
  (jsc#SLE-15131).
- cxgb4: move PTP lock and unlock to caller in Tx path
  (jsc#SLE-15131).
- cxgb4: move handling L2T ARP failures to caller (jsc#SLE-15131).
- crypto: Replace zero-length array with flexible-array
  (jsc#SLE-15129).
- Crypto/chcr: Checking cra_refcnt before unregistering the
  algorithms (jsc#SLE-15129).
- Crypto/chcr: Calculate src and dst sg lengths separately for
  dma map (jsc#SLE-15129).
- cxgb4: Use kfree() instead kvfree() where appropriate
  (jsc#SLE-15131).
- crypto/chtls:Fix compile error when CONFIG_IPV6 is disabled
  (jsc#SLE-15129).
- crypto/chcr: error seen if CONFIG_CHELSIO_TLS_DEVICE isn't set
  (jsc#SLE-15131).
- crypto/chtls: IPv6 support for inline TLS (jsc#SLE-15129).
- Crypto/chcr: Fixes a coccinile check error (jsc#SLE-15129).
- Crypto/chcr: Fixes compilations warnings (jsc#SLE-15129).
- crypto/chcr: IPV6 code needs to be in CONFIG_IPV6
  (jsc#SLE-15131).
- cxgb4/chcr: Enable ktls settings at run time (jsc#SLE-15131).
- cxgb4: cleanup error code in setup_sge_queues_uld()
  (jsc#SLE-15131).
- cxgb4: add adapter hotplug support for ULDs (jsc#SLE-15131).
- cxgb4: Use %%pM format specifier for MAC addresses
  (jsc#SLE-15131).
- cxgb4: add EOTID tracking and software context dump
  (jsc#SLE-15131).
- cxgb4: tune burst buffer size for TC-MQPRIO offload
  (jsc#SLE-15131).
- cxgb4: improve credits recovery in TC-MQPRIO Tx path
  (jsc#SLE-15131).
- cxgb4: remove duplicate headers (jsc#SLE-15131).
- Crypto/chcr: fix for hmac(sha) test fails (jsc#SLE-15129).
- Crypto/chcr: support for 48 byte key_len in aes-xts
  (jsc#SLE-15129).
- Crypto/chcr: fix ctr, cbc, xts and rfc3686-ctr failed tests
  (jsc#SLE-15129).
- Crypto/chcr: fix gcm-aes and rfc4106-gcm failed tests
  (jsc#SLE-15129).
- Revert "crypto: chelsio - Inline single pdu only"
  (jsc#SLE-15129).
- cxgb4/cxgb4vf: Remove superfluous void * cast in
  debugfs_create_file() call (jsc#SLE-15131).
- crypto: chelsio - remove redundant assignment to variable error
  (jsc#SLE-15129).
- cxgb4/chcr: avoid -Wreturn-local-addr warning (jsc#SLE-15129).
- cxgb4: Add missing annotation for service_ofldq()
  (jsc#SLE-15131).
- chcr: Fix CPU hard lockup (jsc#SLE-15131).
- net/cxgb4: Check the return from t4_query_params properly
  (jsc#SLE-15131).
- crypto/chcr: Add missing include file <linux/highmem.h>
  (jsc#SLE-15131).
- crypto: chelsio - remove set but not used variable 'adap'
  (jsc#SLE-15129).
- crypto: chelsio/chtls - Fixed boolinit.cocci warning
  (jsc#SLE-15129).
- crypto: chelsio/chtls - Fixed tls stats (jsc#SLE-15129).
- crypto: chelsio - Recalculate iv only if it is needed
  (jsc#SLE-15129).
- crypto: chelsio - un-register crypto algorithms (jsc#SLE-15131).
- crypto: chelsio - Endianess bug in create_authenc_wr
  (jsc#SLE-15129).
- crypto: chelsio - remove extra allocation for chtls_dev
  (jsc#SLE-15129).
- crypto: chelsio - Print the chcr driver information while
  module load (jsc#SLE-15131).
- crypto: chelsio - This fixes the kernel panic which occurs
  during a libkcapi test (jsc#SLE-15129).
- crypto: chelsio - This fixes the libkcapi's cbc(aes) aio fail
  test cases (jsc#SLE-15129).
- cxgb4/chcr: nic-tls stats in ethtool (jsc#SLE-15131).
- crypto/chtls: Fix chtls crash in connection cleanup
  (jsc#SLE-15129).
- crypto/chcr: fix incorrect ipv6 packet length (jsc#SLE-15131).
- cxgb4: Add support to catch bits set in INT_CAUSE5
  (jsc#SLE-15131).
- cxgb4: remove set but not used variable 'tab' (jsc#SLE-15131).
- Crypto/chtls: add/delete TLS header in driver (jsc#SLE-15129).
- cxgb4: rework TC filter rule insertion across regions
  (jsc#SLE-15131).
- chcr: remove set but not used variable 'status' (jsc#SLE-15131).
- cxgb4: update T5/T6 adapter register ranges (jsc#SLE-15131).
- net: cxgb4vf: reject unsupported coalescing params
  (jsc#SLE-15131).
- net: cxgb4: reject unsupported coalescing params
  (jsc#SLE-15131).
- cxgb4/chcr: Add ipv6 support and statistics (jsc#SLE-15131).
- chcr: Handle first or middle part of record (jsc#SLE-15131).
- chcr: handle partial end part of a record (jsc#SLE-15131).
- cxgb4/chcr: complete record tx handling (jsc#SLE-15131).
- net/chelsio: Don't set N/A for not available FW (jsc#SLE-15131).
- chelsio: Replace zero-length array with flexible-array member
  (jsc#SLE-15131).
- cxgb4/ptp: pass the sign of offset delta in FW CMD
  (jsc#SLE-15131).
- cxgb4: fix checks for max queues to allocate (jsc#SLE-15131).
- crypto: chtls - Fixed listen fail when max stid range reached
  (jsc#SLE-15129).
- crypto: chtls - Corrected function call context (jsc#SLE-15129).
- crypto: chelsio - Resetting crypto counters during the driver
  unregister (jsc#SLE-15131).
- crypto: chelsio - calculating tx_channel_id as per the max
  number of channels (jsc#SLE-15129).
- crypto: chelsio - switch to skcipher API (jsc#SLE-15129).
- crypto: chtls - remove the redundant check in chtls_recvmsg()
  (jsc#SLE-15129).
- crypto: chtls - simplify a bit 'create_flowc_wr_skb()'
  (jsc#SLE-15129).
- crypto: x86/aes-ni - use AES library instead of single-use
  AES cipher (jsc#SLE-15129).
- crypto: chelsio - Rename arrays to avoid conflict with
  crypto/sha256.h (jsc#SLE-15129).
- crypto: x86/xts - implement support for ciphertext stealing
  (jsc#SLE-15129).
- crypto: aes-generic - remove unused variable 'rco_tab'
  (jsc#SLE-15129).
- crypto: gcm - helper functions for assoclen/authsize check
  (jsc#SLE-15129).
- crypto: aes-generic - unexport last-round AES tables
  (jsc#SLE-15129).
- crypto: chelsio - replace AES cipher calls with library calls
  (jsc#SLE-15131).
- crypto: aes-generic - drop key expansion routine in favor of
  library version (jsc#SLE-15129).
- crypto: padlock/aes - switch to library version of key expansion
  routine (jsc#SLE-15129).
- crypto: x86/aes - drop scalar assembler implementations
  (jsc#SLE-15129).
- crypto: x86/aes-ni - switch to generic for fallback and key
  routines (jsc#SLE-15129).
- crypto: aes/fixed-time - align key schedule with other
  implementations (jsc#SLE-15131).
- crypto: aes - rename local routines to prevent future clashes
  (jsc#SLE-15129).
- commit 6c96ac0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: fix a few spelling mistakes (bsc#1152489)
- commit 20b4179
* Tue Sep 29 2020 tzimmermann@suse.de
- gpu: drm: radeon: Fix a possible null-pointer dereference in (bsc#1152489)
- commit a3611ff
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: fix off-by-one upper bounds limit checks (bsc#1152489)
- commit cda5adb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: Fix EEH during kexec (bsc#1152489)
- commit 2a544aa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Extend CU mask to 8 SEs (v3) (bsc#1152489)
- commit 0acbb25
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: support get_cu_info for Arcturus (bsc#1152489)
- commit c474563
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Fix pcie_bw on Vega20 (bsc#1152489)
- commit 79f4b92
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Update NBIO headers to add TXCLK3/4 (bsc#1152489)
- commit a2ff658
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Add amdgpu_asic_funcs.reset_method for Vega20 (bsc#1152489)
- commit 0bef5bb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Mark KFD VRAM allocations for wipe on release (bsc#1152489)
- commit 5803e25
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Implement VRAM wipe on release (bsc#1152489)
- commit a58ec87
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Add flag to wipe VRAM on release (bsc#1152489)
- commit 9f14f08
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ttm: Add release_notify callback to ttm_bo_driver (bsc#1152489)
- commit 567bc13
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Use switch table for dc_to_smu_clock_type (bsc#1152489)
- commit 55dd84f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Use proper enum conversion functions (bsc#1152489)
- commit 4b5249d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix double ucode load by PSP(v3) (bsc#1152489)
- commit 8b0f29f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: fix incorrect judge on sos fw version (bsc#1152489)
- commit 753b3b7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: cleanup vega10 SRIOV code path (bsc#1152489)
- commit 449e960
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: sort feature status index by asic feature id for (bsc#1152489)
- commit bdc65ca
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: enable KFD support for navi14 (bsc#1152489)
- commit 80d78ca
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: disable inject for failed subblocks of gfx (bsc#1152489)
- commit 20e5c2b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: support gfx ras error injection and err_cnt query (bsc#1152489)
- commit 597abb3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add RAS callback for gfx (bsc#1152489)
- commit b745094
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add define for gfx ras subblock (bsc#1152489)
- commit 3c44631
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/include: add define of TCP_EDC_CNT_NEW (bsc#1152489)
- commit 0974c47
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/include: add bitfield define for EDC registers (bsc#1152489)
- commit 0cbc483
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: remove ras_reserve_vram in ras injection (bsc#1152489)
- commit ced6998
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add check for ras error type (bsc#1152489)
- commit 4999f96
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: update interrupt callback for all ras clients (bsc#1152489)
- commit d88104a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: allow ras interrupt callback to return error data (bsc#1152489)
- commit 46ed6a0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: query umc ras error address (bsc#1152489)
- commit 6f5c9a3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add structures for umc error address translation (bsc#1152489)
- commit 8be9eee
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add support for recording ras error address (bsc#1152489)
- commit 7f39ee7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: update algorithm of umc uncorrectable error counting (bsc#1152489)
- commit 71b2a41
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: switch to amdgpu_umc structure (bsc#1152489)
- commit f743c8b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: use 64bit operation macros for umc (bsc#1152489)
- commit 25490b4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add RREG64/WREG64(_PCIE) operations (bsc#1152489)
- commit d72a792
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add ras error count after each query (v2) (bsc#1152489)
- commit 4138ef2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: querry umc error count (bsc#1152489)
- commit e117063
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: init umc v6_1 functions for vega20 (bsc#1152489)
- commit 60e0f3b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add umc v6_1 query error count support (bsc#1152489)
- commit 8a25980
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add umc v6_1_1 IP headers (bsc#1152489)
- commit 134a0a5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add rsmu v_0_0_2 ip headers (bsc#1152489)
- commit 4b6389b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add amdgpu_umc_functions structure (bsc#1152489)
- commit 2a8f5bb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: init RSMU and UMC ip base address for vega20 (bsc#1152489)
- commit 5b681c1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: move some ras data structure to amdgpu_ras.h (bsc#1152489)
- commit c11eafd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: drop drmP.h from vcn_v2_5.c (bsc#1152489)
- commit ac472db
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: drop drmP.h from vcn_v2_0.c (bsc#1152489)
- commit 57390a2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: drop drmP.h from sdma_v5_0.c (bsc#1152489)
- commit e6021a8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: drop drmP.h from nv.c (bsc#1152489)
- commit 1be95ea
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: drop drmP.h from navi10_ih.c (bsc#1152489)
- commit 1237a9a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: drop drmP.h in gfx_v10_0.c (bsc#1152489)
- commit 793a94e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: drop drmP.h from amdgpu_amdkfd_gfx_v10.c (bsc#1152489)
- commit 61454c6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: drop drmP.h in amdgpu_amdkfd_arcturus.c (bsc#1152489)
- commit 7af4b47
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: determine the features to enable by pptable only (bsc#1152489)
- commit 1279f9b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: correct irq type used for sdma ecc (bsc#1152489)
- commit 8794064
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: make power limit retrieval as asic specific (bsc#1152489)
- commit 71952d6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: correct arcturus current clock level calculation (bsc#1152489)
- commit ca2d403
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: support UMD PSTATE settings on arcturus (bsc#1152489)
- commit bdefb20
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: fix arcturus real-time clock frequency retrieval (bsc#1152489)
- commit 007877a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: remove redundancy debug log in smu (bsc#1152489)
- commit 09c23f9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: correct the bitmask used in arcturus (bsc#1152489)
- commit 18996e7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: add missing arcturus feature maps (bsc#1152489)
- commit 53e9f8c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: support fan speed retrieval on arcturus (bsc#1152489)
- commit 198e84d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: support real-time clock retrieval on arcturus (bsc#1152489)
- commit e13c175
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: support sensor reading on arcturus (bsc#1152489)
- commit 69d6210
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: init arcturus SMU metrics table on bootup (bsc#1152489)
- commit 3284a90
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: update more sdma instances irq support (bsc#1152489)
- commit ff16027
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/include: adjust base offset of SMUIO and THM for Arcturus (bsc#1152489)
- commit 3c2d3ff
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: hold on the arcturus gfx dpm support in driver (bsc#1152489)
- commit 8b7b8d4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: correct VCN powergate routine for acturus (bsc#1152489)
- commit c38ce95
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: enable arcturus powerplay (bsc#1152489)
- commit f61fd9f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: initialize arcturus MP1 and THM base address (bsc#1152489)
- commit c8cc16c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: enable SW SMU routine support for arcturus (bsc#1152489)
- commit 0298083
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: update arcturus_ppt.c/h V3 (bsc#1152489)
- commit a0fa271
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: update arcturus_ppsmc.h (bsc#1152489)
- commit fd0b2fb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: update smu11_driver_if_arcturus.h (bsc#1152489)
- commit 6594378
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: add SW SMU interface for dumping pptable out (v2) (bsc#1152489)
- commit dda17f8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: add smcdpminfo table v4_6 support (bsc#1152489)
- commit 1b05d55
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Save/restore vcc on gfx10 (bsc#1152489)
- commit bb97e13
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Save/restore flat_scratch_lo/hi on gfx10 (bsc#1152489)
- commit d79ee3a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Fix gfx10 wave64 VGPR context restore (bsc#1152489)
- commit bc55bc8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Support uclk switching for DCN2 (bsc#1152489)
- commit 767399c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Embed DCN2 SOC bounding box (bsc#1152489)
- commit 6cf2a57
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: provide the interface to disable uclk switch (bsc#1152489)
- commit b440815
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: update golden settings for navi14 (bsc#1152489)
- commit 2f59d63
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: implment sysfs feature status function in smu (bsc#1152489)
- commit 27ca7ae
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: move smu_feature_update_enable_state to up level (bsc#1152489)
- commit 443eed3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: add smu feature name support (bsc#1152489)
- commit 92a3cd1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: add smu message name support (bsc#1152489)
- commit a8bead9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: move smu types to smu_types.h (bsc#1152489)
- commit 6574e9a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Default disable GDS for compute+gfx (bsc#1152489)
- commit 6c3b66f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/display: fix the build without (bsc#1152489)
- commit b16cded
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Fix amdgpu_display_supported_domains logic. (bsc#1152489)
- commit 654e21f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: put the SMC into the proper state on reset/unload (bsc#1152489)
- commit 1a53690
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add set_mp1_state for vega12 (bsc#1152489)
- commit a0f6bd4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add set_mp1_state for vega10 (bsc#1152489)
- commit 55db491
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add set_mp1_state for vega20 (bsc#1152489)
- commit a01642a
* Tue Sep 29 2020 mbenes@suse.cz
- tracing: fix double free (git-fixes).
- commit dd7027e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: return success if set_mp1_state is not set (bsc#1152489)
- commit 67dee8e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add a new interface to set the mp1 state (bsc#1152489)
- commit 114ca33
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add reset_method asic callback for navi (bsc#1152489)
- commit ad29ff9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add reset_method asic callback for soc15 (bsc#1152489)
- commit c51cbc4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add reset_method asic callback for vi (bsc#1152489)
- commit 7cbd77e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add reset_method asic callback for cik (bsc#1152489)
- commit eb3f054
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add reset_method asic callback for si (bsc#1152489)
- commit 83158b4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add an asic callback to determine the reset method (bsc#1152489)
- commit 7494c8f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: minor fixes around SW SMU power and fan setting (bsc#1152489)
- commit ebbf67f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: enable S/G for RAVEN chip (bsc#1152489)
- commit bb48767
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Add check for USWC support for (bsc#1152489)
- commit 1c7c5c6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Create helper to clear AMDGPU_GEM_CREATE_CPU_GTT_USWC (bsc#1152489)
- commit 017fe05
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Fix hard hang for S/G display BOs. (bsc#1152489)
- commit f76ecc1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: adding xgmi error monitoring (bsc#1152489)
- commit d50854e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add perfmon and fica atomics for df (bsc#1152489)
- commit 246c3b2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Remove dead code from gfx8/gfx9 trap handlers (bsc#1152489)
- commit f3ba626
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Replace gfx10 trap handler with correct branch (bsc#1152489)
- commit 59dd6fd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Fix lost single step exceptions in gfx9 trap handler (bsc#1152489)
- commit 450b8c5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Use SQC when TCP would fail in gfx9 context save. (bsc#1152489)
- commit f01c0b9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gmc10: fix pte mytpe field error for navi14 (bsc#1152489)
- commit 90804b4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: some cosmetic fixes (bsc#1152489)
- commit a1d8fef
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: no pptable transfer and dpms enabled with "dpm=0" (bsc#1152489)
- commit be80727
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix a missing null check on a failed kzalloc (bsc#1152489)
- commit 9765827
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: Use dev_get_drvdata where possible (bsc#1152489)
- commit ce0254d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Use dev_get_drvdata (bsc#1152489)
- commit 426742e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Use dev_get_drvdata where possible (bsc#1152489)
- commit a9c1c1d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: set sdma irq src num according to sdma instances (bsc#1152489)
- commit 993ced9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Copy GSL groups when committing a new context (bsc#1152489)
- commit df4476c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add debug entry to destroy disconnected edp link (bsc#1152489)
- commit fc62a22
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: avoid power gate domains that doesn't exist (bsc#1152489)
- commit 4c2908c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add SMU version field to clk_mgr_internal (bsc#1152489)
- commit 80701cb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: support "dummy pstate" (bsc#1152489)
- commit f80168e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix mpcc assert condition (bsc#1152489)
- commit 01fbfe3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.42 (bsc#1152489)
- commit 02a969c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Clean up dynamic metadata logic (bsc#1152489)
- commit a1e462c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: populate last calculated bb state with max clocks (bsc#1152489)
- commit 5f21dc0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add dcc programming for dual plane (bsc#1152489)
- commit 17a6b2a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Implement DAL3 GPU Integer Scaling (bsc#1152489)
- commit 3065140
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add pipe CRC sources without disabling dithering. (bsc#1152489)
- commit 756b2fb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: use min disp and dpp clk debug option for dcn2 (bsc#1152489)
- commit 94c2a25
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add a option to force the clock at every mode (bsc#1152489)
- commit 65215f4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Change offset_to_id to reflect what id_to_offset (bsc#1152489)
- commit 50fefa6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add set and get clock for testing purposes (bsc#1152489)
- commit d3a1728
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Hook up calls to do stereo mux and dig programming (bsc#1152489)
- commit 157c677
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.41 (bsc#1152489)
- commit 1b945d4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Fixes for some MPO cases (bsc#1152489)
- commit 6428285
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Cache the use_pitch_c conditional (bsc#1152489)
- commit b11b964
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add DIG_CLOCK_PATTERN register (bsc#1152489)
- commit babf617
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add CM_BYPASS via debug option (bsc#1152489)
- commit d3b5d26
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add MPC 3DLUT resource management (bsc#1152489)
- commit c2449da
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add debug option to disable timing sync (bsc#1152489)
- commit 0660e4e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Clear FEC_READY shadow register if DPCD write fails (bsc#1152489)
- commit cf374f8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Optimize gamma calculations (bsc#1152489)
- commit f086612
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Set FEC_READY always before link training (bsc#1152489)
- commit 5cb290e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Use helper for determining HDMI signal (bsc#1152489)
- commit 326fb85
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Implement generic MUX registers (v2) (bsc#1152489)
- commit ffe13de
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.40 (bsc#1152489)
- commit 5a30b69
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: move isdn/capi ioctl translation into
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/compat_ioctl-move-hci_sock-handlers-into-driver.patch.
- Refresh
  patches.suse/compat_ioctl-move-rfcomm-handlers-into-driver.patch.
- commit 2bc424e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Remove second initialization of pp_smu (bsc#1152489)
- commit cb4916a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: fix not calling ppsmu to trigger PME (bsc#1152489)
- commit e447ba2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Remove unnecessary NULL check in (bsc#1152489)
- commit eac1b5c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Do not fill Null packet in the blank period (bsc#1152489)
- commit ba19b24
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Power-gate all DSCs at driver init time (bsc#1152489)
- commit f3bb995
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Remove dsc disable_ich flag programming. (bsc#1152489)
- commit c7b91b9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Fix some HUBP programming issues (bsc#1152489)
- commit 2685737
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Expose enc2_set_dynamic_metadata (bsc#1152489)
- commit b24e0aa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.39 (bsc#1152489)
- commit 2d4ea85
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add functionality to get pipe CRC source. (bsc#1152489)
- commit b6e1415
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add functionality to grab DPRX CRC entries. (bsc#1152489)
- commit 2c0cd7f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add monitor patch to add T7 delay (bsc#1152489)
- commit c48c9c2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add hdmi2.1 dsc pps packet programming (bsc#1152489)
- commit 859e97e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: refactor dump_clk_registers (bsc#1152489)
- commit b1855c9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display:Use Pixel clock in 100Hz units for HDMI Audio wall (bsc#1152489)
- commit 295a02d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Incorrect Read Interval Time For CR Sequence (bsc#1152489)
- commit 831c3c3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.38 (bsc#1152489)
- commit bd1754c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Split out common HUBP registers and code (bsc#1152489)
- commit 50c933a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: early return when pipe_cnt is 0 in bw validation (bsc#1152489)
- commit 6d58f5e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Update drm_dsc to reflect native 4.2.0 DSC spec (bsc#1152489)
- commit 0caa0f8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add aux tracing log in dce (bsc#1152489)
- commit fc66a5a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: move bw calc code into helpers (bsc#1152489)
- commit 8b93daa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.37 (bsc#1152489)
- commit 6c7c586
* Tue Sep 29 2020 hare@suse.de
- series.conf: refresh patch order
- commit 5f89670
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: 3.2.36 (bsc#1152489)
- commit a1bcf42
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Add ability to set preferred link training (bsc#1152489)
- commit 8acdaca
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu:  exposing fica registers to df offsets (bsc#1152489)
- commit b836de3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: input check for unsupported message/clock index (bsc#1152489)
- commit 282c8cc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: correct SW SMU valid mapping check (bsc#1152489)
- commit 000219c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: flag arcturus as experimental for now (bsc#1152489)
- commit 3f6800d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: drop unused function definitions (bsc#1152489)
- commit 8103022
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu:add all VCN rings into schedule request queue (bsc#1152489)
- commit 441e243
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Increase vcrat size for GPU (bsc#1152489)
- commit 76d7634
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable all 8 sdma instances for Arcturus silicon (bsc#1152489)
- commit 7a6e2fa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Merge gfx9/arcturus trap handlers, add ACC VGPR save (bsc#1152489)
- commit 19c8e75
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Add more detail to the VM fault printing (bsc#1152489)
- commit aed0be3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Add device id for real asics (bsc#1152489)
- commit 0db6c2a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: limit sdma instances to 2 for Arcturus in BU phase (bsc#1152489)
- commit b47c154
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: skip gfx 9 common golden settings for arct (bsc#1152489)
- commit f0030c6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Add arcturus CWSR trap handler (bsc#1152489)
- commit c291ed6
* Tue Sep 29 2020 tzimmermann@suse.de
- amd/powerplay: No SW XGMI dpm for Arcturus rev 2 (bsc#1152489)
- commit 353fe0f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: clean up nonexistent firmware declaration for Arcturus (bsc#1152489)
- commit e0cbf4a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: init gds config for arct (bsc#1152489)
- commit 10c7e22
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: keep stolen memory for arct (bsc#1152489)
- commit 9738d9a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: init arct external rev id (bsc#1152489)
- commit ae98f94
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add arct gc golden settings (bsc#1152489)
- commit e1aca94
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add arct sdma golden settings (bsc#1152489)
- commit f1ab50a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add pci DID for Arcturus GL-XL. (bsc#1152489)
- commit aa42a9b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: assign fb_start/end in mmhub v9.4 interface (bsc#1152489)
- commit 6357453
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add harvest support for Arcturus (bsc#1152489)
- commit 68da984
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add multiple instances support for Arcturus (bsc#1152489)
- commit a03725f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: modify amdgpu_vcn to support multiple instances (bsc#1152489)
- commit 706f739
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add vcn nbio doorbell range setting for 2nd vcn instance (bsc#1152489)
- commit 36ba2a5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/: increase AMDGPU_MAX_RINGS to add 2nd vcn instance (bsc#1152489)
- commit 8f63f5e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/: add doorbell assignment for 2nd vcn instance (bsc#1152489)
- commit 580c4e4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/: add ucodeID for 2nd vcn instance (bsc#1152489)
- commit c2fde66
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/: add clientID for 2nd vcn instance (bsc#1152489)
- commit 16898e6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Set number of xgmi optimized SDMA engines for arcturus (bsc#1152489)
- commit edcbb37
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: correct ip for mmHDP_READ_CACHE_INVALIDATE register (bsc#1152489)
- commit a905f5b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: set system aperture to cover whole FB region in mmhub (bsc#1152489)
- commit 54f3fb4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: skip get/update xgmi topology info when no psp exists (bsc#1152489)
- commit 3c5d3dd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: get smc firmware and pptable (bsc#1152489)
- commit fdc841e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add smu11 driver interface for arcturus. (v2) (bsc#1152489)
- commit a89f19e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/powerplay: add arcturus ppt functions (bsc#1152489)
- commit 0fb03f4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable the Doorbell support for VCN2.5 (bsc#1152489)
- commit 4c8b5d0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add vcn doorbell range function to nbio7.4 (v2) (bsc#1152489)
- commit 369703c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable VCN2.5 on Arcturus (bsc#1152489)
- commit 0164510
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/VCN2.5: set JPEG decode ring functions (bsc#1152489)
- commit e4933b5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add JPEG2.5 HW start and stop (bsc#1152489)
- commit 7cb1f4d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/VCN2.5: set encode ring functions (bsc#1152489)
- commit 97c6e56
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/VCN2.5: set decode ring functions (bsc#1152489)
- commit b3480e1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add Arcturus to the VCN family (bsc#1152489)
- commit f4a242a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add VCN2.5 VCPU start and stop (bsc#1152489)
- commit c510a40
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add VCN2.5 basic supports (bsc#1152489)
- commit 942a061
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/VCN2: expose rings functions (bsc#1152489)
- commit a5103c1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/VCN2: put IB internal registers offset to structure (bsc#1152489)
- commit bd1d88a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: declare sdma firmware binary files for Arcturus (bsc#1152489)
- commit 3b59c41
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Clear build undefined warning (bsc#1152489)
- commit 13dce2e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Enable xgmi support for Arcturus (bsc#1152489)
- commit c0d2f85
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Hack xgmi topology info when there is no psp fw (bsc#1152489)
- commit 83c2446
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Support MMHUB1 in kfd interrupt path (bsc#1152489)
- commit 1cc381d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Set VM_L2_CNTL.PDE_FAULT_CLASSIFICATION to 0 for MMHUB (bsc#1152489)
- commit f49637c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Implement kfd2kgd_calls for Arcturus (bsc#1152489)
- commit 7f9acdc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Fix sdma_bitmap overflow issue (bsc#1152489)
- commit fc01533
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Change arcturus sdma engines number (bsc#1152489)
- commit a50fe6c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Support two MMHUBs when setting up page table base in KFD (bsc#1152489)
- commit 3cc67ea
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Expose function mmhub_v9_4_setup_vm_pt_regs() for kfd to (bsc#1152489)
- commit edb8121
* Tue Sep 29 2020 tzimmermann@suse.de
- amd/amdkfd: Add ASIC ARCTURUS to kfd (bsc#1152489)
- commit e1a4a3b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Support bigger gds size (bsc#1152489)
- commit ed99e18
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdkfd: Extend PM4 packets to support 8 SDMA (bsc#1152489)
- commit a0db8e3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Initialize asic functions for Arcturus (bsc#1152489)
- commit c72ad52
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add paging queue support for 8 SDMA instances on Arcturus (bsc#1152489)
- commit f0a7b93
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: correct programming of ih_chicken for Arcturus (bsc#1152489)
- commit 5e1f911
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add Arcturus chip_name for init sdma microcode (bsc#1152489)
- commit 810152e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable 8 SDMA instances for Arcturus (bsc#1152489)
- commit f1bb029
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: correct Arcturus SDMA address space base index (bsc#1152489)
- commit 198f1ed
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: support sdma 2~7 doorbell range register offset (bsc#1152489)
- commit 5eec945
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: skip all gfx ring settings for Arcturus (bsc#1152489)
- commit af849e8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: skip load cp gfx firmware for Arcturus (bsc#1152489)
- commit a8674fd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: optimize gfx9 init_microcode function (bsc#1152489)
- commit 1bd282c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add Arcturus gpu info firmware (bsc#1152489)
- commit 7878a73
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: skip pasid mapping for second mmhub on Arcturus (bsc#1152489)
- commit 50aa209
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: skip to get 3D engine clockgating state for Arcturus (bsc#1152489)
- commit 4c4d029
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add to set rlc funcs for Arcturus (bsc#1152489)
- commit 3811d4e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add number of mec for Arcturus (bsc#1152489)
- commit 3801241
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add gfx config for Arcturus (bsc#1152489)
- commit f34d503
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add support for Arcturus firmware (bsc#1152489)
- commit dd0d598
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/dce_virtual: add Arcturus virtual display support (bsc#1152489)
- commit 34768c3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: set Arcturus fw load type as direct (bsc#1152489)
- commit 6c33df0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add to set Arcturus ip blocks (bsc#1152489)
- commit ee0e22a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/soc15: add Arcturus common ip blocks (bsc#1152489)
- commit 16216de
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: support hdp flush for more sdma instances (bsc#1152489)
- commit 5e8f984
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: specify sdma instance 5~7 with second mmhub type (bsc#1152489)
- commit 48b153f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: reorganize sdma v4 code to support more instances (bsc#1152489)
- commit b8556fb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: update vmc interrupt routine to support 3 vmhubs (bsc#1152489)
- commit c4a40fc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add VMC1 interrupt client id for Arcturus (bsc#1152489)
- commit ceebc69
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: dynamically initialize IP offset for Arcturus (bsc#1152489)
- commit 6b8b94d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: increase max number of ip base instances to 8 (bsc#1152489)
- commit 984f24b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add SDMA 2~7 ip block type (bsc#1152489)
- commit c98456d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add SDMA 2~7 interrupt client id for Arcturus (bsc#1152489)
- commit cd17942
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: use new mmhub interfaces for Arcturus (bsc#1152489)
- commit 492c735
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add mmhub v9.4.1 block for Arcturus (v2) (bsc#1152489)
- commit 2020eea
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add one more mmhub instance for Arcturus (v2) (bsc#1152489)
- commit 793ed32
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add new member in amdgpu_device for vmhub counts per asic (bsc#1152489)
- commit f146618
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: rename AMDGPU_GFXHUB/MMHUB macro with hub number (bsc#1152489)
- commit 96f590d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add gmc basic support for Arcturus (bsc#1152489)
- commit 0b01436
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add Arcturus asic type (bsc#1152489)
- commit 68645d4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add Arcturus ip_offset header (v3) (bsc#1152489)
- commit d842c43
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add VCN2.5 headers (bsc#1152489)
- commit b330d66
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add sdma 4.2.2 header files for Arcturus (bsc#1152489)
- commit 3e2414a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add mmhub 9.4.1 header files for Acrturus (bsc#1152489)
- commit 4bf24fa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: consolidate navi14 IP init (bsc#1152489)
- commit 446c8f3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: disable concurrent flushes on Navi14 (bsc#1152489)
- commit 7a88843
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable gfxoff code path for navi14 (bsc#1152489)
- commit 081f537
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/vcn: enable indirect DPG SRAM mode for navi14 (bsc#1152489)
- commit b4671ab
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/powerplay: disable gfxoff for navi14 (bsc#1152489)
- commit 718e578
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/nv: set vcn pg flag for navi14 (bsc#1152489)
- commit 528a532
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: disable display writeback for navi14 (bsc#1152489)
- commit c7cf349
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable async gfx ring for navi14 (bsc#1152489)
- commit 265aaa1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable clock gatings for navi14 (bsc#1152489)
- commit 5687c01
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/athub2: set clock gating for navi14 (bsc#1152489)
- commit a89c8c7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/mmhub2: set clock gating for navi14 (bsc#1152489)
- commit f11e9e6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: declare asd firmware for navi14 (bsc#1152489)
- commit d41ef41
* Tue Sep 29 2020 hare@suse.de
- scsi: compat_ioctl: cdrom: Replace .ioctl with .compat_ioctl
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: fix FIONREAD on devices
  (bsc#1175995,jsc#SLE-15608).
- commit dc3fcb9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Enable VCN on navi14 (bsc#1152489)
- commit 4728bc8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: skip to load dmcu firmware for navi14 (bsc#1152489)
- commit b833ffc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: skip to load ta firmware for navi14 (bsc#1152489)
- commit a3f7f86
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add ASICREV defines v2 (bsc#1152489)
- commit 71067ca
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add dm block (bsc#1152489)
- commit 6679526
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add NAVI14 in resource construct (bsc#1152489)
- commit 4782efa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: add nv14 cases to amdgpu_dm (bsc#1152489)
- commit 08ebd4f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable sw smu ip for navi14 (bsc#1152489)
- commit 0d4f7cc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/smu11: add support for navi14 (bsc#1152489)
- commit b93945a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/psp: start rlc autoload after psp received rlcg for navi14 (bsc#1152489)
- commit 2c42d6d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable psp ip block for navi14 (bsc#1152489)
- commit 98af8bd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/psp: add psp support for navi14 (v3) (bsc#1152489)
- commit b3e2379
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: enable virtual display for navi14 (bsc#1152489)
- commit 5d92111
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add ip blocks for navi14 (bsc#1152489)
- commit 78018f9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/soc15: add support for navi14 (bsc#1152489)
- commit 14305ef
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: fix programming of SC_HIZ_TILE_FIFO_SIZE field (bsc#1152489)
- commit 1d1d921
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: update gfx golden settings for navi14 (bsc#1152489)
- commit 80afa19
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: update gfx golden settings for navi14 (bsc#1152489)
- commit 48bf359
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx: update gc_v10_1_1 golden setting (bsc#1152489)
- commit e776c32
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: add gfx v10_1_1 golden settings for navi14 (bsc#1152489)
- commit 01777c4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx: add definition of mmCGTT_GS_NGG_CLK_CTRL (bsc#1152489)
- commit 39c5ef3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: set tcp harvest for navi14 (bsc#1152489)
- commit 9490ae0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: set rlc funcs for navi14 (bsc#1152489)
- commit 44a38c3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add me/mec configurations for navi14 (bsc#1152489)
- commit ab2a380
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: add clockgating support for navi14 (bsc#1152489)
- commit 364e53c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: add gfx config for navi14 (bsc#1152489)
- commit 6a2900d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: add placeholder for navi14 golden settings (bsc#1152489)
- commit fd8cc2b
* Tue Sep 29 2020 hare@suse.de
- Documentation: document ioctl interfaces better
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: simplify up block/ioctl.c
  (bsc#1175995,jsc#SLE-15608).
- commit e827cbb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: add support for navi14 firmware (bsc#1152489)
- commit 94e493c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/sdma5: set clock gating for navi14 (bsc#1152489)
- commit efabae9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/sdma5: update sdma5 golden settings for navi14 (bsc#1152489)
- commit 2d5671a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/sdma5: add sdma5_0 golden settings for navi14 (bsc#1152489)
- commit 1019152
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/sdma5: add placeholder for navi14 golden settings (bsc#1152489)
- commit 1207b10
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/sdma5: add support for navi14 firmware (bsc#1152489)
- commit b0f0304
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/gmc10: add navi14 support (bsc#1152489)
- commit 3a2b225
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: increase max instance number for hw ip (bsc#1152489)
- commit 746f3c7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/discovery: init reg base offset via ip discovery for (bsc#1152489)
- commit c2dd5f6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu/soc15: initialize reg base for navi14 (v2) (bsc#1152489)
- commit 71447e2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add navi14 ucode loading method (bsc#1152489)
- commit 1511a18
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: set asic family and ip blocks for navi14 (bsc#1152489)
- commit b039937
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add gpu_info firmware for navi14 (bsc#1152489)
- commit 9e18b0f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: add navi14 asic type (bsc#1152489)
- commit 8c49c4b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/rockchip: fix VOP_WIN_GET macro (bsc#1152472)
- commit f6ec908
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/gem: Rename drm_gem_dumb_map_offset() to (bsc#1152472)
- commit 4714a18
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/panfrost: Use drm_gem_map_offset()" (bsc#1152472)
- commit ec45eca
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vgem: drop DRM_AUTH usage from the driver (bsc#1152472)
- commit da55412
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: drop DRM_AUTH usage from the driver (bsc#1152472)
- commit a7c1df4
* Tue Sep 29 2020 colyli@suse.de
- dax: Fix compilation for CONFIG_DAX && !CONFIG_FS_DAX
  (bsc#1175995, jsc#SLE-15608).
- dax: Fix stack overflow when mounting fsdax pmem device
  (bsc#1175995, jsc#SLE-15608).
- dax: fix detection of dax support for non-persistent memory
  block devices (bsc#1175995, jsc#SLE-15608).
- commit b4ff676
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: remove open-coded drm_invalid_op() (bsc#1152472)
- commit 94773d8
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/nouveau: remove open-coded drm_invalid_op()" (bsc#1152472)
- commit 918af03
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/msm: drop DRM_AUTH usage from the driver" (bsc#1152472)
- commit ec008c5
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/vgem: drop DRM_AUTH usage from the driver" (bsc#1152472)
- commit 3998cdf
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "Revert "drm/panfrost: Use drm_gem_map_offset()"" (bsc#1152472)
- commit ab1ef19
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "Revert "drm/gem: Rename drm_gem_dumb_map_offset() to (bsc#1152472)
- commit a429156
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/sti: fix opencoded use of drm_panel_* (bsc#1152472)
- commit 8c03019
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: stop using seqcount for fence pruning (bsc#1152472)
- commit 8308ebb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/crc-debugfs: Add notes about CRC<->commit interactions (bsc#1152472)
- commit c95b79b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/hdcp: reference for srm file format (bsc#1152472)
- commit 339ed9e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: update the hdcp state with uevent (bsc#1152472)
- commit 4378291
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/hdcp: update content protection property with uevent (bsc#1152472)
- commit b6c7e80
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: uevent for connector status change (bsc#1152472)
- commit f6629f4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Attach content type property (bsc#1152472)
- commit 061bd2e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Add Content protection type property (bsc#1152472)
- commit 5719371
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bochs: Use dev_get_drvdata (bsc#1152472)
- commit 70f55b4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/qxl: Use dev_get_drvdata where possible (bsc#1152472)
- commit 222feb2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ttm: drop ttm_buffer_object->resv (bsc#1152472)
- commit 128a04e
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: block: simplify compat_blkpg_ioctl()
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/block-move-block-layer-internals-out-of-include-linu.patch.
- Refresh patches.suse/block-refactor-blkpg_ioctl.patch.
- commit 123899c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/virtio: switch driver from bo->resv to bo->base.resv (bsc#1152472)
- commit 009200b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/qxl: switch driver from bo->resv to bo->base.resv (bsc#1152472)
- commit f69e3fb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: switch driver from bo->resv to bo->base.resv (bsc#1152472)
- commit 06f06ae
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: switch driver from bo->resv to bo->base.resv (bsc#1152472)
- commit 0a23237
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vmwgfx: switch driver from bo->resv to bo->base.resv (bsc#1152472)
- commit 4d31fb5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: switch driver from bo->resv to bo->base.resv (bsc#1152472)
- commit 2bf7c48
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ttm: switch ttm core from bo->resv to bo->base.resv (bsc#1152472)
- commit beee9fd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ttm: set both resv and base.resv pointers (bsc#1152472)
- commit e48d0b8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ttm: use gem vma_node (bsc#1152472)
- commit a034ac8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ttm: use gem reservation object (bsc#1152472)
- commit 3608562
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: use embedded gem object (bsc#1152472)
- commit 27a8fed
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: use embedded gem object (bsc#1152472)
- commit a55a9ed
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: use embedded gem object (bsc#1152472)
- commit 6771a46
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/qxl: use embedded gem object (bsc#1152472)
- commit cab48a6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vram: use embedded gem object (bsc#1152472)
- commit de4ce44
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ttm: add gem base object (bsc#1152472)
- commit 1c2a2bb
* Tue Sep 29 2020 tzimmermann@suse.de
- backlight: drop EARLY_EVENT_BLANK support (bsc#1152472)
- commit 8c99980
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge/parade: Drop legacy GPIO header (bsc#1152472)
- commit 7d5939f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge/nxp-ptn3460: Drop legacy GPIO headers (bsc#1152472)
- commit 5bb3dd6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge/megachips: Drop GPIO header (bsc#1152472)
- commit 2aa408c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/pl111: Fix unused variable warning (bsc#1152472)
- commit 3f3e35d
* Tue Sep 29 2020 tzimmermann@suse.de
- dma-buf: add more reservation object locking wrappers (bsc#1152472)
- commit 2dce229
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vblank: drop use of DRM_WAIT_ON() (bsc#1152472)
- commit eec07c1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/pl111: Drop special pads config check (bsc#1152472)
- commit 99657ca
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/komeda: Enable dual-link support (bsc#1152472)
- commit b1416a1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/komeda: Use drm_display_mode "crtc_" prefixed hardware timings (bsc#1152472)
- commit e29c995
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/drm_debugfs_crc.c: Document that .verify_crc_source vfunc is (bsc#1152472)
- commit 0c660d2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: mali-dp: Mark expected switch fall-through (bsc#1152472)
- commit 8716b20
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tilcdc: Remove obsolete crtc_mode_valid() hack (bsc#1152472)
- commit 2fbd921
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/radeon: Provide ddc symlink in connector sysfs directory" (bsc#1152472)
- commit 5b9450b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: Provide ddc symlink in connector sysfs directory (bsc#1152472)
- commit db069f9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Provide ddc symlink in connector sysfs directory (bsc#1152472)
- commit 5875760
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: ti-tfp410: Provide ddc symlink in connector sysfs (bsc#1152472)
- commit 493170a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi: Provide ddc symlink in connector sysfs directory (bsc#1152472)
- commit 4df6c72
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: dumb-vga-dac: Provide ddc symlink in connector sysfs (bsc#1152472)
- commit 5fa34bb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ast: Provide ddc symlink in connector sysfs directory (bsc#1152472)
- commit 77e1613
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mgag200: Provide ddc symlink in connector sysfs directory (bsc#1152472)
- commit a3a652d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: sti: Provide ddc symlink in hdmi connector sysfs directory (bsc#1152472)
- commit 99c53ff
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/imx: imx-tve: Provide ddc symlink in connector's sysfs (bsc#1152472)
- commit bfd2dc2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/imx: imx-ldb: Provide ddc symlink in connector's sysfs (bsc#1152472)
- commit a426400
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/sun4i: hdmi: Provide ddc symlink in sun4i hdmi connector sysfs (bsc#1152472)
- commit 89ae16f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Add drm_connector_init() variant with ddc (bsc#1152472)
- commit e1ef761
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Add ddc link in sysfs created by drm_connector (bsc#1152472)
- commit 896b59e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/gm12u320: Move driver to drm/tiny (bsc#1152472)
- commit c98a3bb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm: Rename folder to tiny (bsc#1152472)
- commit d2eafb3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm/Kconfig: Remove menuconfig DRM_TINYDRM (bsc#1152472)
- commit 7d828da
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/prime: Ditch gem_prime_res_obj hook (bsc#1152472)
- commit eb74a62
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amdgpu: Fill out gem_object->resv (bsc#1152472)
- commit c844fc5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: Fill out gem_object->resv (bsc#1152472)
- commit de021a9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: Fill out gem_object->resv (bsc#1152472)
- commit 26b4d71
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/rockchip: Make analogix_dp_atomic_check static (bsc#1152472)
- commit d7d5dfe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/syncobj: fix leaking dma_fence in drm_syncobj_query_ioctl (bsc#1152472)
- commit a44669b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: sti: Mark expected switch fall-throughs (bsc#1152472)
- commit 748adf1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mst: Fix sphinx warnings in drm_dp_msg_connector register (bsc#1152472)
- commit 09a4e9c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/rockchip: Use drm_atomic_helper_commit_tail_rpm (bsc#1152472)
- commit 697f7a8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/rockchip: Don't fully disable vop on self refresh (bsc#1152472)
- commit 56a586a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/rockchip: Use vop_win in vop_win_disable instead of vop_win_data (bsc#1152472)
- commit d0e9b0f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/rockchip: Use the helpers for PSR (bsc#1152472)
- commit c4c05ab
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/rockchip: Check for fast link training before enabling psr (bsc#1152472)
- commit 6404bda
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: jh057n00900: Use drm_panel_{unprepare, disable} (bsc#1152472)
- commit ed1a798
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: jh057n00900: Print error code on all DRM_DEV_ERROR()s (bsc#1152472)
- commit e6c8891
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: jh057n00900: Move mipi_dsi_dcs_set_display_off to (bsc#1152472)
- commit f39e1a0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: jh057n00900: Move panel DSI init to enable() (bsc#1152472)
- commit 4fed0e8
* Tue Sep 29 2020 tzimmermann@suse.de
- video: amba-clcd: Spout an error if of_get_display_timing() gives an (bsc#1152472)
- commit 139495b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: panel-lvds: Spout an error if of_get_display_timing() gives an (bsc#1152472)
- commit d287088
* Tue Sep 29 2020 tzimmermann@suse.de
- video: of: display_timing: Don't yell if no timing node is present (bsc#1152472)
- commit 9aef94a
* Tue Sep 29 2020 tzimmermann@suse.de
- video: of: display_timing: Add of_node_put() in (bsc#1152472)
- commit a24558d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: simple: Add support for Sharp LD-D5116Z01B panel (bsc#1152472)
- commit ae28b88
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: check failure cases in the probe func (bsc#1152472)
- commit fe0ccb4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Switch to use DEVFREQ_GOV_SIMPLE_ONDEMAND constant (bsc#1152472)
- commit 389f1c0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Export all GPU feature registers (bsc#1152472)
- commit 859b393
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Implement MST Aux device registration (bsc#1152472)
- commit a7905b7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/amd/display: Use connector kdev as aux device parent (bsc#1152472)
- commit c950e11
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: Use connector kdev as aux device parent (bsc#1152472)
- commit c976f36
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/dp_mst: Enable registration of AUX devices for MST ports (bsc#1152472)
- commit c930852
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/dp: Use non-cyclic idr (bsc#1152472)
- commit 1d9bfdd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/via: drop use of drmP.h (bsc#1152472)
- commit d0e737f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/via: make via_drv.h self-contained (bsc#1152472)
- commit 3a2a691
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/via: copy DRM_WAIT_ON as VIA_WAIT_ON and use it (bsc#1152472)
- commit db02be8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/via: drop use of DRM(READ|WRITE) macros (bsc#1152472)
- commit b5bc260
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: sii902x: add audio graph card support (bsc#1152472)
- commit 9c5d6ae
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: sii902x: make audio mclk optional (bsc#1152472)
- commit fbfe775
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: sii902x: fix missing reference to mclk clock (bsc#1152472)
- commit fad4593
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/stm: attach gem fence to atomic state (bsc#1152472)
- commit 5573fd1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm: Move mipi-dbi (bsc#1152472)
- commit a9e8a12
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm/mipi-dbi: Select DRM_KMS_HELPER (bsc#1152472)
- commit 89b5415
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm/Kconfig: drivers: Select BACKLIGHT_CLASS_DEVICE (bsc#1152472)
- commit 7716f42
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm/mipi-dbi: Remove CMA helper dependency (bsc#1152472)
- commit ff8c12b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm: Split struct mipi_dbi in two (bsc#1152472)
- commit 0defaeb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm: Rename remaining variable mipi -> dbidev (bsc#1152472)
- commit f5ede9c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm: Rename variable mipi -> dbi (bsc#1152472)
- commit b1e982e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm/mipi-dbi: Move cmdlock mutex init (bsc#1152472)
- commit 5560150
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mgag200: Don't unpin the current cursor image's buffer. (bsc#1152472)
- commit 5fd7aa9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mgag200: Set cursor scanout address to correct BO (bsc#1152472)
- commit 187a36d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mgag200: Pin displayed cursor BO to video memory (bsc#1152472)
- commit a0855fd
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: block: move blkdev_compat_ioctl() into ioctl.c
  (bsc#1175995,jsc#SLE-15608).
- commit 16bffa3
* Tue Sep 29 2020 tzimmermann@suse.de
- video: ssd1307fb: Add devicetree configuration of display setup (bsc#1152472)
- commit deb096f
* Tue Sep 29 2020 tzimmermann@suse.de
- video: ssd1307fb: Handle width and height that are not multiple of 8 (bsc#1152472)
- commit 1efaf36
* Tue Sep 29 2020 tzimmermann@suse.de
- video: ssd1307fb: Start page range at page_offset (bsc#1152472)
- commit d321944
* Tue Sep 29 2020 tzimmermann@suse.de
- video: ssd1307fb: Remove unneeded semicolons (bsc#1152472)
- commit b89d4e0
* Tue Sep 29 2020 tzimmermann@suse.de
- video: ssd1307fb: Use screen_buffer instead of screen_base (bsc#1152472)
- commit e81833c
* Tue Sep 29 2020 tzimmermann@suse.de
- video: fbdev-MMP: Remove call to memset after dma_alloc_coherent (bsc#1152472)
- commit 352aaef
* Tue Sep 29 2020 tzimmermann@suse.de
- video: fbdev: nvidia: Remove dead code (bsc#1152472)
- commit 742207b
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: move HDIO ioctl handling into drivers/ide
  (bsc#1175995,jsc#SLE-15608).
- commit fa2dd9a
* Tue Sep 29 2020 tzimmermann@suse.de
- video: fbdev: nvidia: Remove extra return (bsc#1152472)
- commit de8d2d9
* Tue Sep 29 2020 tzimmermann@suse.de
- au1200fb: don't use DMA_ATTR_NON_CONSISTENT (bsc#1152472)
- commit 1f38c0c
* Tue Sep 29 2020 tzimmermann@suse.de
- fbmem: remove redundant assignment to err (bsc#1152472)
- commit 7f5aa22
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm: Move tinydrm_display_pipe_init() to mipi-dbi (bsc#1152472)
- commit 5a2084f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm/mipi-dbi: Add mipi_dbi_init_with_formats() (bsc#1152472)
- commit 2037d8b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm/repaper: Don't use tinydrm_display_pipe_init() (bsc#1152472)
- commit 5f19278
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm: Move tinydrm_machine_little_endian() (bsc#1152472)
- commit 9e57ea4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm: Move tinydrm_spi_transfer() (bsc#1152472)
- commit 9b367b9
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: scsi: handle HDIO commands from drivers
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/block-move-dma-drain-handling-to-scsi.patch.
- Refresh
  patches.suse/scsi-Wire-up-ata_scsi_dma_need_drain-for-SAS-HBA-dri.patch.
- commit 1e191dc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm: Clean up tinydrm_spi_transfer() (bsc#1152472)
- commit 4770e24
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm: Remove tinydrm_spi_max_transfer_size() (bsc#1152472)
- commit 5bc81a7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm: Remove spi debug buffer dumping (bsc#1152472)
- commit b237d60
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm: Use spi_is_bpw_supported() (bsc#1152472)
- commit 1dc53ea
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tinydrm: Use DRM_MODE_CONNECTOR_SPI (bsc#1152472)
- commit 769cd06
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Add SPI connector type (bsc#1152472)
- commit 494662d
* Tue Sep 29 2020 tzimmermann@suse.de
- fbdev: Ditch fb_edid_add_monspecs (bsc#1152472)
- commit eb52721
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/komeda: remove set but not used variable 'old' (bsc#1152472)
- commit 49cd296
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: Improve the help text for DRM_ANALOGIX_ANX78XX (bsc#1152472)
- commit b447105
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Add Grain Media GM12U320 driver v2 (bsc#1152472)
- commit cbafbd5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/fb: remove unused function: drm_gem_fbdev_fb_create() (bsc#1152472)
- commit b75a587
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/sun4i: sun8i-csc: Add support for color encoding and range (bsc#1152472)
- commit 90809a6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/sun4i: sun8i_csc: Simplify register writes (bsc#1152472)
- commit 509b422
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/sun4i: Introduce color encoding and range properties (bsc#1152472)
- commit fdc5e3d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mediatek: direct include of drm.h in mtk_drm_gem.c (bsc#1152472)
- commit d50539a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: direct include of drm.h in drm_syncobj.c (bsc#1152472)
- commit 911c14b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: direct include of drm.h in drm_prime.c (bsc#1152472)
- commit 79ca7f7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: direct include of drm.h in drm_gem_shmem_helper.c (bsc#1152472)
- commit 5c5412b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: direct include of drm.h in drm_gem.c (bsc#1152472)
- commit a0bcc83
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ati_pcigart: drop dependency on drm_os_linux.h (bsc#1152472)
- commit 4f58e8f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: drop uapi dependency from drm_vblank.h (bsc#1152472)
- commit 05ee888
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: make drm_panel.h self-contained (bsc#1152472)
- commit a38a272
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/doc: Document kapi doc expectations (bsc#1152472)
- commit c1adc7b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: simple: document panel_desc; rename a few functions (bsc#1152472)
- commit 12e5799
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Make the bw/link rate calculations more forgiving (bsc#1152472)
- commit 81c2cbf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mediatek: drop use of drmP.h (bsc#1152472)
- commit bb83f21
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/rockchip: drop use of drmP.h (bsc#1152472)
- commit 657f2f0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/imx: drop use of drmP.h (bsc#1152472)
- commit b89bb64
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i2c/sil164: drop use of drmP.h (bsc#1152472)
- commit 9e6f91b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i2c/ch7006: drop use of drmP.h (bsc#1152472)
- commit 8a9fd19
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tilcdc: drop use of drmP.h (bsc#1152472)
- commit b3bc4fb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i810: drop use of drmP.h (bsc#1152472)
- commit 65a43b2
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: move cdrom commands into cdrom.c
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: simplify the implementation
  (bsc#1175995,jsc#SLE-15608).
- commit f063b86
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vgem: drop use of drmP.h (bsc#1152472)
- commit 7a22b47
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tdfx: drop use of drmP.h (bsc#1152472)
- commit bd92058
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/selftests: drop use of drmP.h (bsc#1152472)
- commit 85c7c2a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/omapdrm: drop use of drmP.h (bsc#1152472)
- commit 8b8772c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/udl: drop use of drmP.h (bsc#1152472)
- commit 6132fc4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vc4: drop use of drmP.h (bsc#1152472)
- commit 1969195
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/sun4i: drop use of drmP.h (bsc#1152472)
- commit 0f7f25d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/zte: drop use of drmP.h (bsc#1152472)
- commit e79e589
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/pl111: drop use of drmP.h (bsc#1152472)
- commit a7564ad
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/v3d: drop use of drmP.h (bsc#1152472)
- commit 18620db
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/meson: drop use of drmP.h (bsc#1152472)
- commit d64e4d2
* Tue Sep 29 2020 tzimmermann@suse.de
- gpu/drm: fix a few kernel-doc "/**" mark warnings (bsc#1152472)
- commit 4f4f41a
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: move sys_compat_ioctl() to ioctl.c
  (bsc#1175995,jsc#SLE-15608).
- commit 636dfe4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: ti-sn65dsi86: use dev name for debugfs (bsc#1152472)
- commit f788070
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/pl111: pl111_vexpress.c: Add of_node_put() before return (bsc#1152472)
- commit 0eb1ecf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/atmel_hlcdc: drop use of drmP.h (bsc#1152472)
- commit 2306791
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/shmobile: drop use of drmP.h (bsc#1152472)
- commit c66f5cf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/hisilicon: drop use of drmP.h (bsc#1152472)
- commit fa270bd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ast: drop use of drmP.h (bsc#1152472)
- commit 892c614
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bochs: drop use of drmP.h (bsc#1152472)
- commit 980b0a4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: add missing include to drm_vram_mm_helper.h (bsc#1152472)
- commit 58095e5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/virtgpu: drop use of drmP.h (bsc#1152472)
- commit cd3cfae
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/scheduler: drop use of drmP.h (bsc#1152472)
- commit d1c2b33
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vkms: drop use of drmP.h (bsc#1152472)
- commit e021559
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/qxl: drop use of drmP.h (bsc#1152472)
- commit ae2c6c8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/fsl-dcu: drop use of drmP.h (bsc#1152472)
- commit a4bb8e3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mxsfb: drop use of drmP.h (bsc#1152472)
- commit 7651daa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tve200: drop use of drmP.h (bsc#1152472)
- commit 1dbd7c5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/xen: drop use of drmP.h (bsc#1152472)
- commit 35c82da
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/agp: Remove unused function drm_agp_bind_pages (bsc#1152472)
- commit 368a57e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vgem: Reclassify buffer creation debug message (bsc#1152472)
- commit 54f0524
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: simple: fix AUO g185han01 horizontal blanking (bsc#1152472)
- commit 4a37bf2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/atmel-hlcdc: set layer REP bit to enable replication logic (bsc#1152472)
- commit d6e0227
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: simple: Use display_timing for AUO b101ean01 (bsc#1152472)
- commit c656d61
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: simple: Use display_timing for Innolux n116bge (bsc#1152472)
- commit dfd0047
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: simple: Add ability to override typical timing (bsc#1152472)
- commit 4a3bd44
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vkms: Rename vkms_crc.c into vkms_composer.c (bsc#1152472)
- commit 0d99dc5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vkms: Avoid assigning 0 for possible_crtc (bsc#1152472)
- commit 9f5aaf0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/kms: Catch mode_object lifetime errors (bsc#1152472)
- commit 72302ee
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/client: remove the exporting of drm_client_close (bsc#1152472)
- commit db19f3b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mgag200: Replace struct mga_fbdev with generic framebuffer (bsc#1152472)
- commit 477018a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ast: Replace struct ast_fbdev with generic framebuffer emulation (bsc#1152472)
- commit 72c4882
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/sti: Try to fix up the tvout possible clones (bsc#1152472)
- commit e41db07
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/sti: Remove pointless casts (bsc#1152472)
- commit 3e13ba1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: ti-sn65dsi86: correct dsi mode_flags (bsc#1152472)
- commit cdb4c12
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: ti-sn65dsi86: add debugfs (bsc#1152472)
- commit 7525cc5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: ti-sn65dsi86: add link to datasheet (bsc#1152472)
- commit cb0e1d9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: sii902x: Make sii902x_audio_digital_mute static (bsc#1152472)
- commit 9a1a540
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/gem: Rename drm_gem_dumb_map_offset() to (bsc#1152472)
- commit 771704c
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/panfrost: Use drm_gem_map_offset()" (bsc#1152472)
- commit c5b4908
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vram: Don't export driver callback functions for PRIME (bsc#1152472)
- commit e6c7d90
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vbox: Remove empty PRIME functions (bsc#1152472)
- commit f337476
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/hibmc: Update struct drm_driver for GEM object functions (bsc#1152472)
- commit 92057f0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bochs: Remove PRIME helpers from driver structure (bsc#1152472)
- commit a9c4f2b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vram: Set GEM object functions for PRIME (bsc#1152472)
- commit 1fc130f
* Tue Sep 29 2020 tzimmermann@suse.de
- DRM: ingenic: Add support for panels with 8-bit serial bus (bsc#1152472)
- commit 8ca6707
* Tue Sep 29 2020 tzimmermann@suse.de
- DRM: ingenic: Add support for Sharp panels (bsc#1152472)
- commit d30269b
* Tue Sep 29 2020 tzimmermann@suse.de
- DRM: ingenic: Use devm_platform_ioremap_resource (bsc#1152472)
- commit 5bbfbb6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi: Use automatic CTS generation mode when using (bsc#1152472)
- commit f8f2fe2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: do a software reset if reset pin isn't (bsc#1152472)
- commit 804af2e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: adv7511: Attach to DSI host at probe time (bsc#1152472)
- commit f4c769f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/stm: drop use of drmP.h (bsc#1152472)
- commit ce066e2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mgag200: drop use of drmP.h (bsc#1152472)
- commit 0f56ef3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mga: drop use of drmP.h (bsc#1152472)
- commit 7afc027
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mga: make header file self contained (bsc#1152472)
- commit 804c0e2
* Tue Sep 29 2020 oneukum@suse.com
- Revert "crypto: chelsio - Inline single pdu only" (git-fixes).
- commit 11462e6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mga: drop dependency on drm_os_linux.h (bsc#1152472)
- commit 8066d10
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: Use drm_gem_map_offset() (bsc#1152472)
- commit 850cb58
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/gem: Rename drm_gem_dumb_map_offset() to drm_gem_map_offset() (bsc#1152472)
- commit 1799cc6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vmwgfx: Don't look at state->allow_modeset (bsc#1152472)
- commit 8b89e82
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ast: Replace struct ast_framebuffer with GEM framebuffer helpers (bsc#1152472)
- commit d9ccae0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vc4: Use drm_gem_fb_prepare_fb (bsc#1152472)
- commit b0f6062
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: Use drm_gem_fb_prepare_fb (bsc#1152472)
- commit e30b49a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/fb-helper: use gem_bo.resv, not dma_buf.resv in prepare_fb (bsc#1152472)
- commit 0d6531b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mgag200: Replace struct mga_framebuffer with GEM framebuffer (bsc#1152472)
- commit aa2c303
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Add support for address-only I2C transfers (bsc#1152472)
- commit 5d67b5c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Replace magic number in tc_main_link_enable() (bsc#1152472)
- commit b02c93b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Drop unnecessary 8 byte buffer (bsc#1152472)
- commit 2f3d060
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Simplify tc_aux_wait_busy() (bsc#1152472)
- commit 0aee92e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Introduce tc_pllupdate() (bsc#1152472)
- commit efe0bc9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Introduce tc_set_syspllparam() (bsc#1152472)
- commit d504555
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Use reported AUX transfer size (bsc#1152472)
- commit 988c2a9
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: scsi: move ioctl handling into drivers
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/0004-virtio-blk-handle-block_device_operations-callbacks-.patch.
- commit 8af02a6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Increase AUX transfer length limit (bsc#1152472)
- commit 4e70dfe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Simplify AUX data write (bsc#1152472)
- commit 859455e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Simplify AUX data read (bsc#1152472)
- commit 82cde9e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Drop custom tc_write()/tc_read() accessors (bsc#1152472)
- commit eeaf68b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Simplify tc_set_video_mode() (bsc#1152472)
- commit d48c2e7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Simplify polling in tc_link_training() (bsc#1152472)
- commit cceac61
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Simplify polling in tc_main_link_setup() (bsc#1152472)
- commit 6c7f0bc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge: tc358767: Simplify tc_poll_timeout() (bsc#1152472)
- commit 8f56540
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mgag200: add in missing { } around if block (bsc#1152472)
- commit 3af73a9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vkms: No need for ->pages_lock in crc work anymore (bsc#1152472)
- commit f731b9d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vkms: totally reworked crc data tracking (bsc#1152472)
- commit 4674da6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vkms: No _irqsave within spin_lock_irq needed (bsc#1152472)
- commit e0fc4c0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vkms: Dont flush crc worker when we change crc status (bsc#1152472)
- commit d675b23
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vkms: flush crc workers earlier in commit flow (bsc#1152472)
- commit 17470bb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vkms: Add our own commit_tail (bsc#1152472)
- commit 3386b5a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vkms: Rename vkms_output.state_lock to crc_lock (bsc#1152472)
- commit 41e642c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vkms: Use spin_lock_irq in process context (bsc#1152472)
- commit 2f5edf4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vkms: Fix crc worker races (bsc#1152472)
- commit 091131a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Allow range of 0 for drm_mm_insert_node_in_range() (bsc#1152472)
- commit 5560ba1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/virtio: drop DRM_AUTH usage from the driver (bsc#1152472)
- commit 5fc853f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vgem: drop DRM_AUTH usage from the driver (bsc#1152472)
- commit cbffae0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/omap: drop DRM_AUTH from DRM_RENDER_ALLOW ioctls (bsc#1152472)
- commit df370fd
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: ide: floppy: add handler
  (bsc#1175995,jsc#SLE-15608).
- commit a2bd1ce
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: drop DRM_AUTH from DRM_RENDER_ALLOW ioctls (bsc#1152472)
- commit c90fb75
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: drop DRM_AUTH usage from the driver (bsc#1152472)
- commit 6522547
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/lima: drop DRM_AUTH usage from the driver (bsc#1152472)
- commit f6d4606
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/exynos: drop DRM_AUTH from DRM_RENDER_ALLOW ioctls (bsc#1152472)
- commit 1d1d918
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: drop DRM_AUTH usage from the driver (bsc#1152472)
- commit 7d0744c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vmwgfx: use core drm to extend/check vmw_execbuf_ioctl (bsc#1152472)
- commit b847b17
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vmgfx: kill off unused init_mutex (bsc#1152472)
- commit 3fdcb73
* Tue Sep 29 2020 tzimmermann@suse.de
- vmwgfx: drop empty lastclose stub (bsc#1152472)
- commit f0c6f17
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: remove open-coded drm_invalid_op() (bsc#1152472)
- commit 450d9a2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: remove irrelevant DRM_UNLOCKED flag (bsc#1152472)
- commit 0e0ea4d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tegra: remove irrelevant DRM_UNLOCKED flag (bsc#1152472)
- commit 0fc48ef
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: jh057n00900: Add regulator support (bsc#1152472)
- commit ce30dde
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: jh057n00900: Don't use magic constant (bsc#1152472)
- commit 1c94cf2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: Add support for Raydium RM67191 panel driver (bsc#1152472)
- commit 85878e9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: simple: Add Sharp LS020B1DD01D panel support (bsc#1152472)
- commit 4ad2d3b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Add bus flag for Sharp-specific signals (bsc#1152472)
- commit 56f366e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: Add Novatek NT39016 panel support (bsc#1152472)
- commit b11611b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: simple: Add Ortustech COM37H3M panel support (bsc#1152472)
- commit 896dfff
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: simple: Add Sharp LQ070Y3DG3B panel support (bsc#1152472)
- commit 1ee1737
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panel: simple: Add GiantPlus GPM940B0 panel support (bsc#1152472)
- commit 169a1fa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: Drop robj from msm_gem_new_impl (bsc#1152472)
- commit b22a025
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: Drop resv argument from etnaviv_gem_new_impl (bsc#1152472)
- commit f635a4b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/todo: Add new debugfs todo (bsc#1152472)
- commit 556e2d6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/todo: Update mmap todo (bsc#1152472)
- commit be5f4b3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/todo: Update backlight todo (bsc#1152472)
- commit 525732d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/todo: remove gem_prime_import/export todo (bsc#1152472)
- commit b2281bf
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: add scsi_compat_ioctl (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: block: handle cdrom compat ioctl in non-cdrom
  (bsc#1175995,jsc#SLE-15608).
- commit 857fdc8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vc4: Don set gem_obj->resv in prime import anymore (bsc#1152472)
- commit 4a146dc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/panfrost: don't set gem_obj->resv for prime import anymore (bsc#1152472)
- commit 8a6a851
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mediatek: Use drm_atomic_helper_wait_for_fences (bsc#1152472)
- commit 9c6bebe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/lima: Drop resv argument from lima_bo_create_struct (bsc#1152472)
- commit d892378
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mcde: Fix uninitialized variable (bsc#1152472)
- commit f5af39b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/sun4i: Eliminate pointless on stack copy of drm_display_info (bsc#1152472)
- commit 266ff42
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: WARN on illegal aspect ratio when converting a mode to umode (bsc#1152472)
- commit b48c8c5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Do not accept garbage mode aspect ratio flags (bsc#1152472)
- commit 34161a8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm: Do not use bitwise OR to set picure_aspect_ratio (bsc#1152472)
- commit 3f1a961
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/connector: Fix warning in debug message (bsc#1152472)
- commit 961e133
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/bridge/synopsys: dsi: Allow VPG to be enabled via debugfs (bsc#1152472)
- commit f8a1111
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/lima: Reduce the amount of logs on deferred probe of clocks and (bsc#1152472)
- commit 3851525
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/lima: Reduce number of PTR_ERR() calls (bsc#1152472)
- commit 6a370d6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/lima: Reduce the amount of logs on deferred probe (bsc#1152472)
- commit 99e02be
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/lima: Mark 64-bit number as ULL (bsc#1152472)
- commit 2114c7b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vgem: Ditch attach trickery in the fence ioctl (bsc#1152472)
- commit de63afe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/prime: automatically set gem_obj->resv on import (bsc#1152472)
- commit 1cf52a4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vram-helper: Drop drm_gem_prime_export/import (bsc#1152472)
- commit cd22a78
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/zte: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 73ef55f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/xen: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 349ba4e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/virtio: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 964d22f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vgem: Drop drm_gem_prime_export (bsc#1152472)
- commit cccb73b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/radeon: Drop drm_gem_prime_import (bsc#1152472)
- commit 4cc1d3d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vc3: Drop drm_gem_prime_import (bsc#1152472)
- commit fc56cea
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vboxvideo: Drop drm_gem_prime_export/import (bsc#1152472)
- commit c8840c9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tve2000: Drop drm_gem_prime_export/import (bsc#1152472)
- commit e79a08b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/tilcdc: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 4bf46c6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/stm: Drop drm_gem_prime_export/import (bsc#1152472)
- commit fee9ced
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/sti: Drop drm_gem_prime_export/import (bsc#1152472)
- commit a2f0e12
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/shmob: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 4c29d6f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/rockchip: Drop drm_gem_prime_export/import (bsc#1152472)
- commit a0c7eeb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/rcar-du: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 9db3b9c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/qxl: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 8ab7639
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/pl111: Drop drm_gem_prime_export/import (bsc#1152472)
- commit d38a137
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/nouveau: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 5c2f2c4
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: cdrom: handle CDROM_LAST_WRITTEN
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/block-move-the-devnode-callback-to-struct-block_devi.patch.
- commit 9b8e848
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mxsfb: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 3418cef
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/msm: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 186f5fe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/meson: Drop drm_gem_prime_export/import (bsc#1152472)
- commit a68f355
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mtk: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 071b73c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/mcde: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 6572be9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/imx: Drop drm_gem_prime_export/import (bsc#1152472)
- commit d72cf9f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/hisilicon: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 8709ae8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/fsl-dcu: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 15f4a10
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/exynos: Drop drm_gem_prime_export (bsc#1152472)
- commit a5bd076
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/etnaviv: Drop drm_gem_prime_export/import (bsc#1152472)
- commit fe10f84
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/atmel: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 8b6dfd1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/arm: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 9b948a1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/arc: Drop drm_gem_prime_export/import (bsc#1152472)
- commit 749b7f4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/ioctl: Ditch DRM_UNLOCKED except for the legacy vblank ioctl (bsc#1152472)
- commit 5d46158
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/prime: Align gem_prime_export with obj_funcs.export (bsc#1152472)
- commit 69c2333
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/omapdrm: drop fb_debug_enter/leave (bsc#1152472)
- commit cb74d4e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/arm/komeda: Remove DRIVER_HAVE_IRQ (bsc#1152472)
- commit 7f8d17b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/prime: Actually remove DRIVER_PRIME everywhere (bsc#1152472)
- commit c66545c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/prime: Make DRIVER_PRIME a no-op (bsc#1152472)
- commit 7df9fb0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/prime: Unconditionally set up the prime file private (bsc#1152472)
- commit 13a2d9d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/prime: Update docs (bsc#1152472)
- commit 65105a7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/prime: Shuffle functions. (bsc#1152472)
- commit 8f51ad9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/sti: Remove duplicated include from sti_drv.c (bsc#1152472)
- commit 237272f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Update DRIVER_DATE to 20190730 (bsc#1152489)
- commit 49e8483
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Provide a local intel_context.vm (bsc#1152489)
- commit 4e450ea
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move aliasing_ppgtt underneath its i915_ggtt (bsc#1152489)
- commit 3b10502
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Inline engine->init_context into its caller (bsc#1152489)
- commit dbd6c06
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: use upstream version of header tests (bsc#1152489)
- commit a350f28
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Don't fail on HuC firmware failure (bsc#1152489)
- commit 49c4408
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Flush the i915_vm_release before ggtt shutdown (bsc#1152489)
- commit 6c355d5
* Tue Sep 29 2020 yousaf.kaukab@suse.com
- usb: host: xhci-tegra: fix tegra_xusb_get_phy() (jsc#SLE-15847).
- usb: host: xhci-tegra: otg usb2/usb3 port init (jsc#SLE-15847).
- i2c: tegra: Avoid tegra_i2c_init_dma() for Tegra210 vi i2c
  (jsc#SLE-15847).
- i2c: tegra: Fix runtime resume to re-init VI I2C
  (jsc#SLE-15847).
- i2c: tegra: Fix the error path in tegra_i2c_runtime_resume
  (jsc#SLE-15847).
- i2c: tegra: Remove NULL pointer check before
  clk_enable/disable/prepare/unprepare (jsc#SLE-15847).
- i2c: tegra: Don't mark VI I2C as IRQ safe runtime PM
  (jsc#SLE-15847).
- usb: xhci: tegra: Remove PLL power supplies (jsc#SLE-15847).
- dmaengine: tegra-apb: Replace zero-length array with
  flexible-array (jsc#SLE-15847).
- i2c: tegra: Add support for the VI I2C on Tegra210
  (jsc#SLE-15847).
- i2c: tegra: Use FIELD_PREP/FIELD_GET macros (jsc#SLE-15847).
- i2c: tegra: Synchronize DMA before termination (jsc#SLE-15847).
- i2c: tegra: Better handle case where CPU0 is busy for a long
  time (jsc#SLE-15847).
- i2c: tegra: Keep IRQs enabled during suspend/resume
  (jsc#SLE-15847).
- i2c: tegra: Restore pinmux on system resume (jsc#SLE-15847).
- pwm: tegra: Support dynamic clock frequency configuration
  (jsc#SLE-15847).
- dmaengine: tegra-apb: Ensure that clock is enabled during of
  DMA synchronization (jsc#SLE-15847).
- phy: tegra: Select USB_COMMON for usb_get_maximum_speed()
  (jsc#SLE-15847).
- drivers/dma/tegra20-apb-dma.c: fix platform_get_irq.cocci
  warnings (jsc#SLE-15847).
- pwm: tegra: Add support for Tegra194 (jsc#SLE-15847).
- dmaengine: tegra-apb: Improve DMA synchronization
  (jsc#SLE-15847).
- dmaengine: tegra-apb: Don't save/restore IRQ flags in interrupt
  handler (jsc#SLE-15847).
- dmaengine: tegra-apb: mark PM functions as __maybe_unused
  (jsc#SLE-15847).
- dmaengine: tegra-apb: Improve error message about DMA underflow
  (jsc#SLE-15847).
- dmaengine: tegra-apb: Remove unused function argument
  (jsc#SLE-15847).
- dmaengine: tegra-apb: Remove MODULE_ALIAS (jsc#SLE-15847).
- dmaengine: tegra-apb: Allow to compile as a loadable kernel
  module (jsc#SLE-15847).
- dmaengine: tegra-apb: Add missing of_dma_controller_free
  (jsc#SLE-15847).
- dmaengine: tegra-apb: Clean up suspend-resume (jsc#SLE-15847).
- dmaengine: tegra-apb: Keep clock enabled only during of DMA
  transfer (jsc#SLE-15847).
- dmaengine: tegra-apb: Remove duplicated pending_sg_req checks
  (jsc#SLE-15847).
- dmaengine: tegra-apb: Remove assumptions about unavailable
  runtime PM (jsc#SLE-15847).
- dmaengine: tegra-apb: Remove unneeded initialization of
  tdc->config_init (jsc#SLE-15847).
- dmaengine: tegra-apb: Fix coding style problems (jsc#SLE-15847).
- dmaengine: tegra-apb: Use devm_request_irq (jsc#SLE-15847).
- dmaengine: tegra-apb: Use devm_platform_ioremap_resource
  (jsc#SLE-15847).
- dmaengine: tegra-apb: Clean up tasklet releasing
  (jsc#SLE-15847).
- dmaengine: tegra-apb: Prevent race conditions on channel's
  freeing (jsc#SLE-15847).
- dmaengine: tegra-apb: Implement synchronization hook
  (jsc#SLE-15847).
- dmaengine: tegra210-adma: Replace zero-length array with
  flexible-array member (jsc#SLE-15847).
- usb: xhci-tegra: Add OTG support (jsc#SLE-15847).
- phy: tegra: Select USB_PHY (jsc#SLE-15847).
- phy: tegra: Don't use device-managed API to allocate ports
  (jsc#SLE-15847).
- phy: tegra: Fix regulator leak (jsc#SLE-15847).
- phy: tegra: Print -EPROBE_DEFER error message at debug level
  (jsc#SLE-15847).
- phy: tegra: xusb: Don't warn on probe defer (jsc#SLE-15847).
- phy: tegra: xusb: Add Tegra194 support (jsc#SLE-15847).
- phy: tegra: xusb: Protect Tegra186 soc with config
  (jsc#SLE-15847).
- phy: tegra: xusb: Add set_mode support for UTMI phy on Tegra186
  (jsc#SLE-15847).
- phy: tegra: xusb: Add set_mode support for USB 2 phy on Tegra210
  (jsc#SLE-15847).
- phy: tegra: xusb: Add support to get companion USB 3 port
  (jsc#SLE-15847).
- phy: tegra: xusb: Add usb-phy support (jsc#SLE-15847).
- phy: tegra: xusb: Add usb-role-switch support (jsc#SLE-15847).
- usb: host: xhci-tegra: Tegra186/Tegra194 LPM (jsc#SLE-15847).
- i2c: tegra: Check DMA completion status in addition to left time
  (jsc#SLE-15847).
- i2c: tegra: Always terminate DMA transfer (jsc#SLE-15847).
- i2c: tegra: Use relaxed versions of readl/writel
  (jsc#SLE-15847).
- i2c: tegra: Rename I2C_PIO_MODE_MAX_LEN to
  I2C_PIO_MODE_PREFERRED_LEN (jsc#SLE-15847).
- i2c: tegra: Support atomic transfers (jsc#SLE-15847).
- i2c: tegra: Prevent interrupt triggering after transfer timeout
  (jsc#SLE-15847).
- thermal: tegra: Appease the kernel-doc deity (jsc#SLE-15847).
- rtc: tegra: remove set but unused variable (jsc#SLE-15847).
- i2c: tegra: Use dma_request_chan() directly for channel request
  (jsc#SLE-15847).
- phy: tegra: xusb: remove unused variable (jsc#SLE-15847).
- commit e0abf3c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Careful not to flush hang_fini on error setups (bsc#1152489)
- commit 45c0f9c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Fixup kerneldoc after params were flipped and renamed (bsc#1152489)
- commit 7de05fd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: update ddi/tc clock_off bits (bsc#1152489)
- commit 3950c85
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: select correct bit for port select (bsc#1152489)
- commit 19a1717
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: skip setting PORT_CL_DW12_* on initialization (bsc#1152489)
- commit 4a76c20
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Remove redundant RSA offset definition (bsc#1152489)
- commit da5dccb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Remove redundant ucode offset definition (bsc#1152489)
- commit ea0f8d3
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: move CDROMREADADIO to cdrom.c
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: move CDROM_SEND_PACKET handling into scsi
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: ubd, aoe: use blkdev_compat_ptr_ioctl
  (bsc#1175995,jsc#SLE-15608).
- commit e509c49
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Remove redundant header_offset/size definitions (bsc#1152489)
- commit 17643bc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Add to timeline requires the timeline mutex (bsc#1152489)
- commit b283445
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Don't sanitize guc_log_level modparam (bsc#1152489)
- commit a3949ce
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Do not rely on for loop caching the mask (bsc#1152489)
- commit 8996fa4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/perf: Initialise err to 0 before looping over ce->engines (bsc#1152489)
- commit dcd1340
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: init submission structures as part of guc_init (bsc#1152489)
- commit fab9156
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Reorder params in intel_uc_fw_fetch (bsc#1152489)
- commit 9fe2fba
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Capture vma contents outside of spinlock (bsc#1152489)
- commit 172cd7c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Move uc firmware layout definitions to dedicated file (bsc#1152489)
- commit a14159f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Update drawing for firmware layout (bsc#1152489)
- commit e444743
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Fix GuC documentation links (bsc#1152489)
- commit d84d3e8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Unify uC firmware upload (bsc#1152489)
- commit c3be3ca
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Plumb the gt through fw_upload (bsc#1152489)
- commit f9e5430
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/huc: Copy huc rsa only once (bsc#1152489)
- commit 7f68037
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Move xfer rsa logic to common function (bsc#1152489)
- commit 6a85a75
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Unify uc_fw status tracking (bsc#1152489)
- commit b31303e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Unify uC FW selection (bsc#1152489)
- commit 4920031
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Fix handling of non-supported uC (bsc#1152489)
- commit f164aae
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Unify uC platform check (bsc#1152489)
- commit d7b0430
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Set GuC init params only once (bsc#1152489)
- commit 907514c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use dev_get_drvdata (bsc#1152489)
- commit 3ca7a41
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/huc: fix status check (bsc#1152489)
- commit 6474981
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Squelch nop wait-for-idle trace (bsc#1152489)
- commit 8027bee
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Let igt_vma_partial et al breathe (bsc#1152489)
- commit 27e9c8c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Sanitize uC when GT is sanitized (bsc#1152489)
- commit cff4b84
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Gt-fy uc reset (bsc#1152489)
- commit 72d2979
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add HDCP capability info to i915_display_info. (bsc#1152489)
- commit c2fc72b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Rely on spinlock protection for GPU error capture (bsc#1152489)
- commit 279c880
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Hook up intel_context_fini() (bsc#1152489)
- commit 8d07d68
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Remove obsolete engine cleanup (bsc#1152489)
- commit dd4ff67
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Fix rounding for 36b (bsc#1152489)
- commit eb9e65e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/dsi: remove set but not used variable 'hfront_porch' (bsc#1152489)
- commit 2cc8284
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Don't try to clear failed empty pd allocation (bsc#1152489)
- commit 356d127
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Correct unshifted 'from' for gen8_ppgtt_alloc errors (bsc#1152489)
- commit 5120e8a
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/i915: Update description of i915.enable_guc modparam" (bsc#1152489)
- commit e209a99
* Tue Sep 29 2020 tzimmermann@suse.de
- Revert "drm/i915/guc: Turn on GuC/HuC auto mode" (bsc#1152489)
- commit 9ed9164
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Add Wa_1409178092 (bsc#1152489)
- commit 316fceb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Verify engine workarounds in GEN8_L3SQCREG4 (bsc#1152489)
- commit 7b683ad
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Skip CS verification of L3 bank registers (bsc#1152489)
- commit e23277d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Fix and improve MCR selection logic (bsc#1152489)
- commit 7311ef0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Trust programmed MCR in read_subslice_reg (bsc#1152489)
- commit 9fb6512
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Remove set but not used variable 'src_y' (bsc#1152489)
- commit c04f290
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Cancel breadcrumb on preempting the virtual (bsc#1152489)
- commit ad9c0bf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use maximum write flush for pwrite_gtt (bsc#1152489)
- commit 8db22ce
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Drop wmb() inside pread_gtt (bsc#1152489)
- commit 2ca85f5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl: Use an id of 4 while accessing DPLL4's CR0 and CR1 (bsc#1152489)
- commit 895b16d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add gen8_de_pipe_fault_mask() (bsc#1152489)
- commit 14fb9bb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Push engine stopping into reset-prepare (bsc#1152489)
- commit 93ad282
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Process interrupted context on reset (bsc#1152489)
- commit 7a0064c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Update description of i915.enable_guc modparam (bsc#1152489)
- commit 53ddafd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/oa: Reconfigure contexts on the fly (bsc#1152489)
- commit e5ee707
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Tidy up ppgtt insertion for gen8 (bsc#1152489)
- commit b3f8de5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Recursive ppgtt alloc for gen8 (bsc#1152489)
- commit a285375
* Tue Sep 29 2020 msuchanek@suse.de
- powerpc: Don't flush caches when adding memory (bsc#1176980
  ltc#187962).
- commit 63612e5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Disable preemption under GVT (bsc#1152489)
- commit 335774a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Enable hotplug retry (bsc#1152489)
- commit 76fa2e8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add support for retrying hotplug (bsc#1152489)
- commit 635e258
* Tue Sep 29 2020 msuchanek@suse.de
- Fix patch order in sorted section.
- commit ca43e45
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl: Map MCC pins based on PHY, not port (bsc#1152489)
- commit 0b4bcbd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Ignore self-preemption suppression under gvt (bsc#1152489)
- commit 16d99bf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: kill <g,h>uc_to_i915 (bsc#1152489)
- commit a05a3eb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: prefer intel_gt in guc interrupt functions (bsc#1152489)
- commit b82e977
* Tue Sep 29 2020 hare@suse.de
- compat: scsi: sg: fix v3 compat read/write interface
  (bsc#1175995,jsc#SLE-15608).
- blacklist.conf: remove blacklisted commit
- commit dac234f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: prefer intel_gt over i915 in GuC/HuC paths (bsc#1152489)
- commit 9d1b472
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: Move intel functions to intel_uc (bsc#1152489)
- commit de33772
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: move GuC/HuC inside intel_gt under a new intel_uc (bsc#1152489)
- commit 424888e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: move GuC and HuC files under gt/uc/ (bsc#1152489)
- commit c646606
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: unify guc irq handling (bsc#1152489)
- commit dc12a56
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: move guc irq functions to intel_guc parameter (bsc#1152489)
- commit 7524b2a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: introduce intel_uc_fw_supported (bsc#1152489)
- commit a77f396
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/uc: replace uc init/fini misc (bsc#1152489)
- commit 0b88c46
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Use system workqueue for log capture (bsc#1152489)
- commit 55a5a6b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Use intel_gt as the primary object for handling resets (bsc#1152489)
- commit 23709d7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: add modular FIA to device info (bsc#1152489)
- commit 27ea93a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add modular FIA (bsc#1152489)
- commit c9180f9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Recursive ppgtt clear for gen8 (bsc#1152489)
- commit 2165ec5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Recursive cleanup for gen8 (bsc#1152489)
- commit f5af046
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/display: Drop kerneldoc for 'intel_atomic_commit' (bsc#1152489)
- commit fdc5e9f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Skip SINK_COUNT read on CH7511 (bsc#1152489)
- commit 5629df5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Turn on GuC/HuC auto mode (bsc#1152489)
- commit c3adfb7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Don't enable GuC/HuC in auto mode on pre-Gen11 (bsc#1152489)
- commit 238c191
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Propagate "_probe" function name suffix down (bsc#1152489)
- commit 7a87e22
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Propagate "_remove" function name suffix down (bsc#1152489)
- commit 494cd3c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Propagate "_release" function name suffix down (bsc#1152489)
- commit d42226d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Replace "_load" with "_probe" consequently (bsc#1152489)
- commit 1522173
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Rename "_load"/"_unload" to match PCI entry points (bsc#1152489)
- commit f443ea0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Drop extern qualifiers from header function prototypes (bsc#1152489)
- commit f243a36
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Use NULL to encode scratch shadow entries (bsc#1152489)
- commit 29dafd4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Convert vm->scratch into an array (bsc#1152489)
- commit d7c0dc3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Compute the radix for gen8 page table levels (bsc#1152489)
- commit f2ad378
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Markup i915_ppgtt height (bsc#1152489)
- commit 4cd3eb4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Reorder gen8 ppgtt free/clear/alloc (bsc#1152489)
- commit 34d0777
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Wrap page_table with page_directory (bsc#1152489)
- commit 5636b99
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Use shallow dma pages for scratch (bsc#1152489)
- commit d8373ee
* Tue Sep 29 2020 hare@suse.de
- compat: provide compat_ptr() on all architectures
  (bsc#1175995,jsc#SLE-15608).
- commit a31658b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add engine name to workaround debug print (bsc#1152489)
- commit e174407
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Implement read-only support in whitelist selftest (bsc#1152489)
- commit 58f5b84
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add test for invalid flag bits in whitelist entries (bsc#1152489)
- commit fca4856
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Update DPLL clock reference register (bsc#1152489)
- commit a2cac2f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add DPLL registers (bsc#1152489)
- commit 213cd0b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add vbt value mapping for DDC Bus pin (bsc#1152489)
- commit 5eb25d0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: port to ddc pin mapping (bsc#1152489)
- commit 486586e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add gmbus gpio pin to port mapping (bsc#1152489)
- commit e1c6ed4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gen12: MBUS B credit change (bsc#1152489)
- commit 43d773f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: apply Display WA #1178 to fix type C dongles (bsc#1152489)
- commit 289d2eb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: init ddi port A-C for Tiger Lake (bsc#1152489)
- commit ab5fb4b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add additional PHYs for Tiger Lake (bsc#1152489)
- commit 43aa50a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add additional ports for Tiger Lake (bsc#1152489)
- commit 3c0ce69
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add pll manager (bsc#1152489)
- commit b3908ff
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add new pll ids (bsc#1152489)
- commit 71113ac
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add power well to support 4th pipe (bsc#1152489)
- commit 3736b5b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add power well support (bsc#1152489)
- commit af5e8a1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: rename TRANSCODER_EDP_VDSC to use on transcoder A (bsc#1152489)
- commit 41d0581
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Check if pipe D is fused (bsc#1152489)
- commit efbc707
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add TGL PCI IDs (bsc#1152489)
- commit 309849c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Add TGL PCH detection in virtualized environment (bsc#1152489)
- commit 97bd6e1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: Introduce Tiger Lake PCH (bsc#1152489)
- commit 18a418c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/tgl: add initial Tiger Lake definitions (bsc#1152489)
- commit 7b4c8da
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add 4th pipe and transcoder (bsc#1152489)
- commit 2061af6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Don't overestimate 4:2:0 link symbol clock (bsc#1152489)
- commit 5afa2e6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Copy name string into ring buffer for (bsc#1152489)
- commit 3962ec3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Drop redundant ctx param from kerneldoc (bsc#1152489)
- commit c979501
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Don't pass stack garbage to pcode in the second data (bsc#1152489)
- commit 2543a5f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use intel_ types in intel_atomic_commit() (bsc#1152489)
- commit 2e62061
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use intel_ types in intel_{lock,modeset}_all_pipes() (bsc#1152489)
- commit e4b5ced
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Polish intel_atomic_track_fbs() (bsc#1152489)
- commit eed7093
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Polish intel_shared_dpll_swap_state() (bsc#1152489)
- commit 231dca8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Simplify modeset_get_crtc_power_domains() arguments (bsc#1152489)
- commit 6129bfa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Check crtc_state->wm.need_postvbl_update before grabbing (bsc#1152489)
- commit dfc8160
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use the "display core" power domain in vlv/chv set_cdclk() (bsc#1152489)
- commit 8f037b4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Hold the vma manager lock while modifying (bsc#1152489)
- commit 3b472ce
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/sdvo: Fix handling if zero hbuf size (bsc#1152489)
- commit 4a33c3b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Simplify guc client (bsc#1152489)
- commit f3f6f78
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Remove preemption support for current fw (bsc#1152489)
- commit 44c7886
* Tue Sep 29 2020 msuchanek@suse.de
- powerpc/papr_scm: Add PAPR command family to pass-through
  command-set (bsc#1175052 jsc#SLE-13823 ltc#186863).
- commit 010b45a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Ensure we don't clamp a random offset to 32b (bsc#1152489)
- commit 31544ad
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Drop the duplicate icl workaround (bsc#1152489)
- commit 4a1f5da
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl: Enable DDI-D (bsc#1152489)
- commit 46e6624
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Transition port type checks to phy checks (bsc#1152489)
- commit b6ffe62
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gen11: Convert combo PHY logic to use new 'enum phy' (bsc#1152489)
- commit c7090c8
* Tue Sep 29 2020 hare@suse.de
- scsi: core: Fix scsi_get/set_resid() interface
  (bsc#1175995,jsc#SLE-15608).
- commit 2f81aac
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gen11: Program ICL_DPCLKA_CFGCR0 according to PHY (bsc#1152489)
- commit c03e255
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gen11: Start distinguishing 'phy' from 'port' (bsc#1152489)
- commit dcd2819
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: move intel_ddi_set_fia_lane_count to intel_tc.c (bsc#1152489)
- commit 9ca4b15
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: fix include order in intel_tc.* (bsc#1152489)
- commit bf0606a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: make new intel_tc.c use uncore accessors (bsc#1152489)
- commit 7508ac6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Fixed Input CSC Co-efficients for BT601/709 (bsc#1152489)
- commit ebbcb16
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Fix Y pre-offset for Full Range YCbCr (bsc#1152489)
- commit 1cb1055
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Handle YCbCr to RGB conversion for BT2020 case (bsc#1152489)
- commit 49d43c8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Record preemption for selftests (bsc#1152489)
- commit a38107d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Remove unused i915_gem_context_lookup_engine (bsc#1152489)
- commit fdb3f00
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: add infrastructure to hold off preemption on a request (bsc#1152489)
- commit 52ea2c4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: enumerate scratch fields (bsc#1152489)
- commit b8d5b6b
* Tue Sep 29 2020 msuchanek@suse.de
- Fix patch order in sorted section.
- commit c25ea98
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/userptr: Don't mark readonly objects as dirty (bsc#1152489)
- commit a652283
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Clear the shared port PLLs from the new crtc state (bsc#1152489)
- commit e5b127f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Clear the shared PLL from the put_dplls() hook (bsc#1152489)
- commit 2711181
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/sdvo: Add helpers to get the cmd/status string (bsc#1152489)
- commit 4d5ecbc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/sdvo: Shrink sdvo_cmd_names[] strings (bsc#1152489)
- commit 629cfde
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/sdvo: Remove duplicate SET_INPUT_TIMINGS_PART1 cmd name (bsc#1152489)
- commit 56d828c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/sdvo: Use named initializers for the SDVO command names (bsc#1152489)
- commit a48c662
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add icl mipi dsi properties (bsc#1152489)
- commit 6a42bb3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/hdcp: debug logs for sink related failures (bsc#1152489)
- commit cdf4061
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Remove presumption of RCS0 (bsc#1152489)
- commit b03071c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Apply RCS workarounds to the render class (bsc#1152489)
- commit 856a298
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Fill in a little more of the dummy fence (bsc#1152489)
- commit 542cc27
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Set igt_spinner.gt for early exit (bsc#1152489)
- commit 2fa4291
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Update DRIVER_DATE to 20190708 (bsc#1152489)
- commit 05aea7e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Reorder error cleanup for whitelist checking (bsc#1152489)
- commit d7a63a7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Explicitly track active fw_domain timers (bsc#1152489)
- commit b0c16d2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Pull assert_forcewake_active() underneath the lock (bsc#1152489)
- commit 21ca764
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Introduce release_pd_entry (bsc#1152489)
- commit 67c2fb9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Setup phys pages for 3lvl pdps (bsc#1152489)
- commit fc9e8dc
* Tue Sep 29 2020 colyli@suse.de
- dm: fix comment in dm_process_bio() (bsc#1175995,
  jsc#SLE-15608).
- dm: fix bio splitting and its bio completion order for regular
  IO (bsc#1175995, jsc#SLE-15608).
- dm: Call proper helper to determine dax support (bsc#1175995,
  jsc#SLE-15608).
- dm/dax: Fix table reference counts (bsc#1175995, jsc#SLE-15608).
- dm thin metadata: Fix use-after-free in dm_bm_set_read_only
  (bsc#1175995, jsc#SLE-15608).
- dm thin metadata:  Avoid returning cmd->bm wild pointer on error
  (bsc#1175995, jsc#SLE-15608).
- dm cache metadata: Avoid returning cmd->bm wild pointer on error
  (bsc#1175995, jsc#SLE-15608).
- dm integrity: fix error reporting in bitmap mode after creation
  (bsc#1175995, jsc#SLE-15608).
- dm mpath: fix racey management of PG initialization
  (bsc#1175995, jsc#SLE-15608).
- dm writecache: handle DAX to partitions on persistent memory
  correctly (bsc#1175995, jsc#SLE-15608).
- dm init: Set file local variable static (bsc#1175995,
  jsc#SLE-15608).
- dm ioctl: Fix compilation warning (bsc#1175995, jsc#SLE-15608).
- dm raid: Remove empty if statement (bsc#1175995, jsc#SLE-15608).
- dm verity: Fix compilation warning (bsc#1175995, jsc#SLE-15608).
- dm crypt: Enable zoned block device support (bsc#1175995,
  jsc#SLE-15608).
- dm bufio: do buffer cleanup from a workqueue (bsc#1175995,
  jsc#SLE-15608).
- dm verity: add "panic_on_corruption" error handling mode
  (bsc#1175995, jsc#SLE-15608).
- commit a277279
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Tear down setup and cleanup macros for page dma (bsc#1152489)
- commit 0a501e4
* Tue Sep 29 2020 hare@suse.de
- scsi: sg: sg_ioctl(): get rid of access_ok()
  (bsc#1175995,jsc#SLE-15608).
- scsi: sg: sg_write(): get rid of (bsc#1175995,jsc#SLE-15608).
- scsi: sg: sg_read(): get rid of access_ok()/__copy_..._user()
  (bsc#1175995,jsc#SLE-15608).
- commit 25a21c7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: pde entry encoding is identical (bsc#1152489)
- commit 2d332b1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Remove set but not used variable 'intel_dig_port' (bsc#1152489)
- commit c100cb9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Remove set but not used variable 'encoder' (bsc#1152489)
- commit 966ec8b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Order assert forcewake test (bsc#1152489)
- commit f2a6acb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl: Add support for DPLL4 (v10) (bsc#1152489)
- commit d2c195e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Clean up skl vs. icl plane formats (bsc#1152489)
- commit fa0d772
* Tue Sep 29 2020 colyli@suse.de
- dm mpath: use double checked locking in fast path (bsc#1175995,
  jsc#SLE-15608).
- Refresh for the above change,
  patches.suse/dm-mpath-no-partitions-feature.
- commit ab52c0c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Cosmetic fix for skl+ plane switch statement (bsc#1152489)
- commit b7347c1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Deal with cpp==8 for g4x watermarks (bsc#1152489)
- commit 1e9db9f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Program plane gamma ramps (bsc#1152489)
- commit 227945e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Disable sprite gamma on ivb-bdw (bsc#1152489)
- commit 9579e7e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add windowing for primary planes on gen2/3 and chv (bsc#1152489)
- commit b8cd477
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move dev_priv->pm_i{m, e}r into intel_gt (bsc#1152489)
- commit bfae517
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Remove some legacy mmio accessors from interrupt handling (bsc#1152489)
- commit 070e099
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Rework some interrupt handling functions to take intel_gt (bsc#1152489)
- commit 4cdf8cd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Show instdone for each engine in debugfs (bsc#1152489)
- commit 041a41e
* Tue Sep 29 2020 colyli@suse.de
- dm mpath: rename current_pgpath to pgpath in
  multipath_prepare_ioctl (bsc#1175995, jsc#SLE-15608).
- dm mpath: rework __map_bio() (bsc#1175995, jsc#SLE-15608).
- dm mpath: factor out multipath_queue_bio (bsc#1175995,
  jsc#SLE-15608).
- dm mpath: push locking down to must_push_back_rq() (bsc#1175995,
  jsc#SLE-15608).
- dm mpath: take m->lock spinlock when testing QUEUE_IF_NO_PATH
  (bsc#1175995, jsc#SLE-15608).
- dm mpath: changes from initial m->flags locking audit
  (bsc#1175995, jsc#SLE-15608).
- block: remove bdev_stack_limits (bsc#1175995, jsc#SLE-15608).
- block: inherit the zoned characteristics in blk_stack_limits
  (bsc#1175995, jsc#SLE-15608).
- dm: use noio when sending kobject event (bsc#1175995,
  jsc#SLE-15608).
- dm zoned: Fix zone reclaim trigger (bsc#1175995, jsc#SLE-15608).
- dm: use dynamic debug instead of compile-time config option
  (bsc#1175995, jsc#SLE-15608).
- dm,dax: Add dax zero_page_range operation (bsc#1175995,
  jsc#SLE-15608).
- dax, pmem: Add a dax operation zero_page_range (bsc#1175995,
  jsc#SLE-15608).
- commit 6eb8010
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Be engine agnostic (bsc#1152489)
- commit 8f93848
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/overlay: Stash the kernel context on initialisation (bsc#1152489)
- commit 7e0902b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/hangcheck: Look at instdone for all engines (bsc#1152489)
- commit 6bf45c1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Drain the freedlists between exec passes (bsc#1152489)
- commit 37580a0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Pull engine w/a initialisation into common (bsc#1152489)
- commit b9fa19d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Dump w/a lists on all engines (bsc#1152489)
- commit 24fe078
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Upgrade to GuC 33.0.0 (bsc#1152489)
- commit c40643e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Handle double alloc failures (bsc#1152489)
- commit b6eab0b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Show support for accurate sw PMU busyness tracking (bsc#1152489)
- commit 7bfcd07
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gem: Defer obj->base.resv fini until RCU callback (bsc#1152489)
- commit 3318a22
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Ignore forcewake acquisition for posting_reads (bsc#1152489)
- commit e43d902
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Assume we hold forcewake for execlists resume (bsc#1152489)
- commit 7dac973
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Use caller provided forcewake for intel_mocs_init_engine (bsc#1152489)
- commit b30c7b7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Check caller held wakerefs in assert_forcewakes_active (bsc#1152489)
- commit fcfdbe8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Flush the workqueue before draining (bsc#1152489)
- commit 8492630
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move the renderstate setup under gt/ (bsc#1152489)
- commit f4e3013
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add N & CTS values for 10/12 bit deep color (bsc#1152489)
- commit b25323f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use port clock to set correct N value (bsc#1152489)
- commit d40e9e0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Mark up vma->active as safe for use inside shrinkers (bsc#1152489)
- commit 5b416c8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Markup potential lock for i915_active (bsc#1152489)
- commit 2ca89d0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gem: Free pages before rcu-freeing the object (bsc#1152489)
- commit 6644656
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Hesitate before slicing (bsc#1152489)
- commit 3ff1b58
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Lock the drm_mm while modifying (bsc#1152489)
- commit 285cf4a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Common live setup/teardown (bsc#1152489)
- commit 968e414
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/display: Handle lost primary_port across suspend (bsc#1152489)
- commit 43a1326
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: synchronize_irq() against the actual irq (bsc#1152489)
- commit 0eb3a14
* Tue Sep 29 2020 hare@suse.de
- scsi: sg: sg_write(): __get_user() can
  fail.. (bsc#1175995,jsc#SLE-15608).
- scsi: sg: sg_new_write(): replace access_ok() +
  (bsc#1175995,jsc#SLE-15608).
- scsi: sg: sg_ioctl(): fix copyout handling
  (bsc#1175995,jsc#SLE-15608).
- commit 7572f7b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Report if i915_active is still busy upon waiting (bsc#1152489)
- commit cba7fd5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Refactor CSB state machine (bsc#1152489)
- commit 48fe304
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl: Don't program PHY_MISC on EHL PHY C (bsc#1152489)
- commit d2ca1f9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl: Add third combo PHY offset (bsc#1152489)
- commit 747c8ac
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Drop port parameter to icl_get_combo_buf_trans() (bsc#1152489)
- commit 767191c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Avoid reclaim locks during reset (bsc#1152489)
- commit b9c474d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: WARN about invalid lane reversal in TBT-alt/DP-alt modes (bsc#1152489)
- commit 8cdf53b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Remove unneeded disconnect in TypeC legacy port mode (bsc#1152489)
- commit 1059a05
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Add state verification for the TypeC port mode (bsc#1152489)
- commit 6693a60
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Keep the TypeC port mode fixed when the port is active (bsc#1152489)
- commit d3d62df
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Reserve all required PLLs for TypeC ports (bsc#1152489)
- commit 54ca493
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Split getting the DPLLs to port type specific functions (bsc#1152489)
- commit 868bf8c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Sanitize the shared DPLL find/reference interface (bsc#1152489)
- commit d3adce4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Sanitize the shared DPLL reserve/release interface (bsc#1152489)
- commit 4adb6fe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Sanitize the TypeC FIA lane configuration decoding (bsc#1152489)
- commit 4cc3d06
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Keep the TypeC port mode fixed for detect/AUX transfers (bsc#1152489)
- commit f5d40f9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Fix the TypeC port mode sanitization during loading/resume (bsc#1152489)
- commit 08a4a81
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Sanitize the TypeC connect/detect sequences (bsc#1152489)
- commit 14b3f52
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Handle the TCCOLD power-down event (bsc#1152489)
- commit 53a837e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Wait for TypeC PHY complete flag to clear in safe mode (bsc#1152489)
- commit c0d1ee0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Factor out common parts from TypeC port handling functions (bsc#1152489)
- commit fdf81d3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Unify the TypeC port notation in debug/error messages (bsc#1152489)
- commit 0ebe974
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use the correct AUX power domain in TypeC TBT-alt mode (bsc#1152489)
- commit 1ee82d3
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Don't enable the DDI-IO power in the TypeC TBT-alt mode (bsc#1152489)
- commit b7faf12
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Sanitize the terminology used for TypeC port modes (bsc#1152489)
- commit 59adddf
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move the TypeC port handling code to a separate file (bsc#1152489)
- commit b4c57c8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Tune down WARNs about TBT AUX power well enabling (bsc#1152489)
- commit 25abd1c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Add support to read out the TBT PLL HW state (bsc#1152489)
- commit d753508
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use intel state as much as possible in wm code (bsc#1152489)
- commit d0ba45c
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Pass intel state to plane functions as well (bsc#1152489)
- commit 162a95f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use intel_crtc_state in sanitize_watermarks() too (bsc#1152489)
- commit 71a0a4f
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: move SG_GET_REQUEST_TABLE handling
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: ppp: move simple commands into
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: handle PPPIOCGIDLE for 64-bit time_t
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: move PPPIOCSCOMPRESS to ppp_generic
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: unify copy-in of ppp filters
  (bsc#1175995,jsc#SLE-15608).
- tty: handle compat PPP ioctls (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: move SIOCOUTQ out of compat_ioctl.c
  (bsc#1175995,jsc#SLE-15608).
- commit 199018a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Convert hw state verifier to take more intel state, v2. (bsc#1152489)
- commit e10be14
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Convert most of atomic commit to take more intel state (bsc#1152489)
- commit 29867b4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Pass intel_crtc_state to needs_modeset() (bsc#1152489)
- commit ff659ab
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: rework reading pipe disable fuses (bsc#1152489)
- commit 04a39fe
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Make i945gm_vblank_work_func static (bsc#1152489)
- commit 9aa882a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: make intel_uc_fw.h self-contained (bsc#1152489)
- commit 25199e5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: make intel_gvt.h self-contained (bsc#1152489)
- commit 13fecc4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: make intel_guc_reg.h self-contained (bsc#1152489)
- commit 2016efc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: make intel_guc_fwif.h self-contained (bsc#1152489)
- commit ace3aea
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: make intel_guc_ct.h self-contained (bsc#1152489)
- commit 2a7631f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: make i915_vgpu.h self-contained (bsc#1152489)
- commit d208ed4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: make i915_pvinfo.h self-contained (bsc#1152489)
- commit f92ace4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: make i915_globals.h self-contained (bsc#1152489)
- commit be04950
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: make i915_fixed.h self-contained (bsc#1152489)
- commit bd6a762
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: add header search path to subdir Makefiles (bsc#1152489)
- commit dad8563
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: prefix header search path with $(srctree)/ (bsc#1152489)
- commit bf691ec
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move OA files to separate folder (bsc#1152489)
- commit 666987a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl: Add voltage level requirement table (bsc#1152489)
- commit f1788ae
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl: Remove unsupported cd clocks (bsc#1152489)
- commit e84ca99
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Add new supported CD clocks (bsc#1152489)
- commit c82a122
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: move WDIOC handling into wdt drivers
  (bsc#1175995,jsc#SLE-15608).
- fs: compat_ioctl: move FITRIM emulation into file systems
  (bsc#1175995,jsc#SLE-15608).
- commit bd7179b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Initialize drm_driver vblank funcs at compile time (bsc#1152489)
- commit 2d8f63b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Nuke drm_driver irq vfuncs (bsc#1152489)
- commit 6683f87
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Switch to per-crtc vblank vfuncs (bsc#1152489)
- commit 657e8b5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Fixup atomic reset checking (bsc#1152489)
- commit f09b632
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Drop manual request wakerefs around hangcheck (bsc#1152489)
- commit 723190f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Serialise nop reset with retirement (bsc#1152489)
- commit a336db1
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Check backlight type while doing eDP backlight (bsc#1152489)
- commit 9f814fa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/icl: Add missing device ID (bsc#1152489)
- commit 473e38d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Add some debug tracing for context pinning (bsc#1152489)
- commit 867bd6a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Always call kref_init for the timeline (bsc#1152489)
- commit a64a081
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Drop stale commentary for timeline density (bsc#1152489)
- commit 7a3b9f8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Hold ref on request across waits (bsc#1152489)
- commit d146676
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: remove unused convert_in_user macro
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: remove last RAID handling code
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: remove /dev/raw ioctl translation
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: remove PCI ioctl translation
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: remove joystick ioctl translation
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: remove /dev/random commands
  (bsc#1175995,jsc#SLE-15608).
- commit ad91f6b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Rename intel_wakeref_[is]_active (bsc#1152489)
- commit 9a26367
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Pass intel_gt to pm routines (bsc#1152489)
- commit d734869
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: Add debug capture of GuC exception (bsc#1152489)
- commit 6d1feb4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Convert recursive defer_request() into iterative (bsc#1152489)
- commit eaa1905
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl: Add missing VECS engine (bsc#1152489)
- commit da48058
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl: Add one additional PCH ID to MCC (bsc#1152489)
- commit e50c3d5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gem: Clear read/write domains for GPU clear (bsc#1152489)
- commit a0abfc4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Always clear ring_pause if we do not submit (bsc#1152489)
- commit 8b27093
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: remove IGNORE_IOCTL() (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/compat_ioctl-reimplement-SG_IO-handling.patch.
- commit ac8a86d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/blt: Remove recursive vma->lock (bsc#1152489)
- commit 7c4c5b7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Local debug BUG_ON for intel_wakeref (bsc#1152489)
- commit 5c0f892
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Provide an i915_active.acquire callback (bsc#1152489)
- commit 776194d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Throw away the active object retirement complexity (bsc#1152489)
- commit 9fcb12b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Track i915_active using debugobjects (bsc#1152489)
- commit d211f42
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Remove waiting & retiring from shrinker paths (bsc#1152489)
- commit 59debf9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: handle GuC messages received with CTB disabled (bsc#1152489)
- commit 6e0a119
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/guc: reorder enable/disable communication steps (bsc#1152489)
- commit fe34fa4
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Fixup kerneldoc parameters (bsc#1152489)
- commit 1c51e70
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gt: Rename i915_gt_timelines (bsc#1152489)
- commit 20363b7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Prevent dereference of engine before NULL check in error (bsc#1152489)
- commit 0ab996e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Eliminate dual personality of i915_scratch_offset (bsc#1152489)
- commit 1ea29f7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Rename i915_timeline to intel_timeline and move under gt (bsc#1152489)
- commit 2d099cc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Make timelines gt centric (bsc#1152489)
- commit 8211640
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: remove HIDIO translation
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: remove HCIUART handling
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: move ATYFB_CLK handling to atyfb driver
  (bsc#1175995,jsc#SLE-15608).
- commit e38f32e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Save trip via top-level i915 in a few more places (bsc#1152489)
- commit eeb963f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Compartmentalize ring buffer creation (bsc#1152489)
- commit 04be609
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Store ggtt pointer in intel_gt (bsc#1152489)
- commit 45ab08e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Compartmentalize i915_gem_init_ggtt (bsc#1152489)
- commit 90c5e03
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Compartmentalize i915_ggtt_cleanup_hw (bsc#1152489)
- commit acbba89
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Compartmentalize timeline_init/park/fini (bsc#1152489)
- commit 8b61c6d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move i915_gem_chipset_flush to intel_gt (bsc#1152489)
- commit a5cab02
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Convert i915_gem_flush_ggtt_writes to intel_gt (bsc#1152489)
- commit eff6e6f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Compartmentalize i915_gem_suspend/restore_gtt_mappings (bsc#1152489)
- commit cf5bbf6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Store intel_gt backpointer in vm (bsc#1152489)
- commit b24cc8d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Make ggtt invalidation work on ggtt (bsc#1152489)
- commit 85eb15d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Compartmentalize i915_ggtt_init_hw (bsc#1152489)
- commit 0e4b1e7
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Compartmentalize i915_ggtt_probe_hw (bsc#1152489)
- commit 994f8bd
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Stop using I915_READ/WRITE in intel_wopcm_init_hw (bsc#1152489)
- commit 5b9fa34
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move intel_engines_resume into common init (bsc#1152489)
- commit fe06128
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Convert i915_gem_init_hw to intel_gt (bsc#1152489)
- commit efad4f2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Consolidate some open coded mmio rmw (bsc#1152489)
- commit f0ac879
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Convert i915_ppgtt_init_hw to intel_gt (bsc#1152489)
- commit cca0ee6
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Convert intel_mocs_init_l3cc_table to intel_gt (bsc#1152489)
- commit ff7852a
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Store backpointer to intel_gt in the engine (bsc#1152489)
- commit 10ff575
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Convert gt workarounds to intel_gt (bsc#1152489)
- commit beee8aa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Convert init_unused_rings to intel_gt (bsc#1152489)
- commit 07bae73
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Use intel_uncore_rmw in intel_gt_init_swizzling (bsc#1152489)
- commit 2371ac9
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Convert i915_gem_init_swizzling to intel_gt (bsc#1152489)
- commit e8a2faa
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Make i915_check_and_clear_faults take intel_gt (bsc#1152489)
- commit 012d219
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move intel_gt_pm_init under intel_gt_init_early (bsc#1152489)
- commit 3388f6b
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Store some backpointers in struct intel_gt (bsc#1152489)
- commit 902c5ee
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: move tape handling into drivers
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/compat_ioctl-reimplement-SG_IO-handling.patch.
- commit c617b2f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Move intel_gt initialization to a separate file (bsc#1152489)
- commit 326d0ad
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Introduce struct intel_gt as replacement for anonymous (bsc#1152489)
- commit a1fd9d5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Convert intel_vgt_(de)balloon to uncore (bsc#1152489)
- commit 719feac
* Tue Sep 29 2020 hare@suse.de
- compat_ioctl: move more drivers to compat_ptr_ioctl
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: move drivers to compat_ptr_ioctl
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: move rtc handling into drivers/rtc/dev.c
  (bsc#1175995,jsc#SLE-15608).
- commit cb70d01
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Keep virtual context alive until after we kick (bsc#1152489)
- commit eb683fb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gtt: Defer address space cleanup to an RCU worker (bsc#1152489)
- commit 0fb5be2
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl/dsi: Enable AFE over PPI strap (bsc#1152489)
- commit b26c778
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl/dsi: Set lane latency optimization for DW1 (bsc#1152489)
- commit 51f30ba
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/selftests: Use request managed wakerefs (bsc#1152489)
- commit f45a071
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Rings are always flushed (bsc#1152489)
- commit 42322f5
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Minimalistic timeslicing (bsc#1152489)
- commit 287bcdb
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/execlists: Preempt-to-busy (bsc#1152489)
- commit 8042e03
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/gvt: decouple check_vgpu() from uncore_init() (bsc#1152489)
- commit 5d5921d
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: dynamically allocate forcewake domains (bsc#1152489)
- commit 371f5c0
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: skip forcewake actions on forcewake-less uncore (bsc#1152489)
- commit 5a57226
* Tue Sep 29 2020 hare@suse.de
- compat_sys_ioctl(): make parallel to do_vfs_ioctl()
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/fs-add-generic-UNRESVSP-and-ZERO_RANGE-ioctl-handler.patch.
- commit c7b14c8
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: kill uncore_to_i915 (bsc#1152489)
- commit e2b0f30
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: kill uncore_sanitize (bsc#1152489)
- commit 0ff6085
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: use vfuncs for reg_read/write_fw_domains (bsc#1152489)
- commit 72e793f
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915/ehl: Allow combo PHY A to drive a third external display (bsc#1152489)
- commit a53aa5e
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Flush the execution-callbacks on retiring (bsc#1152489)
- commit bafd6ba
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/i915: Signal fence completion from i915_request_wait (bsc#1152489)
- commit 32f8166
* Tue Sep 29 2020 tzimmermann@suse.de
- dma-mapping: remove dma_{alloc,free,mmap}_writecombine (bsc#1152489)
- commit 83161ba
* Tue Sep 29 2020 tzimmermann@suse.de
- video: fbdev: sm501fb: convert platform driver to use dev_groups (bsc#1152489)
- commit 88b54fe
* Tue Sep 29 2020 tzimmermann@suse.de
- video: fbdev: w100fb: convert platform driver to use dev_groups (bsc#1152489)
- commit 98a4e2b
* Tue Sep 29 2020 tzimmermann@suse.de
- video: fbdev: wm8505fb: convert platform driver to use dev_groups (bsc#1152489)
- commit 0219165
* Tue Sep 29 2020 tzimmermann@suse.de
- video: pxafb: Remove cpufreq policy notifier (bsc#1152489)
- commit 8abd9cd
* Tue Sep 29 2020 tzimmermann@suse.de
- video: sa1100fb: Remove cpufreq policy notifier (bsc#1152489)
- commit ac114bf
* Tue Sep 29 2020 tzimmermann@suse.de
- platform: Add platform_find_device_by_driver() helper (bsc#1152489)
- commit f4e270e
* Tue Sep 29 2020 tzimmermann@suse.de
- drivers: Introduce device lookup variants by of_node (bsc#1152489)
- commit aacaedc
* Tue Sep 29 2020 tzimmermann@suse.de
- drm/vmwgfx: Update the backdoor call with support for new (bsc#1152489)
- commit cf60c9c
* Tue Sep 29 2020 tzimmermann@suse.de
- fbdev: remove w90x900/nuc900 platform drivers (bsc#1152489)
- commit 964c4bb
* Tue Sep 29 2020 tzimmermann@suse.de
- fbdev: da8xx: use resource management for dma (bsc#1152489)
- commit f5c16e8
* Tue Sep 29 2020 tzimmermann@suse.de
- fbdev: da8xx-fb: drop a redundant if (bsc#1152489)
- commit 5913373
* Tue Sep 29 2020 tzimmermann@suse.de
- fbdev: da8xx-fb: use devm_platform_ioremap_resource() (bsc#1152489)
- commit a0c17a0
* Tue Sep 29 2020 tzimmermann@suse.de
- fbdev: da8xx: remove panel_power_ctrl() callback from platform data (bsc#1152489)
- commit 5d2f7dd
* Tue Sep 29 2020 tzimmermann@suse.de
- fbdev: da8xx: add support for a regulator (bsc#1152489)
- commit 86f21c6
* Tue Sep 29 2020 tzimmermann@suse.de
- m68k: atari: Rename shifter to shifter_st to avoid conflict (bsc#1152489)
- commit ccd3fa6
* Tue Sep 29 2020 hare@suse.de
- compat: move FS_IOC_RESVSP_32 handling to fs/ioctl.c
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/fs-add-generic-UNRESVSP-and-ZERO_RANGE-ioctl-handler.patch.
- commit 04da741
* Tue Sep 29 2020 tbogendoerfer@suse.de
- RDMA/bnxt_re: Restrict the max_gids to 256 (bsc#1173017).
- RDMA/bnxt_re: Fix the qp table indexing (bsc#1173017).
- RDMA/bnxt_re: Do not report transparent vlan from QP1
  (bsc#1173017).
- commit 279a57c
* Tue Sep 29 2020 ohering@suse.de
- irqdomain/treewide: Free firmware node after domain removal (git-fixes).
- commit 2fa0cd5
* Tue Sep 29 2020 tzimmermann@suse.de
- Remove most fbdev patches
  Done in preparation of the DRM upgrade.
- commit 9f67476
* Tue Sep 29 2020 ohering@suse.de
- irqdomain/treewide: Keep firmware node unconditionally allocated (git-fixes).
- commit 7778bc2
* Tue Sep 29 2020 hare@suse.de
- pktcdvd: add compat_ioctl handler (bsc#1175995,jsc#SLE-15608). - Refresh patches.suse/block-move-the-devnode-callback-to-struct-block_devi.patch.
- commit 4244c1a
* Tue Sep 29 2020 tzimmermann@suse.de
- blacklist.conf: Remove DRM commits
  This removes DRM commits in preparation of the DRM backport for SLE15-SP3.
- commit 7f696a6
* Tue Sep 29 2020 ohering@suse.de
- Drivers: hv: vmbus: Add timeout to vmbus_wait_for_unload
  (git-fixes).
- Drivers: hv: vmbus: hibernation: do not hang forever in
  vmbus_bus_resume() (git-fixes).
- hv_utils: drain the timesync packets on onchannelcallback
  (bsc#1176877).
- hv_utils: return error if host timesysnc update is stale
  (bsc#1176877).
- Drivers: hv: Specify receive buffer size using Hyper-V page size
  (bsc#1176877).
- commit 5ca04fc
* Mon Sep 28 2020 tiwai@suse.de
- soundwire: bus: only clear valid DPN interrupts (jsc#SLE-16518).
- soundwire: bus: only clear valid DP0 interrupts (jsc#SLE-16518).
- soundwire: registers: add definitions for clearable interrupt
  fields (jsc#SLE-16518).
- soundwire: bus: reset slave_notify status at each loop
  (jsc#SLE-16518).
- soundwire: bus: add comments to explain interrupt loop filter
  (jsc#SLE-16518).
- soundwire: SDCA: add helper macro to access controls
  (jsc#SLE-16518).
- soundwire: SDCA: detect sdca_cascade interrupt (jsc#SLE-16518).
- ASoC: rt715: Add power-up delay to fix dmic pop sound issue
  (jsc#SLE-16518).
- commit bab2857
* Mon Sep 28 2020 tiwai@suse.de
- regmap: Add can_sleep configuration option (jsc#SLE-16518).
- regmap: Use flexible sleep (jsc#SLE-16518).
- regmap: soundwire: remove unused header mod_devicetable.h
  (jsc#SLE-16518).
- regmap: add Intel SPI Slave to AVMM Bus Bridge support
  (jsc#SLE-16518).
- commit 9c695ae
* Mon Sep 28 2020 tiwai@suse.de
- timer: add fsleep for flexible sleeping (jsc#SLE-16518).
- commit 60328a7
* Mon Sep 28 2020 tiwai@suse.de
- regmap: fix page selection for noinc writes (jsc#SLE-16518).
- regmap: fix page selection for noinc reads (jsc#SLE-16518).
- regmap: debugfs: Add back in erroneously removed initialisation
  of ret (jsc#SLE-16518).
- regmap: debugfs: Fix handling of name string for debugfs init
  delays (jsc#SLE-16518).
- regmap: fix duplicated word in <linux/regmap.h> (jsc#SLE-16518).
- regmap: remove stray space (jsc#SLE-16518).
- regmap: convert all regmap_update_bits() and co. macros to
  static inlines (jsc#SLE-16518).
- regmap: add missing dependency on SoundWire (jsc#SLE-16518).
- regmap: fix the kerneldoc for regmap_test_bits()
  (jsc#SLE-16518).
- regmap: provide helpers for simple bit operations
  (jsc#SLE-16518).
- regmap: add helper for per-port regfield initialization
  (jsc#SLE-16518).
- regmap-i2c: add 16-bit width registers support (jsc#SLE-16518).
- regmap: Simplify implementation of the
  regmap_field_read_poll_timeout() macro (jsc#SLE-16518).
- regmap: Simplify implementation of the
  regmap_read_poll_timeout() macro (jsc#SLE-16518).
- regmap-irq: make it possible to add irq_chip do a specific
  device node (jsc#SLE-16518).
- regmap: Add bus reg_update_bits() support (jsc#SLE-16518).
- regmap: add reg_sequence helpers (jsc#SLE-16518).
- regmap: wrong descriptions in regmap_range_cfg (jsc#SLE-16518).
- regmap: add iopoll-like atomic polling macro (jsc#SLE-16518).
- regmap-i2c: constify regmap_bus structures (jsc#SLE-16518).
- regmap: regmap-w1: Drop unreachable code (jsc#SLE-16518).
- regmap: no need to check return value of debugfs_create
  functions (jsc#SLE-16518).
- regmap-irq: Correct error paths in regmap_irq_thread for
  pm_runtime (jsc#SLE-16518).
- commit f8bfe3f
* Mon Sep 28 2020 hare@suse.de
- do_vfs_ioctl(): use saner types (bsc#1175995,jsc#SLE-15608).
- commit 15b6d9b
* Mon Sep 28 2020 yousaf.kaukab@suse.com
- gpio: Avoid using pin ranges with !PINCTRL (jsc#SLE-15847).
- pinctrl: qcom: ssbi-gpio: Fix fwspec parsing bug
  (jsc#SLE-15847).
- memory: tegra30-emc: Fix panic on suspend (jsc#SLE-15847).
- commit 545a731
* Mon Sep 28 2020 hare@suse.de
- compat: itanic doesn't have one (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/fs-add-generic-UNRESVSP-and-ZERO_RANGE-ioctl-handler.patch.
- commit 3d75907
* Mon Sep 28 2020 hare@suse.de
- FIGETBSZ: fix compat (bsc#1175995,jsc#SLE-15608).
- commit fa84d24
* Mon Sep 28 2020 tiwai@suse.de
- supported.conf: add soundwire-generic-allocation
- commit 7979ab4
* Mon Sep 28 2020 tbogendoerfer@suse.de
- drm/amdkfd: fix a use after free race with mmu_notifer
  unregister (jsc#SLE-15176).
- drm/amdkfd: remove set but not used variable 'pdd'
  (jsc#SLE-15176).
- drm/amdkfd: Fill amdgpu_task_info for KFD VMs (jsc#SLE-15176).
- commit d1c10e0
* Mon Sep 28 2020 tiwai@suse.de
- soundwire: Add generic bandwidth allocation algorithm
  (jsc#SLE-16518).
- Update config files.
- commit b659691
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: codecs: realtek-soundwire: ignore initial PARITY errors
  (jsc#SLE-16518).
- commit f0058cf
* Mon Sep 28 2020 tiwai@suse.de
- soundwire: sysfs: add slave status and device number before
  probe (jsc#SLE-16518).
- soundwire: bus: add enumerated Slave device to device list
  (jsc#SLE-16518).
- soundwire: remove an unnecessary NULL check (jsc#SLE-16518).
- soundwire: cadence: add data port test fail interrupt
  (jsc#SLE-16518).
- soundwire: intel: enable test modes (jsc#SLE-16518).
- soundwire: enable Data Port test modes (jsc#SLE-16518).
- soundwire: intel: use {u32|u16}p_replace_bits (jsc#SLE-16518).
- soundwire: cadence: use u32p_replace_bits (jsc#SLE-16518).
- soundwire: qcom: get max rows and cols info from compatible
  (jsc#SLE-16518).
- soundwire: qcom: add support to block packing mode
  (jsc#SLE-16518).
- soundwire: qcom: clear BIT FIELDs before value set
  (jsc#SLE-16518).
- soundwire: cadence: add parity error injection through debugfs
  (jsc#SLE-16518).
- soundwire: bus: export broadcast read/write capability for tests
  (jsc#SLE-16518).
- soundwire: bus: use quirk to filter out invalid parity errors
  (jsc#SLE-16518).
- soundwire: slave: add first_interrupt_done status
  (jsc#SLE-16518).
- soundwire: bus: filter-out unwanted interrupt reports
  (jsc#SLE-16518).
- ASoC/soundwire: bus: use property to set interrupt masks
  (jsc#SLE-16518).
- soundwire: qcom: fix SLIBMUS/SLIMBUS typo (jsc#SLE-16518).
- soundwire: cadence: fix race condition between suspend and
  Slave device alerts (jsc#SLE-16518).
- soundwire: qcom: add v1.5.1 compatible (jsc#SLE-16518).
- soundwire: qcom: add support for mmio soundwire master devices
  (jsc#SLE-16518).
- soundwire: qcom: avoid dependency on CONFIG_SLIMBUS
  (jsc#SLE-16518).
- soundwire: qcom: fix abh/ahb typo (jsc#SLE-16518).
- soundwire: intel: remove stream handling from .prepare and
  .hw_free (jsc#SLE-16518).
- soundwire: intel: remove .trigger operation (jsc#SLE-16518).
- soundwire: intel: fix NULL/ERR_PTR confusion (jsc#SLE-16518).
- soundwire: stream: fix NULL/IS_ERR confusion (jsc#SLE-16518).
- soundwire: remove SDW_REG_SHIFT() (jsc#SLE-16518).
- soundwire: intel_init: use FIELD_{GET|PREP} (jsc#SLE-16518).
- soundwire: intel: use FIELD_{GET|PREP} (jsc#SLE-16518).
- soundwire: cadence: use FIELD_{GET|PREP} (jsc#SLE-16518).
- soundwire: qcom : use FIELD_{GET|PREP} (jsc#SLE-16518).
- soundwire: stream: use FIELD_{GET|PREP} (jsc#SLE-16518).
- soundwire: slave: use SDW_DISCO_LINK_ID() (jsc#SLE-16518).
- soundwire: bus: use FIELD_GET() (jsc#SLE-16518).
- soundwire: define and use addr bit masks (jsc#SLE-16518).
- soundwire: intel: don't manage link power individually
  (jsc#SLE-16518).
- soundwire: intel: pass link_mask information to each master
  (jsc#SLE-16518).
- soundwire: intel: add error log for clock-stop invalid configs
  (jsc#SLE-16518).
- soundwire: stream: enable hw_sync as needed by hardware
  (jsc#SLE-16518).
- soundwire: intel: add multi-link hw_synchronization information
  (jsc#SLE-16518).
- soundwire: bus: update multi-link definition with hw sync
  details (jsc#SLE-16518).
- soundwire: intel: add missing support for all clock stop modes
  (jsc#SLE-16518).
- soundwire: intel: add multi-link support (jsc#SLE-16518).
- soundwire: intel: ignore software command retries
  (jsc#SLE-16518).
- soundwire: intel: disable shim wake on suspend (jsc#SLE-16518).
- soundwire: fix port_ready[] dynamic allocation in mipi_disco
  (jsc#SLE-16518).
- soundwire: add definition for maximum number of ports
  (jsc#SLE-16518).
- soundwire: intel: fix intel_suspend/resume defined but not
  used warning (jsc#SLE-16518).
- soundwire: intel: refine runtime pm for
  SDW_INTEL_CLK_STOP_BUS_RESET (jsc#SLE-16518).
- soundwire: intel: support clock_stop mode without quirks
  (jsc#SLE-16518).
- soundwire: intel_init: handle power rail dependencies for
  clock stop mode (jsc#SLE-16518).
- soundwire: intel: add CLK_STOP_NOT_ALLOWED support
  (jsc#SLE-16518).
- soundwire: intel: add CLK_STOP_BUS_RESET support
  (jsc#SLE-16518).
- soundwire: intel: add CLK_STOP_TEARDOWN for pm_runtime suspend
  (jsc#SLE-16518).
- soundwire: intel: pm_runtime idle scheduling (jsc#SLE-16518).
- soundwire: intel: reinitialize IP+DSP in .prepare(), but only
  when resuming (jsc#SLE-16518).
- soundwire: intel: call helper to reset Slave states on resume
  (jsc#SLE-16518).
- soundwire: intel: fix race condition on system resume
  (jsc#SLE-16518).
- soundwire: intel: reset pm_runtime status during system resume
  (jsc#SLE-16518).
- soundwire: intel: add pm_runtime support (jsc#SLE-16518).
- soundwire: intel: Add basic power management support
  (jsc#SLE-16518).
- soundwire: master: enable pm runtime (jsc#SLE-16518).
- commit 06176a0
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: SOF: Add `src_hash` to `sof_ipc_fw_version` structure
  (jsc#SLE-16518).
- ASoC: soc-dai: clarify return value for get_sdw_stream()
  (jsc#SLE-16518).
- ASoC: rt711: wait for the delayed work to finish when the
  system suspends (jsc#SLE-16518).
- ASoC: rt700: wait for the delayed work to finish when the
  system suspends (jsc#SLE-16518).
- ASoC: codecs: soundwire: remove port_ready[] usage from codecs
  (jsc#SLE-16518).
- commit 70d64d2
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: max9867: shutdown codec when changing filter type
  (jsc#SLE-16518).
- ASoC: codecs: max98373-sdw: add missing test on resume
  (jsc#SLE-16518).
- commit 48611c7
* Mon Sep 28 2020 yousaf.kaukab@suse.com
- gpio: export of_pinctrl_get to modules (jsc#SLE-15847).
- commit f81dcf5
* Mon Sep 28 2020 yousaf.kaukab@suse.com
- Refresh patches.suse/gpio-max77620-Don-t-shadow-error-code-of-platform_ge.patch.
  Fix following warning:
  In file included from ./include/linux/gpio/driver.h:5:0,
    from drivers/gpio/gpio-max77620.c:8:
  drivers/gpio/gpio-max77620.c: In function ‘max77620_gpio_probe’:
  ./include/linux/device.h:1632:2: warning: ‘gpio_irq’ may be used uninitialized in this function [-Wmaybe-uninitialized]
  _dev_err(dev, dev_fmt(fmt), ##__VA_ARGS__)
  ^~~~~~~~
  drivers/gpio/gpio-max77620.c:292:15: note: ‘gpio_irq’ was declared here
  unsigned int gpio_irq;
    ^~~~~~~~
- commit 4654e1b
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: SOF: Add .prepare/.complete callbacks (jsc#SLE-16518).
- ASoC: SOF: Activate runtime PM with SOF OF device
  (jsc#SLE-16518).
- ASOC: Intel: sof_sdw: restore playback functionality with
  max98373 amps (jsc#SLE-16518).
- ASoC: Intel: add support for new SoundWire hardware layout on
  TGL (jsc#SLE-16518).
- ASoC: Intel: sof_sdw_rt700: add codec prefix (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: remove hard-coded codec_conf table
  (jsc#SLE-16518).
- ASoC: Intel: add codec name prefix to ACPI machine description
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: remove ternary operator (jsc#SLE-16518).
- ASoC: Intel: hda_dsp_common: use static function in conditional
  block (jsc#SLE-16518).
- ASoC: SOF: control: add size checks for ext_bytes control .put()
  (jsc#SLE-16518).
- ASoC: SOF: control: fix size checks for volatile ext_bytes
  control .get() (jsc#SLE-16518).
- ASoC: SOF: control: fix size checks for ext_bytes control .get()
  (jsc#SLE-16518).
- ASoC: hdac: make SOF HDA codec driver probe deterministic
  (jsc#SLE-16518).
- ASoC: SOF: imx: add missing MODULE_LICENSE() for imx-common
  (jsc#SLE-16518).
- ASoC: SOF: pm: Fix prepare callback behavior for OF usecase
  (jsc#SLE-16518).
- ASoC: SOF: topology: fix the process being scheduled on core0
  always (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: reduce verbosity of boot error logs
  (jsc#SLE-16518).
- ASoC: SOF: fix range checks (jsc#SLE-16518).
- ASoC: SOF: remove several superfluous type-casts
  (jsc#SLE-16518).
- ASoC: SOF: (cosmetic) remove redundant "ret" variable uses
  (jsc#SLE-16518).
- ASoC: SOF: control: update test for pm_runtime_get_sync()
  (jsc#SLE-16518).
- ASoC: SOF: debug: update test for pm_runtime_get_sync()
  (jsc#SLE-16518).
- ASoC: SOF: imx: Add debug support for imx platforms
  (jsc#SLE-16518).
- ASoC: SOF: Intel: Add support for tgl-h (jsc#SLE-16518).
- ASoC: SOF: Intel: hda-loader: s/master/primary (jsc#SLE-16518).
- ASoC: SOF: Intel: remove the HDA_DSP_CORE_MASK() macro
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: modify core_power_up/down op
  (jsc#SLE-16518).
- ASoC: SOF: rename cores_mask to host_managed_cores_mask
  (jsc#SLE-16518).
- ASoC: SOF: Intel: Use DMI oem string search for
  tgl_max98373_rt5682 (jsc#SLE-16518).
- ASoC: SOF: Implement snd_sof_bytes_ext_volatile_get kcontrol IO
  (jsc#SLE-16518).
- ASoC: SOF: topology: make process type optional (jsc#SLE-16518).
- ASoC: SOF: append extended data to sof_ipc_comp_mux
  (jsc#SLE-16518).
- ASoC: SOF: append extended data to sof_ipc_comp_process
  (jsc#SLE-16518).
- ASoC: SOF: append extended data to sof_ipc_comp_tone
  (jsc#SLE-16518).
- ASoC: SOF: append extended data to sof_ipc_comp_asrc
  (jsc#SLE-16518).
- ASoC: SOF: append extended data to sof_ipc_comp_src
  (jsc#SLE-16518).
- ASoC: SOF: append extended data to sof_ipc_comp_host
  (jsc#SLE-16518).
- ASoC: SOF: append extended data to sof_ipc_comp_volume
  (jsc#SLE-16518).
- ASoC: SOF: append extended data to sof_ipc_comp_mixer
  (jsc#SLE-16518).
- ASoC: SOF: append extended data to sof_ipc_comp_dai
  (jsc#SLE-16518).
- ASoC: SOF: topology: add helper for setting up IPC component
  (jsc#SLE-16518).
- ASoC: SOF: topology: parse comp_ext_tokens for all widgets
  (jsc#SLE-16518).
- ASoC: SOF: topology: create component extended tokens
  (jsc#SLE-16518).
- ASoC: SOF: add comp_ext to struct snd_sof_widget
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: add dailink .prepare and .hw_free callback
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: add dailink .trigger callback
  (jsc#SLE-16518).
- ASoC: Intel: KeemBay: Fix warning potential ! vs ~ typo
  (jsc#SLE-16518).
- ASoC: SOF: topology: fix core enable sequence (jsc#SLE-16518).
- ASoC: SOF: tokens: add token for component UUID (jsc#SLE-16518).
- ASoC: SOF: support topology components on secondary cores
  (jsc#SLE-16518).
- ASoC: SOF: add a "core" parameter to widget loading functions
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Simplify error handling during FW boot
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Add sof_tgl_ops for TGL platforms
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Define FW boot sequence with ICCMAX
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: define macro for code loader stream
  format (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: modify the signature of
  get_stream_with_tag() (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Add helper function to program ICCMAX
  stream (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Remove unused parameters in cl_dsp_init()
  (jsc#SLE-16518).
- ASoC: SOF: sof-of-dev: Add .arch_ops field (jsc#SLE-16518).
- ASoC: SOF: imx: Replace sdev->private with sdev->pdata->hw_pdata
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: add extended rom status dump to error
  log (jsc#SLE-16518).
- ASoC: SOF: topology: fix the ipc_size calculation for process
  component (jsc#SLE-16518).
- ASoC: SOF: intel: hda: support also devices with 1 and 3 dmics
  (jsc#SLE-16518).
- ASoC: SOF: fix a runtime pm issue in SOF when HDMI codec
  doesn't work (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: report error only for the last ROM init
  iteration (jsc#SLE-16518).
- ASoC: SOF: loader: Add debug box region (jsc#SLE-16518).
- ASoC: SOF: ext_manifest: Parse debug ABI version
  (jsc#SLE-16518).
- ASoC: SOF: loader: fix memory leak in get_ext_windows
  (jsc#SLE-16518).
- ASoC: SOF: IPC: make sof_ipc_window monosized (jsc#SLE-16518).
- ASoC: Intel: use consistent HDAudio spelling in comments/docs
  (jsc#SLE-16518).
- ASoC: SOF: Intel: add dev_dbg log when driver is not selected
  (jsc#SLE-16518).
- ASoC: SOF: acpi: add dev_dbg() log for probe completion
  (jsc#SLE-16518).
- ASoC: SOF: IPC: reduce verbosity of IPC pointer updates
  (jsc#SLE-16518).
- ASoC: SOF: topology: reduce the log level for unhandled widgets
  (jsc#SLE-16518).
- ASoC: SOF: topology: remove unnecessary memory alloc for
  sdev->private (jsc#SLE-16518).
- ASoC: SOF: (cosmetic) use the "bool" type where it makes sense
  (jsc#SLE-16518).
- ASoC: SOF: topology: (cosmetic) remove redundant variable
  initialisations (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: clean-up inclusion of header files
  (jsc#SLE-16518).
- ASoC: intel: sof_sdw: add rt711 rt1316 rt714 SDCA codec support
  (jsc#SLE-16518).
- ASoC: SOF: Add topology filename override based on dmi data
  match (jsc#SLE-16518).
- ASoC: Intel: sof_rt5682: override quirk data for
  tgl_max98373_rt5682 (jsc#SLE-16518).
- SoC: Intel: sof_sdw: Add support for product Ripto
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: rename id as part_id (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: check SoundWire version when matching
  codec (jsc#SLE-16518).
- ASoC: Intel: soc-acpi: add support for SDCA boards
  (jsc#SLE-16518).
- ASoC: Intel: soc-acpi: mirror CML and TGL configurations
  (jsc#SLE-16518).
- ASoC: Intel: sof-soundwire: add support for rt5682 on link2
  (jsc#SLE-16518).
- ASoC: Intel: soc-acpi: cnl: add support for rt5682 on SoundWire
  link2 (jsc#SLE-16518).
- ASoC: Intel: modify SoundWire version id in acpi match table
  (jsc#SLE-16518).
- ASoC: intel: sof_sdw: add .exit callback function
  (jsc#SLE-16518).
- ASoC: SOF: Intel: add build support for SoundWire
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: (cosmetic) align function parameters
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: skl-topology: remove redundant assignment
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: skl-topology: remove redundant assignments
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: sst-utils: remove redundant assignment
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: cldma: remove redundant initialization
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: skl-nhlt: remove redundant initialization
  (jsc#SLE-16518).
- ASoC: Intel: haswell-ipc: remove redundant assignments
  (jsc#SLE-16518).
- ASoC: Intel: haswell: (cosmetic) align function parameters
  (jsc#SLE-16518).
- ASoC: Intel: common: (cosmetic) align function parameters
  (jsc#SLE-16518).
- ASoC: Intel: Baytrail: (cosmetic) align function parameters
  (jsc#SLE-16518).
- ASoC: Intel: Atom: (cosmetic) align parameters (jsc#SLE-16518).
- ASoC: Intel: Atom: sst_pvt: simplify return handling
  (jsc#SLE-16518).
- ASoC: Intel: Atom: sst_loader: remove always-true condition
  (jsc#SLE-16518).
- ASoC: Intel: Atom: remove useless assignment (jsc#SLE-16518).
- ASoC: Intel: Atom: platform-pcm: fix redundant return
  (jsc#SLE-16518).
- ASoC: Intel: Atom: sst_pvt: remove redundant initialization
  (jsc#SLE-16518).
- ASoC: Intel: Atom: remove redundant initialization
  (jsc#SLE-16518).
- ASoC: Intel: Atom: sst: remove useless NULL assignment
  (jsc#SLE-16518).
- ASoC: Intel: Atom: platform-pcm: remove redundant assignment
  (jsc#SLE-16518).
- ASoC: Intel: Atom: compress: remove redundant assignment
  (jsc#SLE-16518).
- ASoC: Intel: Atom: sst-atom-controls: remove redundant
  assignments (jsc#SLE-16518).
- ASoC: Intel: KMB: Enable TDM audio capture (jsc#SLE-16518).
- ASoC: Intel: bytcht_cx2072x: simplify return handling
  (jsc#SLE-16518).
- ASoC: Intel: rename shadowed variable for all broadwell boards
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda-codec: move variable used conditionally
  (jsc#SLE-16518).
- ASOC: SOF: Intel: hda-codec: move unused label to correct
  position (jsc#SLE-16518).
- ASoC: SOF: delete repeated words in comments (jsc#SLE-16518).
- sound/soc/intel: Fix spelling mistake "cant" --> "can't"
  (jsc#SLE-16518).
- ASoC: various vendors: delete repeated words in comments
  (jsc#SLE-16518).
- ALSA: hda - remove kerneldoc for internal hdac_i915 function
  (jsc#SLE-16518).
- ALSA: hda - fix CONTROLLER_IN_GPU macro name (jsc#SLE-16518).
- ALSA: hda - handle multiple i915 device instances
  (jsc#SLE-16518).
- ALSA: hda - controller is in GPU on the DG1 (jsc#SLE-16518).
- ALSA: hda - add Intel DG1 PCI and HDMI ids (jsc#SLE-16518).
- ALSA: hda: (cosmetic) align function parameters (jsc#SLE-16518).
- ALSA: hda: auto_parser: remove shadowed variable declaration
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add AE-7 exit commands (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add AE-7 custom controls (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add AE-7 microphone selection commands
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add output selection for SoundBlaster AE-7
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add DSP setup functions for AE-7
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add init data for SoundBlaster AE-7
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add pre-init function for SoundBlaster AE-7
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add ca0132_mmio_init data for SoundBlaster
  AE-7 (jsc#SLE-16518).
- ALSA: hda/ca0132 - Set AE-7 bools and select mixer
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add SoundBlaster AE-7 pincfg (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add new quirk ID for SoundBlaster AE-7
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Fix Recon3D Center/LFE output
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add quirk output selection structures
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Clean up ca0132_alt_out_select
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Remove surround output selection
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add bass redirection controls
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add full-range speaker selection controls
  (jsc#SLE-16518).
- ASoC: SOF: use the sof_ipc_comp reserved bytes for extended data
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add surround channel config control
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add speaker tuning initialization commands
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Cleanup ca0132_mmio_init function
  (jsc#SLE-16518).
- ALSA: hda: fix VS_LTRC register name (jsc#SLE-16518).
- commit 3934635
* Mon Sep 28 2020 tiwai@suse.de
- clk: tegra: Fix initial rate for pll_a on Tegra124
  (jsc#SLE-16518).
- commit c103662
* Mon Sep 28 2020 tiwai@suse.de
- Documentation: sound/cards: fix heading underline lengths for
  https: changes (jsc#SLE-16518).
- ASoC: Documentation: fix reference to renamed source file
  (jsc#SLE-16518).
- commit ffbc027
* Mon Sep 28 2020 tiwai@suse.de
- blacklist.conf: add already cherry-picked ASoC entry
- commit e3a3df7
* Mon Sep 28 2020 yousaf.kaukab@suse.com
- gpiolib: Introduce ->add_pin_ranges() callback (jsc#SLE-15847).
- gpiolib: No need to call gpiochip_remove_pin_ranges() twice (jsc#SLE-15847).
- gpiolib: Switch order of valid mask and hw init (jsc#SLE-15847).
- commit 9d20bd0
* Mon Sep 28 2020 tiwai@suse.de
- supported.conf: mark soundwire stuff as supported (jsc#SLE-16518)
- commit 69ed3e4
* Mon Sep 28 2020 tiwai@suse.de
- blacklist.conf: remove the temporary blacklist entries again
- commit 84f2d38
* Mon Sep 28 2020 tiwai@suse.de
- Revert "ALSA: usb-audio: Disable Lenovo P620 Rear line-in
  volume control" (jsc#SLE-16518).
- Revert "ALSA: hda - Fix silent audio output and corrupted
  input on MSI X570-A PRO" (jsc#SLE-16518).
- ALSA: usb-audio: Add delay quirk for H570e USB headsets
  (jsc#SLE-16518).
- ALSA: hda/realtek: Enable front panel headset LED on Lenovo
  ThinkStation P520 (jsc#SLE-16518).
- ALSA: hda/realtek - Couldn't detect Mic if booting with headset
  plugged (jsc#SLE-16518).
- ALSA: asihpi: fix iounmap in error handler (jsc#SLE-16518).
- ASoC: tlv320adcx140: Wake up codec before accessing register
  (jsc#SLE-16518).
- ASoC: core: Do not cleanup uninitialized dais on soc_pcm_open
  failure (jsc#SLE-16518).
- ASoC: Intel: bytcr_rt5640: Add quirk for MPMAN Converter9 2-in-1
  (jsc#SLE-16518).
- ASoC: Intel: haswell: Fix power transition refactor
  (jsc#SLE-16518).
- ASoC: tlv320adcx140: Fix accessing uninitialized adcx140->dev
  (jsc#SLE-16518).
- ASoC: wm8994: Ensure the device is resumed in wm89xx_mic_detect
  functions (jsc#SLE-16518).
- ASoC: wm8994: Skip setting of the WM8994_MICBIAS register for
  WM1811 (jsc#SLE-16518).
- ASoC: meson: axg-toddr: fix channel order on g12 platforms
  (jsc#SLE-16518).
- ASoC: soc-core: add snd_soc_find_dai_with_mutex()
  (jsc#SLE-16518).
- ASoC: rt700: Fix return check for devm_regmap_init_sdw()
  (jsc#SLE-16518).
- ASoC: rt715: Fix return check for devm_regmap_init_sdw()
  (jsc#SLE-16518).
- ASoC: rt711: Fix return check for devm_regmap_init_sdw()
  (jsc#SLE-16518).
- ASoC: rt1308-sdw: Fix return check for devm_regmap_init_sdw()
  (jsc#SLE-16518).
- ASoC: max98373: Fix return check for devm_regmap_init_sdw()
  (jsc#SLE-16518).
- ASoC: qcom: common: Fix refcount imbalance on error
  (jsc#SLE-16518).
- ASoC: ti: fixup ams_delta_mute() function name (jsc#SLE-16518).
- ASoC: pcm3168a: ignore 0 Hz settings (jsc#SLE-16518).
- ASoC: Intel: tgl_max98373: fix a runtime pm issue in
  multi-thread case (jsc#SLE-16518).
- ASoC: qcom: Set card->owner to avoid warnings (jsc#SLE-16518).
- ASoC: intel: atom: Add period size constraint (jsc#SLE-16518).
- ASoC: Intel: skl_hda_dsp_generic: Fix NULLptr dereference in
  autosuspend delay (jsc#SLE-16518).
- ALSA: hda/realtek - The Mic on a RedmiBook doesn't work
  (jsc#SLE-16518).
- ALSA: hda: fixup headset for ASUS GX502 laptop (jsc#SLE-16518).
- soundwire: fix double free of dangling pointer (jsc#SLE-16518).
- soundwire: bus: fix typo in comment on INTSTAT registers
  (jsc#SLE-16518).
- ALSA: hda/realtek - Improved routing for Thinkpad X1 7th/8th
  Gen (jsc#SLE-16518).
- ALSA: hda: use consistent HDAudio spelling in comments/docs
  (jsc#SLE-16518).
- ALSA: hda: add dev_dbg log when driver is not selected
  (jsc#SLE-16518).
- ALSA: hda: fix a runtime pm issue in SOF when integrated GPU
  is disabled (jsc#SLE-16518).
- ALSA: hda: hdmi - add Rocketlake support (jsc#SLE-16518).
- commit 9c6baf3
* Mon Sep 28 2020 tiwai@suse.de
- ALSA: pcm: oss: Remove superfluous WARN_ON() for mulaw sanity
  check (jsc#SLE-16518).
- ALSA: hda - Fix silent audio output and corrupted input on
  MSI X570-A PRO (jsc#SLE-16518).
- ALSA: hda/hdmi: always check pin power status in i915 pin fixup
  (jsc#SLE-16518).
- ALSA: hda/realtek: Add quirk for Samsung Galaxy Book Ion
  NT950XCJ-X716A (jsc#SLE-16518).
- ALSA: usb-audio: Add basic capture support for Pioneer DJ
  DJM-250MK2 (jsc#SLE-16518).
- ALSA: usb-audio: Add implicit feedback quirk for UR22C
  (jsc#SLE-16518).
- Revert "ALSA: hda: Add support for Loongson 7A1000 controller"
  (jsc#SLE-16518).
- ALSA: hda/tegra: Program WAKEEN register for Tegra
  (jsc#SLE-16518).
- ALSA: hda: Fix 2 channel swapping for Tegra (jsc#SLE-16518).
- ALSA: ca0106: fix error code handling (jsc#SLE-16518).
- ALSA: usb-audio: Disable autosuspend for Lenovo ThinkStation
  P620 (jsc#SLE-16518).
- ALSA: firewire-digi00x: exclude Avid Adrenaline from detection
  (jsc#SLE-16518).
- ALSA; firewire-tascam: exclude Tascam FE-8 from detection
  (jsc#SLE-16518).
- ALSA: hda: avoid reset of sdo_limit (jsc#SLE-16518).
- ALSA: hda/realtek: Add quirk for Samsung Galaxy Book Ion
  (jsc#SLE-16518).
- ASoC: intel: Fix memleak in sst_media_open (jsc#SLE-16518).
- ASoC: wm8994: Avoid attempts to read unreadable registers
  (jsc#SLE-16518).
- ASoC: msm8916-wcd-analog: fix register Interrupt offset
  (jsc#SLE-16518).
- ASoC: wm8994: Prevent access to invalid VU register bits on
  WM1811 (jsc#SLE-16518).
- ASoC: q6routing: add dummy register read/write function
  (jsc#SLE-16518).
- ASoC: q6afe-dai: mark all widgets registers as SND_SOC_NOPM
  (jsc#SLE-16518).
- ASoC: Make soc_component_read() returning an error code again
  (jsc#SLE-16518).
- ASoC: amd: Replacing component->name with codec_dai->name
  (jsc#SLE-16518).
- ASoC: tegra: tegra210_i2s: Fix compile warning with CONFIG_PM=n
  (jsc#SLE-16518).
- ASoC: tegra: tegra210_dmic: Fix compile warning with CONFIG_PM=n
  (jsc#SLE-16518).
- ASoC: tegra: tegra210_ahub: Fix compile warning with CONFIG_PM=n
  (jsc#SLE-16518).
- ASoC: tegra: tegra210_admaif: Fix compile warning with
  CONFIG_PM=n (jsc#SLE-16518).
- ASoC: tegra: tegra186_dspk: Fix compile warning with CONFIG_PM=n
  (jsc#SLE-16518).
- ASoC: fsl: Fix unused variable warning (jsc#SLE-16518).
- ASoC: amd: renoir: restore two more registers during resume
  (jsc#SLE-16518).
- ASoC: wm8962: Do not remove ADDITIONAL_CONTROL_4 from readable
  register list (jsc#SLE-16518).
- ASoC: fsl-asoc-card: Remove fsl_asoc_card_set_bias_level
  function (jsc#SLE-16518).
- ALSA: usb-audio: ignore broken processing/extension unit
  (jsc#SLE-16518).
- ALSA: hda/realtek: Add model alc298-samsung-headphone
  (jsc#SLE-16518).
- ALSA: usb-audio: Update documentation comment for MS2109 quirk
  (jsc#SLE-16518).
- ALSA: isa: fix spelling mistakes in the comments
  (jsc#SLE-16518).
- ALSA: usb-audio: Add capture support for Saffire 6 (USB 1.1)
  (jsc#SLE-16518).
- ALSA: hda/realtek: Add quirk for Samsung Galaxy Flex Book
  (jsc#SLE-16518).
- ALSA: echoaudio: Fix potential Oops in snd_echo_resume()
  (jsc#SLE-16518).
- ALSA: hda/hdmi: Use force connectivity quirk on another HP
  desktop (jsc#SLE-16518).
- ALSA: hda/realtek - Fix unused variable warning (jsc#SLE-16518).
- ALSA: hda - reverse the setting value in the micmute_led_set
  (jsc#SLE-16518).
- ALSA: echoaduio: Drop superfluous volatile modifier
  (jsc#SLE-16518).
- ALSA: usb-audio: Disable Lenovo P620 Rear line-in volume control
  (jsc#SLE-16518).
- ALSA: usb-audio: add quirk for Pioneer DDJ-RB (jsc#SLE-16518).
- ALSA: usb-audio: work around streaming quirk for MacroSilicon
  MS2109 (jsc#SLE-16518).
- ALSA: hda - fix the micmute led status for Lenovo ThinkCentre
  AIO (jsc#SLE-16518).
- ALSA: usb-audio: fix overeager device match for MacroSilicon
  MS2109 (jsc#SLE-16518).
- ALSA: hda/realtek: Fix pin default on Intel NUC 8 Rugged
  (jsc#SLE-16518).
- ALSA: usb-audio: Creative USB X-Fi Pro SB1095 volume knob
  support (jsc#SLE-16518).
- ALSA: usb-audio: fix spelling mistake "buss" -> "bus"
  (jsc#SLE-16518).
- ALSA: pci: delete repeated words in comments (jsc#SLE-16518).
- ALSA: isa: delete repeated words in comments (jsc#SLE-16518).
- ALSA: hda/tegra: Add 100us dma stop delay (jsc#SLE-16518).
- ALSA: hda: Add dma stop delay variable (jsc#SLE-16518).
- ASoC: hda/tegra: Set buffer alignment to 128 bytes
  (jsc#SLE-16518).
- ALSA: seq: oss: Serialize ioctls (jsc#SLE-16518).
- ALSA: hda/hdmi: Add quirk to force connectivity (jsc#SLE-16518).
- ALSA: usb-audio: add startech usb audio dock name
  (jsc#SLE-16518).
- ALSA: usb-audio: Add support for Lenovo ThinkStation P620
  (jsc#SLE-16518).
- ASoC: core: Two step component registration (jsc#SLE-16518).
- ASoC: core: Simplify snd_soc_component_initialize declaration
  (jsc#SLE-16518).
- ASoC: core: Relocate and expose snd_soc_component_initialize
  (jsc#SLE-16518).
- ASoC: sh: Replace 'select' DMADEVICES 'with depends on'
  (jsc#SLE-16518).
- ASoC: Intel: drop unnecessary list_empty (jsc#SLE-16518).
- ASoC: rk3399_gru_sound: Add DAPM pins, kcontrols for jack
  detection (jsc#SLE-16518).
- ASoC: wm8962: Do not access WM8962_GPIO_BASE (jsc#SLE-16518).
- ASoC: SOF: imx: use resource_size (jsc#SLE-16518).
- ASoC: Intel: KMB: Rework disable channel function
  (jsc#SLE-16518).
- ASoC: Intel: KMB: Add 8kHz audio support (jsc#SLE-16518).
- ASoC: meson: cards: remove DT_PREFIX for standard daifmt
  properties (jsc#SLE-16518).
- ASoC: amd: Added hw_params support for ALC1015 (jsc#SLE-16518).
- ASoC: amd: Adding DAI LINK for rt1015 codec (jsc#SLE-16518).
- ASoC: amd: Adding support for ALC1015 codec in machine driver
  (jsc#SLE-16518).
- ASoC: amd: Passing card structure based on codec
  (jsc#SLE-16518).
- ASoC: amd: Renaming snd-soc-card structure and fields
  (jsc#SLE-16518).
- ASoC: samsung: Add sound support for Midas boards
  (jsc#SLE-16518).
- ASoC: tlv320adcx140: Move device reset to before programming
  (jsc#SLE-16518).
- ASoC: tlv320adcx140: Fix GPO register start address
  (jsc#SLE-16518).
- ASoC: tlv320adcx140: Add GPO configuration and drive output
  config (jsc#SLE-16518).
- ASoC: tlv320adcx140: Fix various style errors and warnings
  (jsc#SLE-16518).
- ASoC: bcm2835: Silence clk_get() error on -EPROBE_DEFER
  (jsc#SLE-16518).
- ASoC: SOF: Intel: disable traces when switching to S0Ix D0I3
  (jsc#SLE-16518).
- ASoC: SOF: Intel: fix the suspend procedure to support s0ix
  entry (jsc#SLE-16518).
- ASoC: tas2562: Update shutdown GPIO property (jsc#SLE-16518).
- ASoC: madera: Add channel numbers to AIFs (jsc#SLE-16518).
- ASoC: intel: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: intel/boards: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: dt-bindings: q6asm: Add Q6ASM_DAI_{TX_RX, TX, RX} defines
  (jsc#SLE-16518).
- ASoC: AMD: Restore PME_EN state at Power On (jsc#SLE-16518).
- ASoC: dapm: don't call pm_runtime_* on card device
  (jsc#SLE-16518).
- ASoC: qcom: common: Avoid printing errors for -EPROBE_DEFER
  (jsc#SLE-16518).
- ASoC: qcom: apq8016_sbc: Use qcom_snd_parse_of()
  (jsc#SLE-16518).
- ASoC: qcom: common: Parse properties with "qcom," prefix
  (jsc#SLE-16518).
- ASoC: qcom: common: Support parsing links without DPCM
  (jsc#SLE-16518).
- ASoC: q6afe: Remove unused q6afe_is_rx_port() function
  (jsc#SLE-16518).
- ASoC: qcom: common: Use snd_soc_dai_link_set_capabilities()
  (jsc#SLE-16518).
- ASoC: qcom: Use devm for resource management (jsc#SLE-16518).
- commit 1080777
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: max98390: update dsm param bin max size (jsc#SLE-16518).
- ASoC: max98390: Update dsm init sequence and condition
  (jsc#SLE-16518).
- ASoC: soc-component: don't report of_xlate_dai_name failures
  (jsc#SLE-16518).
- ASoC: uniphier: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: mxs: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: xtensa: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: kirkwood: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: sprd: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: generic: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: codecs: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: bcm: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: au1x: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: meson: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: dwc: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: qcom: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: atmel: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: mediatek: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: fsl: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: amd: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: rockchip: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: cirrus: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: pxa: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: samsung: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: sh: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: sof: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: stm: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: sunxi: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: tegra: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: ti: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: ux500: use asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: soc-xxx: add asoc_substream_to_rtd() (jsc#SLE-16518).
- ASoC: fsl-asoc-card: Support configuring dai fmt from DT
  (jsc#SLE-16518).
- ASoC: fsl_esai: add IRQF_SHARED for devm_request_irq
  (jsc#SLE-16518).
- ASoC: tegra: Fix build error due to 64-by-32 division
  (jsc#SLE-16518).
- ASoC: ti: fix SND_SOC_J721E_EVM warnings & errors
  (jsc#SLE-16518).
- ASoC: omap: Replace HTTP links with HTTPS ones (jsc#SLE-16518).
- ASoC: wm_adsp: Support new metadata block ID's (jsc#SLE-16518).
- ASoC: fsl: Replace HTTP links with HTTPS ones (jsc#SLE-16518).
- ASoC: ti: Replace HTTP links with HTTPS ones (jsc#SLE-16518).
- ASoC: mediatek: mt8183: support machine driver with max98357b
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183: support left justified format for I2S
  (jsc#SLE-16518).
- ASoC: SOF: pcm: Update rate/channels for SAI/ESAI DAIs
  (jsc#SLE-16518).
- ASoC: SOF: topology: Update SAI config bclk/fsync rate
  (jsc#SLE-16518).
- ASoC: SOF: imx8: Add SAI dai driver for i.MX/i.MX8X
  (jsc#SLE-16518).
- ASoC: SOF: imx8m: Fix SAI DAI driver for i.MX8M (jsc#SLE-16518).
- ASoC: SOF: imx8: Fix ESAI DAI driver name for i.MX8/iMX8X
  (jsc#SLE-16518).
- ASoC: SOF: imx: Use ARRAY_SIZE instead of hardcoded value
  (jsc#SLE-16518).
- ASoC: SOF: define INFO_ flags in dsp_ops for imx8
  (jsc#SLE-16518).
- ASoC: hdac_hda: fix deadlock after PCM open error
  (jsc#SLE-16518).
- ASoC: hdac_hda: fix memleak on module unload (jsc#SLE-16518).
- ASoC: hdac_hda: call patch_ops.free() on probe error
  (jsc#SLE-16518).
- ASoC: Replace HTTP links with HTTPS ones (jsc#SLE-16518).
- ASoC: tegra: Add Tegra210 based ADMAIF driver (jsc#SLE-16518).
- ASoC: tas2770: Fix reset gpio property name (jsc#SLE-16518).
- ASoC: intel: board: sof_rt5682: Update rt1015 pll input clk freq
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: avoid crash if invalid DSP topology loaded
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: add support for systems without i915 audio
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw_rt711: remove properties in card remove
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw_rt711: remove hard-coded codec name
  (jsc#SLE-16518).
- ASoC: tegra: Add Tegra186 based DSPK driver (jsc#SLE-16518).
- commit 9a74e2d
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: tegra: Add Tegra210 based AHUB driver (jsc#SLE-16518).
- ASoC: tegra: Add Tegra210 based I2S driver (jsc#SLE-16518).
- ASoC: tegra: Add Tegra210 based DMIC driver (jsc#SLE-16518).
- ASoC: tegra: Add support for CIF programming (jsc#SLE-16518).
- ASoC: soc-dai.h: drop a duplicated word (jsc#SLE-16518).
- ASoC: wcd9335.h: fix duplicated word (jsc#SLE-16518).
- ASoC: tegra20_das.h: delete duplicated words (jsc#SLE-16518).
- ASoC: Intel: Skylake: Avoid the use of one-element array
  (jsc#SLE-16518).
- ASoC: soc-core: snd_soc_dai_digital_mute() for both CPU/Codec
  (jsc#SLE-16518).
- ASoC: atmel: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: rt5682: optimize the power consumption (jsc#SLE-16518).
- ASoC: soc-dai.h: don't use discriminatory terms for comment
  (jsc#SLE-16518).
- ASoC: qcom: qdsp6: Use IS_ERR() instead of IS_ERR_OR_NULL()
  (jsc#SLE-16518).
- ASoC: rt5682: disable MICBIAS and Vref2 widget in default
  (jsc#SLE-16518).
- ASoC: qcom: qdsp6: Use the defined variable to clean code
  (jsc#SLE-16518).
- ALSA: hda: fix snd_hda_codec_cleanup() documentation
  (jsc#SLE-16518).
- ALSA: hda: export snd_hda_codec_cleanup_for_unbind()
  (jsc#SLE-16518).
- ASoC: fsl-asoc-card: Support Headphone and Microphone Jack
  detection (jsc#SLE-16518).
- ASoC: simple-card-utils: Support configure pin_name for
  asoc_simple_init_jack (jsc#SLE-16518).
- ASoC: codecs: ak*: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: codecs: cs*: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: codecs: da*: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: codecs: es*: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: codecs: wm*: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: codecs: alc*: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: codecs: max*: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: codecs: pcm*: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: codecs: ssm*: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: codecs: tas*: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: codecs: tlv*: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: codecs: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: meson: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: spear: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: ti: merge .digital_mute() into .mute_stream()
  (jsc#SLE-16518).
- ASoC: soc-dai.c: add .no_capture_mute support (jsc#SLE-16518).
- ASoC: hdmi-codec: return -ENOTSUPP for digital_mute
  (jsc#SLE-16518).
- ASoC: soc-component: Add missed return for calling
  soc_component_ret (jsc#SLE-16518).
- ASoC: fsl: fsl-asoc-card: Trivial: Fix misspelling of 'exists'
  (jsc#SLE-16518).
- ASoC: ssi: don't use discriminatory terms for debug log
  (jsc#SLE-16518).
- ASoC: siu: don't use discriminatory terms for parameter
  (jsc#SLE-16518).
- ASoC: fsi: don't use discriminatory terms for comment
  (jsc#SLE-16518).
- ASoC: rsnd: don't use discriminatory terms for comment
  (jsc#SLE-16518).
- ASoC: rsnd: don't use discriminatory terms for function names
  (jsc#SLE-16518).
- ASoC: rockchip: spdif: Handle clk by pm runtime (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: support HDMI jack reporting
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: use hdmi-codec (jsc#SLE-16518).
- ASoC: mediatek: mt8183: support HDMI jack reporting
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183: use hdmi-codec (jsc#SLE-16518).
- ASoC: codecs: ak4458: Remove set but never checked variable
  'ret' (jsc#SLE-16518).
- ASoC: codecs: tlv320aic26: Demote seemingly unintentional
  kerneldoc header (jsc#SLE-16518).
- ASoC: codecs: rt5659: Remove many unused const variables
  (jsc#SLE-16518).
- ASoC: codecs: rt5631: fix spurious kernel-doc start and missing
  arguments (jsc#SLE-16518).
- ASoC: ux500: ux500_msp_i2s: Remove unused variables 'reg_val_DR'
  and 'reg_val_TSTDR' (jsc#SLE-16518).
- ASoC: pxa: pxa-ssp: Demote seemingly unintentional kerneldoc
  header (jsc#SLE-16518).
- ASoC: sunxi: sun4i-spdif: Fix misspelling of 'reg_dac_txdata'
  in kernel-doc (jsc#SLE-16518).
- ASoC: sunxi: sun4i-i2s: add missing clock and format arguments
  in kernel-doc (jsc#SLE-16518).
- ASoC: qcom: qdsp6: q6asm: Provide documentation for
  'codec_profile' (jsc#SLE-16518).
- ASoC: sti: uniperif: fix 'defined by not used' warning
  (jsc#SLE-16518).
- commit 045db04
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: codecs: max98373: add SoundWire support (jsc#SLE-16518).
- Update config files.
- commit 83c7b7f
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: fsl_spdif: Add kctl for configuring TX validity bit
  (jsc#SLE-16518).
- ASoC: fsl_spdif: Clear the validity bit for TX (jsc#SLE-16518).
- ASoC: Intel: cht_bsw_rt5672: Improve dai-set-fmt comment in
  cht_codec_fixup() (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: support machine driver with
  rt1015 (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: extract codec and DAI names
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: remove forward declaration of
  headset_init (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: sort header inclusions in
  alphabetical (jsc#SLE-16518).
- ASoC: Intel: sdw_max98373: add card_late_probe support
  (jsc#SLE-16518).
- ASoC: Intel: sof-sdw: add MAX98373 I2C dependencies
  (jsc#SLE-16518).
- commit 5062b70
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: codecs: max98373: split I2C and common parts
  (jsc#SLE-16518).
- Update config files.
- commit de268ad
* Mon Sep 28 2020 yousaf.kaukab@suse.com
- dt-bindings: soc: tegra-pmc: Add ID for Tegra PMC 32 kHz blink clock (jsc#SLE-15847).
- dt-bindings: soc: tegra-pmc: Add Tegra PMC clock bindings (jsc#SLE-15847).
- commit f7e6e0d
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: amd: raven: acp3x-i2s: fix 'set but not used' warning
  (jsc#SLE-16518).
- Update config files.
- commit 16e01a3
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: codecs: rt*: fix 'defined but not used' warning
  (jsc#SLE-16518).
- ASoC: codecs: max98390: fix 'defined but not used' warning
  (jsc#SLE-16518).
- ASoC: codecs: es8316: fix 'defined but not used' warning
  (jsc#SLE-16518).
- ASoC: ti: omap-mcbsp-st: Remove set, but unused variable 'w'
  (jsc#SLE-16518).
- ASoC: codecs: jz4770: Remove defined but never used variable
  'mic_boost_tlv' (jsc#SLE-16518).
- ASoC: codecs: da7219: fix 'defined but not used' warning
  (jsc#SLE-16518).
- ASoC: codecs: da7210: fix kernel-doc (jsc#SLE-16518).
- ASoC: uniphier: aio-core: fix kernel-doc (jsc#SLE-16518).
- ASoC: tegra: tegra20_das: remove always-true comparison
  (jsc#SLE-16518).
- ASoC: samsung: pcm: fix kernel-doc (jsc#SLE-16518).
- ASoC: samsung: spdif: fix kernel-doc (jsc#SLE-16518).
- ASoC: atmel: fix kernel-doc (jsc#SLE-16518).
- ASoC: codecs: Use fallthrough pseudo-keyword (jsc#SLE-16518).
- ASoC: tlv320adcx140: Add tx offset slot programming
  (jsc#SLE-16518).
- ASoC: tlv320adcx140: Add ASI enable for channel 5-8
  (jsc#SLE-16518).
- ASoC: atmel-pdmic: remove codec component (jsc#SLE-16518).
- ASoC: atmel-classd: remove codec component (jsc#SLE-16518).
- ASoC: mediatek: mt8183: support machine driver with rt1015
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183: sort header inclusions in alphabetical
  (jsc#SLE-16518).
- ASoC: topology: add more logs when topology load fails
  (jsc#SLE-16518).
- ASoC: topology: factor kfree(se) in error handling
  (jsc#SLE-16518).
- ASoC: topology: use break on errors, not continue
  (jsc#SLE-16518).
- ASoC: qdsp6: use dev_err instead of pr_err (jsc#SLE-16518).
- ASoC: q6asm: add command opcode to timeout error report
  (jsc#SLE-16518).
- ASoC: amd: fixed kernel warnings (jsc#SLE-16518).
- ASoC: fsl: mpc8610_hpcd: Add missing of_node_put()
  (jsc#SLE-16518).
- ASoC: amd: raven: acp3x-i2s: remove unused-but-set variable
  (jsc#SLE-16518).
- ASoC: amd: raven: acp3x-pcm-dma: remove unused-but-set variable
  (jsc#SLE-16518).
- commit 5439a6b
* Mon Sep 28 2020 yousaf.kaukab@suse.com
- dt-bindings: memory: Add Tegra194 memory controller header (jsc#SLE-15847).
- commit 461954d
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: amd: raven: acp3x-pcm-dma: fix 'set but not used' warning
  (jsc#SLE-16518).
- ASoC: amd: acp-rt5645: fix 'defined but not used' warning
  (jsc#SLE-16518).
- ASoC: amd: acp-da7219-max98357a: fix 'defined but not used'
  warning (jsc#SLE-16518).
- ASoC: da7213: add default clock handling (jsc#SLE-16518).
- ASoC: amd: add ACPI dependency check (jsc#SLE-16518).
- ASoC: codecs: wm8400: remove unused variables (jsc#SLE-16518).
- ASoC: fsl: fsl_esai: fix kernel-doc (jsc#SLE-16518).
- ASoC: fsl: fsl_spdif: fix kernel-doc (jsc#SLE-16518).
- ASoC: fsl: fsl-asoc-card: fix kernel-doc (jsc#SLE-16518).
- ASoC: fsl: fsl_ssi_dbg: remove spurious kernel-doc comment start
  (jsc#SLE-16518).
- ASoC: rt5670: Rename dev_gpio to gpio1_is_irq (jsc#SLE-16518).
- ASoC: rt5670: Remove struct rt5670_platform_data
  (jsc#SLE-16518).
- ASoC: fsl: fsl_asrc: fix kernel-doc (jsc#SLE-16518).
- ASoC: fsl: fsl_ssi: fix kernel-doc (jsc#SLE-16518).
- ASoC: soc-ac97: fix kernel-doc (jsc#SLE-16518).
- ASoC: amd: add logic to check dmic hardware runtime
  (jsc#SLE-16518).
- ASoC: ti: j721e-evm: Fix missing unlock on error in
  j721e_audio_hw_params() (jsc#SLE-16518).
- ASoC: Intel: bxt-da7219-max98357a: return -EINVAL on
  unrecognized speaker amplifier (jsc#SLE-16518).
- ASoC: codecs: wm8994: fix kernel-doc (jsc#SLE-16518).
- ASoC: codecs: wm9713: remove spurious kernel-doc comment start
  (jsc#SLE-16518).
- ASoC: codecs: wm8960: fix kernel-doc (jsc#SLE-16518).
- ASoC: codecs: wm8986: fix missing kernel-doc arguments
  (jsc#SLE-16518).
- ASoC: codecs: cs42l42: remove always-true comparisons
  (jsc#SLE-16518).
- ASoC: codecs: cs4270: fix kernel-doc (jsc#SLE-16518).
- ASoC: Intel: atom: fix 'defined but not used' warning
  (jsc#SLE-16518).
- ASoC: Intel: atom: fix kernel-doc (jsc#SLE-16518).
- ASoC: SOF: sof-acpi-dev: fix 'defined but unused' warning
  (jsc#SLE-16518).
- ASoC: Intel: bxt-da7219-max98357a: support MAX98390 speaker amp
  (jsc#SLE-16518).
- ASoC: ti: Add custom machine driver for j721e EVM (CPB and IVI)
  (jsc#SLE-16518).
- ASoC: ti: davinci-mcasp: Specify stream_name for
  playback/capture (jsc#SLE-16518).
- ASoC: fsl_asrc: Add an option to select internal ratio mode
  (jsc#SLE-16518).
- ASoC: amd: Enable interrupt in dma_open (jsc#SLE-16518).
- ASoC: Intel: KeemBay: Fix header guard (jsc#SLE-16518).
- ASoC: fsl_sai: Refine regcache usage with pm runtime
  (jsc#SLE-16518).
- ASoC: tas2562: Add voltage sense slot configuration
  (jsc#SLE-16518).
- ASoC: tas2562: Add right and left channel slot programming
  (jsc#SLE-16518).
- asoc: Update supported rate and format for dummy dai
  (jsc#SLE-16518).
- commit 318e1a6
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: Intel: sof_sdw: Add MAX98373 support (jsc#SLE-16518).
- ASoC: samsung: Fix a typo in Kconfig (jsc#SLE-16518).
- ASoC: Intel: common: add match table for TGL MAX98373 + RT5682
  SoundWire driver (jsc#SLE-16518).
- ASoc: Intel: cml_rt1011_rt5682: explicitly access first codec
  (jsc#SLE-16518).
- ASoC: Intel: Boards: tgl_max98373: Update TDM configuration
  in hw_params (jsc#SLE-16518).
- ASoC: intel: cml_rt1011_rt5682: use for_each_card_prelinks
  (jsc#SLE-16518).
- ASoC: Intel: Boards: cml_rt1011_rt5682: use statically define
  codec config (jsc#SLE-16518).
- ASoC: Intel: Boards: cml_rt1011_rt5682: reduce log level for
  printing quirk (jsc#SLE-16518).
- ASoC: intel: sof_rt5682: Add support for jsl-max98360a-rt5682
  (jsc#SLE-16518).
- ASoC: Intel: Boards: tgl_max98373: Fix the comment for
  max_98373_components (jsc#SLE-16518).
- ASoC: Intel: Boards: tgl_max98373: add dai_trigger function
  (jsc#SLE-16518).
- ASoC: Intel: boards: byt*.c: remove cast in dev_info quirk log
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: add quirk override with kernel parameter
  (jsc#SLE-16518).
- ASoC: Intel: bxt_rt298: add missing .owner field
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: add missing .owner field (jsc#SLE-16518).
- ASoC: Intel: cml_rt1011_rt5682: add missing .owner field
  (jsc#SLE-16518).
- ASoC: SOF: nocodec: add missing .owner field (jsc#SLE-16518).
- snd/soc: correct trivial kernel-doc inconsistency
  (jsc#SLE-16518).
- ASoC: rt1015: add missing header inclusion (jsc#SLE-16518).
- ASoC: dapm: declare missing structure prototypes
  (jsc#SLE-16518).
- commit 8e0a666
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: core: move definition of enum snd_soc_bias_level
  (jsc#SLE-16518).
- ASoC: tas2562: Fix format issue for extra space before a comma
  (jsc#SLE-16518).
- ASoC: tas2562: Update shutdown GPIO property (jsc#SLE-16518).
- ASoC: fsl-asoc-card: Add WM8524 support (jsc#SLE-16518).
- ASoC: intel: cml_rt1011_rt5682: disable jack in dailink .exit()
  (jsc#SLE-16518).
- ASoC: intel: sof_rt5682: move disabling jack to dai link's
  exit() (jsc#SLE-16518).
- ASoC: Intel: kbl-rt5660: use .exit() dailink callback to
  release gpiod (jsc#SLE-16518).
- ASoC: Intel: bdw-rt5677: fix module load/unload issues
  (jsc#SLE-16518).
- ASoC: soc-link: introduce exit() callback (jsc#SLE-16518).
- ASoC: rt1011: fix KASAN out-of-bounds bug in find_next_bit()
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: set playback and capture
  constraints (jsc#SLE-16518).
- ASoC: fsl_easrc: Fix uninitialized scalar variable in
  fsl_easrc_set_ctx_format (jsc#SLE-16518).
- ASoC: remove snd_soc_component_read32() (jsc#SLE-16518).
- ASoC: codecs: ak*: rename to snd_soc_component_read()
  (jsc#SLE-16518).
- ASoC: codecs: cs*: rename to snd_soc_component_read()
  (jsc#SLE-16518).
- ASoC: codecs: da*: rename to snd_soc_component_read()
  (jsc#SLE-16518).
- ASoC: codecs: rt*: rename to snd_soc_component_read()
  (jsc#SLE-16518).
- ASoC: codecs: wm*: rename to snd_soc_component_read()
  (jsc#SLE-16518).
- ASoC: codecs: alc*: rename to snd_soc_component_read()
  (jsc#SLE-16518).
- ASoC: codecs: msm*: rename to snd_soc_component_read()
  (jsc#SLE-16518).
- ASoC: codecs: max*: rename to snd_soc_component_read()
  (jsc#SLE-16518).
- ASoC: codecs: tlv*: rename to snd_soc_component_read()
  (jsc#SLE-16518).
- ASoC: codecs: wcd*: rename to snd_soc_component_read()
  (jsc#SLE-16518).
- ASoC: codecs: rename to snd_soc_component_read()
  (jsc#SLE-16518).
- ASoC: atmel: rename to snd_soc_component_read() (jsc#SLE-16518).
- ASoC: pxa: rename to snd_soc_component_read() (jsc#SLE-16518).
- ASoC: soc-component: use io_mutex correctly (jsc#SLE-16518).
- ASoC: soc-component: merge snd_soc_component_read() and
  snd_soc_component_read32() (jsc#SLE-16518).
- ASoC: wm_adsp: Add controls for calibration and diagnostic FW
  (jsc#SLE-16518).
- ASoC: qcom: Kconfig: Tweak dependencies on SND_SOC_SDM845
  (jsc#SLE-16518).
- ASoC: fsl_spdif: Add pm runtime function (jsc#SLE-16518).
- ASoC: amd: Removing unnecessary instance initialization
  (jsc#SLE-16518).
- ASoC: Intel: broadwell: simplify card names for SOF uses
  (jsc#SLE-16518).
- ASoC: Intel: cht*: simplify card names for SOF uses
  (jsc#SLE-16518).
- ASoC: Intel: byt*: simplify card names for SOF uses
  (jsc#SLE-16518).
- ASoC: meson: imply acodec glue on axg sound card
  (jsc#SLE-16518).
- ASoC: fsl_spdif: Add support for imx6sx platform
  (jsc#SLE-16518).
- ASoC: fsl-asoc-card: Add MQS support (jsc#SLE-16518).
- ASoC: tegra: Fix reference count leaks (jsc#SLE-16518).
- ASoC: rt1015: Flush DAC data before playback (jsc#SLE-16518).
- commit d562e8a
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: Intel: Add makefiles and kconfig changes for KeemBay
  (jsc#SLE-16518).
- Update config files.
- commit 5d5ac9a
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: fsl_easrc: Fix "Function parameter not described" warnings
  (jsc#SLE-16518).
- ASoC: fsl_easrc: Fix -Wunused-but-set-variable (jsc#SLE-16518).
- ASoC: fsl_easrc: Fix -Wmissing-prototypes warning
  (jsc#SLE-16518).
- ASoC: Intel: Add KeemBay platform driver (jsc#SLE-16518).
- ASoC: soc-pcm/compress: reduce verbosity on mapping ok messages
  (jsc#SLE-16518).
- ASoC: soc-pcm: improve error messages in soc_pcm_new()
  (jsc#SLE-16518).
- ASoC: soc-core: reduce verbosity of BE override message
  (jsc#SLE-16518).
- ASoC: max98357a: add compatible string for MAX98360A
  (jsc#SLE-16518).
- ASoC: mediatek: mt6358: support DMIC one-wire mode
  (jsc#SLE-16518).
- ASoC: soc-component: tidyup Copyright (jsc#SLE-16518).
- ASoC: soc-component: merge soc_pcm_trigger_start/stop()
  (jsc#SLE-16518).
- ASoC: soc-component: merge soc-io.c into soc-component.c
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_init()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_pcm_component_trigger()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_pcm_component_hw_free()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_pcm_component_hw_params()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_pcm_component_prepare()
  (jsc#SLE-16518).
- ASoC: soc-component: add soc_component_err() (jsc#SLE-16518).
- ASoC: soc-component: move snd_soc_component_initialize()
  to soc-component.c (jsc#SLE-16518).
- ASoC: soc-component: move snd_soc_component_xxx_regmap()
  to soc-component (jsc#SLE-16518).
- ASoC: soc-component: add soc_component_pin() and share code
  (jsc#SLE-16518).
- ASoC: AMD: Use mixer control to switch between DMICs
  (jsc#SLE-16518).
- ASoC: max98390: Add Amp init common setting func
  (jsc#SLE-16518).
- ASoC: rt5682: DAI wclk supports 44100 Hz output (jsc#SLE-16518).
- ASoC: rt5682: Let PLL2 support the freq conversion for 44100Hz
  sample rate (jsc#SLE-16518).
- ASoC: rl6231: Add new supports on rl6231 (jsc#SLE-16518).
- ASoC: img-parallel-out: Fix a reference count leak
  (jsc#SLE-16518).
- ASoC: img: Fix a reference count leak in img_i2s_in_set_fmt
  (jsc#SLE-16518).
- ASoC: wm8960: Support headphone jack detection function
  (jsc#SLE-16518).
- commit 0d00972
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: samsung: Add driver for Aries boards (jsc#SLE-16518).
- ASoC: wm0010: Use kmemdup rather than duplicating its
  implementation (jsc#SLE-16518).
- ASoC: fsl_sai: Fix value of FSL_SAI_CR1_RFW_MASK
  (jsc#SLE-16518).
- ASoC: meson: cards: deal dpcm flag change (jsc#SLE-16518).
- ASoC: core: use less strict tests for dailink capabilities
  (jsc#SLE-16518).
- ASoC: meson: axg-tdm-formatters: fix sclk inversion
  (jsc#SLE-16518).
- ASoC: meson: axg-tdmin: fix g12a skew (jsc#SLE-16518).
- ASoC: meson: axg-tdm-interface: fix link fmt setup
  (jsc#SLE-16518).
- ASoC: soc-core: Fix regression causing sysfs entries to
  disappear (jsc#SLE-16518).
- ASoC: max98390: Fix dac event dapm mixer (jsc#SLE-16518).
- ASoC: Intel: kbl_rt5663_rt5514_max98927: Fix kabylake_ssp_fixup
  function (jsc#SLE-16518).
- ASoC: intel/skl/hda - fix probe regression on systems without
  i915 (jsc#SLE-16518).
- ASoC: max98357a: move control of SD_MODE back to DAI ops
  (jsc#SLE-16518).
- ASoC: Intel: common: change match table ehl-rt5660
  (jsc#SLE-16518).
- ASoC: meson: fixes the missed kfree() for
  axg_card_add_tdm_loopback (jsc#SLE-16518).
- Revert "ALSA: hda: call runtime_allow() for all hda controllers"
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Fix AE-5 microphone selection commands
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add new quirk ID for Recon3D (jsc#SLE-16518).
- ALSA: hda/ca0132 - Fix ZxR Headphone gain control get value
  (jsc#SLE-16518).
- ALSA: usb-audio: endpoint : remove needless check before
  usb_free_coherent() (jsc#SLE-16518).
- commit 5cad3ca
* Mon Sep 28 2020 tiwai@suse.de
- ALSA: hda/hdmi: Add Intel silent stream support (jsc#SLE-16518).
- Update config files.
- commit 91b7672
* Mon Sep 28 2020 tiwai@suse.de
- ALSA: Replace the word "slave" in vmaster API (jsc#SLE-16518).
- ALSA: asihpi: delete duplicated word (jsc#SLE-16518).
- ALSA: Replace HTTP links with HTTPS ones (jsc#SLE-16518).
- ALSA: line6: Use kmemdup in podhd_set_monitor_level()
  (jsc#SLE-16518).
- ALSA: hda: Add support for Loongson 7A1000 controller
  (jsc#SLE-16518).
- Revert "ALSA: pcm: Use SG-buffer only when direct DMA is
  available" (jsc#SLE-16518).
- ALSA: usb-audio: Replace blacklist word (jsc#SLE-16518).
- ALSA: via82xx: Replace the words whitelist (jsc#SLE-16518).
- ALSA: nm256: Replace the words blacklist (jsc#SLE-16518).
- ALSA: intel8x0: Replace the words white/blacklist
  (jsc#SLE-16518).
- ALSA: hda: Replace the words white/blacklist (jsc#SLE-16518).
- ALSA: es1968: Replace the words white/blacklist (jsc#SLE-16518).
- ALSA: ctxfi: Replace the word blacklist (jsc#SLE-16518).
- ALSA: bt87x: Replace the words white/blacklist (jsc#SLE-16518).
- ALSA: ac97: Replace the words white/blacklist (jsc#SLE-16518).
- ALSA: hda/tegra: Disable sync-write operation (jsc#SLE-16518).
- ALSA: echoaudio: re-enable IRQs on failure path (jsc#SLE-16518).
- ALSA: line6: add hw monitor volume control for POD HD500
  (jsc#SLE-16518).
- ALSA: Replace with fallthrough pseudo keyword in the remaining
  places (jsc#SLE-16518).
- ALSA: xen: Remove superfluous fall through comments
  (jsc#SLE-16518).
- ALSA: atmel: Remove invalid "fall through" comments
  (jsc#SLE-16518).
- ALSA: Use fallthrough pseudo-keyword (jsc#SLE-16518).
- ALSA: echoaudio: Address bugs in the interrupt handling
  (jsc#SLE-16518).
- ALSA: echoaudio: Prevent some noise on unloading the module
  (jsc#SLE-16518).
- ALSA: echoaudio: Prevent races in calls to set_audio_format()
  (jsc#SLE-16518).
- ALSA: echoaudio: Race conditions around "opencount"
  (jsc#SLE-16518).
- ALSA: echoaudio: Remove redundant check (jsc#SLE-16518).
- ALSA: usb/line6: remove 'defined but not used' warning
  (jsc#SLE-16518).
- ALSA: pcm: Fix build error on m68k and others (jsc#SLE-16518).
- ALSA: pci/au88x0: remove "defined but not used" warnings
  (jsc#SLE-16518).
- ALSA: vx_core: remove warning for empty loop body
  (jsc#SLE-16518).
- ALSA: pcmcia/pdaudiocf: fix kernel-doc (jsc#SLE-16518).
- ALSA: pci/via82xx: remove 'set but not used' warnings
  (jsc#SLE-16518).
- ALSA: pci/fm801: fix kernel-doc (jsc#SLE-16518).
- ALSA: pci/es1938: remove 'set but not used' warning
  (jsc#SLE-16518).
- ALSA: xen: remove 'set but not used' warning (jsc#SLE-16518).
- ALSA: pci/oxygen/xonar_wm87x6: remove always true condition
  (jsc#SLE-16518).
- ALSA: pci/rme9652/hdspm: remove always true condition
  (jsc#SLE-16518).
- ALSA: pci/korg1212: remove 'set but not used' warnings
  (jsc#SLE-16518).
- ALSA: pci/emu10k1: remove 'set but not used' warning
  (jsc#SLE-16518).
- ALSA: firewire: fix kernel-doc (jsc#SLE-16518).
- ASoC: pci/emu10k1: remove "set but not used' warnings
  (jsc#SLE-16518).
- ALSA: pci/ctxfi: fix kernel-doc warnings (jsc#SLE-16518).
- ALSA: pci/ctxfi/ctatc: fix kernel-doc (jsc#SLE-16518).
- ALSA: pci/aw2-saa7146: remove 'set but not used' warning
  (jsc#SLE-16518).
- ALSA: pci/echoaudio: remove 'set but not used' warning
  (jsc#SLE-16518).
- ALSA: pci/asihpi: remove 'set but not used' warning
  (jsc#SLE-16518).
- ALSA: pci/asihpi: fix kernel-doc (jsc#SLE-16518).
- ALSA: pci/asihpi: remove 'set but not used' warnings
  (jsc#SLE-16518).
- ALSA: isa/gus: remove 'set but not used' warning
  (jsc#SLE-16518).
- ALSA: isa/gus: remove -Wmissing-prototypes warnings
  (jsc#SLE-16518).
- ALSA: hda: fix SND_HDA_GENERIC kconfig & build (jsc#SLE-16518).
- ALSA: core: pcm_iec958: fix kernel-doc (jsc#SLE-16518).
- ALSA: usb-audio: Fix some typos (jsc#SLE-16518).
- ALSA: hda: Let LED cdev handling suspend/resume (jsc#SLE-16518).
- ALSA: hda/realtek: Unify LED helper code (jsc#SLE-16518).
- ALSA: hda/sigmatel: Use the new vmaster mute LED helper
  (jsc#SLE-16518).
- ALSA: hda/conexant: Use the new vmaster mute LED helper
  (jsc#SLE-16518).
- ALSA: hda/realtek: Use the new vmaster mute LED helper
  (jsc#SLE-16518).
- ALSA: hda: generic: Add vmaster mute LED helper (jsc#SLE-16518).
- ALSA: hda: generic: Drop the old mic-mute LED hook
  (jsc#SLE-16518).
- ALSA: hda: generic: Drop unused snd_hda_gen_fixup_micmute_led()
  (jsc#SLE-16518).
- ALSA: hda/sigmatel: Convert to cdev-variant of mic-mute LED
  controls (jsc#SLE-16518).
- ALSA: hda/conexant: Convert to cdev-variant of mic-mute LED
  controls (jsc#SLE-16518).
- ALSA: hda/realtek: Convert to cdev-variant of mic-mute LED
  controls (jsc#SLE-16518).
- ALSA: hda: generic: Add a helper for mic-mute LED with LED
  classdev (jsc#SLE-16518).
- ALSA: hda: generic: Always call led-trigger for mic mute LED
  (jsc#SLE-16518).
- ALSA: hda: Enable sync-write operation as default for all
  controllers (jsc#SLE-16518).
- ALSA: pcm: Use SG-buffer only when direct DMA is available
  (jsc#SLE-16518).
- ALSA: memalloc: Make SG-buffer helper usable for continuous
  buffer, too (jsc#SLE-16518).
- ALSA: memalloc: Initialize all fields of snd_dma_buffer properly
  (jsc#SLE-16518).
- ALSA: pcm: Use dma_mmap_coherent() on x86, too (jsc#SLE-16518).
- ALSA: firewire-motu: wait for notification when changing clock
  configuration for protocol v3 (jsc#SLE-16518).
- ALSA: hda/realtek: Add alc269/alc662 pin-tables for Loongson-3
  laptops (jsc#SLE-16518).
- Soundwire: intel_init: save Slave(s) _ADR info in sdw_intel_ctx
  (jsc#SLE-16518).
- soundwire: intel: add wake interrupt support (jsc#SLE-16518).
- soundwire: intel/cadence: merge Soundwire interrupt
  handlers/threads (jsc#SLE-16518).
- soundwire: intel_init: add implementation of
  sdw_intel_enable_irq() (jsc#SLE-16518).
- soundwire: intel: introduce helper for link synchronization
  (jsc#SLE-16518).
- soundwire: intel: introduce a helper to arm link synchronization
  (jsc#SLE-16518).
- soundwire: intel: revisit SHIM programming sequences
  (jsc#SLE-16518).
- soundwire: intel: reuse code for wait loops to set/clear bits
  (jsc#SLE-16518).
- soundwire: fix the kernel-doc comment (jsc#SLE-16518).
- soundwire: sdw.h: fix indentation (jsc#SLE-16518).
- soundwire: sdw.h: fix PRBS/Static_1 swapped definitions
  (jsc#SLE-16518).
- soundwire: intel: don't free dma_data in DAI shutdown
  (jsc#SLE-16518).
- soundwire: cadence: allocate/free dma_data in set_sdw_stream
  (jsc#SLE-16518).
- soundwire: intel: remove stream allocation/free (jsc#SLE-16518).
- soundwire: stream: add helper to startup/shutdown streams
  (jsc#SLE-16518).
- soundwire: intel: implement get_sdw_stream() operations
  (jsc#SLE-16518).
- soundwire: bus: initialize bus clock base and scale registers
  (jsc#SLE-16518).
- soundwire: extend SDW_SLAVE_ENTRY (jsc#SLE-16518).
- soundwire: bus_type: convert open-coded while() to for() loop
  (jsc#SLE-16518).
- soundwire: add definitions for 1.2 spec (jsc#SLE-16518).
- soundwire: qcom: Constify static structs (jsc#SLE-16518).
- soundwire: intel: transition to 3 steps initialization
  (jsc#SLE-16518).
- soundwire: intel_init: pass link information as platform data
  (jsc#SLE-16518).
- soundwire: intel_init: use devm_ allocation (jsc#SLE-16518).
- soundwire: intel_init: remove useless test (jsc#SLE-16518).
- soundwire: intel: clarify drvdata and remove more indirections
  (jsc#SLE-16518).
- soundwire: intel: cleanups for indirections/logs
  (jsc#SLE-16518).
- soundwire: bus: clock_stop: don't deal with UNATTACHED Slave
  devices (jsc#SLE-16518).
- soundwire: Replace 'objs' by 'y' (jsc#SLE-16518).
- commit 1f91df1
* Mon Sep 28 2020 yousaf.kaukab@suse.com
- dt-bindings: clock: tegra: Add IDs for OSC clocks (jsc#SLE-15847).
- commit 4af4b35
* Mon Sep 28 2020 tiwai@suse.de
- ALSA: hda/realtek - Fixed HP right speaker no sound
  (jsc#SLE-16518).
- ALSA: hda: fix NULL pointer dereference during suspend
  (jsc#SLE-16518).
- ALSA: hda/hdmi: Fix keep_power assignment for non-component
  devices (jsc#SLE-16518).
- ALSA: hda: Workaround for spurious wakeups on some Intel
  platforms (jsc#SLE-16518).
- ALSA: hda/realtek: Fix add a "ultra_low_power" function for
  intel reference board (alc256) (jsc#SLE-16518).
- ALSA: hda/realtek: typo_fix: enable headset mic of ASUS ROG
  Zephyrus G14(GA401) series with ALC289 (jsc#SLE-16518).
- ALSA: hda/realtek: enable headset mic of ASUS ROG Zephyrus
  G15(GA502) series with ALC289 (jsc#SLE-16518).
- ALSA: usb-audio: Add implicit feedback quirk for SSL2
  (jsc#SLE-16518).
- ALSA: hda/realtek: Fixed ALC298 sound bug by adding quirk for
  Samsung Notebook Pen S (jsc#SLE-16518).
- ASoC: rt5682: Report the button event in the headset type only
  (jsc#SLE-16518).
- ASoC: Intel: bytcht_es8316: Add missed put_device()
  (jsc#SLE-16518).
- ASoC: rt5682: Enable Vref2 under using PLL2 (jsc#SLE-16518).
- ASoC: rt286: fix unexpected interrupt happens (jsc#SLE-16518).
- ASoC: wm8974: remove unsupported clock mode (jsc#SLE-16518).
- ASoC: wm8974: fix Boost Mixer Aux Switch (jsc#SLE-16518).
- ASoC: SOF: imx: add min/max channels for SAI/ESAI on
  i.MX8/i.MX8M (jsc#SLE-16518).
- ASoC: Intel: bdw-rt5677: fix non BE conversion (jsc#SLE-16518).
- ASoC: soc-dai: set dai_link dpcm_ flags with a helper
  (jsc#SLE-16518).
- ASoC: topology: fix tlvs in error handling for widget_dmixer
  (jsc#SLE-16518).
- ASoC: topology: fix kernel oops on route addition error
  (jsc#SLE-16518).
- ASoc: codecs: max98373: remove Idle_bias_on to let codec suspend
  (jsc#SLE-16518).
- ASoC: codecs: max98373: Removed superfluous volume control
  from chip default (jsc#SLE-16518).
- ASoC: SOF: core: fix null-ptr-deref bug during device removal
  (jsc#SLE-16518).
- ASoC: core: Remove only the registered component in devm
  functions (jsc#SLE-16518).
- ASoC: rockchip: add format and rate constraints on rk3399
  (jsc#SLE-16518).
- ASoC: amd: Rectifying Unbalanced pm_runtime_enable! issue
  (jsc#SLE-16518).
- ASoC: rt5682: cancel jack_detect_work if hs_jack is set to
  null even soundwire mode (jsc#SLE-16518).
- ASoC: rt5670: Fix dac- and adc- vol-tlv values being off by
  a factor of 10 (jsc#SLE-16518).
- ASoC: rt5670: Add new gpio1_is_ext_spk_en quirk and enable it
  on the Lenovo Miix 2 10 (jsc#SLE-16518).
- ASoC: rt5670: Correct RT5670_LDO_SEL_MASK (jsc#SLE-16518).
- ASoC: Intel: cht_bsw_rt5672: Change bus format to I2S 2 channel
  (jsc#SLE-16518).
- ASoC: qcom: Drop HAS_DMA dependency to fix link failure
  (jsc#SLE-16518).
- ALSA: info: Drop WARN_ON() from buffer NULL sanity check
  (jsc#SLE-16518).
- ALSA: hda/realtek - fixup for yet another Intel reference board
  (jsc#SLE-16518).
- ALSA: hda/realtek - Enable Speaker for ASUS UX563
  (jsc#SLE-16518).
- ALSA: hda/realtek - Enable Speaker for ASUS UX533 and UX534
  (jsc#SLE-16518).
- ALSA: hda/realtek: Enable headset mic of Acer TravelMate
  B311R-31 with ALC256 (jsc#SLE-16518).
- ALSA: hda/realtek: enable headset mic of ASUS ROG Zephyrus
  G14(G401) series with ALC289 (jsc#SLE-16518).
- ALSA: hda/realtek - change to suitable link model for ASUS
  platform (jsc#SLE-16518).
- ALSA: usb-audio: Fix race against the error recovery URB
  submission (jsc#SLE-16518).
- ALSA: line6: Sync the pending work cancel at disconnection
  (jsc#SLE-16518).
- ALSA: line6: Perform sanity check for each URB creation
  (jsc#SLE-16518).
- ALSA: compress: fix partial_drain completion state
  (jsc#SLE-16518).
- ALSA: usb-audio: Add implicit feedback quirk for RTX6001
  (jsc#SLE-16518).
- ALSA: usb-audio: add quirk for MacroSilicon MS2109
  (jsc#SLE-16518).
- ALSA: hda/realtek: Enable headset mic of Acer Veriton N4660G
  with ALC269VC (jsc#SLE-16518).
- ALSA: hda/realtek: Enable headset mic of Acer C20-820 with
  ALC269VC (jsc#SLE-16518).
- ALSA: hda/realtek - Enable audio jacks of Acer vCopperbox with
  ALC269VC (jsc#SLE-16518).
- ALSA: hda/realtek - Fix Lenovo Thinkpad X1 Carbon 7th quirk
  subdevice id (jsc#SLE-16518).
- ALSA: hda/hdmi: improve debug traces for stream lookups
  (jsc#SLE-16518).
- ALSA: hda/hdmi: fix failures at PCM open on Intel ICL and later
  (jsc#SLE-16518).
- ALSA: opl3: fix infoleak in opl3 (jsc#SLE-16518).
- AsoC: amd: add missing snd- module prefix to the acp3x-rn
  driver kernel module (jsc#SLE-16518).
- ASoC: rt5682: fix the pop noise while OMTP type headset plugin
  (jsc#SLE-16518).
- ASoC: fsl_mqs: Fix unchecked return value for clk_prepare_enable
  (jsc#SLE-16518).
- ASoC: fsl_mqs: Don't check clock is NULL before calling clk API
  (jsc#SLE-16518).
- ALSA: usb-audio: Replace s/frame/packet/ where appropriate
  (jsc#SLE-16518).
- ALSA: usb-audio: Fix packet size calculation (jsc#SLE-16518).
- ALSA: hda - let hs_mic be picked ahead of hp_mic
  (jsc#SLE-16518).
- ALSA: usb-audio: Fix OOB access of mixer element list
  (jsc#SLE-16518).
- ALSA: usb-audio: add quirk for Samsung USBC Headset (AKG)
  (jsc#SLE-16518).
- ALSA: usb-audio: Add registration quirk for Kingston HyperX
  Cloud Flight S (jsc#SLE-16518).
- commit 05c31fd
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: Intel: SOF: merge COMETLAKE_LP and COMETLAKE_H
  (jsc#SLE-16518).
- Update config files.
- commit 028f97c
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: rockchip: Fix a reference count leak (jsc#SLE-16518).
- ASoC: amd: closing specific instance (jsc#SLE-16518).
- ASoC: SOF: Intel: add PCI IDs for ICL-H and TGL-H
  (jsc#SLE-16518).
- ASoC: SOF: Intel: add PCI ID for CometLake-S (jsc#SLE-16518).
- ASoC: hdac_hda: fix memleak with regmap not freed on remove
  (jsc#SLE-16518).
- ASoC: fsl_ssi: Fix bclk calculation for mono channel
  (jsc#SLE-16518).
- ASoC: soc-topology: use devm_snd_soc_register_dai()
  (jsc#SLE-16518).
- ASoC: soc-devres: add devm_snd_soc_register_dai()
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Clear RIRB status before reading WP
  (jsc#SLE-16518).
- ASoC: rt1015: Update rt1015 default register value according
  to spec modification (jsc#SLE-16518).
- ASoC: qcom: common: set correct directions for dailinks
  (jsc#SLE-16518).
- ASoc: q6afe: add support to get port direction (jsc#SLE-16518).
- ASoC: soc-pcm: fix checks for multi-cpu FE dailinks
  (jsc#SLE-16518).
- ASoC: rt5682: Let dai clks be registered whether mclk exists
  or not (jsc#SLE-16518).
- ASoC: fsl_asrc_dma: Fix data copying speed issue with EDMA
  (jsc#SLE-16518).
- ASoC: fsl_asrc_dma: Reuse the dma channel if available in
  Back-End (jsc#SLE-16518).
- ASoC: dmaengine_pcm: export soc_component_to_pcm
  (jsc#SLE-16518).
- ASoC: soc-card: export snd_soc_lookup_component_nolocked
  (jsc#SLE-16518).
- ASoC: q6asm: handle EOS correctly (jsc#SLE-16518).
- ASoC: max98390: Update regmap readable reg and volatile
  (jsc#SLE-16518).
- ALSA: hda: Intel: add missing PCI IDs for ICL-H, TGL-H and EKL
  (jsc#SLE-16518).
- ALSA: hda/realtek: Add mute LED and micmute LED support for
  HP systems (jsc#SLE-16518).
- ALSA: usb-audio: Fix potential use-after-free of streams
  (jsc#SLE-16518).
- ALSA: hda/realtek - Add quirk for MSI GE63 laptop
  (jsc#SLE-16518).
- ALSA: usb-audio: Set 48 kHz rate for Rodecaster (jsc#SLE-16518).
- ALSA: usb-audio: add quirk for Denon DCD-1500RE (jsc#SLE-16518).
- ALSA: usb-audio: Add implicit feedback quirk for SSL2+
  (jsc#SLE-16518).
- ALSA: hda: Add NVIDIA codec IDs 9a & 9d through a0 to patch
  table (jsc#SLE-16518).
- ASoC: SOF: Replace zero-length array with flexible-array
  (jsc#SLE-16518).
- commit c546229
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: SOF: nocodec: conditionally set dpcm_capture/dpcm_playback
  flags (jsc#SLE-16518).
- ASoC: Intel: boards: replace capture_only by dpcm_capture
  (jsc#SLE-16518).
- ASoC: core: only convert non DPCM link to DPCM link
  (jsc#SLE-16518).
- ASoC: soc-pcm: dpcm: fix playback/capture checks
  (jsc#SLE-16518).
- ASoC: rt5645: Add platform-data for Asus T101HA (jsc#SLE-16518).
- ASoC: Intel: bytcr_rt5640: Add quirk for Toshiba Encore WT10-A
  tablet (jsc#SLE-16518).
- ASoC: meson: add missing free_irq() in error path
  (jsc#SLE-16518).
- ASoC: meson: fix memory leak of links if allocation of ldata
  fails (jsc#SLE-16518).
- ASoC: max98390: Fix potential crash during param fw loading
  (jsc#SLE-16518).
- ASoC: max98390: Fix incorrect printf qualifier (jsc#SLE-16518).
- ASoC: fsl-asoc-card: Defer probe when fail to find codec device
  (jsc#SLE-16518).
- ASoC: rl6231: Modify the target DMIC clock rate (jsc#SLE-16518).
- ALSA: pcm: disallow linking stream to itself (jsc#SLE-16518).
- ALSA: usb-audio: Manage auto-pm of all bundled interfaces
  (jsc#SLE-16518).
- ALSA: hda/realtek - add a pintbl quirk for several Lenovo
  machines (jsc#SLE-16518).
- ALSA: pcm: fix snd_pcm_link() lockdep splat (jsc#SLE-16518).
- ALSA: usb-audio: Use the new macro for HP Dock rename quirks
  (jsc#SLE-16518).
- ALSA: usb-audio: Add vendor, product and profile name for HP
  Thunderbolt Dock (jsc#SLE-16518).
- ALSA: emu10k1: delete an unnecessary condition (jsc#SLE-16518).
- ALSA: usb-audio: Fix inconsistent card PM state after resume
  (jsc#SLE-16518).
- soundwire: intel: use a single module (jsc#SLE-16518).
- soundwire: fix spelling mistake (jsc#SLE-16518).
- soundwire: fix trailing line in sysfs_slave.c (jsc#SLE-16518).
- soundwire: add Slave sysfs support (jsc#SLE-16518).
- soundwire: master: add sysfs support (jsc#SLE-16518).
- soundwire: disco: s/ch/channels/ (jsc#SLE-16518).
- soundwire: master: add runtime pm support (jsc#SLE-16518).
- soundwire: bus_type: add sdw_master_device support
  (jsc#SLE-16518).
- soundwire: bus: add unique bus id (jsc#SLE-16518).
- soundwire: bus_type: introduce sdw_slave_type and
  sdw_master_type (jsc#SLE-16518).
- soundwire: bus: rename sdw_bus_master_add/delete, add arguments
  (jsc#SLE-16518).
- soundwire: intel: (cosmetic) remove multiple superfluous "else"
  statements (jsc#SLE-16518).
- soundwire: (cosmetic) remove multiple superfluous "else"
  statements (jsc#SLE-16518).
- soundwire: qcom: Use IRQF_ONESHOT (jsc#SLE-16518).
- soundwire: bus: reduce verbosity on enumeration (jsc#SLE-16518).
- soundwire: debugfs: clarify SDPX license with GPL-2.0-only
  (jsc#SLE-16518).
- soundwire: slave: don't init debugfs on device registration
  error (jsc#SLE-16518).
- soundwire: qcom: fix error handling in probe (jsc#SLE-16518).
- ALSA: es1688: Add the missed snd_card_free() (jsc#SLE-16518).
- ALSA: hda: add sienna_cichlid audio asic id for sienna_cichlid
  up (jsc#SLE-16518).
- ALSA: usb-audio: Add Pioneer DJ DJM-900NXS2 support
  (jsc#SLE-16518).
- ASoC: qcom: q6asm-dai: kCFI fix (jsc#SLE-16518).
- ASoC: soc-card: add snd_soc_card_remove_dai_link()
  (jsc#SLE-16518).
- ASoC: soc-card: add snd_soc_card_add_dai_link() (jsc#SLE-16518).
- ASoC: soc-card: add snd_soc_card_set_bias_level_post()
  (jsc#SLE-16518).
- ASoC: soc-card: add snd_soc_card_set_bias_level()
  (jsc#SLE-16518).
- ASoC: soc-card: add snd_soc_card_remove() (jsc#SLE-16518).
- ASoC: soc-card: add snd_soc_card_late_probe() (jsc#SLE-16518).
- ASoC: soc-card: add snd_soc_card_probe() (jsc#SLE-16518).
- ASoC: soc-card: add probed bit field to snd_soc_card
  (jsc#SLE-16518).
- ASoC: soc-card: add snd_soc_card_resume_post() (jsc#SLE-16518).
- ASoC: soc-card: add snd_soc_card_resume_pre() (jsc#SLE-16518).
- ASoC: soc-card: add snd_soc_card_suspend_post() (jsc#SLE-16518).
- ASoC: soc-card: add snd_soc_card_suspend_pre() (jsc#SLE-16518).
- ASoC: soc-card: move snd_soc_card_subclass to soc-card
  (jsc#SLE-16518).
- ASoC: soc-card: move snd_soc_card_get_codec_dai() to soc-card
  (jsc#SLE-16518).
- ASoC: soc-card: move snd_soc_card_set/get_drvdata() to soc-card
  (jsc#SLE-16518).
- ASoC: soc-card: move snd_soc_card_jack_new() to soc-card
  (jsc#SLE-16518).
- ASoC: soc-card: move snd_soc_card_get_kcontrol() to soc-card
  (jsc#SLE-16518).
- ASoC: add soc-card.c (jsc#SLE-16518).
- ASoC: soc.h: convert bool to bit field for snd_soc_card
  (jsc#SLE-16518).
- ASoC: sof_pcm512x: remove CONFIG_SND_HDA_CODEC_HDMI condition
  (jsc#SLE-16518).
- commit c7ccd53
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: sof-sdw: remove CONFIG_SND_SOC_SOF_HDA_AUDIO_CODEC
  condition (jsc#SLE-16518).
- ASoC: intel: add depends on SND_SOC_SOF_HDA_AUDIO_CODEC for
  common hdmi (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: fix generic hda codec support
  (jsc#SLE-16518).
- ASoC: SOF: Intel: Baytrail: fix 'defined but not used' warnings
  (jsc#SLE-16518).
- Subject: [PATCH v2] ASoC: soc-pcm: fix BE dai not hw_free and
  shutdown during mixer update (jsc#SLE-16518).
- ASoC: reduce verbosity of error messages for sof-dai and
  sof-link (jsc#SLE-16518).
- ASoC: topology: remove the redundant pass checks
  (jsc#SLE-16518).
- ASoC: topology: refine and log the header in the correct pass
  (jsc#SLE-16518).
- ASoC: fsl_asrc_dma: Fix dma_chan leak when config DMA channel
  failed (jsc#SLE-16518).
- ASoC: rt1015: Enable class-D silence and clock detections
  (jsc#SLE-16518).
- ASoC: img-i2s-out: Fix runtime PM imbalance on error
  (jsc#SLE-16518).
- ASoC: amd: Removing unnecessary instance initialization
  (jsc#SLE-16518).
- ASoC: sta32x: add missed function calls in error paths
  (jsc#SLE-16518).
- ASoC: rt5682: split i2c driver into separate module
  (jsc#SLE-16518).
- ASoC: nau8810: add I2C device and compatible ID (jsc#SLE-16518).
- ASoC: ingenic: Unconditionally depend on devicetree
  (jsc#SLE-16518).
- ASoC: SOF: Intel: BYT: harden IPC initialization and handling
  (jsc#SLE-16518).
- ASoC: SOF: Intel: BYT: mask BUSY or DONE interrupts in handler
  (jsc#SLE-16518).
- ASoC: SOF: Intel: BYT: add .remove op (jsc#SLE-16518).
- ASoC: SOF: ipc: ignore DSP replies received when they are not
  expected (jsc#SLE-16518).
- ASoC: Intel: byt/cht: add .pm_ops (jsc#SLE-16518).
- ASoC: Intel: bytcr_rt5640/51: remove .ignore_suspend
  (jsc#SLE-16518).
- ASoC: SOF: pm: handle resume on legacy Intel platforms
  (jsc#SLE-16518).
- ASoC: SOF: Intel: byt: Add PM callbacks (jsc#SLE-16518).
- ASoC: mmp-sspa: Fix return value check in asoc_mmp_sspa_probe()
  (jsc#SLE-16518).
- ASoC: tlv320adcx140: Fix warnings when using W=1
  (jsc#SLE-16518).
- ASoC: wm8962: Fix runtime PM imbalance on error (jsc#SLE-16518).
- ASoC: img-spdif-in: Fix runtime PM imbalance on error
  (jsc#SLE-16518).
- ASoC: tlv320adcx140: Add support for configuring GPI pins
  (jsc#SLE-16518).
- ASoC: img-spdif-out: Fix runtime PM imbalance on error
  (jsc#SLE-16518).
- commit 3d54828
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: tas2552: Fix runtime PM imbalance in
  tas2552_component_probe (jsc#SLE-16518).
- ASoC: fix incomplete error-handling in img_i2s_in_probe
  (jsc#SLE-16518).
- ASoC: ti: Fix runtime PM imbalance in omap2_mcbsp_set_clks_src
  (jsc#SLE-16518).
- ASoC: fix semicolon.cocci warnings (jsc#SLE-16518).
- ASoC: soc-link: add snd_soc_link_compr_set_params()
  (jsc#SLE-16518).
- ASoC: soc-link: add snd_soc_link_compr_shutdown()
  (jsc#SLE-16518).
- ASoC: soc-link: add snd_soc_link_compr_startup()
  (jsc#SLE-16518).
- ASoC: soc-link: add snd_soc_link_be_hw_params_fixup()
  (jsc#SLE-16518).
- ASoC: soc-link: remove unneeded parameter from
  snd_soc_link_xxx() (jsc#SLE-16518).
- ASoC: soc-link: move soc_rtd_xxx() (jsc#SLE-16518).
- commit cae9fee
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: max98390: Added Amplifier Driver (jsc#SLE-16518).
- Update config files.
- commit 5dca8a5
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: add soc-link.c (jsc#SLE-16518).
- ASoC: SOF: ext_manifest: parse compiler version (jsc#SLE-16518).
- ASoC: SOF: ext_manifest: parse windows (jsc#SLE-16518).
- ASoC: SOF: ext_manifest: parse firmware version (jsc#SLE-16518).
- ASoC: SOF: Introduce extended manifest (jsc#SLE-16518).
- ASoC: SOF: loader: Adjust validation condition for fw_offset
  (jsc#SLE-16518).
- ASoC: fsl_asrc: Merge suspend/resume function to
  runtime_suspend/resume (jsc#SLE-16518).
- ASoC: fsl: imx-audmix: Fix unused assignment to variable 'ret'
  (jsc#SLE-16518).
- ASoC: fsl_asrc: Fix -Wmissing-prototypes warning
  (jsc#SLE-16518).
- ASoC: max9867: keep ADCs and DACs always on (jsc#SLE-16518).
- ASoC: max9867: add digital microphone controls (jsc#SLE-16518).
- ASoC: pxa: remove Compulab pxa2xx boards (jsc#SLE-16518).
- ASoC: max9867: add mono playback switch (jsc#SLE-16518).
- ASoC: max9867: add filter controls (jsc#SLE-16518).
- ASoC: max9867: don't use regmap defaults (jsc#SLE-16518).
- ASoC: mmp-sspa: Fix the error handling in probe()
  (jsc#SLE-16518).
- ASoC: mmp-sspa: Add Device Tree support (jsc#SLE-16518).
- ASoC: amd: return error when acp de-init fails (jsc#SLE-16518).
- ASoC: amd: refactoring dai_hw_params() callback (jsc#SLE-16518).
- commit c04d39f
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: amd: enable build for RN machine driver (jsc#SLE-16518).
- Update config files.
- commit 47fc3b0
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: amd: fix kernel warning (jsc#SLE-16518).
- ASoC: amd: RN machine driver using dmic (jsc#SLE-16518).
- ASoC: amd: create platform devices for Renoir (jsc#SLE-16518).
- ASoC: amd: enable Renoir acp3x drivers build (jsc#SLE-16518).
- ASoC: amd: add ACP PDM DMA driver pm ops (jsc#SLE-16518).
- ASoC: amd: add Renoir ACP PCI driver PM ops (jsc#SLE-16518).
- ASoC: amd: add ACP PDM DMA driver dai ops (jsc#SLE-16518).
- ASoC: amd: add acp3x pdm driver dma ops (jsc#SLE-16518).
- ASoC: amd: irq handler changes for ACP3x PDM dma driver
  (jsc#SLE-16518).
- ASoC: amd: add ACP3x PDM platform driver (jsc#SLE-16518).
- ASoC: amd: create acp3x pdm platform device (jsc#SLE-16518).
- ASoC: amd: add acp init/de-init functions (jsc#SLE-16518).
- ASoC: amd: add Renoir ACP PCI driver (jsc#SLE-16518).
- ASoC: amd: add Renoir ACP3x IP register header (jsc#SLE-16518).
- ASoC: fsl_micfil: Do not pass irq numbers in comments
  (jsc#SLE-16518).
- ASoC: fsl_micfil: Remove unneeded ifdef's (jsc#SLE-16518).
- ASoC: fsl_asrc: Set ASR76K and ASR56K based on processing clock
  (jsc#SLE-16518).
- ASoC: Intel: bytcr_rt5640: Add quirk for Toshiba Encore WT8-A
  tablet (jsc#SLE-16518).
- ASoC: SOF: imx: make imx8m_dsp_ops static (jsc#SLE-16518).
- ASoC: SOF: imx: make dsp_ops static (jsc#SLE-16518).
- ASoC: SOF: define INFO_ flags in dsp_ops (jsc#SLE-16518).
- ASoC: SOF: Intel: sdw: relax sdw machine select constraints
  (jsc#SLE-16518).
- ASoC: SOF: topology: add support to smart amplifier
  (jsc#SLE-16518).
- ASoC: SOF: inform DSP that driver is going to be removed
  (jsc#SLE-16518).
- ASoC: SOF: add a power_down_notify method (jsc#SLE-16518).
- ASoC: SOF: Do nothing when DSP PM callbacks are not set
  (jsc#SLE-16518).
- ASoC: cleanup dai / component active code (jsc#SLE-16518).
- ASoC: dwc: use snd_soc_xxx_active() (jsc#SLE-16518).
- ASoC: uniphier: use snd_soc_xxx_active() (jsc#SLE-16518).
- commit 19aff4a
* Mon Sep 28 2020 yousaf.kaukab@suse.com
- clk: tegra: pll: Improve PLLM enable-state detection (jsc#SLE-15847).
- pinctrl: tegra: pinctrl-tegra194: Do not initialise field twice (jsc#SLE-15847).
- cpufreq: replace cpu_logical_map() with read_cpuid_mpir() (jsc#SLE-15847).
- cpufreq: Add Tegra194 cpufreq driver (jsc#SLE-15847).
- cpufreq: tegra186: Simplify probe return path (jsc#SLE-15847).
- memory: tegra: Add Tegra132 compatible string match (jsc#SLE-15847).
- memory: tegra: Fix KCONFIG variables for Tegra186 and Tegra194 (jsc#SLE-15847).
- memory: tegra: Delete some dead code (jsc#SLE-15847).
- memory: tegra: Avoid unused function warnings (jsc#SLE-15847).
- memory: tegra: Drop <linux/clk-provider.h> (jsc#SLE-15847).
- memory: tegra: Fix an error handling path in tegra186_emc_probe() (jsc#SLE-15847).
- memory: tegra: Support derated timings on Tegra210 (jsc#SLE-15847).
- memory: tegra: Add EMC scaling sequence code for Tegra210 (jsc#SLE-15847).
- memory: tegra: Add EMC scaling support code for Tegra210 (jsc#SLE-15847).
- firmware: tegra: Add support for in-band debug (jsc#SLE-15847).
- firmware: tegra: Prepare for supporting in-band debugfs (jsc#SLE-15847).
- firmware: tegra: Use consistent return variable name (jsc#SLE-15847).
- firmware: tegra: Add return code checks and increase debugfs size (jsc#SLE-15847).
- clk: tegra: Remove the old emc_mux clock for Tegra210 (jsc#SLE-15847).
- clk: tegra: Implement Tegra210 EMC clock (jsc#SLE-15847).
- clk: tegra: Export functions for EMC clock scaling (jsc#SLE-15847).
- clk: tegra: Add PLLP_UD and PLLMB_UD for Tegra210 (jsc#SLE-15847).
- clk: tegra: Rename Tegra124 EMC clock source file (jsc#SLE-15847).
- of: Make <linux/of_reserved_mem.h> self-contained (jsc#SLE-15847).
- of: reserved-memory: Support multiple regions per device (jsc#SLE-15847).
- of: reserved-memory: Support lookup of regions by name (jsc#SLE-15847).
- firmware: tegra: Defer BPMP probe if shared memory not available (jsc#SLE-15847).
- firmware: tegra: Make BPMP a regular driver (jsc#SLE-15847).
- ASoC: tegra: Enable audio mclk during tegra_asoc_utils_init() (jsc#SLE-15847).
- ASoC: tegra: Add audio mclk parent configuration (jsc#SLE-15847).
- ASoC: tegra: Use device managed resource APIs to get the clock (jsc#SLE-15847).
- clk: tegra: Fix initial rate for pll_a on Tegra124 (jsc#SLE-15847).
- clk: tegra: Use NULL for pointer initialization (jsc#SLE-15847).
- clk: tegra: Remove audio clocks configuration from clock driver (jsc#SLE-15847).
- clk: tegra: Remove tegra_pmc_clk_init along with clk ids (jsc#SLE-15847).
- clk: tegra: Remove CLK_M_DIV fixed clocks (jsc#SLE-15847).
- clk: tegra: Add Tegra OSC to clock lookup (jsc#SLE-15847).
- clk: tegra: Add support for OSC_DIV fixed clocks (jsc#SLE-15847).
- gpio: tegra186: Add Tegra194 pin ranges for GG.0 and GG.1 (jsc#SLE-15847).
- gpio: tegra186: Add support for pin ranges (jsc#SLE-15847).
- gpio: Support GPIO controllers without pin-ranges (jsc#SLE-15847).
- memory: tegra: Correct debugfs clk rate-range on Tegra124 (jsc#SLE-15847).
- firmware: tegra: Fix a typo in Kconfig (jsc#SLE-15847).
- soc/tegra: Add support for 32 kHz blink clock (jsc#SLE-15847).
- soc/tegra: Add Tegra PMC clocks registration into PMC driver (jsc#SLE-15847).
- pinctrl: tegra: Add SFIO/GPIO programming on Tegra194 (jsc#SLE-15847).
- pinctrl: tegra: Renumber the GG.0 and GG.1 pins (jsc#SLE-15847).
- pinctrl: tegra: Do not add default pin range on Tegra194 (jsc#SLE-15847).
- pinctrl: tegra: Pass struct tegra_pmx for pin range check (jsc#SLE-15847).
- pinctrl: tegra: Fix "Scmitt" -> "Schmitt" typo (jsc#SLE-15847).
- pinctrl: tegra: Fix whitespace issues for improved readability (jsc#SLE-15847).
- memory: tegra: Correct reset value of xusb_hostr (jsc#SLE-15847).
- memory: tegra: Add support for the Tegra194 memory controller (jsc#SLE-15847).
- memory: tegra: Only include support for enabled SoCs (jsc#SLE-15847).
- memory: tegra: Support DVFS on Tegra186 and later (jsc#SLE-15847).
- memory: tegra: Add system sleep support (jsc#SLE-15847).
- memory: tegra: Extract memory client SID programming (jsc#SLE-15847).
- memory: tegra: Add per-SoC data for Tegra186 (jsc#SLE-15847).
- memory: tegra: Rename tegra_mc to tegra186_mc on Tegra186 (jsc#SLE-15847).
- memory: tegra: Refashion EMC debugfs interface on Tegra124 (jsc#SLE-15847).
- clk: tegra: divider: Check UART's divider enable-bit state on rate's recalculation (jsc#SLE-15847).
- clk: tegra: clk-dfll: Remove call to pm_runtime_irq_safe() (jsc#SLE-15847).
- pinctrl: tegra: fix missing __iomem in suspend/resume (jsc#SLE-15847).
- gpiolib: Add the support for the msi parent domain (jsc#SLE-15847).
- gpiolib: Add support for the irqdomain which doesn't use irq_fwspec as arg (jsc#SLE-15847).
- gpio: tegra: Use NOIRQ phase for suspend/resume (jsc#SLE-15847).
- gpio: tegra: Properly handle irq_set_irq_wake() error (jsc#SLE-15847).
- gpio: tegra: Use generic readl_relaxed/writel_relaxed accessors (jsc#SLE-15847).
- memory: tegra: Consolidate registers definition into common header (jsc#SLE-15847).
- memory: tegra: Ensure timing control debug features are disabled (jsc#SLE-15847).
- memory: tegra: Introduce Tegra30 EMC driver (jsc#SLE-15847).
- memory: tegra: Add gr2d and gr3d to DRM IOMMU group (jsc#SLE-15847).
- soc/tegra: pmc: Remove unnecessary memory barrier (jsc#SLE-15847).
- soc/tegra: pmc: Query PCLK clock rate at probe time (jsc#SLE-15847).
- clk: tegra: Use match_string() helper to simplify the code (jsc#SLE-15847).
- pinctrl: ssbi-gpio: convert to hierarchical IRQ helpers in gpio core (jsc#SLE-15847).
- qcom: spmi-gpio: convert to hierarchical IRQ helpers in gpio core (jsc#SLE-15847).
- commit 88128be
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: ti: use snd_soc_xxx_active() (jsc#SLE-16518).
- ASoC: pxa: use snd_soc_xxx_active() (jsc#SLE-16518).
- ASoC: meson: use snd_soc_xxx_active() (jsc#SLE-16518).
- ASoC: mediatek: use snd_soc_xxx_active() (jsc#SLE-16518).
- ASoC: jz4740: use snd_soc_xxx_active() (jsc#SLE-16518).
- ASoC: intel: use snd_soc_xxx_active() (jsc#SLE-16518).
- ASoC: fsl: use snd_soc_xxx_active() (jsc#SLE-16518).
- ASoC: codecs: use snd_soc_xxx_active() (jsc#SLE-16518).
- ASoC: cirrus: use snd_soc_xxx_active() (jsc#SLE-16518).
- ASoC: bcm: use snd_soc_xxx_active() (jsc#SLE-16518).
- ASoC: atomel: use snd_soc_xxx_active() (jsc#SLE-16518).
- ASoC: use snd_soc_xxx_active() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_stream_active() (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_active()
  (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_active() (jsc#SLE-16518).
- ASoC: soc-dapm: use snd_soc_dai_activate()/deactivate()
  (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_action() (jsc#SLE-16518).
- ASoC: soc-pcm: replace snd_soc_runtime_activate()/deactivate()
  to macro (jsc#SLE-16518).
- ASoC: codecs: rt1308-sdw: remove duplicate allocation
  (jsc#SLE-16518).
- ASoC: codecs: rt*-sdw: fix memory leak in set_sdw_stream()
  (jsc#SLE-16518).
- ASoC: codecs: rt*-sdw: don't assign slave_ops (jsc#SLE-16518).
- ASoC: Intel: cht_bsw_nau8824: remap BTN_0 as KEY_PLAYPAUSE
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw_rt700: remap buttons (jsc#SLE-16518).
- ASoC: Intel: sof_sdw_rt711: remap buttons (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: fix typo in components string
  (jsc#SLE-16518).
- ASoC: Intel: soc-acpi: change machine driver name for WM8804
  platforms (jsc#SLE-16518).
- ASoC: da7213: move set_pll to codec level (jsc#SLE-16518).
- ASoC: da7213: move set_sysclk to codec level (jsc#SLE-16518).
- ASoC: da7213: Add regulator support (jsc#SLE-16518).
- ASoC: da7213: Add da7212 DT compatible (jsc#SLE-16518).
- ASoC: fsl_micfil: Fix unused assignment in
  fsl_set_clock_params() (jsc#SLE-16518).
- ASoC: amd: raven: Make the driver name consistent across files
  (jsc#SLE-16518).
- ASoC: fsl_micfil: Fix indentation to put on one line affected
  code (jsc#SLE-16518).
- ASoC: fsl_esai: introduce SoC specific data (jsc#SLE-16518).
- ASoC: tlv320adcx140: Configure PDM sampling edge
  (jsc#SLE-16518).
- ASoC: tlv320adcx140: Add controls for PDM clk (jsc#SLE-16518).
- ASoC: mmp-sspa: Set appropriate bus format for given bit width
  (jsc#SLE-16518).
- ASoC: mmp-sspa: Add support for the runtime power management
  (jsc#SLE-16518).
- ASoC: mmp-sspa: Prepare/unprepare the clocks (jsc#SLE-16518).
- commit 7a38a3d
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: mmp-sspa: Remove the embedded struct ssp_device
  (jsc#SLE-16518).
- ASoC: mmp-sspa: Add support for soc-generic-dmaengine-pcm
  (jsc#SLE-16518).
- ASoC: mmp-sspa: Get rid of dma_params and phys_base
  (jsc#SLE-16518).
- ASoC: mmp-sspa: A trivial typo fix (jsc#SLE-16518).
- ASoC: ti: omap-mcbsp: Fix an error handling path in
  'asoc_mcbsp_probe()' (jsc#SLE-16518).
- ASoC: Intel: Skylake: Update description for HDaudio kconfig
  (jsc#SLE-16518).
- ASoC: ux500: mop500: Fix some refcounted resources issues
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Replace zero-length array with
  flexible-array (jsc#SLE-16518).
- SoC: rsnd: add interrupt support for SSI BUSIF buffer
  (jsc#SLE-16518).
- ASoC: SOF: core: fix error return code in sof_probe_continue()
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: set headset button maps
  (jsc#SLE-16518).
- ASoC: soc-core: Replace zero-length array with flexible-array
  (jsc#SLE-16518).
- ASoC: SOF: Intel: Fix unused variable warning (jsc#SLE-16518).
- soc: fsl_asrc: Make some functions static (jsc#SLE-16518).
- ASoC: rt1016: Add the rt1016 support (jsc#SLE-16518).
- ASoC: rt5677: Use devm_snd_soc_register_component()
  (jsc#SLE-16518).
- ASoC: mediatek: Fix error handling (jsc#SLE-16518).
- ASoC: qcom: lpass-cpu: Make I2S SD lines configurable
  (jsc#SLE-16518).
- ASoC: wm8524: Add support S32_LE (jsc#SLE-16518).
- ASoC: meson: g12a: add toacodec dt-binding documentation
  (jsc#SLE-16518).
- commit d5ca0f3
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: Intel: boards: sof-wm8804: support for Hifiberry Digiplus
  boards (jsc#SLE-16518).
- Update config files.
- commit 444d0b9
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: qcom: Use the defined variable to simplify code
  (jsc#SLE-16518).
- ASoC: rt1015: Add condition to prevent SoC providing bclk in
  ratio of 50 times of sample rate (jsc#SLE-16518).
- ASoC: rl6231: Add the K bypass for the PLL parameters
  (jsc#SLE-16518).
- ASoC: SOF/Intel: clarify SPDX license with GPL-2.0-only
  (jsc#SLE-16518).
- ASoC: rt5682: remove unwanted btn_type assignment
  (jsc#SLE-16518).
- ASoC: rt5682: remove duplicate rt5682_reset() calls
  (jsc#SLE-16518).
- ASoC: rt5682: replace message printing from pr_() to dev_()
  (jsc#SLE-16518).
- ASoC: rt5682: remove empty default case (jsc#SLE-16518).
- ASoC: rt5682: fix space issues (jsc#SLE-16518).
- ASoC: rt5682: simplify assertions (jsc#SLE-16518).
- ASoC: SOF: Intel: change trigger sequence to fix pop noise
  when stopping playback on sdw platforms (jsc#SLE-16518).
- ASoC: SOF: topology: replace sof_link_hda_process by
  sof_set_dai_config (jsc#SLE-16518).
- ASoC: topology: set component dai_index to ipc dai config
  dai_index (jsc#SLE-16518).
- ASoC: SOF: topology: send ipc for all found DAIs in
  sof_set_dai_config (jsc#SLE-16518).
- ASoC: SOF: sort out Kconfig, again (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_compr_get_metadata()
  (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_compr_set_metadata()
  (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_compr_pointer() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_compr_ack() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_compr_get_params()
  (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_compr_set_params()
  (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_compr_trigger() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_compr_shutdown() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_compr_start() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_pcm_dai_remove() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_pcm_dai_probe() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_pcm_dai_bespoke_trigger()
  (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_pcm_dai_trigger() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_pcm_dai_prepare() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_pcm_dai_new() (jsc#SLE-16518).
- ASoC: soc-dai: don't overwide dai->driver->ops (jsc#SLE-16518).
- ASoC: soc-dai: add soc_dai_err() (jsc#SLE-16518).
- ASoC: rt5682: fix I2C/Soundwire dependencies (jsc#SLE-16518).
- ASoC: fsl_easrc: mark PM functions __maybe_unused
  (jsc#SLE-16518).
- ASoC: mxs-saif: Fix unused assignment (jsc#SLE-16518).
- ASoc: nau8810: add AUX related dapm widgets and routes
  (jsc#SLE-16518).
- ASoC: codecs: wm97xx: fix ac97 dependency (jsc#SLE-16518).
- ASoC: component: suppress uninitialized-variable warning
  (jsc#SLE-16518).
- ASoC: Intel: boards: add explicit dependency on GPIOLIB when
  DMIC is used (jsc#SLE-16518).
- commit a17ca1c
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: broadwell: add channel constraint (jsc#SLE-16518).
- ASoC: bdw-rt5650: add channel constraint (jsc#SLE-16518).
- ASoC: bdw-rt5677: add channel constraint (jsc#SLE-16518).
- ASoC: tegra: tegra_wm8903: Use devm_snd_soc_register_card()
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Automatic DMIC format configuration
  according to information from NHLT (jsc#SLE-16518).
- ASoC: Intel: Multiple I/O PCM format support for pipe
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Add alternative topology binary name
  (jsc#SLE-16518).
- ASoC: hisilicon: Use the defined variable to clean code
  (jsc#SLE-16518).
- ASoC: fsl_easrc: Check for null pointer before dereferencing
  "ctx" in fsl_easrc_hw_free() (jsc#SLE-16518).
- ASoC: ti: remove comparison to bool in
  omap_mcbsp_dai_set_dai_fmt() (jsc#SLE-16518).
- ASoC: mxs-saif: Avoid unnecessary check (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: add amp number in components string for
  ucm (jsc#SLE-16518).
- ASoC: hisilicon: Use IS_ERR() instead of IS_ERR_OR_NULL()
  (jsc#SLE-16518).
- ASoC: snd-sof-intel-hda-common - add hda_model parameter and
  pass it to HDA codec driver (jsc#SLE-16518).
- ASoC: soc-compress: avoid false-positive Wuninitialized warning
  (jsc#SLE-16518).
- ASoC: SOF: Add missing dependency on IMX_SCU (jsc#SLE-16518).
- ASoC: fsl_easrc: fix spelling mistake "prefitler" -> "prefilter"
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Replace guid_copy() with import_guid()
  (jsc#SLE-16518).
- ASoC: dmic: Allow GPIO operations to sleep (jsc#SLE-16518).
- ASoC: soc-core: return true, false in snd_soc_volsw_is_stereo()
  (jsc#SLE-16518).
- ASoC: SOF: Fix build (jsc#SLE-16518).
- ASoC: intel/skl/hda - fix oops on systems without i915 audio
  codec (jsc#SLE-16518).
- ASoC: fsl_easrc: Add EASRC ASoC CPU DAI drivers (jsc#SLE-16518).
- ASoC: fsl_asrc: Move common definition to fsl_asrc_common
  (jsc#SLE-16518).
- ASoC: fsl_asrc: Support new property fsl,asrc-format
  (jsc#SLE-16518).
- ASoC: fsl-asoc-card: Support new property fsl, asrc-format
  (jsc#SLE-16518).
- ASoC: fsl_asrc: rename asrc_priv to asrc (jsc#SLE-16518).
- ASoC: soc-compress: remove snd_compr_ops (jsc#SLE-16518).
- ASoC: sprd: use snd_compress_ops (jsc#SLE-16518).
- ASoC: sof: use snd_compress_ops (jsc#SLE-16518).
- commit 15d1ed9
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: intel: atom: use snd_compress_ops (jsc#SLE-16518).
- ASoC: qcom: q6sp6: use snd_compress_ops (jsc#SLE-16518).
- ASoC: uniphier: use snd_compress_ops (jsc#SLE-16518).
- ASoC: codec: wm_adsp: use snd_compress_ops (jsc#SLE-16518).
- ASoC: soc-compress: add snd_compress_ops (jsc#SLE-16518).
- ASoC: Add initial ZL38060 driver (jsc#SLE-16518).
- ASoC: wcd934x: remove unneeded semicolon (jsc#SLE-16518).
- ASoC: wcd9335: remove unneeded semicolon (jsc#SLE-16518).
- ASoC: wcd934x: remove unnecessary comparisons to bool
  (jsc#SLE-16518).
- ASoC: Intel: boards: split woofer and tweeter support
  (jsc#SLE-16518).
- soundwire: intel: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: Fix wrong dependency of da7210 and wm8983 (jsc#SLE-16518).
- ASoC: Intel: haswell: Power transition refactor (jsc#SLE-16518).
- ASoC: Fix misspellings of "Analog Devices" (jsc#SLE-16518).
- ASoC: SOF: topology: handle multiple sets of tuple arrays
  (jsc#SLE-16518).
- ASoC: SOF: topology: stop parsing when all tokens have been
  found (jsc#SLE-16518).
- ASoC: SOF: topology: Get HDA rate and channels from topology
  (jsc#SLE-16518).
- ASoC: SOF: topology: fix: parse hda_tokens to &config->hda
  (jsc#SLE-16518).
- ASoC: SOF: topology: Get ALH rate amd channels from topology
  (jsc#SLE-16518).
- commit 7b78773
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: SOF: align sof_ipc_dai_alh_params with FW (jsc#SLE-16518).
- ASoC: SOF: Intel: Rename deprecated DMIC IPC struct field
  (jsc#SLE-16518).
- ASoC: SOF: Intel: Change DMIC load IPC to fixed length
  (jsc#SLE-16518).
- ASoC: SOF: Intel: Fix typo in header file comment text
  (jsc#SLE-16518).
- ASoC: SOF: Add XRUN flags field to struct sof_ipc_buffer
  (jsc#SLE-16518).
- ASoC: SOF: make sof_ipc_cc_version to fixed length
  (jsc#SLE-16518).
- ASoC: SOF: change type char to uint8_t in topology.h
  (jsc#SLE-16518).
- ASoC: SOF: change type char to uint8_t in trace.h
  (jsc#SLE-16518).
- ASoC: SOF: change type char to uint8_t in info.h
  (jsc#SLE-16518).
- ASoC: SOF: add debug ABI version (jsc#SLE-16518).
- ASoC: SOF: add probe support extend data (jsc#SLE-16518).
- ASoC: SOF: topology: Add support for DC Blocker (jsc#SLE-16518).
- ASoC: SOF: ext_manifest: parse compiler version (jsc#SLE-16518).
- ASoC: SOF: ext_manifest: parse windows (jsc#SLE-16518).
- ASoC: SOF: ext_manifest: parse firmware version (jsc#SLE-16518).
- ASoC: SOF: Introduce extended manifest (jsc#SLE-16518).
- ASoC: SOF: Introduce offset in firmware data (jsc#SLE-16518).
- ASoC: SOF: Mark get_ext* function ext_hdr arguments as const
  (jsc#SLE-16518).
- ASoC: SOF: topology: fix: handle DAI widget connections properly
  with multiple CPU DAI's (jsc#SLE-16518).
- ASoC: SOF: Add i.MX8MP device descriptor (jsc#SLE-16518).
- ASoC: SOF: imx: Add i.MX8M HW support (jsc#SLE-16518).
- ASoC: SOF: imx: fix undefined reference issue (jsc#SLE-16518).
- ASoC: SOF: imx8: Fix randbuild error (jsc#SLE-16518).
- ASoC: topology: Remove unneeded semicolon (jsc#SLE-16518).
- ASoC: fsl_micfil: Omit superfluous error message in
  fsl_micfil_probe() (jsc#SLE-16518).
- ASoC: soc-core: Add dynamic debug logs in
  soc_dai_link_sanity_check() (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: log number of microphones detected in
  NHLT tables (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: reduce verbosity on SoundWire detection
  (jsc#SLE-16518).
- ASoC: codecs: rt1308-sdw: reduce verbosity (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: remove unnecessary parentheses
  (jsc#SLE-16518).
- ASoC: SOF: remove unneeded variables (jsc#SLE-16518).
- ASoC: tegra: tegra_wm8903: Support nvidia, headset property
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw_rt711: remove codec_dai use
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw_rt700: remove codec_dai use
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw_rt5682: remove codec_dai use
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw_rt1308: remove codec dai use
  (jsc#SLE-16518).
- ASoC: Intel: sof_sdw_hdmi: remove codec_dai use (jsc#SLE-16518).
- ASoC: Intel: sof_sdw_hdmi: fix compilation issue in fallback
  mode (jsc#SLE-16518).
- ASoC: Intel: sof-da7219-max98373: add DMIC widget and route
  (jsc#SLE-16518).
- commit d00bb7d
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: Intel: boards: support Elkhart Lake with rt5660
  (jsc#SLE-16518).
- Update config files.
- commit b347c2b
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: Intel: skl_hda_generic: remove rtd->codec_dai
  (jsc#SLE-16518).
- ASoC: intel: sof_sdw: init all aggregated codecs
  (jsc#SLE-16518).
- ASoC: SOF: Intel: add PCI ID for ElkhartLake (jsc#SLE-16518).
- ALSA: hda: Add ElkhartLake HDMI codec vid (jsc#SLE-16518).
- ASoC: intel/skl/hda - set autosuspend timeout for hda codecs
  (jsc#SLE-16518).
- ASoC: Intel: sof_da7219_max98373: Add BE dailink for dmic16k
  (jsc#SLE-16518).
- ASoC: soc-core: remove cpu_dai/codec_dai/cpu_dais/codec_dais
  (jsc#SLE-16518).
- ASoC: soc-core: tidyup soc_new_pcm_runtime() rtd setups
  (jsc#SLE-16518).
- ASoC: soc-core: set rtd->num_cpu/codec at soc_new_pcm_runtime()
  (jsc#SLE-16518).
- ASoC: soc: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- commit f074d66
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: wm8900: remove some defined but not used symbols
  (jsc#SLE-16518).
- ASoC: wm8990: remove some defined but unused symbols
  (jsc#SLE-16518).
- ASoC: wm8991: remove defined but not used
  'wm8991_dapm_rxvoice_controls' (jsc#SLE-16518).
- ASoC: wm8994: remove wm1811_snd_controls and mixin_boost_tlv
  (jsc#SLE-16518).
- ASoC: dapm: Move dai_link widgets to runtime to fix use after
  free (jsc#SLE-16518).
- ASoC: max9867: fix ADC level control (jsc#SLE-16518).
- ASoC: max9867: fix volume controls (jsc#SLE-16518).
- ASoC: tlv320adcx140: Fix bias config values (jsc#SLE-16518).
- ASoC: wm8962: Use force clear for WM8962_SYSCLK_ENA after reset
  (jsc#SLE-16518).
- ASoC: mmp-sspa: Drop S20_3LE case (jsc#SLE-16518).
- ASoC: mmp-sspa: Flip SNDRV_PCM_FMTBIT_S24_3LE on
  (jsc#SLE-16518).
- ASoC: Intel: Use readq to read 64 bit registers (jsc#SLE-16518).
- ASoC: Intel: baytrail: Fix register access (jsc#SLE-16518).
- ASoC: mediatek: mt8183: fix error handling of platform_get_irq()
  (jsc#SLE-16518).
- ASoC: amd :High hw_level while simultaneous capture
  (jsc#SLE-16518).
- ASoC: adau7118: Mark the ADAU7118 reset register as volatile
  (jsc#SLE-16518).
- ASoC: codecs: max9768: update contact email (jsc#SLE-16518).
- ASoC: max98373: reorder max98373_reset() in resume
  (jsc#SLE-16518).
- ASoC: SOF: Update correct LED status at the first time usage
  of update_mute_led() (jsc#SLE-16518).
- ASoC: Intel: broadwell: Fix oops during module removal
  (jsc#SLE-16518).
- ASoC: tlv320adcx140: Fix mic gain registers (jsc#SLE-16518).
- ASoC: davinci-mcasp: Fix dma_chan refcnt leak when getting
  dma type (jsc#SLE-16518).
- ASoC: fsl_esai: Disable exception interrupt before scheduling
  tasklet (jsc#SLE-16518).
- ASoC: wm8962: set CLOCKING2 as non-volatile register
  (jsc#SLE-16518).
- ASoC: tegra: Enable audio mclk during tegra_asoc_utils_init()
  (jsc#SLE-16518).
- ASoC: tegra: Add audio mclk parent configuration
  (jsc#SLE-16518).
- ASoC: tegra: Use device managed resource APIs to get the clock
  (jsc#SLE-16518).
- ALSA: usb-audio: Fixing usage of plain int instead of NULL
  (jsc#SLE-16518).
- ALSA: usb-audio: Clean up quirk entries with macros
  (jsc#SLE-16518).
- ALSA: firewire-motu: add support for MOTU UltraLite-mk3
  (FireWire only model) (jsc#SLE-16518).
- ALSA: firewire-motu: refactoring protocol v2 for fetching mode
  switch (jsc#SLE-16518).
- ALSA: firewire-motu: refactoring protocol v3 for clock source
  getter (jsc#SLE-16518).
- ALSA: firewire-motu: refactoring protocol v2 for clock source
  getter (jsc#SLE-16518).
- ALSA: firewire-motu: remove obsoleted codes (jsc#SLE-16518).
- ALSA: firewire-motu: use table-based calculation of packet
  formats for stream management (jsc#SLE-16518).
- ALSA: firewire-motu: use table-based calculation of packet
  formats for proc (jsc#SLE-16518).
- ALSA: firewire-motu: add alternative functions to detect packet
  format for protocol v3 (jsc#SLE-16518).
- ALSA: firewire-motu: add alternative functions to detect packet
  format for protocol v2 (jsc#SLE-16518).
- ALSA: firewire-motu: add model-specific table of chunk count
  (jsc#SLE-16518).
- ALSA: firewire-motu: drop protocol structure (jsc#SLE-16518).
- ALSA: firewire-motu: add wrapper functions for
  protocol-dependent operations (jsc#SLE-16518).
- ALSA: firewire-motu: localize protocol data (jsc#SLE-16518).
- ALSA: firewire-motu: move spec data to v3 protocol file
  (jsc#SLE-16518).
- ALSA: firewire-motu: move spec data to v2 protocol file
  (jsc#SLE-16518).
- ALSA: hda: Unexport some local helper functions (jsc#SLE-16518).
- ALSA: hda: Drop unused snd_hda_queue_unsol_event()
  (jsc#SLE-16518).
- ALSA: hda: Fix potential race in unsol event handler
  (jsc#SLE-16518).
- ALSA: usb-audio: Add duplex sound support for USB devices
  using implicit feedback (jsc#SLE-16518).
- ALSA: usb-audio: fixing upper volume limit for RME Babyface
  Pro routing crosspoints (jsc#SLE-16518).
- ALSA: firewire-motu: fulfill missing entries in Kconfig
  (jsc#SLE-16518).
- ALSA: fireface: add support for RME Fireface UFX (untested)
  (jsc#SLE-16518).
- ALSA: fireface: add support for RME FireFace 802
  (jsc#SLE-16518).
- ALSA: fireface: code refactoring to decide name of sound card
  (jsc#SLE-16518).
- ALSA: fireface: code refactoring to add enumeration constants
  for model identification (jsc#SLE-16518).
- ALSA: fireface: start IR context immediately (jsc#SLE-16518).
- ALSA: fireface: fix configuration error for nominal sampling
  transfer frequency (jsc#SLE-16518).
- ALSA: firewire-lib: use sequence of syt offset and data block
  on pool in AMDTP domain (jsc#SLE-16518).
- ALSA: firewire-lib: pool ideal sequence of syt offset and data
  block (jsc#SLE-16518).
- ALSA: firewire-lib: add cache for packet sequence to AMDTP
  domain structure (jsc#SLE-16518).
- ALSA: firewire-lib: code refactoring for data block calculation
  (jsc#SLE-16518).
- ALSA: firewire-lib: code refactoring for syt offset calculation
  (jsc#SLE-16518).
- ALSA: firewire-lib: code refactoring for syt computation
  (jsc#SLE-16518).
- ALSA: firewire-lib: code refactoring for parameters of packet
  queue and IRQ timing (jsc#SLE-16518).
- ALSA: firewire-lib: add reference to domain structure from
  stream structure (jsc#SLE-16518).
- ALSA: firewire-lib: use macro for maximum value of second in
  1394 OHCI isoc descriptor (jsc#SLE-16518).
- ALSA: firewire-lib: fix invalid assignment to union data for
  directional parameter (jsc#SLE-16518).
- ALSA: fireworks: Replace zero-length array with flexible-array
  (jsc#SLE-16518).
- ALSA: Replace zero-length array with flexible-array
  (jsc#SLE-16518).
- ALSA: hda: Allow SST driver on SKL and KBL platforms with DMIC
  (jsc#SLE-16518).
- ALSA: portman2x4: Use bitwise instead of arithmetic operator
  for flags (jsc#SLE-16518).
- commit fe87f07
* Mon Sep 28 2020 tiwai@suse.de
- ALSA: sound/ppc: Use bitwise instead of arithmetic operator
  for flags (jsc#SLE-16518).
- ALSA: hda: Return true,false for return type bool
  (jsc#SLE-16518).
- ALSA: hda: Use hdac_to_hda_codec macro (jsc#SLE-16518).
- ALSA: hda: Use dev_to_hdac_dev macro (jsc#SLE-16518).
- ALSA: hda/tegra: workaround playback failure on Tegra194
  (jsc#SLE-16518).
- ALSA: hda: add member to store ratio for stripe control
  (jsc#SLE-16518).
- ALSA: hda/tegra: correct number of SDO lines for Tegra194
  (jsc#SLE-16518).
- ALSA: line6: Add poll callback for hwdep (jsc#SLE-16518).
- ALSA: line6: hwdep: add support for O_NONBLOCK opening mode
  (jsc#SLE-16518).
- ALSA: isa/wavefront: prevent out of bounds write in ioctl
  (jsc#SLE-16518).
- ALSA: hda/realtek - Fix unused variable warning w/o
  CONFIG_LEDS_TRIGGER_AUDIO (jsc#SLE-16518).
- ALSA: hda/realtek - Add LED class support for micmute LED
  (jsc#SLE-16518).
- ALSA: hda/realtek - Enable micmute LED on and HP system
  (jsc#SLE-16518).
- ALSA: hda/realtek - Introduce polarity for micmute LED GPIO
  (jsc#SLE-16518).
- ALSA: seq: oss: remove unused inline function
  snd_seq_oss_timer_is_realtime (jsc#SLE-16518).
- ALSA: usb-audio: Fix racy list management in output queue
  (jsc#SLE-16518).
- ALSA: usb-audio: Remove async workaround for Scarlett 2nd gen
  (jsc#SLE-16518).
- ALSA: usb-audio: Improve frames size computation
  (jsc#SLE-16518).
- ALSA: hda: Refactor Intel NHLT init (jsc#SLE-16518).
- ALSA: oxygen: use true,false for bool variables (jsc#SLE-16518).
- ALSA: usb-audio: Fix a limit check in
  proc_dump_substream_formats() (jsc#SLE-16518).
- ALSA: usb-audio: Print more information in stream proc files
  (jsc#SLE-16518).
- ALSA: Fix misspellings of "Analog Devices" (jsc#SLE-16518).
- ALSA: usb-audio: RME Babyface Pro mixer patch (jsc#SLE-16518).
- ALSA: hda: add autodetection for SoundWire (jsc#SLE-16518).
- ASoC: txx9: add back the hack for a too small resource_size_t
  (jsc#SLE-16518).
- ASoC: txx9: don't work around too small resource_size_t
  (jsc#SLE-16518).
- pcm_native: result of put_user() needs to be checked
  (jsc#SLE-16518).
- ACPICA: Add NHLT table signature (jsc#SLE-16518).
- commit 7db3f22
* Mon Sep 28 2020 tiwai@suse.de
- Bluetooth: btrtl: Add support for RTL8761B (bsc#1177021).
- commit 6c51917
* Mon Sep 28 2020 tiwai@suse.de
- ALSA: hda/realtek - Add new codec supported for ALC287
  (jsc#SLE-16518).
- ALSA: usb-audio: Quirks for Gigabyte TRX40 Aorus Master onboard
  audio (jsc#SLE-16518).
- ALSA: usb-audio: mixer: volume quirk for ESS Technology Asus
  USB DAC (jsc#SLE-16518).
- ALSA: hda/realtek - Add a model for Thinkpad T570 without DAC
  workaround (jsc#SLE-16518).
- ALSA: hwdep: fix a left shifting 1 by 31 UB bug (jsc#SLE-16518).
- ALSA: hda/realtek - Add more fixup entries for Clevo machines
  (jsc#SLE-16518).
- ALSA: iec1712: Initialize STDSP24 properly when using the
  model=staudio option (jsc#SLE-16518).
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus
  Xtreme (jsc#SLE-16518).
- ALSA: pcm: fix incorrect hw_base increase (jsc#SLE-16518).
- ALSA: hda/realtek - Limit int mic boost for Thinkpad T530
  (jsc#SLE-16518).
- ALSA: hda/realtek - Add COEF workaround for ASUS ZenBook UX431DA
  (jsc#SLE-16518).
- ALSA: hda/realtek: Enable headset mic of ASUS UX581LV with
  ALC295 (jsc#SLE-16518).
- ALSA: hda/realtek - Enable headset mic of ASUS UX550GE with
  ALC295 (jsc#SLE-16518).
- ALSA: hda/realtek - Enable headset mic of ASUS GL503VM with
  ALC295 (jsc#SLE-16518).
- ALSA: hda/realtek: Add quirk for Samsung Notebook
  (jsc#SLE-16518).
- ALSA: rawmidi: Fix racy buffer resize under concurrent accesses
  (jsc#SLE-16518).
- ALSA: usb-audio: add mapping for ASRock TRX40 Creator
  (jsc#SLE-16518).
- ALSA: hda/realtek - Fix S3 pop noise on Dell Wyse
  (jsc#SLE-16518).
- Revert "ALSA: hda/realtek: Fix pop noise on ALC225"
  (jsc#SLE-16518).
- ALSA: firewire-lib: fix 'function sizeof not defined' error
  of tracepoints format (jsc#SLE-16518).
- ALSA: usb-audio: Add control message quirk delay for Kingston
  HyperX headset (jsc#SLE-16518).
- ALSA: usb-audio: Correct a typo of NuPrime DAC-10 USB ID
  (jsc#SLE-16518).
- ALSA: opti9xx: shut up gcc-10 range warning (jsc#SLE-16518).
- ALSA: hda/hdmi: fix without unlocked before return
  (jsc#SLE-16518).
- ALSA: hda/hdmi: fix race in monitor detection during probe
  (jsc#SLE-16518).
- ALSA: hda/realtek - Two front mics on a Lenovo ThinkCenter
  (jsc#SLE-16518).
- ALSA: line6: Fix POD HD500 audio playback (jsc#SLE-16518).
- ALSA: pcm: oss: Place the plugin buffer overflow checks
  correctly (for 5.7) (jsc#SLE-16518).
- ALSA: hda: Match both PCI ID and SSID for driver blacklist
  (jsc#SLE-16518).
- ALSA: hda: Always use jackpoll helper for jack update after
  resume (jsc#SLE-16518).
- ALSA: hda/realtek - Add new codec supported for ALC245
  (jsc#SLE-16518).
- ALSA: usb-audio: Fix usb audio refcnt leak when getting spdif
  (jsc#SLE-16518).
- ALSA: usb-audio: Add connector notifier delegation
  (jsc#SLE-16518).
- ASoC: wm8960: Fix wrong clock after suspend & resume
  (jsc#SLE-16518).
- ASoC: wm89xx: Add missing dependency (jsc#SLE-16518).
- ASoC: rsnd: Fix "status check failed" spam for multi-SSI
  (jsc#SLE-16518).
- ASoC: rsnd: Don't treat master SSI in multi SSI setup as parent
  (jsc#SLE-16518).
- ASoC: meson: gx-card: fix codec-to-codec link setup
  (jsc#SLE-16518).
- ASoC: meson: axg-card: fix codec-to-codec link setup
  (jsc#SLE-16518).
- ASoC: dapm: fixup dapm kcontrol widget (jsc#SLE-16518).
- ASoC: SOF: Intel: add min/max channels for SSP on
  Baytrail/Broadwell (jsc#SLE-16518).
- ASoC: stm32: sai: fix sai probe (jsc#SLE-16518).
- ASoC: rsnd: Fix HDMI channel mapping for multi-SSI mode
  (jsc#SLE-16518).
- ASoC: rsnd: Fix parent SSI start/stop in multi-SSI mode
  (jsc#SLE-16518).
- ASoC: codecs: hdac_hdmi: Fix incorrect use of
  list_for_each_entry (jsc#SLE-16518).
- ASoC: soc-dai: revert all changes to DAI startup/shutdown
  sequence (jsc#SLE-16518).
- ASoC: topology: Fix endianness issue (jsc#SLE-16518).
- ASoC: q6dsp6: q6afe-dai: add missing channels to MI2S DAIs
  (jsc#SLE-16518).
- ASoC: soc-pcm: dpcm: Only allow playback/capture if supported
  (jsc#SLE-16518).
- ASoC: sgtl5000: Fix VAG power-on handling (jsc#SLE-16518).
- ASoC: madera: Remove a couple of stray blank lines
  (jsc#SLE-16518).
- ASoC: wsa881x: mark read_only_wordlength flag (jsc#SLE-16518).
- ASoC: qcom: common: Silence duplicate parse error messages
  (jsc#SLE-16518).
- ASoC: dapm: Remove dapm_connect_dai_link_widgets helper
  (jsc#SLE-16518).
- commit 7336096
* Mon Sep 28 2020 tiwai@suse.de
- blacklist.conf: remove an ASoC entry to be backported
- commit 1177da5
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: dapm: Move error message to avoid some duplication
  (jsc#SLE-16518).
- ASoC: Intel: soc-acpi-intel-cml-match: remove useless
  'rt1308_2_adr' (jsc#SLE-16518).
- ASoC: intel: soc-acpi-intel-icl-match: remove useless
  'rt1308_2_adr' (jsc#SLE-16518).
- ASoC: amd: Fix button configuration (jsc#SLE-16518).
- ASoC: tas571x: disable regulators on failed probe
  (jsc#SLE-16518).
- ASoC: dapm: Fix regression introducing multiple copies of DAI
  widgets (jsc#SLE-16518).
- ASoC: samsung: s3c24xx-i2s: Fix build after removal of DAI
  suspend/resume (jsc#SLE-16518).
- ASoC: topology: Check return value of soc_tplg_dai_config
  (jsc#SLE-16518).
- ASoC: topology: Check return value of pcm_new_ver
  (jsc#SLE-16518).
- ASoC: topology: Check soc_tplg_add_route return value
  (jsc#SLE-16518).
- ASoC: topology: Check return value of soc_tplg_*_create
  (jsc#SLE-16518).
- ASoC: topology: Check return value of soc_tplg_create_tlv
  (jsc#SLE-16518).
- ASoC: topology: Add missing memory checks (jsc#SLE-16518).
- ALSA: usb-audio: Apply async workaround for Scarlett 2i4 2nd
  gen (jsc#SLE-16518).
- ALSA: usx2y: Fix potential NULL dereference (jsc#SLE-16518).
- ALSA: usb-audio: Add quirk for Focusrite Scarlett 2i2
  (jsc#SLE-16518).
- ALSA: usb-audio: Add static mapping table for ALC1220-VB-based
  mobos (jsc#SLE-16518).
- ALSA: hda: Remove ASUS ROG Zenith from the blacklist
  (jsc#SLE-16518).
- ALSA: hda/realtek - Fix unexpected init_amp override
  (jsc#SLE-16518).
- ALSA: usb-audio: Filter out unsupported sample rates on
  Focusrite devices (jsc#SLE-16518).
- ALSA: hda/hdmi: Add module option to disable audio component
  binding (jsc#SLE-16518).
- ALSA: hda: call runtime_allow() for all hda controllers
  (jsc#SLE-16518).
- ALSA: hda: Explicitly permit using autosuspend if runtime PM
  is supported (jsc#SLE-16518).
- ALSA: hda: Skip controller resume if not needed (jsc#SLE-16518).
- ALSA: hda: Keep the controller initialization even if no codecs
  found (jsc#SLE-16518).
- ALSA: hda: Release resources at error in delayed probe
  (jsc#SLE-16518).
- ALSA: hda: Honor PM disablement in PM freeze and thaw_noirq ops
  (jsc#SLE-16518).
- ALSA: hda: Don't release card at firmware loading error
  (jsc#SLE-16518).
- ALSA: usb-audio: Check mapping at creating connector controls,
  too (jsc#SLE-16518).
- ALSA: usb-audio: Don't create jack controls for PCM terminals
  (jsc#SLE-16518).
- ALSA: usb-audio: Don't override ignore_ctl_error value from
  the map (jsc#SLE-16518).
- ALSA: usb-audio: Filter error from connector kctl ops, too
  (jsc#SLE-16518).
- ALSA: hda/realtek - Enable the headset mic on Asus FX505DT
  (jsc#SLE-16518).
- ALSA: ctxfi: Remove unnecessary cast in kfree (jsc#SLE-16518).
- ASoC: cs4270: pull reset GPIO low then high (jsc#SLE-16518).
- ASoC: rt5645: Add platform-data for Medion E1239T
  (jsc#SLE-16518).
- ASoC: Intel: bytcr_rt5640: Add quirk for MPMAN MPWIN895CL tablet
  (jsc#SLE-16518).
- ASoC: stm32: sai: Add missing cleanup (jsc#SLE-16518).
- ASoC: Intel: atom: Fix uninitialized variable compiler warning
  (jsc#SLE-16518).
- ASoC: Intel: atom: Check drv->lock is locked in
  sst_fill_and_send_cmd_unlocked (jsc#SLE-16518).
- ASoC: Intel: atom: Take the drv->lock mutex before calling
  sst_send_slot_map() (jsc#SLE-16518).
- ASoC: SOF: Turn "firmware boot complete" message into a dbg
  message (jsc#SLE-16518).
- ASoC: topology: use name_prefix for new kcontrol
  (jsc#SLE-16518).
- ASoC: rt5682: Fix build error without CONFIG_I2C
  (jsc#SLE-16518).
- ASoC: dpcm: allow start or stop during pause for backend
  (jsc#SLE-16518).
- ASoC: dapm: connect virtual mux with default value
  (jsc#SLE-16518).
- ASoC: qcom: q6asm-dai: Add SNDRV_PCM_INFO_BATCH flag
  (jsc#SLE-16518).
- ASoC: Intel: bdw-rt5650: Remove ignore_suspend flag from SSP0
  dai link (jsc#SLE-16518).
- ASoC: Intel: bdw-rt5677: Remove ignore_suspend flag from SSP0
  dai link (jsc#SLE-16518).
- commit 03d3d71
* Mon Sep 28 2020 tbogendoerfer@suse.de
- net: sched: initialize with 0 before setting erspan md->u
  (bsc#1154353).
- debugfs: Fix module state check condition (bsc#1173746).
- RDMA/siw: Suppress uninitialized var warning (jsc#SLE-8381).
- commit 97c7a55
* Mon Sep 28 2020 tiwai@suse.de
- dmaengine: Add support for reporting DMA cached data amount
  (jsc#SLE-16518).
- commit 9f20355
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: Intel: haswell: Remove ignore_suspend flag from SSP0
  dai link (jsc#SLE-16518).
- ASoC: Intel: broadwell: Remove ignore_suspend flag from SSP0
  dai link (jsc#SLE-16518).
- ASoC: soc-dai: fix DAI startup/shutdown sequence
  (jsc#SLE-16518).
- ASoC: fix regwmask (jsc#SLE-16518).
- ASoC: AMD: Clear format bits before setting them
  (jsc#SLE-16518).
- ASoC: bcm: Fix pointer cast warning (jsc#SLE-16518).
- ALSA: hda: Add driver blacklist (jsc#SLE-16518).
- ALSA: usb-audio: Add mixer workaround for TRX40 and co
  (jsc#SLE-16518).
- ALSA: hda/realtek - Add quirk for MSI GL63 (jsc#SLE-16518).
- ALSA: ice1724: Fix invalid access for enumerated ctl items
  (jsc#SLE-16518).
- commit a229968
* Mon Sep 28 2020 tiwai@suse.de
- ALSA: hda: Fix potential access overflow in beep helper
  (jsc#SLE-16518).
- ALSA: hda/realtek - Add HP new mute led supported for ALC236
  (jsc#SLE-16518).
- ALSA: hda/realtek - Add supported new mute Led for HP
  (jsc#SLE-16518).
- ALSA: usb-audio: Add registration quirk for Kingston HyperX
  Cloud Alpha S (jsc#SLE-16518).
- ALSA: usb-audio: Add Pioneer DJ DJM-250MK2 quirk
  (jsc#SLE-16518).
- ALSA: pcm: oss: Fix regression by buffer overflow fix (again)
  (jsc#SLE-16518).
- ALSA: hda/realtek - Add quirk for Lenovo Carbon X1 8th gen
  (jsc#SLE-16518).
- soundwire: qcom: add support for get_sdw_stream()
  (jsc#SLE-16518).
- soundwire: cadence: clear FIFO to avoid pop noise issue on
  playback start (jsc#SLE-16518).
- soundwire: cadence: multi-link support (jsc#SLE-16518).
- soundwire: cadence: commit changes in the exit_reset() sequence
  (jsc#SLE-16518).
- soundwire: cadence: remove automatic command retries
  (jsc#SLE-16518).
- soundwire: cadence: remove PREQ_DELAY assignment
  (jsc#SLE-16518).
- soundwire: cadence: enable NORMAL operation in cdns_init()
  (jsc#SLE-16518).
- soundwire: cadence: reorder MCP_CONFIG settings (jsc#SLE-16518).
- soundwire: cadence: make SSP interval programmable
  (jsc#SLE-16518).
- soundwire: cadence: move clock/SSP related inits to dedicated
  function (jsc#SLE-16518).
- soundwire: cadence: merge routines to clear/set bits
  (jsc#SLE-16518).
- soundwire: cadence: mask Slave interrupt before stopping clock
  (jsc#SLE-16518).
- soundwire: cadence: fix a io timeout issue in S3 test
  (jsc#SLE-16518).
- soundwire: cadence: add clock_stop/restart routines
  (jsc#SLE-16518).
- soundwire: cadence: handle error cases with CONFIG_UPDATE
  (jsc#SLE-16518).
- soundwire: cadence: add interface to check clock status
  (jsc#SLE-16518).
- soundwire: cadence: simplifiy cdns_init() (jsc#SLE-16518).
- soundwire: cadence: s/update_config/config_update
  (jsc#SLE-16518).
- soundwire: stream: use sdw_write instead of update
  (jsc#SLE-16518).
- soundwire: bus: provide correct return value on error
  (jsc#SLE-16518).
- soundwire: add helper macros for devID fields (jsc#SLE-16518).
- soundwire: cadence: remove useless prototypes (jsc#SLE-16518).
- soundwire: bus: don't treat CMD_IGNORED as error on ClockStop
  (jsc#SLE-16518).
- soundwire: bus: add clock stop helpers (jsc#SLE-16518).
- soundwire: bus: fix io error when processing alert event
  (jsc#SLE-16518).
- soundwire: bus: disable pm_runtime in sdw_slave_delete
  (jsc#SLE-16518).
- soundwire: bus: add helper to clear Slave status to UNATTACHED
  (jsc#SLE-16518).
- soundwire: bus: write Slave Device Number without runtime_pm
  (jsc#SLE-16518).
- soundwire: bus: add PM/no-PM versions of read/write functions
  (jsc#SLE-16518).
- soundwire: bus: fix race condition with initialization_complete
  signaling (jsc#SLE-16518).
- soundwire: bus: fix race condition with enumeration_complete
  signaling (jsc#SLE-16518).
- soundwire: bus: fix race condition with probe_complete signaling
  (jsc#SLE-16518).
- soundwire: intel: free all resources on hw_free()
  (jsc#SLE-16518).
- soundwire: intel: add sdw_stream_setup helper for .startup
  callback (jsc#SLE-16518).
- soundwire: intel: add trigger support in sdw dai driver
  (jsc#SLE-16518).
- soundwire: intel: add prepare support in sdw dai driver
  (jsc#SLE-16518).
- soundwire: intel: rename res field as link_res (jsc#SLE-16518).
- soundwire: stream: don't program ports when a stream that has
  not been prepared (jsc#SLE-16518).
- soundwire: stream: fix support for multiple Slaves on the same
  link (jsc#SLE-16518).
- soundwire: stream: do not update parameters during
  DISABLED-PREPARED transition (jsc#SLE-16518).
- soundwire: stream: only prepare stream when it is configured
  (jsc#SLE-16518).
- soundwire: stream: update state machine and add state checks
  (jsc#SLE-16518).
- commit 4cdcd92
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: Intel: boards: add sof_sdw machine driver (jsc#SLE-16518).
- Update config files.
- commit 89620c3
* Mon Sep 28 2020 tiwai@suse.de
- ALSA: usb-audio: Fix case when USB MIDI interface has more
  than one extra endpoint descriptor (jsc#SLE-16518).
- Revert "ALSA: uapi: Drop asound.h inclusion from asoc.h"
  (jsc#SLE-16518).
- ALSA: hda/realtek - Remove now-unnecessary XPS 13 headphone
  noise fixups (jsc#SLE-16518).
- ALSA: hda/realtek - Set principled PC Beep configuration for
  ALC256 (jsc#SLE-16518).
- ASoC: Intel: sof_sdw: Add Volteer support with RT5682 SNDW
  helper function (jsc#SLE-16518).
- ASoC: Intel: common: add match table for TGL RT5682 SoundWire
  driver (jsc#SLE-16518).
- ASoC: Intel: soc-acpi: update topology and driver name for
  SoundWire platforms (jsc#SLE-16518).
- ASoC: amd: acp3x-pcm-dma: clean up two indentation issues
  (jsc#SLE-16518).
- ASoC: codecs: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: arm: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: xtensa: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: ux500: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: uniphier: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: txx9: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: ti: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: tegra: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: sunxi: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: stm: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: sprd: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: sof: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: sh: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: samsung: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: rockchip: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: qcom: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: pxa: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: mxs: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: meson: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: mediatek: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: kirkwood: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: intel: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: img: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: generic: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: fsl: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: dwc: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: cirrus: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: bcm: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: au1x: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- commit 8ef84d7
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: atmel: use asoc_rtd_to_cpu() / asoc_rtd_to_codec()
  macro for DAI pointer (jsc#SLE-16518).
- ASoC: amd: use asoc_rtd_to_cpu() / asoc_rtd_to_codec() macro
  for DAI pointer (jsc#SLE-16518).
- ASoC: soc-core: add asoc_rtd_to_cpu/codec() macro
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda-ctrl: add reset cycle before parsing
  capabilities (jsc#SLE-16518).
- Asoc: SOF: Intel: hda: check SoundWire wakeen interrupt in
  irq thread (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: add WAKEEN interrupt support for
  SoundWire (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: add parameter to control SoundWire
  clock stop quirks (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: merge IPC, stream and SoundWire interrupt
  handlers (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: disable SoundWire interrupts on suspend
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: initial SoundWire machine driver
  autodetect (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: add SoundWire stream config/free
  callbacks (jsc#SLE-16518).
- ASoC: SOF: IPC: dai-intel: move ALH declarations in header file
  (jsc#SLE-16518).
- ASoC: SOF: Intel: add SoundWire configuration interface
  (jsc#SLE-16518).
- ASoC: soc-acpi: expand description of _ADR-based devices
  (jsc#SLE-16518).
- ASoC: rt5682: move DAI clock registry to I2S mode
  (jsc#SLE-16518).
- ASoC: pxa: magician: convert to use i2c_new_client_device()
  (jsc#SLE-16518).
- ASoC: rt1308-sdw: use slot and rx_mask to configure stream
  (jsc#SLE-16518).
- ASoC: rt1308-sdw: add set_tdm_slot() support (jsc#SLE-16518).
- ASoC: Intel: common: Add mach table for tgl-max98373-rt5682
  (jsc#SLE-16518).
- ASoC: Intel: sof_rt5682: Add support for tgl-max98373-rt5682
  (jsc#SLE-16518).
- ASoC: intel: sof_da7219_max98373: Add speaker switch
  (jsc#SLE-16518).
- ASoC: Intel: Make glk+rt5682 echo ref dynamic (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: call codec wake at chip init
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: do not leave clock gating off upon error
  (jsc#SLE-16518).
- ASoC: SOF: fix uninitialised "work" with VirtIO (jsc#SLE-16518).
- ASoC: SOF: (cosmetic) use for_each_pcm_streams() in
  sof_dai_load() (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Improve DSP state logging
  (jsc#SLE-16518).
- ASoC: pxa: Enable AC'97 bus support for PXA machines
  (jsc#SLE-16518).
- ASoC: pxa: Select regmap from AC'97 machines (jsc#SLE-16518).
- ASoC: mchp-i2s-mcc: make signed 1 bit bitfields unsigned
  (jsc#SLE-16518).
- ASoC: jz4740-i2s: Add support for the JZ4770 (jsc#SLE-16518).
- ASoC: jz4740-i2s: Add support for the JZ4760 (jsc#SLE-16518).
- ASoC: wm8974: remove unused variables (jsc#SLE-16518).
- ASoC: tegra: tegra_wm8903: Support DAPM events for built-in
  microphone (jsc#SLE-16518).
- ASoC: rt5682: Add a property for DMIC delay (jsc#SLE-16518).
- ASoC: rt5682: Add a property for DMIC clock rate
  (jsc#SLE-16518).
- ASoC: MT6660: make spdxcheck.py happy (jsc#SLE-16518).
- ASoC: soc-core: Merge CPU/Codec for soc_dai_pcm_new()
  (jsc#SLE-16518).
- ASoC: soc-pcm: Merge for_each_rtd_cpu/codec_dais()
  (jsc#SLE-16518).
- ASoC: soc-dapm: Merge for_each_rtd_cpu/codec_dais()
  (jsc#SLE-16518).
- ASoC: soc-core: Merge for_each_rtd_cpu/codec_dais()
  (jsc#SLE-16518).
- ASoC: soc-core: Merge CPU/Codec DAIs (jsc#SLE-16518).
- soundwire: stream: Add read_only_wordlength flag to port
  properties (jsc#SLE-16518).
- ASoC: stm32: i2s: manage rebind issue (jsc#SLE-16518).
- ASoC: stm32: spdifrx: manage rebind issue (jsc#SLE-16518).
- ASoC: qcom: sdm845: handle soundwire stream (jsc#SLE-16518).
- ASoC: codecs: wsa881x: remove soundwire stream handling
  (jsc#SLE-16518).
- ASoC: rt5682: remove noisy debug messages (jsc#SLE-16518).
- ALSA: compress: bump the version (jsc#SLE-16518).
- ASoC: qcom: q6asm-dai: add support for ALAC and APE decoders
  (jsc#SLE-16518).
- commit e824e56
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: qcom: q6asm: add support for alac and ape configs
  (jsc#SLE-16518).
- ALSA: compress: add alac & ape decoder params (jsc#SLE-16518).
- ASoC: qcom: q6asm-dai: add support to wma decoder
  (jsc#SLE-16518).
- ASoC: qcom: q6asm: add support to wma config (jsc#SLE-16518).
- ASoC: qcom: q6asm: pass codec profile to q6asm_open_write
  (jsc#SLE-16518).
- ALSA: compress: Add wma decoder params (jsc#SLE-16518).
- ALSA: compress: add wma codec profiles (jsc#SLE-16518).
- ASoC: soc-dai: return proper error for get_sdw_stream()
  (jsc#SLE-16518).
- ASoC: SOF: topology: connect dai widget to all cpu-dais
  (jsc#SLE-16518).
- ASoC: SOF: Intel: remove unnecessary waitq before loading
  firmware (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: remove unnecessary ROM IPC filter
  function (jsc#SLE-16518).
- ASoC: SOF: Remove SOF_IPC_EXT_DMA_BUFFER (jsc#SLE-16518).
- ASoC: SOF: Make sof_ipc_ext_data enum more rigid
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda-dai: add stream capability
  (jsc#SLE-16518).
- ASoC: Intel: don't use GFP_ATOMIC for machine driver contexts
  (jsc#SLE-16518).
- ASoC: Intel: sof_rt5682: Add rt1015 speaker amp support
  (jsc#SLE-16518).
- ASoC: Intel: sof_da7219_max98373: Add support for max98360a
  speaker amp (jsc#SLE-16518).
- ASoC: Intel: (cosmetic) simplify structure member access
  (jsc#SLE-16518).
- ASoC: Intel: skylake: (cosmetic) remove redundant variable
  initialisations (jsc#SLE-16518).
- ASoC: codecs: hdac_hdmi: (cosmetic) remove redundant variable
  initialisations (jsc#SLE-16518).
- commit a61dec4
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: SOF: Intel: hda: remove SND_SOC_SOF_HDA_COMMON_HDMI_CODEC
  (jsc#SLE-16518).
- Update config files.
- commit 274913b
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: Intel: sof_pcm512x: make HDMI optional for all platforms
  (jsc#SLE-16518).
- ASoC: Intel: sof_pcm512x: drop reverse deps for
  SND_HDA_CODEC_HDMI (jsc#SLE-16518).
- ASoC: Intel: boards: drop reverse deps for SND_HDA_CODEC_HDMI
  (jsc#SLE-16518).
- ASoC: brcm: Add DSL/PON SoC audio driver (jsc#SLE-16518).
- ASoC: rt5682: Fine tune the HP performance in soundwire mode
  (jsc#SLE-16518).
- ASoC: export DPCM runtime update functions (jsc#SLE-16518).
- ASoC: (cosmetic) simplify dpcm_prune_paths() (jsc#SLE-16518).
- ASoC: zte: zx-tdm: remove redundant variables dev
  (jsc#SLE-16518).
- ASoC: rt5682-sdw: fix 'defined but not used' pm functions
  (jsc#SLE-16518).
- ASoC: rt5682: fix unmet dependencies (jsc#SLE-16518).
- ASoC: pcm: Fix (again) possible buffer overflow in dpcm state
  sysfs output (jsc#SLE-16518).
- ASoC: soc-dapm: add for_each_card_widgets() macro
  (jsc#SLE-16518).
- ASoC: soc-dapm: add for_each_card_dapms() macro (jsc#SLE-16518).
- ASoC: soc.h: remove non plural form for_each_xxx macro
  (jsc#SLE-16518).
- ASoC: soc: use for_each_rtd_codecs/cpus_dai() macro
  (jsc#SLE-16518).
- ASoC: qcom: use for_each_rtd_codecs/cpus_dai() macro
  (jsc#SLE-16518).
- ASoC: meson: use for_each_rtd_codecs/cpus_dai() macro
  (jsc#SLE-16518).
- ASoC: mediatek: use for_each_rtd_codecs/cpus_dai() macro
  (jsc#SLE-16518).
- ASoC: Intel: use for_each_rtd_codecs/cpus_dai() macro
  (jsc#SLE-16518).
- ASoC: soc.h: add for_each_rtd_codecs/cpus_dai() macro
  (jsc#SLE-16518).
- ASoC: SOF: Fix probe point getter (jsc#SLE-16518).
- ASoC: jz4740-i2s: Avoid passing enum as match data
  (jsc#SLE-16518).
- ASoC: jz4740-i2s: Add local dev variable in probe function
  (jsc#SLE-16518).
- ASoC: amd: Adding TDM support in hw_params (jsc#SLE-16518).
- ASoC: simple-card-utils: use for_each_pcm_streams()
  (jsc#SLE-16518).
- ASoC: soc-pcm: Do Digital Mute for both CPU/Codec in same timing
  (jsc#SLE-16518).
- ASoC: soc-pcm: check DAI's activity more simply (jsc#SLE-16518).
- ASoC: soc-pcm: tidyup dulicate handing at dpcm_fe_dai_startup()
  (jsc#SLE-16518).
- ASoC: soc-pcm: use snd_soc_dai_get_pcm_stream() at
  dpcm_set_fe_runtime() (jsc#SLE-16518).
- commit bedc48b
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: soc-pcm: add dpcm_fe_dai_cleanup() (jsc#SLE-16518).
- ASoC: soc-pcm: move dpcm_fe_dai_close() (jsc#SLE-16518).
- ASoC: simple-card: Add support for codec2codec DAI links
  (jsc#SLE-16518).
- ASoC: pcm: Export parameter intersection logic (jsc#SLE-16518).
- ALSA: pcm: Add a standalone version of snd_pcm_limit_hw_rates
  (jsc#SLE-16518).
- ASoC: wcd934x: remove unused headers (jsc#SLE-16518).
- ASoC: wcd934x: fix High Accuracy Buck enable (jsc#SLE-16518).
- ALSA: dmaengine_pcm: No need to take runtime reference twice
  in pcm_pointer (jsc#SLE-16518).
- ASoC: soc-pcm: remove duplicate be check from dpcm_add_paths()
  (jsc#SLE-16518).
- ASoC: soc-pcm: use defined stream (jsc#SLE-16518).
- ASoC: sprd: Allow the MCDT driver to build into modules
  (jsc#SLE-16518).
- ASoC: tlv320adcx140: Fix mic_bias and vref device tree
  verification (jsc#SLE-16518).
- ASoc: amd: acp3x: Add missing include <linux/io.h>
  (jsc#SLE-16518).
- ASoC: amd: Fix compile warning of argument type (jsc#SLE-16518).
- ASoC: amd: AMD RV RT5682 should depends on CROS_EC
  (jsc#SLE-16518).
- ASoC: SOF: add core id to sof_ipc_comp (jsc#SLE-16518).
- ASoC: SOF: Intel: hda-loader: clear the IPC ack bit after
  FW_PURGE done (jsc#SLE-16518).
- ASoC: SOF: ipc: check ipc return value before data copy
  (jsc#SLE-16518).
- ASoC: SOF: pcm: skip DMA buffer pre-allocation (jsc#SLE-16518).
- ASoC: rt1015: set snd_soc_dai_ops in rt1015_dai driver
  (jsc#SLE-16518).
- ASoc: amd: Add DMIC switch capability to machine driver
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: use snd_sof_dsp_set_power_state() op
  (jsc#SLE-16518).
- ASoC: zte: zx-spdif: remove redundant dev_err message
  (jsc#SLE-16518).
- ASoC: soc-dapm: don't use rtd->cpu_dai on for_each_rtd_cpu_dai()
  (jsc#SLE-16518).
- ASoC: samsung: Silence warnings during deferred probe
  (jsc#SLE-16518).
- ASoC: rt5682: Make rt5682_clock_config static (jsc#SLE-16518).
- ASoC: rt1015: modify some structure to be static
  (jsc#SLE-16518).
- ASoC: pcm: check if cpu-dai supports a given stream
  (jsc#SLE-16518).
- ASoC: Return error if the function does not support multi-cpu
  (jsc#SLE-16518).
- ASoC: Add multiple CPU DAI support in DAPM (jsc#SLE-16518).
- commit 7720f7d
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: rt5682: Add the soundwire support (jsc#SLE-16518).
- Update config files.
- commit 175a8f8
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: amd: Add machine driver for Raven based platform
  (jsc#SLE-16518).
- Update config files.
- commit af681ec
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: Add dapm_add_valid_dai_widget helper (jsc#SLE-16518).
- ASoC: Add multiple CPU DAI support for PCM ops (jsc#SLE-16518).
- ASoC: Add initial support for multiple CPU DAIs (jsc#SLE-16518).
- ASoC: soc-dai: add get_sdw_stream() callback (jsc#SLE-16518).
- ASoC: tas2562: Add entries for the TAS2563 audio amplifier
  (jsc#SLE-16518).
- ASoC: amd: Allow I2S wake event after ACP is powerd On
  (jsc#SLE-16518).
- ASoC: rt5682: Revise the function name (jsc#SLE-16518).
- ASoC: Intel: mrfld: fix incorrect check on p->sink
  (jsc#SLE-16518).
- ASoC: soc-pcm: add dpcm_create/remove_debugfs_state()
  (jsc#SLE-16518).
- ASoC: soc-pcm: move CONFIG_DEBUG_FS functions to top side
  (jsc#SLE-16518).
- ASoC: soc-pcm: move dpcm_path_put() to soc-pcm.c
  (jsc#SLE-16518).
- ASoC: soc-pcm: merge dpcm_run_new/old_update() into
  dpcm_fe_runtime_update() (jsc#SLE-16518).
- ASoC: soc-pcm: add snd_soc_dai_get_widget() (jsc#SLE-16518).
- ASoC: soc-pcm: cleanup soc_pcm_apply_msb() (jsc#SLE-16518).
- ASoC: soc-pcm: add snd_soc_dai_get_pcm_stream() (jsc#SLE-16518).
- ASoC: soc-pcm: fix state tracking error in
  snd_soc_component_open/close() (jsc#SLE-16518).
- ASoC: meson: aiu: fix semicolon.cocci warnings (jsc#SLE-16518).
- ASoC: Fix SND_SOC_ALL_CODECS imply ac97 fallout (jsc#SLE-16518).
- commit 1e840ca
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: meson: g12a: add internal DAC glue driver (jsc#SLE-16518).
- Update config files.
- commit f1ea609
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: tlv320adcx140: Add decimation filter support
  (jsc#SLE-16518).
- ASoC: tlv320adcx140: Add DRE and AGC support (jsc#SLE-16518).
- ASoC: meson: axg-card: add toacodec support (jsc#SLE-16518).
- ASoC: tas2562: Add support for digital volume control
  (jsc#SLE-16518).
- ASoC: sun8i-codec: Remove unused dev from codec struct
  (jsc#SLE-16518).
- ASoC: meson: aiu: add support for the Meson8 and Meson8b SoC
  families (jsc#SLE-16518).
- ASoC: meson: aiu: introduce a struct for platform specific
  information (jsc#SLE-16518).
- ASoC: tlv320adcx140: Add the tlv320adcx140 codec driver family
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: allow operation without i915 gfx
  (jsc#SLE-16518).
- commit e6d7852
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: meson: add t9015 internal DAC driver (jsc#SLE-16518).
- Update config files.
- commit 9afb673
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: intel/skl/hda - add no-HDMI cases to generic HDA driver
  (jsc#SLE-16518).
- ASoC: samsung: Update dependencies for Arizona machine drivers
  (jsc#SLE-16518).
- ASoC: dpcm: remove confusing trace in dpcm_get_be()
  (jsc#SLE-16518).
- ASoC: rockchip: Make RK3328 GPIO_MUTE control explicit
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219-max98357: use
  for_each_rtd_codec_dai() macro (jsc#SLE-16518).
- ASoC: intel: kbl_da7219_max98927: use for_each_rtd_codec_dai()
  macro (jsc#SLE-16518).
- ASoC: intel: cml_rt1011_rt5682: use for_each_rtd_codec_dai()
  macro (jsc#SLE-16518).
- ASoC: qcom: apq8016_sbc: use for_each_rtd_codec_dai() macro
  (jsc#SLE-16518).
- ASoC: qcom: sdm845: use for_each_rtd_codec_dai() macro
  (jsc#SLE-16518).
- ASoC: soundwaire: qcom: use for_each_rtd_codec_dai() macro
  (jsc#SLE-16518).
- ASoC: tas2562: Add support for ISENSE and VSENSE
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: use SND_SOC_DAPM_PINCTRL in
  TDM out (jsc#SLE-16518).
- ASoC: dapm: select sleep_state when initializing PINCTRL widget
  (jsc#SLE-16518).
- ASoC: fix card registration regression (jsc#SLE-16518).
- ASoC: MT6660 update to 1.0.8_G (jsc#SLE-16518).
- ALSA: usx2y: use for_each_pcm_streams() macro (jsc#SLE-16518).
- ASoC: sof: sof-audio: use for_each_pcm_streams() macro
  (jsc#SLE-16518).
- ASoC: qcom: lpass-platform: use for_each_pcm_streams() macro
  (jsc#SLE-16518).
- ASoC: fsl: fsl_asrc_dma: use for_each_pcm_streams() macro
  (jsc#SLE-16518).
- ASoC: dwc: dwc-i2s: use for_each_pcm_streams() macro
  (jsc#SLE-16518).
- ASoC: soc-generic-dmaengine-pcm: use for_each_pcm_streams()
  macro (jsc#SLE-16518).
- ASoC: soc-pcm: use for_each_pcm_streams() macro (jsc#SLE-16518).
- ASoC: soc-core: use for_each_pcm_streams() macro
  (jsc#SLE-16518).
- ALSA: pcm.h: add for_each_pcm_streams() (jsc#SLE-16518).
- ASoC: soc-pcm: merge playback/cature_active into stream_active
  (jsc#SLE-16518).
- ASoC: soc-pcm: use goto and remove multi return (jsc#SLE-16518).
- ASoC: soc-pcm: add snd_soc_dpcm_can_be() and remove duplicate
  code (jsc#SLE-16518).
- ASoC: soc-pcm: remove snd_soc_dpcm_be_get/set_state()
  (jsc#SLE-16518).
- ASoC: soc-pcm: remove soc_dpcm_be_digital_mute()
  (jsc#SLE-16518).
- ASoC: soc-pcm: use dpcm_get_be() at dpcm_end_walk_at_be()
  (jsc#SLE-16518).
- ASoC: soc-pcm: use dai_get_widget() at dpcm_end_walk_at_be()
  (jsc#SLE-16518).
- ASoC: soc-pcm: use dai_get_widget() at dpcm_get_be()
  (jsc#SLE-16518).
- ASoC: soc-pcm: move dai_get_widget() (jsc#SLE-16518).
- ASoC: rt5682: Add CCF usage for providing I2S clks
  (jsc#SLE-16518).
- ASoC: SOF: Intel: Add Probe compress CPU DAIs (jsc#SLE-16518).
- ASoC: SOF: Provide probe debugfs support (jsc#SLE-16518).
- ASoC: SOF: Intel: Probe compress operations (jsc#SLE-16518).
- ASoC: SOF: Intel: Expose SDnFMT helpers (jsc#SLE-16518).
- ASoC: SOF: Generic probe compress operations (jsc#SLE-16518).
- commit 8352892
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: SOF: Implement Probe IPC API (jsc#SLE-16518).
- Update config files.
- commit 3798bde
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: SOF: Intel: Account for compress streams when servicing
  IRQs (jsc#SLE-16518).
- ALSA: core: Implement compress page allocation and free routines
  (jsc#SLE-16518).
- ALSA: core: Expand DMA buffer information (jsc#SLE-16518).
- ASoC: soc-pcm: fix regression in soc_new_pcm() (jsc#SLE-16518).
- ASoC: meson: aiu: simplify component addition (jsc#SLE-16518).
- ASoC: rt1015: fix typo for bypass boost control (jsc#SLE-16518).
- ASoC: meson: codec-glue: fix pcm format cast warning
  (jsc#SLE-16518).
- ASoC: meson: aiu: fix acodec dai input name init
  (jsc#SLE-16518).
- ASoC: meson: aiu: fix irq registration (jsc#SLE-16518).
- commit e4473f3
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: meson: gx: add sound card support (jsc#SLE-16518).
- Update config files.
- commit 7dd4968
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: meson: aiu: fix clk bulk size allocation (jsc#SLE-16518).
- ASoC: meson: aiu: remove unused encoder structure
  (jsc#SLE-16518).
- ASoC: core: ensure component names are unique (jsc#SLE-16518).
- ASoC: meson: axg: extract sound card utils (jsc#SLE-16518).
- ASoC: meson: aiu: add internal dac codec control support
  (jsc#SLE-16518).
- ASoC: meson: aiu: add hdmi codec control support
  (jsc#SLE-16518).
- ASoC: meson: aiu: add i2s and spdif support (jsc#SLE-16518).
- ASoC: meson: g12a: extract codec-to-codec utils (jsc#SLE-16518).
- ASoC: core: allow a dt node to provide several components
  (jsc#SLE-16518).
- ASoC: rt5682: Enable PLL2 function (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: apply some refactors
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: support TDM out and 8ch I2S out
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: pull TDM GPIO pins down when
  probed (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: change supported formats of
  DL2 and UL1 (jsc#SLE-16518).
- ASoC: Fix SND_SOC_ALL_CODECS imply misc fallout (jsc#SLE-16518).
- ASoC: Fix SND_SOC_ALL_CODECS imply I2C fallout (jsc#SLE-16518).
- ASoC: Fix SND_SOC_ALL_CODECS imply SPI fallout (jsc#SLE-16518).
- ASoC: soc-pcm: tidyup soc_pcm_open() order (jsc#SLE-16518).
- ASoC: soc-pcm: move soc_pcm_close() next to soc_pcm_open()
  (jsc#SLE-16518).
- commit 6ad8c6a
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: soc-pcm: call snd_soc_component_open/close() once
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219: add speaker switch
  (jsc#SLE-16518).
- ASoC: max98357a: move control of SD_MODE to DAPM
  (jsc#SLE-16518).
- ASoC: wm0010: Replace zero-length array with flexible-array
  member (jsc#SLE-16518).
- ASoC: sh: fsi: Restore devm_ioremap() alignment (jsc#SLE-16518).
- ALSA: dmaengine_pcm: Consider DMA cache caused delay in pointer
  callback (jsc#SLE-16518).
- ASoC: soc-pcm: call snd_soc_dai_startup()/shutdown() once
  (jsc#SLE-16518).
- ASoC: soc-pcm: don't use bit-OR'ed error (jsc#SLE-16518).
- ASoC: soc-pcm: add for_each_dapm_widgets() macro
  (jsc#SLE-16518).
- ASoC: soc-pcm: adjustment for DAI member 0 reset
  (jsc#SLE-16518).
- ASoC: soc-pcm: add snd_soc_runtime_action() (jsc#SLE-16518).
- ALSA: dmaengine_pcm: Consider DMA cache caused delay in pointer
  callback (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Allow trace DMA in S0 when DSP is in
  D0I3 for debug (jsc#SLE-16518).
- ASoC: SOF: Intel: cnl: Implement feature to support DSP D0i3
  in S0 (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Amend the DSP state transition diagram
  (jsc#SLE-16518).
- ASoC: SOF: audio: Add helper to check if only D0i3 streams
  are active (jsc#SLE-16518).
- ASoC: SOF: Move DSP power state transitions to platform-specific
  ops (jsc#SLE-16518).
- ASoC: SOF: pm: Introduce DSP power states (jsc#SLE-16518).
- ASoC: SOF: Add system_suspend_target field to struct snd_sof_dev
  (jsc#SLE-16518).
- ASoC: SOF: pm: Unify suspend/resume routines (jsc#SLE-16518).
- commit 5e5bcfb
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: SOF: Do not reset hw_params for streams that ignored
  suspend (jsc#SLE-16518).
- ASoC: ti: davinci-mcasp: remove redundant assignment to variable
  ret (jsc#SLE-16518).
- ASoC: wcd934x: Remove set but not unused variable
  'hph_comp_ctrl7' (jsc#SLE-16518).
- ASoC: mediatek: mt8173-rt5650: support HDMI jack reporting
  (jsc#SLE-16518).
- ASoC: ti: davinci-mcasp: Add support for platforms using UDMA
  (jsc#SLE-16518).
- ASoC: ti: Add udma-pcm platform driver for UDMA (jsc#SLE-16518).
- ASoC: Use imply for SND_SOC_ALL_CODECS (jsc#SLE-16518).
- ASoC: SOF: Add i.MX8QM device descriptor (jsc#SLE-16518).
- ASoC: SOF: imx8: Add ops for i.MX8QM (jsc#SLE-16518).
- ASoC: SOF: Rename i.MX8 platform to i.MX8X (jsc#SLE-16518).
- ASoC: rt5659: remove redundant assignment to variable idx
  (jsc#SLE-16518).
- ASoC: Intel: mrfld: return error codes when an error occurs
  (jsc#SLE-16518).
- ASoC: stm32: i2s: improve error management on probe deferral
  (jsc#SLE-16518).
- ASoC: stm32: spdifrx: improve error management on probe deferral
  (jsc#SLE-16518).
- ASoC: stm32: sai: improve error management on probe deferral
  (jsc#SLE-16518).
- ASoC: stm32: i2s: manage error when getting reset controller
  (jsc#SLE-16518).
- ASoC: stm32: spdifrx: manage error when getting reset controller
  (jsc#SLE-16518).
- ASoC: stm32: sai: manage error when getting reset controller
  (jsc#SLE-16518).
- ASoC: rt5682: Add the field "is_sdw" of private data
  (jsc#SLE-16518).
- ASoC: rl6231: Add new supports on rl6231 (jsc#SLE-16518).
- commit b9da842
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: Intel: sof_pcm512x: add support for SOF platforms with
  pcm512x (jsc#SLE-16518).
- Update config files.
- commit 94e4873
* Mon Sep 28 2020 tiwai@suse.de
- ASoC: wcd934x: Remove some unnecessary NULL checks
  (jsc#SLE-16518).
- ASoC: Remove unused including <linux/version.h> (jsc#SLE-16518).
- ASoC: Intel: CHT: add support for pcm512x boards
  (jsc#SLE-16518).
- ASoC: Intel: BXT: switch pcm512x based boards to sof_pcm512x
  (jsc#SLE-16518).
- ASoC: Intel: bdw-rt5650: Revert SSP0 link to use dummy
  components (jsc#SLE-16518).
- ASoC: Intel: bdw-rt5677: Revert SSP0 link to use dummy
  components (jsc#SLE-16518).
- ASoC: Intel: broadwell: Revert back SSP0 link to use dummy
  components (jsc#SLE-16518).
- ASoC: tas2562: Fixed incorrect amp_level setting
  (jsc#SLE-16518).
- ASoC: stm32: spdifrx: fix regmap status check (jsc#SLE-16518).
- ASoC: rt5682: fix the random recording noise of headset
  (jsc#SLE-16518).
- ASoC: codecs: wsa881x: request gpio direction before setting
  (jsc#SLE-16518).
- ASoC: max98357a: Add ACPI HID MAX98360A (jsc#SLE-16518).
- ASoC: rt5682: Revise the DAC1 volume setting (jsc#SLE-16518).
- ASoC: wm_adsp: Use scnprintf() for the limited buffer output
  (jsc#SLE-16518).
- ASoC: topology: Perform component check upfront (jsc#SLE-16518).
- ASoC: qdsp6: q6routing: remove default routing (jsc#SLE-16518).
- ASoC: qdsp6: q6asm-dai: only enable dais from device tree
  (jsc#SLE-16518).
- ASoC: SOF: Intel: Fix stream cleanup on hw free (jsc#SLE-16518).
- ASoC: Intel: Skylake: Await purge request ack on CNL
  (jsc#SLE-16518).
- ASoC: Intel: Allow for ROM init retry on CNL platforms
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Shield against no-NHLT configurations
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Enable codec wakeup during chip init
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Select hda configuration permissively
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Remove superfluous chip initialization
  (jsc#SLE-16518).
- ASoC: Intel: skl_nau88l25_ssm4567: disable route checks
  (jsc#SLE-16518).
- ASoC: soc-core: disable route checks for legacy devices
  (jsc#SLE-16518).
- ASoC: jz4740-i2s: Fix divider written at incorrect offset in
  register (jsc#SLE-16518).
- ASoC: wcd9335: fix address map representation (jsc#SLE-16518).
- commit c430711
* Mon Sep 28 2020 tiwai@suse.de
- ALSA: hda: default enable CA0132 DSP support (jsc#SLE-16518).
- ALSA: ppc: keywest: convert to use i2c_new_client_device()
  (jsc#SLE-16518).
- ALSA: usb-audio: Inform devices that need delayed registration
  (jsc#SLE-16518).
- ALSA: usb-audio: Add delayed_register option (jsc#SLE-16518).
- ALSA: usb-audio: Rewrite registration quirk handling
  (jsc#SLE-16518).
- ALSA: core: Add snd_device_get_state() helper (jsc#SLE-16518).
- ALSA: usb-audio: Create a registration quirk for Kingston
  HyperX Amp (0951:16d8) (jsc#SLE-16518).
- ALSA: usb-audio: Fix mixer controls' USB interface for Kingston
  HyperX Amp (0951:16d8) (jsc#SLE-16518).
- ALSA: hda: Use scnprintf() for string truncation
  (jsc#SLE-16518).
- ALSA: pcm: Fix superfluous snprintf() usage (jsc#SLE-16518).
- ALSA: firewire-tascam: Add missing annotation for
  tscm_hwdep_read_locked() (jsc#SLE-16518).
- ALSA: firewire-tascam: Add missing annotation for
  tscm_hwdep_read_queue() (jsc#SLE-16518).
- ALSA: pcm: oss: Simplify plugin frame size calculations
  (jsc#SLE-16518).
- ALSA: firewire: use KBUILD_MODNAME for struct driver.name
  instead of string (jsc#SLE-16518).
- ALSA: usb-audio: Fix missing braces in some struct inits
  (jsc#SLE-16518).
- ALSA: usb-audio: Add support for MOTU MicroBook IIc
  (jsc#SLE-16518).
- ALSA: korg1212: fix if-statement empty body warnings
  (jsc#SLE-16518).
- ALSA: usb-audio: Parse source ID of UAC2 effect unit
  (jsc#SLE-16518).
- ALSA: usb-audio: Add support for Presonus Studio 1810c
  (jsc#SLE-16518).
- ALSA: pcm: oss: Unlock mutex temporarily for sleeping at
  read/write (jsc#SLE-16518).
- ALSA: usb-audio: Don't create a mixer element with bogus volume
  range (jsc#SLE-16518).
- ALSA: hda_codec: Replace zero-length array with flexible-array
  member (jsc#SLE-16518).
- ALSA: hda/ca0132 - Replace zero-length array with flexible-array
  member (jsc#SLE-16518).
- ALSA: usb-midi: Replace zero-length array with flexible-array
  member (jsc#SLE-16518).
- ALSA: core: Replace zero-length array with flexible-array member
  (jsc#SLE-16518).
- ALSA: info: remove redundant assignment to variable c
  (jsc#SLE-16518).
- ALSA: ali5451: remove redundant variable capture_flag
  (jsc#SLE-16518).
- ALSA: hda: remove redundant assignment to variable timeout
  (jsc#SLE-16518).
- ALSA: hdsp: remove redundant assignment to variable err
  (jsc#SLE-16518).
- ALSA: pcm: Minor refactoring (jsc#SLE-16518).
- ALSA: pcm_dmaengine: Use pcm_for_each_format() macro for PCM
  format iteration (jsc#SLE-16518).
- ALSA: pcm: Use a macro for parameter masks to reduce the needed
  cast (jsc#SLE-16518).
- ALSA: pcm: Use standard macros for fixing PCM format cast
  (jsc#SLE-16518).
- ALSA: dummy: Use standard macros for fixing PCM format cast
  (jsc#SLE-16518).
- ALSA: usb-audio: Use pcm_for_each_format() macro for PCM format
  iterations (jsc#SLE-16518).
- ALSA: pcm: More helper macros for reducing snd_pcm_format_t cast
  (jsc#SLE-16518).
- ALSA: aloop: Fix PCM format assignment (jsc#SLE-16518).
- ALSA: emu8000: Fix the cast to __user pointer (jsc#SLE-16518).
- ALSA: emu10k1: Fix endianness annotations (jsc#SLE-16518).
- ALSA: via82xx: Fix endianness annotations (jsc#SLE-16518).
- ALSA: hda/hdmi: Move ELD parse and jack reporting into
  update_eld() (jsc#SLE-16518).
- ALSA: hda/hdmi: Move runtime PM resume into
  hdmi_present_sense_via_verbs() (jsc#SLE-16518).
- ALSA: hda/hdmi: Don't use standard hda_jack for generic HDMI
  jacks (jsc#SLE-16518).
- ALSA: hda/hdmi: Reduce hda_jack_tbl lookup at unsol event
  handling (jsc#SLE-16518).
- ALSA: hda/realtek - a fake key event is triggered by running
  shutup (jsc#SLE-16518).
- ALSA: hda/realtek: Enable mute LED on an HP system
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Add Recon3Di quirk to handle integrated
  sound on EVGA X99 Classified motherboard (jsc#SLE-16518).
- commit dbb12c7
* Mon Sep 28 2020 colyli@suse.de
- bcache: avoid extra memory consumption in struct bbio for
  large bucket size (bsc#1175995, jsc#SLE-15608).
- bcache: avoid extra memory allocation from mempool c->fill_iter
  (bsc#1175995, jsc#SLE-15608).
- bcache: add sysfs file to display feature sets information of
  cache set (bsc#1175995, jsc#SLE-15608).
- bcache: add bucket_size_hi into struct cache_sb_disk for large
  bucket (bsc#1175995, jsc#SLE-15608).
- bcache: handle btree node memory allocation properly for bucket
  size > 8MB (bsc#1175995, jsc#SLE-15608).
- bcache: handle cache set verify_ondisk properly for bucket
  size > 8MB (bsc#1175995, jsc#SLE-15608).
- bcache: handle cache prio_buckets and disk_buckets properly
  for bucket size > 8MB (bsc#1175995, jsc#SLE-15608).
- bcache: handle c->uuids properly for bucket size > 8MB
  (bsc#1175995, jsc#SLE-15608).
- bcache: introduce meta_bucket_pages() related helper routines
  (bsc#1175995, jsc#SLE-15608).
- bcache: struct cache_sb is only for in-memory super block now
  (bsc#1175995, jsc#SLE-15608).
- bcache: move bucket related code into read_super_common()
  (bsc#1175995, jsc#SLE-15608).
- bcache: increase super block version for cache device and
  backing device (bsc#1175995, jsc#SLE-15608).
- bcache: fix super block seq numbers comparision in
  register_cache_set() (bsc#1175995, jsc#SLE-15608).
- bcache: disassemble the big if() checks in bch_cache_set_alloc()
  (bsc#1175995, jsc#SLE-15608).
- bcache: add more accurate error information in
  read_super_common() (bsc#1175995, jsc#SLE-15608).
- bcache: add read_super_common() to read major part of super
  block (bsc#1175995, jsc#SLE-15608).
- bcache: fix overflow in offset_to_stripe() (bsc#1175995,
  jsc#SLE-15608).
- bcache: avoid nr_stripes overflow in bcache_device_init()
  (bsc#1175995, jsc#SLE-15608).
- bcache: Use struct_size() in kzalloc() (bsc#1175995,
  jsc#SLE-15608).
- bcache: movinggc: Use struct_size() helper in kzalloc()
  (bsc#1175995, jsc#SLE-15608).
- bcache: writeback: Remove unneeded variable i (bsc#1175995,
  jsc#SLE-15608).
- bcache: journel: use for_each_clear_bit() to simplify the code
  (bsc#1175995, jsc#SLE-15608).
- commit 5d49c68
* Sun Sep 27 2020 tbogendoerfer@suse.de
- blacklist.conf: c7211ff3be0f not needed, mlx5 commits which will backported later
- commit c670d9e
* Sun Sep 27 2020 tbogendoerfer@suse.de
- ice: implement device flash update via devlink (jsc#SLE-12878).
- Update config files.
- commit 7632ad6
* Sun Sep 27 2020 tiwai@suse.de
- spi: pxa2xx: Enable support for compile-testing (jsc#SLE-16518).
- ASoC: dt-bindings: mt8183: add missing update (jsc#SLE-16518).
- commit 2cd35a4
* Sun Sep 27 2020 tiwai@suse.de
- supported.conf: add regmap-sdw
- commit ac569c9
* Sun Sep 27 2020 tbogendoerfer@suse.de
- net/mlx5e: mlx5e_fec_in_caps() returns a boolean
  (jsc#SLE-15172).
- bnxt_en: Fix wrong flag value passed to HWRM_PORT_QSTATS_EXT
  fw call (jsc#SLE-15075).
- bnxt_en: Fix HWRM_FUNC_QSTATS_EXT firmware call (jsc#SLE-15075).
- bnxt_en: Return -EOPNOTSUPP for ETHTOOL_GREGS on VFs
  (jsc#SLE-15075).
- bnxt_en: Use memcpy to copy VPD field info (jsc#SLE-15075).
- ethtool: add and use message type for tunnel info reply
  (bsc#1176447).
- netfilter: ctnetlink: fix mark based dump filtering regression
  (bsc#1176447).
- nfp: flower: fix ABI mismatch between driver and firmware
  (bsc#1176447).
- netfilter: conntrack: do not auto-delete clash entries on reply
  (bsc#1176447).
- netfilter: nfnetlink: nfnetlink_unicast() reports EAGAIN
  instead of ENOBUFS (bsc#1176447).
- netfilter: delete repeated words (bsc#1176447).
- net_sched: fix error path in red_init() (bsc#1176447).
- bnxt_en: Setup default RSS map in all scenarios (jsc#SLE-15075).
- bnxt_en: init RSS table for Minimal-Static VF reservation
  (jsc#SLE-15075).
- bnxt_en: Fix ethtool -S statitics with XDP or TCs enabled
  (jsc#SLE-15075).
- netfilter: nf_tables: fix destination register zeroing
  (bsc#1176447).
- netfilter: nf_tables: add NFTA_SET_USERDATA if not null
  (bsc#1176447).
- netfilter: nft_set_rbtree: Detect partial overlap with start
  endpoint match (bsc#1176447).
- netfilter: nft_set_rbtree: Handle outcomes of tree rotations
  in overlap detection (bsc#1176447).
- netfilter: conntrack: allow sctp hearbeat after connection
  re-use (bsc#1176447).
- net/sched: act_ct: Fix skb double-free in
  tcf_ct_handle_fragments() error flow (bsc#1176447).
- net: devlink: Remove overzealous WARN_ON with snapshots
  (bsc#1176447).
- netfilter: nf_tables: free chain context when BINDING flag is
  missing (bsc#1176447).
- netfilter: nft_compat: remove flush counter optimization
  (bsc#1176447).
- netfilter: nf_tables: nft_exthdr: the presence return value
  should be little-endian (bsc#1176447).
- net/tls: allow MSG_CMSG_COMPAT in sendmsg (bsc#1176447).
- platform/x86: mlx-platform: support new watchdog type with
  longer timeout (bsc#1176774).
- platform_data/mlxreg: support new watchdog type with longer
  timeout period (bsc#1176774).
- lib/bitmap.c: fix bitmap_cut() for partial overlapping case
  (bsc#1176447).
- mlxbf-tmfifo: sparse tags for config access (bsc#1176774).
- PCI: Use 'pci_channel_state_t' instead of 'enum
  pci_channel_state' (jsc#SLE-12878).
- netfilter: flowtable: Set offload timeout when adding flow
  (bsc#1176447).
- netfilter: conntrack: Move nf_ct_offload_timeout to header file
  (bsc#1176447).
- netfilter: nft_meta: fix iifgroup matching (bsc#1176447).
- netfilter: nft_compat: make sure xtables destructors have run
  (bsc#1176447).
- udp_tunnel: add the ability to hard-code IANA VXLAN
  (bsc#1176447).
- selftests: mlxsw: RED: Test offload of trapping on RED qevents
  (bsc#1176774).
- mlxsw: spectrum_qdisc: Offload action trap for qevents
  (bsc#1176774).
- mlxsw: spectrum_trap: Add early_drop trap (bsc#1176774).
- mlxsw: spectrum_trap: Allow for per-ASIC traps initialization
  (bsc#1176774).
- mlxsw: spectrum_trap: Allow for per-ASIC trap groups
  initialization (bsc#1176774).
- mlxsw: spectrum_span: On policer_id_base_ref_count, use
  dec_and_test (bsc#1176774).
- mlxsw: spectrum_trap: Use 'size_t' for array sizes
  (bsc#1176774).
- devlink: Pass extack when setting trap's action and group's
  parameters (bsc#1176447).
- devlink: Add early_drop trap (bsc#1176447).
- netfilter: nf_tables: report EEXIST on overlaps (bsc#1176447).
- netfilter: nf_tables: extended netlink error reporting for
  expressions (bsc#1176447).
- netfilter: Replace HTTP links with HTTPS ones (bsc#1176447).
- netfilter: Use fallthrough pseudo-keyword (bsc#1176447).
- ipvs: queue delayed work to expire no destination connections
  if expire_nodest_conn=1 (bsc#1176447).
- netfilter: nf_tables: Fix a use after free in
  nft_immediate_destroy() (bsc#1176447).
- ice: Misc minor fixes (jsc#SLE-12878).
- ice: adjust profile ID map locks (jsc#SLE-12878).
- ice: update PTYPE lookup table (jsc#SLE-12878).
- ice: Disable VLAN pruning in promiscuous mode (jsc#SLE-12878).
- ice: port fix for chk_linearlize (jsc#SLE-12878).
- ice: Allow 2 queue pairs per VF on SR-IOV initialization
  (jsc#SLE-12878).
- ice: add useful statistics (jsc#SLE-12878).
- ice: remove page_reuse statistic (jsc#SLE-12878).
- ice: Fix RSS profile locks (jsc#SLE-12878).
- ice: fix the vsi_id mask to be 10 bit for set_rss_lut
  (jsc#SLE-12878).
- ice: rename misleading grst_delay variable (jsc#SLE-12878).
- ice: mark PM functions as __maybe_unused (jsc#SLE-12878).
- net/sched: act_ct: fix miss set mru for ovs after defrag in
  act_ct (bsc#1176447).
- net/sched: cls_u32: Use struct_size() helper (bsc#1176447).
- bnxt_en: Remove superfluous memset() (jsc#SLE-15075).
- net/sched: act_pedit: Use flex_array_size() helper in memcpy()
  (bsc#1176447).
- mlxsw: spectrum_cnt: Use flex_array_size() helper in memcpy()
  (bsc#1176774).
- ice: fix unused parameter warning (jsc#SLE-12878).
- ice: disable no longer needed workaround for FW logging
  (jsc#SLE-12878).
- ice: reduce scope of variable (jsc#SLE-12878).
- ice: cleanup VSI on probe fail (jsc#SLE-12878).
- ice: Allow all VLANs in safe mode (jsc#SLE-12878).
- ice: need_wakeup flag might not be set for Tx (jsc#SLE-12878).
- ice: distribute Tx queues evenly (jsc#SLE-12878).
- ice: Adjust scheduler default BW weight (jsc#SLE-12878).
- ice: Add RL profile bit mask check (jsc#SLE-12878).
- ice: fix overwriting TX/RX descriptor values when rebuilding
  VSI (jsc#SLE-12878).
- ice: return correct error code from ice_aq_sw_rules
  (jsc#SLE-12878).
- ice: restore VF MSI-X state during PCI reset (jsc#SLE-12878).
- ice: fix link event handling timing (jsc#SLE-12878).
- ice: Fix link broken after GLOBR reset (jsc#SLE-12878).
- ice: Implement LFC workaround (jsc#SLE-12878).
- net_sched: initialize timer earlier in red_init() (bsc#1176447).
- ice: add flags indicating pending update of firmware module
  (jsc#SLE-12878).
- ice: Add AdminQ commands for FW update (jsc#SLE-12878).
- ice: Add support for unified NVM update flow capability
  (jsc#SLE-12878).
- Add pldmfw library for PLDM firmware update (jsc#SLE-12878).
- mlxsw: core: Add support for temperature thresholds reading
  for QSFP-DD transceivers (bsc#1176774).
- mlxsw: core: Add ethtool support for QSFP-DD transceivers
  (bsc#1176774).
- net/mlx4: Use fallthrough pseudo-keyword (jsc#SLE-15171).
- bnxt_en: Add support for 'ethtool -d' (jsc#SLE-15075).
- bnxt_en: Switch over to use the 64-bit software accumulated
  counters (jsc#SLE-15075).
- bnxt_en: Accumulate all counters (jsc#SLE-15075).
- bnxt_en: Retrieve hardware masks for port counters
  (jsc#SLE-15075).
- bnxt_en: Retrieve hardware counter masks from firmware if
  available (jsc#SLE-15075).
- bnxt_en: Allocate additional memory for all statistics blocks
  (jsc#SLE-15075).
- bnxt_en: Refactor statistics code and structures
  (jsc#SLE-15075).
- bnxt_en: Use macros to define port statistics size and offset
  (jsc#SLE-15075).
- bnxt_en: Update firmware interface to 1.10.1.54 (jsc#SLE-15075).
- bnxt_en: Remove PCIe non-counters from ethtool statistics
  (jsc#SLE-15075).
- ice: add 1G SGMII PHY type (jsc#SLE-12878).
- ice: Report AOC PHY Types as Fiber (jsc#SLE-12878).
- ice: add AQC get link topology handle support (jsc#SLE-12878).
- ice: Rename low_power_ctrl (jsc#SLE-12878).
- ice: update reporting of autoneg capabilities (jsc#SLE-12878).
- ice: add ice_aq_get_phy_caps() debug logs (jsc#SLE-12878).
- ice: support Total Port Shutdown on devices that support it
  (jsc#SLE-12878).
- ice: add link lenient and default override support
  (jsc#SLE-12878).
- ice: restore PHY settings on media insertion (jsc#SLE-12878).
- ice: move auto FEC checks into ice_cfg_phy_fec()
  (jsc#SLE-12878).
- ice: refactor FC functions (jsc#SLE-12878).
- ice: Add advanced power mgmt for WoL (jsc#SLE-12878).
- ice: split ice_discover_caps into two functions (jsc#SLE-12878).
- ice: split ice_parse_caps into separate functions
  (jsc#SLE-12878).
- ice: refactor ice_discover_caps to avoid need to retry
  (jsc#SLE-12878).
- net/sched: cls_flower: Add hash info to flow classification
  (bsc#1176447).
- net/flow_dissector: add packet hash dissection (bsc#1176447).
- devlink: Always use user_ptr for devlink and simplify post_doit
  (bsc#1176447).
- devlink: Constify devlink instance pointer (bsc#1176447).
- devlink: Add comment for devlink instance lock (bsc#1176447).
- devlink: Avoid duplicate check for reload enabled flag
  (bsc#1176447).
- devlink: Do not hold devlink mutex when initializing devlink
  fields (bsc#1176447).
- sched: sch_api: add missing rcu read lock to silence the warning
  (bsc#1176447).
- net: bnxt: don't complain if TC flower can't be supported
  (jsc#SLE-15075).
- Revert "net: sched: Pass root lock to Qdisc_ops.enqueue"
  (bsc#1176447).
- net: sched: Do not drop root lock in tcf_qevent_handle()
  (bsc#1176447).
- selftests: mlxsw: Test policers' occupancy (bsc#1176774).
- selftests: mlxsw: Add scale test for tc-police (bsc#1176774).
- selftests: mlxsw: tc_restrictions: Test tc-police restrictions
  (bsc#1176774).
- mlxsw: spectrum_acl: Offload FLOW_ACTION_POLICE (bsc#1176774).
- mlxsw: core_acl_flex_actions: Add police action (bsc#1176774).
- mlxsw: core_acl_flex_actions: Work around hardware limitation
  (bsc#1176774).
- mlxsw: spectrum_policer: Add devlink resource support
  (bsc#1176774).
- mlxsw: spectrum_policer: Add policer core (bsc#1176774).
- mlxsw: resources: Add resource identifier for global policers
  (bsc#1176774).
- mlxsw: reg: Add policer bandwidth limits (bsc#1176774).
- nfp: convert to new udp_tunnel_nic infra (bsc#1176447).
- mlxsw: core: Use mirror reason during Rx listener lookup
  (bsc#1176774).
- mlxsw: pci: Retrieve mirror reason from CQE during receive
  (bsc#1176774).
- mlxsw: pci: Add mirror reason field to CQEv2 (bsc#1176774).
- mlxsw: trap: Add trap identifiers for mirrored packets
  (bsc#1176774).
- mlxsw: reg: Increase trap identifier to 10 bits (bsc#1176774).
- mlxsw: spectrum_span: Allow setting policer on a SPAN agent
  (bsc#1176774).
- mlxsw: spectrum_span: Allow passing parameters to SPAN agents
  (bsc#1176774).
- mlxsw: spectrum_span: Add support for mirroring towards CPU port
  (bsc#1176774).
- mlxsw: spectrum_span: Do not dereference destination netdev
  (bsc#1176774).
- mlxsw: spectrum_span: Add driver private info to parms_set()
  callback (bsc#1176774).
- mlxsw: spectrum_span: Add per-ASIC SPAN agent operations
  (bsc#1176774).
- mlxsw: reg: add mirroring_pid_base to MOGCR register
  (bsc#1176774).
- mlxsw: reg: Add session_id and pid to MPAT register
  (bsc#1176774).
- devlink: Fix use-after-free when destroying health reporters
  (bsc#1176447).
- selftests: mlxsw: RED: Test offload of mirror on RED early_drop
  qevent (bsc#1176774).
- mlxsw: spectrum_qdisc: Offload mirroring on RED qevent
  early_drop (bsc#1176774).
- mlxsw: spectrum_flow: Promote binder-type dispatch to spectrum.c
  (bsc#1176774).
- mlxsw: spectrum_matchall: Publish matchall data structures
  (bsc#1176774).
- mlxsw: spectrum_flow: Drop an unused field (bsc#1176774).
- mlxsw: spectrum_flow: Convert a goto to a return (bsc#1176774).
- mlxsw: spectrum_span: Add APIs to enable / disable global
  mirroring triggers (bsc#1176774).
- mlxsw: spectrum_span: Add support for global mirroring triggers
  (bsc#1176774).
- mlxsw: spectrum_span: Prepare for global mirroring triggers
  (bsc#1176774).
- mlxsw: spectrum_span: Move SPAN operations out of global file
  (bsc#1176774).
- mlxsw: reg: Add Monitoring Port Analyzer Global Register
  (bsc#1176774).
- mlxsw: reg: Add Monitoring Mirror Trigger Enable Register
  (bsc#1176774).
- net: sched: Pass qdisc reference in struct flow_block_offload
  (bsc#1176447).
- net: sched: kerneldoc fixes (bsc#1176447).
- net: netfilter: kerneldoc fixes (bsc#1176447).
- devlink: Add devlink health port reporters API (bsc#1176447).
- devlink: Implement devlink health reporters on per-port basis
  (bsc#1176447).
- devlink: Create generic devlink health reporter search function
  (bsc#1176447).
- devlink: Rework devlink health reporter destructor
  (bsc#1176447).
- devlink: Refactor devlink health reporter constructor
  (bsc#1176447).
- mlx4: convert to new udp_tunnel_nic infra (jsc#SLE-15171).
- bnxt: convert to new udp_tunnel_nic infra (jsc#SLE-15075).
- ethtool: add tunnel info interface (bsc#1176447).
- udp_tunnel: add central NIC RX port offload infrastructure
  (bsc#1176447).
- udp_tunnel: re-number the offload tunnel types (bsc#1176447).
- devlink: Move input checks from driver to devlink (bsc#1176447).
- devlink: Add a new devlink port split ability attribute and
  pass to netlink (bsc#1176447).
- mlxsw: Set port split ability attribute in driver (bsc#1176774).
- devlink: Add a new devlink port lanes attribute and pass to
  netlink (bsc#1176447).
- mlxsw: Set number of port lanes attribute in driver
  (bsc#1176774).
- devlink: Replace devlink_port_attrs_set parameters with a struct
  (bsc#1176447).
- devlink: Move switch_port attribute of devlink_port_attrs to
  devlink_port (bsc#1176447).
- devlink: Move set attribute of devlink_port_attrs to
  devlink_port (bsc#1176447).
- ethtool: Add support for 100Gbps per lane link modes
  (bsc#1176447).
- bnxt_en: allow firmware to disable VLAN offloads
  (jsc#SLE-15075).
- bnxt_en: clean up VLAN feature bit handling (jsc#SLE-15075).
- bnxt_en: Implement ethtool -X to set indirection table
  (jsc#SLE-15075).
- bnxt_en: Return correct RSS indirection table entries to
  ethtool -x (jsc#SLE-15075).
- bnxt_en: Fill HW RSS table from the RSS logical indirection
  table (jsc#SLE-15075).
- bnxt_en: Add helper function to return the number of RSS
  contexts (jsc#SLE-15075).
- bnxt_en: Add logical RSS indirection table structure
  (jsc#SLE-15075).
- bnxt_en: Fix up bnxt_get_rxfh_indir_size() (jsc#SLE-15075).
- bnxt_en: Set up the chip specific RSS table size
  (jsc#SLE-15075).
- netfilter: nf_tables: reject unsupported chain flags
  (bsc#1176447).
- netfilter: nf_tables: add NFT_CHAIN_BINDING (bsc#1176447).
- netfilter: nf_tables: add nft_chain_add() (bsc#1176447).
- netfilter: nf_tables: expose enum nft_chain_flags through UAPI
  (bsc#1176447).
- netfilter: nf_tables: add NFTA_VERDICT_CHAIN_ID attribute
  (bsc#1176447).
- netfilter: nf_tables: add NFTA_RULE_CHAIN_ID attribute
  (bsc#1176447).
- netfilter: nf_tables: add NFTA_CHAIN_ID attribute (bsc#1176447).
- ipvs: allow connection reuse for unconfirmed conntrack
  (bsc#1176447).
- ipvs: avoid expiring many connections from timer (bsc#1176447).
- ipvs: register hooks only with services (bsc#1176447).
- netfilter: nft_set_pipapo: Drop useless assignment of scratch
  map index on insert (bsc#1176447).
- netfilter: introduce support for reject at prerouting stage
  (bsc#1176447).
- net: phy: Uninline PHY ethtool statistics operations
  (bsc#1176447).
- net: phy: Define PHY statistics ethtool_phy_ops (bsc#1176447).
- net/sched: Use fallthrough pseudo-keyword (bsc#1176447).
- net: ethtool: Remove PHYLIB direct dependency (bsc#1176447).
- net: phy: Register ethtool PHY operations (bsc#1176447).
- net: ethtool: Introduce ethtool_phy_ops (bsc#1176447).
- Documentation: networking: fix ethtool-netlink table formats
  (bsc#1176447).
- net: sched: Allow changing default qdisc to FQ-PIE
  (bsc#1176447).
- net/tls: fix sign extension issue when left shifting u16 value
  (bsc#1176447).
- mlxsw: spectrum_ethtool: Add link extended state (bsc#1176774).
- mlxsw: reg: Port Diagnostics Database Register (bsc#1176774).
- ethtool: Add link extended state (bsc#1176447).
- Documentation: networking: ethtool-netlink: Add link extended
  state (bsc#1176447).
- mlxsw: spectrum_ethtool: Move mlxsw_sp_port_type_speed_ops
  structs (bsc#1176774).
- mlxsw: Move ethtool_ops to spectrum_ethtool.c (bsc#1176774).
- mlxsw: spectrum_dcb: Rename mlxsw_sp_port_headroom_set()
  (bsc#1176774).
- net/tls: Add asynchronous resync (bsc#1176447).
- net: sched: sch_red: Add qevents "early_drop" and "mark"
  (bsc#1176447).
- net: sched: sch_red: Split init and change callbacks
  (bsc#1176447).
- net: sched: Introduce helpers for qevent blocks (bsc#1176447).
- net: sched: Pass root lock to Qdisc_ops.enqueue (bsc#1176447).
- net: nfp: fix nfp_net_tx()'s return type (bsc#1176447).
- sch_cake: add RFC 8622 LE PHB support to CAKE diffserv handling
  (bsc#1176447).
- net: qos: police action add index for tc flower offloading
  (bsc#1176447).
- net: qos: add tc police offloading action with max frame size
  limit (bsc#1176447).
- mlxsw: Enforce firmware version for Spectrum-3 (bsc#1176774).
- mlxsw: Bump firmware version to XX.2007.1168 (bsc#1176774).
- mlxsw: spectrum_dcb: Fix a spelling typo in spectrum_dcb.c
  (bsc#1176774).
- net/core/devlink.c: remove new uninitialized_var() usage
  (bsc#1176447).
- tcindex_change: Remove redundant null check (bsc#1176447).
- mlxsw: spectrum_acl: Support FLOW_ACTION_MANGLE for TCP,
  UDP ports (bsc#1176774).
- mlxsw: core_acl_flex_actions: Add L4_PORT_ACTION (bsc#1176774).
- mlxsw: spectrum: Split handling of pedit mangle by chip type
  (bsc#1176774).
- bnxt_en: Add board.serial_number field to info_get cb
  (jsc#SLE-15075).
- devlink: Add support for board.serial_number to info_get cb
  (bsc#1176447).
- net/devlink: Support setting hardware address of port function
  (bsc#1176447).
- net/devlink: Support querying hardware address of port function
  (bsc#1176447).
- net/devlink: Prepare devlink port functions to fill extack
  (bsc#1176447).
- Remove redundant skb null check (bsc#1176447).
- Remove redundant condition in qdisc_graft (bsc#1176447).
- net/sched: cls_u32: Use struct_size() in kzalloc()
  (bsc#1176447).
- taprio: Use struct_size() in kzalloc() (bsc#1176447).
- net: qos offload add flow status with dropped count
  (jsc#SLE-15075).
- ethtool: ioctl: Use array_size() in copy_to_user()
  (bsc#1176447).
- audit: use the proper gfp flags in the audit_log_nfcfg() calls
  (bsc#1176447).
- audit: add gfp parameter to audit_log_nfcfg (bsc#1176447).
- audit: log nftables configuration change events (bsc#1176447).
- platform/x86: mlx-platform: Extend FAN platform data description
  (bsc#1176774).
- platform_data/mlxreg: Add presence register field for FAN
  devices (bsc#1176774).
- platform/mellanox: mlxreg-io: Add support for complex attributes
  (bsc#1176774).
- platform/x86: mlx-platform: Add more definitions for system
  attributes (bsc#1176774).
- platform_data/mlxreg: Add support for complex attributes
  (bsc#1176774).
- platform/mellanox: mlxreg-hotplug: Add environmental data to
  uevent (bsc#1176774).
- platform/mellanox: mlxreg-hotplug: Use capability register
  for attribute creation (bsc#1176774).
- platform/mellanox: mlxreg-hotplug: Modify module license
  (bsc#1176774).
- lib/string_helpers: Introduce string_upper() and string_lower()
  helpers (bsc#1176774).
- net/mlx5e: fix bpf_prog reference count leaks in mlx5e_alloc_rq
  (jsc#SLE-15172).
- net/mlx5e: E-Switch, Specify flow_source for rule with no
  in_port (jsc#SLE-15172).
- net/mlx5e: E-Switch, Add misc bit when misc fields changed
  for mirroring (jsc#SLE-15172).
- net/mlx5e: CT: Support restore ipv6 tunnel (jsc#SLE-15172).
- net/sched: The error lable position is corrected in
  ct_init_module (bsc#1176447).
- selftests/bpf: fix netdevsim trap_flow_action_cookie read
  (bsc#1176774).
- mlxsw: spectrum_router: Fix use-after-free in router init /
  de-init (bsc#1176774).
- mlxsw: core: Free EMAD transactions using kfree_rcu()
  (bsc#1176774).
- mlxsw: core: Increase scope of RCU read-side critical section
  (bsc#1176774).
- mlxsw: spectrum: Use different trap group for externally routed
  packets (bsc#1176774).
- mlxsw: spectrum_router: Allow programming link-local host routes
  (bsc#1176774).
- Documentation: bareudp: Corrected description of bareudp module
  (jsc#SLE-15172).
- bareudp: forbid mixing IP and MPLS in multiproto mode
  (jsc#SLE-15172).
- net/mlx5e: Modify uplink state on interface up/down
  (jsc#SLE-15172).
- net/mlx5: Query PPS pin operational status before registering it
  (jsc#SLE-15172).
- net/mlx5e: Fix slab-out-of-bounds in mlx5e_rep_is_lag_netdev
  (jsc#SLE-15172).
- net/mlx5: Verify Hardware supports requested ptp function on
  a given pin (jsc#SLE-15172).
- net/mlx5: Fix a bug of using ptp channel index as pin index
  (jsc#SLE-15172).
- net/mlx5e: Fix missing cleanup of ethtool steering during rep
  rx cleanup (jsc#SLE-15172).
- net/mlx5e: Fix error path of device attach (jsc#SLE-15172).
- net/mlx5: Fix forward to next namespace (jsc#SLE-15172).
- net/mlx5: E-switch, Destroy TSAR after reload interface
  (jsc#SLE-15172).
- flow_offload: Move rhashtable inclusion to the source file
  (bsc#1176447).
- netfilter: nf_tables: fix nat hook table deletion (bsc#1176447).
- net/sched: act_ct: fix restore the qdisc_skb_cb after defrag
  (bsc#1176447).
- net/mlx5e: CT: Fix memory leak in cleanup (jsc#SLE-15172).
- net/mlx5e: Fix port buffers cell size value (jsc#SLE-15172).
- net/mlx5e: Fix usage of rcu-protected pointer (jsc#SLE-15172).
- net/mxl5e: Verify that rpriv is not NULL (jsc#SLE-15172).
- net/mlx5: E-Switch, Fix vlan or qos setting in legacy mode
  (jsc#SLE-15172).
- net/sched: act_ct: add miss tcf_lastuse_update (bsc#1176447).
- net/mlx5e: Do not include rwlock.h directly (jsc#SLE-15172).
- netfilter: conntrack: refetch conntrack after
  nf_conntrack_update() (bsc#1176447).
- netfilter: ipset: call ip_set_free() instead of kfree()
  (bsc#1176447).
- bpf, sockmap: RCU dereferenced psock may be used outside RCU
  block (bsc#1176447).
- bpf, sockmap: RCU splat with redirect and strparser error or
  TLS (bsc#1176447).
- sch_cake: fix a few style nits (bsc#1176447).
- ethtool: fix error handling in linkstate_prepare_data()
  (bsc#1176447).
- netfilter: Add MODULE_DESCRIPTION entries to kernel modules
  (bsc#1176447).
- netfilter: ipset: fix unaligned atomic access (bsc#1176447).
- net: phylink: fix ethtool -A with attached PHYs (bsc#1176447).
- net: ethtool: Handle missing cable test TDR parameters
  (bsc#1176447).
- bnxt_en: Read VPD info only for PFs (jsc#SLE-15075).
- bnxt_en: Fix statistics counters issue during ifdown with
  older firmware (jsc#SLE-15075).
- bnxt_en: Do not enable legacy TX push on older firmware
  (jsc#SLE-15075).
- bnxt_en: Store the running firmware version code
  (jsc#SLE-15075).
- mlxsw: spectrum: Do not rely on machine endianness
  (bsc#1176774).
- net: Add MODULE_DESCRIPTION entries to network modules
  (bsc#1176447).
- net/sched: cls_api: fix nooffloaddevcnt warning dmesg log
  (bsc#1176447).
- net: flow_offload: fix flow_indr_dev_unregister path
  (bsc#1176447).
- flow_offload: use flow_indr_block_cb_alloc/remove function
  (bsc#1176447).
- flow_offload: add flow_indr_block_cb_alloc/remove function
  (bsc#1176447).
- bareudp: Fixed multiproto mode configuration (jsc#SLE-15172).
- net/sched: act_gate: fix configuration of the periodic timer
  (bsc#1176447).
- net/sched: act_gate: fix NULL dereference in tcf_gate_init()
  (bsc#1176447).
- overflow.h: Add flex_array_size() helper (bsc#1176447).
- mlxsw: spectrum: Adjust headroom buffers for 8x ports
  (bsc#1176774).
- bareudp: Fixed configuration to avoid having garbage values
  (jsc#SLE-15172).
- netfilter: flowtable: Make nf_flow_table_offload_add/del_cb
  inline (bsc#1176447).
- net/sched: act_ct: Make tcf_ct_flow_table_restore_skb inline
  (bsc#1176447).
- netfilter: nf_tables: hook list memleak in flowtable deletion
  (bsc#1176447).
- netfilter: ctnetlink: memleak in filter initialization error
  path (bsc#1176447).
- netfilter: nft_set_pipapo: Disable preemption before getting
  per-CPU pointer (bsc#1176447).
- netfilter: nft_set_rbtree: Don't account for expired elements
  on insertion (bsc#1176447).
- net/mlx5: E-Switch, Fix some error pointer dereferences
  (jsc#SLE-15172).
- net/mlx5: Don't fail driver on failure to create debugfs
  (jsc#SLE-15172).
- net/mlx5e: CT: Fix ipv6 nat header rewrite actions
  (jsc#SLE-15172).
- net/mlx5: Fix devlink objects and devlink device unregister
  sequence (jsc#SLE-15172).
- net/mlx5e: Fix ethtool hfunc configuration change
  (jsc#SLE-15172).
- docs: networking: fix extra spaces in ethtool-netlink
  (bsc#1176447).
- net: flow_offload: remove indirect flow_block declarations
  leftover (bsc#1176447).
- net: sched: export __netdev_watchdog_up() (bsc#1176447).
- net: tls: Avoid assigning 'const' pointer to non-const pointer
  (bsc#1176447).
- net: ethtool: Fix comment mentioning typo in IS_ENABLED()
  (bsc#1176447).
- RDMA/cm: Spurious WARNING triggered in cm_destroy_id()
  (jsc#SLE-15176).
- flow_dissector: Pull locking up from prog attach callback
  (bsc#1176447).
- bpf: Fix running sk_skb program types with ktls (bsc#1176447).
- bpf: Refactor sockmap redirect code so its easy to reuse
  (bsc#1176447).
- cls_flower: remove mpls_opts_policy (bsc#1176447).
- flow_dissector: work around stack frame size warning
  (bsc#1176447).
- selftests: mlxsw: Add test for control packets (bsc#1176774).
- mlxsw: spectrum_trap: Register ACL control traps (bsc#1176774).
- mlxsw: spectrum_trap: Register layer 3 control traps
  (bsc#1176774).
- mlxsw: spectrum_trap: Register layer 2 control traps
  (bsc#1176774).
- mlxsw: spectrum_trap: Factor out common Rx listener function
  (bsc#1176774).
- netdevsim: Register control traps (bsc#1176447).
- devlink: Add ACL control packet traps (bsc#1176774).
- devlink: Add layer 3 control packet traps (bsc#1176774).
- devlink: Add layer 2 control packet traps (bsc#1176774).
- devlink: Add 'control' trap type (bsc#1176774).
- devlink: Add 'mirror' trap action (bsc#1176774).
- netdevsim: Move layer 3 exceptions to exceptions trap group
  (bsc#1176447).
- mlxsw: spectrum_trap: Move layer 3 exceptions to exceptions
  trap group (bsc#1176774).
- devlink: Create dedicated trap group for layer 3 exceptions
  (bsc#1176774).
- netfilter: nf_tables: skip flowtable hooknum and priority on
  device updates (bsc#1176447).
- netfilter: nf_tables: allow to register flowtable with no
  devices (bsc#1176447).
- netfilter: nf_tables: delete devices from flowtable
  (bsc#1176447).
- netfilter: nf_tables: add devices to existing flowtable
  (bsc#1176447).
- netfilter: nf_tables: pass hook list to flowtable event notifier
  (bsc#1176447).
- netfilter: nf_tables: add nft_flowtable_hooks_destroy()
  (bsc#1176447).
- netfilter: nf_tables: pass hook list to
  nft_{un,}register_flowtable_net_hooks() (bsc#1176447).
- netfilter: nf_tables: generalise flowtable hook parsing
  (bsc#1176447).
- netfilter: ctnetlink: add kernel side filtering for dump
  (bsc#1176447).
- net: remove indirect block netdev event registration
  (bsc#1176447).
- bnxt_tc: update indirect block support (jsc#SLE-15075).
- nfp: update indirect block support (bsc#1176447).
- mlx5: update indirect block support (jsc#SLE-15172).
- net: use flow_indr_dev_setup_offload() (bsc#1176447).
- net: cls_api: add tcf_block_offload_init() (bsc#1176447).
- net: flow_offload: consolidate indirect flow_block
  infrastructure (jsc#SLE-15075).
- netfilter: nf_flowtable: expose nf_flow_table_gc_cleanup()
  (bsc#1176447).
- selftests: fix flower parent qdisc (bsc#1176447).
- net: phy: fix less than zero comparison with unsigned variable
  val (bsc#1176447).
- net: sched: Do not assume RTNL is held in tunnel key action
  helpers (jsc#SLE-15075).
- tcp: also NULL skb->dev when copy was needed (bsc#1176447).
- tcp: ensure skb->dev is NULL before leaving TCP stack
  (bsc#1176447).
- drivers/net: netdevsim depends on INET (bsc#1176447).
- net: openvswitch: don't unlock mutex when changing the
  user_features fails (jsc#SLE-15172).
- workqueue: Add RCU annotation for pwq list walk (bsc#1176447).
- udp: drop skb extensions before marking skb stateless
  (bsc#1176447).
- net: dsa: Fix off-by-one number of calls to
  devlink_port_unregister (bsc#1176447).
- commit c1e4fb4
* Sun Sep 27 2020 tiwai@suse.de
- soundwire: qcom: add support for SoundWire controller
  (jsc#SLE-16518).
- Update config files.
- commit 8229615
* Sun Sep 27 2020 tiwai@suse.de
- media: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- media: ivtv: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- media: cx18: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- media: cobalt: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- media: tm6000: Clean up ALSA PCM API usages (jsc#SLE-16518).
- media: go7007: Clean up ALSA PCM API usages (jsc#SLE-16518).
- media: em28xx: Clean up ALSA PCM API usages (jsc#SLE-16518).
- media: cs231xx: Clean up ALSA PCM API usages (jsc#SLE-16518).
- media: ivtv: Clean up ALSA PCM API usages (jsc#SLE-16518).
- media: cx18: Clean up ALSA PCM API usages (jsc#SLE-16518).
- media: cobalt: Clean up ALSA PCM API usages (jsc#SLE-16518).
- media: usbtv: Use managed buffer allocation (jsc#SLE-16518).
- media: tw686x: Use managed buffer allocation (jsc#SLE-16518).
- media: solo6x10: Use managed buffer allocation (jsc#SLE-16518).
- staging: bcm2835-audio: Drop superfluous ioctl PCM ops
  (jsc#SLE-16518).
- staging: most: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- staging: bcm2835-audio: Use managed buffer allocation
  (jsc#SLE-16518).
- staging: most: Use managed buffer allocation (jsc#SLE-16518).
- usb: gadget: u_audio: Drop superfluous ioctl PCM ops
  (jsc#SLE-16518).
- usb: gadget: u_audio: Use managed buffer allocation
  (jsc#SLE-16518).
- media: tw686x: audio: Avoid non-standard macro usage
  (jsc#SLE-16518).
- media: solo6x10: Remove superfluous snd_dma_continuous_data()
  (jsc#SLE-16518).
- staging: most: Convert to the common vmalloc memalloc
  (jsc#SLE-16518).
- usb: gadget: u_audio: Remove superfluous
  snd_dma_continuous_data() (jsc#SLE-16518).
- commit 2c47bc5
* Sun Sep 27 2020 tiwai@suse.de
- blacklist.conf: temporarily blacklist sound stuff while backporting
- commit 16f41a1
* Sun Sep 27 2020 tiwai@suse.de
- ALSA: hda/realtek - Enable the headset of Acer N50-600 with
  ALC662 (jsc#SLE-16518).
- ALSA: hda/realtek - Enable headset mic of Acer X2660G with
  ALC662 (jsc#SLE-16518).
- ALSA: seq: oss: Fix running status after receiving sysex
  (jsc#SLE-16518).
- ALSA: seq: virmidi: Fix running status after receiving sysex
  (jsc#SLE-16518).
- ALSA: pcm: oss: Remove WARNING from snd_pcm_plug_alloc() checks
  (jsc#SLE-16518).
- ALSA: hda/realtek: Fix pop noise on ALC225 (jsc#SLE-16518).
- ALSA: line6: Fix endless MIDI read loop (jsc#SLE-16518).
- ALSA: pcm: oss: Avoid plugin buffer overflow (jsc#SLE-16518).
- ASoC: wm8741: Fix typo in Kconfig prompt (jsc#SLE-16518).
- ASoC: stm32: sai: manage rebind issue (jsc#SLE-16518).
- ASoC: SOF: Fix snd_sof_ipc_stream_posn() (jsc#SLE-16518).
- ASoC: rt1015: modify pre-divider for sysclk (jsc#SLE-16518).
- ASoC: rt1015: add operation callback function for rt1015_dai[]
  (jsc#SLE-16518).
- ASoC: soc-component: tidyup snd_soc_pcm_component_sync_stop()
  (jsc#SLE-16518).
- ASoC: dapm: Correct DAPM handling of active widgets during
  shutdown (jsc#SLE-16518).
- ASoC: tas2562: Fix sample rate error message (jsc#SLE-16518).
- ASoC: Intel: Skylake: Fix available clock counter incrementation
  (jsc#SLE-16518).
- ASoC: soc-pcm/soc-compress: don't use snd_soc_dapm_stream_stop()
  (jsc#SLE-16518).
- ASoC: meson: g12a: add tohdmitx reset (jsc#SLE-16518).
- ASoC: pcm512x: Fix unbalanced regulator enable call in probe
  error path (jsc#SLE-16518).
- ASoC: soc-core: fix for_rtd_codec_dai_rollback() macro
  (jsc#SLE-16518).
- ASoC: topology: Fix memleak in soc_tplg_manifest_load()
  (jsc#SLE-16518).
- ASoC: topology: Fix memleak in soc_tplg_link_elems_load()
  (jsc#SLE-16518).
- ASoC: pcm: Fix possible buffer overflow in dpcm state sysfs
  output (jsc#SLE-16518).
- ASoC: intel: skl: Fix possible buffer overflow in debug outputs
  (jsc#SLE-16518).
- ASoC: intel: skl: Fix pin debug prints (jsc#SLE-16518).
- ASoC: tas2562: Return invalid for when bitwidth is invalid
  (jsc#SLE-16518).
- ALSA: sgio2audio: Remove usage of dropped hw_params/hw_free
  functions (jsc#SLE-16518).
- ALSA: hda/realtek - Enable the headset of ASUS B9450FA with
  ALC294 (jsc#SLE-16518).
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus
  Master (jsc#SLE-16518).
- ALSA: hda/realtek - Add Headset Button supported for ThinkPad X1
  (jsc#SLE-16518).
- ALSA: hda/realtek - Add Headset Mic supported (jsc#SLE-16518).
- ALSA: hda/realtek - Fix a regression for mute led on Lenovo
  Carbon X1 (jsc#SLE-16518).
- ASoC: sun8i-codec: Fix setting DAI data format (jsc#SLE-16518).
- ASoC: amd: ACP needs to be powered off in BIOS (jsc#SLE-16518).
- ASoC: hdmi-codec: set plugged_cb to NULL when component removing
  (jsc#SLE-16518).
- ASoC: dapm: remove snd_soc_dapm_put_enum_double_locked
  (jsc#SLE-16518).
- ASoC: max98090: revert invalid fix for handling SHDN
  (jsc#SLE-16518).
- ASoC: codec2codec: avoid invalid/double-free of pcm runtime
  (jsc#SLE-16518).
- ASoC: amd: Buffer Size instead of MAX Buffer (jsc#SLE-16518).
- commit 8c61ed2
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: SOF: Intel: hda: move i915 init earlier (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: fix ordering bug in resume flow
  (jsc#SLE-16518).
- ALSA: hda: do not override bus codec_mask in link_get()
  (jsc#SLE-16518).
- ASoC: atmel: fix atmel_ssc_set_audio link failure
  (jsc#SLE-16518).
- ASoC: fsl_sai: Fix exiting path on probing failure
  (jsc#SLE-16518).
- ALSA: hda: Use scnprintf() for printing texts for sysfs/procfs
  (jsc#SLE-16518).
- ALSA: hda/realtek - Apply quirk for yet another MSI laptop
  (jsc#SLE-16518).
- ALSA: hda/realtek - Apply quirk for MSI GP63, too
  (jsc#SLE-16518).
- ALSA: rawmidi: Avoid bit fields for state flags (jsc#SLE-16518).
- ALSA: seq: Fix concurrent access to queue current tick/time
  (jsc#SLE-16518).
- ALSA: seq: Avoid concurrent access to queue flags
  (jsc#SLE-16518).
- ALSA: pcm: Fix double hw_free calls (jsc#SLE-16518).
- ALSA: usb-audio: Add clock validity quirk for Denon
  MC7000/MCX8000 (jsc#SLE-16518).
- ALSA: hda/realtek - Fix silent output on MSI-GL73
  (jsc#SLE-16518).
- ALSA: hda/realtek - Add more codec supported Headset Button
  (jsc#SLE-16518).
- ALSA: usb-audio: Apply sample rate quirk for Audioengine D1
  (jsc#SLE-16518).
- ALSA: usb-audio: Fix UAC2/3 effect unit parsing (jsc#SLE-16518).
- ALSA: usb-audio: Apply 48kHz fixed rate playback for Jabra
  Evolve 65 headset (jsc#SLE-16518).
- ASoC: wcd934x: Add missing COMMON_CLK dependency to
  SND_SOC_ALL_CODECS (jsc#SLE-16518).
- ALSA: hda: Clear RIRB status before reading WP (jsc#SLE-16518).
- ALSA: hda/realtek - Fixed one of HP ALC671 platform Headset
  Mic supported (jsc#SLE-16518).
- ASoC: wcd934x: Add missing COMMON_CLK dependency
  (jsc#SLE-16518).
- ASoC: tegra: Revert 24 and 32 bit support (jsc#SLE-16518).
- ASoC: SOF: Intel: add PCI ID for JasperLake (jsc#SLE-16518).
- ASoC: rt715: Add __maybe_unused to PM callbacks (jsc#SLE-16518).
- ASoC: rt711: Add __maybe_unused to PM callbacks (jsc#SLE-16518).
- ASoC: rt700: Add __maybe_unused to PM callbacks (jsc#SLE-16518).
- ASoC: rt1308-sdw: Add __maybe_unused to PM callbacks
  (jsc#SLE-16518).
- ASoC: amd: Fix simultaneous playback and capture
  (jsc#SLE-16518).
- ASoC: Intel: consistent HDMI codec probing code (jsc#SLE-16518).
- ASoC: intel: soc-acpi-intel-icl-match: fix rt715 ADR
  (jsc#SLE-16518).
- ASoC: SOF: pci: add missing default_fw_name of JasperLake
  (jsc#SLE-16518).
- ASoC: SOF: trace: fix unconditional free in trace release
  (jsc#SLE-16518).
- ASoC: SOF: core: release resources on errors in probe_continue
  (jsc#SLE-16518).
- ASoC: SOF: core: free trace on errors (jsc#SLE-16518).
- ASoC: SOF: fix an Oops, caused by invalid topology
  (jsc#SLE-16518).
- ASoC: amd: Fix for Subsequent Playback issue (jsc#SLE-16518).
- ASoC: SOF: Intel: do not disable i915 power during probe
  (jsc#SLE-16518).
- ASoC: SOF: Intel: refactor i915_get/put functions
  (jsc#SLE-16518).
- commit 4429299
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: rt1015: Remove unnecessary const (jsc#SLE-16518).
- ASoC: max98090: silence lockdep warning (jsc#SLE-16518).
- ALSA: hda - Fix DP-MST support for NVIDIA codecs
  (jsc#SLE-16518).
- ALSA: hdsp: Make the firmware loading ioctl a bit more readable
  (jsc#SLE-16518).
- ALSA: emu10k1: Fix annotation and cast for the recent uapi
  header change (jsc#SLE-16518).
- ALSA: dummy: Fix PCM format loop in proc output (jsc#SLE-16518).
- ALSA: usb-audio: Annotate endianess in Scarlett gen2 quirk
  (jsc#SLE-16518).
- ALSA: usb-audio: Fix endianess in descriptor validation
  (jsc#SLE-16518).
- ALSA: hda: Add JasperLake PCI ID and codec vid (jsc#SLE-16518).
- ALSA: pcm: Fix sparse warnings wrt snd_pcm_state_t
  (jsc#SLE-16518).
- ALSA: pcm: Fix memory leak at closing a stream without hw_free
  (jsc#SLE-16518).
- ALSA: uapi: Fix sparse warning (jsc#SLE-16518).
- ALSA: hda: Reset stream if DMA RUN bit not cleared
  (jsc#SLE-16518).
- soundwire: cadence: fix kernel-doc parameter descriptions
  (jsc#SLE-16518).
- soundwire: intel: report slave_ids for each link to SOF driver
  (jsc#SLE-16518).
- soundwire: intel: fix factor of two in MCLK handling
  (jsc#SLE-16518).
- soundwire: bus: fix device number leak on errors
  (jsc#SLE-16518).
- soundwire: cadence: remove useless variable incrementation
  (jsc#SLE-16518).
- soundwire: cadence: update kernel-doc parameter descriptions
  (jsc#SLE-16518).
- soundwire: bus: check first if Slaves become UNATTACHED
  (jsc#SLE-16518).
- soundwire: cadence_master: handle multiple status reports per
  Slave (jsc#SLE-16518).
- soundwire: cadence_master: remove config update for interrupt
  setting (jsc#SLE-16518).
- soundwire: cadence_master: log more useful information during
  timeouts (jsc#SLE-16518).
- soundwire: cadence_master: clear interrupt status before
  enabling interrupt (jsc#SLE-16518).
- soundwire: cadence_master: filter out bad interrupts
  (jsc#SLE-16518).
- soundwire: stream: remove redundant pr_err traces
  (jsc#SLE-16518).
- ASoC: soc-core: remove null_snd_soc_ops (jsc#SLE-16518).
- ASoC: soc-pcm: add soc_rtd_trigger() (jsc#SLE-16518).
- commit 97e6ff8
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: Add MediaTek MT6660 Speaker Amp Driver (jsc#SLE-16518).
- Update config files.
- commit b6b8ef2
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: soc-pcm: add soc_rtd_hw_free() (jsc#SLE-16518).
- ASoC: soc-pcm: add soc_rtd_hw_params() (jsc#SLE-16518).
- ASoC: soc-pcm: add soc_rtd_prepare() (jsc#SLE-16518).
- ASoC: soc-pcm: add soc_rtd_shutdown() (jsc#SLE-16518).
- ASoC: soc-pcm: add soc_rtd_startup() (jsc#SLE-16518).
- ASoC: rt1015: add rt1015 amplifier driver (jsc#SLE-16518).
- ASoC: madera: Correct some kernel doc (jsc#SLE-16518).
- ASoC: max98090: fix deadlock in max98090_dapm_put_enum_double()
  (jsc#SLE-16518).
- ASoC: dapm: add snd_soc_dapm_put_enum_double_locked
  (jsc#SLE-16518).
- ASoC: max98090: revert "ASoC: max98090: fix lockdep warning"
  (jsc#SLE-16518).
- ASoC: soc-core: remove bus_control (jsc#SLE-16518).
- ASoC: soc-core: remove DAI suspend/resume (jsc#SLE-16518).
- ASoC: pxa: pxa2xx-i2s: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: pxa: pxa-ssp: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: ux500: ux500_msp_dai: remove unused DAI .suspend/.resume
  (jsc#SLE-16518).
- ASoC: samsung: i2s: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: dwc: dwc-i2s: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: uniphier: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: ti: omap-mcpdm: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: sti: sti_uniperif: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: samsung: spdif: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: samsung: s3c24xx-i2s: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: mediatek: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: jz4740: jz4740-i2s: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: cirrus: ep93xx-i2s: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: atmel: atmel_ssc_dai: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: bcm: cygnus-ssp: move .suspend/.resume to component
  (jsc#SLE-16518).
- ASoC: Intel: cht_bsw_rt5645: Remove unnecessary string buffers
  and snprintf calls (jsc#SLE-16518).
- ASoC: Intel: bytcr_rt5651: Remove unnecessary string buffers
  and snprintf calls (jsc#SLE-16518).
- commit 754a58d
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: Intel: bytcr_rt5640: Remove unnecessary string buffers
  and snprintf calls (jsc#SLE-16518).
- ASoC: Intel: bytcr_rt5640: Remove code duplication in
  byt_rt5640_codec_fixup (jsc#SLE-16518).
- ASoC: msm8916-wcd-analog: Add MIC BIAS Internal3
  (jsc#SLE-16518).
- ASoC: msm8916-wcd-analog: Simplify MIC BIAS Internal
  (jsc#SLE-16518).
- ASoC: amd: Additional DAI for I2S SP instance (jsc#SLE-16518).
- ASoC: rt715: fix return value check in rt715_sdw_probe()
  (jsc#SLE-16518).
- ASoC: rt711: fix return value check in rt711_sdw_probe()
  (jsc#SLE-16518).
- ASoC: rt700: fix return value check in rt700_sdw_probe()
  (jsc#SLE-16518).
- ASoC: rt715: remove unused including <linux/version.h>
  (jsc#SLE-16518).
- ASoC: rt1011: set the different setting for QFN/WLCSP package
  (jsc#SLE-16518).
- ASoC: madera: Correct error path handling in
  madera_out1_demux_put (jsc#SLE-16518).
- ASoC: sgtl5000: add multi endpoint support (jsc#SLE-16518).
- ASoC: fsl_asrc: Add support for imx8qm & imx8qxp
  (jsc#SLE-16518).
- ASoC: sgtl5000: Fix VDDA and VDDIO comparison (jsc#SLE-16518).
- ASoC: codecs: Add jz4770-codec driver (jsc#SLE-16518).
- ASoC: Intel: bytcr_rt5651: remove unused variable
  (jsc#SLE-16518).
- ASoC: Intel: bytcr_rt5640: remove unused variable
  (jsc#SLE-16518).
- ASoC: Intel: bytcht_es8316: removed unused variable
  (jsc#SLE-16518).
- ASoC: Intel: skl_rt286: rename shadowed variable
  (jsc#SLE-16518).
- ASoC: Intel: skl_nau88l25_ssm4567: rename shadowed variable
  (jsc#SLE-16518).
- ASoC: Intel: skl_nau88l25_max98357a: rename shadowed variable
  (jsc#SLE-16518).
- ASOC: Intel: kbl_rt5663_rt5514_max98927: remove useless
  initialization (jsc#SLE-16518).
- ASoC: Intel: kbl_rt5663_rt5514_max98927: rename shadowed
  variable (jsc#SLE-16518).
- ASoC: Intel: kbl_rt5663_max98927: rename shadowed variable
  (jsc#SLE-16518).
- ASoC: Intel: kbl_rt5660: rename shadowed variable
  (jsc#SLE-16518).
- ASoC: Intel: kbl_da7219_max98927: remove unnecessary
  initialization (jsc#SLE-16518).
- ASoC: Intel: kbl_da7219_max98927: rename shadowed variable
  (jsc#SLE-16518).
- ASoC: Intel: kbl_da7219_max98927: test return value on route
  add (jsc#SLE-16518).
- ASoC: Intel: kbl_da7219_max98357a: rename shadowed variable
  (jsc#SLE-16518).
- commit f31c731
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: rt1308-sdw: add rt1308 SdW amplifier driver
  (jsc#SLE-16518).
- Update config files.
- commit 290ac0a
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: Intel: glk_rt5682_max98357a: removed unused variables
  (jsc#SLE-16518).
- ASoC: Intel: glk_rt5682_max98357a: rename shadowed variable
  (jsc#SLE-16518).
- ASoC: Intel: bxt_rt298: rename shadowed variable
  (jsc#SLE-16518).
- ASoC: Intel: bxt_da7219_max98357a: rename shadowed variable
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda-dai: fix compilation warning in
  pcm_prepare (jsc#SLE-16518).
- ASoC: rt715: remove warnings (jsc#SLE-16518).
- ASoC: rt715: use dev_to_sdw_dev() instead of
  to_sdw_slave_device() (jsc#SLE-16518).
- ASoC: rt700: remove unused including <linux/version.h>
  (jsc#SLE-16518).
- ASoC: atmel: fix build error with CONFIG_SND_ATMEL_SOC_DMA=m
  (jsc#SLE-16518).
- commit b2ed8f3
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: SOF: Intel: reference SoundWire machine lists
  (jsc#SLE-16518).
- ASoC: Intel: common: add match tables for TGL w/ SoundWire
  (jsc#SLE-16518).
- ASoC: Intel: common: add match tables for CNL/CFL/CML w/
  SoundWire (jsc#SLE-16518).
- ASoC: Intel: common: add match tables for ICL w/ SoundWire
  (jsc#SLE-16518).
- ASoC: Intel: common: soc-acpi: declare new tables for SoundWire
  (jsc#SLE-16518).
- ASoC: soc-acpi: add _ADR-based link descriptors (jsc#SLE-16518).
- ASoC: SOF: fix PCM playback through ALSA OSS emulation
  (jsc#SLE-16518).
- ASoC: Intel: bdw-rt5650: change cpu_dai and platform components
  for SOF (jsc#SLE-16518).
- ASoC: Intel: broadwell: change cpu_dai and platform components
  for SOF (jsc#SLE-16518).
- ASoC: Intel: bdw-rt5677: change cpu_dai and platform components
  for SOF (jsc#SLE-16518).
- commit 3ad216d
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: rt715: add RT715 codec driver (jsc#SLE-16518).
- Update config files.
- commit ff4c9bf
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: Intel: bdw-rt5677: fix Kconfig dependencies
  (jsc#SLE-16518).
- ASoC: rt711: remove unused including <linux/version.h>
  (jsc#SLE-16518).
- ASoC: txx9: Remove unused rtd variable (jsc#SLE-16518).
- ASoC: soc-pcm/soc-compress: use snd_soc_dapm_stream_stop()
  for SND_SOC_DAPM_STREAM_STOP (jsc#SLE-16518).
- ASoC: soc-dapm: add snd_soc_dapm_stream_stop() (jsc#SLE-16518).
- ASoC: soc-core: add snd_soc_close_delayed_work()
  (jsc#SLE-16518).
- ASoC: soc-core: do pinctrl_pm_select_xxx() as component
  (jsc#SLE-16518).
- ASoC: soc-core: remove duplicate pinctrl operation when suspend
  (jsc#SLE-16518).
- ASoC: soc-core: care .ignore_suspend for Component suspend
  (jsc#SLE-16518).
- commit 8591842
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: rt711: add rt711 codec driver (jsc#SLE-16518).
- Update config files.
- commit 43b42f4
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: rt700: add rt700 codec driver (jsc#SLE-16518).
- Update config files.
- commit 16bd43e
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: soc-core: rename snd_soc_rtdcom_add() to
  snd_soc_rtd_add_component() (jsc#SLE-16518).
- ASoC: soc-core: remove snd_soc_rtdcom_list (jsc#SLE-16518).
- ASoC: max98090: Drop incorrectly applied duplicate commit
  (jsc#SLE-16518).
- soundwire: intel: add clock stop quirks (jsc#SLE-16518).
- soundwire: intel: add mutex for shared SHIM register access
  (jsc#SLE-16518).
- soundwire: intel: add prototype for WAKEEN interrupt processing
  (jsc#SLE-16518).
- soundwire: intel: add link_list to handle interrupts with a
  single thread (jsc#SLE-16518).
- soundwire: intel: update headers for interrupts (jsc#SLE-16518).
- commit 0bedbc2
* Sun Sep 27 2020 tiwai@suse.de
- ASoC: codecs: add wsa881x amplifier support (jsc#SLE-16518).
- Update config files.
- commit 6406216
* Sun Sep 27 2020 tiwai@suse.de
- soundwire: intel: update stream callbacks for hwparams/free
  stream operations (jsc#SLE-16518).
- soundwire: intel: update interfaces between ASoC and SoundWire
  (jsc#SLE-16518).
- soundwire: sdw_slave: track unattach_request to handle all
  init sequences (jsc#SLE-16518).
- soundwire: sdw_slave: add initialization_complete definition
  (jsc#SLE-16518).
- soundwire: sdw_slave: add enumeration_complete structure
  (jsc#SLE-16518).
- soundwire: sdw_slave: add probe_complete structure and new
  fields (jsc#SLE-16518).
- ASoC: max98090: fix lockdep warning (jsc#SLE-16518).
- ASoC: max98090: fix incorrect helper in
  max98090_dapm_put_enum_double() (jsc#SLE-16518).
- ASoC: amd: acp3x: Fix return value check in acp3x_dai_probe()
  (jsc#SLE-16518).
- ASoC: gtm601: fix build warning (jsc#SLE-16518).
- ASoC: SOF: loader: add dynamic debug trace (jsc#SLE-16518).
- ASoC: SOF: pci: change the default firmware path when the
  community key is used (jsc#SLE-16518).
- ASoC: Intel: sof_rt5682: Ignore the speaker amp when there
  isn't one (jsc#SLE-16518).
- ASoC: soc-topology: fix endianness issues (jsc#SLE-16518).
- ASoC: Intel: boards: hda_dsp_common: use NULL pointer
  assignment, not 0 (jsc#SLE-16518).
- ASoC: SOF: imx8: use resource_size (jsc#SLE-16518).
- ASoC: qdsp6: q6asm-dai: constify copied structure
  (jsc#SLE-16518).
- ASoC: amd MMAP_INTERLEAVED Support (jsc#SLE-16518).
- ASoC: amd: Added ACP3x system resume and runtime pm
  (jsc#SLE-16518).
- ASoC: amd: Handle ACP3x I2S-SP Interrupts (jsc#SLE-16518).
- ASoC: amd: add ACP3x TDM mode support (jsc#SLE-16518).
- ASoC: amd: Enabling I2S instance in DMA and DAI (jsc#SLE-16518).
- ASoC: amd: Refactoring of DAI from DMA driver (jsc#SLE-16518).
- ASoC: madera: Enable clocks for input pins when used for the
  FLL (jsc#SLE-16518).
- ASoC: madera: Enable clocks for input pins when used as a
  direct clock (jsc#SLE-16518).
- ASoC: cs47l92: Simplify error handling code in 'cs47l92_probe()'
  (jsc#SLE-16518).
- ASoC: amd: Create multiple I2S platform device endpoint
  (jsc#SLE-16518).
- ASoC: qcom: sdm845: add support to DB845c and Lenovo Yoga
  (jsc#SLE-16518).
- commit 8f83834
* Sun Sep 27 2020 lduncan@suse.com
- scsi: target: cxgbit: Remove tx flow control code (bsc#1177002
  jsc#sle-15119).
- scsi: target: cxgbit: Check connection state before issuing
  hardware command (bsc#1177002 jsc#sle-15119).
- commit 95499d6
* Sat Sep 26 2020 tiwai@suse.de
- ASoC: wcd934x: add audio routings (jsc#SLE-16518).
- ASoC: wcd934x: add capture dapm widgets (jsc#SLE-16518).
- ASoC: wcd934x: add playback dapm widgets (jsc#SLE-16518).
- ASoC: wcd934x: add basic controls (jsc#SLE-16518).
- ASoC: wcd934x: add support to wcd9340/wcd9341 codec
  (jsc#SLE-16518).
- ASoC: gtm601: add Broadmobi bm818 sound profile (jsc#SLE-16518).
- ASoC: Intel: kbl_da7219_max98357a: remove unused variable
  'constraints_16000' and 'ch_mono' (jsc#SLE-16518).
- ASoC: hdac_hda: Update hdac hda dai table to include
  intel-hdmi-hifi4 (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Add iDisp4 DAI (jsc#SLE-16518).
- ASoC: max98090: Remove empty suspend function (jsc#SLE-16518).
- commit 4416929
* Sat Sep 26 2020 tiwai@suse.de
- ASoC: intel: Add Broadwell rt5650 machine driver
  (jsc#SLE-16518).
- Update config files.
- commit 0552cc8
* Sat Sep 26 2020 tiwai@suse.de
- ASoC: SOF: move arch_ops under ops (jsc#SLE-16518).
- ASoC: meson: axg-fifo: relax period size constraints
  (jsc#SLE-16518).
- ASoC: meson: axg-fifo: improve depth handling (jsc#SLE-16518).
- ASoC: meson: axg-fifo: fix fifo threshold setup (jsc#SLE-16518).
- ASoC: SOF: imx: Read SAI parameters and send them to DSP
  (jsc#SLE-16518).
- ASoC: SOF: imx: Describe SAI parameters to be sent to DSP
  (jsc#SLE-16518).
- commit 644b556
* Sat Sep 26 2020 tiwai@suse.de
- ASoC: Intel: Add machine driver for da7219_max98373
  (jsc#SLE-16518).
- Update config files.
- commit de25b25
* Sat Sep 26 2020 tiwai@suse.de
- ASoC: Intel: boards: fix incorrect HDMI Kconfig dependency
  (jsc#SLE-16518).
- ASoC: SOF: Intel: drop HDA codec upon probe failure
  (jsc#SLE-16518).
- ASoC: SOF: log compiler name and version information
  (jsc#SLE-16518).
- ASoC: SOF: define struct with compiler name and version
  (jsc#SLE-16518).
- ASoC: SOF: Introduce state machine for FW boot (jsc#SLE-16518).
- ASoC: SOF: remove references to Haswell (jsc#SLE-16518).
- commit a7100dc
* Sat Sep 26 2020 tiwai@suse.de
- ASoC: Intel: cml_rt1011_rt5682: fix codec_conf by removing
  legacy style (jsc#SLE-16518).
- ASoC: compress: Add pm_runtime support (jsc#SLE-16518).
- ASoC: intel: skylake: Remove superfluous bus ops
  (jsc#SLE-16518).
- ASoC: soc-core: remove legacy style of codec_conf
  (jsc#SLE-16518).
- ASoC: ti: rx51: use snd_soc_dai_link_component for codec_conf
  (jsc#SLE-16518).
- ASoC: samsung: speyside: use snd_soc_dai_link_component for
  codec_conf (jsc#SLE-16518).
- ASoC: samsung: neo1973_wm8753: use snd_soc_dai_link_component
  for codec_conf (jsc#SLE-16518).
- ASoC: samsung: lowland: use snd_soc_dai_link_component for
  codec_conf (jsc#SLE-16518).
- ASoC: samsung: bells: use snd_soc_dai_link_component for
  codec_conf (jsc#SLE-16518).
- commit 4a6222f
* Sat Sep 26 2020 tiwai@suse.de
- ASoC: mediatek: mt8183-da7219-max98357: use
  snd_soc_dai_link_component for codec_conf (jsc#SLE-16518).
- ASoC: mediatek: mt8173-rt5650-rt5676: use
  snd_soc_dai_link_component for codec_conf (jsc#SLE-16518).
- ASoC: mediatek: mt8173-rt5650-rt5514: use
  snd_soc_dai_link_component for codec_conf (jsc#SLE-16518).
- ASoC: intel: skl_nau88l25_ssm4567: use
  snd_soc_dai_link_component for codec_conf (jsc#SLE-16518).
- ASoC: intel: kbl_rt5663_rt5514_max98927: use
  snd_soc_dai_link_component for codec_conf (jsc#SLE-16518).
- ASoC: intel: kbl_rt5663_max98927: use snd_soc_dai_link_component
  for codec_conf (jsc#SLE-16518).
- ASoC: intel: kbl_da7219_max98927: use snd_soc_dai_link_component
  for codec_conf (jsc#SLE-16518).
- ASoC: fsl: imx-audmix: use snd_soc_dai_link_component for
  codec_conf (jsc#SLE-16518).
- ASoC: soc-core: support snd_soc_dai_link_component for
  codec_conf (jsc#SLE-16518).
- ASoC: SOF: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: mediatek: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: Drop snd_soc_pcm_lib_ioctl() (jsc#SLE-16518).
- ASoC: uniphier: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: sh: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: uniphier: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: siu_pcm: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: fsi: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: intel: skylake: Use managed buffer allocation
  (jsc#SLE-16518).
- ASoC: intel: haswell: Use managed buffer allocation
  (jsc#SLE-16518).
- ASoC: intel: baytrail: Use managed buffer allocation
  (jsc#SLE-16518).
- ASoC: intel: atom: Use managed buffer allocation
  (jsc#SLE-16518).
- ASoC: rt5677-spi: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: rt5514-spi: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: xtensa: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: xilinx: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: txx9: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: stm32: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: generic-dmaengine-pcm: Use managed buffer allocation
  (jsc#SLE-16518).
- ASoC: rcar: Use managed buffer allocation (jsc#SLE-16518).
- commit 4a4cad5
* Sat Sep 26 2020 tiwai@suse.de
- ASoC: dma-sh7760: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: meson: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: dwc: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: au1x: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: soc-core: tidyup for CONFIG_DEBUG_FS (jsc#SLE-16518).
- ASoC: soc-core: tidyup for CONFIG_DMI (jsc#SLE-16518).
- ASoC: soc-core: merge soc_set_name_prefix() and
  soc_set_of_name_prefix() (jsc#SLE-16518).
- ASoC: utils: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: xtensa: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: xilinx: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: txx9: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: sprd: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: SOF: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: generic-dmaengine: Drop superfluous ioctl PCM ops
  (jsc#SLE-16518).
- ASoC: samsung: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: qcom: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: pxa: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: meson: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: mediatek: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: kirkwood: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: intel: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: fsl: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: dwc: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: bcm: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: au1x: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: atmel: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: amd: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ASoC: amd: Use managed buffer allocation (jsc#SLE-16518).
- ASoC: SOF: Intel: byt: fixup topology filename for BYT-CR
  (jsc#SLE-16518).
- ASoC: soc-core: soc_set_name_prefix(): get component device_node
  at out of loop (jsc#SLE-16518).
- commit 8ed00d9
* Sat Sep 26 2020 tiwai@suse.de
- ASoC: soc-core: soc_set_name_prefix(): tidyup loop condition
  (jsc#SLE-16518).
- ASoC: soc-core: rename soc_link_init() to soc_init_pcm_runtime()
  (jsc#SLE-16518).
- ASoC: soc-core: add missing return value check for
  soc_link_init() (jsc#SLE-16518).
- ASoC: soc-core: move soc_link_init() (jsc#SLE-16518).
- ASoC: soc-core: rename soc_link_dai_pcm_new() to
  soc_dai_pcm_new() (jsc#SLE-16518).
- ASoC: soc-core: move soc_link_dai_pcm_new() (jsc#SLE-16518).
- ASoC: soc-core: rename snd_soc_remove_dai_link() to
  snd_soc_remove_pcm_runtime() (jsc#SLE-16518).
- ASoC: soc-core: rename snd_soc_add_dai_link() to
  snd_soc_add_pcm_runtime() (jsc#SLE-16518).
- ASoC: soc-core: move snd_soc_find_dai_link() (jsc#SLE-16518).
- ASoC: soc-core: find rtd via dai_link pointer at
  snd_soc_get_pcm_runtime() (jsc#SLE-16518).
- commit 6d56a63
* Sat Sep 26 2020 tiwai@suse.de
- ASoC: soc-core: move snd_soc_get_pcm_runtime() (jsc#SLE-16518).
- ASoC: soc-core: remove snd_soc_get_dai_substream()
  (jsc#SLE-16518).
- ASoC: soc-core: remove snd_soc_disconnect_sync()
  (jsc#SLE-16518).
- ASoC: soc-core: remove dai_link_list (jsc#SLE-16518).
- ASoC: SOF: Intel: add codec_mask module parameter
  (jsc#SLE-16518).
- ASoC: SOF: ipc: channel map structures (jsc#SLE-16518).
- ASoC: SOF: Add asynchronous sample rate converter topology
  support (jsc#SLE-16518).
- ASoC: SOF: nocodec: Amend arguments for sof_nocodec_setup()
  (jsc#SLE-16518).
- ASoC: SOF: Remove unused drv_name in sof_pdata (jsc#SLE-16518).
- ASoC: SOF: remove nocodec_fw_filename (jsc#SLE-16518).
- commit e9bfecc
* Sat Sep 26 2020 tiwai@suse.de
- ASoC: Intel - do not describe I/O configuration in the long
  card name (jsc#SLE-16518).
- Update config files.
- commit 9e1831b
* Sat Sep 26 2020 tiwai@suse.de
- ASoC: SOF: Make creation of machine device from SOF core
  optional (jsc#SLE-16518).
- ASoC: SOF: intel: hda: Modify signature for
  hda_codec_probe_bus() (jsc#SLE-16518).
- ASoC: SOF: partition audio-related parts from SOF core
  (jsc#SLE-16518).
- ASoC: SOF: Introduce default_fw_filename member in sof_dev_desc
  (jsc#SLE-16518).
- ASoC: SOF: core: move check for runtime callbacks to core
  (jsc#SLE-16518).
- ASoC: SOF: core: modify the signature for
  snd_sof_create_page_table (jsc#SLE-16518).
- ASoC: SOF: topology: remove snd_sof_init_topology()
  (jsc#SLE-16518).
- ASoC: Intel - use control components to describe card config
  (jsc#SLE-16518).
- ASoC: intel/skl/hda - export number of digital microphones
  via control components (jsc#SLE-16518).
- commit 8f7730d
* Sat Sep 26 2020 tiwai@suse.de
- ASoC: hdmi-codec: re-introduce mutex locking again
  (jsc#SLE-16518).
- ASoC: fix soc-core.c kernel-doc warning (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: solve MSI issues by merging ipc and
  stream irq handlers (jsc#SLE-16518).
- ASoC: ti: davinci-mcasp: Improve the sysclk selection
  (jsc#SLE-16518).
- ASoC: cs42l51: add dac mux widget in codec routes
  (jsc#SLE-16518).
- ASoC: rsnd: Calculate DALIGN inversion at run-time
  (jsc#SLE-16518).
- ASoC: tlv320aic31xx: Add Volume Soft Stepping control
  (jsc#SLE-16518).
- ASoC: max98090: save and restore SHDN when changing sensitive
  registers (jsc#SLE-16518).
- ASoC: fsl_sai: add IRQF_SHARED (jsc#SLE-16518).
- ASoC: tlv320aic31xx: Add HP output driver pop reduction controls
  (jsc#SLE-16518).
- ASoC: mediatek: common: refine hw_params and hw_prepare
  (jsc#SLE-16518).
- ASoC: mediatek: common: add some helpers to control mtk_memif
  (jsc#SLE-16518).
- ASoC: hdac_hdmi: Drop support for Icelake (jsc#SLE-16518).
- ASoC: Intel: boards: make common HDMI driver the default for
  SOF (jsc#SLE-16518).
- ASoC: SOF: Intel: make common HDMI driver default
  (jsc#SLE-16518).
- ASoC: Intel: common: Add mach table for tgl-max98357a-rt5682
  (jsc#SLE-16518).
- ASoC: intel: sof_rt5682: Add support for tgl-max98357a-rt5682
  (jsc#SLE-16518).
- ASoC: intel: sof_rt5682: Add quirk for number of HDMI DAI's
  (jsc#SLE-16518).
- ASoC: topology: fix soc_tplg_fe_link_create() - link->dobj
  initialization order (jsc#SLE-16518).
- ASoC: Intel: skl_hda_dsp_common: Fix global-out-of-bounds bug
  (jsc#SLE-16518).
- commit 98c735e
* Sat Sep 26 2020 tiwai@suse.de
- ALSA: hda: Allow setting preallocation again for x86
  (jsc#SLE-16518).
- ASoC: madera: Correct DMIC only input hook ups (jsc#SLE-16518).
- ASoC: soc-generic-dmaengine-pcm: Fix error handling
  (jsc#SLE-16518).
- ASoC: soc-pcm: crash in snd_soc_dapm_new_dai (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Fix SKL dai count (jsc#SLE-16518).
- ASoC: madera: Update handling of DAPM routes for mono muxed
  outputs (jsc#SLE-16518).
- ASoC: wm_adsp: Correct cache handling of new kernel control API
  (jsc#SLE-16518).
- ALSA: usb-audio: add quirks for Line6 Helix devices fw>=2.82
  (jsc#SLE-16518).
- ALSA: hda: Add Clevo W65_67SB the power_save blacklist
  (jsc#SLE-16518).
- ALSA: hda - Add docking station support for Lenovo Thinkpad
  T420s (jsc#SLE-16518).
- ALSA: cs46xx: fix spelling mistake "to" -> "too"
  (jsc#SLE-16518).
- commit 2169757
* Sat Sep 26 2020 tiwai@suse.de
- ALSA: hda/hdmi - add retry logic to parse_intel_hdmi()
  (jsc#SLE-16518).
- ALSA: hda: No preallocation on x86 platforms (jsc#SLE-16518).
- ALSA: pcm: Set per-card upper limit of PCM buffer allocations
  (jsc#SLE-16518).
- ALSA: hda: Apply aligned MMIO access only conditionally
  (jsc#SLE-16518).
- ALSA: hda/realtek - Add Headset Mic supported for HP cPC
  (jsc#SLE-16518).
- ALSA: pcm: Make snd_pcm_hw_constraints_init() and _complete()
  static (jsc#SLE-16518).
- ALSA: hda/analog - Minor optimization for SPDIF mux connections
  (jsc#SLE-16518).
- ALSA: usb-audio: add implicit fb quirk for MOTU M Series
  (jsc#SLE-16518).
- ALSA: usb-audio: unlock on error in probe (jsc#SLE-16518).
- ALSA: hda: patch_hdmi: remove warnings with empty body
  (jsc#SLE-16518).
- ALSA: hda: correct kernel-doc parameter descriptions
  (jsc#SLE-16518).
- ALSA: hda: Update kernel-doc function parameter descriptions
  (jsc#SLE-16518).
- ALSA: hda: Manage concurrent reg access more properly
  (jsc#SLE-16518).
- ALSA: usb-audio: Add boot quirk for MOTU M Series
  (jsc#SLE-16518).
- ALSA: dice: add support for Alesis MasterControl
  (jsc#SLE-16518).
- ALSA: dice: loosen stream format check for MIDI conformant
  data channel (jsc#SLE-16518).
- ALSA: oxfw: fix for Stanton SCS.1d (jsc#SLE-16518).
- ALSA: oxfw: don't add MIDI/PCM interface when packet streaming
  is unavailable (jsc#SLE-16518).
- ALSA: oxfw: use ENXIO for not-supported cases (jsc#SLE-16518).
- ALSA: usb: update old-style static const declaration
  (jsc#SLE-16518).
- commit 401ab42
* Sat Sep 26 2020 tiwai@suse.de
- ALSA: hda: patch_realtek: fix empty macro usage in if block
  (jsc#SLE-16518).
- ALSA: timer: fix nsec/sec initialization confusion
  (jsc#SLE-16518).
- ALSA: hda: Fix a typo in comments (jsc#SLE-16518).
- ALSA: pci: echoaudio: remove set but not used variable 'chip'
  (jsc#SLE-16518).
- ALSA: control: potential uninitialized return value
  (jsc#SLE-16518).
- ALSA: sh: Fix compile warning wrt const (jsc#SLE-16518).
- ALSA: spi: More constification (jsc#SLE-16518).
- ALSA: pdaudiocf: More constification (jsc#SLE-16518).
- ALSA: via82xx: More constification (jsc#SLE-16518).
- ALSA: fm801: More constification (jsc#SLE-16518).
- ALSA: ens137x: More constification (jsc#SLE-16518).
- ALSA: echoaudio: More constification (jsc#SLE-16518).
- ALSA: cs4281: More constification (jsc#SLE-16518).
- ALSA: azt3328: More constification (jsc#SLE-16518).
- ALSA: ak4531: More constification (jsc#SLE-16518).
- ALSA: serial-u16550: More constification (jsc#SLE-16518).
- ALSA: opl4: More constification (jsc#SLE-16518).
- ALSA: arm: More constification (jsc#SLE-16518).
- ALSA: lx6464es: More constifications (jsc#SLE-16518).
- ALSA: aw2: More constifications (jsc#SLE-16518).
- ALSA: mts64: More constifications (jsc#SLE-16518).
- ALSA: sc6000: More constification (jsc#SLE-16518).
- ALSA: wss: More constifications (jsc#SLE-16518).
- ALSA: opti9xx: More constifications (jsc#SLE-16518).
- ALSA: gus: More constifications (jsc#SLE-16518).
- ALSA: es18xx: More constifications (jsc#SLE-16518).
- ALSA: es1688: More constifications (jsc#SLE-16518).
- ALSA: cmi8330: More constifications (jsc#SLE-16518).
- ALSA: sb: More constifications (jsc#SLE-16518).
- ALSA: cs423x: More constification (jsc#SLE-16518).
- ALSA: cmi8328: More constifications (jsc#SLE-16518).
- ALSA: opl3: More constifications (jsc#SLE-16518).
- ALSA: rawmidi: More constification (jsc#SLE-16518).
- ALSA: oss: More constifications (jsc#SLE-16518).
- ALSA: jack: More constification (jsc#SLE-16518).
- ALSA: info: More constifications (jsc#SLE-16518).
- ALSA: sparc: More constifications (jsc#SLE-16518).
- ALSA: cmipci: More constifications (jsc#SLE-16518).
- ALSA: es1968: More constifications (jsc#SLE-16518).
- ALSA: es1938: More constifications (jsc#SLE-16518).
- ALSA: atiixp: More constifications (jsc#SLE-16518).
- ALSA: asihpi: More constifications (jsc#SLE-16518).
- ALSA: ctxfi: More constifications (jsc#SLE-16518).
- ALSA: ca0106: More constifications (jsc#SLE-16518).
- ALSA: cs46xx: More constifications (jsc#SLE-16518).
- ALSA: korg1212: More constifications (jsc#SLE-16518).
- ALSA: nm256: More constifications (jsc#SLE-16518).
- ALSA: bcd2000: More constifications (jsc#SLE-16518).
- ALSA: ymfpci: More constifications (jsc#SLE-16518).
- ALSA: mixart: More constifications (jsc#SLE-16518).
- ALSA: pcxhr: More constifications (jsc#SLE-16518).
- ALSA: usx2y: More constifications (jsc#SLE-16518).
- ALSA: emux: More constifications (jsc#SLE-16518).
- ALSA: rme9652: More constifications (jsc#SLE-16518).
- ALSA: hdspm: More constifications (jsc#SLE-16518).
- ALSA: hdsp: More constifications (jsc#SLE-16518).
- ALSA: ppc: More constifications (jsc#SLE-16518).
- ALSA: ice1712: More constifications (jsc#SLE-16518).
- ALSA: riptide: More constifications (jsc#SLE-16518).
- ALSA: emu10k1: More constifications (jsc#SLE-16518).
- ALSA: au88x0: More constifications (jsc#SLE-16518).
- ALSA: caiaq: More constifications (jsc#SLE-16518).
- ALSA: usb-audio: More constifications (jsc#SLE-16518).
- ALSA: ac97: More constifications (jsc#SLE-16518).
- ALSA: hda: More constifications (jsc#SLE-16518).
- ALSA: intel8x0: More constifications (jsc#SLE-16518).
- ALSA: vx: More constifications (jsc#SLE-16518).
- ALSA: seq: More constifications (jsc#SLE-16518).
- ALSA: pcm: More constifications (jsc#SLE-16518).
- ALSA: dummy: More constifications (jsc#SLE-16518).
- commit 010a379
* Sat Sep 26 2020 tiwai@suse.de
- ALSA: control: Add verification for kctl accesses
  (jsc#SLE-16518).
- Update config files.
- commit f4d3f65
* Sat Sep 26 2020 tiwai@suse.de
- ALSA: hda/realtek - More constifications (jsc#SLE-16518).
- ALSA: aoa: More constifications (jsc#SLE-16518).
- ALSA: Allow const arrays for legacy resource management helpers
  (jsc#SLE-16518).
- ALSA: usb-audio: Use lower hex numbers for IDs (jsc#SLE-16518).
- ALSA: hda/realtek - Apply mic mute LED quirk for Dell E7xx
  laptops, too (jsc#SLE-16518).
- ALSA: sh: Fix unused variable warnings (jsc#SLE-16518).
- ALSA: hda - constify and cleanup static NodeID tables
  (jsc#SLE-16518).
- ALSA: pci: Constify snd_pci_quirk tables (jsc#SLE-16518).
- ALSA: hda: Constify snd_pci_quirk tables (jsc#SLE-16518).
- ALSA: fm801: Constify snd_fm801_tea575x_gpios (jsc#SLE-16518).
- ALSA: es1968: Constify snd_es1968_tea575x_gpios (jsc#SLE-16518).
- ALSA: emu10k1: Constify snd_emu_chip_details (jsc#SLE-16518).
- ALSA: bt87x: Constify snd_bt87x_boards (jsc#SLE-16518).
- ALSA: seq: oss: Constify snd_seq_oss_callback definitions
  (jsc#SLE-16518).
- ALSA: usx2y: Constify struct snd_usb_audio_quirk entries
  (jsc#SLE-16518).
- ALSA: line6: Constify snd_ratden definitions (jsc#SLE-16518).
- ALSA: ice1712: Constify wm-specific tables (jsc#SLE-16518).
- ALSA: ice17xx: Constify snd_ice1712_card_info (jsc#SLE-16518).
- ALSA: ca0106: Constify snd_ca0106_details (jsc#SLE-16518).
- ALSA: ca0106: Constify snd_ca0106_category_str items
  (jsc#SLE-16518).
- ALSA: ac97: Constify snd_ac97_res_table definition
  (jsc#SLE-16518).
- ALSA: opl3: Constify snd_opl3_drum_voice definitions
  (jsc#SLE-16518).
- ALSA: dummy: Constify snd_pcm_ops definitions (jsc#SLE-16518).
- ALSA: parisc: Constify snd_kcontrol_new items (jsc#SLE-16518).
- ALSA: usb: Constify snd_kcontrol_new items (jsc#SLE-16518).
- ALSA: spi: Constify snd_kcontrol_new items (jsc#SLE-16518).
- ALSA: sparc: Constify snd_kcontrol_new items (jsc#SLE-16518).
- ALSA: ppc: Constify snd_kcontrol_new items (jsc#SLE-16518).
- ALSA: pci: Constify snd_kcontrol_new items (jsc#SLE-16518).
- ALSA: hda: Constify snd_kcontrol_new items (jsc#SLE-16518).
- ALSA: isa: Constify snd_kcontrol_new items (jsc#SLE-16518).
- ALSA: i2c: Constify snd_kcontrol_new items (jsc#SLE-16518).
- ALSA: drivers: Constify snd_kcontrol_new items (jsc#SLE-16518).
- ALSA: aoa: Constify snd_kcontrol_new items (jsc#SLE-16518).
- ALSA: mixer: oss: Constify snd_mixer_oss_assign_table definition
  (jsc#SLE-16518).
- ALSA: vx: Constify snd_vx_hardware and snd_vx_ops definitions
  (jsc#SLE-16518).
- ALSA: seq: Constify struct snd_midi_op (jsc#SLE-16518).
- ALSA: info: Make snd_info_entry_ops as const (jsc#SLE-16518).
- ALSA: pci: Constify snd_ac97_bus_ops definitions
  (jsc#SLE-16518).
- ALSA: drivers: Constify snd_ac97_bus_ops definitions
  (jsc#SLE-16518).
- ALSA: atmel: Constify snd_ac97_bus_ops definitions
  (jsc#SLE-16518).
- ALSA: arm: Constify snd_ac97_bus_ops definitions
  (jsc#SLE-16518).
- ALSA: ac97: Constify snd_ac97_bus_ops definitions
  (jsc#SLE-16518).
- ALSA: ac97: Treat snd_ac97_bus_ops as const (jsc#SLE-16518).
- ALSA: Constify snd_timer_hardware definitions (jsc#SLE-16518).
- ALSA: timer: Constify snd_timer_hardware definitions
  (jsc#SLE-16518).
- ALSA: spi: Constify snd_device_ops definitions (jsc#SLE-16518).
- ALSA: sh: Constify snd_device_ops definitions (jsc#SLE-16518).
- ALSA: sparc: Constify snd_device_ops definitions
  (jsc#SLE-16518).
- commit dd95689
* Sat Sep 26 2020 tiwai@suse.de
- ALSA: usb-audio: Support PCM sync_stop (jsc#SLE-16518).
- commit 8824797
* Sat Sep 26 2020 tiwai@suse.de
- ALSA: ppc: Constify snd_device_ops definitions (jsc#SLE-16518).
- ALSA: pcmcia: Constify snd_device_ops definitions
  (jsc#SLE-16518).
- ALSA: parisc: Constify snd_device_ops definitions
  (jsc#SLE-16518).
- ALSA: mips: Constify snd_device_ops definitions (jsc#SLE-16518).
- ALSA: aoa: Constify snd_device_ops definitions (jsc#SLE-16518).
- ALSA: usb: Constify snd_device_ops definitions (jsc#SLE-16518).
- ALSA: pci: Constify snd_device_ops definitions (jsc#SLE-16518).
- ALSA: hda: Constify snd_device_ops definitions (jsc#SLE-16518).
- ALSA: isa: Constify snd_device_ops definitions (jsc#SLE-16518).
- ALSA: i2c: Constify snd_device_ops definitions (jsc#SLE-16518).
- ALSA: drivers: Constify snd_device_ops definitions
  (jsc#SLE-16518).
- ALSA: core: Constify snd_device_ops definitions (jsc#SLE-16518).
- ALSA: core: Treat snd_device_ops as const (jsc#SLE-16518).
- ALSA: usb: Constify snd_pcm_hardware definitions
  (jsc#SLE-16518).
- ALSA: pci: Constify snd_pcm_hardware definitions
  (jsc#SLE-16518).
- ALSA: hda: constify copied structure (jsc#SLE-16518).
- ALSA: ad1816a: constify copied structure (jsc#SLE-16518).
- ALSA: uapi: Add linux/types.h include back (but carefully)
  (jsc#SLE-16518).
- ALSA: usb-audio: fix Corsair Virtuoso mixer label collision
  (jsc#SLE-16518).
- ALSA: control: Fix incompatible protocol error (jsc#SLE-16518).
- ALSA: ctl: allow TLV read operation for callback type of
  element in locked case (jsc#SLE-16518).
- ALSA: ctl: bump protocol version up to v2.1.0 (jsc#SLE-16518).
- ALSA: ctl: remove dimen member from elem_info structure
  (jsc#SLE-16518).
- ALSA: pci: echoaudio: remove usage of dimen menber of elem_value
  structure (jsc#SLE-16518).
- ALSA: ctl: remove unused macro for timestamping of elem_value
  (jsc#SLE-16518).
- ALSA: uapi: Drop unneeded typedefs (jsc#SLE-16518).
- ALSA: uapi: Drop asound.h inclusion from asoc.h (jsc#SLE-16518).
- ALSA: uapi: Fix typos and header inclusion in asound.h
  (jsc#SLE-16518).
- ALSA: hdspm: Drop linux/types.h inclusion in uapi header
  (jsc#SLE-16518).
- ALSA: hdsp: Make uapi/hdsp.h compilable again (jsc#SLE-16518).
- ALSA: emu10k1: Make uapi/emu10k1.h compilable again
  (jsc#SLE-16518).
- ALSA: usx2y: Adjust indentation in snd_usX2Y_hwdep_dsp_status
  (jsc#SLE-16518).
- ALSA: bump uapi version numbers (jsc#SLE-16518).
- ALSA: add new 32-bit layout for snd_pcm_mmap_status/control
  (jsc#SLE-16518).
- ALSA: move snd_pcm_ioctl_sync_ptr_compat into pcm_native.c
  (jsc#SLE-16518).
- ALSA: Avoid using timespec for struct snd_timer_tread
  (jsc#SLE-16518).
- ALSA: Avoid using timespec for struct snd_rawmidi_status
  (jsc#SLE-16518).
- ALSA: Avoid using timespec for struct snd_pcm_status
  (jsc#SLE-16518).
- ALSA: Avoid using timespec for struct snd_ctl_elem_value
  (jsc#SLE-16518).
- ALSA: Avoid using timespec for struct snd_timer_status
  (jsc#SLE-16518).
- ALSA: Replace timespec with timespec64 (jsc#SLE-16518).
- ALSA: cmipci: Allow disabling MPU port via module option
  (jsc#SLE-16518).
- ALSA: hda: Comment about snd_hdac_bus_update_rirb() and spinlock
  (jsc#SLE-16518).
- ALSA: control: remove useless assignment in .info callback of
  PCM chmap element (jsc#SLE-16518).
- ALSA: hda: Unify get_response handling (jsc#SLE-16518).
- ALSA: hda: Use waitqueue for RIRB in HDA-core helper, too
  (jsc#SLE-16518).
- ALSA: hda: tegra: Fix unused variable compile warning
  (jsc#SLE-16518).
- ALSA: vxpocket: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: pdaudiocf: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: vx222: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: pcxhr: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: mixart: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: lx6464es: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: wss: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: wavefront: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: sb: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: opti9xx: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: opl3sa2: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: msnd: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: gus: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: es18xx: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: es1688: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: ad1816a: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: ymfpci: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: via82xx: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: trident: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: sonicvibes: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: sis7019: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: rme9652: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: rme96: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: rme32: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: riptide: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: oxygen: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: nm256: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: maestro3: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: lola: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: korg1212: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: intel8x0: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: ice1724: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: ice1712: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: hda: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: fm801: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: es1968: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: es1938: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: ens137x: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: emu10k1: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: echoaudio: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: ctxfi: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: cs5535audio: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: cs46xx: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: cs4281: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: cmipci: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: ca0106: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: bt87x: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: azt3328: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: aw2: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: au88x0: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: atiixp: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: als300: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: ali5451: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: ad1889: Support PCM sync_stop (jsc#SLE-16518).
- ALSA: xen: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: x86: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: usb: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: spi: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: sparc: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: sh: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: ppc: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: pcmcia: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: pci: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: trident: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: asihpi: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: atiixp: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: via82xx: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: intel8x0: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: parisc: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: mips: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: isa: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: es1688: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: firewire: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: drivers: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: atmel: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: arm: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: aoa: Drop superfluous ioctl PCM ops (jsc#SLE-16518).
- ALSA: hdml-lpe-audio: Use managed buffer allocation
  (jsc#SLE-16518).
- ALSA: pcxhr: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: usb-audio: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: usx2y: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: ua101: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: line6: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: hiface: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: caiaq: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: 6fire: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: spi: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: sparc: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: sh: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: aica: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: ps3: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: pmac: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: pdaudiocf: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: ymfpci: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: via82xx: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: trident: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: sonicvibes: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: sis7019: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: rme32: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: riptide: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: oxygen: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: mixart: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: maestro3: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: lx6464es: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: lola: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: intel8x0: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: ice1724: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: ice1712: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: hda: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: fm801: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: es1938: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: ens137x: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: emu10k1: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: emu10k1x: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: echoaudio: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: ctxfi: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: cs5535: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: cs4281: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: cmipci: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: ca0106: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: bt87x: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: azt3328: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: aw2: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: au88x0: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: atiixp: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: asihpi: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: als4000: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: als300: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: ali5451: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: ad1889: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: parisc: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: mips: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: wss: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: gus: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: sb: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: es18xx: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: es1688: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: cmi8330: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: ad1816a: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: firewire: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: vx: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: pcsp: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: ml403: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: dummy: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: aloop: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: atmel: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: aaci: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: aoa: Use managed buffer allocation (jsc#SLE-16518).
- ALSA: hda: Use standard waitqueue for RIRB wakeup
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Explicitly include linux/io.h for
  virt_to_phys() (jsc#SLE-16518).
- commit 5a54b8e
* Sat Sep 26 2020 nstange@suse.de
- s390/maccess: add no DAT mode to kernel_write (bsc#1176449).
- commit 8fd068b
* Sat Sep 26 2020 nstange@suse.de
- s390: Change s390_kernel_write() return type to match memcpy()
  (bsc#1176449).
  Prerequisite for bsc#1176449.
- commit 3f17b43
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: msm8916-wcd-digital: Reset RX interpolation path after
  use (jsc#SLE-16518).
- ASoC: msm8916-wcd-analog: Fix MIC BIAS Internal1
  (jsc#SLE-16518).
- ASoC: sti: fix possible sleep-in-atomic (jsc#SLE-16518).
- ASoC: msm8916-wcd-analog: Fix selected events for MIC BIAS
  External1 (jsc#SLE-16518).
- ASoC: hdac_hda: Fix error in driver removal after failed probe
  (jsc#SLE-16518).
- ASoC: SOF: Intel: fix HDA codec driver probe with multiple
  controllers (jsc#SLE-16518).
- ASoC: SOF: Intel: lower print level to dbg if we will reinit
  DSP (jsc#SLE-16518).
- ASoC: stm32: dfsdm: fix 16 bits record (jsc#SLE-16518).
- ASoC: stm32: sai: fix possible circular locking (jsc#SLE-16518).
- ASoC: Fix NULL dereference at freeing (jsc#SLE-16518).
- ASoC: Intel: bytcht_es8316: Fix Irbis NB41 netbook quirk
  (jsc#SLE-16518).
- ASoC: rt5640: Fix NULL dereference on module unload
  (jsc#SLE-16518).
- ALSA: seq: Fix racy access for queue timer in proc read
  (jsc#SLE-16518).
- ALSA: usb-audio: fix sync-ep altsetting sanity check
  (jsc#SLE-16518).
- ALSA: dice: fix fallback from protocol extension into limited
  functionality (jsc#SLE-16518).
- ALSA: firewire-tascam: fix corruption due to spin lock without
  restoration in SoftIRQ context (jsc#SLE-16518).
- ALSA: hda: Rename back to dmic_detect option (jsc#SLE-16518).
- ALSA: hda: enable regmap internal locking (jsc#SLE-16518).
- ALSA: hda/realtek - Add quirk for the bass speaker on Lenovo
  Yoga X1 7th gen (jsc#SLE-16518).
- ALSA: hda/realtek - Set EAPD control to default for ALC222
  (jsc#SLE-16518).
- ASoC: Intel: boards: Fix compile-testing RT1011/RT5682
  (jsc#SLE-16518).
- ASoC: SOF: imx8: Fix dsp_box offset (jsc#SLE-16518).
- ASoC: topology: Prevent use-after-free in
  snd_soc_get_pcm_runtime() (jsc#SLE-16518).
- ASoC: fsl_audmix: add missed pm_runtime_disable (jsc#SLE-16518).
- ASoC: stm32: spdifrx: fix input pin state management
  (jsc#SLE-16518).
- ASoC: stm32: spdifrx: fix race condition in irq handler
  (jsc#SLE-16518).
- ASoC: stm32: spdifrx: fix inconsistent lock state
  (jsc#SLE-16518).
- ASoC: core: Fix access to uninitialized list heads
  (jsc#SLE-16518).
- ASoC: soc-core: Set dpcm_playback / dpcm_capture
  (jsc#SLE-16518).
- ASoC: SOF: imx8: fix memory allocation failure check on
  priv->pd_dev (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: hda-dai: fix oops on hda_link .hw_free
  (jsc#SLE-16518).
- ASoC: SOF: fix fault at driver unload after failed probe
  (jsc#SLE-16518).
- ALSA: usb-audio: Apply the sample rate quirk for Bose Companion
  5 (jsc#SLE-16518).
- ALSA: hda/realtek - Add new codec supported for ALCS1200A
  (jsc#SLE-16518).
- ALSA: hda/realtek - Enable the bass speaker of ASUS UX431FLC
  (jsc#SLE-16518).
- ALSA: ice1724: Fix sleep-in-atomic in Infrasonic Quartet
  support code (jsc#SLE-16518).
- ALSA: hda/realtek - Add Bass Speaker and fixed dac for bass
  speaker (jsc#SLE-16518).
- ALSA: hda - Apply sync-write workaround to old Intel platforms,
  too (jsc#SLE-16518).
- ALSA: hda/hdmi - fix atpx_present when CLASS is not VGA
  (jsc#SLE-16518).
- ALSA: usb-audio: fix set_format altsetting sanity check
  (jsc#SLE-16518).
- ALSA: hda/realtek - Add headset Mic no shutup for ALC283
  (jsc#SLE-16518).
- ALSA: usb-audio: set the interface format after resume on Dell
  WD19 (jsc#SLE-16518).
- ASoC: wm8962: fix lambda value (jsc#SLE-16518).
- ASoC: Intel: common: work-around incorrect ACPI HID for CML
  boards (jsc#SLE-16518).
- ASoC: SOF: Intel: split cht and byt debug window sizes
  (jsc#SLE-16518).
- ASoC: SOF: loader: fix snd_sof_fw_parse_ext_data
  (jsc#SLE-16518).
- ASoC: SOF: loader: snd_sof_fw_parse_ext_data log warning on
  unknown header (jsc#SLE-16518).
- ASoC: simple-card: Don't create separate link when platform
  is present (jsc#SLE-16518).
- ASoC: topology: Check return value for soc_tplg_pcm_create()
  (jsc#SLE-16518).
- ASoC: topology: Check return value for snd_soc_add_dai_link()
  (jsc#SLE-16518).
- ASoC: core: only flush inited work during free (jsc#SLE-16518).
- ASoC: Intel: bytcr_rt5640: Update quirk for Teclast X89
  (jsc#SLE-16518).
- ASoC: core: Init pcm runtime work early to avoid warnings
  (jsc#SLE-16518).
- ASoC: Intel: sst: Add missing include <linux/io.h>
  (jsc#SLE-16518).
- ASoC: max98090: fix possible race conditions (jsc#SLE-16518).
- ASoC: max98090: exit workaround earlier if PLL is locked
  (jsc#SLE-16518).
- ASoC: max98090: remove msleep in PLL unlocked workaround
  (jsc#SLE-16518).
- ASoC: wm8904: fix automatic sysclk configuration
  (jsc#SLE-16518).
- ASoC: rt5677: Fix build error without CONFIG_SPI
  (jsc#SLE-16518).
- ASoC: SOF: topology: Fix unload for SAI/ESAI (jsc#SLE-16518).
- ASoC: SOF: Intel: BYT: fix a copy/paste mistake in byt_dump()
  (jsc#SLE-16518).
- ASoC: AMD: Enable clk in startup intead of hw_params
  (jsc#SLE-16518).
- ASoC: rt5682: fix i2c arbitration lost issue (jsc#SLE-16518).
- ALSA: hda - Downgrade error message for single-cmd fallback
  (jsc#SLE-16518).
- ALSA: hda: Fix regression by strip mask fix (jsc#SLE-16518).
- ALSA: hda/ca0132 - Fix work handling in delayed HP detection
  (jsc#SLE-16518).
- ALSA: hda/ca0132 - Avoid endless loop (jsc#SLE-16518).
- ALSA: hda/ca0132 - Keep power on during processing DSP response
  (jsc#SLE-16518).
- ALSA: pcm: Avoid possible info leaks from PCM stream buffers
  (jsc#SLE-16518).
- commit 4c1452e
* Fri Sep 25 2020 tiwai@suse.de
- ALSA: hda/realtek - Line-out jack doesn't work on a Dell AIO
  (jsc#SLE-16518).
- ALSA: hda/hdmi - Fix duplicate unref of pci_dev (jsc#SLE-16518).
- ALSA: fireface: fix return value in error path of isochronous
  resources reservation (jsc#SLE-16518).
- ALSA: oxfw: fix return value in error path of isochronous
  resources reservation (jsc#SLE-16518).
- ALSA: firewire-motu: fix double unlocked 'motu->mutex'
  (jsc#SLE-16518).
- ALSA: echoaudio: simplify get_audio_levels (jsc#SLE-16518).
- ALSA: pcm: oss: Avoid potential buffer overflows
  (jsc#SLE-16518).
- ALSA: hda: hdmi - Keep old slot assignment behavior for Intel
  platforms (jsc#SLE-16518).
- ALSA: hda: Modify stream stripe mask only when needed
  (jsc#SLE-16518).
- ALSA: hda - fixup for the bass speaker on Lenovo Carbon X1
  7th gen (jsc#SLE-16518).
- ALSA: hda: hdmi - preserve non-MST PCM routing for Intel
  platforms (jsc#SLE-16518).
- ALSA: hda: hdmi - fix kernel oops caused by invalid PCM idx
  (jsc#SLE-16518).
- ALSA: hda/realtek - Fix inverted bass GPIO pin on Acer 8951G
  (jsc#SLE-16518).
- ALSA: hda/realtek - Dell headphone has noise on unmute for
  ALC236 (jsc#SLE-16518).
- ALSA: hda: hdmi - fix regression in connect list handling
  (jsc#SLE-16518).
- ALSA: aloop: Avoid pointer dereference before null-check
  (jsc#SLE-16518).
- ALSA: hda/hdmi - enable automatic runtime pm for AMD HDMI
  codecs by default (jsc#SLE-16518).
- ALSA: hda/hdmi - enable runtime pm for newer AMD display audio
  (jsc#SLE-16518).
- ALSA: hda/hdmi - Add new pci ids for AMD GPU display audio
  (jsc#SLE-16518).
- ALSA: hda/hdmi - fix vgaswitcheroo detection for AMD
  (jsc#SLE-16518).
- compat_ioctl: remove translation for sound ioctls
  (jsc#SLE-16518).
- soundwire: ignore uniqueID when irrelevant (jsc#SLE-16518).
- soundwire: slave: add helper to extract slave ID
  (jsc#SLE-16518).
- soundwire: remove bitfield for unique_id, use u8
  (jsc#SLE-16518).
- soundwire: cadence_master: make clock stop exit configurable
  on init (jsc#SLE-16518).
- soundwire: intel/cadence: add flag for interrupt enable
  (jsc#SLE-16518).
- soundwire: intel: add helper for initialization (jsc#SLE-16518).
- soundwire: cadence_master: add hw_reset capability in debugfs
  (jsc#SLE-16518).
- soundwire: intel/cadence: fix startup sequence (jsc#SLE-16518).
- soundwire: intel: use correct header for io calls
  (jsc#SLE-16518).
- soundwire: cadence_master: improve PDI allocation
  (jsc#SLE-16518).
- soundwire: intel: don't filter out PDI0/1 (jsc#SLE-16518).
- soundwire: cadence/intel: simplify PDI/port mapping
  (jsc#SLE-16518).
- soundwire: intel: remove playback/capture stream_name
  (jsc#SLE-16518).
- soundwire: remove DAI_ID_RANGE definitions (jsc#SLE-16518).
- soundwire: intel: remove X86 dependency (jsc#SLE-16518).
- soundwire: intel: add missing headers for cross-compilation
  (jsc#SLE-16518).
- ALSA: usb-audio: Fix Focusrite Scarlett 6i6 gen1 - input
  handling (jsc#SLE-16518).
- ALSA: hda/realtek - Enable internal speaker of ASUS UX431FLC
  (jsc#SLE-16518).
- ASoC: DMI long name - avoid to add board name if matches with
  product name (jsc#SLE-16518).
- ASoC: improve the DMI long card code in asoc-core
  (jsc#SLE-16518).
- ASoC: Fix Kconfig indentation (jsc#SLE-16518).
- ASoC: soc-pcm: check symmetry before hw_params (jsc#SLE-16518).
- ASoC: pcm3168a: Update the RST gpio handling to align with
  documentation (jsc#SLE-16518).
- ASoC: core: add SND_SOC_BYTES_E (jsc#SLE-16518).
- ASoC: add control components management (jsc#SLE-16518).
- ASoC: soc-pcm: remove soc_pcm_private_free() (jsc#SLE-16518).
- ASoC: soc-component: tidyup snd_soc_pcm_component_new/free()
  parameter (jsc#SLE-16518).
- ASoC: wm_adsp: Expose mixer control API (jsc#SLE-16518).
- commit 884f66f
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: tlv320aic31xx: configure output common-mode voltage
  (jsc#SLE-16518).
- ASoC: pcm3168a: Add support for optional RST gpio handling
  (jsc#SLE-16518).
- ASoC: wm5100: add missed pm_runtime_disable (jsc#SLE-16518).
- ASoC: wm2200: add missed operations in remove and probe failure
  (jsc#SLE-16518).
- ASoC: qcom: q6asm-dai: add support to flac decoder
  (jsc#SLE-16518).
- ASoC: qcom: q6asm: add support to flac config (jsc#SLE-16518).
- ALSA: compress: add flac decoder params (jsc#SLE-16518).
- ASoC: rt5677: rt5677_check_hotword() can be static
  (jsc#SLE-16518).
- ASoC: ti: davinci-mcasp: Use dma_request_chan() directly for
  channel request (jsc#SLE-16518).
- ASoC: dmaengine: Use dma_request_chan() directly for channel
  request (jsc#SLE-16518).
- ASoC: soc-core: care card_probed at soc_cleanup_card_resources()
  (jsc#SLE-16518).
- ASoC: soc-core: move snd_soc_unbind_card() next to
  snd_soc_bind_card() (jsc#SLE-16518).
- ASoC: soc-core: call snd_soc_dapm_shutdown() at
  soc_cleanup_card_resources() (jsc#SLE-16518).
- ASoC: tas2770: clean up an indentation issue (jsc#SLE-16518).
- ASoC: soc-core: tidyup soc_probe_aux_devices() (jsc#SLE-16518).
- ASoC: soc-core: merge snd_soc_bind_card() and
  snd_soc_instantiate_card() (jsc#SLE-16518).
- ASoC: soc-core: merge soc_remove_component() and
  soc_cleanup_component() (jsc#SLE-16518).
- ASoC: soc-core: merge snd_soc_remove_dai_link() and
  soc_unbind_dai_link() (jsc#SLE-16518).
- ASoC: soc-core: merge snd_soc_add_dai_link() and
  soc_bind_dai_link() (jsc#SLE-16518).
- ASoC: soc-core: merge snd_soc_unregister_dai() and soc_del_dai()
  (jsc#SLE-16518).
- ASoC: soc-core: merge snd_soc_register_dai() and soc_add_dai()
  (jsc#SLE-16518).
- ASoC: soc-core: remove soc_is_dai_link_bound() (jsc#SLE-16518).
- ASoC: SOF: topology: free kcontrol memory on error
  (jsc#SLE-16518).
- ASoC: SOF: PM: only suspend to D0I3 when needed (jsc#SLE-16518).
- ASoC: SOF: add helper to check if we should enter d0i3 suspend
  (jsc#SLE-16518).
- ASoC: SOF: PM: add check before setting d0_substate
  (jsc#SLE-16518).
- ASoC: SOF: PM: add state machine to comments (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: use fallback for firmware name
  (jsc#SLE-16518).
- ASoC: Intel: acpi-match: split CNL tables in three
  (jsc#SLE-16518).
- commit 5d6ba5b
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net: Fix CONFIG_NET_CLS_ACT=n and CONFIG_NFT_FWD_NETDEV={y,
  m} build (bsc#1176447).
- Update config files.
- commit 77d1cd4
* Fri Sep 25 2020 trenn@suse.com
- powercap: RAPL: Add support for Lakefield (jsc#INTEL-233).
- powercap/intel_rapl: add support for AlderLake (jsc#SLE-13409).
- powercap/intel_rapl: add support for RocketLake (jsc#SLE-13393
  jsc#SLE-13898).
- powercap/intel_rapl: add support for TigerLake Desktop
  (jsc#INTEL-549).
- powercap: Add Power Limit4 support (jsc#INTEL-549).
- powercap: intel_rapl: add support for Sapphire Rapids
  (jsc#SLE-13172 jsc#SLE-13371).
- powercap/intel_rapl: add support for ElkhartLake
  (jsc#SLE-12985).
- commit 9b0b8f2
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: wm8904: configure sysclk/FLL automatically
  (jsc#SLE-16518).
- ASoC: Intel: kbl_rt5663_rt5514_max98927: Add dmic format
  constraint (jsc#SLE-16518).
- ASoC: Add DA7213 audio codec as selectable option
  (jsc#SLE-16518).
- ASoC: rt5677: Wait for DSP to boot before loading firmware
  (jsc#SLE-16518).
- ASoC: rt5677: Set ADC clock to use PLL and enable ASRC
  (jsc#SLE-16518).
- ASoC: bdw-rt5677: Turn on MCLK1 for DSP via DAPM
  (jsc#SLE-16518).
- ASoC: rt5677: Allow VAD to be shut on/off at all times
  (jsc#SLE-16518).
- ASoC: rt5677: Disable irq at suspend (jsc#SLE-16518).
- ASoC: rt5677: Stop and restart DSP over suspend/resume
  (jsc#SLE-16518).
- ASoC: rt5677: Mark reg RT5677_PWR_ANLG2 as volatile
  (jsc#SLE-16518).
- ASoC: rt5677: Add DAPM audio path for hotword stream
  (jsc#SLE-16518).
- ASoC: rt5677: Enable jack detect while DSP is running
  (jsc#SLE-16518).
- ASoC: bdw-rt5677: Add a DAI link for rt5677 SPI PCM device
  (jsc#SLE-16518).
- ASoC: rt5677: Load firmware via SPI using delayed work
  (jsc#SLE-16518).
- ASoC: fsl_audmix: Add spin lock to protect tdms (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: set L1SEN on S0ix suspend
  (jsc#SLE-16518).
- ASoC: SOF: topology: fix missing NULL pointer check
  (jsc#SLE-16518).
- ASoC: core: Fix compile warning with CONFIG_DEBUG_FS=n
  (jsc#SLE-16518).
- ASoC: rsnd: fix DALIGN register for SSIU (jsc#SLE-16518).
- ASoC: Intel: bytcr_rt5640: Update quirk for Acer Switch 10
  SW5-012 2-in-1 (jsc#SLE-16518).
- ASoC: SOF: Intel: Fix build break (jsc#SLE-16518).
- ASoC: rt5682: fix the charge pump capacitor discharges
  (jsc#SLE-16518).
- ASoC: rt5645: Fixed typo for buddy jack support (jsc#SLE-16518).
- ASoC: wm8904: fix regcache handling (jsc#SLE-16518).
- ASoC: Jack: Fix NULL pointer dereference in snd_soc_jack_report
  (jsc#SLE-16518).
- ASoC: SOF: Intel: Fix CFL and CML FW nocodec binary names
  (jsc#SLE-16518).
- ASoC: rt5682: cancel jack_detect_work if hs_jack is set to null
  (jsc#SLE-16518).
- ASoC: rt5645: Fixed buddy jack support (jsc#SLE-16518).
- ALSA: aloop: Fix dependency on timer API (jsc#SLE-16518).
- ALSA: aloop: Avoid unexpected timer event callback tasklets
  (jsc#SLE-16518).
- commit 93cd9d0
* Fri Sep 25 2020 tiwai@suse.de
- ALSA: aloop: Remove redundant locking in timer open function
  (jsc#SLE-16518).
- ASoC: component: Add sync_stop PCM ops (jsc#SLE-16518).
- ASoC: pcm: Make ioctl ops optional (jsc#SLE-16518).
- ALSA: hda/hdmi - Clear codec->relaxed_resume flag at unbinding
  (jsc#SLE-16518).
- ALSA: hda - Disable audio component for legacy Nvidia HDMI
  codecs (jsc#SLE-16518).
- ALSA: cs4236: fix error return comparison of an unsigned integer
  (jsc#SLE-16518).
- ALSA: usb-audio: Fix NULL dereference at parsing BADD
  (jsc#SLE-16518).
- ALSA: usb-audio: Fix Scarlett 6i6 Gen 2 port data
  (jsc#SLE-16518).
- ALSA: hda/realtek - Enable the headset-mic on a Xiaomi's laptop
  (jsc#SLE-16518).
- ALSA: hda/realtek - Move some alc236 pintbls to fallback table
  (jsc#SLE-16518).
- ALSA: hda/realtek - Move some alc256 pintbls to fallback table
  (jsc#SLE-16518).
- ALSA: pcm: Add card sync_irq field (jsc#SLE-16518).
- ALSA: pcm: Add the support for sync-stop operation
  (jsc#SLE-16518).
- ALSA: pcm: Move PCM_RUNTIME_CHECK() macro into local header
  (jsc#SLE-16518).
- ALSA: pcm: Allow NULL ioctl ops (jsc#SLE-16518).
- ALSA: pcm: Introduce managed buffer allocation mode
  (jsc#SLE-16518).
- ALSA: aloop: Support runtime change of snd_timer via info
  interface (jsc#SLE-16518).
- ALSA: aloop: Support selection of snd_timer instead of jiffies
  (jsc#SLE-16518).
- ALSA: aloop: Move CABLE_VALID_BOTH to the top of file
  (jsc#SLE-16518).
- ALSA: aloop: Rename all jiffies timer specific functions
  (jsc#SLE-16518).
- ALSA: aloop: Use callback functions for timer specific
  implementations (jsc#SLE-16518).
- ALSA: aloop: Support return of error code for timer start and
  stop (jsc#SLE-16518).
- ALSA: aloop: Describe units of variables (jsc#SLE-16518).
- ALSA: hda - Add mute led support for HP ProBook 645 G4
  (jsc#SLE-16518).
- ALSA: hda - Add DP-MST support for NVIDIA codecs
  (jsc#SLE-16518).
- ALSA: hda - Add DP-MST support for non-acomp codecs
  (jsc#SLE-16518).
- ALSA: hda - Add DP-MST jack support (jsc#SLE-16518).
- ALSA: hda - Rename snd_hda_pin_sense to snd_hda_jack_pin_sense
  (jsc#SLE-16518).
- ALSA: hda - remove forced polling workaround for CFL and CNL
  (jsc#SLE-16518).
- ALSA: hda: hdmi - remove redundant code comments
  (jsc#SLE-16518).
- ALSA: hda: hdmi - fix port numbering for ICL and TGL platforms
  (jsc#SLE-16518).
- ALSA: usb-audio: Add skip_validation option (jsc#SLE-16518).
- ALSA: hda/hdmi - Clean up Intel platform-specific fixup checks
  (jsc#SLE-16518).
- ALSA: au88x0: Fix incorrect device pointer for preallocation
  (jsc#SLE-16518).
- ALSA: timer: Fix the breakage of slave link open
  (jsc#SLE-16518).
- ALSA: memalloc: Drop snd_dma_pci_data() macro (jsc#SLE-16518).
- ALSA: pcm: Unexport snd_pcm_sgbuf_ops_page (jsc#SLE-16518).
- ASoC: rt5677-spi: Convert to the common vmalloc memalloc
  (jsc#SLE-16518).
- ASoC: SOF: Drop superfluous snd_pcm_sgbuf_ops_page
  (jsc#SLE-16518).
- commit b7744c2
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: intel: Avoid non-standard macro usage (jsc#SLE-16518).
- ASoC: intel: Drop superfluous snd_pcm_sgbuf_ops_page
  (jsc#SLE-16518).
- ASoC: rt5514-spi: Convert to the common vmalloc memalloc
  (jsc#SLE-16518).
- ASoC: Remove superfluous snd_dma_continuous_data()
  (jsc#SLE-16518).
- ALSA: pcm: Yet another missing check of non-cached buffer type
  (jsc#SLE-16518).
- ALSA: timer: Fix possible race at assigning a timer instance
  (jsc#SLE-16518).
- ALSA: timer: Make snd_timer_close() returning void
  (jsc#SLE-16518).
- ALSA: timer: Unify master/slave linking code (jsc#SLE-16518).
- ASoC: soc-core: fixup dead-lock at
  snd_soc_unregister_component() (jsc#SLE-16518).
- ASoC: soc-core: fix RIP warning on card removal (jsc#SLE-16518).
- ASoC: soc.h: dobj is used only when SND_SOC_TOPOLOGY
  (jsc#SLE-16518).
- ASoC: soc-core: remove topology specific operation
  (jsc#SLE-16518).
- ASoC: soc-core: call snd_soc_register_dai() from
  snd_soc_register_dais() (jsc#SLE-16518).
- ASoC: soc-core: don't call snd_soc_dapm_new_dai_widgets()
  at snd_soc_register_dai() (jsc#SLE-16518).
- ASoC: soc-core: have legacy_dai_naming at snd_soc_register_dai()
  (jsc#SLE-16518).
- ASoC: soc-core: add snd_soc_unregister_dai() (jsc#SLE-16518).
- ASoC: soc-core: move snd_soc_unregister_dais() (jsc#SLE-16518).
- ASoC: soc-core: move snd_soc_register_dai() (jsc#SLE-16518).
- ASoC: soc-core: use snd_soc_lookup_component() at
  snd_soc_unregister_component() (jsc#SLE-16518).
- commit 79a3b28
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: soc-core: remove snd_soc_component_add/del()
  (jsc#SLE-16518).
- ASoC: soc-core: add snd_soc_del_component_unlocked()
  (jsc#SLE-16518).
- ASoC: soc-core: tidyup snd_soc_lookup_component()
  (jsc#SLE-16518).
- ASoC: soc-core: move snd_soc_lookup_component() (jsc#SLE-16518).
- ASoC: soc-core: add soc_unbind_dai_link() (jsc#SLE-16518).
- ASoC: soc-core: call soc_bind_dai_link() under
  snd_soc_add_dai_link() (jsc#SLE-16518).
- ASoC: soc-core: remove duplicated soc_is_dai_link_bound()
  (jsc#SLE-16518).
- ASoC: soc-core: typo fix at soc_dai_link_sanity_check()
  (jsc#SLE-16518).
- ASoC: soc-core: tidyup soc_init_dai_link() (jsc#SLE-16518).
- ASoC: soc-core: move soc_init_dai_link() (jsc#SLE-16518).
- commit f5a1e16
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: Intel: boards: fix configs for bxt-da7219-max98057a
  (jsc#SLE-16518).
- Update config files.
- commit 17e9bc9
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: SOF: imx: fix reverse CONFIG_SND_SOC_SOF_OF dependency
  (jsc#SLE-16518).
- commit 296dcdd
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: SOF: topology: set trigger order for FE DAI link
  (jsc#SLE-16518).
- ASoC: pcm: update FE/BE trigger order based on the command
  (jsc#SLE-16518).
- ASoC: Intel: boards: sof_rt5682: use dependency on SOF_HDA_LINK
  (jsc#SLE-16518).
- ASoC: Intel: boards: Geminilake is only supported by SOF
  (jsc#SLE-16518).
- ASoC: Intel: boards: remove select SND_HDA_DSP_LOADER
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: mark HDAudio codec support as deprecated
  (jsc#SLE-16518).
- ASoC: SOF: Intel: use def_tristate, avoid using select
  (jsc#SLE-16518).
- commit 43aacb2
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: SOF: Kconfig: add EXPERT dependency for developer options,
  clarify help (jsc#SLE-16518).
- Update config files.
- commit ec1624d
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: SOF: Intel: Broadwell: clarify mutual exclusion with
  legacy driver (jsc#SLE-16518).
- Update config files.
- commit a96f786
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: SOF: Intel: Baytrail: clarify mutual exclusion with
  Atom/SST driver (jsc#SLE-16518).
- Update config files.
- commit 45d6b49
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: Intel: boards: Add CML m/c using RT1011 and RT5682
  (jsc#SLE-16518).
- Update config files.
- commit adab694
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: Intel: add mutual exclusion between SOF and legacy
  Baytrail driver (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Simplify the hda_dsp_wait_d0i3c_done()
  function (jsc#SLE-16518).
- ASoC: Intel: Add acpi match for rt1011 based m/c driver
  (jsc#SLE-16518).
- ASoC: ux500: Remove redundant variable "status" (jsc#SLE-16518).
- ASoC: rt1011: some minor changes to improve readability
  (jsc#SLE-16518).
- ASoC: rt1011: add the range check for temperature_calib from
  device property (jsc#SLE-16518).
- ASoC: rt1011: remove unnecessary tabs using spaces instead
  (jsc#SLE-16518).
- commit d69571c
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: SOF: Intel: add support for snd-hda-codec-hdmi
  (jsc#SLE-16518).
- Update config files.
- commit 773d794
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: rt1011: improve the rt1011_set_dai_fmt() function
  (jsc#SLE-16518).
- ASoC: rt1011: remove redundant code in kcontrol (jsc#SLE-16518).
- ASoC: rt5682: improve the sensitivity of push button
  (jsc#SLE-16518).
- ASoC: soc-core: remove unneeded snd_soc_tplg_component_remove()
  (jsc#SLE-16518).
- ASoC: rt5677-spi: fixup compile warning (jsc#SLE-16518).
- ASoC: Intel: bxt_rt298: common hdmi codec support
  (jsc#SLE-16518).
- ASoC: intel: sof_rt5682: common hdmi codec support
  (jsc#SLE-16518).
- ASoC: Intel: glk_rt5682_max98357a: common hdmi codec support
  (jsc#SLE-16518).
- ASoC: Intel: bxt-da7219-max98357a: common hdmi codec support
  (jsc#SLE-16518).
- commit 695304b
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: Intel: skl-hda-dsp-generic: fix include guard name
  (jsc#SLE-16518).
- ASoC: Intel: skl-hda-dsp-generic: use snd-hda-codec-hdmi
  (jsc#SLE-16518).
- ASoC: hdac_hda: add support for HDMI/DP as a HDA codec
  (jsc#SLE-16518).
- ALSA: hda/hdmi - implement mst_no_extra_pcms flag
  (jsc#SLE-16518).
- ASoC: rockchip_max98090: Add HDMI jack support (jsc#SLE-16518).
- ASoC: rockchip_max98090: Optionally support HDMI use case
  (jsc#SLE-16518).
- ASoC: SOF - remove the dead code (skylake/kabylake)
  (jsc#SLE-16518).
- ASoC: intel - fix the card names (jsc#SLE-16518).
- ASoC: SOF: pci: Add prepare/complete PM callbacks
  (jsc#SLE-16518).
- ASoC: SOF: PM: Add support for DSP D0i3 state when entering S0ix
  (jsc#SLE-16518).
- ASoC: SOF: return -ENOTSUPP if D0I3 is not supported
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda-dsp: implement suspend/resume for
  S0ix<->S0 transition (jsc#SLE-16518).
- ASoC: SOF: ignore suspend/resume for D0ix compatible streams
  (jsc#SLE-16518).
- ASoC: SOF: PM: implement prepare/complete callbacks
  (jsc#SLE-16518).
- ASoC: SOF: add a flag suspend_ignored for sof stream
  (jsc#SLE-16518).
- ASoC: SOF: add a flag to indicate the system suspend target
  (jsc#SLE-16518).
- ASoC: SOF: Intel: CNL: add support for sending compact IPC
  (jsc#SLE-16518).
- ASoC: SOF: PM: add helpers for setting D0 substate for ADSP
  (jsc#SLE-16518).
- ASoC: SOF: configure D0ix IPC flags in set_power_state
  (jsc#SLE-16518).
- ASoC: SOF: Intel: HDA: add cAVS specific compact IPC header file
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda-ipc: Don't read mailbox for PM_GATE reply
  (jsc#SLE-16518).
- ASoC: SOF: ipc: introduce message for DSP power gating
  (jsc#SLE-16518).
- ASoC: SOF: PM: rename sof_send_pm_ipc to sof_send_pm_ctx_ipc
  (jsc#SLE-16518).
- ASoC: SOF: Intel: HDA: use macro for register polling retry
  count (jsc#SLE-16518).
- ASoC: SOF: Intel: hda-dsp: align the comments for D0I3C update
  (jsc#SLE-16518).
- ASoC: SOF: topology: parse and store d0i3_compatible flag
  (jsc#SLE-16518).
- ASoC: SOF: token: add tokens for PCM compatible with D0i3
  substate (jsc#SLE-16518).
- ASoC: SOF: add flag to snd_sof_pcm_stream for D0i3 compatible
  stream (jsc#SLE-16518).
- ASoC: SOF: Intel: APL: add set_power_state() ops
  (jsc#SLE-16518).
- ASoC: SOF: Intel: CNL: add set_power_state() ops
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda-dsp: Add helper for setting DSP D0ix
  substate (jsc#SLE-16518).
- ASoC: SOF: add set_power_state() to dsp_ops for power state
  update (jsc#SLE-16518).
- ASoC: SOF: reset default d0_substate at probe() and resume()
  (jsc#SLE-16518).
- ASoC: SOF: add a field to store the current D0 substate of DSP
  (jsc#SLE-16518).
- ASoC: rsnd: core.c: add WARN_ON() on
  rsnd_channel_normalization() (jsc#SLE-16518).
- ASoC: fsl_esai: Add spin lock to protect reset, stop and start
  (jsc#SLE-16518).
- ASoC: fsl_asrc: refine the setting of internal clock divider
  (jsc#SLE-16518).
- ASoC: eve: implement set_bias_level function for rt5514
  (jsc#SLE-16518).
- ASoC: sunxi: sun4i-codec: remove unneeded semicolon
  (jsc#SLE-16518).
- ASoC: fsl: fsl_dma: fix build failure (jsc#SLE-16518).
- ASoC: SOF: Intel: only support INFO_BATCH for legacy platforms
  (jsc#SLE-16518).
- ASoC: SOF: define INFO_ flags in dsp_ops (jsc#SLE-16518).
- ASoC: tegra: disable rx_fifo after disable stream
  (jsc#SLE-16518).
- ASoC: tegra: add a TDM configuration callback (jsc#SLE-16518).
- ASoC: pxa: poodle: Spelling s/enpoints/endpoints/,
  s/connetion/connection/ (jsc#SLE-16518).
- ASoC: Spelling s/configr/configur/ (jsc#SLE-16518).
- ASoC: soc-dpcm: tidyup for_each_dpcm_xx() macro (jsc#SLE-16518).
- ASoC: tegra: Allow 24bit and 32bit samples (jsc#SLE-16518).
- ASoC: rt5677-spi: fix sparse warnings (jsc#SLE-16518).
- ASoC: rt5677: Add missing null check for failed allocation of
  rt5677_dsp (jsc#SLE-16518).
- commit 766b44b
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: SOF: Intel: initial support to JasperLake (jsc#SLE-16518).
- Update config files.
- commit 7f5b676
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: rt5650: Add Kahlee platform specfic changes
  (jsc#SLE-16518).
- ASoC: kirkwood: fix IRQ error handling (jsc#SLE-16518).
- ASoC: Intel: common: add ACPI matching tables for JSL
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: add dev_err() traces for
  snd_sof_dsp_read_poll_timeout() (jsc#SLE-16518).
- ASoC: SOF: Intel: hda-loader: improve error handling
  (jsc#SLE-16518).
- ASoC: mediatek: Check SND_SOC_CROS_EC_CODEC dependency
  (jsc#SLE-16518).
- ASoC: rsnd: add missing of_node_put() (jsc#SLE-16518).
- ASoC: rsnd: dma: set bus width to data width for monaural data
  (jsc#SLE-16518).
- ASoC: soc-core: add for_each_rtd_components() and replace
  (jsc#SLE-16518).
- commit 1cde028
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: soc-core: snd_soc_unbind_card() cleanup (jsc#SLE-16518).
- ASoC: soc-core: remove for_each_rtdcom_safe() (jsc#SLE-16518).
- ASoC: soc-pcm: fixup dpcm_prune_paths() loop continue
  (jsc#SLE-16518).
- ASoC: rt5677: Add a PCM device for streaming hotword via SPI
  (jsc#SLE-16518).
- ASOC: adau7118: Change regulators id (jsc#SLE-16518).
- ASoC: mediatek: mt8183: support WoV (jsc#SLE-16518).
- ASoC: mediatek: mt6358: support WoV (jsc#SLE-16518).
- ASoC: msm8916-wcd-analog: Add earpiece (jsc#SLE-16518).
- ASoC: tlv320aic32x4: add a check for devm_clk_get
  (jsc#SLE-16518).
- ASoC: rt1011: fix spelling mistake "temperture" -> "temperature"
  (jsc#SLE-16518).
- ASoC: tas2562: Fix misuse of GENMASK macro (jsc#SLE-16518).
- ASoC: rt1011: Read and apply r0 and temperature device property
  (jsc#SLE-16518).
- ASoC: wm8958: use <asm/unaligned.h> to simplify code
  (jsc#SLE-16518).
- ASoC: rt1011: set tx/rx slots from tx/rx_mask in TDM case
  (jsc#SLE-16518).
- ASoC: pcm3168a: Fix serial mode dependent format support
  (jsc#SLE-16518).
- ASoC: audio-graph: fixup graph_dai_link_of_dpcm() comment
  (jsc#SLE-16518).
- ASoC: sof: include types.h at header.h (jsc#SLE-16518).
- ASoC: simple-card: fixup simple_dai_link_of_dpcm() comment
  (jsc#SLE-16518).
- ASoC: Intel: eve: Enable mclk and ssp sclk early
  (jsc#SLE-16518).
- ASoC: SOF: Fix randbuild error (jsc#SLE-16518).
- ASoC: SOF: topology: check errors when parsing LED tokens
  (jsc#SLE-16518).
- ASoC: SOF: topology: remove always-true redundant test
  (jsc#SLE-16518).
- ASoC: SOF: Intel: bdw: fix operator precedence warnings
  (jsc#SLE-16518).
- ASoC: SOF: Intel: byt: fix operator precedence warnings
  (jsc#SLE-16518).
- ASoC: fsl_mqs: Move static keyword to the front of declarations
  (jsc#SLE-16518).
- ASoC: adau7118: Fix Kconfig warning without CONFIG_I2C
  (jsc#SLE-16518).
- commit b3a38cf
* Fri Sep 25 2020 tiwai@suse.de
- Update patch reference for NFC security fix (CVE-2020-26088 bsc#1176990)
- commit 7eec5ca
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: tas2562: Introduce the TAS2562 amplifier (jsc#SLE-16518).
- Update config files.
- commit fa7602c
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: stm32: spdifrx: retry synchronization in sync state
  (jsc#SLE-16518).
- ASoC: SOF: imx: Read ESAI parameters and send them to DSP
  (jsc#SLE-16518).
- ASoC: SOF: acpi led support for switch controls (jsc#SLE-16518).
- ASoC: SOF: imx: Describe ESAI parameters to be sent to DSP
  (jsc#SLE-16518).
- ASoC: SOF: pci: add debug module param (jsc#SLE-16518).
- ASoC: SOF: acpi: add debug module param (jsc#SLE-16518).
- Revert "ASoC: SOF: Force polling mode on CFL and CNL"
  (jsc#SLE-16518).
- AsoC: SOF: refactor control load code (jsc#SLE-16518).
- ASoC: SOF: enable dual control for pga (jsc#SLE-16518).
- commit 2e3800d
* Fri Sep 25 2020 tiwai@suse.de
- ASOC: Add ADAU7118 8 Channel PDM-to-I2S/TDM Converter driver
  (jsc#SLE-16518).
- Update config files.
- commit 18bd6eb
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: SOF: enable sync_write in hdac_bus (jsc#SLE-16518).
- ASoC: simple_card_utils.h: Add missing include (jsc#SLE-16518).
- ASoC: jz4740: Remove unused match variable (jsc#SLE-16518).
- ASoC: soc-component: remove snd_pcm_ops from component driver
  (jsc#SLE-16518).
- ASoC: soc-utils: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: soc-generic-dmaengine-pcm: remove snd_pcm_ops
  (jsc#SLE-16518).
- ASoC: fsl: fsl_dma: don't use snd_soc_rtdcom_lookup()
  (jsc#SLE-16518).
- ASoC: fsl: fsl_asrc_dma: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: fsl: mpc5200_dma: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: fsl: fsl_dma: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: fsl: imx-pcm-fiq: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: bcm: cygnus-pcm: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: rt5514-spi: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: dwc: dwc-pcm: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: kirkwood: kirkwood-dma: remove snd_pcm_ops
  (jsc#SLE-16518).
- ASoC: mediatek: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: mediatek: mtk-btcvsd: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: meson: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: pxa: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: pxa: mmp-pcm: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: qcom: q6asm-dai: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: qcom: q6routing: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: qcom: lpass-platform: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: samsung: idma: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: sh: siu_pcm: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: sh: dma-sh7760: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: sh: fsi: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: sh: rsnd: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: sof: pcm: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: sprd: sprd-pcm-dma: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: stm: stm32_adfsdm: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: txx9: txx9aclc: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: uniphier: aio-dma: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: xilinx: xlnx_formatter_pcm: remove snd_pcm_ops
  (jsc#SLE-16518).
- ASoC: xtensa: xtfpga-i2s: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: au1x: dma: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: au1x: dbdma2: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: atmel: atmel-pcm-pdc: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: amd: acp-pcm-dma: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: amd: acp3x-pcm-dma: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: intel: sst-baytrail-pcm: remove snd_pcm_ops
  (jsc#SLE-16518).
- ASoC: intel: sst-mfld-platform-pcm: remove snd_pcm_ops
  (jsc#SLE-16518).
- ASoC: intel: skl-pcm: remove snd_pcm_ops (jsc#SLE-16518).
- ASoC: intel: sst-haswell-pcm: remove snd_pcm_ops
  (jsc#SLE-16518).
- ASoC: soc-core: add snd_soc_pcm_lib_ioctl() (jsc#SLE-16518).
- ASoC: soc-core: add new pcm_construct/pcm_destruct
  (jsc#SLE-16518).
- ASoC: soc-core: merge snd_pcm_ops member to component driver
  (jsc#SLE-16518).
- ASoC: mt8183: fix audio playback slowly after playback during
  bootup (jsc#SLE-16518).
- ASoC: pcm3168a: Use fixup instead of constraint for channels
  and formats (jsc#SLE-16518).
- ASoC: SOF: support alternate list of machines (jsc#SLE-16518).
- ASoC: soc-acpi: add link_mask field (jsc#SLE-16518).
- ASoC: tas2770: Fix snd_soc_update_bits error handling
  (jsc#SLE-16518).
- ASoc: tas2770: Remove unused defines and variables
  (jsc#SLE-16518).
- ASoC: tas2770: Remove unneeded read of the TDM_CFG3 register
  (jsc#SLE-16518).
- ASoC: fsl_mqs: Fix error handling in probe (jsc#SLE-16518).
- ASoC: fsl_mqs: remove set but not used variable 'bclk'
  (jsc#SLE-16518).
- ASoc: tas2770: Fix build error without GPIOLIB (jsc#SLE-16518).
- ASoC: jz4740: Use of_device_get_match_data() (jsc#SLE-16518).
- ASoC: soc-ops: use snd_soc_card_get_kcontrol() at
  snd_soc_limit_volume() (jsc#SLE-16518).
- commit ffcf1f4
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: soc-core: setup card->rtd_num at
  snd_soc_instantiate_card() (jsc#SLE-16518).
- ASoC: soc-core: use devm_xxx for component related resource
  (jsc#SLE-16518).
- ASoC: soc-core: add soc_setup_card_name() (jsc#SLE-16518).
- ASoC: soc-core: remove soc_remove_dai_links() (jsc#SLE-16518).
- ASoC: soc-core: use devm_kzalloc() for rtd (jsc#SLE-16518).
- tas2770: fix platform_no_drv_owner.cocci warnings
  (jsc#SLE-16518).
- commit 21213e6
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: samsung: Rename Arndale card driver (jsc#SLE-16518).
- ASoC: samsung: arndale: Add support for WM1811 CODEC
  (jsc#SLE-16518).
- ASoC: samsung: arndale: Simplify DAI link initialization
  (jsc#SLE-16518).
- ASoC: SOF: Intel: Add context data to any IPC timeout
  (jsc#SLE-16518).
- commit 05d6e48
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: SOF: Intel: hda: fix reset of host_period_bytes
  (jsc#SLE-16518).
- ASoC: SOF: ipc: introduce no_stream_position in
  sof_ipc_stream_params struct (jsc#SLE-16518).
- ASoC: SOF: core: check for mandatory fw_ready op during SOF
  probe (jsc#SLE-16518).
- ASoC: SOF: ipc: retain DSP context after FW exception
  (jsc#SLE-16518).
- ASoC: SOF: trace: move to opt-in with Kconfig and module
  parameter (jsc#SLE-16518).
- ASoC: madera: Add support for using MCLK3 (jsc#SLE-16518).
- commit 3d489a7
* Fri Sep 25 2020 tiwai@suse.de
- tas2770: add tas2770 smart PA kernel driver (jsc#SLE-16518).
- Update config files.
- commit fec9ea8
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: soc-pcm: Use different sequence for start/stop trigger
  (jsc#SLE-16518).
- ASoC: fsl_asrc: Fix error with S24_3LE format bitstream in i.MX8
  (jsc#SLE-16518).
- ASoC: pcm_dmaengine: Extract
  snd_dmaengine_pcm_refine_runtime_hwparams (jsc#SLE-16518).
- ASoC: fsl_asrc: update supported sample format (jsc#SLE-16518).
- ASoC: fsl_asrc: Use in(out)put_format instead of
  in(out)put_word_width (jsc#SLE-16518).
- ASoC: adau1761: Add ALC controls (jsc#SLE-16518).
- ASoC: adau1761: Add PGA Slew time control (jsc#SLE-16518).
- ASoC: core: Clarify usage of ignore_machine (jsc#SLE-16518).
- ASoC: stm32: sai: clean up indentation issue (jsc#SLE-16518).
- ASoC: wcd9335: clean up indentation issue (jsc#SLE-16518).
- ASoC: rt5663: clean up indentation issues (jsc#SLE-16518).
- ASoC: amd: acp3x: clean up indentation issue (jsc#SLE-16518).
- ASoC: soc-core: remove snd_soc_rtdcom_del_all() (jsc#SLE-16518).
- ASoC: soc-core: tidyup soc_new_pcm_runtime() alloc order
  (jsc#SLE-16518).
- ASoC: soc-core: merge soc_free_pcm_runtime() and soc_rtd_free()
  (jsc#SLE-16518).
- ASoC: soc-core: merge soc_new_pcm_runtime() and soc_rtd_init()
  (jsc#SLE-16518).
- ASoC: soc-core: create rtd->codec_dais first (jsc#SLE-16518).
- ASoC: soc-core: call list_del(&rtd->list) at
  soc_free_pcm_runtime() (jsc#SLE-16518).
- ASoC: soc-core: merge soc_add_pcm_runtime() into
  soc_new_pcm_runtime() (jsc#SLE-16518).
- ASoC: soc-core: move soc_free_pcm_runtime() (jsc#SLE-16518).
- ASoC: wm8994: Add support for MCLKn clock gating
  (jsc#SLE-16518).
- ASoC: wm8994: Add support for setting MCLK clock rate
  (jsc#SLE-16518).
- ASoC: soc-component.h: remove GPL explanation from header
  (jsc#SLE-16518).
- commit fd7b52e
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: xlnx: Use devm_platform_ioremap_resource() in
  xlnx_formatter_pcm_probe() (jsc#SLE-16518).
- ASoC: Intel: cht_bsw_rt5645: Add quirk for boards using
  pmc_plt_clk_0 (jsc#SLE-16518).
- ASoC: fsl_mqs: Add MQS component driver (jsc#SLE-16518).
- ALSA: timer: Limit max amount of slave instances
  (jsc#SLE-16518).
- ALSA: pci: Avoid non-standard macro usage (jsc#SLE-16518).
- ALSA: rme: Avoid non-standard macro usage (jsc#SLE-16518).
- ALSA: es1968: Avoid non-standard macro usage (jsc#SLE-16518).
- ALSA: echoaudio: Avoid non-standard macro usage (jsc#SLE-16518).
- ALSA: aoa: Avoid non-standard macro usage (jsc#SLE-16518).
- ALSA: pci: Drop superfluous snd_pcm_sgbuf_ops_page
  (jsc#SLE-16518).
- ALSA: mips: Convert to the common vmalloc memalloc
  (jsc#SLE-16518).
- ALSA: pdaudiocf: Convert to the common vmalloc memalloc
  (jsc#SLE-16518).
- ALSA: vx: Convert to the common vmalloc memalloc
  (jsc#SLE-16518).
- ALSA: ua101: Convert to the common vmalloc memalloc
  (jsc#SLE-16518).
- ALSA: hiface: Convert to the common vmalloc memalloc
  (jsc#SLE-16518).
- ALSA: caiaq: Convert to the common vmalloc memalloc
  (jsc#SLE-16518).
- ALSA: 6fire: Convert to the common vmalloc memalloc
  (jsc#SLE-16518).
- ALSA: firewire: Convert to the common vmalloc memalloc
  (jsc#SLE-16518).
- ALSA: aloop: Convert to the common vmalloc memalloc
  (jsc#SLE-16518).
- ALSA: usb-audio: Convert to the common vmalloc memalloc
  (jsc#SLE-16518).
- ALSA: 6fire: Drop the dead code (jsc#SLE-16518).
- ALSA: usb: Remove superfluous snd_dma_continuous_data()
  (jsc#SLE-16518).
- ALSA: sparc: Remove superfluous snd_dma_continuous_data()
  (jsc#SLE-16518).
- ALSA: sh: Remove superfluous snd_dma_continuous_data()
  (jsc#SLE-16518).
- ALSA: rme32: Remove superfluous snd_dma_continuous_data()
  (jsc#SLE-16518).
- ALSA: mips: Remove superfluous snd_dma_continuous_data()
  (jsc#SLE-16518).
- ALSA: drivers: Remove superfluous snd_dma_continuous_data()
  (jsc#SLE-16518).
- ALSA: pcm: Create proc files only for non-empty preallocations
  (jsc#SLE-16518).
- ALSA: pcm: Warn if doubly preallocated (jsc#SLE-16518).
- ALSA: pcm: Handle special page mapping in the default mmap
  handler (jsc#SLE-16518).
- ALSA: memalloc: Add vmalloc buffer allocation support
  (jsc#SLE-16518).
- ALSA: memalloc: Allow NULL device for SNDRV_DMA_TYPE_CONTINUOUS
  type (jsc#SLE-16518).
- ALSA: hda: Disable regmap internal locking (jsc#SLE-16518).
- ALSA: pcm: Fix missing check of the new non-cached buffer type
  (jsc#SLE-16518).
- ALSA: bebob: link the order of establishing connections and
  Syt-match clock mode (jsc#SLE-16518).
- ALSA: bebob: expand delay of start for IR context just for
  version 3 firmware (jsc#SLE-16518).
- ALSA: bebob: expand sleep just after breaking connections for
  protocol version 1 (jsc#SLE-16518).
- ALSA: firewire-motu: Correct a typo in the clock proc string
  (jsc#SLE-16518).
- ALSA: firewire-motu: add support for MOTU UltraLite
  (jsc#SLE-16518).
- ALSA: firewire-motu: code refactoring to handle model specific
  switch for protocol v2 (jsc#SLE-16518).
- ALSA: firewire-motu: minor code refactoring for protocol
  version 2 (jsc#SLE-16518).
- ALSA: firewire-motu: detect SPH source of sampling clock
  (jsc#SLE-16518).
- ALSA: firewire-motu: print for unknown source of sampling clock
  (jsc#SLE-16518).
- ALSA: firewire-motu: fix wrong spelling for macro
  (jsc#SLE-16518).
- ALSA: usb-audio: sound: usb: usb true/false for bool return type
  (jsc#SLE-16518).
- ALSA: hda: Allow non-Intel device probe gracefully
  (jsc#SLE-16518).
- ALSA: hda - Fix pending unsol events at shutdown
  (jsc#SLE-16518).
- ALSA: intel_hdmi: Remove dev_err() on platform_get_irq()
  failure (jsc#SLE-16518).
- ALSA: hda: fix intel DSP config (jsc#SLE-16518).
- commit 2b26eed
* Fri Sep 25 2020 tiwai@suse.de
- ALSA: hda: add Intel DSP configuration / probe code
  (jsc#SLE-16518).
- Update config files.
- commit 155aaef
* Fri Sep 25 2020 tiwai@suse.de
- ALSA: hda: Allow HDA to be runtime suspended when dGPU is not
  bound to a driver (jsc#SLE-16518).
- ALSA: firewire-lib: postpone to start IR context
  (jsc#SLE-16518).
- ALSA: firewire-lib: handle several AMDTP streams in callback
  handler of IRQ target (jsc#SLE-16518).
- ALSA: firewire-lib: cancel flushing isoc context in the laste
  step to process context callback (jsc#SLE-16518).
- ALSA: firewire-lib: replace ack callback to flush isoc contexts
  in AMDTP domain (jsc#SLE-16518).
- ALSA: firewire-lib: replace pointer callback to flush isoc
  contexts in AMDTP domain (jsc#SLE-16518).
- ALSA: firewire-lib: add irq_target member into amdtp_domain
  struct (jsc#SLE-16518).
- ALSA: firewire-lib: tune the minimum available size of PCM
  period (jsc#SLE-16518).
- ALSA: firewire-lib: tune the maximum available size of PCM
  period (jsc#SLE-16518).
- ALSA: firewire-lib: schedule hardware IRQ according to the
  size of PCM period (jsc#SLE-16518).
- ALSA: fireface: share PCM buffer size for both direction
  (jsc#SLE-16518).
- ALSA: firewire-motu: share PCM buffer size for both direction
  (jsc#SLE-16518).
- ALSA: firewire-tascam: share PCM buffer size for both direction
  (jsc#SLE-16518).
- ALSA: firewire-digi00x: share PCM buffer size for both direction
  (jsc#SLE-16518).
- ALSA: dice: share PCM buffer size for both direction
  (jsc#SLE-16518).
- ALSA: oxfw: share PCM buffer size for both direction
  (jsc#SLE-16518).
- ALSA: fireworks: share PCM buffer size for both direction
  (jsc#SLE-16518).
- ALSA: bebob: share PCM buffer size for both direction
  (jsc#SLE-16518).
- ALSA: firewire-lib: use variable size of queue for isoc packets
  instead of fixed size (jsc#SLE-16518).
- ALSA: fireface: use the same size of period for PCM substreams
  in AMDTP streams (jsc#SLE-16518).
- ALSA: firewire-motu: use the same size of period for PCM
  substream in AMDTP streams (jsc#SLE-16518).
- ALSA: firewire-tascam: use the same size of period for PCM
  substream in AMDTP streams (jsc#SLE-16518).
- ALSA: firewire-digi00x: use the same size of period for PCM
  substream in AMDTP streams (jsc#SLE-16518).
- ALSA: dice: use the same size of period for PCM substream in
  AMDTP streams (jsc#SLE-16518).
- ALSA: oxfw: use the same size of period for PCM substream in
  AMDTP streams (jsc#SLE-16518).
- ALSA: fireworks: use the same size of period for PCM substream
  in AMDTP streams (jsc#SLE-16518).
- ALSA: bebob: use the same size of period for PCM substream in
  AMDTP streams (jsc#SLE-16518).
- ALSA: fireface: register the size of PCM period to AMDTP domain
  (jsc#SLE-16518).
- ALSA: firewire-motu: register the size of PCM period to AMDTP
  domain (jsc#SLE-16518).
- ALSA: firewire-tascam: register the size of PCM period to
  AMDTP domain (jsc#SLE-16518).
- ALSA: firewire-digi00x: register the size of PCM period to
  AMDTP domain (jsc#SLE-16518).
- ALSA: dice: register the size of PCM period to AMDTP domain
  (jsc#SLE-16518).
- ALSA: oxfw: register the size of PCM period to AMDTP domain
  (jsc#SLE-16518).
- ALSA: fireworks: register the size of PCM period to AMDTP domain
  (jsc#SLE-16518).
- ALSA: bebob: register the size of PCM period to AMDTP domain
  (jsc#SLE-16518).
- ALSA: firewire-lib: add a member into AMDTP domain for events
  per period (jsc#SLE-16518).
- sound: Fix Kconfig indentation (jsc#SLE-16518).
- ASoC: samsung: Use pr_warn instead of pr_warning
  (jsc#SLE-16518).
- commit cf6bec5
* Fri Sep 25 2020 tiwai@suse.de
- ALSA: usb-audio: Fix incorrect size check for
  processing/extension units (jsc#SLE-16518).
- ALSA: usb-audio: Fix incorrect NULL check in
  create_yamaha_midi_quirk() (jsc#SLE-16518).
- ALSA: pcm: Fix stream lock usage in snd_pcm_period_elapsed()
  (jsc#SLE-16518).
- ALSA: usb-audio: not submit urb for stopped endpoint
  (jsc#SLE-16518).
- ALSA: hda: hdmi - fix pin setup on Tigerlake (jsc#SLE-16518).
- ALSA: hda: Add Cometlake-S PCI ID (jsc#SLE-16518).
- ALSA: usb-audio: Fix missing error check at mixer resolution
  test (jsc#SLE-16518).
- ASoC: SOF: topology: Fix bytes control size checks
  (jsc#SLE-16518).
- ASoC: max98373: replace gpio_request with devm_gpio_request
  (jsc#SLE-16518).
- ASoC: stm32: sai: add restriction on mmap support
  (jsc#SLE-16518).
- ASoC: hdac_hda: fix race in device removal (jsc#SLE-16518).
- ASoC: rockchip: rockchip_max98090: Enable SHDN to fix headset
  detection (jsc#SLE-16518).
- ASoC: ti: sdma-pcm: Add back the flags parameter for non
  standard dma names (jsc#SLE-16518).
- ASoC: SOF: ipc: Fix memory leak in sof_set_get_large_ctrl_data
  (jsc#SLE-16518).
- ASoC: SOF: Fix memory leak in sof_dfsentry_write
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda-stream: fix the CONFIG_ prefix missing
  (jsc#SLE-16518).
- ASoC: kirkwood: fix device remove ordering (jsc#SLE-16518).
- ASoC: rsnd: dma: fix SSI9 4/5/6/7 busif dma address
  (jsc#SLE-16518).
- ASoC: hdmi-codec: drop mutex locking again (jsc#SLE-16518).
- ASoC: kirkwood: fix external clock probe defer (jsc#SLE-16518).
- ASoC: compress: fix unsigned integer overflow check
  (jsc#SLE-16518).
- ASoC: msm8916-wcd-analog: Fix RX1 selection in RDAC2 MUX
  (jsc#SLE-16518).
- ALSA: timer: Fix incorrectly assigned timer instance
  (jsc#SLE-16518).
- ALSA: hda: hdmi - add Tigerlake support (jsc#SLE-16518).
- ALSA: hda/ca0132 - Fix possible workqueue stall (jsc#SLE-16518).
- ALSA: bebob: fix to detect configured source of sampling clock
  for Focusrite Saffire Pro i/o series (jsc#SLE-16518).
- ALSA: timer: Fix mutex deadlock at releasing card
  (jsc#SLE-16518).
- ALSA: hda - Fix mutex deadlock in HDMI codec driver
  (jsc#SLE-16518).
- Revert "ALSA: hda: Flush interrupts on disabling"
  (jsc#SLE-16518).
- ALSA: bebob: Fix prototype of helper function to return negative
  value (jsc#SLE-16518).
- ALSA: hda/realtek - Fix 2 front mics of codec 0x623
  (jsc#SLE-16518).
- ALSA: hda/realtek - Add support for ALC623 (jsc#SLE-16518).
- ALSA: usb-audio: Add DSD support for Gustard U16/X26 USB
  Interface (jsc#SLE-16518).
- ALSA: hda: Add Tigerlake/Jasperlake PCI ID (jsc#SLE-16518).
- ALSA: usb-audio: Fix copy&paste error in the validator
  (jsc#SLE-16518).
- ASoC: SOF: control: return true when kcontrol values change
  (jsc#SLE-16518).
- ASoC: stm32: sai: fix sysclk management on shutdown
  (jsc#SLE-16518).
- ASoC: Intel: sof-rt5682: add a check for devm_clk_get
  (jsc#SLE-16518).
- ASoC: rsnd: Reinitialize bit clock inversion flag for every
  format setting (jsc#SLE-16518).
- ASoC: simple_card_utils.h: Fix potential multiple redefinition
  error (jsc#SLE-16518).
- ASoC: msm8916-wcd-digital: add missing MIX2 path for RX1/2
  (jsc#SLE-16518).
- ASoC: core: Fix pcm code debugfs error (jsc#SLE-16518).
- ASoc: rockchip: i2s: Fix RPM imbalance (jsc#SLE-16518).
- ASoC: wm_adsp: Don't generate kcontrols without READ flags
  (jsc#SLE-16518).
- commit c4cd4f1
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: SOF: Intel: hda: Disable DMI L1 entry during capture
  (jsc#SLE-16518).
- Update config files.
- commit 577a760
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: intel: bytcr_rt5651: add null check to
  support_button_press (jsc#SLE-16518).
- ASoC: intel: sof_rt5682: add remove function to disable jack
  (jsc#SLE-16518).
- ASoC: rt5682: add NULL handler to set_jack function
  (jsc#SLE-16518).
- ASoC: intel: sof_rt5682: use separate route map for dmic
  (jsc#SLE-16518).
- ASoC: SOF: Intel: initialise and verify FW crash dump data
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: fix warnings during FW load
  (jsc#SLE-16518).
- ASoC: SOF: pcm: harden PCM STOP sequence (jsc#SLE-16518).
- ASoC: SOF: pcm: fix resource leak in hw_free (jsc#SLE-16518).
- ASoC: SOF: topology: fix parse fail issue for byte/bool tuple
  types (jsc#SLE-16518).
- ASoC: SOF: loader: fix kernel oops on firmware boot failure
  (jsc#SLE-16518).
- ASoC: wm_adsp: Fix theoretical NULL pointer for alg_region
  (jsc#SLE-16518).
- ASoC: max98373: check for device node before parsing
  (jsc#SLE-16518).
- ASoC: topology: Fix a signedness bug in
  soc_tplg_dapm_widget_create() (jsc#SLE-16518).
- ASoC: soc-component: fix a couple missing error assignments
  (jsc#SLE-16518).
- ASoC: wm8994: Do not register inapplicable controls for WM1811
  (jsc#SLE-16518).
- ASoC: samsung: arndale: Add missing OF node dereferencing
  (jsc#SLE-16518).
- ALSA: hda/realtek - Add support for ALC711 (jsc#SLE-16518).
- ALSA: hda - Force runtime PM on Nvidia HDMI codecs
  (jsc#SLE-16518).
- ALSA: hda/realtek - Enable headset mic on Asus MJ401TA
  (jsc#SLE-16518).
- ALSA: usb-audio: Disable quirks for BOSS Katana amplifiers
  (jsc#SLE-16518).
- ALSA: hdac: clear link output stream mapping (jsc#SLE-16518).
- ALSA: hda/realtek: Reduce the Headphone static noise on XPS
  9350/9360 (jsc#SLE-16518).
- ALSA: usb-audio: Add DSD support for EVGA NU Audio
  (jsc#SLE-16518).
- ASoC: ti: fix SND_SOC_DM365_VOICE_CODEC dependencies
  (jsc#SLE-16518).
- ASoC: pcm3168a: The codec does not support S32_LE
  (jsc#SLE-16518).
- ASoC: core: use list_del_init and move it back to
  soc_cleanup_component (jsc#SLE-16518).
- ASoC: rsnd: do error check after rsnd_channel_normalization()
  (jsc#SLE-16518).
- ASoC: atmel_ssc_dai: Remove wrong spinlock usage
  (jsc#SLE-16518).
- ASoC: core: delete component->card_list in soc_remove_component
  only (jsc#SLE-16518).
- ASoC: fsl_sai: Fix noise when using EDMA (jsc#SLE-16518).
- ALSA: hda - Add laptop imic fixup for ASUS M9V laptop
  (jsc#SLE-16518).
- ALSA: hda/realtek - PCI quirk for Medion E4254 (jsc#SLE-16518).
- ALSA: hda - Apply AMD controller workaround for Raven platform
  (jsc#SLE-16518).
- ALSA: usb-audio: Add Hiby device family to quirks for native
  DSD support (jsc#SLE-16518).
- ALSA: hda/realtek - Fix alienware headset mic (jsc#SLE-16518).
- ALSA: dice: fix wrong packet parameter for Alesis iO26
  (jsc#SLE-16518).
- ASoC: jz4740: Drop lb60 board code (jsc#SLE-16518).
- ALSA: pcm: use dma_can_mmap() to check if a device supports
  dma_mmap_* (jsc#SLE-16518).
- ASoC: sdm845: remove unneeded semicolon (jsc#SLE-16518).
- ASoC: fsl_sai: Implement set_bclk_ratio (jsc#SLE-16518).
- ASoC: wcd9335: remove redundant use of ret variable
  (jsc#SLE-16518).
- ASoC: dmaengine: Replace strncpy() with strscpy_pad() for
  pcm->name (jsc#SLE-16518).
- ASoC: hdmi-codec: Add an op to set callback function for plug
  event (jsc#SLE-16518).
- ASoC: rt5677: keep analog power register at SND_SOC_BIAS_OFF
  (jsc#SLE-16518).
- ASoC: rt5677: Remove magic number register writes
  (jsc#SLE-16518).
- ASoC: soc-core: self contained soc_unbind_aux_dev()
  (jsc#SLE-16518).
- ASoC: soc-core: add soc_unbind_aux_dev() (jsc#SLE-16518).
- commit 8433b27
* Fri Sep 25 2020 msuchanek@suse.de
- powerpc/64s: remove unnecessary translation cache flushes at
  boot (jsc#SLE-13512 bsc#1176916 ltc#186249).
- commit 43a7a4e
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net/mlx5e: Introduce kconfig var for TC support (jsc#SLE-15172).
- Update config files.
- commit 5ce8627
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net: qos: introduce a gate control flow action (bsc#1176447).
- Update config files.
- supported.conf: added net/sched/act_gate
- commit e2c4efd
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: soc-core: self contained soc_bind_aux_dev()
  (jsc#SLE-16518).
- ASoC: soc-core: move soc_probe_link_dais() next to
  soc_remove_link_dais() (jsc#SLE-16518).
- ASoC: soc-core: self contained soc_probe_link_dais()
  (jsc#SLE-16518).
- ASoC: soc-core: add new soc_link_init() (jsc#SLE-16518).
- ASoC: soc-core: move soc_probe_dai() next to soc_remove_dai()
  (jsc#SLE-16518).
- ASoC: soc-core: self contained soc_remove_link_dais()
  (jsc#SLE-16518).
- ASoC: soc-core: self contained soc_remove_link_components()
  (jsc#SLE-16518).
- ASoC: soc-core: self contained soc_probe_link_components()
  (jsc#SLE-16518).
- ASoC: rt1308: make array pd static const, makes object smaller
  (jsc#SLE-16518).
- ASoC: rt1305: make array pd static const, makes object smaller
  (jsc#SLE-16518).
- ASoC: rt1011: make array pd static const, makes object smaller
  (jsc#SLE-16518).
- SoC: simple-card-utils: set 0Hz to sysclk when shutdown
  (jsc#SLE-16518).
- ASoC: rockchip: ignore 0Hz sysclk (jsc#SLE-16518).
- ASoC: codecs: ad193x: make two arrays static const, makes
  object smaller (jsc#SLE-16518).
- ASoC: es8316: support fixed and variable both clock rates
  (jsc#SLE-16518).
- ASoC: es8316: fix redundant codes of clock (jsc#SLE-16518).
- ASoC: SOF: imx8: Fix COMPILE_TEST error (jsc#SLE-16518).
- ASoC: meson: tdmout: add sm1 support (jsc#SLE-16518).
- ASoC: meson: axg-toddr: add sm1 support (jsc#SLE-16518).
- ASoC: meson: axg-frddr: add sm1 support (jsc#SLE-16518).
- ASoC: meson: tdmin: expose all 16 inputs (jsc#SLE-16518).
- ASoC: meson: axg-toddr: expose all 8 inputs (jsc#SLE-16518).
- ASoC: meson: axg-frddr: expose all 8 outputs (jsc#SLE-16518).
- ASoC: qcom: common: Include link-name in error messages
  (jsc#SLE-16518).
- ASoC: soc-core: add comment to jack at soc_remove_component()
  (jsc#SLE-16518).
- ASoC: tegra: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-16518).
- ASoC: sirf-audio: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-16518).
- ASoC: ep93xx: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-16518).
- ASoC: amd: use devm_platform_ioremap_resource() to simplify code
  (jsc#SLE-16518).
- ASoC: es8316: add clock control of MCLK (jsc#SLE-16518).
- ASoC: audio-graph: indicate rebind issue (jsc#SLE-16518).
- ASoC: simple-card: indicate rebind issue (jsc#SLE-16518).
- ASoC: soc-core: move soc_probe_link_components() position
  (jsc#SLE-16518).
- ASoC: soc-core: add snd_soc_dapm_init() (jsc#SLE-16518).
- ASoC: soc-core: dapm related setup at one place (jsc#SLE-16518).
- ASoC: soc-core: move soc_probe_component() position
  (jsc#SLE-16518).
- ASoC: soc-core: add soc_rtd_free() (jsc#SLE-16518).
- ASoC: mediatek: mt8183: fix space issues (jsc#SLE-16518).
- ASoC: mediatek: mt8183: remove forward declaration of
  headset_init (jsc#SLE-16518).
- ASoC: mediatek: mt8183: move headset jack to card-specific
  storage (jsc#SLE-16518).
- ASoC: mediatek: mt8183: move private structure (jsc#SLE-16518).
- ASoC: SOF/Intel: fix selection of SND_INTEL_NHTL
  (jsc#SLE-16518).
- ASoC: Intel: broadwell: Simplify device probe (jsc#SLE-16518).
- ASoC: Intel: bdw-rt5677: Simplify device probe (jsc#SLE-16518).
- ASoC: Intel: haswell: Simplify device probe (jsc#SLE-16518).
- ASoC: Intel: Haswell: Adjust machine device private context
  (jsc#SLE-16518).
- ASoC: ti: davinci-evm: Do not fail if the dai_set_sysclk
  returns -ENOTSUPP (jsc#SLE-16518).
- ASoC: ti: edma-pcm: Fix for legacy dma_slave_map based channel
  lookup (jsc#SLE-16518).
- ASoC: ti: davinci-i2s: Add S32_LE as support format
  (jsc#SLE-16518).
- ASoC: wcd9335: Fix primary interpolator max rate
  (jsc#SLE-16518).
- commit 1cf9d9b
* Fri Sep 25 2020 tiwai@suse.de
- ALSA: pcm: add support for 352.8KHz and 384KHz sample rate
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183: fix tdm out data is valid on rising edge
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183: tdm hw support tdm out and 8ch i2s out
  (jsc#SLE-16518).
- ASoC: atmel_ssc_dai: implement left-justified data mode
  (jsc#SLE-16518).
- ASoC: atmel_ssc_dai: rework DAI format configuration
  (jsc#SLE-16518).
- ASoC: atmel: enable SOC_SSC_PDC and SOC_SSC_DMA in Kconfig
  (jsc#SLE-16518).
- ASoC: cs42xx8: Force suspend/resume during system suspend/resume
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Release topology when we are done with it
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Print module type instead of id
  (jsc#SLE-16518).
- ASoC: SOF: imx8: Fix an is IS_ERR() vs NULL check
  (jsc#SLE-16518).
- ASoC: sun4i: Revert A83t description (jsc#SLE-16518).
- ASoC: SOF: imx8: Fix return value check in imx8_probe()
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183: remove unused DAPM-related variables
  (jsc#SLE-16518).
- ASoC: sunxi: Revert initial A83t support (jsc#SLE-16518).
- ASoC: imx-audmix: register the card on a proper dev
  (jsc#SLE-16518).
- ASoC: SOF: imx8: Make some functions static (jsc#SLE-16518).
- ASoC: soc-core: rename soc_post_component_init() to
  soc_rtd_init() (jsc#SLE-16518).
- ASoC: soc-core: initialize list at one place (jsc#SLE-16518).
- ASoC: SOF: topology: fix get control data return type and
  arguments (jsc#SLE-16518).
- ASoC: soc-core: initialize component list (jsc#SLE-16518).
- commit 987bba9
* Fri Sep 25 2020 tiwai@suse.de
- soundwire: add debugfs support (jsc#SLE-16518).
- commit 69d2239
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net/mlx5e: CT: Introduce connection tracking (jsc#SLE-15172).
- Update config files.
- commit 5df5a19
* Fri Sep 25 2020 tiwai@suse.de
- soundwire: slave: fix scanf format (jsc#SLE-16518).
- soundwire: depend on ACPI || OF (jsc#SLE-16518).
- soundwire: stream: make stream name a const pointer
  (jsc#SLE-16518).
- soundwire: Add compute_params callback (jsc#SLE-16518).
- soundwire: core: add device tree support for slave devices
  (jsc#SLE-16518).
- soundwire: intel: handle disabled links (jsc#SLE-16518).
- soundwire: intel: add debugfs register dump (jsc#SLE-16518).
- soundwire: cadence_master: add debugfs register dump
  (jsc#SLE-16518).
- soundwire: intel: remove unused variables (jsc#SLE-16518).
- soundwire: intel: move shutdown() callback and don't export
  symbol (jsc#SLE-16518).
- soundwire: cadence_master: add kernel parameter to override
  interrupt mask (jsc#SLE-16518).
- soundwire: intel_init: add kernel module parameter to filter
  out links (jsc#SLE-16518).
- soundwire: cadence_master: fix divider setting in clock register
  (jsc#SLE-16518).
- soundwire: cadence_master: make use of mclk_freq property
  (jsc#SLE-16518).
- soundwire: intel: read mclk_freq property from firmware
  (jsc#SLE-16518).
- soundwire: add new mclk_freq field for properties
  (jsc#SLE-16518).
- soundwire: stream: remove unnecessary variable initializations
  (jsc#SLE-16518).
- soundwire: stream: fix disable sequence (jsc#SLE-16518).
- soundwire: include mod_devicetable.h to avoid compiling warnings
  (jsc#SLE-16518).
- soundwire: cadence_master: use firmware defaults for frame shape
  (jsc#SLE-16518).
- soundwire: export helpers to find row and column values
  (jsc#SLE-16518).
- soundwire: bus: improve dynamic debug comments for enumeration
  (jsc#SLE-16518).
- soundwire: cadence_master: revisit interrupt settings
  (jsc#SLE-16518).
- soundwire: intel: prevent possible dereference in hw_params
  (jsc#SLE-16518).
- soundwire: bus: split handling of Device0 events
  (jsc#SLE-16518).
- soundwire: cadence_master: simplify bus clash interrupt clear
  (jsc#SLE-16518).
- soundwire: intel: remove BIOS work-arounds (jsc#SLE-16518).
- soundwire: mipi_disco: Switch to use fwnode_property_count_uXX()
  (jsc#SLE-16518).
- commit d0bf0e7
* Fri Sep 25 2020 tiwai@suse.de
- blacklist.conf: remove soundwire entry to be backported
- commit a80dcc8
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net: UDP tunnel encapsulation module for tunnelling different
  protocols like MPLS, IP, NSH etc (jsc#SLE-15172).
- Update config files.
- supported.conf: added drivers/net/bareudp
- commit a45a4f9
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: mchp-i2s-mcc: Fix simultaneous capture and playback in
  master mode (jsc#SLE-16518).
- commit 91c0170
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net: sched: add Flow Queue PIE packet scheduler (jsc#SLE-15172).
- Update config files.
- supported.conf: added sch_fq_pie
- commit 346780e
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: soc-topology: use for_each_component_dais() at
  remove_dai() (jsc#SLE-16518).
- ASoC: soc-dai: use bit field for bus_control (jsc#SLE-16518).
- ASoC: soc-core: soc_cleanup_card_resources() become void
  (jsc#SLE-16518).
- ASoC: soc-core: add NOTE to snd_soc_rtdcom_lookup()
  (jsc#SLE-16518).
- ASoC: soc-core: use device_register() (jsc#SLE-16518).
- ASoC: mediatek: mt8183: switch tdm pins gpio function when
  playback on or off (jsc#SLE-16518).
- ASoC: mediatek: mt2701: Fix -Wunused-const-variable warnings
  (jsc#SLE-16518).
- ASoC: wm8988: fix typo in wm8988_right_line_controls
  (jsc#SLE-16518).
- ASoC: SOF: imx: Add i.MX8 HW support (jsc#SLE-16518).
- ASoC: SOF: Add OF DSP device support (jsc#SLE-16518).
- ASoC: sun4i-i2s: Add support for DSP formats (jsc#SLE-16518).
- ASoC: sun4i-i2s: Replace call to params_width by local variable
  (jsc#SLE-16518).
- ASoC: sun4i-i2s: Use the actual format width instead of an
  hardcoded one (jsc#SLE-16518).
- ASoC: sun4i-i2s: Use the physical / slot width for the clocks
  (jsc#SLE-16518).
- ASoC: sun4i-i2s: Add support for TDM slots (jsc#SLE-16518).
- ASoC: soc-core: remove unneeded dai_link check from
  snd_soc_remove_dai_link() (jsc#SLE-16518).
- ASoC: soc-core: merge snd_soc_initialize_card_lists()
  (jsc#SLE-16518).
- ASoC: fsl_sai: Add support for imx8qm (jsc#SLE-16518).
- ASoC: sun4i-i2s: Support more channels (jsc#SLE-16518).
- ASoC: sun4i-i2s: Pass the channels number as an argument
  (jsc#SLE-16518).
- ASoC: sun4i-i2s: Remove duplicated quirks structure
  (jsc#SLE-16518).
- ASoC: sun4i-i2s: Fix the LRCK period on A83t (jsc#SLE-16518).
- ASoC: sun4i-i2s: Fix MCLK Enable bit offset on A83t
  (jsc#SLE-16518).
- ASoC: sun4i-i2s: Fix WSS and SR fields for the A83t
  (jsc#SLE-16518).
- ASoC: sun4i-i2s: Fix the LRCK polarity (jsc#SLE-16518).
- ASoC: sun4i-i2s: Fix LRCK and BCLK polarity offsets on newer
  SoCs (jsc#SLE-16518).
- ASoC: sun4i-i2s: RX and TX counter registers are swapped
  (jsc#SLE-16518).
- ASoC: sun4i-i2s: Fix the MCLK and BCLK dividers on newer SoCs
  (jsc#SLE-16518).
- ASoC: sun4i-i2s: Use module clock as BCLK parent on newer SoCs
  (jsc#SLE-16518).
- ASoC: sun4i-i2s: Move the format configuration to a callback
  (jsc#SLE-16518).
- ASoC: sun4i-i2s: Move the channel configuration to a callback
  (jsc#SLE-16518).
- ASoC: sun4i-i2s: Rework MCLK divider calculation
  (jsc#SLE-16518).
- ASoC: sun4i-i2s: Replace call to params_channels by local
  variable (jsc#SLE-16518).
- ASoC: sun4i-i2s: Don't use the oversample to calculate BCLK
  (jsc#SLE-16518).
- ASoC: sun4i-i2s: Switch to devm for PCM register
  (jsc#SLE-16518).
- ASoC: SOF: pcm: add ALH support (jsc#SLE-16518).
- ASoC: SOF: topology: initial support for Intel ALH DAI type
  (jsc#SLE-16518).
- ASoC: SOF: rename SOUNDWIRE to ALH (jsc#SLE-16518).
- ASoC: SOF: topology: Add dummy support for i.MX8 DAIs
  (jsc#SLE-16518).
- commit c18e070
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net: sch_ets: Add a new Qdisc (bsc#1176774).
- Update config files.
- supported.conf: added net/sch_ets
- commit fe91ed8
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: SOF: Intel: initial support for Elkhart Lake
  (jsc#SLE-16518).
- Update config files.
- commit fe8f01e
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: Intel: common: add ACPI matching tables for EHL
  (jsc#SLE-16518).
- ASoC: SOF: Intel: initial support for Tiger Lake
  (jsc#SLE-16518).
- ASoC: Intel: common: add ACPI matching tables for Tiger Lake
  (jsc#SLE-16518).
- ASoC: SOF: ipc: add ALH parameters (jsc#SLE-16518).
- commit 294ec6d
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: Intel: boards: Add Cometlake machine driver support
  (jsc#SLE-16518).
- Update config files.
- Refresh
  patches.suse/asoc-intel-convert-to-new-x86-cpu-match-macros.patch.
- commit 7ad7a67
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net: openvswitch: Set OvS recirc_id from tc chain index
  (jsc#SLE-15172).
- Update config files.
- commit 4bb3ca6
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net: phy: adin: add support for Analog Devices PHYs
  (bsc#1176447).
- Update config files.
- commit 0ad321e
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: core: Move pcm_mutex up to card level from
  snd_soc_pcm_runtime (jsc#SLE-16518).
- ASoC: 88pm860x: remove unused variables 'pcm_switch_controls'
  and 'aif1_mux' (jsc#SLE-16518).
- ASoC: cs42l56: remove unused variable 'adc_swap_enum'
  (jsc#SLE-16518).
- ASoC: es8328: remove unused variable 'pga_tlv' (jsc#SLE-16518).
- ASoC: tlv320aic31xx: remove unused variable 'cm_m_enum'
  (jsc#SLE-16518).
- ASoC: tlv320aic23: remove unused variable 'tlv320aic23_rec_src'
  (jsc#SLE-16518).
- ASoC: rt1011: remove unused variable 'dac_vol_tlv' and
  'adc_vol_tlv' (jsc#SLE-16518).
- ASoC: max98371: remove unused variable
  'max98371_noload_gain_tlv' (jsc#SLE-16518).
- ASoC: cs42l73: remove unused variables 'vsp_output_mux' and
  'xsp_output_mux' (jsc#SLE-16518).
- ASoC: Intel: Skylake: Print constant literals from format
  specifier (jsc#SLE-16518).
- ASoC: mediatek: mt6358: add delay after dmic clock on
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183-mt6358-ts3a227-max98357: remove unused
  variables (jsc#SLE-16518).
- ASoC: mediatek: mt8183-da7219-max98357: remove unused variable
  (jsc#SLE-16518).
- ASoC: mt2701: remove unused variables (jsc#SLE-16518).
- ASoC: soc-core: Fix -Wunused-const-variable warning
  (jsc#SLE-16518).
- ASoC: Intel: hsw: remove i386 build warning w/ size_t argument
  (jsc#SLE-16518).
- ASoC: ti: Fix typos in ti/Kconfig (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: fixup HDaudio topology name with DMIC
  number (jsc#SLE-16518).
- ASoC: pcm3168a: Allow reconfiguration of tdm_slots and
  slot_width (jsc#SLE-16518).
- ASoC: pcm3168a: Retain the independence of DAC and ADC side
  of the codec (jsc#SLE-16518).
- ASoC: Intel: skl-hda-dsp-generic: add dmic dapm widget and route
  (jsc#SLE-16518).
- ASoC: Intel: skl-hda-dsp-generic: add dependency to dmic driver
  (jsc#SLE-16518).
- ASoC: Intel: boards: Match Product Family instead of product
  (jsc#SLE-16518).
- ASoC: dapm: Invalidate only paths reachable for a given stream
  (jsc#SLE-16518).
- ASoC: SOF: topology: use set_get_data in process load
  (jsc#SLE-16518).
- ASoC: fsl_esai: Add compatible string for imx6ull
  (jsc#SLE-16518).
- ASoC: rt5677: Revert remove superfluous set (jsc#SLE-16518).
- ASoC: remove w90x900/nuc900 platform drivers (jsc#SLE-16518).
- ASoC: soc-core: add for_each_xxx macro for aux_dev
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183-mt6358-ts3a227-max98357: use
  snd_soc_dai_link_component for aux_dev (jsc#SLE-16518).
- ASoC: max9850: remove unused variable 'max9850_reg'
  (jsc#SLE-16518).
- ASoC: max98926: remove two unused variables (jsc#SLE-16518).
- ASoC: soc-core: remove legacy style of aux_dev (jsc#SLE-16518).
- ASoC: ti: rx51: use snd_soc_dai_link_component for aux_dev
  (jsc#SLE-16518).
- ASoC: sunxi: sun4i-codec: use snd_soc_dai_link_component for
  aux_dev (jsc#SLE-16518).
- ASoC: samsung: tm2_wm5110: use snd_soc_dai_link_component for
  aux_dev (jsc#SLE-16518).
- ASoC: samsung: speyside: use snd_soc_dai_link_component for
  aux_dev (jsc#SLE-16518).
- ASoC: samsung: neo1973_wm8753: use snd_soc_dai_link_component
  for aux_dev (jsc#SLE-16518).
- ASoC: rockchip: rockchip_max98090: use
  snd_soc_dai_link_component for aux_dev (jsc#SLE-16518).
- ASoC: meson: axg-card: use snd_soc_dai_link_component for
  aux_dev (jsc#SLE-16518).
- commit 9c21c82
* Fri Sep 25 2020 msuchanek@suse.de
- Refresh papr_scm patches closer to upstream.
- Refresh patches.suse/powerpc-papr_scm-Fetch-nvdimm-health-information-fro.patch.
- Refresh patches.suse/powerpc-papr_scm-Fetch-nvdimm-performance-stats-from.patch.
- commit 16750a8
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: mediatek: mt8183-da7219-max98357: use
  snd_soc_dai_link_component for aux_dev (jsc#SLE-16518).
- ASoC: intel: cht_bsw_max98090_ti: use snd_soc_dai_link_component
  for aux_dev (jsc#SLE-16518).
- ASoC: simple-card: use snd_soc_dai_link_component for aux_dev
  (jsc#SLE-16518).
- ASoC: soc-core: support snd_soc_dai_link_component for aux_dev
  (jsc#SLE-16518).
- ASoC: SOF: Intel: byt: Refactor fw ready / mem windows creation
  (jsc#SLE-16518).
- ASoC: SOF: Introduce snd_sof_dsp_get_window_offset
  (jsc#SLE-16518).
- ASoC: SOF: Introduce snd_sof_dsp_get_mailbox_offset
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Use generic function for fw ready /
  mem windows creation (jsc#SLE-16518).
- ASoC: SOF: Intel: bdw: Use generic function for fw ready /
  mem windows creation (jsc#SLE-16518).
- ASoC: SOF: Remove call to snd_sof_dsp_mailbox_init
  (jsc#SLE-16518).
- ASoC: ml26124: remove unused variable 'ngth' (jsc#SLE-16518).
- ASoC: mt6351: remove unused variable 'mt_lineout_control'
  (jsc#SLE-16518).
- ASoC: sof: Fix warning when IPC flood test is not enabled
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: large_config_get overhaul (jsc#SLE-16518).
- ASoC: Intel: Skylake: Limit large_config_get to single frame
  (jsc#SLE-16518).
- ASoC: intel: skl_hda_dsp_common: create HDMI jack kctl
  (jsc#SLE-16518).
- ASoC: tscs454: remove unused variable 'PLL_48K_RATE'
  (jsc#SLE-16518).
- ASoC: soc-core: fix module_put() warning in
  soc_cleanup_component (jsc#SLE-16518).
- ASoC: soc-core: dai_link check under soc_dpcm_debugfs_add()
  (jsc#SLE-16518).
- commit 9712477
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: soc-core: define soc_dpcm_debugfs_add() for non
  CONFIG_DEBUG_FS (jsc#SLE-16518).
- ASoC: soc-core: tidyup for card->deferred_resume_work
  (jsc#SLE-16518).
- ASoC: soc-core: remove unneeded list_empty() check for
  snd_soc_try_rebind_card() (jsc#SLE-16518).
- ASoC: soc-core: call snd_soc_dapm_debugfs_init() at
  soc_init_card_debugfs() (jsc#SLE-16518).
- ASoC: soc-core: tidyup for snd_soc_add_card_controls()
  (jsc#SLE-16518).
- ASoC: soc-core: tidyup for snd_soc_dapm_add_routes()
  (jsc#SLE-16518).
- ASoC: soc-core: tidyup for snd_soc_add_component_controls()
  (jsc#SLE-16518).
- ASoC: fsl_sai: Add support for imx7ulp/imx8mq (jsc#SLE-16518).
- ASoC: fsl_sai: Add support for SAI new version (jsc#SLE-16518).
- ASoC: fsl_sai: Update Tx/Rx channel enable mask (jsc#SLE-16518).
- ASoC: fsl_sai: Add registers definition for multiple datalines
  (jsc#SLE-16518).
- ASoC: Intel: Update request-reply IPC model (jsc#SLE-16518).
- ASoC: soc-core: tidyup for snd_soc_dapm_new_controls()
  (jsc#SLE-16518).
- ASoC: soc-core: reuse rtdcom at snd_soc_rtdcom_add()
  (jsc#SLE-16518).
- ASoC: soc-core: don't use for_each_card_links_safe() at
  snd_soc_find_dai_link() (jsc#SLE-16518).
- ASoC: soc-core: check return value of snd_soc_add_dai_link()
  (jsc#SLE-16518).
- ASoC: soc-core: add comment for for_each_xxx (jsc#SLE-16518).
- ASoC: soc-core: set component->debugfs_root NULL
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: fix MSI handling (jsc#SLE-16518).
- ASoC: rt1011: Add a flag for the R0 calibration test
  (jsc#SLE-16518).
- ASoC: rt1011: Add R0 temperature and TDM1 ADC2DAT Swap control
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_pcm_component_pcm_free()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_pcm_component_pcm_new()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_pcm_component_mmap()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_pcm_component_page()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_pcm_component_copy_user()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_pcm_component_ioctrl()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_pcm_component_pointer()
  (jsc#SLE-16518).
- ASoC: soc-component: move snd_soc_component_set_bias_level()
  (jsc#SLE-16518).
- ASoC: soc-component: move snd_soc_component_stream_event()
  (jsc#SLE-16518).
- ASoC: soc-component: move snd_soc_component_seq_notifier()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_of_xlate_dai_name()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_of_xlate_dai_id()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_remove()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_probe()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_is_suspended()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_resume()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_suspend()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_trigger()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_hw_free()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_hw_params()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_prepare()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_close()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_open()
  (jsc#SLE-16518).
- ASoC: soc-component: add snd_soc_component_get/put()
  (jsc#SLE-16518).
- ASoC: add soc-component.c (jsc#SLE-16518).
- ASoC: soc-pcm: remove soc_fill_silence() (jsc#SLE-16518).
- ASoC: soc-pcm: remove soc_rtdcom_copy_kernel() (jsc#SLE-16518).
- ASoC: soc-pcm: remove soc_rtdcom_ack() (jsc#SLE-16518).
- ASoC: Remove dev_err() usage after platform_get_irq()
  (jsc#SLE-16518).
- commit f8ad30f
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: zx-tdm: remove redundant assignment to ts_width on error
  return path (jsc#SLE-16518).
- ASoC: SOF: no need to check return value of debugfs_create
  functions (jsc#SLE-16518).
- ASoC: core: no need to check return value of debugfs_create
  functions (jsc#SLE-16518).
- ASoC: Intel: SoC: skylake: no need to check return value of
  debugfs_create functions (jsc#SLE-16518).
- ASoC: codec2codec: fill some of the runtime stream parameters
  (jsc#SLE-16518).
- ASoC: codec2codec: remove ephemeral variables (jsc#SLE-16518).
- ASoC: create pcm for codec2codec links as well (jsc#SLE-16518).
- commit f0cb65a
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: codecs: Add uda1334 codec driver (jsc#SLE-16518).
- Update config files.
- commit ddb3639
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: meson: axg-tdm-formatter: use
  devm_platform_ioremap_resource() to simplify code
  (jsc#SLE-16518).
- ASoC: meson: g12a-tohdmitx: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-16518).
- commit 3e5f472
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: au1x: psc-i2s: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-16518).
- ASoC: psc-ac97: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-16518).
- ASoC: uniphier: aio-dma: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-16518).
- ASoC: uniphier: evea: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-16518).
- ASoC: inno_rk3036: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-16518).
- ASoC: jz4740: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-16518).
- ASoC: mmp-sspa: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-16518).
- ASoC: codecs: jz4725b: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-16518).
- ASoC: codecs: msm8916-wcd: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-16518).
- ASoC: stm32: sai: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-16518).
- ASoC: sun8i-codec: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-16518).
- ASoC: sunxi: sun50i-codec-analog: use
  devm_platform_ioremap_resource() to simplify code
  (jsc#SLE-16518).
- ASoC: sun8i-codec-analog: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-16518).
- ASoC: xlnx: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-16518).
- ASoC: meson: axg-fifo: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-16518).
- ASoC: meson: axg-spdifout: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-16518).
- ASoC: meson: axg-spdifin: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-16518).
- ASoC: meson: axg-pdm: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-16518).
- ASoC: cs4271: Fix a typo in the CS4171_NR_RATIOS
  (jsc#SLE-16518).
- ASoC: ti: Mark expected switch fall-throughs (jsc#SLE-16518).
- ASoC: xtfpga-i2s: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-16518).
- ASoC: kirkwood-i2s: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-16518).
- ASoC: spear: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-16518).
- ASoC: mxs-saif: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-16518).
- ASoC: sirf: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-16518).
- ASoC: bcm2835-i2s: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-16518).
- ASoC: fsl_audmix: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-16518).
- ASoC: imx-audmux: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-16518).
- ASoC: mt6797: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-16518).
- ASoC: mt8173: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-16518).
- commit 2a5358e
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: ep93xx-i2s: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-16518).
- ASoC: rockchip: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-16518).
- ASoC: tegra: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-16518).
- ASoC: tegra20_das: use devm_platform_ioremap_resource() to
  simplify code (jsc#SLE-16518).
- ASoC: meson: g12a-tohdmitx: override codec2codec params
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Remove static table index when parsing
  topology (jsc#SLE-16518).
- ASoC: codec2codec: fix missing return of error return code
  (jsc#SLE-16518).
- ASoC: ti: davinci-mcasp: Support for correct symmetric sample
  bits (jsc#SLE-16518).
- ASoC: codec2codec: deal with params when necessary
  (jsc#SLE-16518).
- ASoC: codec2codec: name link using stream direction
  (jsc#SLE-16518).
- ASoC: codec2codec: run callbacks in order (jsc#SLE-16518).
- ASoC: cs47l92: Add codec driver for Cirrus Logic CS47L92
  (jsc#SLE-16518).
- ASoC: cs47l15: Add codec driver for Cirrus Logic CS47L15
  (jsc#SLE-16518).
- ASoC: wm_adsp: Allow bus error handler to be called directly
  (jsc#SLE-16518).
- ASoC: SOF: Makefile - fix the top-level kernel module names
  (add snd- prefix) (jsc#SLE-16518).
- ASoC: ti: davinci-mcasp: Improve serializer handling in multi
  AXR setups (jsc#SLE-16518).
- ASoC: ti: davinci-mcasp: Add support for RIGHT_J format
  (jsc#SLE-16518).
- ASoC: pcm3168a: Allow all channels in case of parallel DIN/DOUT
  setup (jsc#SLE-16518).
- ASoC: Intel: Skylake: Cleanup skl_module_cfg declaration
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Make MCPS and CPS params obsolete
  (jsc#SLE-16518).
- commit 1b1cb98
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: Intel: Skylake: Do not disable FW notifications
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Remove memory available check
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Remove MCPS available check
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Combine snd_soc_skl_ipc and snd_soc_skl
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Merge skl_sst and skl into skl_dev struct
  (jsc#SLE-16518).
- ASoC: wm8955: Fix a typo in 'wm8995_pll_factors()' function name
  (jsc#SLE-16518).
- ASoC: soc-dai: move snd_soc_dai_stream_valid() to soc-dai.c
  (jsc#SLE-16518).
- ASoC: soc-core: use existing snd_soc_dai_digital_mute()
  (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_compress_new() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_remove() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_probe() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_resume() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_suspend() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_delay() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_bespoke_trigger()
  (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_trigger() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_prepare() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_shutdown() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_startup() (jsc#SLE-16518).
- ASoC: soc-dai: add snd_soc_dai_hw_free() (jsc#SLE-16518).
- ASoC: soc-dai: mv soc_dai_hw_params() to soc-dai
  (jsc#SLE-16518).
- ASoC: add soc-dai.c (jsc#SLE-16518).
- ASoC: rsnd: Support hw_free() callback at DAI level
  (jsc#SLE-16518).
- ASoC: rt1308: Convert headers to SPDX (jsc#SLE-16518).
- ASoC: rt5665: Fix a typo in the name of a function
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: fix stream id setting (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: fix link DMA config (jsc#SLE-16518).
- ASoC: fsl_esai: recover the channel swap after xrun
  (jsc#SLE-16518).
- ASoC: SOF: Intel: ssp: BCLK delay parameter (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: reset link DMA state in prepare
  (jsc#SLE-16518).
- commit a2cfd41
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: SOF: Intel: hda: add a parameter to disable MSI
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: remove duplicated clear WAKESTS
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: use SOF defined init chip in resume
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: set position buffer in init chip
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Enable jack detection (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: reduce ifdef usage for hda
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: correct ROM state mask (jsc#SLE-16518).
- ASoC: SOF: remove unused state variable in suspend function
  (jsc#SLE-16518).
- ASoC: SOF: loader: Don't ignore SRAM block types
  (jsc#SLE-16518).
- ASoC: SOF: loader: Use the BAR provided by FW (jsc#SLE-16518).
- ASoC: SOF: Introduce snd_sof_dsp_get_bar_index ops
  (jsc#SLE-16518).
- ASoC: SOF: core: increase default IPC timeouts (jsc#SLE-16518).
- ASoC: SOF: ipc: use timeout configured at probe (jsc#SLE-16518).
- ASoC: SOF: use common code to send PCM_FREE IPC (jsc#SLE-16518).
- ASoC: SOF: reset DMA state in prepare (jsc#SLE-16518).
- ASoC: SOF: pci: mark last_busy value at runtime PM init
  (jsc#SLE-16518).
- ASoC: pcm3168a: Fix a typo in the name of a constant
  (jsc#SLE-16518).
- ASoC: madera: Read device tree configuration (jsc#SLE-16518).
- ASoC: sgtl5000: Fix charge pump source assignment
  (jsc#SLE-16518).
- ASoC: sgtl5000: Fix of unmute outputs on probe (jsc#SLE-16518).
- ASoC: sgtl5000: add ADC mute control (jsc#SLE-16518).
- ASoC: sgtl5000: Fix definition of VAG Ramp Control
  (jsc#SLE-16518).
- ASoC: sgtl5000: Improve VAG power and mute control
  (jsc#SLE-16518).
- ASoC: Define a set of DAPM pre/post-up events (jsc#SLE-16518).
- ASoC: rockchip-max98090: Remove MICBIAS as supply of input
  pin IN34 (jsc#SLE-16518).
- ASoC: cs47l35: Use define for DSPCLK enable bit (jsc#SLE-16518).
- ASoC: rt1308: add silence detection and manual PDB control
  (jsc#SLE-16518).
- ASoC: rt1308: simplify the EFUSE read function (jsc#SLE-16518).
- ASoC: tlv320aic31xx: suppress error message for EPROBE_DEFER
  (jsc#SLE-16518).
- ASoC: max98383: fix i2c probe failure (jsc#SLE-16518).
- commit b1e6694
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: fsl_sai: mark regmap as fast_io (jsc#SLE-16518).
- ASoC: fsl_sai: derive TX FIFO watermark from FIFO depth
  (jsc#SLE-16518).
- ASoC: fsl_sai: add of_match data (jsc#SLE-16518).
- ASoC: mediatek: mt8183: make headset codec optional
  (jsc#SLE-16518).
- ASoC: wcd9335: add irqflag IRQF_ONESHOT flag (jsc#SLE-16518).
- ASoC: bcm: cygnus-pcm: Unneeded variable: "ret" (jsc#SLE-16518).
- sound: soc: codecs: mt6358: change return type of
  mt6358_codec_init_reg (jsc#SLE-16518).
- ASoC: fsl_esai: Wrap some operations to be functions
  (jsc#SLE-16518).
- ASoC: rt5677: remove superfluous set (jsc#SLE-16518).
- ASoC: codecs: ad193x: Use regmap_multi_reg_write() when
  initializing (jsc#SLE-16518).
- ASoC: wcd9335: Fix misuse of GENMASK macro (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Make hdac_device device-managed
  (jsc#SLE-16518).
- ASoC: ams-delta: Take control over audio mute GPIO pins
  (jsc#SLE-16518).
- ASoC: dmaengine: Make the pcm->name equal to pcm->id if the
  name is not set (jsc#SLE-16518).
- ASoC: ti: davinci-i2s: Move the XSYNCERR workaround to .prepare
  callback (jsc#SLE-16518).
- ASoC: Intel: Baytrail: Fix implicit fallthrough warning
  (jsc#SLE-16518).
- ASoC: fsl_ssi: Fix clock control issue in master mode
  (jsc#SLE-16518).
- ASoC: mediatek: mt8183: fix tdm out data align issue
  (jsc#SLE-16518).
- ASoC: rt1011: add mutex protection to set_fmt/set_tdm_slot
  (jsc#SLE-16518).
- ASoC: es8316: fix inverted L/R of headphone mixer volume
  (jsc#SLE-16518).
- ASoC: es8316: fix headphone mixer volume table (jsc#SLE-16518).
- ASoC: Intel: NHLT: Fix debug print format (jsc#SLE-16518).
- ASoC: dapm: Expose snd_soc_dapm_new_control_unlocked properly
  (jsc#SLE-16518).
- ASoC: Intel: Fix use of potentially uninitialized variable
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: Use correct function to access iomem space
  (jsc#SLE-16518).
- ASoC: AMD: Fix Kconfig warning without GPIOLIB (jsc#SLE-16518).
- ASoC: mchp-i2s-mcc: Wait for RX/TX RDY only if controller is
  running (jsc#SLE-16518).
- ASoC: mchp-i2s-mcc: Fix unprepare of GCLK (jsc#SLE-16518).
- ASoC: sun4i-i2s: Register regmap and PCM before our component
  (jsc#SLE-16518).
- ASoC: wm8904: implement input mode select as a mux
  (jsc#SLE-16518).
- ASoC: wm8904: fix typo in DAPM kcontrol name (jsc#SLE-16518).
- ASoC: intel: cht_bsw_max98090_ti: Add all Chromebooks that
  need pmc_plt_clk_0 quirk (jsc#SLE-16518).
- ASoC: meson: g12a-tohdmitx: require regmap mmio (jsc#SLE-16518).
- ASoC: meson: axg-tdm-formatter: free reset on device removal
  (jsc#SLE-16518).
- ASoC: uniphier: Fix double reset assersion when transitioning
  to suspend state (jsc#SLE-16518).
- ASoC: imx-audmux: Add driver suspend and resume to support
  MEGA Fast (jsc#SLE-16518).
- ASoC: wm8737: Fix copy-paste error in wm8737_snd_controls
  (jsc#SLE-16518).
- ASoC: cs4349: Use PM ops 'cs4349_runtime_pm' (jsc#SLE-16518).
- ASoC: es8328: Fix copy-paste error in es8328_right_line_controls
  (jsc#SLE-16518).
- ASoC: rockchip: rockchip_max98090: Set period size to 240
  (jsc#SLE-16518).
- commit 27dba45
* Fri Sep 25 2020 msuchanek@suse.de
- powerpc/kernel: Enables memory hot-remove after reboot on
  pseries guests (bsc#1177030 ltc#187588).
- powerpc/mm: Limit resize_hpt_for_hotplug() call to hash guests
  only (bsc#1177030 ltc#187588).
- powerpc/mm: Limit resize_hpt_for_hotplug() call to hash guests
  only (jsc#SLE-13512).
- powerpc/mm/book3s64/radix: Off-load TLB invalidations to host
  when !GTSE (jsc#SLE-13512).
- powerpc/pseries: H_REGISTER_PROC_TBL should ask for GTSE only
  if enabled (jsc#SLE-13512).
- powerpc/kernel: Enables memory hot-remove after reboot on
  pseries guests (jsc#SLE-13512).
  Refresh patches.suse/powerpc-drmem-Make-LMB-walk-a-bit-more-flexible.patch
- powerpc/64s: make mmu_partition_table_set_entry TLB flush
  optional (jsc#SLE-13512).
- commit 9885202
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: Intel: sof-rt5682: add dmic dapm widget to support dmic
  PCM (jsc#SLE-16518).
- ASoC: hdac_hdmi: Offload dapm update at jack detection
  (jsc#SLE-16518).
- ASoC: hdac_hda: fix page fault issue by removing race
  (jsc#SLE-16518).
- ASoC: SOF: Intel: hda: Initialize HDA controller after i915 init
  (jsc#SLE-16518).
- ASoC: rsnd: don't call clk_get_rate() under atomic context
  (jsc#SLE-16518).
- ALSA: lx6464es - add support for LX6464ESe pci express variant
  (jsc#SLE-16518).
- ALSA: firewire-lib: remove WARN_ON() at destruction of AMDTP
  domain (jsc#SLE-16518).
- ALSA: firewire-tascam: add note for FE-8 (jsc#SLE-16518).
- Add Acer Aspire Ethos 8951G model quirk (jsc#SLE-16518).
- ALSA: hda/hdmi: remove redundant assignment to variable pcm_idx
  (jsc#SLE-16518).
- ALSA: firewire-motu: add support for MOTU 4pre (jsc#SLE-16518).
- ALSA: firewire-lib: fix isoc cycle count to which rx packet
  is scheduled (jsc#SLE-16518).
- ALSA: dice: fix error path for initialization of stream
  structures (jsc#SLE-16518).
- ALSA: hda - Update descriptions about new position_fix values
  (jsc#SLE-16518).
- ALSA: usb-audio: Update DSD support quirks for Oppo and Rotel
  (jsc#SLE-16518).
- ALSA: usb-audio: DSD auto-detection for Playback Designs
  (jsc#SLE-16518).
- ALSA: hda - Allow runtime PM for controller if component
  notifier is used (jsc#SLE-16518).
- ALSA: oxfw: fix NULL pointer dereference to unused stream
  structure (jsc#SLE-16518).
- ALSA: usb-audio: remove some dead code (jsc#SLE-16518).
- ALSA: usb-audio: Fix possible NULL dereference at
  create_yamaha_midi_quirk() (jsc#SLE-16518).
- ALSA: usb-audio: Clean up check_input_term() (jsc#SLE-16518).
- ALSA: usb-audio: Remove superfluous bLength checks
  (jsc#SLE-16518).
- ALSA: usb-audio: Unify the release of usb_mixer_elem_info
  objects (jsc#SLE-16518).
- ALSA: usb-audio: Simplify parse_audio_unit() (jsc#SLE-16518).
- ALSA: usb-audio: More validations of descriptor units
  (jsc#SLE-16518).
- ALSA: hda/realtek - Blacklist PC beep for Lenovo ThinkCentre
  M73/93 (jsc#SLE-16518).
- ALSA: hda/realtek - Check beep whitelist before assigning in
  all codecs (jsc#SLE-16518).
- ALSA: hda - Define a fallback_pin_fixup_tbl for alc269 family
  (jsc#SLE-16518).
- ALSA: hda - Expand pin_match function to match upcoming new tbls
  (jsc#SLE-16518).
- Revert "ALSA: hda: Add codec on bus address table lately"
  (jsc#SLE-16518).
- ALSA: hda: Unexport a few more stuff (jsc#SLE-16518).
- ALSA: hda: Drop export of snd_hdac_bus_add/remove_device()
  (jsc#SLE-16518).
- ALSA: hda: Add codec on bus address table lately
  (jsc#SLE-16518).
- ALSA: hda - Drop unsol event handler for Intel HDMI codecs
  (jsc#SLE-16518).
- ALSA: sb: remove redundant assignment to variable result
  (jsc#SLE-16518).
- ALSA: hda/sigmatel - remove unused variable 'stac9200_core_init'
  (jsc#SLE-16518).
- ALSA: hda: Set fifo_size for both playback and capture streams
  (jsc#SLE-16518).
- ALSA: hda - Add a quirk model for fixing Huawei Matebook X
  right speaker (jsc#SLE-16518).
- ALSA: hda - Inform too slow responses (jsc#SLE-16518).
- ASoC: SOF: Intel: Add missing include file hdac_hda.h
  (jsc#SLE-16518).
- ALSA: ac97: remove unused variable
  'snd_ac97_controls_master_mono' (jsc#SLE-16518).
- ALSA: hda: readl/writel need linux/io.h (jsc#SLE-16518).
- ASoC: SOF: Intel: Initialize hdaudio bus properly
  (jsc#SLE-16518).
- ALSA: hda: Direct MMIO accesses (jsc#SLE-16518).
- ALSA: hda: Remove page allocation redirection (jsc#SLE-16518).
- ALSA: usb-audio: Add Pioneer DDJ-SX3 PCM quirck (jsc#SLE-16518).
- ALSA: usb-audio: Skip bSynchAddress endpoint check if it is
  invalid (jsc#SLE-16518).
- ALSA: usb-audio: fix PCM device order (jsc#SLE-16518).
- ALSA: usb-audio: Unify audioformat release code (jsc#SLE-16518).
- ALSA: firewire-lib: localize kernel APIs to start/stop each
  AMDTP stream (jsc#SLE-16518).
- commit 48650a6
* Fri Sep 25 2020 tiwai@suse.de
- ALSA: fireface: support AMDTP domain (jsc#SLE-16518).
- ALSA: firewire-motu: support AMDTP domain (jsc#SLE-16518).
- ALSA: firewire-tascam: support AMDTP domain (jsc#SLE-16518).
- ALSA: firewire-digi00x: support AMDTP domain (jsc#SLE-16518).
- ALSA: dice: support AMDTP domain (jsc#SLE-16518).
- ALSA: oxfw: support AMDTP domain (jsc#SLE-16518).
- ALSA: fireworks: support AMDTP domain (jsc#SLE-16518).
- ALSA: bebob: support AMDTP domain (jsc#SLE-16518).
- ALSA: fireface: code refactoring for initialization/destruction
  of AMDTP stream (jsc#SLE-16518).
- ALSA: firewire-motu: code refactoring for
  initialization/destruction of AMDTP stream (jsc#SLE-16518).
- ALSA: firewire-tascam: code refactoring for
  initialization/destruction of AMDTP stream (jsc#SLE-16518).
- ALSA: firewire-digi00x: code refactoring for
  initialization/destruction of AMDTP stream (jsc#SLE-16518).
- ALSA: fireworks: code refactoring for bus reset handler
  (jsc#SLE-16518).
- ALSA: fireworks: code refactoring for initialization/destruction
  of AMDTP streams (jsc#SLE-16518).
- ALSA: firewire-lib: add a kernel API to start AMDTP streams
  in AMDTP domain (jsc#SLE-16518).
- ALSA: firewire-lib: add a kernel API to add AMDTP stream into
  AMDTP domain (jsc#SLE-16518).
- ALSA: firewire-lib: add a kernel API to stop a couple of AMDTP
  streams in AMDTP domain (jsc#SLE-16518).
- ALSA: firewire-lib: add AMDTP domain structure to handle
  several isoc contexts (jsc#SLE-16518).
- ALSA: hda: Add support of Zhaoxin controller (jsc#SLE-16518).
- ALSA: isa/wavefront: remove redundant assignment to pointer bptr
  (jsc#SLE-16518).
- commit 45bf547
* Fri Sep 25 2020 tiwai@suse.de
- ALSA: hda/intel: stop probe if DMICS are detected on Skylake+
  platforms (jsc#SLE-16518).
- Update config files.
- commit 697fd6a
* Fri Sep 25 2020 tiwai@suse.de
- ASoC: Intel: Skylake: use common NHLT module (jsc#SLE-16518).
- ALSA: hda: intel-nhlt: handle NHLT VENDOR_DEFINED DMIC geometry
  (jsc#SLE-16518).
- ALSA: hda: move parts of NHLT code to new module
  (jsc#SLE-16518).
- ASoC: Intel: Skylake: move NHLT header to common directory
  (jsc#SLE-16518).
- ALSA: sparc: Mark expected switch fall-throughs (jsc#SLE-16518).
- sound: dmasound_atari: Mark expected switch fall-through
  (jsc#SLE-16518).
- ALSA: aoa: onyx: always initialize register read value
  (jsc#SLE-16518).
- ALSA: usb-audio: Scarlett Gen 2 mixer interface (jsc#SLE-16518).
- ALSA: i2c: ak4xxx-adda: Fix a possible null pointer dereference
  in build_adc_controls() (jsc#SLE-16518).
- ALSA: hda - Show the fatal CORB/RIRB error more clearly
  (jsc#SLE-16518).
- ALSA: echoaudio: Replace kmalloc + memcpy with kmemdup
  (jsc#SLE-16518).
- ALSA: line6: sizeof (byte) is always 1, use that fact
  (jsc#SLE-16518).
- ALSA: firewire-motu: more code refactoring for MOTU data block
  processing layer (jsc#SLE-16518).
- ALSA: firewire-lib: process payload of isoc context according
  to packet descriptors (jsc#SLE-16518).
- ALSA: fireface: code refactoring for FF data block processing
  layer (jsc#SLE-16518).
- ALSA: firewire-motu: code refactoring for MOTU data block
  processing layer (jsc#SLE-16518).
- ALSA: firewire-tascam: code refactoring for TASCAM data block
  processing layer (jsc#SLE-16518).
- ALSA: firewire-digi00x: code refactoring for DOT data block
  processing layer (jsc#SLE-16518).
- ALSA: firewire-lib: code refactoring for AM824 data block
  processing layer (jsc#SLE-16518).
- ALSA: firewire-lib: pass packet descriptor to data block
  processing layer (jsc#SLE-16518).
- ALSA: firewire-lib: code refactoring to process context payloads
  (jsc#SLE-16518).
- ALSA: firewire-lib: code refactoring to process PCM substream
  (jsc#SLE-16518).
- ALSA: firewire-lib: use packet descriptor for IR context
  (jsc#SLE-16518).
- ALSA: firewire-lib: use packet descriptor for IT context
  (jsc#SLE-16518).
- ALSA: firewire-lib: add list of packet descriptor
  (jsc#SLE-16518).
- ALSA: firewire-lib: pass no syt information to data block
  processing layer (jsc#SLE-16518).
- ALSA: firewire-lib: add syt_override member for some protocols
  (jsc#SLE-16518).
- ALSA: firewire-lib: operate data block counter in top level
  of processing for IR context (jsc#SLE-16518).
- ALSA: firewire-lib: operate data block counter in top level
  of processing for IT context (jsc#SLE-16518).
- ALSA: firewire-lib: pass data block counter to data block
  processing layer (jsc#SLE-16518).
- ALSA: firewire-lib: pass data block count as an argument to
  tracepoints event (jsc#SLE-16518).
- ALSA: firewire-lib: obsolete ctx_data.tx.first_dbc with
  CIP_UNALIGHED_DBC flag (jsc#SLE-16518).
- ALSA: hda/hdmi - Allow audio component for AMD/ATI and Nvidia
  HDMI (jsc#SLE-16518).
- ALSA: hda/hdmi - Don't report spurious jack state changes
  (jsc#SLE-16518).
- ALSA: hda: Flush interrupts on disabling (jsc#SLE-16518).
- ALSA: firewire-tascam: check intermediate state of clock status
  and retry (jsc#SLE-16518).
- ALSA: firewire-tascam: handle error code when getting current
  source of clock (jsc#SLE-16518).
- commit ad8723b
* Fri Sep 25 2020 tbogendoerfer@suse.de
- sch_cake: Take advantage of skb->hash where appropriate
  (bsc#1176447).
- Refresh
  patches.suse/sched-consistently-handle-layer3-header-accesses-in-.patch.
- commit 0a71f1a
* Fri Sep 25 2020 tbogendoerfer@suse.de
- bnxt_en: Allocate TQM ring context memory according to fw
  specification (jsc#SLE-15075).
- Refresh
  patches.suse/bnxt_en-Improve-TQM-ring-context-memory-sizing-formu.patch.
- commit 4820b20
* Fri Sep 25 2020 tbogendoerfer@suse.de
- netlink: remove type-unsafe validation_data pointer
  (bsc#1176447).
- Refresh patches.suse/netlink-remove-NLA_EXACT_LEN_WARN.patch.
- commit dd52c7a
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net/mlx5: Remove extra indirection while storing QPN
  (jsc#SLE-15172).
- Refresh
  patches.suse/net-mlx5-DR-Fix-freeing-in-dr_create_rc_qp.patch.
- commit 19e5277
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net/mlx5: Remove empty QP and CQ events handlers
  (jsc#SLE-15172).
- Refresh
  patches.suse/net-mlx5-DR-Fix-freeing-in-dr_create_rc_qp.patch.
- commit e65cb1d
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net/mlx5: Open-code create and destroy QP calls (jsc#SLE-15172).
- Refresh
  patches.suse/net-mlx5-DR-Fix-freeing-in-dr_create_rc_qp.patch.
- commit e06665e
* Fri Sep 25 2020 tbogendoerfer@suse.de
- mlxsw: spectrum_flower: Do not stop at FLOW_ACTION_PRIORITY
  (bsc#1176774).
- Refresh
  patches.suse/mlxsw-spectrum_flower-Do-not-stop-at-FLOW_ACTION_VLA.patch.
- commit e8f522e
* Fri Sep 25 2020 tbogendoerfer@suse.de
- RDMA/cm: Simplify establishing a listen cm_id (jsc#SLE-15176).
- Refresh
  patches.suse/RDMA-cm-Fix-an-error-check-in-cm_alloc_id_priv.patch.
- commit 9134185
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net: sched: expose HW stats types per action used by drivers
  (jsc#SLE-15172).
- Refresh
  patches.suse/net-mlx5e-Fix-stats-update-for-matchall-classifier.patch.
- commit 8d6956a
* Fri Sep 25 2020 tbogendoerfer@suse.de
- bnxt_en: Add fw.mgmt.api version to devlink info_get cb
  (jsc#SLE-15075).
- Refresh
  patches.suse/bnxt_en-Fix-fw.mgmt-and-fw.nsci-info-via-devlink-inf.patch.
- commit f50e160
* Fri Sep 25 2020 tbogendoerfer@suse.de
- mlxsw: spectrum_flower: Offload FLOW_ACTION_PRIORITY
  (bsc#1176774).
- Refresh
  patches.suse/mlxsw-spectrum_flower-Do-not-stop-at-FLOW_ACTION_VLA.patch.
- commit 4832ff9
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net/mlx5e: Introduce root ft concept for representors netdevs
  (jsc#SLE-15172).
- Refresh patches.suse/net-mlx5e-Fix-inner-tirs-handling.patch.
- commit de0accd
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net/mlx5e: Fix configuration of XPS cpumasks and netdev queues
  in corner cases (jsc#SLE-15172).
- Refresh
  patches.suse/net-mlx5e-Fix-CPU-mapping-after-function-reload-to-a.patch.
- commit da0810c
* Fri Sep 25 2020 tbogendoerfer@suse.de
- devlink: extend devlink_trap_report() to accept cookie and pass
  (bsc#1176774).
- Refresh
  patches.suse/devlink-Add-API-to-register-packet-trap-groups.patch.
- Refresh
  patches.suse/devlink-track-snapshot-id-usage-count-using-an-xarra.patch.
- commit 014cf19
* Fri Sep 25 2020 jroedel@suse.de
- PCI: Add DMA alias quirk for PLX PEX NTB (bsc#1175713).
- commit e238951
* Fri Sep 25 2020 tbogendoerfer@suse.de
- bitmap: Introduce bitmap_cut(): cut bits and shift remaining
  (bsc#1176447).
- Refresh
  patches.suse/include-bitmap.h-add-missing-parameter-in-docs.patch.
- commit 55af036
* Fri Sep 25 2020 tbogendoerfer@suse.de
- IB: Allow calls to ib_umem_get from kernel ULPs (jsc#SLE-15176).
- Refresh
  patches.suse/RDMA-bnxt_re-use-ibdev-based-message-printing-functi.patch.
- commit 40f08fc
* Fri Sep 25 2020 tbogendoerfer@suse.de
- mlxsw: spectrum_router: Start using new IPv4 route notifications
  (bsc#1176774).
- Refresh
  patches.suse/mlxsw-spectrum_router-Make-route-creation-and-destru.patch.
- commit 304ea2e
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net: phylink: split link_an_mode configured and current settings
  (bsc#1176447).
- Refresh
  patches.suse/net-phylink-add-support-for-polling-MAC-PCS.patch.
- commit eac529e
* Fri Sep 25 2020 tbogendoerfer@suse.de
- RDMA/hfi1: Use mmu_interval_notifier_insert for user_exp_rcv
  (jsc#SLE-15176).
- Refresh
  patches.suse/IB-hfi1-Acquire-lock-to-release-TID-entries-when-use.patch.
- Refresh
  patches.suse/IB-hfi1-Close-window-for-pq-and-request-coliding.patch.
- commit 40e9871
* Fri Sep 25 2020 tbogendoerfer@suse.de
- RDMA/odp: Use mmu_interval_notifier_insert() (jsc#SLE-15176).
- Refresh
  patches.suse/IB-core-Fix-ODP-with-IB_ACCESS_HUGETLB-handling.patch.
- Refresh
  patches.suse/IB-core-Fix-build-failure-without-hugepages.patch.
- Refresh
  patches.suse/IB-mlx5-Unify-ODP-MR-code-paths-to-allow-extra-flexi.patch.
- Refresh
  patches.suse/RDMA-mlx5-Fix-handling-of-IOVA-user_va-in-ODP-paths.patch.
- Refresh
  patches.suse/RDMA-odp-Ensure-the-mm-is-still-alive-before-creatin.patch.
- commit f163861
* Fri Sep 25 2020 tbogendoerfer@suse.de
- IB/umem: remove the dmasync argument to ib_umem_get
  (jsc#SLE-15176).
- Refresh
  patches.suse/RDMA-bnxt_re-use-ibdev-based-message-printing-functi.patch.
- Refresh
  patches.suse/RDMA-hns-Redefine-interfaces-used-in-creating-cq.patch.
- Refresh
  patches.suse/RDMA-hns-Redefine-the-member-of-hns_roce_cq-struct.patch.
- commit 41d329c
* Fri Sep 25 2020 jroedel@suse.de
- PCI: Add nr_devfns parameter to pci_add_dma_alias()
  (bsc#1175713).
- Refresh
  patches.suse/iommu-amd-move-amd-iommu-driver-into-subdirectory.
- commit bb6a72d
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net/mlx5: TC: Offload flow table rules (jsc#SLE-15172).
- Refresh
  patches.suse/net-mlx5e-Avoid-duplicating-rule-destinations.patch.
- commit 68ebf6a
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net: phy: extract link partner advertisement reading
  (bsc#1176447).
- Refresh
  patches.suse/net-phy-Fix-link-partner-information-disappear-issue.patch.
- commit 50d9bc7
* Fri Sep 25 2020 tbogendoerfer@suse.de
- drm/amdkfd: use mmu_notifier_put (jsc#SLE-15176).
- Refresh
  patches.suse/drm-iommu-change-type-of-pasid-to-u32.patch.
- commit 198bc5d
* Fri Sep 25 2020 tbogendoerfer@suse.de
- hmm: use mmu_notifier_get/put for 'struct hmm' (jsc#SLE-15176).
- Refresh
  patches.suse/mm-add-a-pasid-member-to-struct-mm_struct.patch.
- commit 94ccbf0
* Fri Sep 25 2020 tbogendoerfer@suse.de
- mm/hmm: remove the page_shift member from struct hmm_range
  (jsc#SLE-15176).
- Refresh patches.suse/mm-hmm-hmm_range_fault-infinite-loop.patch.
- commit 050018d
* Fri Sep 25 2020 tbogendoerfer@suse.de
- mm/hmm: replace the block argument to hmm_range_fault with a
  flags value (jsc#SLE-15176).
- Refresh
  patches.suse/0003-drm-amdgpu-Call-find_vma-under-mmap_sem.patch.
- Refresh
  patches.suse/mm-hmm-hmm_range_fault-null-pointer-bug.patch.
- commit 2732f5a
* Fri Sep 25 2020 tbogendoerfer@suse.de
- mm/hmm: comment on VM_FAULT_RETRY semantics in handle_mm_fault
  (jsc#SLE-15176).
- Refresh
  patches.suse/mm-hmm-hmm_range_fault-null-pointer-bug.patch.
- commit c838313
* Fri Sep 25 2020 tbogendoerfer@suse.de
- netfilter: remove CONFIG_NETFILTER checks from headers
  (bsc#1176447).
- Refresh
  patches.suse/netfilter-iptables-Split-ipt_unregister_table-into-p.patch.
- commit 0e4af9d
* Fri Sep 25 2020 tbogendoerfer@suse.de
- netfilter: update include directives (bsc#1176447).
- Refresh
  patches.suse/Revert-netfilter-conntrack-remove-helper-hook-again.patch.
- commit bfe3d73
* Fri Sep 25 2020 tbogendoerfer@suse.de
- netfilter: nf_tables_offload: refactor the
  nft_flow_offload_chain function (bsc#1176447).
- Refresh
  patches.suse/netfilter-nf_tables_offload-skip-EBUSY-on-chain-upda.patch.
- commit 196e120
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net: phy: dp83867: Add SGMII mode type switching (bsc#1176447).
- Refresh
  patches.suse/net-phy-dp83867-enable-robust-auto-mdix.patch.
- commit cec51f9
* Fri Sep 25 2020 tbogendoerfer@suse.de
- netfilter: add missing IS_ENABLED(CONFIG_NETFILTER) checks to
  some header-files (bsc#1176447).
- Refresh
  patches.suse/netfilter-iptables-Split-ipt_unregister_table-into-p.patch.
- commit 20458b6
* Fri Sep 25 2020 tbogendoerfer@suse.de
- netfilter: inline four headers files into another one
  (bsc#1176447).
- Refresh
  patches.suse/netfilter-ipset-use-bitmap-infrastructure-completely.patch.
- commit c09d116
* Fri Sep 25 2020 tbogendoerfer@suse.de
- net: phy: prepare phylib to deal with PHY's extending Clause 22
  (bsc#1176447).
- Refresh
  patches.suse/net-phy-Fix-link-partner-information-disappear-issue.patch.
- Refresh
  patches.suse/net-phy-add-support-for-clause-37-auto-negotiation.patch.
- commit 36b1359
* Fri Sep 25 2020 jroedel@suse.de
- Refresh
  patches.suse/iommu-vt-d-do-deferred-attachment-in-iommu_need_mapping.
- Refresh
  patches.suse/iommu-vt-d-move-intel-iommu-driver-into-subdirectory.
- Refresh patches.suse/iommu-vt-d-remove-deferred_attach_domain.
- commit 13c1a3c
* Fri Sep 25 2020 msuchanek@suse.de
- Enable kernel lockdown on ppc64le (bsc#1176918 ltc#186474 jsc#SLE-13644).
- commit 9074b84
* Fri Sep 25 2020 jroedel@suse.de
- Refresh
  patches.suse/iommu-vt-d-move-intel-iommu-driver-into-subdirectory.
- Refresh patches.suse/iommu-vt-d-refactor-find_domain-helper.
- commit 4ca331e
* Fri Sep 25 2020 yousaf.kaukab@suse.com
- lib/test_bitmap: correct test data offsets for 32-bit
  (jsc#SLE-15847).
- gpio: mockup: Fix usage of new GPIO_LINE_DIRECTION
  (jsc#SLE-15847).
- commit 24a7dac
* Fri Sep 25 2020 msuchanek@suse.de
- scsi: ibmvfc: Avoid link down on FS9100 canister reboot
  (bsc#1176962 ltc#188304).
- scsi: ibmvfc: Use compiler attribute defines instead of
  __attribute__() (bsc#1176962 ltc#188304).
- commit 2f6bf7f
* Fri Sep 25 2020 msuchanek@suse.de
- powerpc: lock down kernel in secure boot mode (bsc#1176918
  ltc#186474 jsc#SLE-13644).
- commit d485a62
* Fri Sep 25 2020 tiwai@suse.de
- Preliminary drop of the whole sound patches for clean backports for SP3
- commit 0cb4915
* Fri Sep 25 2020 yousaf.kaukab@suse.com
- gpio: of: Fix bogus reference to gpiod_get_count() (jsc#SLE-15847).
- gpio: of: don't warn if ignored GPIO flag matches the behavior (jsc#SLE-15847).
- gpio: fix kernel-doc for of_gpio_need_valid_mask() (jsc#SLE-15847).
- gpio: devres: Switch to EXPORT_SYMBOL_GPL() (jsc#SLE-15847).
- gpio: of: Switch to EXPORT_SYMBOL_GPL() (jsc#SLE-15847).
- gpio: of: Make of_gpio_simple_xlate() private (jsc#SLE-15847).
- gpio: of: Make of_get_named_gpiod_flags() private (jsc#SLE-15847).
- gpio: of: Fix hard-assigned valid_mask for OF case (jsc#SLE-15847).
- gpiolib: of: Reshuffle contents of consumer.h for new library layout (jsc#SLE-15847).
- commit f494e82
* Fri Sep 25 2020 tiwai@suse.de
- Bluetooth: Sort list of LE features constants (jsc#SLE-13430).
- Refresh
  patches.suse/Bluetooth-Enable-LE-Enhanced-Connection-Complete-eve.patch.
- commit 3de2003
* Fri Sep 25 2020 tiwai@suse.de
- Bluetooth: L2CAP: Replace zero-length array with flexible-array
  (jsc#SLE-13430).
- Bluetooth: Clear HCI_LL_RPA_RESOLUTION flag on reset
  (jsc#SLE-13430).
- Bluetooth: Add HCI device identifier for VIRTIO devices
  (jsc#SLE-13430).
- Bluetooth: Fixing a few comment typos in the quirk definitions
  (jsc#SLE-13430).
- commit b512bcb
* Fri Sep 25 2020 tiwai@suse.de
- mac80211: fix memory overlap due to variable length param
  (jsc#SLE-13430).
- commit 114984a
* Thu Sep 24 2020 tiwai@suse.de
- Revert "ALSA: usb-audio: Disable Lenovo P620 Rear line-in
  volume control" (git-fixes).
- Revert "ALSA: hda - Fix silent audio output and corrupted
  input on MSI X570-A PRO" (git-fixes).
- ALSA: usb-audio: Add delay quirk for H570e USB headsets
  (git-fixes).
- ALSA: hda/realtek: Enable front panel headset LED on Lenovo
  ThinkStation P520 (git-fixes).
- ALSA: hda/realtek - Couldn't detect Mic if booting with headset
  plugged (git-fixes).
- ALSA: asihpi: fix iounmap in error handler (git-fixes).
- commit 392c032
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: remove a BUG_ON() from merge_reloc_roots() (bsc#1176019).
- commit 070656a
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: hold a ref on the root->reloc_root (bsc#1176019).
- commit cfada4f
* Thu Sep 24 2020 msuchanek@suse.de
- blacklist.conf: Add duplicate fix.
- commit 4b6ed84
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: clear DEAD_RELOC_TREE before dropping the reloc root
  (bsc#1176019).
- commit 3414f3d
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: Remove block_rsv parameter from btrfs_drop_snapshot
  (bsc#1176019).
- commit 0eab798
* Thu Sep 24 2020 msuchanek@suse.de
- powerpc/smp: Implement cpu_to_coregroup_id (jsc#SLE-13617
  bsc#1176912 ltc#186322).
- powerpc/smp: Create coregroup domain (jsc#SLE-13617 bsc#1176912
  ltc#186322).
- powerpc/smp: Allocate cpumask only after searching thread group
  (jsc#SLE-13617 bsc#1176912 ltc#186322).
- powerpc/numa: Detect support for coregroup (jsc#SLE-13617
  bsc#1176912 ltc#186322).
- powerpc/smp: Optimize start_secondary (jsc#SLE-13617 bsc#1176912
  ltc#186322).
- powerpc/smp: Dont assume l2-cache to be superset of sibling
  (jsc#SLE-13617 bsc#1176912 ltc#186322).
- powerpc/smp: Move topology fixups into a new function
  (jsc#SLE-13617 bsc#1176912 ltc#186322).
- powerpc/smp: Move powerpc_topology above (jsc#SLE-13617
  bsc#1176912 ltc#186322).
- powerpc/smp: Merge Power9 topology with Power topology
  (jsc#SLE-13617 bsc#1176912 ltc#186322).
- powerpc/smp: Fix a warning under !NEED_MULTIPLE_NODES
  (jsc#SLE-13617 bsc#1176912 ltc#186322).
- powerpc/numa: Restrict possible nodes based on platform
  (jsc#SLE-13617 bsc#1176912 ltc#186322).
- powerpc/numa: Limit possible nodes to within num_possible_nodes
  (jsc#SLE-13617 bsc#1176912 ltc#186322).
- powerpc: Fix misleading small cores print (jsc#SLE-13617
  bsc#1176912 ltc#186322).
- commit 932e818
* Thu Sep 24 2020 tiwai@suse.de
- Add cherry-picked commit IDs to ignore
  Refreshed:
  patches.suse/mt76-mt7615-fix-hw-queue-mapping.patch
  patches.suse/mt76-overwrite-qid-for-non-bufferable-mgmt-frames.patch
- commit 69695d4
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: free the reloc_control in a consistent way (bsc#1176019).
- commit 7857718
* Thu Sep 24 2020 yousaf.kaukab@suse.com
- gpio: pca953x: Request IRQ after all initialisation done (jsc#SLE-15847).
- gpio: pca953x: Use irqchip template (jsc#SLE-15847).
- gpio: pca953x: Add support for the PCAL9535 (jsc#SLE-15847).
- gpio: pca953x: Fix direction setting when configure an IRQ (jsc#SLE-15847).
- gpio: pca953x: Synchronize interrupt handler properly (jsc#SLE-15847).
- gpio: pca953x: Drop unneeded ACPI_PTR() (jsc#SLE-15847).
- gpio: pca953x: drop unused parameters of pca953x_recalc_addr() (jsc#SLE-15847).
- gpio: pca953x: Rewrite ->get_multiple() function (jsc#SLE-15847).
- gpio: gpio-pca953x, Add get_multiple function (jsc#SLE-15847).
- gpiolib: of: improve gpiolib-of support of pull up/down on expanders (jsc#SLE-15847).
- gpio: pca953x: Remove redundant forward declaration (jsc#SLE-15847).
- gpio: pca953x: Don't hardcode irq trigger type (jsc#SLE-15847).
- gpio: pca953x: Switch to bitops in IRQ callbacks (jsc#SLE-15847).
- gpio: pca953x: tighten up indentation (jsc#SLE-15847).
- gpio: pca953x: convert to use bitmap API (jsc#SLE-15847).
- gpio: pca953x: use input from regs structure in pca953x_irq_pending() (jsc#SLE-15847).
- gpio: pca953x: remove redundant variable and check in IRQ handler (jsc#SLE-15847).
- lib/bitmap: introduce bitmap_replace() helper (jsc#SLE-15847).
- lib/test_bitmap: fix comment about this file (jsc#SLE-15847).
- lib/test_bitmap: move exp1 and exp2 upper for others to use (jsc#SLE-15847).
- lib/test_bitmap: rename exp to exp1 to avoid ambiguous name (jsc#SLE-15847).
- lib/test_bitmap: name EXP_BYTES properly (jsc#SLE-15847).
- lib/test_bitmap: undefine macros after use (jsc#SLE-15847).
- lib/test_bitmap: force argument of bitmap_parselist_user() to proper address space (jsc#SLE-15847).
- gpio: pca953x: utilize the for_each_set_clump8 macro (jsc#SLE-15847).
- lib/test_bitmap.c: add for_each_set_clump8 test cases (jsc#SLE-15847).
- bitops: introduce the for_each_set_clump8 macro (jsc#SLE-15847).
- gpio: Use new GPIO_LINE_DIRECTION (jsc#SLE-15847).
- gpio: Add definition for GPIO direction (jsc#SLE-15847).
- gpio: of: Break out OF-only code (jsc#SLE-15847).
- commit ce131cf
* Thu Sep 24 2020 msuchanek@suse.de
- cpuidle: pseries: Fix CEDE latency conversion from tb to us
  (jsc#SLE-13614 bsc#1176914 ltc#186394).
- cpuidle: pseries: Fixup exit latency for CEDE(0) (jsc#SLE-13614
  bsc#1176914 ltc#186394).
- cpuidle: pseries: Add function to parse extended CEDE records
  (jsc#SLE-13614 bsc#1176914 ltc#186394).
- cpuidle: pseries: Set the latency-hint before entering CEDE
  (jsc#SLE-13614 bsc#1176914 ltc#186394).
- cpuidle/pseries: Make symbol 'pseries_idle_driver' static
  (jsc#SLE-13614 bsc#1176914 ltc#186394).
- commit 7de6282
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: fix setting last_trans for reloc roots (bsc#1176019).
- commit fe4b564
* Thu Sep 24 2020 tbogendoerfer@suse.de
- net/sched: fix a couple of splats in the error path of
  tfc_gate_init() (bsc#1176447).
- net/mlx5e: Make mlx5e_dcbnl_ops static (jsc#SLE-15172).
- net/mlx5e: en_tc: Fix cast to restricted __be32 warning
  (jsc#SLE-15172).
- net/mlx5e: en_tc: Fix incorrect type in initializer warnings
  (jsc#SLE-15172).
- net/mlx5: Accel: fpga tls fix cast to __be64 and incorrect
  argument types (jsc#SLE-15172).
- net/mlx5: cmd: Fix memset with byte count warning
  (jsc#SLE-15172).
- net/mlx5: DR: Fix incorrect type in return expression
  (jsc#SLE-15172).
- net/mlx5: DR: Fix cast to restricted __be32 (jsc#SLE-15172).
- net/mlx5: DR: Fix incorrect type in argument (jsc#SLE-15172).
- net/mlx5e: Use generic API to build MPLS label (jsc#SLE-15172).
- net: Make mpls_entry_encode() available for generic users
  (jsc#SLE-15172).
- net/mlx5: reduce stack usage in qp_read_field (jsc#SLE-15172).
- net/mlx5e: Don't use err uninitialized in mlx5e_attach_decap
  (jsc#SLE-15172).
- net/mlx5: Kconfig: Fix spelling typo (jsc#SLE-15172).
- mlx5: fix xdp data_meta setup in mlx5e_fill_xdp_buff
  (jsc#SLE-15172).
- net/mlx5: Add ability to read and write ECE options
  (jsc#SLE-15172).
- net/mlx5: Add support for RDMA TX FT headers modifying
  (jsc#SLE-15172).
- net/mlx5: Move iseg access helper routines close to mlx5_core
  driver (jsc#SLE-15172).
- net/mlx5: Cleanup mlx5_ifc_fte_match_set_misc2_bits
  (jsc#SLE-15172).
- net/mlx5: Add support in forward to namespace (jsc#SLE-15172).
- {IB/net}/mlx5: Simplify don't trap code (jsc#SLE-15172).
- net/mlx5: Replace zero-length array with flexible-array
  (jsc#SLE-15172).
- net: ethtool: cabletest: Make ethnl_act_cable_test_tdr_cfg
  static (bsc#1176447).
- nfp: flower: fix incorrect flag assignment (bsc#1176447).
- net: phy: marvell: unlock after phy_select_page() failure
  (bsc#1176447).
- net/mlx5: DR, Split RX and TX lock for parallel insertion
  (jsc#SLE-15172).
- net/mlx5: DR, Add a spinlock to protect the send ring
  (jsc#SLE-15172).
- net/mlx5e: Optimize performance for IPv4/IPv6 ethertype
  (jsc#SLE-15172).
- net/mlx5e: Helper function to set ethertype (jsc#SLE-15172).
- net/mlx5: Add missing mutex destroy (jsc#SLE-15172).
- net/mlx5e: Use change upper event to setup representors'
  bond_metadata (jsc#SLE-15172).
- net/mlx5e: Slave representors sharing unique metadata for match
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Alloc and free unique metadata for match
  (jsc#SLE-15172).
- net/mlx5e: Add bond_metadata and its slave entries
  (jsc#SLE-15172).
- net/mlx5e: Offload flow rules to active lower representor
  (jsc#SLE-15172).
- net/mlx5e: Support tc block sharing for representors
  (jsc#SLE-15172).
- net/mlx5e: Use netdev events to set/del egress acl
  forward-to-vport rule (jsc#SLE-15172).
- net/mlx5: E-Switch, Introduce APIs to enable egress acl
  forward-to-vport rule (jsc#SLE-15172).
- net/mlx5: E-Switch, Refactor eswitch ingress acl codes
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Refactor eswitch egress acl codes
  (jsc#SLE-15172).
- net_sched: get rid of unnecessary dev_qdisc_reset()
  (bsc#1176447).
- net_sched: avoid resetting active qdisc for multiple times
  (bsc#1176447).
- net_sched: add a tracepoint for qdisc creation (bsc#1176447).
- net_sched: add tracepoints for qdisc_reset() and qdisc_destroy()
  (bsc#1176447).
- net_sched: use qdisc_reset() in qdisc_destroy() (bsc#1176447).
- mlxsw: spectrum_router: remove redundant initialization of
  pointer br_dev (bsc#1176774).
- net: phy: marvell: Configure TDR pulse based on measurement
  length (bsc#1176447).
- net : phy: marvell: Speedup TDR data retrieval by only changing
  page once (bsc#1176447).
- net: ethtool: Allow PHY cable test TDR data to configured
  (bsc#1176447).
- net: phy: marvell: Add support for amplitude graph
  (bsc#1176447).
- net: ethtool: Add helpers for cable test TDR data (bsc#1176447).
- net: ethtool: Add generic parts of cable test TDR (bsc#1176447).
- net: ethtool: Add attributes for cable test TDR data
  (bsc#1176447).
- mlxsw: spectrum_router: Allow programming link-local prefix
  routes (bsc#1176774).
- mlxsw: spectrum: Add packet traps for BFD packets (bsc#1176774).
- mlxsw: spectrum: Treat IPv6 link-local SIP as an exception
  (bsc#1176774).
- mlxsw: spectrum: Share one group for all locally delivered
  packets (bsc#1176774).
- mlxsw: reg: Move all trap groups under the same enum
  (bsc#1176774).
- mlxsw: spectrum_trap: Do not hard code "thin" policer identifier
  (bsc#1176774).
- mlxsw: switchx2: Move SwitchX-2 trap groups out of main enum
  (bsc#1176774).
- mlxsw: spectrum: Reduce priority of locally delivered packets
  (bsc#1176774).
- mlxsw: spectrum: Use same trap group for local routes and
  link-local destination (bsc#1176774).
- mlxsw: spectrum: Use separate trap group for FID miss
  (bsc#1176774).
- mlxsw: spectrum: Use same trap group for various IPv6 packets
  (bsc#1176774).
- mlxsw: spectrum: Rename IPv6 ND trap group (bsc#1176774).
- mlxsw: spectrum: Use same switch case for identical groups
  (bsc#1176774).
- mlxsw: spectrum: Use dedicated trap group for ACL trap
  (bsc#1176774).
- cls_flower: Support filtering on multiple MPLS Label Stack
  Entries (bsc#1176447).
- flow_dissector: Parse multiple MPLS Label Stack Entries
  (bsc#1176447).
- mlxsw: spectrum: Fix spelling mistake in trap's name
  (bsc#1176774).
- mlxsw: spectrum: Use dedicated trap group for sampled packets
  (bsc#1176774).
- mlxsw: spectrum: Use same trap group for IPv6 ND and ARP packets
  (bsc#1176774).
- mlxsw: spectrum: Rename ARP trap group (bsc#1176774).
- mlxsw: spectrum_trap: Remove unnecessary field (bsc#1176774).
- mlxsw: spectrum: Align TC and trap priority (bsc#1176774).
- mlxsw: spectrum_buffers: Assign non-zero quotas to TC 0 of
  the CPU port (bsc#1176774).
- mlxsw: spectrum: Change default rate and priority of DHCP
  packets (bsc#1176774).
- mlxsw: spectrum: Trap IPv4 DHCP packets in router (bsc#1176774).
- mlxsw: spectrum: Use same trap group for MLD and IGMP packets
  (bsc#1176774).
- mlxsw: spectrum: Rename IGMP trap group (bsc#1176774).
- net/mlx5e: Support pedit on mpls over UDP decap (jsc#SLE-15172).
- net/mlx5e: Add support for hw decapsulation of MPLS over UDP
  (jsc#SLE-15172).
- net/mlx5e: Allow to match on mpls parameters (jsc#SLE-15172).
- net/mlx5e: Add support for hw encapsulation of MPLS over UDP
  (jsc#SLE-15172).
- net: Add netif_is_bareudp() API to identify bareudp devices
  (jsc#SLE-15172).
- net/mlx5e: Move TC-specific code from en_main.c to en_tc.c
  (jsc#SLE-15172).
- net/mlx5e: Extract neigh-specific code from en_rep.c to
  rep/neigh.c (jsc#SLE-15172).
- net/mlx5e: Extract TC-specific code from en_rep.c to rep/tc.c
  (jsc#SLE-15172).
- net/mlx5e: Use IS_ERR() to check and simplify code
  (jsc#SLE-15172).
- mlx5, xsk: Migrate to new MEM_TYPE_XSK_BUFF_POOL
  (jsc#SLE-15172).
- net: flow_offload: simplify hw stats check handling
  (bsc#1176774).
- ethtool: provide UAPI for PHY Signal Quality Index (SQI)
  (bsc#1176447).
- nfp: flower: inform firmware of flower features (bsc#1176447).
- nfp: flower: renaming of feature bits (bsc#1176447).
- net: phy: simplify phy_link_change arguments (bsc#1176447).
- selftests: mlxsw: Do not hard code trap group name
  (bsc#1176774).
- selftests: devlink_lib: Remove double blank line (bsc#1176774).
- mlxsw: spectrum_trap: Store all trap data in one array
  (bsc#1176774).
- mlxsw: spectrum_trap: Store all trap group data in one array
  (bsc#1176774).
- mlxsw: spectrum_trap: Store all trap policer data in one array
  (bsc#1176774).
- mlxsw: spectrum_trap: Move struct definition out of header file
  (bsc#1176774).
- nfp: don't check lack of RX/TX channels (bsc#1176447).
- net/mlx5e: Take DCBNL-related definitions into dedicated files
  (jsc#SLE-15172).
- net/mlx5e: Calculate SQ stop room in a robust way
  (jsc#SLE-15172).
- net/mlx5e: IPoIB, Drop multicast packets that this interface
  sent (jsc#SLE-15172).
- net/mlx5e: IPoIB, Enable loopback packets for IPoIB interfaces
  (jsc#SLE-15172).
- net/mlx5e: CT: Fix offload with CT action after CT NAT action
  (jsc#SLE-15172).
- net/mlx5: Move internal timer read function to clock library
  (jsc#SLE-15172).
- net/mlx5: Wait for inactive autogroups (jsc#SLE-15172).
- net/mlx5: Drain wq first during PCI device removal
  (jsc#SLE-15172).
- net/mlx5: Have single error unwinding path (jsc#SLE-15172).
- net/mlx5: Fix a bug of releasing wrong chunks on > 4K page
  size systems (jsc#SLE-15172).
- net/mlx5: Dedicate fw page to the requesting function
  (jsc#SLE-15172).
- mlx5: Rx queue setup time determine frame_sz for XDP
  (jsc#SLE-15172).
- nfp: Add XDP frame size to netronome driver (bsc#1176447).
- bnxt: Add XDP frame size to driver (jsc#SLE-15075).
- net: sched: cls_flower: implement terse dump support
  (bsc#1176447).
- net: sched: implement terse dump support in act (bsc#1176447).
- net: sched: introduce terse dump flag (bsc#1176447).
- devlink: refactor end checks in
  devlink_nl_cmd_region_read_dumpit (bsc#1176447).
- net: phy: Send notifier when starting the cable test
  (bsc#1176447).
- net: phy: Put interface into oper testing during cable test
  (bsc#1176447).
- net: phy: marvell: Add cable test support (bsc#1176447).
- net: ethtool: Add helpers for reporting test results
  (bsc#1176447).
- net: ethtool: Add infrastructure for reporting cable test
  results (bsc#1176447).
- net: ethtool: Make helpers public (bsc#1176447).
- net: ethtool: Add attributes for cable test reports
  (bsc#1176447).
- net: ethtool: netlink: Add support for triggering a cable test
  (bsc#1176447).
- net: phy: Add support for polling cable test (bsc#1176447).
- net: phy: Add cable test support to state machine (bsc#1176447).
- selftests: mlxsw: tc_restrictions: add couple of test for the
  correct matchall-flower ordering (bsc#1176774).
- selftests: mlxsw: tc_restrictions: add test to check sample
  action restrictions (bsc#1176774).
- selftests: mlxsw: rename tc_flower_restrictions.sh to
  tc_restrictions.sh (bsc#1176774).
- mlxsw: spectrum_flower: Forbid to insert flower rules in
  collision with matchall rules (bsc#1176774).
- mlxsw: spectrum_matchall: Forbid to insert matchall rules in
  collision with flower rules (bsc#1176774).
- mlxsw: spectrum_matchall: Expose a function to get min and
  max rule priority (bsc#1176774).
- mlxsw: spectrum_matchall: Put matchall list into substruct of
  flow struct (bsc#1176774).
- mlxsw: spectrum_flower: Expose a function to get min and max
  rule priority (bsc#1176774).
- mlxsw: spectrum_matchall: Restrict sample action to be allowed
  only on ingress (bsc#1176774).
- net/mlx5e: Enhance ICOSQ WQE info fields (jsc#SLE-15172).
- net/mlx5: Accel, Remove unnecessary header include
  (jsc#SLE-15172).
- net/mlx5e: Use struct assignment for WQE info updates
  (jsc#SLE-15172).
- net/mlx5e: Take TX WQE info structures out of general EN header
  (jsc#SLE-15172).
- net/mlx5e: kTLS, Do not fill edge for the DUMP WQEs in TX flow
  (jsc#SLE-15172).
- net/mlx5e: kTLS, Fill work queue edge separately in TX flow
  (jsc#SLE-15172).
- net/mlx5e: Split TX acceleration offloads into two phases
  (jsc#SLE-15172).
- net/mlx5e: Update UDP fields of the SKB for GSO first
  (jsc#SLE-15172).
- net/mlx5e: Make TLS offload independent of wqe and pi
  (jsc#SLE-15172).
- net/mlx5e: Pass only eseg to IPSEC offload (jsc#SLE-15172).
- net/mlx5e: Return void from mlx5e_sq_xmit and mlx5i_sq_xmit
  (jsc#SLE-15172).
- net/mlx5e: Unify checks of TLS offloads (jsc#SLE-15172).
- net/mlx5e: Return bool from TLS and IPSEC offloads
  (jsc#SLE-15172).
- net/mlx5: Add support to get lag physical port (jsc#SLE-15172).
- net/mlx5: Change lag mutex lock to spin lock (jsc#SLE-15172).
- ethtool: provide UAPI for PHY master/slave configuration
  (bsc#1176447).
- sch_choke: Remove classid from choke_skb_cb (bsc#1176447).
- net: sched: choke: Remove unused inline function
  choke_set_classid (bsc#1176447).
- net: bnxt: Remove Comparison to bool in bnxt_ethtool.c
  (jsc#SLE-15075).
- net: partially revert dynamic lockdep key changes (bsc#1176447).
- docs: devlink: clarify the scope of snapshot id (bsc#1176447).
- devlink: let kernel allocate region snapshot id (bsc#1176447).
- devlink: factor out building a snapshot notification
  (bsc#1176447).
- net_sched: sch_fq: add horizon attribute (bsc#1176447).
- net: sched: fallback to qdisc noqueue if default qdisc setup
  fail (bsc#1176447).
- bnxt_en: show only relevant ethtool stats for a TX or RX ring
  (jsc#SLE-15075).
- bnxt_en: Split HW ring statistics strings into RX and TX parts
  (jsc#SLE-15075).
- bnxt_en: Refactor the software ring counters (jsc#SLE-15075).
- bnxt_en: Add doorbell information to bnxt_en_dev struct
  (jsc#SLE-15075).
- bnxt_en: Add support for L2 doorbell size (jsc#SLE-15075).
- bnxt_en: Set the db_offset on 57500 chips for the RDMA MSIX
  entries (jsc#SLE-15075).
- bnxt_en: Define the doorbell offsets on 57500 chips
  (jsc#SLE-15075).
- bnxt_en: Improve kernel log messages related to ethtool reset
  (jsc#SLE-15075).
- bnxt_en: fix ethtool_reset_flags ABI violations (jsc#SLE-15075).
- bnxt_en: refactor ethtool firmware reset types (jsc#SLE-15075).
- bnxt_en: prepare to refactor ethtool reset types
  (jsc#SLE-15075).
- bnxt_en: Do not include ETH_FCS_LEN in the max packet length
  sent to fw (jsc#SLE-15075).
- bnxt_en: Update firmware spec. to 1.10.1.33 (jsc#SLE-15075).
- net_sched: sch_fq: perform a prefetch() earlier (bsc#1176447).
- net_sched: sch_fq: do not call fq_peek() twice per packet
  (bsc#1176447).
- net_sched: sch_fq: use bulk freeing in fq_gc() (bsc#1176447).
- net_sched: sch_fq: change fq_flow size/layout (bsc#1176447).
- net_sched: sch_fq: avoid touching f->next from fq_gc()
  (bsc#1176447).
- net: schedule: add action gate offloading (bsc#1176447).
- net/mlx5e: Unify reserving space for WQEs (jsc#SLE-15172).
- net/mlx5e: Rename ICOSQ WQE info struct and field
  (jsc#SLE-15172).
- net/mlx5e: Fetch WQE: reuse code and enforce typing
  (jsc#SLE-15172).
- net/mlx5e: XDP, Print the offending TX descriptor on error
  completion (jsc#SLE-15172).
- net/mlx5e: TX, Generalise code and usage of error CQE dump
  (jsc#SLE-15172).
- net/mlx5e: Use proper name field for the UMR key
  (jsc#SLE-15172).
- net/mlx5: Add support for release all pages event
  (jsc#SLE-15172).
- net/mlx5: Rate limit page not found error messages
  (jsc#SLE-15172).
- net/mlx5: Add helper function to release fw page
  (jsc#SLE-15172).
- net/mlx5: Remove unused field in EQ (jsc#SLE-15172).
- net/mlx5: CT: Remove unused variables (jsc#SLE-15172).
- net/mlx5e: CT: Avoid false warning about rule may be used
  uninitialized (jsc#SLE-15172).
- net/mlx5e: Remove unneeded semicolon (jsc#SLE-15172).
- net/mlx5e: Use helper API to get devlink port index for all
  port flavours (jsc#SLE-15172).
- net/mlx5: IPsec, Fix coverity issue (jsc#SLE-15172).
- net/mlx5: Add release all pages capability bit (jsc#SLE-15172).
- net/mlx5: Introduce TLS RX offload hardware bits
  (jsc#SLE-15172).
- net/mlx5: Add structure and defines for pci sync for fw update
  event (jsc#SLE-15172).
- net/mlx5: Add structure layout and defines for MFRL register
  (jsc#SLE-15172).
- net/mlx5: Refactor imm_inval_pkey field in cqe struct
  (jsc#SLE-15172).
- net/mlx5: Use aligned variable while allocating ICM memory
  (jsc#SLE-15172).
- net/mlx5: Introduce IPsec Connect-X offload hardware bits and
  structures (jsc#SLE-15172).
- net/mlx5: Add support for COPY steering action (jsc#SLE-15172).
- net/mlx5: Update transobj.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update SW steering new cmd interface (jsc#SLE-15172).
- net/mlx5: Update port.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update rl.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update uar.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update pd.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update pagealloc.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update mr.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update mcg.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update main.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update vxlan.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update mpfs.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update gid.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update lag.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update fw.c new cmd interface (jsc#SLE-15172).
- net/mlx5: Update fs_core new cmd interface (jsc#SLE-15172).
- net/mlx5: Update FPGA to new cmd interface (jsc#SLE-15172).
- net/mlx5: Update eswitch to new cmd interface (jsc#SLE-15172).
- net/mlx5: Update statistics to new cmd interface
  (jsc#SLE-15172).
- net/mlx5: Update eq.c to new cmd interface (jsc#SLE-15172).
- net/mlx5: Update ecpf.c to new cmd interface (jsc#SLE-15172).
- net/mlx5: Update debugfs.c to new cmd interface (jsc#SLE-15172).
- net/mlx5: Update cq.c to new cmd interface (jsc#SLE-15172).
- net/mlx5: Update vport.c to new cmd interface (jsc#SLE-15172).
- net/mlx5: Enable SW-defined RoCEv2 UDP source port
  (jsc#SLE-15172).
- net/mlx5: Refactor HCA capability set flow (jsc#SLE-15172).
- net/mlx5: Move QP logic to mlx5_ib (jsc#SLE-15172).
- RDMA/mlx5: Alphabetically sort build artifacts (jsc#SLE-15172).
- net/mlx5: Delete not-used cmd header (jsc#SLE-15172).
- net/mlx5: Remove Q counter low level helper APIs
  (jsc#SLE-15172).
- net/mlx5: Replace hand written QP context struct with automatic
  getters (jsc#SLE-15172).
- net/mlx5: Open-code modify QP in the IPoIB module
  (jsc#SLE-15172).
- net/mlx5: Open-code modify QP in the FPGA module
  (jsc#SLE-15172).
- net/mlx5: Open-code modify QP in steering module
  (jsc#SLE-15172).
- net/mlx5: Provide simplified command interfaces (jsc#SLE-15172).
- mlxsw: spectrum_span: Remove old SPAN API (bsc#1176774).
- mlxsw: spectrum_span: Use new analyzed ports list during speed /
  MTU change (bsc#1176774).
- mlxsw: spectrum_acl: Convert flower-based mirroring to new
  SPAN API (bsc#1176774).
- mlxsw: spectrum: Convert matchall-based mirroring to new SPAN
  API (bsc#1176774).
- mlxsw: spectrum_span: Add APIs to bind / unbind a SPAN agent
  (bsc#1176774).
- mlxsw: spectrum_span: Wrap buffer change in a function
  (bsc#1176774).
- mlxsw: spectrum_span: Rename function (bsc#1176774).
- mlxsw: spectrum_span: Add APIs to get / put an analyzed port
  (bsc#1176774).
- mlxsw: spectrum_span: Add APIs to get / put a SPAN agent
  (bsc#1176774).
- netfilter: nft_nat: add netmap support (bsc#1176447).
- netfilter: nft_nat: add helper function to set up NAT address
  and protocol (bsc#1176447).
- netfilter: nft_nat: set flags from initialization path
  (bsc#1176447).
- netfilter: nft_nat: return EOPNOTSUPP if type or flags are
  not supported (bsc#1176447).
- netfilter: nf_tables: allow up to 64 bytes in the set element
  data area (bsc#1176447).
- netfilter: nf_conntrack: add IPS_HW_OFFLOAD status bit
  (bsc#1176447).
- mlxsw: spectrum: Move flow offload binding into spectrum_flow.c
  (bsc#1176774).
- mlxsw: spectrum_matchall: Process matchall events from the
  same cb as flower (bsc#1176774).
- mlxsw: spectrum: Avoid copying sample values and use RCU
  pointer direcly instead (bsc#1176774).
- mlxsw: spectrum_matchall: Push per-port rule add/del into
  separate functions (bsc#1176774).
- mlxsw: spectrum_matchall: Move ingress indication into
  mall_entry (bsc#1176774).
- mlxsw: spectrum_matchall: Pass mall_entry as arg to
  mlxsw_sp_mall_port_sample_add() (bsc#1176774).
- mlxsw: spectrum_matchall: Pass mall_entry as arg to
  mlxsw_sp_mall_port_mirror_add() (bsc#1176774).
- mlxsw: spectrum_acl: Use block variable in
  mlxsw_sp_acl_rule_del() (bsc#1176774).
- mlxsw: spectrum: Push matchall bits into a separate file
  (bsc#1176774).
- mlxsw: spectrum: Push flow_block related functions into a
  separate file (bsc#1176774).
- mlxsw: spectrum: Rename acl_block to flow_block (bsc#1176774).
- mlxsw: spectrum_acl: Move block helpers into inline header
  functions (bsc#1176774).
- net/mlxfw: Remove unneeded semicolon (jsc#SLE-15172).
- net: sched: report ndo_setup_tc failures via extack
  (bsc#1176447).
- mlxsw: spectrum_span: Replace zero-length array with
  flexible-array member (bsc#1176774).
- mlxsw: spectrum_span: Use 'refcount_t' for reference counting
  (bsc#1176774).
- mlxsw: spectrum_span: Remove unnecessary debug prints
  (bsc#1176774).
- mlxsw: spectrum_span: Rename parms() to parms_set()
  (bsc#1176774).
- mlxsw: spectrum_span: Reduce nesting in
  mlxsw_sp_span_entry_configure() (bsc#1176774).
- net: sched : Remove unnecessary cast in kfree (bsc#1176447).
- net/sched: act_ct: update nf_conn_acct for act_ct SW offload
  in flowtable (bsc#1176447).
- net/mlx5: improve some comments (jsc#SLE-15172).
- net/mlx5: Read embedded cpu bit only once (jsc#SLE-15172).
- net/mlx5e: Handle errors from netif_set_real_num_{tx,rx}_queues
  (jsc#SLE-15172).
- net/mlx5e: Allow partial data mask for tunnel options
  (jsc#SLE-15172).
- net/mlx5e: Set of completion request bit should not clear
  other adjacent bits (jsc#SLE-15172).
- net/mlx5: IPsec, Refactor SA handle creation and destruction
  (jsc#SLE-15172).
- net/mlx5e: IPSec, Expose IPsec HW stat only for supporting HW
  (jsc#SLE-15172).
- net/mlx5: Refactor mlx5_accel_esp_create_hw_context parameter
  list (jsc#SLE-15172).
- net/mlx5e: en_accel, Add missing net/geneve.h include
  (jsc#SLE-15172).
- net/mlx5: Use the correct IPsec capability function for FPGA
  ops (jsc#SLE-15172).
- mlxsw: reg: Increase register field length to 13 bits
  (bsc#1176774).
- mlxsw: spectrum_router: Re-increase scale of IPv6 nexthop groups
  (bsc#1176774).
- audit: add subj creds to NETFILTER_CFG record to (bsc#1176447).
- audit: make symbol 'audit_nfcfgs' static (bsc#1176447).
- netfilter: add audit table unregister actions (bsc#1176447).
- audit: tidy and extend netfilter_cfg x_tables (bsc#1176447).
- net/sched: act_ct: add nat mangle action only for NAT-conntrack
  (jsc#SLE-15172).
- net/mlx5e: Fix MLX5_TC_CT dependencies (jsc#SLE-15172).
- net/mlx5e: Properly set default values when disabling adaptive
  moderation (jsc#SLE-15172).
- net/mlx5e: Fix arch depending casting issue in FEC
  (jsc#SLE-15172).
- net/mlx5e: Remove warning "devices are not on same switch HW"
  (jsc#SLE-15172).
- netfilter: nf_conntrack_pptp: fix compilation warning with
  W=1 build (bsc#1176447).
- netfilter: conntrack: comparison of unsigned in cthelper
  confirmation (bsc#1176447).
- netfilter: conntrack: Pass value of ctinfo to
  __nf_conntrack_update (bsc#1176447).
- net/sched: fix infinite loop in sch_fq_pie (jsc#SLE-15172).
- bnxt_en: Fix accumulation of bp->net_stats_prev (jsc#SLE-15075).
- netfilter: nfnetlink_cthelper: unbreak userspace helper support
  (bsc#1176447).
- netfilter: conntrack: make conntrack userspace helpers work
  again (bsc#1176447).
- netfilter: nf_conntrack_pptp: prevent buffer overflows in
  debug code (bsc#1176447).
- netfilter: ipset: Fix subcounter update skip (bsc#1176447).
- net/mlx5e: CT: Correctly get flow rule (jsc#SLE-15172).
- net/mlx5: Annotate mutex destroy for root ns (jsc#SLE-15172).
- net/mlx5: Don't maintain a case of del_sw_func being null
  (jsc#SLE-15172).
- net/mlx5e: Fix allowed tc redirect merged eswitch offload cases
  (jsc#SLE-15172).
- net/mlx5: Avoid processing commands before cmdif is ready
  (jsc#SLE-15172).
- net/mlx5: Fix a race when moving command interface to events
  mode (jsc#SLE-15172).
- selftests: mlxsw: qos_mc_aware: Specify arping timeout as an
  integer (bsc#1176774).
- mlxsw: spectrum: Fix use-after-free of split/unsplit/type_set
  in case reload fails (bsc#1176774).
- selftests: netdevsim: Always initialize 'RET' variable
  (bsc#1176774).
- netdevsim: Ensure policer drop counter always increases
  (bsc#1176447).
- flow_dissector: Drop BPF flow dissector prog ref on netns
  cleanup (bsc#1176447).
- netfilter: nft_set_rbtree: Add missing expired checks
  (bsc#1176447).
- netfilter: flowtable: set NF_FLOW_TEARDOWN flag on entry
  expiration (bsc#1176447).
- netfilter: conntrack: fix infinite loop on rmmod (bsc#1176447).
- netfilter: flowtable: Remove WQ_MEM_RECLAIM from workqueue
  (bsc#1176447).
- netfilter: flowtable: Add pending bit for offload work
  (bsc#1176447).
- netfilter: conntrack: avoid gcc-10 zero-length-bounds warning
  (bsc#1176447).
- net: bareudp: avoid uninitialized variable warning
  (jsc#SLE-15172).
- IB/i40iw: Remove bogus call to netdev_master_upper_dev_get()
  (jsc#SLE-13537).
- net: flow_offload: skip hw stats check for
  FLOW_ACTION_HW_STATS_DONT_CARE (bsc#1176774).
- net_sched: fix tcm_parent in tc filter dump (bsc#1176447).
- devlink: Fix reporter's recovery condition (bsc#1176447).
- ice: cleanup language in ice.rst for fw.app (bsc#1176447).
- netfilter: nf_osf: avoid passing pointer to local var
  (bsc#1176447).
- netfilter: nat: never update the UDP checksum when it's 0
  (bsc#1176447).
- net/mlx5: E-switch, Fix mutex init order (jsc#SLE-15172).
- net/mlx5: E-switch, Fix printing wrong error value
  (jsc#SLE-15172).
- net/mlx5: E-switch, Fix error unwinding flow for steering init
  failure (jsc#SLE-15172).
- RDMA/cm: Fix missing RDMA_CM_EVENT_REJECTED event after
  receiving REJ message (jsc#SLE-15176).
- netfilter: nat: fix error handling upon registering inet hook
  (bsc#1176447).
- netfilter: flowtable: Free block_cb when being deleted
  (bsc#1176447).
- net/mlx5e: Get the latest values from counters in switchdev mode
  (jsc#SLE-15172).
- net/mlx5: Kconfig: convert imply usage to weak dependency
  (jsc#SLE-15172).
- net/mlx5e: Don't trigger IRQ multiple times on XSK wakeup to
  avoid WQ overruns (jsc#SLE-15172).
- net/mlx5: CT: Change idr to xarray to protect parallel tuple
  id allocation (jsc#SLE-15172).
- net/mlx5: Fix failing fw tracer allocation on s390
  (jsc#SLE-15172).
- ethtool.h: Replace zero-length array with flexible-array member
  (bsc#1176447).
- net: phy: marvell: Fix pause frame negotiation (bsc#1176447).
- net/mlx5e: CT: Use rhashtable's ct entries instead of a separate
  list (jsc#SLE-15172).
- net/mlx5e: Fix devlink port netdev unregistration sequence
  (jsc#SLE-15172).
- net/mlx5e: Fix missing pedit action after ct clear action
  (jsc#SLE-15172).
- net/mlx5: Fix condition for termination table cleanup
  (jsc#SLE-15172).
- Documentation: devlink: fix broken link warning (bsc#1176447).
- net/tls: fix const assignment warning (bsc#1176447).
- net: sched: Fix setting last executed chain on skb extension
  (bsc#1176447).
- netfilter: nf_tables: reintroduce the NFT_SET_CONCAT flag
  (bsc#1176447).
- netfilter: nf_tables: report EOPNOTSUPP on unsupported
  flags/object type (bsc#1176447).
- netfilter: ipset: Pass lockdep expression to RCU lists
  (bsc#1176447).
- netfilter: nf_tables: do not leave dangling pointer in
  nf_tables_set_alloc_name (bsc#1176447).
- netfilter: xt_IDLETIMER: target v1 - match Android layout
  (bsc#1176447).
- netfilter: nf_tables: do not update stateful expressions if
  lookup is inverted (bsc#1176447).
- netfilter: nft_set_rbtree: Drop spurious condition for overlap
  detection on insertion (bsc#1176447).
- mlxsw: spectrum_trap: fix unintention integer overflow on left
  shift (bsc#1176774).
- IB/qib: Delete struct qib_ivdev.qp_rnd (jsc#SLE-15176).
- RDMA/hns: Fix uninitialized variable bug (jsc#SLE-14777).
- RDMA/hns: Modify the mask of QP number for CQE of hip08
  (jsc#SLE-14777).
- RDMA/hns: Reduce the maximum number of extend SGE per WQE
  (jsc#SLE-14777).
- RDMA/hns: Reduce PFC frames in congestion scenarios
  (jsc#SLE-14777).
- RDMA/mlx5: Add support for RDMA TX flow table (jsc#SLE-15175).
- net/mlx5: Add support for RDMA TX steering (jsc#SLE-15172).
- IB/hfi1: Call kobject_put() when kobject_init_and_add() fails
  (jsc#SLE-13208).
- IB/mlx5: Move to fully dynamic UAR mode once user space supports
  it (jsc#SLE-15175).
- IB/mlx5: Limit the scope of struct mlx5_bfreg_info to mlx5_ib
  (jsc#SLE-15175).
- IB/mlx5: Extend QP creation to get uar page index from user
  space (jsc#SLE-15175).
- IB/mlx5: Extend CQ creation to get uar page index from user
  space (jsc#SLE-15175).
- IB/mlx5: Expose UAR object and its alloc/destroy commands
  (jsc#SLE-15175).
- IB/hfi1: Get rid of a warning (jsc#SLE-13208).
- RDMA/hns: Remove redundant judgment of qp_type (jsc#SLE-14777).
- RDMA/hns: Remove redundant assignment of wc->smac when polling
  cq (jsc#SLE-14777).
- RDMA/hns: Remove redundant qpc setup operations (jsc#SLE-14777).
- RDMA/hns: Remove meaningless prints (jsc#SLE-14777).
- RDMA/hns: Remove definition of cq doorbell structure
  (jsc#SLE-14777).
- RDMA/hns: Adjust the qp status value sequence of the hardware
  (jsc#SLE-14777).
- RDMA/hns: Optimize hns_roce_alloc_vf_resource() (jsc#SLE-14777).
- RDMA/hns: Simplify attribute judgment code (jsc#SLE-14777).
- RDMA/hns: Unify format of prints (jsc#SLE-14777).
- IB/iser: Always check sig MR before putting it to the free pool
  (jsc#SLE-15176).
- IB/hfi1: Use scnprintf() for avoiding potential buffer overflow
  (jsc#SLE-13208).
- IB/mlx5: Generally use the WC auto detection test result
  (jsc#SLE-15175).
- RDMA/hns: Optimize mhop put flow for multi-hop addressing
  (jsc#SLE-14777).
- RDMA/hns: Optimize mhop get flow for multi-hop addressing
  (jsc#SLE-14777).
- IB/mlx5: Fix a NULL vs IS_ERR() check (jsc#SLE-15175).
- RDMA/efa: Use in-kernel offsetofend() to check field
  availability (jsc#SLE-15176).
- IB/hfi1: Remove kobj from hfi1_devdata (jsc#SLE-13208).
- RDMA/hns: Check if depth of qp is 0 before configure
  (jsc#SLE-14777).
- RDMA/hns: Optimize wqe buffer set flow for post send
  (jsc#SLE-14777).
- RDMA/hns: Optimize base address table config flow for qp buffer
  (jsc#SLE-14777).
- RDMA/hns: Optimize the wr opcode conversion from ib to hns
  (jsc#SLE-14777).
- RDMA/hns: Optimize wqe buffer filling process for post send
  (jsc#SLE-14777).
- RDMA/hns: Rename wqe buffer related functions (jsc#SLE-14777).
- RDMA/cm: Make sure the cm_id is in the IB_CM_IDLE state in
  destroy (jsc#SLE-15176).
- RDMA/cm: Allow ib_send_cm_sidr_rep() to be done under lock
  (jsc#SLE-15176).
- RDMA/cm: Allow ib_send_cm_rej() to be done under lock
  (jsc#SLE-15176).
- RDMA/cm: Allow ib_send_cm_drep() to be done under lock
  (jsc#SLE-15176).
- RDMA/cm: Allow ib_send_cm_dreq() to be done under lock
  (jsc#SLE-15176).
- RDMA/cm: Add some lockdep assertions for cm_id_priv->lock
  (jsc#SLE-15176).
- RDMA/cm: Make it clearer how concurrency works in
  cm_req_handler() (jsc#SLE-15176).
- RDMA/cm: Make it clear that there is no concurrency in
  cm_sidr_req_handler() (jsc#SLE-15176).
- RDMA/cm: Make the destroy_id flow more robust (jsc#SLE-15176).
- RDMA/mlx5: Allow MRs to be created in the cache synchronously
  (jsc#SLE-15175).
- RDMA/mlx5: Revise how the hysteresis scheme works for cache
  filling (jsc#SLE-15175).
- RDMA/mlx5: Fix locking in MR cache work queue (jsc#SLE-15175).
- RDMA/mlx5: Lock access to ent->available_mrs/limit when doing
  queue_work (jsc#SLE-15175).
- RDMA/mlx5: Fix MR cache size and limit debugfs (jsc#SLE-15175).
- RDMA/mlx5: Always remove MRs from the cache before destroying
  them (jsc#SLE-15175).
- RDMA/mlx5: Simplify how the MR cache bucket is located
  (jsc#SLE-15175).
- RDMA/mlx5: Rename the tracking variables for the MR cache
  (jsc#SLE-15175).
- RDMA/mlx5: Replace spinlock protected write with atomic var
  (jsc#SLE-15175).
- RDMA/cm: Delete not implemented CM peer to peer communication
  (jsc#SLE-15176).
- RDMA/mlx5: Use offsetofend() instead of duplicated variant
  (jsc#SLE-15175).
- RDMA/mlx4: Delete duplicated offsetofend implementation
  (jsc#SLE-15946).
- RDMA/mlx5: Remove duplicate definitions of SW_ICM macros
  (jsc#SLE-15175).
- RDMA/cma: Teach lockdep about the order of rtnl and lock
  (jsc#SLE-15176).
- RDMA/rw: map P2P memory correctly for signature operations
  (jsc#SLE-15176).
- IB/mlx5: Introduce UAPIs to manage packet pacing
  (jsc#SLE-15175).
- RDMA/hns: fix spelling mistake "attatch" -> "attach"
  (jsc#SLE-14777).
- IB/mlx5: Add np_min_time_between_cnps and rp_max_rate debug
  params (jsc#SLE-15175).
- RDMA/providers: Fix return value when QP type isn't supported
  (jsc#SLE-15176).
- RDMA/efa: Do not delay freeing of DMA pages (jsc#SLE-15176).
- RDMA/efa: Properly document the interrupt mask register
  (jsc#SLE-15176).
- RDMA/efa: Unified getters/setters for device structs bitmask
  access (jsc#SLE-15176).
- RDMA/hns: Optimize qp doorbell allocation flow (jsc#SLE-14777).
- RDMA/hns: Optimize kernel qp wrid allocation flow
  (jsc#SLE-14777).
- RDMA/hns: Optimize qp param setup flow (jsc#SLE-14777).
- RDMA/hns: Optimize qp buffer allocation flow (jsc#SLE-14777).
- RDMA/hns: Optimize qp number assign flow (jsc#SLE-14777).
- RDMA/hns: Optimize qp context create and destroy flow
  (jsc#SLE-14777).
- RDMA/hns: Optimize qp destroy flow (jsc#SLE-14777).
- RDMA/hns: Stop doorbell update while qp state error
  (jsc#SLE-14777).
- RDMA/hns: Use flush framework for the case in aeq
  (jsc#SLE-14777).
- RDMA/hns: Treat revision HIP08_A as a special case
  (jsc#SLE-14777).
- RDMA: Replace zero-length array with flexible-array member
  (jsc#SLE-15176).
- RDMA/hns: Initialize all fields of doorbells to zero
  (jsc#SLE-14777).
- RDMA/hns: fix spelling mistake: "attatch" -> "attach"
  (jsc#SLE-14777).
- RDMA/ucma: Use refcount_t for the ctx->ref (jsc#SLE-15176).
- RDMA/core: Get rid of ib_create_qp_user (jsc#SLE-15176).
- RDMA/hns: Delayed flush cqe process with workqueue
  (jsc#SLE-14777).
- RDMA/hns: Add the workqueue framework for flush cqe handler
  (jsc#SLE-14777).
- RDMA/core: Add weak ordering dma attr to dma mapping
  (jsc#SLE-15176).
- RDMA/ucma: Mask QPN to be 24 bits according to IBTA
  (jsc#SLE-15176).
- RDMA/hns: Optimize eqe buffer allocation flow (jsc#SLE-14777).
- RDMA/hns: Cleanups of magic numbers (jsc#SLE-14777).
- RDMA/cma: Use refcount API to reflect refcount (jsc#SLE-15176).
- RDMA/cma: Rename cma_device ref/deref helpers to to get/put
  (jsc#SLE-15176).
- RDMA/cma: Use refcount API to reflect refcount (jsc#SLE-15176).
- RDMA/cma: Rename cma_device ref/deref helpers to to get/put
  (jsc#SLE-15176).
- RDMA/cma: Use RDMA device port iterator (jsc#SLE-15176).
- RDMA/cma: Use a helper function to enqueue resolve work items
  (jsc#SLE-15176).
- ipvs: fix uninitialized variable warning (bsc#1176447).
- netfilter: nft_exthdr: fix endianness of tcp option cast
  (bsc#1176447).
- netfilter: flowtable: add counter support in HW offload
  (bsc#1176447).
- netfilter: conntrack: add nf_ct_acct_add() (bsc#1176447).
- netfilter: nf_tables: skip set types that do not support for
  expressions (bsc#1176447).
- netfilter: nft_dynset: validate set expression definition
  (bsc#1176447).
- netfilter: nft_set_bitmap: initialize set element extension
  in lookups (bsc#1176447).
- netfilter: ctnetlink: be more strict when NF_CONNTRACK_MARK
  is not set (bsc#1176447).
- netfilter: nf_queue: prefer nf_queue_entry_free (bsc#1176447).
- netfilter: nf_queue: do not release refcouts until nf_reinject
  is done (bsc#1176447).
- netfilter: nf_queue: place bridge physports into queue_entry
  struct (bsc#1176447).
- netfilter: nf_queue: make nf_queue_entry_release_refs static
  (bsc#1176447).
- netfilter: flowtable: Use work entry per offload command
  (bsc#1176447).
- netfilter: flowtable: Use rw sem as flow block lock
  (bsc#1176447).
- netfilter: nf_tables: silence a RCU-list warning in
  nft_table_lookup() (bsc#1176447).
- netfilter: flowtable: Fix incorrect tc_setup_type type
  (bsc#1176447).
- netfilter: flowtable: add counter support (bsc#1176447).
- netfilter: nf_tables: add enum nft_flowtable_flags to uapi
  (bsc#1176447).
- netfilter: conntrack: export nf_ct_acct_update() (bsc#1176447).
- ipvs: optimize tunnel dumps for icmp errors (bsc#1176447).
- netfilter: conntrack: Add missing annotations for
  nf_conntrack_all_lock() and nf_conntrack_all_unlock()
  (bsc#1176447).
- netfilter: ctnetlink: Add missing annotation for
  ctnetlink_parse_nat_setup() (bsc#1176447).
- netfilter: flowtable: fix NULL pointer dereference in tunnel
  offload support (bsc#1176447).
- netfilter: nf_tables: add nft_set_elem_expr_destroy() and use it
  (bsc#1176447).
- netfilter: nf_tables: fix double-free on set expression from
  the error path (bsc#1176447).
- netfilter: nf_tables: allow to specify stateful expression in
  set definition (bsc#1176447).
- netfilter: nf_tables: pass context to nft_set_destroy()
  (bsc#1176447).
- netfilter: nf_tables: move nft_expr_clone() to nf_tables_api.c
  (bsc#1176447).
- selftests: mlxsw: Add test cases for devlink-trap policers
  (bsc#1176774).
- mlxsw: spectrum_trap: Add support for setting of packet trap
  group parameters (bsc#1176774).
- mlxsw: spectrum_trap: Switch to use correct packet trap group
  (bsc#1176774).
- mlxsw: spectrum_trap: Do not initialize dedicated discard
  policer (bsc#1176774).
- mlxsw: spectrum_trap: Add devlink-trap policer support
  (bsc#1176774).
- mlxsw: spectrum_trap: Prepare policers for registration with
  devlink (bsc#1176774).
- mlxsw: spectrum: Track used packet trap policer IDs
  (bsc#1176774).
- mlxsw: reg: Extend QPCR register (bsc#1176774).
- selftests: netdevsim: Add test cases for devlink-trap policers
  (bsc#1176774).
- netdevsim: Add support for setting of packet trap group
  parameters (bsc#1176447).
- devlink: Allow setting of packet trap group parameters
  (bsc#1176774).
- devlink: Add packet trap group parameters support (bsc#1176774).
- netdevsim: Add devlink-trap policer support (bsc#1176447).
- Documentation: Add description of packet trap policers
  (bsc#1176447).
- devlink: Add packet trap policers support (bsc#1176774).
- devlink: Add auto dump flag to health reporter (bsc#1176774).
- devlink: Implicitly set auto recover flag when registering
  health reporter (jsc#SLE-15075).
- netdevsim: Change dummy reporter auto recover default
  (jsc#SLE-15075).
- net: devlink: use NL_SET_ERR_MSG_MOD instead of NL_SET_ERR_MSG
  (bsc#1176447).
- net: introduce nla_put_bitfield32() helper and use it
  (jsc#SLE-15172).
- net/mlx5e: add mlx5e_rep_indr_setup_ft_cb support
  (jsc#SLE-15172).
- net/mlx5e: refactor indr setup block (jsc#SLE-15172).
- net/mlx5: E-Switch: Move eswitch chains to a new directory
  (jsc#SLE-15172).
- net/mlx5: Use a separate work queue for fib event handling
  (jsc#SLE-15172).
- mlx5: Remove uninitialized use of key in mlx5_core_create_mkey
  (jsc#SLE-15172).
- {IB,net}/mlx5: Move asynchronous mkey creation to mlx5_ib
  (jsc#SLE-15172).
- {IB,net}/mlx5: Assign mkey variant in mlx5_ib only
  (jsc#SLE-15172).
- {IB,net}/mlx5: Setup mkey variant before mr create command
  invocation (jsc#SLE-15172).
- devlink: don't wrap commands in rST shell blocks (bsc#1176447).
- bnxt_en: Add partno to devlink info_get cb (jsc#SLE-15075).
- bnxt_en: Read partno and serialno of the board from VPD
  (jsc#SLE-15075).
- PCI: Add new PCI_VPD_RO_KEYWORD_SERIALNO macro (jsc#SLE-15075).
- devlink: Add macro for "fw.mgmt.api" to info_get cb
  (jsc#SLE-15075).
- mlxsw: spectrum_router: Avoid uninitialized symbol errors
  (bsc#1176774).
- mlxsw: switchx2: Remove unnecessary conversion to bool
  (bsc#1176774).
- mlxsw: core_acl: Avoid defining static variable in header file
  (bsc#1176774).
- mlxsw: spectrum: Remove unused RIF and FID families
  (bsc#1176774).
- mlxsw: spectrum_router: Add proper function documentation
  (bsc#1176774).
- mlxsw: i2c: Add missing field documentation (bsc#1176774).
- net: add a reference to MACsec ops in net_device (bsc#1176447).
- cls_flower: Add extack support for flags key (bsc#1176447).
- cls_flower: Add extack support for src and dst port range
  options (bsc#1176447).
- cls_flower: Add extack support for mpls options (bsc#1176447).
- netdevsim: support taking immediate snapshot via devlink
  (jsc#SLE-15075).
- sched: act_pedit: Implement stats_update callback (bsc#1176447).
- sched: act_skbedit: Implement stats_update callback
  (bsc#1176447).
- selftests: mlxsw: qos_dscp_router: Test no DSCP rewrite after
  pedit (bsc#1176774).
- mlxsw: spectrum_flower: Offload FLOW_ACTION_MANGLE
  (bsc#1176774).
- mlxsw: core: Add DSCP, ECN, dscp_rw to QOS_ACTION (bsc#1176774).
- mlxsw: core: Rename mlxsw_afa_qos_cmd to
  mlxsw_afa_qos_switch_prio_cmd (bsc#1176774).
- net/mlx5: E-switch, Protect eswitch mode changes
  (jsc#SLE-15172).
- net/mlx5: E-switch, Extend eswitch enable to handle num_vfs
  change (jsc#SLE-15172).
- net/mlx5: Split eswitch mode check to different helper function
  (jsc#SLE-15172).
- devlink: Rely on driver eswitch thread safety instead of devlink
  (bsc#1176447).
- net/mlx5: Simplify mlx5_unload_one() and its callers
  (jsc#SLE-15172).
- net/mlx5: Simplify mlx5_register_device to return void
  (jsc#SLE-15172).
- net/mlx5: Avoid group version scan when not necessary
  (jsc#SLE-15172).
- net/mlx5: Avoid incrementing FTE version (jsc#SLE-15172).
- net/mlx5: Fix group version management (jsc#SLE-15172).
- net/mlx5: Simplify matching group searches (jsc#SLE-15172).
- net/mlx5: E-Switch, Use correct type for chain, prio and level
  values (jsc#SLE-15172).
- net/mlx5: E-Switch, free flow_group_in after creating the
  restore table (jsc#SLE-15172).
- net/mlx5: E-Switch, Enable chains only if regs loopback is
  enabled (jsc#SLE-15172).
- net/mlx5: E-Switch, Enable restore table only if reg_c1 is
  supported (jsc#SLE-15172).
- net/mlx5e: remove duplicated check chain_index in
  mlx5e_rep_setup_ft_cb (jsc#SLE-15172).
- net/mlx5e: Fix actions_match_supported() return (jsc#SLE-15172).
- devlink: expand the devlink-info documentation (bsc#1176447).
- devlink: Only pass packet trap group identifier in trap
  structure (bsc#1176774).
- devlink: Stop reference counting packet trap groups
  (bsc#1176774).
- netdevsim: Explicitly register packet trap groups (bsc#1176774).
- mlxsw: spectrum_trap: Explicitly register packet trap groups
  (bsc#1176774).
- net: phy: aquantia: remove downshift warning now that phylib
  takes care (bsc#1176447).
- net: phy: marvell: remove downshift warning now that phylib
  takes care (bsc#1176447).
- net: phy: add and use phy_check_downshift (bsc#1176447).
- mlxsw: spectrum_cnt: Fix 64-bit division in
  mlxsw_sp_counter_resources_register (bsc#1176774).
- net: sched: rename more stats_types (jsc#SLE-15172).
- net/tls: Annotate access to sk_prot with READ_ONCE/WRITE_ONCE
  (bsc#1176447).
- net/tls: Read sk_prot once when building tls proto ops
  (bsc#1176447).
- net/tls: Constify base proto ops used for building tls proto
  (bsc#1176447).
- mlxsw: core: Add QOS_ACTION (bsc#1176774).
- net: tc_skbedit: Make the skbedit priority offloadable
  (bsc#1176774).
- net: tc_skbedit: Factor a helper out of is_tcf_skbedit_{mark,
  ptype}() (bsc#1176774).
- net/mlx5: Avoid forwarding to other eswitch uplink
  (jsc#SLE-15172).
- net/mlx5: Eswitch, enable forwarding back to uplink port
  (jsc#SLE-15172).
- net/mlx5e: Add support for offloading traffic from uplink to
  uplink (jsc#SLE-15172).
- net/mlx5: Don't use termination tables in slow path
  (jsc#SLE-15172).
- net/mlx5: Avoid configuring eswitch QoS if not supported
  (jsc#SLE-15172).
- net/mlx5e: Fix devlink port register sequence (jsc#SLE-15172).
- net/mlx5e: Fix rejecting all egress rules not on vlan
  (jsc#SLE-15172).
- net/mlx5e: en_tc: Rely just on register loopback for tunnel
  restoration (jsc#SLE-15172).
- net/mlx5e: CT: Fix stack usage compiler warning (jsc#SLE-15172).
- net/mlx5e: CT: Fix insert rules when TC_CT config isn't enabled
  (jsc#SLE-15172).
- net/mlx5e: CT: remove set but not used variable 'unnew'
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Skip restore modify header between prios
  of same chain (jsc#SLE-15172).
- net/mlx5: E-Switch: Fix using fwd and modify when firmware
  doesn't support it (jsc#SLE-15172).
- net/mlx5: Add missing inline to stub esw_add_restore_rule
  (jsc#SLE-15172).
- net: sched: Fix hw_stats_type setting in pedit loop
  (jsc#SLE-15172).
- selftests: mlxsw: Add tc action hw_stats tests (bsc#1176774).
- mlxsw: spectrum_cnt: Expose devlink resource occupancy for
  counters (bsc#1176774).
- mlxsw: spectrum_cnt: Consolidate subpools initialization
  (bsc#1176774).
- mlxsw: spectrum_cnt: Move config validation along with resource
  register (bsc#1176774).
- mlxsw: spectrum_cnt: Expose subpool sizes over devlink resources
  (bsc#1176774).
- mlxsw: spectrum_cnt: Add entry_size_res_id for each subpool
  and use it to query entry size (bsc#1176774).
- mlxsw: spectrum_cnt: Move sub_pools under per-instance pool
  struct (bsc#1176774).
- selftests: spectrum-2: Adjust tc_flower_scale limit according
  to current counter count (bsc#1176774).
- mlxsw: spectrum_cnt: Query bank size from FW resources
  (bsc#1176774).
- netfilter: conntrack: re-visit sysctls in unprivileged
  namespaces (bsc#1176447).
- netfilter: nft_lookup: update element stateful expression
  (bsc#1176447).
- netfilter: nf_tables: add nft_set_elem_update_expr() helper
  function (bsc#1176447).
- netfilter: nf_tables: add elements with stateful expressions
  (bsc#1176447).
- netfilter: nf_tables: statify nft_expr_init() (bsc#1176447).
- netfilter: nf_tables: add nft_set_elem_expr_alloc()
  (bsc#1176447).
- nft_set_pipapo: Prepare for single ranged field usage
  (bsc#1176447).
- nft_set_pipapo: Introduce AVX2-based lookup implementation
  (bsc#1176447).
- nft_set_pipapo: Prepare for vectorised implementation: helpers
  (bsc#1176447).
- nft_set_pipapo: Prepare for vectorised implementation: alignment
  (bsc#1176447).
- nft_set_pipapo: Add support for 8-bit lookup groups and dynamic
  switch (bsc#1176447).
- nft_set_pipapo: Generalise group size for buckets (bsc#1176447).
- netfilter: flowtable: add tunnel encap/decap action offload
  support (bsc#1176447).
- netfilter: flowtable: add tunnel match offload support
  (bsc#1176447).
- netfilter: flowtable: add indr block setup support
  (bsc#1176447).
- netfilter: flowtable: add nf_flow_table_block_offload_init()
  (bsc#1176447).
- netfilter: xt_IDLETIMER: clean up some indenting (bsc#1176447).
- netfilter: bitwise: use more descriptive variable-names
  (bsc#1176447).
- netfilter: Replace zero-length array with flexible-array member
  (bsc#1176447).
- netfilter: nft_set_pipapo: make the symbol 'nft_pipapo_get'
  static (bsc#1176447).
- netfilter: cleanup unused macro (bsc#1176447).
- netfilter: nf_tables: make all set structs const (bsc#1176447).
- netfilter: nf_tables: make sets built-in (bsc#1176447).
- netfilter: nft_tunnel: add support for geneve opts
  (bsc#1176447).
- netfilter: xtables: Add snapshot of hardidletimer target
  (bsc#1176447).
- netfilter: flowtable: Use nf_flow_offload_tuple for stats as
  well (bsc#1176447).
- net_sched: sch_fq: enable use of hrtimer slack (bsc#1176447).
- net_sched: do not reprogram a timer about to expire
  (bsc#1176447).
- net_sched: add qdisc_watchdog_schedule_range_ns() (bsc#1176447).
- nfp: allow explicitly selected delayed stats (bsc#1176447).
- net: rename flow_action_hw_stats_types* -> flow_action_hw_stats*
  (jsc#SLE-15172).
- net: sched: set the hw_stats_type in pedit loop (jsc#SLE-15172).
- selftests: mlxsw: RED: Test RED ECN nodrop offload
  (bsc#1176774).
- mlxsw: spectrum_qdisc: Offload RED ECN nodrop mode
  (bsc#1176774).
- net: sched: RED: Introduce an ECN nodrop mode (bsc#1176774).
- net: sched: Allow extending set of supported RED flags
  (bsc#1176774).
- net/mlx5: DR, Remove unneeded functions deceleration
  (jsc#SLE-15172).
- net/mlx5: DR, Add support for flow table id destination action
  (jsc#SLE-15172).
- net/mlx5: Avoid deriving mlx5_core_dev second time
  (jsc#SLE-15172).
- net/mlx5: E-switch, Annotate esw state_lock mutex destroy
  (jsc#SLE-15172).
- net/mlx5: E-switch, Annotate termtbl_mutex mutex destroy
  (jsc#SLE-15172).
- net/mlx5: Accept flow rules without match (jsc#SLE-15172).
- net/mlx5: E-Switch, Refactor unload all reps per rep type
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Update VF vports config when num of VFs
  changed (jsc#SLE-15172).
- net/mlx5: E-Switch, Introduce per vport configuration for
  eswitch modes (jsc#SLE-15172).
- net/mlx5: E-switch, Make vport setup/cleanup sequence symmetric
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Prepare for vport enable/disable refactor
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Remove redundant warning when QoS enable
  failed (jsc#SLE-15172).
- net/mlx5: E-Switch, Hold mutex when querying drop counter in
  legacy mode (jsc#SLE-15172).
- net/mlx5: E-Switch, Remove redundant check of eswitch manager
  cap (jsc#SLE-15172).
- net/mlx5e: CT: Support clear action (jsc#SLE-15172).
- net/mlx5e: CT: Handle misses after executing CT action
  (jsc#SLE-15172).
- net/mlx5e: CT: Offload established flows (jsc#SLE-15172).
- flow_offload: Add flow_match_ct to get rule ct match
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Support getting chain mapping
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Add support for offloading rules with no
  in_port (jsc#SLE-15172).
- net/mlx5: E-Switch, Introduce global tables (jsc#SLE-15172).
- net/sched: act_ct: Enable hardware offload of flow table entires
  (jsc#SLE-15172).
- net/sched: act_ct: Support refreshing the flow table entries
  (jsc#SLE-15172).
- net/sched: act_ct: Support restoring conntrack info on skbs
  (jsc#SLE-15172).
- net/sched: act_ct: Instantiate flow table entry actions
  (jsc#SLE-15172).
- netfilter: flowtable: Add API for registering to flow table
  events (jsc#SLE-15172).
- net/mlx5e: en_rep: Create uplink rep root table after eswitch
  offloads table (jsc#SLE-15172).
- net/mlx5: E-Switch, Enable reg c1 loopback when possible
  (jsc#SLE-15172).
- net/mlx5e: Restore tunnel metadata on miss (jsc#SLE-15172).
- net/mlx5: E-Switch, Get reg_c1 value on miss (jsc#SLE-15172).
- net/mlx5e: Support inner header rewrite with goto action
  (jsc#SLE-15172).
- net/mlx5e: Disallow inserting vxlan/vlan egress rules without
  decap/pop (jsc#SLE-15172).
- net/mlx5e: Move tc tunnel parsing logic with the rest at tc_tun
  module (jsc#SLE-15172).
- net/mlx5e: Allow re-allocating mod header actions
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Restore chain id on miss (jsc#SLE-15172).
- net/mlx5e: Rx, Split rep rx mpwqe handler from nic
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Mark miss packets with new chain id mapping
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Get reg_c0 value on CQE (jsc#SLE-15172).
- net/mlx5: E-Switch, Move source port on reg_c0 to the upper
  16 bits (jsc#SLE-15172).
- net/mlx5: Introduce mapping infra for mapping unique ids to data
  (jsc#SLE-15172).
- net: sched: Support specifying a starting chain via tc skb ext
  (jsc#SLE-15172).
- net: sched: Change the block's chain list to an rcu list
  (jsc#SLE-15172).
- net: sched: Pass ingress block to tcf_classify_ingress
  (jsc#SLE-15172).
- net: sched: Introduce ingress classification function
  (jsc#SLE-15172).
- bareudp: Fixed bareudp receive handling (jsc#SLE-15172).
- flow_offload: restrict driver to pass one allowed bit to
  flow_action_hw_stats_types_check() (jsc#SLE-15172).
- flow_offload: turn hw_stats_type into dedicated enum
  (jsc#SLE-15172).
- flow_offload: fix allowed types check (jsc#SLE-15172).
- flow_offload: use flow_action_for_each in
  flow_action_mixed_hw_stats_types_check() (jsc#SLE-15172).
- net/mlx5e: Show/set Rx network flow classification rules on
  ul rep (jsc#SLE-15172).
- net/mlx5e: Init ethtool steering for representors
  (jsc#SLE-15172).
- net/mlx5e: Show/set Rx flow indir table and RSS hash key on
  ul rep (jsc#SLE-15172).
- net/mlx5: E-switch, make query inline mode a static function
  (jsc#SLE-15172).
- net/mlx5: Allocate smaller size tables for ft offload
  (jsc#SLE-15172).
- net/mlx5e: Fix an IS_ERR() vs NULL check (jsc#SLE-15172).
- net/mlx5: Verify goto chain offload support (jsc#SLE-15172).
- net/mlx5: E-Switch, Use vport metadata matching only when
  mandatory (jsc#SLE-15172).
- net/mlx5: Tidy up and fix reverse christmas ordring
  (jsc#SLE-15172).
- net/mlx5: HW bit for goto chain offload support (jsc#SLE-15172).
- net/mlx5: Introduce TLS and IPSec objects enums (jsc#SLE-15172).
- net/mlx5: Introduce egress acl forward-to-vport capability
  (jsc#SLE-15172).
- net/mlx5: Expose raw packet pacing APIs (jsc#SLE-15172).
- net/mlx5e: Replace zero-length array with flexible-array member
  (jsc#SLE-15172).
- net: sched: pie: change tc_pie_xstats->prob (bsc#1176447).
- bnxt_en: Call devlink_port_type_clear() in remove()
  (jsc#SLE-15075).
- bnxt_en: Return -EAGAIN if fw command returns BUSY
  (jsc#SLE-15075).
- bnxt_en: Modify some bnxt_hwrm_*_free() functions to void
  (jsc#SLE-15075).
- bnxt_en: Remove unnecessary assignment of return code
  (jsc#SLE-15075).
- bnxt_en: Clear DCB settings after firmware reset
  (jsc#SLE-15075).
- bnxt_en: Process the NQ under NAPI continuous polling
  (jsc#SLE-15075).
- bnxt_en: Simplify __bnxt_poll_cqs_done() (jsc#SLE-15075).
- bnxt_en: Handle all NQ notifications in bnxt_poll_p5()
  (jsc#SLE-15075).
- net/sched: act_ct: fix lockdep splat in tcf_ct_flow_table_get
  (jsc#SLE-15172).
- bareudp: remove unnecessary udp_encap_enable() in
  bareudp_socket_create() (jsc#SLE-15172).
- bareudp: print error message when command fails (jsc#SLE-15172).
- bareudp: add module alias (jsc#SLE-15172).
- sched: act: allow user to specify type of HW stats for a filter
  (jsc#SLE-15172).
- flow_offload: introduce "disabled" HW stats type and allow it
  in mlxsw (bsc#1176774).
- mlxsw: spectrum_acl: Ask device for rule stats only if counter
  was created (bsc#1176774).
- flow_offload: introduce "delayed" HW stats type and allow it
  in mlx5 (jsc#SLE-15172).
- flow_offload: introduce "immediate" HW stats type and allow
  it in mlxsw (bsc#1176774).
- mlxsw: restrict supported HW stats type to "any" (bsc#1176774).
- mlxsw: spectrum_flower: Do not allow mixing HW stats types
  for actions (bsc#1176774).
- flow_offload: check for basic action hw stats type
  (jsc#SLE-15075).
- ocelot_flower: use flow_offload_has_one_action() helper
  (jsc#SLE-15172).
- flow_offload: Introduce offload of HW stats type
  (jsc#SLE-15075).
- RDMA/ipoib: reject unsupported coalescing params
  (jsc#SLE-15176).
- nfp: Use pci_get_dsn() (bsc#1176447).
- bnxt_en: Use pci_get_dsn() (jsc#SLE-15075).
- selftests: forwarding: ETS: Use Qdisc counters (bsc#1176774).
- mlxsw: spectrum_qdisc: Support offloading of FIFO Qdisc
  (bsc#1176774).
- mlxsw: spectrum_qdisc: Add handle parameter to ..._ops.replace
  (bsc#1176774).
- mlxsw: spectrum_qdisc: Introduce struct mlxsw_sp_qdisc_state
  (bsc#1176774).
- net: sched: Make FIFO Qdisc offloadable (bsc#1176774).
- mlx5: reject unsupported coalescing params (jsc#SLE-15172).
- bnxt: reject unsupported coalescing params (jsc#SLE-15075).
- nfp: let core reject the unsupported coalescing parameters
  (bsc#1176447).
- pie: realign comment (jsc#SLE-15172).
- pie: remove pie_vars->accu_prob_overflows (jsc#SLE-15172).
- pie: remove unnecessary type casting (jsc#SLE-15172).
- pie: use term backlog instead of qlen (jsc#SLE-15172).
- net/sched: act_ct: Use pskb_network_may_pull() (jsc#SLE-15172).
- net/sched: act_ct: Fix ipv6 lookup of offloaded connections
  (jsc#SLE-15172).
- net: mscc: ocelot: return directly in
  ocelot_cls_flower_{replace, destroy} (jsc#SLE-15172).
- net: mscc: ocelot: replace "rule" and "ocelot_rule" variable
  names with "ace" (jsc#SLE-15172).
- net: mscc: ocelot: simplify tc-flower offload structures
  (jsc#SLE-15172).
- net: mscc: ocelot: make ocelot_ace_rule support multiple ports
  (jsc#SLE-15172).
- net: mlxfw: Replace zero-length array with flexible-array member
  (jsc#SLE-15172).
- selftests: mlxsw: qos_defprio: Use until_counter_is
  (bsc#1176774).
- selftests: forwarding: Convert until_counter_is() to take
  expression (bsc#1176774).
- net/mlx5e: Use devlink virtual flavour for VF devlink port
  (jsc#SLE-15172).
- devlink: Introduce devlink port flavour virtual (jsc#SLE-15172).
- net/sched: act_ct: Software offload of established flows
  (jsc#SLE-15172).
- net/sched: act_ct: Offload established connections to flow table
  (jsc#SLE-15172).
- net/sched: act_ct: Create nf flow table per zone
  (jsc#SLE-15172).
- net: flow_offload: Replace zero-length array with flexible-array
  member (jsc#SLE-15075).
- net: sched: Replace zero-length array with flexible-array member
  (bsc#1176447).
- net: core: Replace zero-length array with flexible-array member
  (bsc#1176447).
- net/mlx5e: Remove redundant comment about goto slow path
  (jsc#SLE-15172).
- net/mlx5e: Reduce number of arguments in slow path handling
  (jsc#SLE-15172).
- net/mlx5e: Remove unused argument from parse_tc_pedit_action()
  (jsc#SLE-15172).
- net/mlx5e: Use NL_SET_ERR_MSG_MOD() extack for errors
  (jsc#SLE-15172).
- net/mlx5e: Use netdev_warn() instead of pr_err() for errors
  (jsc#SLE-15172).
- net/mlx5e: Use netdev_warn() for errors for added prefix
  (jsc#SLE-15172).
- net/mlx5: DR, Improve log messages (jsc#SLE-15172).
- net/mlx5: DR, Change matcher priority parameter type
  (jsc#SLE-15172).
- net/mlx5e: Add devlink fdb_large_groups parameter
  (jsc#SLE-15172).
- net/mlx5: Change the name of steering mode param id
  (jsc#SLE-15172).
- net/mlx5e: Add support for devlink-port in non-representors mode
  (jsc#SLE-15172).
- net/mlx5e: Rename representor get devlink port function
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Allow goto earlier chain if FW supports it
  (jsc#SLE-15172).
- net/mlx5e: Eswitch, Use per vport tables for mirroring
  (jsc#SLE-15172).
- net/mlx5: Eswitch, avoid redundant mask (jsc#SLE-15172).
- net/mlx5e: Don't allow forwarding between uplink
  (jsc#SLE-15172).
- mlxsw: reg: Update module_type values in PMTM register and
  map them to width (bsc#1176774).
- selftests: mlxsw: resource_scale: Invoke for Spectrum-3
  (bsc#1176774).
- selftests: mlxsw: Reduce router scale running time using
  offload indication (bsc#1176774).
- selftests: mlxsw: Reduce running time using offload indication
  (bsc#1176774).
- selftests: mlxsw: Add shared buffer traffic test (bsc#1176774).
- selftests: mlxsw: Add mlxsw lib (bsc#1176774).
- selftests: devlink_lib: Add devlink port helpers (bsc#1176774).
- selftests: devlink_lib: Check devlink info command is supported
  (bsc#1176774).
- selftests: mlxsw: Add shared buffer configuration test
  (bsc#1176774).
- selftests: mlxsw: Use busywait helper in rtnetlink test
  (bsc#1176774).
- selftests: mlxsw: Use busywait helper in vxlan test
  (bsc#1176774).
- selftests: mlxsw: Use busywait helper in blackhole routes test
  (bsc#1176774).
- selftests: devlink_trap_l3_drops: Avoid race condition
  (bsc#1176774).
- selftests: add a mirror test to mlxsw tc flower restrictions
  (bsc#1176774).
- selftests: add egress redirect test to mlxsw tc flower
  restrictions (bsc#1176774).
- selftests: mlxsw: Add a RED selftest (bsc#1176774).
- mlxsw: spectrum: Add mlxsw_sp_span_ops.buffsize_get for
  Spectrum-3 (bsc#1176774).
- mlxsw: spectrum: Initialize advertised speeds to supported
  speeds (bsc#1176774).
- mlxsw: spectrum: Move the ECN-marked packet counter to ethtool
  (bsc#1176774).
- mlxsw: spectrum_switchdev: Optimize SFN records processing
  (bsc#1176774).
- net/mlx5: sparse: warning: Using plain integer as NULL pointer
  (jsc#SLE-15172).
- net/mlx5: sparse: warning: incorrect type in assignment
  (jsc#SLE-15172).
- net/mlx5: Fix header guard in rsc_dump.h (jsc#SLE-15172).
- net/mlx5e: RX, Use indirect calls wrapper for handling
  compressed completions (jsc#SLE-15172).
- net/mlx5e: RX, Use indirect calls wrapper for posting
  descriptors (jsc#SLE-15172).
- net/mlx5e: Change inline mode correctly when changing trust
  state (jsc#SLE-15172).
- net/mlx5e: Add context to the preactivate hook (jsc#SLE-15172).
- net/mlx5e: Allow mlx5e_switch_priv_channels to fail and recover
  (jsc#SLE-15172).
- net/mlx5e: Remove unneeded netif_set_real_num_tx_queues
  (jsc#SLE-15172).
- net/mlx5e: Use preactivate hook to set the indirection table
  (jsc#SLE-15172).
- net/mlx5e: Rename hw_modify to preactivate (jsc#SLE-15172).
- net/mlx5e: Encapsulate updating netdev queues into a function
  (jsc#SLE-15172).
- net/mlx5e: Add missing LRO cap check (jsc#SLE-15172).
- net/mlx5e: Define one flow for TXQ selection when TCs are
  configured (jsc#SLE-15172).
- selftests: netdevsim: Extend devlink trap test to include flow
  action cookie (bsc#1176774).
- netdevsim: add ACL trap reporting cookie as a metadata
  (bsc#1176774).
- mlxsw: spectrum_trap: Lookup and pass cookie down to
  devlink_trap_report() (bsc#1176774).
- mlxsw: pci: Extract cookie index for ACL discard trap packets
  (bsc#1176774).
- mlxsw: core_acl_flex_actions: Implement flow_offload action
  cookie offload (bsc#1176774).
- mlxsw: core_acl_flex_actions: Add trap with userdef action
  (bsc#1176774).
- drop_monitor: extend by passing cookie from driver
  (bsc#1176774).
- flow_offload: pass action cookie through offload structures
  (jsc#SLE-15075).
- netronome: Replace zero-length array with flexible-array member
  (bsc#1176447).
- bareudp: Fix uninitialized variable warnings (jsc#SLE-15172).
- net: Special handling for IP & MPLS (jsc#SLE-15172).
- selftests: devlink_trap_acl_drops: Add ACL traps test
  (bsc#1176774).
- selftests: pass pref and handle to devlink_trap_drop_* helpers
  (bsc#1176774).
- selftests: introduce test for mlxsw tc flower restrictions
  (bsc#1176774).
- mlxsw: spectrum_trap: Add ACL devlink-trap support
  (bsc#1176774).
- mlxsw: spectrum_trap: Introduce dummy group with thin policer
  (bsc#1176774).
- mlxsw: core: Extend MLXSW_RXL_DIS to register disabled trap
  group (bsc#1176774).
- mlxsw: core: Allow to enable/disable rx_listener for trap
  (bsc#1176774).
- mlxsw: acl_flex_actions: Trap all ACL dropped packets to
  DISCARD_*_ACL traps (bsc#1176774).
- mlxsw: spectrum_acl: Pass the ingress indication down to flex
  action (bsc#1176774).
- mlxsw: spectrum_flower: Disable mixed bound blocks to contain
  action drop (bsc#1176774).
- mlxsw: spectrum_acl: Track ingress and egress block bindings
  (bsc#1176774).
- mlxsw: spectrum_trap: Prepare mlxsw_core_trap_action_set()
  to handle not only action (bsc#1176774).
- mlxsw: spectrum_trap: Use listener->en/dis_action instead of
  hard-coded values (bsc#1176774).
- mlxsw: core: Allow to register disabled traps using
  MLXSW_RXL_DIS (bsc#1176774).
- mlxsw: spectrum_trap: Set unreg_action to be SET_FW_DEFAULT
  (bsc#1176774).
- net/mlxfw: fix spelling mistake: "progamming" -> "programming"
  (jsc#SLE-15172).
- mlxsw: pci: Remove unused values (bsc#1176774).
- mlxsw: core: Remove priv from listener equality comparison
  (bsc#1176774).
- mlxsw: spectrum_acl: Make block arg const where appropriate
  (bsc#1176774).
- mlxsw: spectrum_trap: Make global arrays const as they should be
  (bsc#1176774).
- mlxsw: core: Remove initialization to false of mlxsw_listener
  struct (bsc#1176774).
- mlxsw: core: Convert is_event and is_ctrl bools to be single
  bits (bsc#1176774).
- mlxsw: core: Remove dummy union name from struct mlxsw_listener
  (bsc#1176774).
- mlxsw: core: Remove unused action field from mlxsw_rx_listener
  struct (bsc#1176774).
- mlxsw: spectrum_trap: Move policer initialization to
  mlxsw_sp_trap_init() (bsc#1176774).
- mlxsw: core_acl_flex_actions: Rename Trap / Discard Action to
  Trap Action (bsc#1176774).
- mlxsw: spectrum_trap: Move functions to avoid their forward
  declarations (bsc#1176774).
- mlxsw: spectrum_trap: Use err variable instead of directly
  checking func return value (bsc#1176774).
- mlxsw: spectrum: Remove RTNL where possible (bsc#1176774).
- mlxsw: spectrum_router: Take router lock from exported helpers
  (bsc#1176774).
- mlxsw: spectrum_router: Take router lock from inetaddr listeners
  (bsc#1176774).
- mlxsw: spectrum_router: Take router lock from netdev listener
  (bsc#1176774).
- mlxsw: spectrum_dpipe: Take router lock from dpipe code
  (bsc#1176774).
- mlxsw: spectrum_router: Take router lock from inside routing
  code (bsc#1176774).
- mlxsw: spectrum_router: Introduce router lock (bsc#1176774).
- mlxsw: spectrum_router: Store NVE decapsulation configuration
  in router (bsc#1176774).
- mlxsw: spectrum_router: Expose router struct to internal users
  (bsc#1176774).
- mlxsw: spectrum_mr: Protect multicast route list with a lock
  (bsc#1176774).
- mlxsw: spectrum_mr: Protect multicast table list with a lock
  (bsc#1176774).
- mlxsw: spectrum_mr: Publish multicast route after writing it
  to the device (bsc#1176774).
- net/mlx5: Add fsm_reactivate callback support (jsc#SLE-15172).
- net/mlxfw: Add reactivate flow support to FSM burn flow
  (jsc#SLE-15172).
- net/mlxfw: Use MLXFW_ERR_MSG macro for error reporting
  (jsc#SLE-15172).
- net/mlxfw: Convert pr_* to dev_* in mlxfw_fsm.c (jsc#SLE-15172).
- net/mlxfw: More error messages coverage (jsc#SLE-15172).
- net/mlxfw: Improve FSM err message reporting and return codes
  (jsc#SLE-15172).
- net/mlxfw: Generic mlx FW flash status notify (jsc#SLE-15172).
- net, sk_msg: Annotate lockless access to sk_prot on clone
  (bsc#1176447).
- mlxsw: spectrum_nve: Make tunnel initialization symmetric
  (bsc#1176774).
- mlxsw: spectrum: Export function to check if RIF exists
  (bsc#1176774).
- mlxsw: spectrum: Prevent RIF access outside of routing code
  (bsc#1176774).
- mlxsw: spectrum_router: Prepare function for router lock
  introduction (bsc#1176774).
- mlxsw: spectrum_router: Do not assume RTNL is taken when
  resolving underlay device (bsc#1176774).
- mlxsw: spectrum_router: Do not assume RTNL is taken during
  RIF teardown (bsc#1176774).
- mlxsw: spectrum_router: Do not assume RTNL is taken during
  nexthop init (bsc#1176774).
- mlxsw: spectrum_span: Only update mirroring agents if present
  (bsc#1176774).
- mlxsw: spectrum: Convert callers to use new mirroring API
  (bsc#1176774).
- mlxsw: spectrum_span: Prepare work item to update mirroring
  agents (bsc#1176774).
- mlxsw: spectrum_span: Use struct_size() to simplify allocation
  (bsc#1176774).
- mlxsw: spectrum_span: Do no expose mirroring agents to entire
  driver (bsc#1176774).
- mlxsw: spectrum: Protect counter pool with a lock (bsc#1176774).
- mlxsw: spectrum_kvdl: Protect allocations with a lock
  (bsc#1176774).
- mlxsw: Replace zero-length array with flexible-array member
  (bsc#1176774).
- phy: avoid unnecessary link-up delay in polling mode
  (bsc#1176447).
- net/mlx5: Remove a useless 'drain_workqueue()' call in
  'mlx5e_ipsec_cleanup()' (jsc#SLE-15172).
- net/mlx5e: Add support for FEC modes based on 50G per lane links
  (jsc#SLE-15172).
- net/mlxe5: Separate between FEC and current speed
  (jsc#SLE-15172).
- net/mlx5e: Advertise globaly supported FEC modes
  (jsc#SLE-15172).
- net/mlx5e: Enforce setting of a single FEC mode (jsc#SLE-15172).
- net/mlx5e: Set FEC to auto when configured mode is not supported
  (jsc#SLE-15172).
- mlx5: Use proper logging and tracing line terminations
  (jsc#SLE-15172).
- net/mlx5e: Support dump callback in RX reporter (jsc#SLE-15172).
- net/mlx5e: Support dump callback in TX reporter (jsc#SLE-15172).
- net/mlx5e: Gather reporters APIs together (jsc#SLE-15172).
- net/mlx5: Add support for resource dump (jsc#SLE-15172).
- selftests: mlxsw: vxlan: Add test for error path (bsc#1176774).
- selftests: mlxsw: vxlan: Adjust test to recent changes
  (bsc#1176774).
- selftests: mlxsw: extack: Test creation of multiple VLAN-aware
  bridges (bsc#1176774).
- selftests: mlxsw: extack: Test bridge creation with VXLAN
  (bsc#1176774).
- selftests: mlxsw: Remove deprecated test (bsc#1176774).
- mlxsw: spectrum: Reduce dependency between bridge and router
  code (bsc#1176774).
- mlxsw: spectrum_switchdev: Remove VXLAN checks during FID
  membership (bsc#1176774).
- mlxsw: spectrum_switchdev: Have VXLAN device take reference
  on FID (bsc#1176774).
- mlxsw: spectrum_switchdev: Propagate extack to bridge creation
  function (bsc#1176774).
- mlxsw: spectrum_fid: Use 'refcount_t' for FID reference counting
  (bsc#1176774).
- net: sched: don't take rtnl lock during flow_action setup
  (jsc#SLE-15075).
- net: sched: lock action when translating it to flow_action infra
  (jsc#SLE-15075).
- net: phylink: clarify flow control settings in documentation
  (bsc#1176447).
- net: phylink: improve initial mac configuration (bsc#1176447).
- net: phylink: allow ethtool -A to change flow control
  advertisement (bsc#1176447).
- net: phylink: resolve fixed link flow control (bsc#1176447).
- net: phylink: use phylib resolved flow control modes
  (bsc#1176447).
- net: phylink: ensure manual flow control is selected
  appropriately (bsc#1176447).
- net: phylink: remove pause mode ethtool setting for fixed links
  (bsc#1176447).
- net: add linkmode helper for setting flow control advertisement
  (bsc#1176447).
- net: add helpers to resolve negotiated flow control
  (bsc#1176447).
- net: linkmode: make linkmode_test_bit() take const pointer
  (bsc#1176447).
- RDMA/mlx5: Block delay drop to unprivileged users
  (jsc#SLE-15175).
- RDMA/odp: Fix leaking the tgid for implicit ODP (jsc#SLE-15176).
- netfilter: nft_fwd_netdev: allow to redirect to ifb via ingress
  (bsc#1176447).
- netfilter: nft_fwd_netdev: validate family and chain type
  (bsc#1176447).
- netfilter: nft_set_rbtree: Detect partial overlaps on insertion
  (bsc#1176447).
- netfilter: nft_set_rbtree: Introduce and use
  nft_rbtree_interval_start() (bsc#1176447).
- netfilter: nft_set_pipapo: Separate partial and complete
  overlap cases on insertion (bsc#1176447).
- netfilter: nf_tables: Allow set back-ends to report partial
  overlaps on insertion (bsc#1176447).
- net/mlx5: Clear LAG notifier pointer after unregister
  (jsc#SLE-15172).
- net/mlx5e: Fix endianness handling in pedit mask
  (jsc#SLE-15172).
- net/mlx5e: kTLS, Fix wrong value in record tracker enum
  (jsc#SLE-15172).
- netfilter: flowtable: populate addr_type mask (bsc#1176447).
- netfilter: flowtable: Fix flushing of offloaded flows on free
  (bsc#1176447).
- netfilter: flowtable: reload ip{v6}h in nf_flow_tuple_ip{v6}
  (bsc#1176447).
- netfilter: flowtable: reload ip{v6}h in nf_flow_nat_ip{v6}
  (bsc#1176447).
- net: netdevsim: Use scnprintf() for avoiding potential buffer
  overflow (bsc#1176447).
- net: nfp: Use scnprintf() for avoiding potential buffer overflow
  (bsc#1176447).
- mlxsw: reg: Increase register field length to 31 bits
  (bsc#1176774).
- netfilter: nft_chain_nat: inet family is missing module
  ownership (bsc#1176447).
- netfilter: nf_tables: dump NFTA_CHAIN_FLAGS attribute
  (bsc#1176447).
- netfilter: nft_tunnel: add missing attribute validation for
  tunnels (bsc#1176447).
- netfilter: nft_payload: add missing attribute validation for
  payload csum flags (bsc#1176447).
- netfilter: cthelper: add missing attribute validation for
  cthelper (bsc#1176447).
- netfilter: nf_tables: free flowtable hooks on hook register
  error (bsc#1176447).
- netfilter: x_tables: xt_mttg_seq_next should increase position
  index (bsc#1176447).
- netfilter: xt_recent: recent_seq_next should increase position
  index (bsc#1176447).
- netfilter: synproxy: synproxy_cpu_seq_next should increase
  position index (bsc#1176447).
- netfilter: nf_conntrack: ct_cpu_seq_next should increase
  position index (bsc#1176447).
- net: phy: marvell: don't interpret PHY status unless resolved
  (bsc#1176447).
- mlx5: register lag notifier for init network namespace only
  (jsc#SLE-15172).
- net: phy: corrected the return value
  for genphy_check_and_restart_aneg and
  genphy_c45_check_and_restart_aneg (bsc#1176447).
- net: core: devlink.c: Use built-in RCU list checking
  (bsc#1176447).
- netfilter: xt_hashlimit: unregister proc file before releasing
  mutex (bsc#1176447).
- nft_set_pipapo: Actually fetch key data in nft_pipapo_remove()
  (bsc#1176447).
- netfilter: ipset: Fix "INFO: rcu detected stall in hash_xxx"
  reports (bsc#1176447).
- net: core: devlink.c: Hold devlink->lock from the beginning
  of devlink_dpipe_table_register() (bsc#1176447).
- net/mlx5: Fix lowest FDB pool size (jsc#SLE-15172).
- net/mlx5: Fix sleep while atomic in mlx5_eswitch_get_vepa
  (jsc#SLE-15172).
- netfilter: nft_set_pipapo: Don't abuse unlikely() in
  pipapo_refill() (bsc#1176447).
- netfilter: nft_set_pipapo: Fix mapping table example in comments
  (bsc#1176447).
- netfilter: conntrack: allow insertion of clashing entries
  (bsc#1176447).
- netfilter: conntrack: split resolve_clash function
  (bsc#1176447).
- netfilter: conntrack: place confirm-bit setting in a helper
  (bsc#1176447).
- netfilter: conntrack: remove two args from resolve_clash
  (bsc#1176447).
- netfilter: flowtable: skip offload setup if disabled
  (bsc#1176447).
- netfilter: xt_hashlimit: limit the max size of hashtable
  (bsc#1176447).
- netfilter: xt_hashlimit: reduce hashlimit_mutex scope for
  htable_put() (bsc#1176447).
- net/flow_dissector: remove unexist field description
  (bsc#1176447).
- mlxsw: spectrum_router: Clear offload indication from IPv6
  nexthops on abort (bsc#1176774).
- selftests: mlxsw: Add test cases for local table route
  replacement (bsc#1176774).
- mlxsw: spectrum_router: Prevent incorrect replacement of local
  table routes (bsc#1176774).
- net: sched: prevent a use after free (jsc#SLE-15172).
- netfilter: flowtable: Fix setting forgotten NF_FLOW_HW_DEAD flag
  (bsc#1176447).
- netfilter: flowtable: Fix missing flush hardware on table free
  (bsc#1176447).
- netfilter: flowtable: Fix hardware flush order on
  nf_flow_table_cleanup (bsc#1176447).
- netfilter: Use kvcalloc (bsc#1176447).
- netfilter: ipset: fix suspicious RCU usage in find_set_and_id
  (bsc#1176447).
- mlxsw: spectrum_qdisc: Fix 64-bit division error in
  mlxsw_sp_qdisc_tbf_rate_kbps (bsc#1176774).
- RDMA/cm: Remove CM message structs (jsc#SLE-15176).
- RDMA/core: Add the core support field to METHOD_GET_CONTEXT
  (jsc#SLE-15176).
- IB/umem: use get_user_pages_fast() to pin DMA pages
  (jsc#SLE-15176).
- sch_choke: Use kvcalloc (bsc#1176447).
- devlink: document devlink info versions reported by bnxt_en
  driver (jsc#SLE-15075).
- mlx5: Use dev_net netdevice notifier registrations
  (jsc#SLE-15172).
- net: introduce dev_net notifier register/unregister variants
  (jsc#SLE-15172).
- net: push code from net notifier reg/unreg into helpers
  (jsc#SLE-15172).
- nf_tables: Add set type for arbitrary concatenation of ranges
  (bsc#1176447).
- netfilter: nf_tables: Support for sets with multiple ranged
  fields (bsc#1176447).
- netfilter: nf_tables: add NFTA_SET_ELEM_KEY_END attribute
  (bsc#1176447).
- netfilter: nf_tables: add nft_setelem_parse_key() (bsc#1176447).
- selftests: mlxsw: Add a TBF selftest (bsc#1176774).
- selftests: forwarding: lib: Add helpers for busywaiting
  (bsc#1176774).
- selftests: Move two functions from mlxsw's qos_lib to lib
  (bsc#1176774).
- mlxsw: spectrum_qdisc: Support offloading of TBF Qdisc
  (bsc#1176774).
- mlxsw: spectrum: Configure shaper rate and burst size together
  (bsc#1176774).
- mlxsw: spectrum: Add lowest_shaper_bs to struct mlxsw_sp
  (bsc#1176774).
- mlxsw: reg: Increase MLXSW_REG_QEEC_MAS_DIS (bsc#1176774).
- mlxsw: reg: Add max_shaper_bs to QoS ETS Element Configuration
  (bsc#1176774).
- mlxsw: spectrum_qdisc: Extract a common leaf unoffload function
  (bsc#1176774).
- mlxsw: spectrum_qdisc: Add mlxsw_sp_qdisc_get_class_stats()
  (bsc#1176774).
- mlxsw: spectrum_qdisc: Extract a per-TC stat function
  (bsc#1176774).
- net: sched: Make TBF Qdisc offloadable (bsc#1176774).
- net/mlx5: make the symbol 'ESW_POOLS' static (jsc#SLE-15172).
- net: sched: pie: export symbols to be reused by FQ-PIE
  (jsc#SLE-15172).
- net: sched: pie: fix alignment in struct instances
  (jsc#SLE-15172).
- net: sched: pie: fix commenting (jsc#SLE-15172).
- pie: improve comments and commenting style (jsc#SLE-15172).
- pie: rearrange structure members and their initializations
  (jsc#SLE-15172).
- pie: use u8 instead of bool in pie_vars (jsc#SLE-15172).
- pie: rearrange macros in order of length (jsc#SLE-15172).
- pie: use U64_MAX to denote (2^64 - 1) (jsc#SLE-15172).
- net: sched: pie: move common code to pie.h (jsc#SLE-15172).
- net: phy: add new version of phy_do_ioctl (bsc#1176447).
- net: phy: rename phy_do_ioctl to phy_do_ioctl_running
  (bsc#1176447).
- spectrum: Add a delayed work to update SPAN buffsize according
  to speed (bsc#1176774).
- mlxsw: spectrum: Fix SPAN egress mirroring buffer size for
  Spectrum-2 (bsc#1176774).
- mlxsw: spectrum_span: Put buffsize update code into helper
  function (bsc#1176774).
- mlxsw: spectrum: Push code getting port speed into a helper
  (bsc#1176774).
- r8169: use generic ndo_do_ioctl handler phy_do_ioctl
  (bsc#1176447).
- net: phy: add generic ndo_do_ioctl handler phy_do_ioctl
  (bsc#1176447).
- net: phylink: allow in-band AN for USXGMII (bsc#1176447).
- net: phy: don't crash in phy_read/_write_mmd without a PHY
  driver (bsc#1176447).
- net: phylink: Allow 2.5BASE-T, 5GBASE-T and 10GBASE-T for the
  10G link modes (bsc#1176447).
- selftests: devlink_trap_tunnel_vxlan: Add test case for
  overlay_smac_is_mc (bsc#1176774).
- mlxsw: Add OVERLAY_SMAC_MC trap (bsc#1176774).
- selftests: devlink_trap_tunnel_ipip: Add test case for
  decap_error (bsc#1176774).
- selftests: devlink_trap_tunnel_vxlan: Add test case for
  decap_error (bsc#1176774).
- mlxsw: Add tunnel devlink-trap support (bsc#1176774).
- mlxsw: spectrum_trap: Reorder cases according to enum order
  (bsc#1176774).
- mlxsw: Add ECN configurations with IPinIP tunnels (bsc#1176774).
- mlxsw: reg: Add Tunneling IPinIP Decapsulation ECN Mapping
  Register (bsc#1176774).
- mlxsw: reg: Add Tunneling IPinIP Encapsulation ECN Mapping
  Register (bsc#1176774).
- mlxsw: Add NON_ROUTABLE trap (bsc#1176774).
- selftests: devlink_trap_l3_drops: Add test cases of irif and
  erif disabled (bsc#1176774).
- mlxsw: Add irif and erif disabled traps (bsc#1176774).
- net/mlx5: E-Switch, Increase number of chains and priorities
  (jsc#SLE-15172).
- net/mlx5: E-Switch, Refactor chains and priorities
  (jsc#SLE-15172).
- net/mlx5: ft: Check prio and chain sanity for ft offload
  (jsc#SLE-15172).
- net/mlx5: ft: Use getter function to get ft chain
  (jsc#SLE-15172).
- netfilter: bitwise: add support for shifts (bsc#1176447).
- netfilter: bitwise: add NFTA_BITWISE_DATA attribute
  (bsc#1176447).
- netfilter: bitwise: only offload boolean operations
  (bsc#1176447).
- netfilter: bitwise: add helper for dumping boolean operations
  (bsc#1176447).
- netfilter: bitwise: add helper for evaluating boolean operations
  (bsc#1176447).
- netfilter: bitwise: add helper for initializing boolean
  operations (bsc#1176447).
- netfilter: bitwise: add NFTA_BITWISE_OP netlink attribute
  (bsc#1176447).
- netfilter: bitwise: replace gotos with returns (bsc#1176447).
- netfilter: bitwise: remove NULL comparisons from attribute
  checks (bsc#1176447).
- netfilter: nf_tables: white-space fixes (bsc#1176447).
- netfilter: flowtable: add nf_flow_table_offload_cmd()
  (bsc#1176447).
- netfilter: flowtable: add nf_flow_offload_tuple() helper
  (bsc#1176447).
- netfilter: hashlimit: do not use indirect calls during gc
  (bsc#1176447).
- netfilter: flowtable: refresh flow if hardware offload fails
  (bsc#1176447).
- netfilter: flowtable: add nf_flowtable_hw_offload() helper
  function (bsc#1176447).
- netfilter: flowtable: use atomic bitwise operations for flow
  flags (bsc#1176447).
- netfilter: flowtable: remove dying bit, use teardown bit instead
  (bsc#1176447).
- netfilter: flowtable: add nf_flow_offload_work_alloc()
  (bsc#1176447).
- netfilter: flowtable: restrict flow dissector match on meta
  ingress device (bsc#1176447).
- netfilter: flowtable: fetch stats only if flow is still alive
  (bsc#1176447).
- Documentation: Fix typo in devlink documentation (bsc#1176774).
- netdevsim: fix nsim_fib6_rt_create() error path (bsc#1176447).
- selftests: mlxsw: Add test for FIB offload API (bsc#1176774).
- netdevsim: fib: Add dummy implementation for FIB offload
  (bsc#1176447).
- mlxsw: spectrum_router: Set hardware flags for routes
  (bsc#1176774).
- mlxsw: spectrum_router: Separate nexthop offload indication
  from route (bsc#1176774).
- ipv6: Add "offload" and "trap" indications to routes
  (bsc#1176774).
- ipv4: Add "offload" and "trap" indications to routes
  (bsc#1176774).
- ipv4: Encapsulate function arguments in a struct (bsc#1176774).
- ipv4: Replace route in list before notifying (bsc#1176774).
- net: netfilter: use skb_list_walk_safe helper for gso segments
  (bsc#1176447).
- net: sched: use skb_list_walk_safe helper for gso segments
  (bsc#1176447).
- net: skbuff: disambiguate argument and member for
  skb_list_walk_safe helper (bsc#1176447).
- devlink: document info versions for each driver (bsc#1176774).
- devlink: mention reloading in devlink-params.rst (bsc#1176447).
- devlink: add documentation for generic devlink parameters
  (bsc#1176447).
- flow_dissector: fix document for skb_flow_get_icmp_tci
  (bsc#1176447).
- mlxsw: spectrum: Only require minimum firmware version
  (bsc#1176774).
- mlxsw: spectrum: Update firmware version to xx.2000.2714
  (bsc#1176774).
- netronome: fix ipv6 link error (bsc#1176447).
- selftests: mlxsw: Add a self-test for port-default priority
  (bsc#1176774).
- netfilter: nft_meta: add support for slave device ifindex
  matching (bsc#1176447).
- netfilter: nft_meta: place rtclassid handling in a helper
  (bsc#1176447).
- netfilter: nft_meta: place prandom handling in a helper
  (bsc#1176447).
- netfilter: nft_meta: move all interface related keys to helper
  (bsc#1176447).
- netfilter: nft_meta: move interface kind handling to helper
  (bsc#1176447).
- netfilter: nft_meta: move cgroup handling to helper
  (bsc#1176447).
- netfilter: nft_meta: move sk uid/git handling to helper
  (bsc#1176447).
- netfilter: nft_meta: move pkttype handling to helper
  (bsc#1176447).
- netfilter: nft_meta: move time handling to helper (bsc#1176447).
- netfilter: conntrack: remove two export symbols (bsc#1176447).
- netfilter: nft_tunnel: add the missing nla_nest_cancel()
  (bsc#1176447).
- netfilter: nft_tunnel: also dump OPTS_ERSPAN/VXLAN
  (bsc#1176447).
- netfilter: nft_tunnel: also dump ERSPAN_VERSION (bsc#1176447).
- netfilter: nft_tunnel: no need to call htons() when dumping
  ports (bsc#1176447).
- netfilter: Document ingress hook (bsc#1176447).
- netfilter: Clean up unnecessary #ifdef (bsc#1176447).
- mlxsw: spectrum_router: Remove FIB entry list from FIB node
  (bsc#1176774).
- mlxsw: spectrum_router: Consolidate identical functions
  (bsc#1176774).
- net: Add a layer for non-PHY MII time stamping drivers
  (bsc#1176447).
- net: Introduce a new MII time stamping interface (bsc#1176447).
- net: phy: dp83640: Move the probe and remove methods around
  (bsc#1176447).
- net: vlan: Use the PHY time stamping interface (bsc#1176447).
- net: macvlan: Use the PHY time stamping interface (bsc#1176447).
- ipv6: Remove old route notifications and convert listeners
  (bsc#1176774).
- mlxsw: spectrum_router: Start using new IPv6 route notifications
  (bsc#1176774).
- ipv6: Handle multipath route deletion notification
  (bsc#1176774).
- ipv6: Handle route deletion notification (bsc#1176774).
- ipv6: Only Replay routes of interest to new listeners
  (bsc#1176774).
- ipv6: Notify multipath route if should be offloaded
  (bsc#1176774).
- ipv6: Notify route if replacing currently offloaded one
  (bsc#1176774).
- ipv6: Notify newly added route if should be offloaded
  (bsc#1176774).
- net: fib_notifier: Add temporary events to the FIB notification
  chain (bsc#1176774).
- nfp: tls: implement the stream sync RX resync (bsc#1176447).
- net/tls: add helper for testing if socket is RX offloaded
  (bsc#1176447).
- nfp: pass packet pointer to nfp_net_parse_meta() (bsc#1176447).
- nfp: flower: update flow merge code to support IPv6 tunnels
  (bsc#1176447).
- nfp: flower: support ipv6 tunnel keep-alive messages from fw
  (bsc#1176447).
- nfp: flower: handle notifiers for ipv6 route changes
  (bsc#1176447).
- nfp: flower: handle ipv6 tunnel no neigh request (bsc#1176447).
- nfp: flower: modify pre-tunnel and set tunnel action for ipv6
  (bsc#1176447).
- nfp: flower: offload list of IPv6 tunnel endpoint addresses
  (bsc#1176447).
- nfp: flower: compile match for IPv6 tunnels (bsc#1176447).
- nfp: flower: move udp tunnel key match compilation to helper
  function (bsc#1176447).
- nfp: flower: pass flow rule pointer directly to match functions
  (bsc#1176447).
- net: sfp: report error on failure to read sfp soft status
  (bsc#1176447).
- net: phy: marvell: use genphy_check_and_restart_aneg()
  (bsc#1176447).
- net: phy: marvell: use phy_modify_changed() (bsc#1176447).
- net: phy: marvell: use existing clause 37 definitions
  (bsc#1176447).
- net: phy: marvell: consolidate phy status reading (bsc#1176447).
- net: phy: marvell: use positive logic for link state
  (bsc#1176447).
- net: phy: marvell: initialise link partner state earlier
  (bsc#1176447).
- net: phy: marvell: rearrange to use genphy_read_lpa()
  (bsc#1176447).
- net: phy: provide and use genphy_read_status_fixed()
  (bsc#1176447).
- net: phy: add genphy_check_and_restart_aneg() (bsc#1176447).
- net: phy: use phy_resolve_aneg_pause() (bsc#1176447).
- net: phy: remove redundant .aneg_done initialisers
  (bsc#1176447).
- selftests: forwarding: sch_ets: Add test coverage for ETS Qdisc
  (bsc#1176774).
- selftests: forwarding: Move start_/stop_traffic from mlxsw to
  lib.sh (bsc#1176774).
- mlxsw: spectrum_qdisc: Support offloading of ETS Qdisc
  (bsc#1176774).
- mlxsw: spectrum_qdisc: Generalize PRIO offload to support ETS
  (bsc#1176774).
- net: sch_ets: Make the ETS qdisc offloadable (bsc#1176774).
- net: phylink: extend clause 45 PHY validation workaround
  (bsc#1176447).
- net: phylink: improve clause 45 PHY ksettings_set implementation
  (bsc#1176447).
- ipv4: Remove old route notifications and convert listeners
  (bsc#1176774).
- ipv4: Only Replay routes of interest to new listeners
  (bsc#1176774).
- ipv4: Handle route deletion notification during flush
  (bsc#1176774).
- ipv4: Handle route deletion notification (bsc#1176774).
- ipv4: Notify newly added route if should be offloaded
  (bsc#1176774).
- ipv4: Notify route if replacing currently offloaded one
  (bsc#1176774).
- ipv4: Extend FIB alias find function (bsc#1176774).
- ipv4: Notify route after insertion to the routing table
  (bsc#1176774).
- net: fib_notifier: Add temporary events to the FIB notification
  chain (bsc#1176774).
- net: phylink: propagate phy_attach_direct() return code
  (bsc#1176447).
- netronome: use the new txqueue timeout argument (bsc#1176447).
- net: sfp: re-attempt probing for phy (bsc#1176447).
- net: sfp: error handling for phy probe (bsc#1176447).
- net: sfp: rename sm_retries (bsc#1176447).
- net: sfp: use a definition for the fault recovery attempts
  (bsc#1176447).
- net: sfp: add support for Clause 45 PHYs (bsc#1176447).
- net: phylink: delay MAC configuration for copper SFP modules
  (bsc#1176447).
- net: phylink: split phylink_sfp_module_insert() (bsc#1176447).
- net: phylink: support Clause 45 PHYs on SFP+ modules
  (bsc#1176447).
- net: phylink: re-split __phylink_connect_phy() (bsc#1176447).
- net: mdio-i2c: add support for Clause 45 accesses (bsc#1176447).
- net: sfp: move phy_start()/phy_stop() to phylink (bsc#1176447).
- net: sfp: add module start/stop upstream notifications
  (bsc#1176447).
- net: sfp: add more extended compliance codes (bsc#1176447).
- net: sfp: derive interface mode from ethtool link modes
  (bsc#1176447).
- net: sfp: remove incomplete 100BASE-FX and 100BASE-LX support
  (bsc#1176447).
- net: sfp: avoid tx-fault with Nokia GPON module (bsc#1176447).
- platform/x86: mlx-platform: Add support for next generation
  systems (bsc#1176774).
- platform/mellanox: mlxreg-hotplug: Add support for new
  capability register (bsc#1176774).
- platform/x86: mlx-platform: Add support for new capability
  register (bsc#1176774).
- platform/x86: mlx-platform: Add support for new system type
  (bsc#1176774).
- platform/x86: mlx-platform: Set system mux configuration based
  on system type (bsc#1176774).
- platform/x86: mlx-platform: Add more definitions for system
  attributes (bsc#1176774).
- platform/x86: mlx-platform: Cosmetic changes (bsc#1176774).
- netfilter: nf_tables_offload: fix check the chain offload flag
  (bsc#1176447).
- netfilter: nf_tables: fix memory leak in
  nf_tables_parse_netdev_hooks() (bsc#1176447).
- selftests: mlxsw: qos_mc_aware: Fix mausezahn invocation
  (bsc#1176774).
- netfilter: flowtable: add nf_flowtable_time_stamp (bsc#1176447).
- netfilter: nf_tables: unbind callbacks from flowtable destroy
  path (bsc#1176447).
- netfilter: nf_flow_table_offload: fix the nat port mangle
  (bsc#1176447).
- netfilter: nf_flow_table_offload: check the status of dst_neigh
  (bsc#1176447).
- netfilter: nf_flow_table_offload: fix incorrect ethernet dst
  address (bsc#1176447).
- netfilter: ebtables: compat: reject all padding in
  matches/watchers (bsc#1176447).
- netfilter: nf_flow_table: fix big-endian integer overflow
  (bsc#1176447).
- netfilter: nf_flow_table_offload: Correct memcpy size for
  flow_overload_mangle() (bsc#1176447).
- netfilter: nf_tables: skip module reference count bump on
  object updates (bsc#1176447).
- netfilter: nf_tables: validate NFT_DATA_VALUE after
  nft_data_init() (bsc#1176447).
- netfilter: nf_tables: validate NFT_SET_ELEM_INTERVAL_END
  (bsc#1176447).
- netfilter: nft_set_rbtree: bogus lookup/get on consecutive
  elements in named sets (bsc#1176447).
- netfilter: nf_tables_offload: Check for the NETDEV_UNREGISTER
  event (bsc#1176447).
- netfilter: nf_flow_table_offload: add IPv6 match description
  (bsc#1176447).
- netfilter: conntrack: tell compiler to not inline
  nf_ct_resolve_clash (bsc#1176447).
- netfilter: nf_flow_table_offload: Don't use offset uninitialized
  in flow_offload_port_{d,s}nat (bsc#1176447).
- netfilter: nf_flow_table_offload: Fix block_cb tc_setup_type
  as TC_SETUP_CLSFLOWER (bsc#1176447).
- netfilter: nf_flow_table_offload: Fix block setup as TC_SETUP_FT
  cmd (bsc#1176447).
- net: sched: allow indirect blocks to bind to clsact in TC
  (bsc#1176447).
- net: core: rename indirect block ingress cb function
  (bsc#1176447).
- nouveau: use mmu_notifier directly for invalidate_range_start
  (jsc#SLE-15176).
- mm/mmu_notifier: add an interval tree notifier (jsc#SLE-15176).
- mm/mmu_notifier: define the header pre-processor parts even
  if disabled (jsc#SLE-15176).
- phy: add PHY_MODE_LVDS (bsc#1176447).
- net: flow_dissector: Wrap unionized VLAN fields in a struct
  (bsc#1176447).
- netfilter: nft_payload: add C-VLAN offload support
  (bsc#1176447).
- netfilter: nft_payload: add VLAN offload support (bsc#1176447).
- netfilter: nf_tables_offload: allow ethernet interface type only
  (bsc#1176447).
- netfilter: nf_tables: constify nft_reg_load{8, 16, 64}()
  (bsc#1176447).
- selftests: mlxsw: Check devlink device before running test
  (bsc#1176774).
- selftests: mlxsw: Add router scale test for Spectrum-2
  (bsc#1176774).
- netfilter: nf_tables: add nft_unregister_flowtable_hook()
  (bsc#1176447).
- netfilter: nf_tables: check if bind callback fails and unbind
  if hook registration fails (bsc#1176447).
- netfilter: nf_tables_offload: undo updates if transaction fails
  (bsc#1176447).
- netfilter: nf_tables_offload: release flow_rule on error from
  commit path (bsc#1176447).
- netfilter: nf_tables_offload: remove reference to flow rule
  from deletion path (bsc#1176447).
- netfilter: nf_flow_table: remove unnecessary parameter in
  flow_offload_fill_dir (bsc#1176447).
- netfilter: nf_flow_table_offload: Fix check ndo_setup_tc when
  setup_block (bsc#1176447).
- netfilter: Support iif matches in POSTROUTING (bsc#1176447).
- netfilter: nf_flow_table_offload: add IPv6 support
  (bsc#1176447).
- netfilter: nf_flow_table_offload: add flow_action_entry_next()
  and use it (bsc#1176447).
- netfilter: nft_meta: use 64-bit time arithmetic (bsc#1176447).
- netfilter: xt_time: use time64_t (bsc#1176447).
- netfilter: ipset: Add wildcard support to net,iface
  (bsc#1176447).
- netfilter: nft_payload: add C-VLAN support (bsc#1176447).
- netfilter: nf_tables_offload: pass extack to
  nft_flow_cls_offload_setup() (bsc#1176447).
- netfilter: nf_tables: add nft_payload_rebuild_vlan_hdr()
  (bsc#1176447).
- netfilter: nft_payload: simplify vlan header handling
  (bsc#1176447).
- netfilter: nft_meta: offload support for interface index
  (bsc#1176447).
- netfilter: nf_flow_table: hardware offload support
  (bsc#1176447).
- netfilter: nf_tables: add flowtable offload control plane
  (bsc#1176447).
- netfilter: nf_flow_table: detach routing information from flow
  description (bsc#1176447).
- netfilter: nf_flowtable: remove flow_offload_entry structure
  (bsc#1176447).
- netfilter: nf_flow_table: remove union from flow_offload
  structure (bsc#1176447).
- netfilter: nf_flow_table: move conntrack object to struct
  flow_offload (bsc#1176447).
- selftests: Add a test of large binary to devlink health test
  (bsc#1176447).
- selftests: mlxsw: Add test cases for devlink-trap layer 3
  exceptions (bsc#1176774).
- selftests: forwarding: devlink: Add functionality for trap
  exceptions test (bsc#1176774).
- selftests: mlxsw: Add test cases for devlink-trap layer 3 drops
  (bsc#1176774).
- selftests: devlink: Make devlink_trap_cleanup() more generic
  (bsc#1176774).
- selftests: devlink: Export functions to devlink library
  (bsc#1176774).
- selftests: devlink: undo changes at the end of resource_test
  (bsc#1176447).
- netfilter: nf_tables_offload: unbind if multi-device binding
  fails (bsc#1176447).
- netfilter: nf_tables_offload: add nft_flow_block_offload_init()
  (bsc#1176447).
- netfilter: nf_tables_offload: add nft_chain_offload_cmd()
  (bsc#1176447).
- netfilter: ecache: don't look for ecache extension on
  dying/unconfirmed conntracks (bsc#1176447).
- netfilter: nf_tables: support for multiple devices per netdev
  hook (bsc#1176447).
- netfilter: nf_tables_offload: remove rules on unregistered
  device only (bsc#1176447).
- netfilter: nf_tables_offload: add nft_flow_cls_offload_setup()
  (bsc#1176447).
- netfilter: nf_tables_offload: Pass callback list to
  nft_setup_cb_call() (bsc#1176447).
- netfilter: nf_tables_offload: add nft_flow_block_chain()
  (bsc#1176447).
- netfilter: nf_tables: increase maximum devices number per
  flowtable (bsc#1176447).
- netfilter: nf_tables: allow netdevice to be used only once
  per flowtable (bsc#1176447).
- netfilter: nf_tables: dynamically allocate hooks per net_device
  in flowtables (bsc#1176447).
- netfilter: nf_flow_table: move priority to struct nf_flowtable
  (bsc#1176447).
- netfilter: nft_tproxy: Fix typo in IPv6 module description
  (bsc#1176447).
- netfilter: add and use nf_hook_slow_list() (bsc#1176447).
- netfilter: conntrack: free extension area immediately
  (bsc#1176447).
- netfilter: ctnetlink: don't dump ct extensions of unconfirmed
  conntracks (bsc#1176447).
- netfilter: ecache: document extension area access rules
  (bsc#1176447).
- netfilter: ipset: move ip_set_get_ip_port() to
  ip_set_bitmap_port.c (bsc#1176447).
- netfilter: ipset: move function to ip_set_bitmap_ip.c
  (bsc#1176447).
- netfilter: ipset: make ip_set_put_flags extern (bsc#1176447).
- netfilter: ipset: move functions to ip_set_core.c (bsc#1176447).
- netfilter: ipset: move ip_set_comment functions from ip_set.h
  to ip_set_core.c (bsc#1176447).
- netfilter: ipset: remove inline from static functions in .c
  files (bsc#1176447).
- selftests: mlxsw: Add Spectrum-2 target scale for tc flower
  scale test (bsc#1176774).
- selftests: mlxsw: Add a resource scale test for Spectrum-2
  (bsc#1176774).
- selftests: mlxsw: Add Spectrum-2 mirror-to-gretap target scale
  test (bsc#1176774).
- selftests: mlxsw: Generalize the parameters of mirror_gre test
  (bsc#1176774).
- selftests: add netdevsim devlink health tests (bsc#1176447).
- selftests: add netdevsim devlink dev info test (bsc#1176447).
- selftests: test netdevsim reload forbid and fail (bsc#1176447).
- selftests: netdevsim: add tests for devlink reload with
  resources (bsc#1176447).
- mlxsw: PCI: Send EMAD traffic on a separate queue (bsc#1176774).
- mlx5: Reject requests to enable time stamping on both edges
  (jsc#SLE-15172).
- dp83640: Reject requests to enable time stamping on both edges
  (bsc#1176447).
- netfilter: nf_tables: fix unexpected EOPNOTSUPP error
  (bsc#1176447).
- netfilter: nf_tables_offload: check for register data length
  mismatches (bsc#1176447).
- mm/mmu_notifiers: use the right return code for WARN_ON
  (jsc#SLE-15176).
- netfilter: nf_tables_offload: restore basechain deletion
  (bsc#1176447).
- net: phy: extract pause mode (bsc#1176447).
- netfilter: drop bridge nf reset from nf_reset (bsc#1176447).
- netfilter: nf_tables: bogus EBUSY when deleting flowtable
  after flush (bsc#1176447).
- netfilter: nf_tables_offload: fix always true policy is unset
  check (bsc#1176447).
- netfilter: nf_tables: add NFT_CHAIN_POLICY_UNSET and use it
  (bsc#1176447).
- net/sched: Set default of CONFIG_NET_TC_SKB_EXT to N
  (bsc#1176447).
- mm, notifier: Catch sleeping/blocking for !blockable
  (jsc#SLE-15176).
- kernel.h: Add non_block_start/end() (jsc#SLE-15176).
- mm/mmu_notifiers: prime lockdep (jsc#SLE-15176).
- mm/mmu_notifiers: add a lockdep map for
  invalidate_range_start/end (jsc#SLE-15176).
- mm/mmu_notifiers: remove the
  __mmu_notifier_invalidate_range_start/end exports
  (jsc#SLE-15176).
- mm/mmu_notifiers: remove unregister_no_release (jsc#SLE-15176).
- mm/mmu_notifiers: check if mmu notifier callbacks are allowed
  to fail (jsc#SLE-15176).
- misc/sgi-gru: use mmu_notifier_get/put for struct gru_mm_struct
  (jsc#SLE-15176).
- mm/hmm: cleanup the hmm_vma_walk_hugetlb_entry stub
  (jsc#SLE-15176).
- mm/hmm: cleanup the hmm_vma_handle_pmd stub (jsc#SLE-15176).
- mm/hmm: only define hmm_vma_walk_pud if needed (jsc#SLE-15176).
- mm/hmm: don't abuse pte_index() in hmm_vma_handle_pmd
  (jsc#SLE-15176).
- mm/hmm: remove the mask variable in hmm_vma_walk_hugetlb_entry
  (jsc#SLE-15176).
- mm/hmm: remove superfluous arguments from hmm_range_register
  (jsc#SLE-15176).
- mm/hmm: remove the unused vma argument to hmm_range_dma_unmap
  (jsc#SLE-15176).
- nouveau: pass struct nouveau_svmm to nouveau_range_fault
  (jsc#SLE-15176).
- mm/hmm: remove hmm_range vma (jsc#SLE-15176).
- mm/hmm: remove hugetlbfs check in hmm_vma_walk_pmd
  (jsc#SLE-15176).
- mm/hmm: merge hmm_range_snapshot into hmm_range_fault
  (jsc#SLE-15176).
- mm/hmm: a few more C style and comment clean ups
  (jsc#SLE-15176).
- mm/hmm: replace hmm_update with mmu_notifier_range
  (jsc#SLE-15176).
- nouveau: return -EBUSY when hmm_range_wait_until_valid fails
  (jsc#SLE-15176).
- net: phy: adin: implement Energy Detect Powerdown mode via
  phy-tunable (bsc#1176447).
- net: mdio: switch to using gpiod_get_optional() (bsc#1176447).
- netfilter: conntrack: remove two unused functions from
  nf_conntrack_timestamp.h (bsc#1176447).
- netfilter: conntrack: remove CONFIG_NF_CONNTRACK checks from
  nf_conntrack_zones.h (bsc#1176447).
- netfilter: conntrack: remove CONFIG_NF_CONNTRACK check from
  nf_conntrack_acct.h (bsc#1176447).
- netfilter: conntrack: move code to linux/nf_conntrack_common.h
  (bsc#1176447).
- netfilter: br_netfilter: update stub br_nf_pre_routing_ipv6
  parameter to `void *priv` (bsc#1176447).
- netfilter: conntrack: wrap two inline functions in config checks
  (bsc#1176447).
- netfilter: replace defined(CONFIG...) ||
  defined(CONFIG...MODULE) with
  IS_ENABLED(CONFIG...) (bsc#1176447).
- netfilter: conntrack: use consistent style when defining inline
  functions (bsc#1176447).
- netfilter: move nf_bridge_frag_data struct definition to a
  more appropriate header (bsc#1176447).
- netfilter: synproxy: move code between headers (bsc#1176447).
- netfilter: move inline nf_ip6_ext_hdr() function to a more
  appropriate header (bsc#1176447).
- netfilter: remove nf_conntrack_icmpv6.h header (bsc#1176447).
- netfilter: inline xt_hashlimit, ebt_802_3 and xt_physdev headers
  (bsc#1176447).
- netfilter: ip_tables: remove unused function declarations
  (bsc#1176447).
- netfilter: fix coding-style errors (bsc#1176447).
- netfilter: fix include guards (bsc#1176447).
- netfilter: nf_tables_offload: remove rules when the device
  unregisters (bsc#1176447).
- netfilter: nf_tables_offload: refactor the nft_flow_offload_rule
  function (bsc#1176447).
- netfilter: nf_tables_offload: add __nft_offload_get_chain
  function (bsc#1176447).
- netfilter: nft_{fwd,dup}_netdev: add offload support
  (bsc#1176447).
- netfilter: nft_synproxy: add synproxy stateful object support
  (bsc#1176447).
- netfilter: nf_tables_offload: move indirect flow_block callback
  logic to core (bsc#1176447).
- netfilter: nf_tables: Fix an Oops in nf_tables_updobj() error
  handling (bsc#1176447).
- netfilter: nf_tables: fix possible null-pointer dereference
  in object update (bsc#1176447).
- netfilter: nft_quota: add quota object update support
  (bsc#1176447).
- netfilter: nf_tables: Introduce stateful object update operation
  (bsc#1176447).
- netfilter: nft_dynset: support for element deletion
  (bsc#1176447).
- netfilter: nfnetlink_log: add support for VLAN information
  (bsc#1176447).
- netfilter: nft_meta: support for time matching (bsc#1176447).
- netfilter: nf_tables: Introduce new 64-bit helper register
  functions (bsc#1176447).
- net: phy: Do not check Link status when loopback is enabled
  (bsc#1176447).
- net: phy: gmii2rgmii: Dont use priv field in phy device
  (bsc#1176447).
- include: mdio: Add driver data helpers (bsc#1176447).
- net: phy: force phy suspend when calling phy_stop (bsc#1176447).
- net: phy: sfp: Add labels to hwmon sensors (bsc#1176447).
- net: dsa: use a single switch statement for port setup
  (bsc#1176447).
- net: phy: realtek: support NBase-T MMD EEE registers on RTL8125
  (bsc#1176447).
- net: phy: add EEE-related constants (bsc#1176447).
- selftests: devlink_trap: Add test cases for devlink-trap
  (bsc#1176774).
- selftests: forwarding: devlink_lib: Add devlink-trap helpers
  (bsc#1176774).
- selftests: forwarding: devlink_lib: Allow tests to define
  devlink device (bsc#1176774).
- net: phy: remove genphy_config_init (bsc#1176447).
- net: dsa: remove calls to genphy_config_init (bsc#1176447).
- net: phy: remove calls to genphy_config_init (bsc#1176447).
- net: phy: adin: add ethtool get_stats support (bsc#1176447).
- net: phy: adin: implement downshift configuration via
  phy-tunable (bsc#1176447).
- net: phy: adin: implement PHY subsystem software reset
  (bsc#1176447).
- net: phy: adin: add EEE translation layer from Clause 45 to
  Clause 22 (bsc#1176447).
- net: phy: adin: add support MDI/MDIX/Auto-MDI selection
  (bsc#1176447).
- net: phy: adin: make RMII fifo depth configurable (bsc#1176447).
- net: phy: adin: make RGMII internal delays configurable
  (bsc#1176447).
- net: phy: adin: configure RGMII/RMII/MII modes on config
  (bsc#1176447).
- net: phy: adin: add {write,read}_mmd hooks (bsc#1176447).
- net: phy: adin: add support for interrupts (bsc#1176447).
- net: phy: adin: hook genphy_{suspend, resume} into the driver
  (bsc#1176447).
- selftests: netdevsim: add devlink regions tests (bsc#1176447).
- selftests: netdevsim: add devlink params tests (bsc#1176447).
- net: phy: realtek: add support for EEE registers on integrated
  PHY's (bsc#1176447).
- net: phy: swphy: emulate register MII_ESTATUS (bsc#1176447).
- net: phy: read MII_CTRL1000 in genphy_read_status only if needed
  (bsc#1176447).
- netfilter: nft_bitwise: Adjust parentheses to fix memcmp size
  argument (bsc#1176447).
- net: phy: realtek: add NBase-T PHY auto-detection (bsc#1176447).
- netfilter: nf_nat_proto: make tables static (bsc#1176447).
- netfilter: nf_tables: add missing prototypes (bsc#1176447).
- netfilter: add missing IS_ENABLED(CONFIG_NF_CONNTRACK) checks
  to some header-files (bsc#1176447).
- netfilter: add missing IS_ENABLED(CONFIG_BRIDGE_NETFILTER)
  checks to header-file (bsc#1176447).
- netfilter: add missing includes to a number of header-files
  (bsc#1176447).
- netfilter: nf_tables: store data in offload context registers
  (bsc#1176447).
- netfilter: nft_bitwise: add offload support (bsc#1176447).
- netfilter: remove unnecessary spaces (bsc#1176447).
- netfilter: conntrack: use shared sysctl constants (bsc#1176447).
- netfilter: synproxy: rename mss synproxy_options field
  (bsc#1176447).
- net: phy: let phy_speed_down/up support speeds >1Gbps
  (bsc#1176447).
- net: phy: add phy_speed_down_core and phy_resolve_min_speed
  (bsc#1176447).
- net: phy: add __set_linkmode_max_speed (bsc#1176447).
- net: phy: realtek: add support for the 2.5Gbps PHY in RTL8125
  (bsc#1176447).
- net: phy: add phy_modify_paged_changed (bsc#1176447).
- net: phy: simplify genphy_config_advert by using the
  linkmode_adv_to_xxx_t functions (bsc#1176447).
- netfilter: nf_tables_offload: support indr block call
  (bsc#1176447).
- net: mdio-octeon: Fix Kconfig warnings and build errors
  (bsc#1176447).
- net: phy: Add mdio-aspeed (bsc#1176447).
- rcu: Add support for consolidated-RCU reader checking
  (bsc#1176447).
- rcu: Remove redundant debug_locks check in
  rcu_read_lock_sched_held() (bsc#1176447).
- commit 939bd7b
* Thu Sep 24 2020 msuchanek@suse.de
- sysfs: Fixes __BIN_ATTR_WO() macro (bsc#1176918 ltc#186474
  jsc#SLE-13644).
- sysfs: add BIN_ATTR_WO() macro (bsc#1176918 ltc#186474
  jsc#SLE-13644).
- commit 7135a4e
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: do not init a reloc root if we aren't relocating
  (bsc#1176019).
- commit c5afb94
* Thu Sep 24 2020 ggherdovich@suse.cz
- x86, sched: Bail out of frequency invariance if
  turbo_freq/base_freq gives 0 (bsc#1176925).
- commit a66109f
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: reloc: clean dirty subvols if we fail to start a
  transaction (bsc#1176019).
- btrfs: unset reloc control if we fail to recover (bsc#1176019).
- commit 30d2800
* Thu Sep 24 2020 msuchanek@suse.de
- Enable IMA_ARCH_POLICY on ppc64le (bsc#1176918 ltc#186474 jsc#SLE-13644).
- commit 355c4c4
* Thu Sep 24 2020 ggherdovich@suse.cz
- x86, sched: Bail out of frequency invariance if turbo frequency
  is unknown (bsc#1176925).
- commit 53cd83a
* Thu Sep 24 2020 ggherdovich@suse.cz
- x86, sched: check for counters overflow in frequency invariant
  accounting (bsc#1176925).
- commit 863fd4c
* Thu Sep 24 2020 msuchanek@suse.de
- ima: add a new CONFIG for loading arch-specific policies
  (bsc#1176918 ltc#186474 jsc#SLE-13644).
- powerpc: expose secure variables to userspace via sysfs
  (bsc#1176918 ltc#186474 jsc#SLE-13644).
- powerpc/powernv: Add OPAL API interface to access secure
  variable (bsc#1176918 ltc#186474 jsc#SLE-13644).
- commit 137b3e6
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: drop block from cache on error in relocation
  (bsc#1176019).
- commit 40126ae
* Thu Sep 24 2020 msuchanek@suse.de
- Enable LSM on ppc64le (bsc#1176918 ltc#186474 jsc#SLE-13644).
- commit ab0ed63
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7663u: fix memory leaks in mt7663u_probe
  (jsc#SLE-13430).
- Refresh
  patches.suse/mt76-move-mt76-workqueue-in-common-code.patch.
- Refresh
  patches.suse/mt76-mt7615-introduce-mt7663-usb-sdio-common-module.patch.
- commit e278f3c
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7915: use ieee80211_free_txskb to free tx skbs
  (jsc#SLE-13430).
- mt76: mt7615: use v1 MCU API on MT7615 to fix issues with
  adding/removing stations (jsc#SLE-13430).
- mt76: mt7615: fix EEPROM buffer size (jsc#SLE-13430).
- mt76: mt76x02: do not access uninitialized NAPI structs
  (jsc#SLE-13430).
- commit c283b5f
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: introduce mt7663s support (jsc#SLE-13430).
- Update config files.
- supported.conf: add new entry
- commit 7f2059b
* Thu Sep 24 2020 tiwai@suse.de
- mt7601u: add missing release on skb in mt7601u_mcu_msg_send
  (jsc#SLE-13430).
- mt76: mt76u: add missing release on skb in
  __mt76x02u_mcu_send_msg (jsc#SLE-13430).
- mt76: mt7615: fix possible memory leak in
  mt7615_mcu_wtbl_sta_add (jsc#SLE-13430).
- mt76: mt7915: fix potential memory leak in mcu message handler
  (jsc#SLE-13430).
- mt76: mt76s: move queue accounting in mt76s_tx_queue_skb
  (jsc#SLE-13430).
- mt76: introduce mt76_sdio module (jsc#SLE-13430).
- mt76: mt7615: introduce mt7663-usb-sdio-common module
  (jsc#SLE-13430).
- mt76: mt7615: sdio code must access rate/key regs in preocess
  context (jsc#SLE-13430).
- mt76: mt76u: add mt76_skb_adjust_pad utility routine
  (jsc#SLE-13430).
- mt76: mt7615: take into account sdio bus configuring txwi
  (jsc#SLE-13430).
- mt76: mt7915: add missing CONFIG_MAC80211_DEBUGFS
  (jsc#SLE-13430).
- mt76: mt7915: potential array overflow in
  mt7915_mcu_tx_rate_report() (jsc#SLE-13430).
- mt76: mt7615: fix potential memory leak in mcu message handler
  (jsc#SLE-13430).
- mt76: mt7663u: fix potential memory leak in mcu message handler
  (jsc#SLE-13430).
- mt76: mt7663u: fix memory leak in set key (jsc#SLE-13430).
- mt76: mt7615: reschedule ps work according to last activity
  (jsc#SLE-13430).
- mt76: mt7615: avoid scheduling runtime-pm during hw scan
  (jsc#SLE-13430).
- commit 467cddb
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7663u: sync probe sampling with rate configuration
  (jsc#SLE-13430).
- mt76: mt7615: improve mt7615_driver_own reliability
  (jsc#SLE-13430).
- mt76: mt7615: add idle-timeout knob in mt7615 debugfs
  (jsc#SLE-13430).
- mt76: mt7615: enable beacon hw filter for runtime-pm
  (jsc#SLE-13430).
- mt76: mt7615: add runtime-pm knob in mt7615 debugfs
  (jsc#SLE-13430).
- mt76: mt7615: do not request {driver,fw}_own if already granted
  (jsc#SLE-13430).
- mt76: mt7615: check MT76_STATE_PM flag before accessing the
  device (jsc#SLE-13430).
- mt76: mt7615: run mt7615_pm_wake in mt7615_mac_sta_{add,remove}
  (jsc#SLE-13430).
- mt76: mt7615: wake device before pushing frames in mt7615_tx
  (jsc#SLE-13430).
- mt76: mt7615: wake device before pulling packets from mac80211
  queues (jsc#SLE-13430).
- mt76: mt7615: run mt7615_mcu_set_roc holding mt76 mutex
  (jsc#SLE-13430).
- mt76: mt7615: run mt7615_mcu_set_wmm holding mt76 mutex
  (jsc#SLE-13430).
- mt76: mt7615: add missing lock in mt7615_regd_notifier
  (jsc#SLE-13430).
- mt76: mt7615: wake device before performing freq scan
  (jsc#SLE-13430).
- mt76: mt7615: acquire driver_own before configuring device
  for suspend (jsc#SLE-13430).
- mt76: mt7615: wake device in mt7615_update_channel before
  access regmap (jsc#SLE-13430).
- mt76: mt7615: introduce pm_power_save delayed work
  (jsc#SLE-13430).
- mt76: mt7615: wake device before configuring hw keys
  (jsc#SLE-13430).
- mt76: mt7615: wake device before accessing regmap in debugfs
  (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_mutex_{acquire,release} utilities
  (jsc#SLE-13430).
- mt76: mt7615: add mt7615_pm_wake utility routine
  (jsc#SLE-13430).
- mt76: move mt76 workqueue in common code (jsc#SLE-13430).
- mt76: mt7615: avoid polling in fw_own for mt7663
  (jsc#SLE-13430).
- mt76: mt7915: avoid memcpy in rxv operation (jsc#SLE-13430).
- mt76: mt76x2u: enable HC-M7662BU1 (jsc#SLE-13430).
- mt76: mt76x2: fix pci suspend/resume on mt7612e (jsc#SLE-13430).
- mt76: mt7915: update HE capabilities (jsc#SLE-13430).
- mt76: mt7615: implement testmode support (jsc#SLE-13430).
- mt76: add API for testmode support (jsc#SLE-13430).
- mt76: vif_mask to struct mt76_phy (jsc#SLE-13430).
- commit 3cd654e
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: use full on-chip memory address for WF_PHY
  registers (jsc#SLE-13430).
- mt76: mt7615: add support for accessing RF registers via MCU
  (jsc#SLE-13430).
- mt76: mt7615: add support for accessing mapped registers via
  bus ops (jsc#SLE-13430).
- mt76: mt7615: schedule tx tasklet and sta poll on mac tx free
  (jsc#SLE-13430).
- mt76: mt76x2e: rename routines in pci.c (jsc#SLE-13430).
- mt76: mt7915: overwrite qid for non-bufferable mgmt frames
  (jsc#SLE-13430).
- mt76: mt7915: use ieee80211_tx_queue_params to avoid open coded
  (jsc#SLE-13430).
- mt76: mt7915: add MU-MIMO support (jsc#SLE-13430).
- mt76: mt7915: add a fixed AC queue mapping (jsc#SLE-13430).
- mt76: mt7615: add .set_tsf callback (jsc#SLE-13430).
- mt76: add U-APSD support on AP side (jsc#SLE-13430).
- mt76: rely on register macros (jsc#SLE-13430).
- mt76: fix include in pci.h (jsc#SLE-13430).
- mt76: allow more channels, allowed in ETSI domain
  (jsc#SLE-13430).
- mt76: mt7615: fix up typo in Kconfig for MT7663U
  (jsc#SLE-13430).
- mt76: mt7663: introduce ARP filter offload (jsc#SLE-13430).
- mt76: usb: rely on mt76_for_each_q_rx (jsc#SLE-13430).
- mt76: mt7615: re-enable offloading of sequence number assignment
  (jsc#SLE-13430).
- mt76: overwrite qid for non-bufferable mgmt frames
  (jsc#SLE-13430).
- mt76: mt7615: fix hw queue mapping (jsc#SLE-13430).
- commit 527edf9
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: fix lmac queue debugsfs entry (jsc#SLE-13430).
- mt76: add missing lock configuring coverage class
  (jsc#SLE-13430).
- mt76: mt7915: remove set but not used variable 'msta'
  (jsc#SLE-13430).
- mt76: mt7615: Use kmemdup in mt7615_queue_key_update()
  (jsc#SLE-13430).
- mt76: only iterate over initialized rx queues (jsc#SLE-13430).
- mt76: mt7615: add support for MT7611N (jsc#SLE-13430).
- mt76: fix wcid allocation issues (jsc#SLE-13430).
- mt76: mt7915: fix possible NULL pointer dereference in
  mt7915_register_ext_phy (jsc#SLE-13430).
- mt76: mt7615: fix hw_scan with ssid_type for specified SSID only
  (jsc#SLE-13430).
- mt76: mt7915: fix a handful of spelling mistakes
  (jsc#SLE-13430).
- mt76: mt7615: switch to per-vif power_save support
  (jsc#SLE-13430).
- mt76: mt7915: fix some sparse warnings (jsc#SLE-13430).
- mt76: fix per-driver wcid range checks after wcid array size
  bump (jsc#SLE-13430).
- mt76: mt7915: fix decoded radiotap HE flags (jsc#SLE-13430).
- mt76: mt7615: fix NULL pointer deref in mt7615_register_ext_phy
  (jsc#SLE-13430).
- mt76: mt7915: fix sparse warnings: incorrect type initializer
  (jsc#SLE-13430).
- mt76: mt7915: fix some sparse warnings (jsc#SLE-13430).
- mt76: mt7915: add spatial reuse support (jsc#SLE-13430).
- mt76: mt76x02: remove check in mt76x02_mcu_msg_send
  (jsc#SLE-13430).
- commit fb5ef3d
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: introduce remain_on_channel support
  (jsc#SLE-13430).
- mt76: mt7915: Fix build error (jsc#SLE-13430).
- mt76: mt7615: fix typo defining ps work (jsc#SLE-13430).
- mt76: mt7615: configure bss info adding the interface
  (jsc#SLE-13430).
- mt76: enable p2p support (jsc#SLE-13430).
- mt76: mt7615: reduce hw scan timeout (jsc#SLE-13430).
- mt76: mt7615: do not report scan_complete twice to mac80211
  (jsc#SLE-13430).
- mt76: mt7663: fix the usage WoW with net detect support
  (jsc#SLE-13430).
- mt76: mt7915: fix possible deadlock in mt7915_stop
  (jsc#SLE-13430).
- mt76: mt7915: allocate proper size for tlv tags (jsc#SLE-13430).
- mt76: mt7915: add debugfs to track TxBF status (jsc#SLE-13430).
- mt76: mt7915: add TxBF capabilities (jsc#SLE-13430).
- mt76: mt7915: add Tx beamformee support (jsc#SLE-13430).
- mt76: mt7915: add Tx beamformer support (jsc#SLE-13430).
- mt76: mt7915: introduce mt7915_get_he_phy_cap (jsc#SLE-13430).
- mt76: mt7615: usb: cancel ps work stopping the vif
  (jsc#SLE-13430).
- mt76: mt7663u: add missing register definitions (jsc#SLE-13430).
- mt76: mt7663u: copy key pointer in mt7663u_mac_write_txwi
  (jsc#SLE-13430).
- mt76: set runtime stream caps by mt76_phy (jsc#SLE-13430).
- mt76: mt7915: enable firmware module debug support
  (jsc#SLE-13430).
- mt76: mt7915: add tsf related callbacks (jsc#SLE-13430).
- mt76: mt7915: set peer Tx fixed rate through debugfs
  (jsc#SLE-13430).
- mt76: mt7915: add .sta_statistics support (jsc#SLE-13430).
- mt76: mt7915: add .sta_add_debugfs support (jsc#SLE-13430).
- mt76: mt7915: add Rx radiotap header support (jsc#SLE-13430).
- mt76: mt7915: add HE capabilities support for peers
  (jsc#SLE-13430).
- mt76: mt7915: add HE bss_conf support for interfaces
  (jsc#SLE-13430).
- mt76: mt7915: register per-phy HE capabilities for each
  interface (jsc#SLE-13430).
- mt76: mt7915: implement HE per-rate tx power support
  (jsc#SLE-13430).
- mt76: mt7915: enable Rx HE rate reporting (jsc#SLE-13430).
- commit 92422e8
* Thu Sep 24 2020 tiwai@suse.de
- mt76: add mac80211 driver for MT7915 PCIe-based chipsets
  (jsc#SLE-13430).
- Update config files.
- supported.conf: add mt7915e
- commit 03a77f1
* Thu Sep 24 2020 tiwai@suse.de
- mt76: add HE phy modes and hardware queue (jsc#SLE-13430).
- mt76: adjust wcid size to support new 802.11ax generation
  (jsc#SLE-13430).
- mt76: add Rx stats support for radiotap (jsc#SLE-13430).
- mt76: add support for HE RX rate reporting (jsc#SLE-13430).
- mt76: avoid rx reorder buffer overflow (jsc#SLE-13430).
- mt76: mt7615: scan all channels if not specified
  (jsc#SLE-13430).
- mt76: mt7663: add support to sched scan with randomise addr
  (jsc#SLE-13430).
- mt76: mt7663: introduce WoW with net detect support
  (jsc#SLE-13430).
- mt76: mt7615: fix delta tx power for mt7663 (jsc#SLE-13430).
- mt76: mt7663: fix target power parsing (jsc#SLE-13430).
- mt76: mt7615: fix ibss mode for mt7663 (jsc#SLE-13430).
- mt76: mt7615: check return value of
  mt7615_eeprom_get_power_index (jsc#SLE-13430).
- mt76: mt7663: read tx streams from eeprom (jsc#SLE-13430).
- mt76: mt7615: introduce beacon_loss mcu event (jsc#SLE-13430).
- mt76: mt7615: add gtk rekey offload support (jsc#SLE-13430).
- mt76: mt7615: introduce PM support (jsc#SLE-13430).
- mt76: mt7663u: introduce suspend/resume to mt7663u
  (jsc#SLE-13430).
- mt76: mt7615: add WoW support (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_mcu_set_hif_suspend mcu command
  (jsc#SLE-13430).
- mt76: mt7615: introduce support for hardware beacon filter
  (jsc#SLE-13430).
- mt76: mt7615: free pci_vector if mt7615_pci_probe fails
  (jsc#SLE-13430).
- mt76: mt7615: add passive mode for hw scan (jsc#SLE-13430).
- mt76: mt7615: do not mark sched_scan disabled in
  mt7615_scan_work (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_check_offload_capability routine
  (jsc#SLE-13430).
- mt76: mt7615: fix ssid configuration in mt7615_mcu_hw_scan
  (jsc#SLE-13430).
- mt76: mt7603: remove duplicate error message (jsc#SLE-13430).
- mt76: mt7615: fix getting maximum tx power from eeprom
  (jsc#SLE-13430).
- mt76: mt7615: set spatial extension index (jsc#SLE-13430).
- mt76: mt7663: remove check in mt7663_load_n9 (jsc#SLE-13430).
- commit d9d7b7b
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7663: add the possibility to load firmware v2
  (jsc#SLE-13430).
- mt76: mt76x0: enable MCS 8 and MCS9 (jsc#SLE-13430).
- mt76: mt7615: fix event report in mt7615_mcu_bss_event
  (jsc#SLE-13430).
- mt76: mt7615: add sta pointer to mt7615_mcu_add_bss_info
  signature (jsc#SLE-13430).
- mt76: mt7663: fix up BMC entry indicated to unicmd firmware
  (jsc#SLE-13430).
- mt76: enable TDLS support (jsc#SLE-13430).
- mt76: mt7615: move mcu bss upload before creating the sta
  (jsc#SLE-13430).
- mt76: mt7603: fix tx status rate index calculation
  (jsc#SLE-13430).
- mt76: mt7615: fix tx status rate index calculation
  (jsc#SLE-13430).
- mt76: mt7615: do not adjust MAC timings if the device is not
  running (jsc#SLE-13430).
- mt76: mt7615: adjust timing in mt7615_mac_set_timing to match
  fw/hw values (jsc#SLE-13430).
- mt76: mt7603: never use an 802.11b CF-End rate on 5GHz
  (jsc#SLE-13430).
- mt76: mt7615: never use an 802.11b CF-End rate on 5GHz
  (jsc#SLE-13430).
- mt76: mt7615: use larger rx buffers if VHT is supported
  (jsc#SLE-13430).
- mt76: fix A-MPDU density handling (jsc#SLE-13430).
- mt76: mt7615: fix sta ampdu factor for VHT (jsc#SLE-13430).
- mt76: mt7663u: enable AirTimeFairness (jsc#SLE-13430).
- mt76: mt7615: rework mt7615_mac_sta_poll for usb code
  (jsc#SLE-13430).
- mt76: mt7615: fix aid configuration in
  mt7615_mcu_wtbl_generic_tlv (jsc#SLE-13430).
- mt76: mt7615: fix mt7615_driver_own routine (jsc#SLE-13430).
- mt76: mt7615: fix max wtbl size for 7663 (jsc#SLE-13430).
- mt76: mt7615: fix mt7615_firmware_own for mt7663e
  (jsc#SLE-13430).
- mt76: mt7615: parse mcu return code for unified commands
  (jsc#SLE-13430).
- mt76: add rx queues info to mt76 debugfs (jsc#SLE-13430).
- mt76: mt7615: make Kconfig entry obvious for MT7663E
  (jsc#SLE-13430).
- mt76: mt7663: introduce 802.11 PS support in sta mode
  (jsc#SLE-13430).
- mt76: remove PS_NULLFUNC_STACK capability (jsc#SLE-13430).
- mt76: mt7615: provide aid info to the mcu (jsc#SLE-13430).
- mt76: mt7615: disable aspm by default (jsc#SLE-13430).
- mt76: mt7615: enable scs for mt7663 driver (jsc#SLE-13430).
- commit d27806d
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: introduce mt7663u support (jsc#SLE-13430).
- Update config files.
- supported.conf: explicitly list mediatek modules
- commit 2e0b521
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: move core shared code in mt7615-common module
  (jsc#SLE-13430).
- mt76: mt7615: fix possible deadlock in mt7615_stop
  (jsc#SLE-13430).
- mt76: remove unnecessary annotations (jsc#SLE-13430).
- mt76: mt7615: enable MSI by default (jsc#SLE-13430).
- mt76: mt7615: rework IRQ handling to prepare for MSI support
  (jsc#SLE-13430).
- mt76: mt7663: fix DMA unmap length (jsc#SLE-13430).
- mt76: mt7622: fix DMA unmap length (jsc#SLE-13430).
- mt76: mt7615: set hw scan limits only for firmware with offload
  support (jsc#SLE-13430).
- mt76: mt7615: disable hw/sched scan ops for non-offload firmware
  (jsc#SLE-13430).
- mt76: mt7663: fix aggr range entry in debugfs (jsc#SLE-13430).
- mt76: mt7615: fix possible division by 0 in
  mt7615_mac_update_mib_stats (jsc#SLE-13430).
- mt76: mt76x2: disable merge of OTP ROM data by default
  (jsc#SLE-13430).
- mt76: mt7603: disable merge of OTP ROM data by default
  (jsc#SLE-13430).
- mt76: mt7615: add support for applying tx DPD calibration from
  EEPROM (jsc#SLE-13430).
- mt76: mt7615: add support for applying DC offset calibration
  from EEPROM (jsc#SLE-13430).
- mt76: mt7615: disable merge of OTP ROM data by default
  (jsc#SLE-13430).
- mt76: mt7615: Delete an error message in mt7622_wmac_probe()
  (jsc#SLE-13430).
- mt76: mt7615: do not always reset the dfs state setting the
  channel (jsc#SLE-13430).
- mt76: mt7663: correct the name of the rom patch (jsc#SLE-13430).
- mt76: mt7615: add address parameter to mt7615_eeprom_init
  (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_wtbl_desc data structure
  (jsc#SLE-13430).
- mt76: mt7615: rework wtbl key configuration (jsc#SLE-13430).
- mt76: mt76u: rely on mt7622 queue scheme for mt7663u
  (jsc#SLE-13430).
- mt76: mt7615: move mt7615_mac_wtbl_addr in mac.h
  (jsc#SLE-13430).
- mt76: mt7615: introduce __mt7663_load_firmware routine
  (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_mac_update_rate_desc routine
  (jsc#SLE-13430).
- mt76: mt7615: introduce mt7663u support to mt7615_write_txwi
  (jsc#SLE-13430).
- mt76: add headroom and tailroom to mt76_mcu_ops data structure
  (jsc#SLE-13430).
- mt76: mt7615: remove unnecessary register operations
  (jsc#SLE-13430).
- mt76: mt7615: introduce rlm tlv in bss_info mcu command
  (jsc#SLE-13430).
- mt76: mt7615: introduce BSS absence event (jsc#SLE-13430).
- mt76: mt7615: introduce scheduled scan support (jsc#SLE-13430).
- mt76: mt7615: introduce hw scan support (jsc#SLE-13430).
- mt76: mt7663: keep Rx filters as the default (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_mcu_set_channel_domain mcu
  command (jsc#SLE-13430).
- mt76: mt7615: add ethool support to mt7663 driver
  (jsc#SLE-13430).
- mt76: mt7663: disable RDD commands (jsc#SLE-13430).
- mt76: mt7615: make scs configurable per phy (jsc#SLE-13430).
- mt76: mt7663: enable nf estimation (jsc#SLE-13430).
- commit 80c029e
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7663: fix mt7615_mac_cca_stats_reset routine
  (jsc#SLE-13430).
- mt76: mt7615: add more useful Tx mib counters (jsc#SLE-13430).
- mt76: mt7615: cleanup mib related defines and structs
  (jsc#SLE-13430).
- mt76: mt7615: enable aggr_stats for both phy (jsc#SLE-13430).
- mt76: mt7615: modify mt7615_ampdu_stat_read for each phy
  (jsc#SLE-13430).
- mt76: mt76x0: pci: add mt7610 PCI ID (jsc#SLE-13430).
- mt76: mt76x2u: introduce Mercury UD13 support (jsc#SLE-13430).
- mt76: mt76x02: fix handling MCU timeouts during hw restart
  (jsc#SLE-13430).
- mt76: mt7615: add missing declaration in mt7615.h
  (jsc#SLE-13430).
- mt76: mt7615: fix endianness in unified command (jsc#SLE-13430).
- mt76: mt7615: fix mt7663e firmware struct endianness
  (jsc#SLE-13430).
- mt76: mt7615: introduce mt7663e support (jsc#SLE-13430).
- mt76: mt7615: get rid of sta_rec_wtbl data structure
  (jsc#SLE-13430).
- mt76: mt7615: introduce set_ba uni command (jsc#SLE-13430).
- mt76: mt7615: add more uni mcu commands (jsc#SLE-13430).
- mt76: mt7615: introduce set_bmc and st_sta for uni commands
  (jsc#SLE-13430).
- mt76: mt7615: introduce uni cmd command types (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_init_mac_chain routine
  (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_eeprom_parse_hw_band_cap routine
  (jsc#SLE-13430).
- mt76: mt7615: add mt7663e support to mt7615_mcu_set_eeprom
  (jsc#SLE-13430).
- mt76: mt7615: add mt7663e support to
  mt7615_{driver,firmware}_own (jsc#SLE-13430).
- mt76: mt7615: add mt7663e support to mt7615_reg_map
  (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_register_map (jsc#SLE-13430).
- mt76: mt7615: introduce MCU_FW_PREFIX for fw mcu commands
  (jsc#SLE-13430).
- mt76: mt7615: move more mcu commands in mt7615_mcu_ops data
  structure (jsc#SLE-13430).
- mt76: mt7615: rework mt7615_mcu_set_bss_info using skb APIs
  (jsc#SLE-13430).
- mt76: mt7615: rely on skb API for mt7615_mcu_set_eeprom
  (jsc#SLE-13430).
- mt76: mt7615: move mt7615_mcu_set_sta in mt7615_mcu_ops
  (jsc#SLE-13430).
- mt76: mt7615: move mt7615_mcu_set_bmc to mt7615_mcu_ops
  (jsc#SLE-13430).
- mt76: mt7615: add mt7615_mcu_ops data structure (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_mcu_send_message routine
  (jsc#SLE-13430).
- mt76: always init to 0 mcu messages (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_init_device routine
  (jsc#SLE-13430).
- mt76: mt7615: cleanup fw queue just for mmio devices
  (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_mcu_wait_response
  (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_mcu_fill_msg (jsc#SLE-13430).
- mt76: mt7615: remove a stray if statement (jsc#SLE-13430).
- mt76: mt76x02: reset MCU timeout counter earlier in watchdog
  reset (jsc#SLE-13430).
- mt76: mt7615: fix monitor injection of beacon frames
  (jsc#SLE-13430).
- mt76: mt7603: make dynamic sensitivity adjustment configurable
  via debugfs (jsc#SLE-13430).
- commit da63c9b
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7603: add upper limit for dynamic sensitivity minimum
  receive power (jsc#SLE-13430).
- mt76: mt7615: fix antenna mask initialization in DBDC mode
  (jsc#SLE-13430).
- mt76: mt76u: rely only on data buffer for usb control messagges
  (jsc#SLE-13430).
- mt76: mt76u: fix a possible memory leak in mt76u_init
  (jsc#SLE-13430).
- mt76: mt76u: loop over all possible rx queues in
  mt76u_rx_tasklet (jsc#SLE-13430).
- mt76: Introduce mt76_mcu data structure (jsc#SLE-13430).
- mt76: mt7615: remove rx_mask in mt7615_eeprom_parse_hw_cap
  (jsc#SLE-13430).
- mt76: mt76u: rename stat_wq in wq (jsc#SLE-13430).
- mt76: mt76u: extend RX scatter gather number (jsc#SLE-13430).
- mt76: mt7615: rely on mt76_queues_read for mt7622
  (jsc#SLE-13430).
- mt76: do not set HOST_BROADCAST_PS_BUFFERING for mt7615
  (jsc#SLE-13430).
- mt76: mt7615: rework rx phy index handling (jsc#SLE-13430).
- mt76: fix rounding issues on converting per-chain and combined
  txpower (jsc#SLE-13430).
- mt76: mt76x2: avoid starting the MAC too early (jsc#SLE-13430).
- mt76: avoid extra RCU synchronization on station removal
  (jsc#SLE-13430).
- mt76: mt7615: fix monitor mode on second PHY (jsc#SLE-13430).
- mt76: mt7615: fix adding active monitor interfaces
  (jsc#SLE-13430).
- mt76: mt7615: switch mt7615_mcu_set_rx_ba to v2 format
  (jsc#SLE-13430).
- mt76: mt7615: switch mt7615_mcu_set_tx_ba to v2 format
  (jsc#SLE-13430).
- mt76: mt7615: use new tag sta_rec_wtbl (jsc#SLE-13430).
- mt76: mt7615: add starec operating flow for firmware v2
  (jsc#SLE-13430).
- mt76: mt7615: add a helper to encapsulate sta_rec operation
  (jsc#SLE-13430).
- mt76: mt7615: simplify mcu_set_sta flow (jsc#SLE-13430).
- mt76: mt7615: simplify mcu_set_bmc flow (jsc#SLE-13430).
- mt76: mt7615: add support for testing hardware reset
  (jsc#SLE-13430).
- mt76: mt7615: implement hardware reset support (jsc#SLE-13430).
- mt76: mt7615: report firmware log event messages
  (jsc#SLE-13430).
- mt76: mt7615: fix and rework tx power handling (jsc#SLE-13430).
- mt76: mt7615: add Kconfig entry for MT7622 (jsc#SLE-13430).
- mt76: mt7615: disable DBDC on MT7622 (jsc#SLE-13430).
- commit b5cd043
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: decrease rx ring size for MT7622 (jsc#SLE-13430).
- mt76: mt7615: implement DMA support for MT7622 (jsc#SLE-13430).
- mt76: mt7615: implement probing and firmware loading on MT7622
  (jsc#SLE-13430).
- mt76: mt7615: disable 5 GHz on MT7622 (jsc#SLE-13430).
- mt76: mt7615: add calibration free support for MT7622
  (jsc#SLE-13430).
- mt76: mt7615: add eeprom support for MT7622 (jsc#SLE-13430).
- mt76: mt7615: add dma and tx queue initialization for MT7622
  (jsc#SLE-13430).
- mt76: mt7615: fix MT_INT_TX_DONE_ALL definition for MT7622
  (jsc#SLE-13430).
- mt76: mt7615: store N9 firmware version instead of CR4
  (jsc#SLE-13430).
- mt76: mt7615: split up firmware loading functions
  (jsc#SLE-13430).
- mt76: mt7615: move mmio related code from pci.c to mmio.c
  (jsc#SLE-13430).
- mt76: mt7615: add __aligned(4) to txp structs (jsc#SLE-13430).
- mt76: enable Airtime Queue Limit support (jsc#SLE-13430).
- mt76: mt7603: increase dma mcu rx ring size (jsc#SLE-13430).
- mt76: dma: do not write cpu_idx on rx queue reset until after
  refill (jsc#SLE-13430).
- mt76: fix handling full tx queues in mt76_dma_tx_queue_skb_raw
  (jsc#SLE-13430).
- mt76: set dma-done flag for flushed descriptors (jsc#SLE-13430).
- mt76: mt76u: introduce MT_DRV_RX_DMA_HDR flag (jsc#SLE-13430).
- mt76: mt76u: add endpoint to mt76u_bulk_msg signature
  (jsc#SLE-13430).
- mt76: mt76u: introduce mt76u_skb_dma_info routine
  (jsc#SLE-13430).
- mt76: mt76u: take into account different queue mapping for 7663
  (jsc#SLE-13430).
- mt76: mt76u: add {read/write}_extended utility routines
  (jsc#SLE-13430).
- mt76: mt76u: introduce mt76u_alloc_mcu_queue utility routine
  (jsc#SLE-13430).
- mt76: mt76u: resume all rx queue in mt76u_resume_rx
  (jsc#SLE-13430).
- mt76: mt76u: add queue parameter to mt76u_rx_urb_alloc
  (jsc#SLE-13430).
- mt76: mt76u: add mt76u_alloc_rx_queue utility routine
  (jsc#SLE-13430).
- mt76: mt76u: stop/free all possible rx queues (jsc#SLE-13430).
- mt76: mt76u: introduce mt76u_free_rx_queue utility routine
  (jsc#SLE-13430).
- mt76: mt76u: move mcu buffer allocation in mt76x02u drivers
  (jsc#SLE-13430).
- mt76: mt76u: add queue id parameter to mt76u_submit_rx_buffers
  (jsc#SLE-13430).
- commit ad1cf2a
* Thu Sep 24 2020 yousaf.kaukab@suse.com
- gpiolib: Initialize the hardware with a callback
  (jsc#SLE-15847).
- commit e1ee56d
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt76u: use mt76_queue as mt76u_complete_rx context
  (jsc#SLE-13430).
- mt76: mt76u: add mt76_queue to mt76u_refill_rx signature
  (jsc#SLE-13430).
- mt76: mt76u: add mt76_queue to mt76u_get_next_rx_entry signature
  (jsc#SLE-13430).
- mt76: mt76u: add mt76u_process_rx_queue utility routine
  (jsc#SLE-13430).
- mt76: mt76u: check tx_status_data pointer in mt76u_tx_tasklet
  (jsc#SLE-13430).
- mt76: mt76x02u: avoid overwrite max_tx_fragments
  (jsc#SLE-13430).
- mt76: rely on mac80211 utility routines to compute airtime
  (jsc#SLE-13430).
- mt76: mt7615: remove leftover routine declaration
  (jsc#SLE-13430).
- mt76: move WIPHY_FLAG_HAS_CHANNEL_SWITCH in mt76_phy_init
  (jsc#SLE-13430).
- mt76: mt7615: fix endianness in mt7615_mcu_set_eeprom
  (jsc#SLE-13430).
- mt76: mt7615: initialize radar specs from host driver
  (jsc#SLE-13430).
- mt76: mt76x2: get rid of leftover target (jsc#SLE-13430).
- mt76: mt7615: add tracing support (jsc#SLE-13430).
- mt76: move mac_txdone tracepoint in mt76 module (jsc#SLE-13430).
- mt76: move dev_irq tracepoint in mt76 module (jsc#SLE-13430).
- mt76: mt7615: add a get_stats() callback (jsc#SLE-13430).
- mt76: mt7615: add per-phy mib statistics (jsc#SLE-13430).
- mt76: mt7615: report TSF information (jsc#SLE-13430).
- mt76: mt7615: add set_antenna callback (jsc#SLE-13430).
- mt76: mt7615: rework set_channel function (jsc#SLE-13430).
- commit 0986221
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: add missing settings for simultaneous dual-band
  support (jsc#SLE-13430).
- mt76: fix compilation warning in mt76_eeprom_override()
  (jsc#SLE-13430).
- mt76: mt7603: simplify led reg definitions (jsc#SLE-13430).
- mt76: mt76x02: simplify led reg definitions (jsc#SLE-13430).
- mt76: mt7615: introduce LED support (jsc#SLE-13430).
- mt76: clear skb pointers from rx aggregation reorder buffer
  during cleanup (jsc#SLE-13430).
- mt76: mt7603: fix input validation issues for powersave-filtered
  frames (jsc#SLE-13430).
- mt76: mt7615: increase MCU command timeout (jsc#SLE-13430).
- mt76: mt7615: measure channel noise and report it via survey
  (jsc#SLE-13430).
- mt76: mt7615: fix MT7615_CFEND_RATE_DEFAULT value
  (jsc#SLE-13430).
- mt76: mt76x02: minor mt76x02_mac_set_beacon optimization
  (jsc#SLE-13430).
- mt76: mt76x02u: do not set NULL beacons (jsc#SLE-13430).
- mt76: usb: use max packet length for m76u_copy (jsc#SLE-13430).
- mt76: mt76x02: add channel switch support for usb interfaces
  (jsc#SLE-13430).
- mt76: speed up usb bulk copy (jsc#SLE-13430).
- mt76: mt76x02: remove a copy call for usb speedup
  (jsc#SLE-13430).
- mt76: mt76x02: add check for invalid vif idx (jsc#SLE-13430).
- mt76: mt76x02: split beaconing (jsc#SLE-13430).
- mt76: mt76x02: omit beacon slot clearing (jsc#SLE-13430).
- mt76: use AC specific reorder timeout (jsc#SLE-13430).
- commit 0ca9a39
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: add set_coverage class support (jsc#SLE-13430).
- mt76: mt7603: set 0 as min coverage_class value (jsc#SLE-13430).
- mt76: mt7615: report firmware version using ethtool
  (jsc#SLE-13430).
- mt76: mt7615: Fix build with older compilers (jsc#SLE-13430).
- mt76: eeprom: add support for big endian eeprom partition
  (jsc#SLE-13430).
- mt76: mt7603: reset STA_CCA counter setting the channel
  (jsc#SLE-13430).
- mt76: fix possible undetected invalid MAC address
  (jsc#SLE-13430).
- mt76: disable bh in mt76_dma_rx_poll (jsc#SLE-13430).
- mt76: fix rx dma ring descriptor state on reset (jsc#SLE-13430).
- mt7615: replace sta_state callback with sta_add/sta_remove
  (jsc#SLE-13430).
- mt76: mt7615: defer mcu initialization via workqueue
  (jsc#SLE-13430).
- mt76: mt7615: update beacon contents on BSS_CHANGED_BEACON
  (jsc#SLE-13430).
- mt76: mt7615: add support for registering a second wiphy via
  debugfs (jsc#SLE-13430).
- mt76: mt7615: select the correct tx queue for frames sent to
  the second phy (jsc#SLE-13430).
- mt76: mt7615: move radio/mac initialization to .start/stop
  callbacks (jsc#SLE-13430).
- mt76: mt7615: initialize dbdc settings on interface add
  (jsc#SLE-13430).
- mt76: mt7615: add multiple wiphy support to the rx path
  (jsc#SLE-13430).
- mt76: mt7615: rework chainmask handling (jsc#SLE-13430).
- mt76: mt7615: add multiple wiphy support to the dfs support code
  (jsc#SLE-13430).
- mt76: mt7615: remove useless MT_HW_RDD0/1 enum (jsc#SLE-13430).
- mt76: mt7615: add missing register init for dual-wiphy support
  (jsc#SLE-13430).
- mt76: mt7615: add multiple wiphy support for smart carrier sense
  (jsc#SLE-13430).
- mt76: mt7615: add dual-phy support for mac80211 ops
  (jsc#SLE-13430).
- mt76: do not overwrite max_tx_fragments if it has been set
  (jsc#SLE-13430).
- mt76: move ampdu_ref from mt76_dev to driver struct
  (jsc#SLE-13430).
- mt76: add ext_phy field to struct mt76_wcid (jsc#SLE-13430).
- mt76: add function for allocating an extra wiphy
  (jsc#SLE-13430).
- mt76: add priv pointer to struct mt76_phy (jsc#SLE-13430).
- mt76: add multiple wiphy support to mt76_get_min_avg_rssi
  (jsc#SLE-13430).
- mt76: move txpower and antenna mask to struct mt76_phy
  (jsc#SLE-13430).
- commit 13dc9ff
* Thu Sep 24 2020 tiwai@suse.de
- mt76: move txpower_conf back to driver specific structs
  (jsc#SLE-13430).
- mt76: move chainmask back to driver specific structs
  (jsc#SLE-13430).
- mt76: move state from struct mt76_dev to mt76_phy
  (jsc#SLE-13430).
- mt76: keep a set of software tx queues per phy (jsc#SLE-13430).
- mt76: move channel state to struct mt76_phy (jsc#SLE-13430).
- mt76: add support for an extra wiphy in mt76_sta_state()
  (jsc#SLE-13430).
- mt76: add support for an extra wiphy in the tx status path
  (jsc#SLE-13430).
- mt76: add support for an extra wiphy in the main tx path
  (jsc#SLE-13430).
- mt76: add support for an extra wiphy in the rx path
  (jsc#SLE-13430).
- mt76: introduce struct mt76_phy (jsc#SLE-13430).
- mt76: move initialization of some struct members to
  mt76_alloc_device (jsc#SLE-13430).
- mt76: mt7615: fix max_nss in mt7615_eeprom_parse_hw_cap
  (jsc#SLE-13430).
- mt76: Off by one in mt76_calc_rx_airtime() (jsc#SLE-13430).
- mt76: fix LED link time failure (jsc#SLE-13430).
- mt76: mt76x0: fix default mac address overwrite (jsc#SLE-13430).
- mt76: fix fix ampdu locking (jsc#SLE-13430).
- mt76: mt7615: read {tx,rx} mask from eeprom (jsc#SLE-13430).
- mt76: move mt76_get_antenna in mt76_core module (jsc#SLE-13430).
- mt76: mt7615: disable radar pattern detector during scanning
  (jsc#SLE-13430).
- mt76: move interface_modes definition in mt76_core module
  (jsc#SLE-13430).
- commit 4862a0c
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: add ibss support (jsc#SLE-13430).
- mt76: move SUPPORTS_REORDERING_BUFFER hw property in
  mt76_register_device (jsc#SLE-13430).
- mt76: use mt76_dev in mt76_is_{mmio,usb} (jsc#SLE-13430).
- mt76: Remove set but not used variable 'idx' (jsc#SLE-13430).
- mt76: mt76u: rely on a dedicated stats workqueue
  (jsc#SLE-13430).
- mt76: mt7615: remove unneeded semicolon (jsc#SLE-13430).
- mt76: mt76x0: remove 350ms delay in mt76x0_phy_calibrate
  (jsc#SLE-13430).
- mt76: mt76x02u: update ewma pkt len in mt76x02u_tx_prepare_skb
  (jsc#SLE-13430).
- mt76: remove obsolete .add_buf() from struct mt76_queue_ops
  (jsc#SLE-13430).
- mt76: add sanity check for a-mpdu rx wcid index (jsc#SLE-13430).
- mt76: refactor cc_lock locking scheme (jsc#SLE-13430).
- mt76: mt76x0: eeprom: add support for MAC address from OF
  (jsc#SLE-13430).
- mt76: avoid enabling interrupt if NAPI poll is still pending
  (jsc#SLE-13430).
- mt76: fix aggregation stop issue (jsc#SLE-13430).
- mt76: add missing locking around ampdu action (jsc#SLE-13430).
- mt76: do not use devm API for led classdev (jsc#SLE-13430).
- mt76: enable airtime fairness (jsc#SLE-13430).
- mt76: mt7615: track tx/rx airtime for airtime fairness
  (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_mac_wtbl_update routine
  (jsc#SLE-13430).
- mt76: mt7615: fix survey channel busy time (jsc#SLE-13430).
- commit 0a46ea0
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: report tx_time, bss_rx and busy time to mac80211
  (jsc#SLE-13430).
- mt76: mt76x02: track approximate tx airtime for airtime fairness
  and survey (jsc#SLE-13430).
- mt76: mt76x02: move MT_CH_TIME_CFG init to mt76x02_mac_cc_reset
  (jsc#SLE-13430).
- mt76: unify channel survey update code (jsc#SLE-13430).
- mt76: mt7603: switch to a different counter for survey busy time
  (jsc#SLE-13430).
- mt76: mt7603: track tx airtime for airtime fairness and survey
  (jsc#SLE-13430).
- mt76: track rx airtime for airtime fairness and survey
  (jsc#SLE-13430).
- mt76: store current channel survey_state in struct mt76_dev
  (jsc#SLE-13430).
- mt76: rename mt76_driver_ops txwi_flags to drv_flags and
  include tx aligned4 (jsc#SLE-13430).
- mt76: report rx a-mpdu subframe status (jsc#SLE-13430).
- mt76: mt7603: remove q_rx field from struct mt7603_dev
  (jsc#SLE-13430).
- mt76: mt7603: collect aggregation stats (jsc#SLE-13430).
- mt76: mt7615: collect aggregation stats (jsc#SLE-13430).
- mt76: move aggr_stats array in mt76_dev (jsc#SLE-13430).
- mt76: mt7615: add queue entry in debugfs (jsc#SLE-13430).
- mt76: move queue debugfs entry to driver specific code
  (jsc#SLE-13430).
- mt76: mt76x02u: move mt76x02u_mac_start in mt76x02-usb module
  (jsc#SLE-13430).
- mt76: mt76x0u: reset counter starting the device
  (jsc#SLE-13430).
- mt76: mt76x2: move mt76x02_mac_reset_counters in
  mt76x02_mac_start (jsc#SLE-13430).
- mt76: mt76x02: move mac_reset_counter in mt76x02_lib module
  (jsc#SLE-13430).
- commit cfb835f
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: enable SCS by default (jsc#SLE-13430).
- mt76: mt76x0e: make array mt76x0_chan_map static const, makes
  object smaller (jsc#SLE-13430).
- mt76: usb: add lockdep_assert_held in __mt76u_vendor_request
  (jsc#SLE-13430).
- mt76: remove empty flag in mt76_txq_schedule_list
  (jsc#SLE-13430).
- mt76: use cancel_delayed_work_sync in mt76_rx_aggr_shutdown
  (jsc#SLE-13430).
- mt76: remove aggr_work field from struct mt76_wcid
  (jsc#SLE-13430).
- mt76: mt7615: fix control frame rx in monitor mode
  (jsc#SLE-13430).
- mt7601u: use DEFINE_DEBUGFS_ATTRIBUTE to define debugfs fops
  (jsc#SLE-13430).
- mt76: mt76x2e: disable pcie_aspm by default (jsc#SLE-13430).
- mt76: mt7615: add support to read temperature from mcu
  (jsc#SLE-13430).
- commit 7d3516a
* Thu Sep 24 2020 tiwai@suse.de
- mt76: add default implementation for
  mt76_sw_scan/mt76_sw_scan_complete (jsc#SLE-13430).
- Refresh
  patches.suse/Revert-mt76-mt76x0e-don-t-use-hw-encryption-for-MT76.patch.
- commit eb2dc0b
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: introduce mt7615_txwi_to_txp utility routine
  (jsc#SLE-13430).
- mt76: mt7603: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-13430).
- mt76: mt76x0: remove unneeded return value on set channel
  (jsc#SLE-13430).
- mt76: mt76x0: remove redundant chandef copy (jsc#SLE-13430).
- mt76: make mt76_rx_convert static (jsc#SLE-13430).
- mt76: remove offchannel check in tx scheduling (jsc#SLE-13430).
- mt76: do not send BAR frame on tx aggregation flush stop
  (jsc#SLE-13430).
- mt76: dma: reset q->rx_head on rx reset (jsc#SLE-13430).
- mt76: mt7615: apply calibration-free data from OTP
  (jsc#SLE-13430).
- mt76: fix some checkpatch warnings (jsc#SLE-13430).
- mt76: mt7615: add BIP_CMAC_128 cipher support (jsc#SLE-13430).
- mt76: mt7603: remove unnecessary mcu queue initialization
  (jsc#SLE-13430).
- mt76: move mt76_tx_tasklet in mt76 module (jsc#SLE-13430).
- mt76: mt7615: enable survey support (jsc#SLE-13430).
- mt76: mt7603: move survey_time in mt76_dev (jsc#SLE-13430).
- mt76: mt76x02u: enable survey support (jsc#SLE-13430).
- mt76: mt76x02u: enable multi-vif support (jsc#SLE-13430).
- mt76: mt76x02: do not copy beacon skb in
  mt76x02_mac_set_beacon_enable (jsc#SLE-13430).
- mt76: mt76x02: introduce mt76x02_pre_tbtt_enable and
  mt76x02_beacon_enable macros (jsc#SLE-13430).
- mt76: mt7615: add Smart Carrier Sense support (jsc#SLE-13430).
- commit ffb46d1
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: rework locking scheme for mt7615_set_channel
  (jsc#SLE-13430).
- mt76: switch to SPDX tag instead of verbose boilerplate text
  (jsc#SLE-13430).
- mt76: mt76x02: fix some checkpatch warnings (jsc#SLE-13430).
- mt76: mt7615: fix some checkpatch warnings (jsc#SLE-13430).
- mt76: mt7603: fix some checkpatch warnings (jsc#SLE-13430).
- mt76: Add paragraphs to describe the config symbols fully
  (jsc#SLE-13430).
- mt76: mt7615: update cw_min/max related settings
  (jsc#SLE-13430).
- mt76: mt7615: add 4 WMM sets support (jsc#SLE-13430).
- mt76: introduce mt76_mmio_read_copy routine (jsc#SLE-13430).
- commit 84dca1b
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: add set_key_cmd and mt76_wcid to
  mt7615_mac_wtbl_set_key signature (jsc#SLE-13430).
- mt76: mt7615: remove wtbl_sec_key definition (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_mac_wtbl_set_key routine
  (jsc#SLE-13430).
- mt76: mt7615: add mt7615_mac_wtbl_addr routine (jsc#SLE-13430).
- mt76: mt7615: move mt7615_mac_get_key_info in mac.c
  (jsc#SLE-13430).
- mt76: mt7615: add missing register initialization
  (jsc#SLE-13430).
- mt76: mt76x0u: add support to TP-Link T2UHP (jsc#SLE-13430).
- commit 8182e1f
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: use params->ssn value directly (jsc#SLE-13430).
- Refresh
  patches.suse/mac80211-simplify-TX-aggregation-start.patch.
- commit de76976
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7603: use params->ssn value directly (jsc#SLE-13430).
- Refresh
  patches.suse/mac80211-simplify-TX-aggregation-start.patch.
- commit 86dacc5
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt76x02: use params->ssn value directly (jsc#SLE-13430).
- Refresh
  patches.suse/mac80211-simplify-TX-aggregation-start.patch.
- commit 9ee9a3b
* Thu Sep 24 2020 tiwai@suse.de
- mt76: usb: remove unneeded {put,get}_unaligned (jsc#SLE-13430).
- mt76: mt7603: fix invalid fallback rates (jsc#SLE-13430).
- mt76: mt7615: fix invalid fallback rates (jsc#SLE-13430).
- mt76: mt7615: fix PS buffering of action frames (jsc#SLE-13430).
- mt76: mt7615: fix using VHT STBC rates (jsc#SLE-13430).
- mt76: mt7615: sync with mt7603 rate control changes
  (jsc#SLE-13430).
- mt76: mt7615: reset rate index/counters on rate table update
  (jsc#SLE-13430).
- mt76: mt7615: move mt7615_mcu_set_rates to mac.c
  (jsc#SLE-13430).
- mt76: mt7603: enable hardware rate up/down selection
  (jsc#SLE-13430).
- commit d37ebad
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: introduce mt7615_mcu_send_ram_firmware routine
  (jsc#SLE-13430).
- Refresh
  patches.suse/mt76-mt7615-fix-mt7615-firmware-path-definitions.patch.
- commit 4d48734
* Thu Sep 24 2020 tiwai@suse.de
- mt76: mt7615: fall back to sw encryption for unsupported ciphers
  (jsc#SLE-13430).
- mt76: mt7615: clean up FWDL TXQ during/after firmware upload
  (jsc#SLE-13430).
- mt76: mt7615: add radar pattern test knob to debugfs
  (jsc#SLE-13430).
- mt76: mt7615: add csa support (jsc#SLE-13430).
- mt76: mt7615: do not perform txcalibration before cac is
  complited (jsc#SLE-13430).
- mt76: mt7615: add hw dfs pattern detector support
  (jsc#SLE-13430).
- mt76: mt7615: introduce mt7615_regd_notifier (jsc#SLE-13430).
- mt7601u: null check the allocation (jsc#SLE-13430).
- commit a7ec0c1
* Thu Sep 24 2020 tiwai@suse.de
- mt7601u: use params->ssn value directly (jsc#SLE-13430).
- Refresh
  patches.suse/mac80211-simplify-TX-aggregation-start.patch.
- commit d3f319c
* Thu Sep 24 2020 tiwai@suse.de
- staging: wlan-ng: fix out of bounds read in
  prism2sta_probe_usb() (jsc#SLE-13430).
- staging: wlan-ng: Fix alignment to match open parenthesis
  (jsc#SLE-13430).
- staging: wlan-ng: Fix third argument going over 80 characters
  (jsc#SLE-13430).
- staging: wlan-ng: Fix line going over 80 characters
  (jsc#SLE-13430).
- staging: wlan-ng: remove unused field from struct
  hfa384x_usbctlx (jsc#SLE-13430).
- staging: wlan-ng: fix compilation for USB debugging
  (jsc#SLE-13430).
- staging: wlan-ng: correct parameter alignment in hfa384x.h
  (jsc#SLE-13430).
- staging: wlan-ng: shorten lines over 80 characters in hfa384x.h
  (jsc#SLE-13430).
- staging: wlan-ng: remove unnecessary casts from prism2usb.c
  (jsc#SLE-13430).
- staging: wlan-ng: p80211wep.c: use lib/crc32 (jsc#SLE-13430).
- staging: wlan-ng: Remove function prism2mib_excludeunencrypted()
  (jsc#SLE-13430).
- staging: wlan-ng: use "%%*pE" for serial number (jsc#SLE-13430).
- staging: wlan-ng: Replace function hfa384x_dowmem()
  (jsc#SLE-13430).
- staging: wlan-ng: Replace function hfa384x_dormem()
  (jsc#SLE-13430).
- staging: wlan-ng: Remove function hfa384x_docmd_wait()
  (jsc#SLE-13430).
- staging: wlan-ng: Remove unused function hfa384x_docmd_async()
  (jsc#SLE-13430).
- staging: wlan-ng: Remove function hfa384x_dowmem_async()
  (jsc#SLE-13430).
- staging: wlan-ng: Remove unused function hfa384x_dormem_async()
  (jsc#SLE-13430).
- staging: wlan-ng: Remove unused function hfa384x_dorrid_async()
  (jsc#SLE-13430).
- staging: wlan-ng: Remove function hfa384x_dowrid_async()
  (jsc#SLE-13430).
- staging: wlan-ng: Remove function hfa384x_dowrid_wait()
  (jsc#SLE-13430).
- staging: wlan-ng: Remove function hfa384x_dorrid_wait()
  (jsc#SLE-13430).
- commit cec1018
* Thu Sep 24 2020 yousaf.kaukab@suse.com
- rtc: max77686: Fix wake-ups for max77620 (jsc#SLE-15847).
- rtc: max77686: Do not allow interrupt to fire before system
  resume (jsc#SLE-15847).
- gpio: max77620: Use helper variable and clarify (jsc#SLE-15847).
- gpio: max77620: Initialize hardware state of interrupts
  (jsc#SLE-15847).
- gpio: max77620: Use irqchip template (jsc#SLE-15847).
- gpio: max77620: Don't shadow error code of platform_get_irq()
  (jsc#SLE-15847).
- gpio: max77620: Don't set of_node (jsc#SLE-15847).
- gpio: max77620: Replace 8 with MAX77620_GPIO_NR (jsc#SLE-15847).
- rtc: max77686: Use single-byte writes on MAX77620
  (jsc#SLE-15847).
- mfd: max77620: Use single-byte writes on MAX77620
  (jsc#SLE-15847).
- thermal: max77620: Appease the kernel-doc deity (jsc#SLE-15847).
- mfd: max77620: Add of_node_put() before return (jsc#SLE-15847).
- rtc: max77686: convert to devm_i2c_new_dummy_device()
  (jsc#SLE-15847).
- rtc: max77686: convert to i2c_new_dummy_device (jsc#SLE-15847).
- commit f482f85
* Thu Sep 24 2020 tiwai@suse.de
- ALSA: hda/realtek - The Mic on a RedmiBook doesn't work
  (git-fixes).
- ALSA: hda: fixup headset for ASUS GX502 laptop (git-fixes).
- commit e989675
* Thu Sep 24 2020 tiwai@suse.de
- batman-adv: mcast: fix duplicate mcast packets from BLA backbone
  to mesh (git-fixes).
- USB: quirks: Add USB_QUIRK_IGNORE_REMOTE_WAKEUP quirk for BYD
  zhaoxin notebook (git-fixes).
- serial: 8250_pci: Add Realtek 816a and 816b (git-fixes).
- Input: trackpoint - add new trackpoint variant IDs (git-fixes).
- Input: i8042 - add Entroware Proteus EL07R4 to nomux and reset
  lists (git-fixes).
- i2c: i801: Fix resume bug (git-fixes).
- i2c: algo: pca: Reapply i2c bus settings after reset
  (git-fixes).
- spi: Fix memory leak on splited transfers (git-fixes).
- spi: spi-loopback-test: Fix out-of-bounds read (git-fixes).
- regulator: pwm: Fix machine constraints application (git-fixes).
- commit 1a5ffc9
* Thu Sep 24 2020 tiwai@suse.de
- batman-adv: mcast: fix duplicate mcast packets in BLA backbone
  from mesh (git-fixes).
- batman-adv: mcast: fix duplicate mcast packets in BLA backbone
  from LAN (git-fixes).
- batman-adv: Add missing include for in_interrupt() (git-fixes).
- batman-adv: mcast/TT: fix wrongly dropped or rerouted packets
  (git-fixes).
- batman-adv: bla: fix type misuse for backbone_gw hash indexing
  (git-fixes).
- USB: UAS: fix disconnect by unplugging a hub (git-fixes).
- usb: typec: ucsi: Prevent mode overrun (git-fixes).
- i2c: mxs: use MXS_DMA_CTRL_WAIT4END instead of DMA_CTRL_ACK
  (git-fixes).
- commit b4b4983
* Thu Sep 24 2020 tiwai@suse.de
- ASoC: meson: axg-toddr: fix channel order on g12 platforms
  (git-fixes).
- ASoC: qcom: common: Fix refcount imbalance on error (git-fixes).
- ASoC: qcom: Set card->owner to avoid warnings (git-fixes).
- USB: serial: option: support dynamic Quectel USB compositions
  (git-fixes).
- dmaengine: acpi: Put the CSRT table after using it (git-fixes).
- NFC: st95hf: Fix memleak in st95hf_in_send_cmd (git-fixes).
- HID: elan: Fix memleak in elan_input_configured (git-fixes).
- HID: microsoft: Add rumble support for the 8bitdo SN30 Pro+
  controller (git-fixes).
- HID: quirks: Set INCREMENT_USAGE_ON_DUPLICATE for all Saitek
  X52 devices (git-fixes).
- HID: quirks: Always poll three more Lenovo PixArt mice
  (git-fixes).
- commit a978a29
* Thu Sep 24 2020 tiwai@suse.de
- clk: rockchip: Fix initialization of mux_pll_src_4plls_p
  (git-fixes).
- clk: davinci: Use the correct size when allocating memory
  (git-fixes).
- USB: serial: option: add support for SIM7070/SIM7080/SIM7090
  modules (git-fixes).
- USB: serial: ftdi_sio: add IDs for Xsens Mti USB converter
  (git-fixes).
- usb: Fix out of sync data toggle if a configured device is
  reconfigured (git-fixes).
- iio: adc: mcp3422: fix locking on error path (git-fixes).
- iio: adc: mcp3422: fix locking scope (git-fixes).
- iio:adc:max1118 Fix alignment of timestamp and data leak issues
  (git-fixes).
- debugfs: Fix module state check condition (git-fixes).
- iio: dac: ad5592r: fix unbalanced mutex unlocks in
  ad5592r_read_raw() (git-fixes).
- commit c8304fa
* Thu Sep 24 2020 tiwai@suse.de
- usb: core: fix slab-out-of-bounds Read in read_descriptors
  (git-fixes).
- usb: typec: ucsi: acpi: Check the _DEP dependencies (git-fixes).
- iio:adc:ina2xx Fix timestamp alignment issue (git-fixes).
- iio:adc:ti-adc084s021 Fix alignment and data leak issues
  (git-fixes).
- iio:adc:ti-adc081c Fix alignment and data leak issues
  (git-fixes).
- iio:magnetometer:ak8975 Fix alignment and data leak issues
  (git-fixes).
- iio:light:ltr501 Fix timestamp alignment issue (git-fixes).
- iio:light:max44000 Fix timestamp alignment and prevent data leak
  (git-fixes).
- iio:chemical:ccs811: Fix timestamp alignment and prevent data
  leak (git-fixes).
- iio:proximity:mb1232: Fix timestamp alignment and prevent data
  leak (git-fixes).
- iio:accel:mma7455: Fix timestamp alignment and prevent data leak
  (git-fixes).
- iio:accel:bmc150-accel: Fix timestamp alignment and prevent
  data leak (git-fixes).
- iio:accel:mma8452: Fix timestamp alignment and prevent data leak
  (git-fixes).
- iio: accel: kxsd9: Fix alignment of local buffer (git-fixes).
- iio: adc: ti-ads1015: fix conversion when CONFIG_PM is not set
  (git-fixes).
- soundwire: fix double free of dangling pointer (git-fixes).
- spi: stm32: fix pm_runtime_get_sync() error checking
  (git-fixes).
- regulator: core: Fix slab-out-of-bounds in
  regulator_unlock_recursive() (git-fixes).
- regulator: remove superfluous lock in
  regulator_resolve_coupling() (git-fixes).
- regulator: plug of_node leak in regulator_register()'s error
  path (git-fixes).
- regulator: push allocation in set_consumer_device_supply()
  out of lock (git-fixes).
- regulator: push allocations in create_regulator() outside of
  lock (git-fixes).
- regulator: push allocation in regulator_ena_gpio_request()
  out of lock (git-fixes).
- regulator: push allocation in regulator_init_coupling()
  outside of lock (git-fixes).
- mmc: sdio: Use mmc_pre_req() / mmc_post_req() (git-fixes).
- mmc: sdhci-of-esdhc: Don't walk device-tree on every interrupt
  (git-fixes).
- mmc: sdhci-msm: Add retries when all tuning phases are found
  valid (git-fixes).
- mmc: sdhci-acpi: Clear amd_sdhci_host on reset (git-fixes).
- commit 3591d68
* Thu Sep 24 2020 glin@suse.com
- bpf: Fix a rcu warning for bpffs map pretty-print (bsc#1155518).
- bpf: map_seq_next should always increase position index
  (bsc#1155518).
- commit e39f9d2
* Thu Sep 24 2020 lyan@suse.com
- arm64: paravirt: Initialize steal time when cpu is online
  (bsc#1176833).
- Drop
  patches.kabi/kabi-workaround-for-enum-cpuhp_state.patch
  (Variable in enum cpuhp_state is no longer needed)
- commit 5b9b111
* Wed Sep 23 2020 msuchanek@suse.de
- powerpc/numa: Early request for home node associativity
  (bsc#1171068 ltc#183935).
- commit bd89a37
* Wed Sep 23 2020 nsaenzjulienne@suse.de
- crypto: talitos - Fix build error by selecting LIB_DES
  (jsc#SLE-16106).
- crypto: hisilicon - select CRYPTO_LIB_DES while compiling SEC
  driver (jsc#SLE-16106).
- commit d393cfd
* Wed Sep 23 2020 nsaenzjulienne@suse.de
- crypto: s390/des - switch to new verification routines
  (jsc#SLE-16106).
- commit a1c93fe
* Wed Sep 23 2020 tiwai@suse.de
- workqueue: require CPU hotplug read exclusion for
  apply_workqueue_attrs (bsc#1176763).
- commit ceaafd0
* Wed Sep 23 2020 msuchanek@suse.de
- powerpc/numa: Offline memoryless cpuless node 0 (bsc#1171068
  ltc#183935).
- powerpc/numa: Prefer node id queried from vphn (bsc#1171068
  ltc#183935).
- powerpc/numa: Set numa_node for all possible cpus (bsc#1171068
  ltc#183935).
- powerpc/numa: Use cpu node map of first sibling thread
  (bsc#1171068 ltc#183935).
- commit 4baf6e2
* Wed Sep 23 2020 tiwai@suse.de
- Revert "wlcore: Adding suppoprt for IGTK key in wlcore driver"
  (jsc#SLE-13430, bsc#1176741).
- airo: use generic power management (jsc#SLE-13430, bsc#1176741).
- intersil: fix wiki website url (jsc#SLE-13430, bsc#1176741).
- qtnfmac: Missing platform_device_unregister() on error in
  qtnf_core_mac_alloc() (jsc#SLE-13430, bsc#1176741).
- hostap: use generic power management (jsc#SLE-13430,
  bsc#1176741).
- prism54: switch from 'pci_' to 'dma_' API (jsc#SLE-13430,
  bsc#1176741).
- prism54: islpci_hotplug: use generic power management
  (jsc#SLE-13430, bsc#1176741).
- prism54: Replace HTTP links with HTTPS ones (jsc#SLE-13430,
  bsc#1176741).
- p54: switch from 'pci_' to 'dma_' API (jsc#SLE-13430,
  bsc#1176741).
- wireless: Fix trivial spelling (jsc#SLE-13430, bsc#1176741).
- zd1211rw: remove needless check before usb_free_coherent()
  (jsc#SLE-13430, bsc#1176741).
- airo: use set_current_state macro (jsc#SLE-13430, bsc#1176741).
- adm8211: use generic power management (jsc#SLE-13430,
  bsc#1176741).
- orinoco: use generic power management (jsc#SLE-13430,
  bsc#1176741).
- orinoco_usb: fix spelling mistake (jsc#SLE-13430, bsc#1176741).
- wlcore: Remove pointless spinlock (jsc#SLE-13430, bsc#1176741).
- wlcore: Use spin_trylock in wlcore_irq() to see if we need to
  queue tx (jsc#SLE-13430, bsc#1176741).
- wlcore: Use spin_trylock in wlcore_irq_locked() for running
  the queue (jsc#SLE-13430, bsc#1176741).
- wlcore: Simplify runtime resume ELP path (jsc#SLE-13430,
  bsc#1176741).
- airo: Fix read overflows sending packets (jsc#SLE-13430,
  bsc#1176741).
- wlcore: fix runtime pm imbalance in wlcore_irq_locked
  (jsc#SLE-13430, bsc#1176741).
- wlcore: fix runtime pm imbalance in __wl1271_op_remove_interface
  (jsc#SLE-13430, bsc#1176741).
- wlcore: fix runtime pm imbalance in wl1271_op_suspend
  (jsc#SLE-13430, bsc#1176741).
- wlcore: fix runtime pm imbalance in wlcore_regdomain_config
  (jsc#SLE-13430, bsc#1176741).
- wlcore: fix runtime pm imbalance in wl1271_tx_work
  (jsc#SLE-13430, bsc#1176741).
- cw1200: Remove local sdio VENDOR and DEVICE id definitions
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: Replace zero-length array with flexible-array
  (jsc#SLE-13430, bsc#1176741).
- prism54: Replace zero-length array with flexible-array
  (jsc#SLE-13430, bsc#1176741).
- wlcore: Adding suppoprt for IGTK key in wlcore driver
  (jsc#SLE-13430, bsc#1176741).
- orinoco: remove useless variable 'err' in spectrum_cs_suspend()
  (jsc#SLE-13430, bsc#1176741).
- hostap: Add missing annotations for prism2_bss_list_proc_start()
  and prism2_bss_list_proc_stop (jsc#SLE-13430, bsc#1176741).
- cw1200: make cw1200_spi_irq_unsubscribe() void (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: Simplify code in _attach functions (jsc#SLE-13430,
  bsc#1176741).
- adm80211: Replace zero-length array with flexible-array member
  (jsc#SLE-13430, bsc#1176741).
- cw1200: Replace zero-length array with flexible-array member
  (jsc#SLE-13430, bsc#1176741).
- zd1211rw: Replace zero-length array with flexible-array member
  (jsc#SLE-13430, bsc#1176741).
- p54: Replace zero-length array with flexible-array member
  (jsc#SLE-13430, bsc#1176741).
- orinoco: Replace zero-length array with flexible-array member
  (jsc#SLE-13430, bsc#1176741).
- hostap: Replace zero-length array with flexible-array member
  (jsc#SLE-13430, bsc#1176741).
- wireless: ti: Replace zero-length array with flexible-array
  member (jsc#SLE-13430, bsc#1176741).
- prism54: Use scnprintf() for avoiding potential buffer overflow
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: add interface combination check for repeater mode
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: assign each wiphy to its own virtual platform device
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: set valid edmg in cfg80211_chan_def (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: support WPA3 OWE in AP mode (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: support WPA3 SAE in AP mode (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: fix potential Spectre vulnerabilities (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: drop unnecessary TLVs from scan command (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: update channel switch command to support 6GHz band
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: cleanup alignment in firmware communication protocol
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: pass max scan SSIDs limit on per-radio basis
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: implement extendable channel survey dump
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: drop QTN_TLV_ID_NUM_IFACE_COMB TLV type (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: merge PHY_PARAMS_GET into MAC_INFO (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: pass hardware capabilities in TLV element
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: use MAJOR.MINOR format for firmware protocol
  (jsc#SLE-13430, bsc#1176741).
- wl1251: remove ti,power-gpio for SDIO mode (jsc#SLE-13430,
  bsc#1176741).
- orinoco_usb: Use the regular completion interfaces
  (jsc#SLE-13430, bsc#1176741).
- wlcore: remove stray plus sign (jsc#SLE-13430, bsc#1176741).
- qtnfmac: add support for TWT responder and spatial reuse
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: add support for STA HE rates (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: control qtnfmac wireless interfaces bridging
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: add module param to configure DFS offload
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: cleanup slave_radar access function (jsc#SLE-13430,
  bsc#1176741).
- cw1200: use true,false for bool variable (jsc#SLE-13430,
  bsc#1176741).
- hostap: Adjust indentation in prism2_hostapd_add_sta
  (jsc#SLE-13430, bsc#1176741).
- wlcore: mesh: Add support for RX Broadcast Key (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: process HE capabilities requests (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: add TLV for extension IEs (jsc#SLE-13430, bsc#1176741).
- qtnfmac: signal that all packets coming from device are already
  flooded (jsc#SLE-13430, bsc#1176741).
- qtnfmac: advertise netdev port parent ID (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: add interface ID to each packet (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: track broadcast domain of each interface
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: remove VIF in firmware in case of error (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: add support for getting/setting transmit power
  (jsc#SLE-13430, bsc#1176741).
- qtnfmac: handle MIC failure event from firmware (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: send EAPOL frames via control path (jsc#SLE-13430,
  bsc#1176741).
- qtnfmac: modify Rx descriptors queue setup (jsc#SLE-13430,
  bsc#1176741).
- adm80211: remove set but not used variables 'mem_addr' and
  'io_addr' (jsc#SLE-13430, bsc#1176741).
- wlcore: clean-up clearing of WL1271_FLAG_IRQ_RUNNING
  (jsc#SLE-13430, bsc#1176741).
- zd1211rw: zd_usb: Use "%%zu" to format size_t (jsc#SLE-13430,
  bsc#1176741).
- zd1211rw: use %%*ph to print small buffer (jsc#SLE-13430,
  bsc#1176741).
- hostap: use %%*ph to print small buffer (jsc#SLE-13430,
  bsc#1176741).
- hostap: remove set but not used variable 'copied' in
  prism2_io_debug_proc_read (jsc#SLE-13430, bsc#1176741).
- zd1211rw: zd_usb: Use struct_size() helper (jsc#SLE-13430,
  bsc#1176741).
- airo: fix memory leaks (jsc#SLE-13430, bsc#1176741).
- qtnfmac_pcie: Use dev_get_drvdata (jsc#SLE-13430, bsc#1176741).
- commit 5da3ada
* Wed Sep 23 2020 tiwai@suse.de
- blacklist.conf: Remove the wireless entry to be backported
- commit 49fbe52
* Wed Sep 23 2020 nsaenzjulienne@suse.de
- crypto: x86/des - switch to library interface (jsc#SLE-16106).
- commit ee24e9c
* Wed Sep 23 2020 nsaenzjulienne@suse.de
- crypto: caam/qi2 - add module alias (jsc#SLE-16106).
- crypto: caam - add more RNG hw error codes (jsc#SLE-16106).
- crypto: caam/jr - remove incorrect reference to
  caam_jr_register() (jsc#SLE-16106).
- crypto: caam - silence .setkey in case of bad key length
  (jsc#SLE-16106).
- crypto: caam/qi2 - create ahash shared descriptors only once
  (jsc#SLE-16106).
- crypto: caam/qi2 - fix error reporting for caam_hash_alloc
  (jsc#SLE-16106).
- crypto: caam - remove deadcode on 32-bit platforms
  (jsc#SLE-16106).
- crypto: caam - Remove broken arc4 support (jsc#SLE-16106).
- crypto: caam/qi2 - fix return code in ahash_finup_no_ctx()
  (jsc#SLE-16106).
- crypto: caam/qi2 - remove redundant assignment to ret
  (jsc#SLE-16106).
- crypto: caam/qi2 - add support for dpseci_reset()
  (jsc#SLE-16106).
- crypto: caam - add clock info for VFxxx SoCs (jsc#SLE-16106).
- crypto: caam - fix typos (jsc#SLE-16106).
- crypto: caam - fix use-after-free KASAN issue for RSA algorithms
  (jsc#SLE-16106).
- crypto: caam - fix use-after-free KASAN issue for HASH
  algorithms (jsc#SLE-16106).
- crypto: caam - fix use-after-free KASAN issue for AEAD
  algorithms (jsc#SLE-16106).
- crypto: caam - fix use-after-free KASAN issue for SKCIPHER
  algorithms (jsc#SLE-16106).
- crypto: caam - limit single JD RNG output to maximum of 16 bytes
  (jsc#SLE-16106).
- crypto: caam - enable prediction resistance in HRWNG
  (jsc#SLE-16106).
- crypto: caam - invalidate entropy register during RNG
  initialization (jsc#SLE-16106).
- crypto: caam - check if RNG job failed (jsc#SLE-16106).
- crypto: caam - simplify RNG implementation (jsc#SLE-16106).
- crypto: caam - drop global context pointer and init_done
  (jsc#SLE-16106).
- crypto: caam - use struct hwrng's .init for initialization
  (jsc#SLE-16106).
- crypto: caam - allocate RNG instantiation descriptor with
  GFP_DMA (jsc#SLE-16106).
- crypto: Replace zero-length array with flexible-array member
  (jsc#SLE-16106).
- crypto: caam - add crypto_engine support for HASH algorithms
  (jsc#SLE-16106).
- crypto: caam - add crypto_engine support for RSA algorithms
  (jsc#SLE-16106).
- crypto: caam - add crypto_engine support for AEAD algorithms
  (jsc#SLE-16106).
- crypto: caam - support crypto_engine framework for SKCIPHER
  algorithms (jsc#SLE-16106).
- crypto: caam - change return code in caam_jr_enqueue function
  (jsc#SLE-16106).
- crypto: caam - refactor RSA private key _done callbacks
  (jsc#SLE-16106).
- crypto: caam - refactor ahash_edesc_alloc (jsc#SLE-16106).
- crypto: caam - refactor ahash_done callbacks (jsc#SLE-16106).
- crypto: caam - refactor skcipher/aead/gcm/chachapoly
  {en,de}crypt functions (jsc#SLE-16106).
- crypto: caam/qi - optimize frame queue cleanup (jsc#SLE-16106).
- crypto: caam - add support for i.MX8M Plus (jsc#SLE-16106).
- crypto: caam - add support for i.MX8M Nano (jsc#SLE-16106).
- crypto: caam - Add support for i.MX8M Mini (jsc#SLE-16106).
- crypto: caam/qi2 - remove double buffering for ahash
  (jsc#SLE-16106).
- crypto: caam - remove double buffering for ahash
  (jsc#SLE-16106).
- crypto: caam - do not reset pointer size from MCFGR register
  (jsc#SLE-16106).
- crypto: caam - populate platform devices last (jsc#SLE-16106).
- crypto: caam - use devres to populate platform devices
  (jsc#SLE-16106).
- crypto: caam - use devres to de-initialize QI (jsc#SLE-16106).
- crypto: caam - use devres to de-initialize the RNG
  (jsc#SLE-16106).
- crypto: caam - use devres to remove debugfs (jsc#SLE-16106).
- crypto: caam - use devres to unmap memory (jsc#SLE-16106).
- crypto: caam - use mapped_{src,dst}_nents for descriptor
  (jsc#SLE-16106).
- crypto: caam - Cast to long first before pointer conversion
  (jsc#SLE-16106).
- crypto: caam - dispose of IRQ mapping only after IRQ is freed
  (jsc#SLE-16106).
- crypto: caam - check irq_of_parse_and_map for errors
  (jsc#SLE-16106).
- crypto: caam - use devres to unmap JR's registers
  (jsc#SLE-16106).
- crypto: caam - make sure clocks are enabled first
  (jsc#SLE-16106).
- crypto: caam - add clock entry for i.MX8MQ (jsc#SLE-16106).
- crypto: caam - always select job ring via RSR on i.MX8MQ
  (jsc#SLE-16106).
- crypto: caam - select DMA address size at runtime
  (jsc#SLE-16106).
- crypto: caam - don't hardcode inpentry size (jsc#SLE-16106).
- crypto: caam - drop explicit usage of struct jr_outentry
  (jsc#SLE-16106).
- crypto: caam - move cpu_to_caam_dma() selection to runtime
  (jsc#SLE-16106).
- crypto: caam - make CAAM_PTR_SZ dynamic (jsc#SLE-16106).
- crypto: caam - share definition for MAX_SDLEN (jsc#SLE-16106).
- crypto: caam - drop 64-bit only wr/rd_reg64() (jsc#SLE-16106).
- crypto: caam - use ioread64*_hi_lo in rd_reg64 (jsc#SLE-16106).
- crytpo: caam - make use of iowrite64*_hi_lo in wr_reg64
  (jsc#SLE-16106).
- crypto: caam - request JR IRQ as the last step (jsc#SLE-16106).
- crypto: caam - convert caam_jr_init() to use devres
  (jsc#SLE-16106).
- crypto: caam - simplfy clock initialization (jsc#SLE-16106).
- crypto: caam - move DMA mask selection into a function
  (jsc#SLE-16106).
- crypto: talitos - Fix build warning in aead_des3_setkey
  (jsc#SLE-16106).
- crypto: n2/des - fix build breakage after DES updates
  (jsc#SLE-16106).
- crypto: des - remove now unused __des3_ede_setkey()
  (jsc#SLE-16106).
- crypto: des - split off DES library from generic DES cipher
  driver (jsc#SLE-16106).
- Update configs
- Refresh: patches.suse/crypto-blake2s-generic-c-library-implementation-and-selftest.patch
- Refresh: patches.suse/crypto-chacha-move-existing-library-code-into-lib-crypto.patch
- Refresh: patches.suse/crypto-chacha20poly1305-import-construction-and-selftest-from-zinc.patch
- Refresh: patches.suse/crypto-lib-curve25519-re-add-selftests.patch
- Refresh: patches.suse/crypto-lib-tidy-up-lib-crypto-kconfig-and-makefile.patch
- Refresh: patches.suse/crypto-poly1305-move-core-routines-into-a-separate-library.patch
- supported.conf: add libdes
- crypto: des - remove unused function (jsc#SLE-16106).
- crypto: 3des - move verification out of exported routine
  (jsc#SLE-16106).
- crypto: ux500/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: talitos/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: sun4i/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: stm32/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: rk3288/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: qce/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: picoxcell/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: omap/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: n2/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: cesa/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: ixp4xx/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: safexcel/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: hisilicon/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: hifn/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: ccree/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: ccp/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: nitrox/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: cpt/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: caam/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: bcm/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: atmel/des - switch to new verification routines
  (jsc#SLE-16106).
- crypto: des/3des_ede - add new helpers to verify keys
  (jsc#SLE-16106).
- crypto: caam - change return value in case CAAM has no MDHA
  (jsc#SLE-16106).
- crypto: caam - fix MDHA key derivation for certain user key
  lengths (jsc#SLE-16106).
- crypto: caam - keep both virtual and dma key addresses
  (jsc#SLE-16106).
- crypto: caam - update rfc4106 sh desc to support zero length
  input (jsc#SLE-16106).
- crypto: caam - check zero-length input (jsc#SLE-16106).
- crypto: caam - check assoclen (jsc#SLE-16106).
- crypto: caam - check authsize (jsc#SLE-16106).
- crypto: caam - check key length (jsc#SLE-16106).
- crypto: caam - update IV only when crypto operation succeeds
  (jsc#SLE-16106).
- crypto: caam - fix return code in completion callbacks
  (jsc#SLE-16106).
- crypto: aes - helper function to validate key length for AES
  algorithms (jsc#SLE-16106).
- crypto: caam - defer probing until QMan is available
  (jsc#SLE-16106).
- crypto: caam/qi2 - Add printing dpseci fq stats using debugfs
  (jsc#SLE-16106).
- crypto: caam/qi2 - Increase napi budget to process more caam
  responses (jsc#SLE-16106).
- crypto: drivers - Use kmemdup rather than duplicating its
  implementation (jsc#SLE-16106).
- crypto: lib/aes - export sbox and inverse sbox (jsc#SLE-16106).
- commit 7b8fc68
* Wed Sep 23 2020 msuchanek@suse.de
- rpadlpar_io: Add MODULE_DESCRIPTION entries to kernel modules
  (bsc#1176869 ltc#188243).
- commit e45f4be
* Wed Sep 23 2020 tiwai@suse.de
- fbcon: remove soft scrollback code (CVE-2020-14390 bsc#1176235).
- commit 9b8ada0
* Wed Sep 23 2020 tiwai@suse.de
- cfg80211: regulatory: reject invalid hints (bsc#1176699).
- commit 899f6a9
* Wed Sep 23 2020 tiwai@suse.de
- mac80211: fix 80 MHz association to 160/80+80 AP on 6 GHz
  (jsc#SLE-13430).
- mac80211: do not allow bigger VHT MPDUs than the hardware
  supports (jsc#SLE-13430).
- cfg80211: fix 6 GHz channel conversion (jsc#SLE-13430).
- mac80211: do not disable HE if HT is missing on 2.4 GHz
  (jsc#SLE-13430).
- mac80211: Fix radiotap header channel flag for 6GHz band
  (jsc#SLE-13430).
- lib80211: fix unmet direct dependendices config warning when
  !CRYPTO (jsc#SLE-13430).
- mac80211: add AQL support for VHT160 tx rates (jsc#SLE-13430).
- mac80211: extend AQL aggregation estimation to HE and fix unit
  mismatch (jsc#SLE-13430).
- brcmfmac: reserve tx credit only when txctl is ready to send
  (jsc#SLE-13430).
- cfg80211: invert HE BSS color 'disabled' to 'enabled'
  (jsc#SLE-13430).
- commit 6a30c41
* Wed Sep 23 2020 nsaenzjulienne@suse.de
- tty: serial: imx: add dependence and build for earlycon
  (jsc#SLE-16106).
- Update configs
- tty/serial: fix serial_core.c kernel-doc warnings
  (jsc#SLE-16106).
- serial: 8520_port: Fix function param documentation
  (jsc#SLE-16106).
- commit 554b64d
* Wed Sep 23 2020 mkubecek@suse.cz
- ethtool: ethnl_set_linkmodes: remove redundant null check
  (bsc#1176447).
- net: ethtool: add missing string for NETIF_F_GSO_TUNNEL_REMCSUM
  (bsc#1176447).
- ethtool: Fix check in ethtool_rx_flow_rule_create (bsc#1176447).
- ethtool: linkinfo: remove an unnecessary NULL check
  (bsc#1176447).
- ethtool: propagate get_coalesce return value (bsc#1176447).
- ethtool: don't call set_channels in drivers if config didn't
  change (bsc#1176447).
- ethtool: check if there is at least one channel for TX/RX in
  the core (bsc#1176447).
- netlink: allow extack cookie also for error messages
  (bsc#1176447).
- commit 83fb27e
* Wed Sep 23 2020 mkubecek@suse.cz
- Update
  patches.suse/ethtool-provide-coalescing-parameters-with-COALESCE_.patch.
  We have to handle zero ethtool_ops::supported_coalesce_params (meaning all
  coalescing parameters are allowed) correctly.
- commit 265b21a
* Wed Sep 23 2020 mkubecek@suse.cz
- Update
  patches.suse/ethtool-set-coalescing-parameters-with-COALESCE_SET-.patch.
  We have to handle zero ethtool_ops::supported_coalesce_params (meaning all
  coalescing parameters are allowed) correctly.
- commit 92c5163
* Wed Sep 23 2020 tiwai@suse.de
- mmc: sdio: Move SDIO IDs from rsi_sdio driver to common include
  file (jsc#SLE-13430).
- commit dd60907
* Wed Sep 23 2020 tiwai@suse.de
- rt2x00: pci: use generic power management (jsc#SLE-13430).
- atmel: fix wiki website url (jsc#SLE-13430).
- atmel: Use shared constant for rfc1042 header (jsc#SLE-13430).
- rt2800: enable MFP support unconditionally (jsc#SLE-13430).
- rsi: fix a typo "throld" -> "threshold" (jsc#SLE-13430).
- atmel: at76c50x: Replace zero-length array with flexible-array
  member (jsc#SLE-13430).
- rsi: fix null pointer dereference during rsi_shutdown()
  (jsc#SLE-13430).
- at76c50x-usb: fix endpoint debug message (jsc#SLE-13430).
- rt2x00usb: Fix a warning message in
  'rt2x00usb_watchdog_tx_dma()' (jsc#SLE-13430).
- rsi: add missing endpoint sanity checks (jsc#SLE-13430).
- rt2x00: use RESET state bit to prevent IV changes on restart
  (jsc#SLE-13430).
- rt2x00: implement reconfig_complete (jsc#SLE-13430).
- atmel: remove set but not used variable 'dev' (jsc#SLE-13430).
- rsi: drop bogus device-id checks from probe (jsc#SLE-13430).
- rt2x00: remove input-polldev.h header (jsc#SLE-13430).
- rt2x00: do not set IEEE80211_TX_STAT_AMPDU_NO_BACK on tx status
  (jsc#SLE-13430).
- rt2800usb: Add new rt2800usb device PLANEX GW-USMicroN
  (jsc#SLE-13430).
- rsi: fix for sdio reset card issue (jsc#SLE-13430).
- rsi: fix for sdio interface setup in 9116 (jsc#SLE-13430).
- rt2x00: no need to check return value of debugfs_create
  functions (jsc#SLE-13430).
- rt2x00usb: remove unnecessary rx flag checks (jsc#SLE-13430).
- rsi: return explicit error values (jsc#SLE-13430).
- commit a8888e8
* Wed Sep 23 2020 tiwai@suse.de
- ath10k: Fix NULL pointer dereference in AHB device probe
  (jsc#SLE-13430).
- ath9k_htc: Set RX filter based to allow broadcast Action frame
  RX (jsc#SLE-13430).
- ath9k: Set RX filter based to allow broadcast Action frame RX
  (jsc#SLE-13430).
- wcn36xx: Replace zero-length array with flexible-array
  (jsc#SLE-13430).
- wil6210: Replace zero-length array with flexible-array
  (jsc#SLE-13430).
- ath10k: fix ath10k_pci struct layout (jsc#SLE-13430).
- ath10k: fix gcc-10 zero-length-bounds warnings (jsc#SLE-13430).
- carl9170: Replace zero-length array with flexible-array
  (jsc#SLE-13430).
- ath10k: remove experimental tag from SDIO and SNOC busses in
  Kconfig (jsc#SLE-13430).
- ath10k: Replace zero-length array with flexible-array
  (jsc#SLE-13430).
- ath10k: fix __le32 warning in
  ath10k_wmi_tlv_op_gen_request_peer_stats_info() (jsc#SLE-13430).
- wil6210: avoid gcc-10 zero-length-bounds warning
  (jsc#SLE-13430).
- ath10k: Remove msdu from idr when management pkt send fails
  (jsc#SLE-13430).
- ath6kl: Replace zero-length array with flexible-array
  (jsc#SLE-13430).
- ath10k: Add support for targets without trustzone
  (jsc#SLE-13430).
- ath10k: Setup the msa resources before qmi init (jsc#SLE-13430).
- ath10k: Avoid override CE5 configuration for QCA99X0 chipsets
  (jsc#SLE-13430).
- ath10k: fix possible memory leak in ath10k_bmi_lz_data_large()
  (jsc#SLE-13430).
- ath10k: correct tx bitrate of iw for SDIO (jsc#SLE-13430).
- ath10k: add bitrate parse for peer stats info (jsc#SLE-13430).
- ath10k: add rx bitrate report for SDIO (jsc#SLE-13430).
- ath10k: enable firmware peer stats info for wmi tlv
  (jsc#SLE-13430).
- ath5k: remove conversion to bool in ath5k_ani_calibration()
  (jsc#SLE-13430).
- ath9k: add calibration timeout for AR9002 (jsc#SLE-13430).
- ath9k: invalidate all calibrations at once (jsc#SLE-13430).
- ath9k: interleaved NF calibration on AR9002 (jsc#SLE-13430).
- ath9k: do not miss longcal on AR9002 (jsc#SLE-13430).
- ath9k: remove needless NFCAL_PENDING flag setting
  (jsc#SLE-13430).
- ath9k: fix AR9002 ADC and NF calibrations (jsc#SLE-13430).
- ath10k: add statistics of tx retries and tx failed when tx
  complete disable (jsc#SLE-13430).
- ath10k: enable rx duration report default for wmi tlv
  (jsc#SLE-13430).
- ath10k: drop the TX packet which size exceed credit size for
  sdio (jsc#SLE-13430).
- ath10k: Fix the invalid tx/rx chainmask configuration
  (jsc#SLE-13430).
- ath10k: add flush tx packets for SDIO chip (jsc#SLE-13430).
- ath10k: enable alt data of TX path for sdio (jsc#SLE-13430).
- ath10k: add htt TX bundle for sdio (jsc#SLE-13430).
- ath10k: hif: make send_complete_check op optional
  (jsc#SLE-13430).
- ath10k: sdio: remove _hif_ prefix from functions not part of
  hif interface (jsc#SLE-13430).
- ath10k: improve power save performance for sdio (jsc#SLE-13430).
- ath10k: rename ath10k_hif_swap_mailbox() to
  ath10k_hif_start_post() (jsc#SLE-13430).
- ath10k: Fix typo in warning messages (jsc#SLE-13430).
- ath10k: change ATH10K_SDIO_BUS_REQUEST_MAX_NUM from 64 to 1024
  (jsc#SLE-13430).
- ath10k: disable TX complete indication of htt for sdio
  (jsc#SLE-13430).
- ath10k: enable radar detection in secondary segment
  (jsc#SLE-13430).
- ath10k: enable VHT160 and VHT80+80 modes (jsc#SLE-13430).
- commit 275b016
* Wed Sep 23 2020 dwagner@suse.de
- scsi: qla2xxx: Handle incorrect entry_type entries
  (bsc#1171688).
- scsi: qla2xxx: Log calling function name in
  qla2x00_get_sp_from_handle() (bsc#1171688).
- scsi: qla2xxx: Simplify return value logic in
  qla2x00_get_sp_from_handle() (bsc#1171688).
- scsi: qla2xxx: Warn if done() or free() are called on an
  already freed srb (bsc#1171688).
- scsi: qla2xxx: Fix the return value (bsc#1171688).
- scsi: qla2xxx: Fix wrong return value in qla_nvme_register_hba()
  (bsc#1171688).
- scsi: qla2xxx: Fix wrong return value in
  qlt_chk_unresolv_exchg() (bsc#1171688).
- scsi: qla2xxx: Remove redundant variable initialization
  (bsc#1171688).
- scsi: qla2xxx: Fix the size used in a 'dma_free_coherent()'
  call (bsc#1171688).
- scsi: qla2xxx: Remove pci-dma-compat wrapper API (bsc#1171688).
- scsi: qla2xxx: Remove superfluous memset() (bsc#1171688).
- commit a59756a
* Wed Sep 23 2020 tiwai@suse.de
- mmc: sdio: Move SDIO IDs from ath10k driver to common include
  file (jsc#SLE-13430).
- Refresh
  patches.suse/mmc-sdio-Move-SDIO-IDs-from-b43-sdio-driver-to-commo.patch.
- commit 724d733
* Wed Sep 23 2020 tiwai@suse.de
- mmc: sdio: Move SDIO IDs from ath6kl driver to common include
  file (jsc#SLE-13430).
- Refresh
  patches.suse/mmc-sdio-Move-SDIO-IDs-from-b43-sdio-driver-to-commo.patch.
- commit ad768d6
* Wed Sep 23 2020 tiwai@suse.de
- ath10k: Fill GCMP MIC length for PMF (jsc#SLE-13430).
- ath5k: Use scnprintf() for avoiding potential buffer overflow
  (jsc#SLE-13430).
- ath10k: allow qca988x family to support ack rssi of tx data
  packets (jsc#SLE-13430).
- ath5k: Add proper dependency for ATH5K_AHB (jsc#SLE-13430).
- commit 24e69ef
* Wed Sep 23 2020 tiwai@suse.de
- ath10k: fix not registering airtime of 11a station with WMM
  disable (jsc#SLE-13430).
- ath10k: fix unsupported chip reset debugs file write
  (jsc#SLE-13430).
- ath10k: use kzalloc to read for ath10k_sdio_hif_diag_read
  (jsc#SLE-13430).
- ath10k: start recovery process when read int status fail for
  sdio (jsc#SLE-13430).
- ath10k: add QCA9377 sdio hw_param item (jsc#SLE-13430).
- ath10k: avoid consecutive OTP download to reduce boot time
  (jsc#SLE-13430).
- ath10k: Add support to read btcoex related data from DT
  (jsc#SLE-13430).
- carl9170: Use scnprintf() for avoiding potential buffer overflow
  (jsc#SLE-13430).
- wil6210: reject unsupported coalescing params (jsc#SLE-13430).
- wcn36xx: fix spelling mistake "to" -> "too" (jsc#SLE-13430).
- ar5523: fix spelling mistake "to" -> "too" (jsc#SLE-13430).
- ar5523: Add USB ID of SMCWUSBT-G2 wireless adapter
  (jsc#SLE-13430).
- ath10k: Use device_get_match_data() to simplify code
  (jsc#SLE-13430).
- ath10k: Add newlines to printk messages (jsc#SLE-13430).
- commit 9b9cecd
* Wed Sep 23 2020 tiwai@suse.de
- ath10k: Don't call SCM interface for statically mapped msa
  region (jsc#SLE-13430).
- Refresh
  patches.suse/ath10k-Skip-handling-del_server-during-driver-exit.patch.
- commit 6e75394
* Wed Sep 23 2020 tiwai@suse.de
- ath10k: drop RX skb with invalid length for sdio
  (jsc#SLE-13430).
- ath10k: use true,false for bool variable (jsc#SLE-13430).
- ath10k: Add optional qdss clk (jsc#SLE-13430).
- wil6210: use true,false for bool variable (jsc#SLE-13430).
- commit ed2b42a
* Wed Sep 23 2020 tiwai@suse.de
- ath9k: use true,false for bool variable (jsc#SLE-13430).
- wil6210: get rid of begin() and complete() ethtool_ops
  (jsc#SLE-13430).
- wil6210: add support for set_cqm_rssi_config (jsc#SLE-13430).
- wil6210: support set_multicast_to_unicast cfg80211 operation
  (jsc#SLE-13430).
- wil6210: fix MID valid bits in Rx status message
  (jsc#SLE-13430).
- wil6210: reduce ucode_debug memory region (jsc#SLE-13430).
- wil6210: add verification for cid upper bound (jsc#SLE-13430).
- wil6210: take mem_lock for writing in crash dump collection
  (jsc#SLE-13430).
- wil6210: minimize the time that mem_lock is held
  (jsc#SLE-13430).
- wil6210: dump Rx status message on errors (jsc#SLE-13430).
- wcn36xx: disable HW_CONNECTION_MONITOR (jsc#SLE-13430).
- ath10k: Fix some typo in some warning messages (jsc#SLE-13430).
- ath: add support for special 0x0 regulatory domain
  (jsc#SLE-13430).
- ath10k: change bundle count for max rx bundle for sdio
  (jsc#SLE-13430).
- ath10k: enable napi on RX path for sdio (jsc#SLE-13430).
- ath10k: enable wow feature for sdio chip (jsc#SLE-13430).
- ath10k: change log level for mpdu status of sdio chip
  (jsc#SLE-13430).
- ath10k: set WMI_PEER_AUTHORIZE after a firmware crash
  (jsc#SLE-13430).
- ath10k: set max mtu to 1500 for sdio chip (jsc#SLE-13430).
- ath10k: enable firmware log by default for sdio (jsc#SLE-13430).
- ath10k: move non-fatal warn logs to dbg level (jsc#SLE-13430).
- commit 7f7df35
* Wed Sep 23 2020 tiwai@suse.de
- ath10k: fix RX of frames with broken FCS in monitor mode
  (jsc#SLE-13430).
- ath10k: report rssi of each chain to mac80211 for sdio
  (jsc#SLE-13430).
- ath10k: Handle "invalid" BDFs for msm8998 devices
  (jsc#SLE-13430).
- ath10k: add NL80211_FEATURE_ND_RANDOM_MAC_ADDR for NLO
  (jsc#SLE-13430).
- ath10k: Handle when FW doesn't support QMI_WLFW_HOST_CAP_REQ_V01
  (jsc#SLE-13430).
- ath10k: add large size for BMI download data for SDIO
  (jsc#SLE-13430).
- ath10k: sdio: remove struct ath10k_sdio_rx_data::status
  (jsc#SLE-13430).
- ath10k: sdio: cosmetic cleanup (jsc#SLE-13430).
- ath10k: add workqueue for RX path of sdio (jsc#SLE-13430).
- ath10k: change max RX bundle size from 8 to 32 for sdio
  (jsc#SLE-13430).
- ath10k: enable RX bundle receive for sdio (jsc#SLE-13430).
- ath9k: use iowrite32 over __raw_writel (jsc#SLE-13430).
- wcn36xx: fix typo (jsc#SLE-13430).
- ath10k: qmi: Sleep for a while before assigning MSA memory
  (jsc#SLE-13430).
- ath10k: disable cpuidle during downloading firmware
  (jsc#SLE-13430).
- ath10k: fix potential issue of peer stats allocation
  (jsc#SLE-13430).
- wcn36xx: remove unecessary return (jsc#SLE-13430).
- ath5k: eeprom: Remove unneeded variable (jsc#SLE-13430).
- wil6210: add SPDX license identifiers (jsc#SLE-13430).
- ath10k: remove unneeded semicolon (jsc#SLE-13430).
- ath: rename regulatory rules (jsc#SLE-13430).
- ath10k: fix memory leak for tpc_stats_final (jsc#SLE-13430).
- ath10k: fix array out-of-bounds access (jsc#SLE-13430).
- ath10k: fix null dereference on pointer crash_data
  (jsc#SLE-13430).
- ath10k: add support for hardware rfkill (jsc#SLE-13430).
- ath10k: coredump: fix IRAM addr for QCA9984, QCA4019, QCA9888
  and QCA99x0 (jsc#SLE-13430).
- commit 406f015
* Wed Sep 23 2020 msuchanek@suse.de
- powerpc/powernv/idle: add a basic stop 0-3 driver for POWER10
  (jsc#SLE-13616).
- powerpc/powernv/idle: Exclude mfspr on HID1, 4, 5 on P9 and
  above (jsc#SLE-13616).
- powerpc/powernv/idle: Rename pnv_first_spr_loss_level variable
  (jsc#SLE-13616).
- commit f39be34
* Wed Sep 23 2020 tiwai@suse.de
- wil6210: fix PTK re-key race (jsc#SLE-13430).
- Refresh
  patches.suse/wil6210-account-for-napi_gro_receive-never-returning.patch.
- commit 56f08b1
* Wed Sep 23 2020 tiwai@suse.de
- ath10k: switch to ieee80211_tx_dequeue_ni (jsc#SLE-13430).
- ath10k: change sw version print format to hex (jsc#SLE-13430).
- ath10k: print supported MCS rates within service ready event
  (jsc#SLE-13430).
- ath10k: print service ready returned channel range
  (jsc#SLE-13430).
- ath10k: add 2ghz channel arguments to service ready structure
  (jsc#SLE-13430).
- ath9k: remove unused including <linux/version.h>
  (jsc#SLE-13430).
- ath10k: remove the warning of sdio not full support
  (jsc#SLE-13430).
- ath: Use dev_get_drvdata where possible (jsc#SLE-13430).
- ath: fix various spelling mistakes (jsc#SLE-13430).
- ath10k: fix missing checks for bmi reads and writes
  (jsc#SLE-13430).
- ath10k: Add support to provide higher range mem chunks in wmi
  init command (jsc#SLE-13430).
- ath10k: Add peer param map for tlv and non-tlv (jsc#SLE-13430).
- ath10k: Enable MSA region dump support for WCN3990
  (jsc#SLE-13430).
- ath10k: Add xo calibration support for wifi rf clock
  (jsc#SLE-13430).
- ath10k: fix spelling mistake "eanble" -> "enable"
  (jsc#SLE-13430).
- ath10k: revalidate the msa region coming from firmware
  (jsc#SLE-13430).
- ath10k: use ath10k_pci_soc_ functions for all warm_reset
  instances (jsc#SLE-13430).
- ath10k: Use ARRAY_SIZE (jsc#SLE-13430).
- ath10k: avoid leaving .bss_info_changed prematurely
  (jsc#SLE-13430).
- ath10k: Use standard bulk clock API in snoc (jsc#SLE-13430).
- ath10k: Use standard regulator bulk API in snoc (jsc#SLE-13430).
- ath10k: snoc: skip regulator operations (jsc#SLE-13430).
- net/wireless: Use kmemdup rather than duplicating its
  implementation (jsc#SLE-13430).
- wil6210: ignore reset errors for FW during probe
  (jsc#SLE-13430).
- wil6210: fix RX short frame check (jsc#SLE-13430).
- wil6210: use writel_relaxed in wil_debugfs_iomem_x32_set
  (jsc#SLE-13430).
- wil6210: report boottime_ns in scan results (jsc#SLE-13430).
- wil6210: properly initialize discovery_expired_work
  (jsc#SLE-13430).
- wil6210: verify cid value is valid (jsc#SLE-13430).
- wil6210: make sure DR bit is read before rest of the status
  message (jsc#SLE-13430).
- wil6210: add debugfs to show PMC ring content (jsc#SLE-13430).
- ath10k: free beacon buf later in vdev teardown (jsc#SLE-13430).
- ath9k: Remove unneeded variable to store return value
  (jsc#SLE-13430).
- ath10k: add reorder and change PN check logic for mac80211
  (jsc#SLE-13430).
- ath10k: add mic bytes for pmf management packet (jsc#SLE-13430).
- ath6kl: Fix a possible null-pointer dereference in
  ath6kl_htc_mbox_create() (jsc#SLE-13430).
- commit 88690d2
* Wed Sep 23 2020 tiwai@suse.de
- ath9k: add loader for AR92XX (and older) pci(e) (jsc#SLE-13430).
- Update config files.
- supported.conf: add ath9k_pci_owl_loader
- commit 5336944
* Wed Sep 23 2020 tiwai@suse.de
- ath9k: dynack: set ackto to max timeout in ath_dynack_reset
  (jsc#SLE-13430).
- ath9k: dynack: set max timeout according to channel width
  (jsc#SLE-13430).
- ath9k: dynack: properly set last timeout timestamp in
  ath_dynack_reset (jsc#SLE-13430).
- ath9k: dyanck: introduce ath_dynack_set_timeout routine
  (jsc#SLE-13430).
- carl9170: remove set but not used variable 'udev'
  (jsc#SLE-13430).
- wil6210: Delete an unnecessary kfree() call in
  wil_tid_ampdu_rx_alloc() (jsc#SLE-13430).
- wil6210: Add EDMG channel support (jsc#SLE-13430).
- wil6210: fix wil_cid_valid with negative cid values
  (jsc#SLE-13430).
- commit 19acb2a
* Wed Sep 23 2020 tiwai@suse.de
- staging: r8188eu: replace rtw_netdev_priv define with inline
  function (jsc#SLE-13430).
- staging: rtl8723bs: Align macro definitions (jsc#SLE-13430).
- staging: rtl8723bs: Clean up function declations
  (jsc#SLE-13430).
- staging: rtl8723bs: Fix coding style errors (jsc#SLE-13430).
- Staging: rtl8712: Fixed a coding sytle issue (jsc#SLE-13430).
- staging: rtl8723bs: remove redundant assignment to variable ret
  (jsc#SLE-13430).
- staging: rtl8712: Use fallthrough pseudo-keyword
  (jsc#SLE-13430).
- staging: rtl8723bs: Use fallthrough pseudo-keyword
  (jsc#SLE-13430).
- staging: rtl8192e: Use fallthrough pseudo-keyword
  (jsc#SLE-13430).
- staging: r8188eu: use proper type for second argiment of
  rtw_(aes|tkip|wep)_(decrypt|encrypt) (jsc#SLE-13430).
- STAGING - REALTEK RTL8188EU DRIVERS: Fix Coding Style Error
  (jsc#SLE-13430).
- Staging: rtl8188eu: Fix a constant comparison coding style issue
  (jsc#SLE-13430).
- staging: rtl8723bs: Cleanup open brace issues (jsc#SLE-13430).
- staging: rtl8188eu: Fix an indent coding style issue
  (jsc#SLE-13430).
- staging: rtl8188eu: cleanup whitespace in declarations
  (jsc#SLE-13430).
- staging: rtl8188eu: clear alignment style issues
  (jsc#SLE-13430).
- staging: rtl8192e: add proper code indent (jsc#SLE-13430).
- staging: rtl8192e: add space before open parenthesis
  (jsc#SLE-13430).
- staging: rtl8188eu: add spaces around operators in header files
  (jsc#SLE-13430).
- Staging: rtl8188eu: core: Fix coding style issue
  (jsc#SLE-13430).
- staging: rtl8188eu: include: fixed multiple blank space coding
  style issues (jsc#SLE-13430).
- staging: rtl8188eu: clear tabstop style issues (jsc#SLE-13430).
- staging: rtl8188eu: add blank line after declarations
  (jsc#SLE-13430).
- staging: rtl*/security: Use static const in array declarations
  (jsc#SLE-13430).
- staging: rtl8188eu: core: fix coding style issues
  (jsc#SLE-13430).
- staging: r8188eu: remove unused members of struct xmit_buf
  (jsc#SLE-13430).
- staging: rtl8192e: rtl_core: Remove pci-dma-compat wrapper APIs
  (jsc#SLE-13430).
- staging: rtl8192e: rtl8192E_dev: Remove pci-dma-compat wrapper
  APIs (jsc#SLE-13430).
- staging: rtl8712/: Using comparison to true is error prone
  (jsc#SLE-13430).
- staging: rtl8712: Use proper format in call to dev_err()
  (jsc#SLE-13430).
- staging: rtl8712: Remove variable 'raw' from rtl871x_open_fw()
  (jsc#SLE-13430).
- staging: rtl8712: Use ETH_ALEN instead of hardcoded value
  (jsc#SLE-13430).
- staging: rtl8712: Simplify expressions with boolean logic
  (jsc#SLE-13430).
- staging: rtl8712: Replace constant 49152 with expression 48 *
  1024 (jsc#SLE-13430).
- staging: rtl8188eu: Use fallthrough pseudo-keyword
  (jsc#SLE-13430).
- staging: rtl8723bs: Using comparison to true is error prone
  (jsc#SLE-13430).
- staging: rtl8192u: Using comparison to true is error prone
  (jsc#SLE-13430).
- staging: rtl8712: Annotate r8712_sitesurvey_cmd()
  (jsc#SLE-13430).
- staging: rtl8192u: remove copying file (jsc#SLE-13430).
- staging: rtl8192u: remove GPL boiler plate text (jsc#SLE-13430).
- staging: rtl8712: base_types: Remove unused macros
  (jsc#SLE-13430).
- staging: rtl8712: Replace FIELD_OFFSET() with offsetof()
  (jsc#SLE-13430).
- staging: rtl8712: use common ieee80211 constants
  (jsc#SLE-13430).
- staging: rtl8188eu: Fix WARNINGs of Block comments
  (jsc#SLE-13430).
- staging: rtl8188eu: Fix CHECK of coding style (jsc#SLE-13430).
- staging: rtl8188eu: use common ieee80211 constants
  (jsc#SLE-13430).
- staging: rtl8188eu: remove unused parameter (jsc#SLE-13430).
- staging: rtl8188eu: core: Fix coding style issue
  (jsc#SLE-13430).
- staging: rtl8188eu: core: Fix WARNING of Block comments
  (jsc#SLE-13430).
- staging: rtl8188eu: Replace function name with __func__
  (jsc#SLE-13430).
- staging: rtl8712: remove some ieee80211 constants from wifi.h
  (jsc#SLE-13430).
- staging: rtl8723bs: remove some ieee80211 constants from wifi.h
  (jsc#SLE-13430).
- staging: rtl8188eu: remove some ieee80211 constants from wifi.h
  (jsc#SLE-13430).
- staging: rtl8188eu: add spaces around operators (jsc#SLE-13430).
- staging: rtl8188eu: use compound assignment operators
  (jsc#SLE-13430).
- staging: rtl8192e: use generic power management (jsc#SLE-13430).
- staging: rtl8188eu: include: odm.h: fixed a blank space coding
  style issue (jsc#SLE-13430).
- staging: rtl8188eu: include: hal8188e_rate_adaptive.h: fixed
  a blank space coding style issue (jsc#SLE-13430).
- staging: rtl8188eu: remove unnecessary comments in
  hal8188e_phy_cfg.h (jsc#SLE-13430).
- staging: rtl8188eu: remove blank lines in header files
  (jsc#SLE-13430).
- staging: rtl8188eu: Fix indentation (jsc#SLE-13430).
- staging: rtl8188eu: Fix strings split across lines
  (jsc#SLE-13430).
- commit 44ab7ed
* Wed Sep 23 2020 dwagner@suse.de
- wireguard: peerlookup: take lock before checking hash in
  replace operation (git-fixes).
- wireguard: noise: take lock when removing handshake entry from
  table (git-fixes).
- commit 742e9a3
* Wed Sep 23 2020 tiwai@suse.de
- staging: rtl8188eu: Fix comment formatting (jsc#SLE-13430).
- Staging: rtl8188eu: Fix alignment coding style issue
  (jsc#SLE-13430).
- staging: rtl8188eu: use common packet header constants
  (jsc#SLE-13430).
- staging:rtl8712: avoid skb_clone after skb allocation fail
  (jsc#SLE-13430).
- staging:r8723bs: remove wrappers around skb_clone() and remove
  unnecessary in_interrupt() call (jsc#SLE-13430).
- staging: rtl8712: Remove unnecesary else after return statement
  (jsc#SLE-13430).
- staging: rtl8712: switch to common ieee80211 headers
  (jsc#SLE-13430).
- staging: rtl8723bs: Use common packet header constants
  (jsc#SLE-13430).
- staging: rtl8188eu: make some arrays static const
  (jsc#SLE-13430).
- staging: rtl8188eu: clean up some declarations (jsc#SLE-13430).
- staging/rtl8192e: Remove function callback casts
  (jsc#SLE-13430).
- staging: rtl8192e: Using comparison to true is error prone
  (jsc#SLE-13430).
- staging: rtl8192u: Merge almost duplicate code (jsc#SLE-13430).
- staging: rtl8192u: Using comparison to true is error prone
  (jsc#SLE-13430).
- staging: rtl8723bs: Using comparison to true is error prone
  (jsc#SLE-13430).
- Staging: rtl8723bs: os_de: if-else coding style issue
  (jsc#SLE-13430).
- staging:rtl8723bs: eliminate usage of skb_clone after skb
  allocation fail (jsc#SLE-13430).
- staging: rtl8723bs: remove conversion to bool in
  halbtcoutsrc_Get() (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: Cleanup pointer casting code style
  (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: remove rtw_spt_band_free()
  (jsc#SLE-13430).
- staging: rtl8723bs: core: remove set but not used 'pframe'
  (jsc#SLE-13430).
- staging: rtl8723bs: core: remove set but not used 'pwrpriv'
  (jsc#SLE-13430).
- staging: rtl8723bs: core: remove set but not used
  'listen_interval' (jsc#SLE-13430).
- staging: rtl8723bs: core: remove set but not used 'algthm'
  (jsc#SLE-13430).
- Staging: rtl8723bs: core: remove set but not used 'ptxservq'
  (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: remove set but not used 'size'
  (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: remove set but not used 'uintRet'
  (jsc#SLE-13430).
- staging: rtl8188eu: remove some superfluous comments
  (jsc#SLE-13430).
- staging:r8188eu: avoid skb_clone for amsdu to msdu conversion
  (jsc#SLE-13430).
- Staging: rtl8188eu: core: rtw_pwrctrl: fixed a coding style
  issue (jsc#SLE-13430).
- Staging: rtl8723bs: Fix comment typo "the the" (jsc#SLE-13430).
- Staging: rtl8723bs: rtw_wlan_util: Add size check of SSID IE
  (jsc#SLE-13430).
- staging: rtl8723bs: remove unused variable 'pregistrypriv'
  (jsc#SLE-13430).
- staging: rtl8723bs: remove defined but not used
  'dB_Invert_Table' (jsc#SLE-13430).
- staging: rtl8723bs: remove some variables in hal_btcoex.c
  (jsc#SLE-13430).
- staging: rtl8188eu: make const char array static
  (jsc#SLE-13430).
- staging: rtl8188eu: cleanup long line in fw.c (jsc#SLE-13430).
- staging: rtl8188eu: rename define to upper case (jsc#SLE-13430).
- staging: rtl8712: correct spelling mistake in comment
  (jsc#SLE-13430).
- staging: r8188eu: replace rtw_malloc/copy_from_user sequence
  with memdup_user (jsc#SLE-13430).
- staging: rtl8188eu: remove 5 GHz if test (jsc#SLE-13430).
- staging: rtl8723bs: hal: Correct misspelled symbolic name
  (jsc#SLE-13430).
- staging: rtl8723bs: hal: Correct misspelt enum name
  (jsc#SLE-13430).
- staging: rtl8723bs: Correct misspelt symbolic names
  (jsc#SLE-13430).
- staging: rtl8188eu: Line over 80 characters (jsc#SLE-13430).
- staging: rtl8188eu: Remove unnecessary extra parentheses
  (jsc#SLE-13430).
- staging: rtl8188eu: Properly structure the multiline comment
  (jsc#SLE-13430).
- staging: rtl8188eu: remove unnecessary variable (jsc#SLE-13430).
- commit 1f82977
* Wed Sep 23 2020 dwagner@suse.de
- series: Update meta data
- commit 46acdd6
* Wed Sep 23 2020 tiwai@suse.de
- Staging: rtl8188eu: rtw_mlme: Add space around operators
  (jsc#SLE-13430).
- Refresh
  patches.suse/Staging-rtl8188eu-rtw_mlme-Fix-uninitialized-variabl.patch.
- commit 1dbce4a
* Wed Sep 23 2020 tiwai@suse.de
- staging: rtl8188eu: remove unnecessary asignment
  (jsc#SLE-13430).
- staging: rtl8192e: rtl8192e: Correct misspelt variable name
  (jsc#SLE-13430).
- staging: rtl8712: fix multiline derefernce warnings
  (jsc#SLE-13430).
- staging: rtl8712: code improvements to make_wlanhdr
  (jsc#SLE-13430).
- staging: rtl8712: fix checkpatch warnings (jsc#SLE-13430).
- staging: rtl8712: fix long-line checkpatch warning
  (jsc#SLE-13430).
- staging: rtl8712: fix checkpatch long-line warning
  (jsc#SLE-13430).
- staging: rtl8188eu: refactor Efuse_GetCurrentSize()
  (jsc#SLE-13430).
- staging: rtl8188eu: remove unnecessary parentheses
  (jsc#SLE-13430).
- Staging: rtl8192u: ieee80211: Use netdev_alert()
  (jsc#SLE-13430).
- Staging: rtl8192u: ieee80211: Use netdev_info() with network
  devices (jsc#SLE-13430).
- Staging: rtl8192u: ieee80211: Use netdev_warn() for network
  devices (jsc#SLE-13430).
- Staging: rtl8192u: ieee80211: Use netdev_dbg() for debug
  messages (jsc#SLE-13430).
- staging: rtl8723bs: hal: Remove NULL check before kfree
  (jsc#SLE-13430).
- staging: rtl8723bs: hal: Correct typos in comments
  (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: Correct typos in comments
  (jsc#SLE-13430).
- staging: rtl8723bs: core: Correct typos in comments
  (jsc#SLE-13430).
- staging: rtl8723bs: hal: Remove unnecessary cast on void pointer
  (jsc#SLE-13430).
- staging: rtl8188eu: cleanup long line in odm.c (jsc#SLE-13430).
- staging: rtl8723bs: hal: Compress return logic (jsc#SLE-13430).
- staging: rtl8723bs: rtw_cmd: Compress lines for immediate return
  (jsc#SLE-13430).
- staging: rtl8723bs: rtw_efuse: Compress lines for immediate
  return (jsc#SLE-13430).
- staging: rtl8723bs: Remove blank line before '}' brace
  (jsc#SLE-13430).
- Staging: rtl8188eu: hal: Add space around operators
  (jsc#SLE-13430).
- staging: rtl8723bs: Add line after variable declarations
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove multiple assignments (jsc#SLE-13430).
- staging: rtl8723bs: Remove unnecessary braces for single
  statements (jsc#SLE-13430).
- staging: rtl8188eu: remove some 5 GHz code (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: Remove whitespace characters in
  code line (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: Correct long line comments
  (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: Remove commented out code lines
  (jsc#SLE-13430).
- staging: rtl8723bs: remove unneeded variables (jsc#SLE-13430).
- staging: rtl8723bs: hal: Correct typos in comments
  (jsc#SLE-13430).
- staging: rtl8723bs: hal: Correct multi-line comments as per
  coding style (jsc#SLE-13430).
- staging: rtl8712: Remove unnecessary braces (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: Correct typo in comments
  (jsc#SLE-13430).
- staging: rtl8712: Fix for long lines in Kconfig help
  (jsc#SLE-13430).
- staging: rtl8188eu: core: Correct a typo in a comment
  (jsc#SLE-13430).
- staging: rtl8188eu: include: Correct a typo in a comment
  (jsc#SLE-13430).
- staging: rtl8192u: ieee80211: Correct a typo in a comment
  (jsc#SLE-13430).
- staging: rtl8712: Correct a typo in a comment (jsc#SLE-13430).
- staging: rtl8192u: r8192U_wx: use netdev_warn() instead of
  printk() (jsc#SLE-13430).
- staging: rtl8192u: Corrects 'Avoid CamelCase' for variables
  (jsc#SLE-13430).
- staging: rtl8192u: Using function name as string
  (jsc#SLE-13430).
- staging: rtl8192u: Replaces symbolic permissions with octal
  permissions (jsc#SLE-13430).
- Staging: rtl8723bs: sdio_halinit: Remove unnecessary conditions
  (jsc#SLE-13430).
- Staging: rtl8723bs: rtw_mlme: Remove unnecessary conditions
  (jsc#SLE-13430).
- staging: rtl8712: Fixes for simple typos in C comments
  (jsc#SLE-13430).
- staging: rtl8723bs: Use scnprintf() for avoiding potential
  buffer overflow (jsc#SLE-13430).
- commit c4a1cc7
* Wed Sep 23 2020 tiwai@suse.de
- staging: rtl8192e: Use scnprintf() for avoiding potential
  buffer overflow (jsc#SLE-13430).
- staging: rtl8188eu: Use scnprintf() for avoiding potential
  buffer overflow (jsc#SLE-13430).
- staging: rtl8188eu: fix typo s/informations/information
  (jsc#SLE-13430).
- Staging: rtl8188eu: Add space around operator (jsc#SLE-13430).
- Staging: rtl8723bs: Remove comparison to true (jsc#SLE-13430).
- staging: rtl8723bs: core: remove redundant zero'ing of counter
  variable k (jsc#SLE-13430).
- staging: rtl8188eu: remove redundant assignment to cond
  (jsc#SLE-13430).
- staging: rtl8723bs: remove temporary variable CrystalCap
  (jsc#SLE-13430).
- staging: rtl8192e: remove redundant initialization of variable
  init_status (jsc#SLE-13430).
- staging: rtl8723bs: Fix spacing issues (jsc#SLE-13430).
- staging: rtl8188eu: rename variable pnetdev -> netdev
  (jsc#SLE-13430).
- staging: rtl8192u: Add space to fix style issue (jsc#SLE-13430).
- staging: rtl8188eu: remove unnecessary RETURN label
  (jsc#SLE-13430).
- staging: rtl8192e: style fix - Prefer using '"%%s...", __func__'
  (jsc#SLE-13430).
- staging: rtl8723bs: hal: fix condition with no effect
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove unneeded goto statements
  (jsc#SLE-13430).
- staging: rtl8188eu: Remove some unneeded goto statements
  (jsc#SLE-13430).
- staging: rtl8712: simplify evm_db2percentage() (jsc#SLE-13430).
- staging: rtl8192u: simplify rtl819x_evm_dbtopercentage()
  (jsc#SLE-13430).
- staging: rtl8192e: simplify rtl92e_evm_db_to_percent()
  (jsc#SLE-13430).
- staging: rtl8188eu: remove unused enum and defines
  (jsc#SLE-13430).
- staging: rtl8188eu: remove redundant defines (jsc#SLE-13430).
- staging: rtl8188eu: remove else after break or return
  (jsc#SLE-13430).
- staging: rtl8192u: replace printk with natdev_<LEVEL> statements
  in ieee80211 (jsc#SLE-13430).
- staging: rtl8188eu: cleanup whitespace in rtl8188e_dm.c
  (jsc#SLE-13430).
- staging: rtl8188eu: remove unnecessary parentheses in
  rtl8188e_dm.c (jsc#SLE-13430).
- staging: rtl8188eu: cleanup long lines in rtl8188e_dm.c
  (jsc#SLE-13430).
- staging: rtl8188eu: convert rtw_hal_antdiv_before_linked()
  to bool (jsc#SLE-13430).
- staging: rtl8188eu: refactor rtw_hal_antdiv_before_linked()
  (jsc#SLE-13430).
- staging: rtl8723bs: remove ODM_GetRightChnlPlaceforIQK()
  (jsc#SLE-13430).
- staging: rtl8188eu: remove unused parameters from
  rtw_check_network_type (jsc#SLE-13430).
- staging: rtl8192u: remove unneeded compiler flags
  (jsc#SLE-13430).
- staging: rtl8192u: remove header include path to ieee80211/
  (jsc#SLE-13430).
- staging: rtl8192u: remove unused Makefile (jsc#SLE-13430).
- staging: rtl8188eu: refactor rtl88eu_dm_update_rx_idle_ant()
  (jsc#SLE-13430).
- staging: rtl8188eu: remove else after return (jsc#SLE-13430).
- staging: rtl8188eu: use break to exit while loop
  (jsc#SLE-13430).
- staging: rtl8188eu: add spaces around operators in
  rtw_mlme_ext.c (jsc#SLE-13430).
- staging: rtl8188eu: cleanup comparsions to NULL in
  rtw_mlme_ext.c (jsc#SLE-13430).
- staging: rtl8723bs: Fix line length (jsc#SLE-13430).
- staging: rtl8723bs: Fix spelling errors (jsc#SLE-13430).
- staging: rtl8188eu: remove return variable from
  rtw_pwr_unassociated_idle (jsc#SLE-13430).
- staging: rtl8188eu: cleanup declarations in rtw_pwrctrl.c
  (jsc#SLE-13430).
- staging: rtl8188eu: remove unnecessary parentheses in
  rtw_pwrctrl.c (jsc#SLE-13430).
- staging: rtl8723bs: remove set but not used variable 'change',
  'pos' (jsc#SLE-13430).
- staging: rtl8723bs: remove set but not used variable
  'notify_ielen', 'notify_ie', 'notify_interval',
  'notify_capability' (jsc#SLE-13430).
- staging: rtl8723bs: remove set but not used variable
  'pmlmeinfo', 'pHalData' (jsc#SLE-13430).
- commit 310b9ca
* Wed Sep 23 2020 tiwai@suse.de
- staging: rtl8723bs: remove set but not used variable 'pHalData',
  'pdmpriv' (jsc#SLE-13430).
- staging: rtl8723bs: remove set but not used variable 'pHalData',
  'pregistrypriv' (jsc#SLE-13430).
- staging: rtl8192e: remove set but not used variable 'frag'
  (jsc#SLE-13430).
- staging: rtl*: Remove tasklet callback casts (jsc#SLE-13430).
- staging: rtl8723bs: fix indentation issue (jsc#SLE-13430).
- staging: rtl8192u: fix indentation issue (jsc#SLE-13430).
- staging: rtl8723bs: Remove unnecessary braces (jsc#SLE-13430).
- staging: rtl8723bs: Remove blank lines after an open brace
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove blank lines before a close brace
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove multiple blank lines (jsc#SLE-13430).
- staging: rtl8723bs: Remove commented code (jsc#SLE-13430).
- staging: rtl8192u: Fix typo in comment (jsc#SLE-13430).
- staging: rtl8723bs: Simplify boolean expression (jsc#SLE-13430).
- staging: rtl8723bs: Fix line over 80 characters (jsc#SLE-13430).
- staging: rtl8723bs: hal: Remove unnecessary typecast in kfree
  (jsc#SLE-13430).
- staging: rtl8723bs: Fix lines over 80 characters
  (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: Remove unnecessary variable used
  in return statement (jsc#SLE-13430).
- staging: rtl8723bs: Remove unnecessary parentheses
  (jsc#SLE-13430).
- staging: rtl8712: Fix Alignment of open parenthesis
  (jsc#SLE-13430).
- staging: rtl8188eu: replace tabs with spaces - style
  (jsc#SLE-13430).
- staging: rtl8188eu: remove return variable from
  rtw_init_bcmc_stainfo (jsc#SLE-13430).
- staging: rtl8188eu: reduce indentation level in
  _rtw_free_sta_priv (jsc#SLE-13430).
- staging: rtl8188eu: remove exit label from rtw_alloc_stainfo
  (jsc#SLE-13430).
- staging: rtl8712: Remove lines before a close brace
  (jsc#SLE-13430).
- staging: rtl8188eu: reduce indentation level in
  rtw_alloc_stainfo (jsc#SLE-13430).
- staging: rtl8188eu: cleanup long lines in rtw_sta_mgt.c
  (jsc#SLE-13430).
- staging: rtl8188eu: remove ternary operator (jsc#SLE-13430).
- staging: rtl8188eu: convert rtw_access_ctrl to return bool
  (jsc#SLE-13430).
- staging: rtl8188eu: rename array bcast_addr (jsc#SLE-13430).
- staging: rtl8188eu: convert unsigned char array to u8
  (jsc#SLE-13430).
- staging: rtl8188eu: cleanup comments in rtw_sta_mgt.c
  (jsc#SLE-13430).
- staging: rtl8723bs: Change tabs for spaces (jsc#SLE-13430).
- staging: rtl8723bs: Fix function call format (jsc#SLE-13430).
- staging: rtl8723bs: Fix indentation warnings (jsc#SLE-13430).
- staging: rtl8723bs: Remove commented code (jsc#SLE-13430).
- staging: rtl8723bs: Add spaces between operators
  (jsc#SLE-13430).
- staging: rtl8723bs: Fix lines over 80 characters
  (jsc#SLE-13430).
- staging: rtl8723bs: Replace string with identifier
  (jsc#SLE-13430).
- staging: rtl8188eu: remove code valid only for 5 GHz
  (jsc#SLE-13430).
- staging: rtl8723bs: reduce stack usage of cfg80211_rtw_scan
  (jsc#SLE-13430).
- staging: rtl8723bs: reduce stack usage of
  rtw_cfg80211_unlink_bss (jsc#SLE-13430).
- staging: rtl8723bs: removed unwanted if..else condition
  (jsc#SLE-13430).
- staging: rtl8188eu: make efuse_power_switch() function static
  (jsc#SLE-13430).
- staging: rtl8188eu: remove blank lines (jsc#SLE-13430).
- staging: rtl8188eu: convert variables from unsigned char to u8
  (jsc#SLE-13430).
- staging: rtl8188eu: rename variables to avoid mixed case
  (jsc#SLE-13430).
- staging: rtl8723bs: remove casts to pointers in kfree
  (jsc#SLE-13430).
- staging: rtl8723bs: remove unnecessary null check
  (jsc#SLE-13430).
- staging: rtl8723bs: use DIV_ROUND_UP helper macro
  (jsc#SLE-13430).
- staging: rtl8188eu: remove unnecessary conversion to bool
  (jsc#SLE-13430).
- commit 1148f6c
* Wed Sep 23 2020 tiwai@suse.de
- staging: rtl8188eu: remove braces from single statement if block
  (jsc#SLE-13430).
- staging: rtl8712: clean up function headers (jsc#SLE-13430).
- staging: rtl8712: remove unnecessary return variables
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove comparison to NULL (jsc#SLE-13430).
- staging: rtl8723bs: Remove unnecessary null check
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove unnecessary blank lines
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove comparisons to booleans in
  conditionals (jsc#SLE-13430).
- staging: rtl8723bs: Remove unnecessary braces for single
  statements (jsc#SLE-13430).
- staging: rtl8723bs: Remove comparisons to NULL in conditionals
  (jsc#SLE-13430).
- staging: rtl8712: Align function arguments with opening
  paranthesis (jsc#SLE-13430).
- staging: rtl8723bs: Fix style in definitions (jsc#SLE-13430).
- staging: rtl8723bs: Remove space before tabs (jsc#SLE-13430).
- staging: rtl8723bs: Remove duplicate blank lines
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove commented code (jsc#SLE-13430).
- staging: rtl8723bs: Fix incorrect type in declaration
  (jsc#SLE-13430).
- staging: rtl8723bs: Add space between elements (jsc#SLE-13430).
- staging: rtl8723bs: Fix function call wrapping style
  (jsc#SLE-13430).
- staging: rtl8723bs: Fix line over 80 characters (jsc#SLE-13430).
- staging: rtl8723bs: Remove File operation APIs (jsc#SLE-13430).
- staging: rtl8723bs: Remove rtw_merge_string() function
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove phy_Config*WithParaFile()
  configuration leftovers (jsc#SLE-13430).
- staging: rtl8723bs: Remove phy_Config*WithParaFile() functions
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove phy_Config*With*ParaFile() calls
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove set but not used variable 'i'
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove space before tab (jsc#SLE-13430).
- staging: rtl8723bs: Replace string with identifier
  (jsc#SLE-13430).
- staging: rtl8723bs: core: Remove typecast in call to kfree
  (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: Remove typecast in kfree
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove commented code (jsc#SLE-13430).
- staging: rtl8723bs: fix typo of "mechanism" in comment
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove set but not used variable 'adapter'
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove set but not used variables 'ppp',
  'type', 'data' (jsc#SLE-13430).
- staging: rtl8723bs: Remove set but not used variable
  'prwskeylen' (jsc#SLE-13430).
- staging: rtl8723bs: Remove set but not used variable 'tmp_aid'
  (jsc#SLE-13430).
- staging: rtl8712: align arguments with open parenthesis in
  file rtl8712_led.c (jsc#SLE-13430).
- staging: rtl8723bs: Switch constant place in test
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove unnecessary braces (jsc#SLE-13430).
- staging: rtl8192u: Fix indentation for cleaner code
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove set but not used variable 'oldcnt'
  (jsc#SLE-13430).
- staging: rtl8188eu: remove unnecessary asignment and
  initialization (jsc#SLE-13430).
- staging: rtl8723bs: Remove unnecessary braces (jsc#SLE-13430).
- staging: rtl8188eu: cleanup comments in update_hw_ht_param
  (jsc#SLE-13430).
- staging: rtl8188eu: cleanup whitespace in update_hw_ht_param
  (jsc#SLE-13430).
- staging: rtl8188eu: rename variables to avoid mixed case
  (jsc#SLE-13430).
- staging: rtl8188eu: convert variables from unsigned char to u8
  (jsc#SLE-13430).
- staging: rtl8712: fix boundary condition for n (jsc#SLE-13430).
- staging: rtl8723bs: remove unused function write_cam_from_cache
  (jsc#SLE-13430).
- staging: rtl8192e: clean up indentation issue (jsc#SLE-13430).
- staging: rtl8188eu: remove dead code/vestigial do..while loop
  (jsc#SLE-13430).
- staging: rtl8192u: release memory on error path (jsc#SLE-13430).
- commit bb1e306
* Wed Sep 23 2020 tiwai@suse.de
- staging: rtl8712: Replace snprintf with scnprintf
  (jsc#SLE-13430).
- staging: rtl8192u: Remove unnecessary line-breaks in function
  signatures (jsc#SLE-13430).
- staging: rtl8192u: Fix alignment to match open parenthesis
  (jsc#SLE-13430).
- staging: rtl8192u: Remove unnecessary blank lines
  (jsc#SLE-13430).
- staging: rtl8192u: ieee80211: Replace snprintf with scnprintf
  (jsc#SLE-13430).
- staging: rtl8188eu: remove unnecessary self-assignment
  (jsc#SLE-13430).
- staging: rtl8188eu: cleanup long line in rtw_mlme_ext.c
  (jsc#SLE-13430).
- staging: rtl8723bs: remove return statements from void functions
  (jsc#SLE-13430).
- staging: rtl8723bs: remove unneeded conversion to bool
  (jsc#SLE-13430).
- staging: rtl8723bs: core: make array op_class static const,
  makes object smaller (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: fix spelling mistake "offet" ->
  "offset" (jsc#SLE-13430).
- staging: rtl8723bs: Removed unneeded variables (jsc#SLE-13430).
- staging: rtl8188eu: make two arrays static const, makes object
  smaller (jsc#SLE-13430).
- staging: rtl8723bs: core: Remove Macro
  "IS_MAC_ADDRESS_BROADCAST" (jsc#SLE-13430).
- staging: rtl8723bs: hal: remove redundant variable n
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove return statement from void function
  (jsc#SLE-13430).
- staging: rtl8192e: remove unnecessary blank line
  (jsc#SLE-13430).
- Staging: rtl8723bs: Use kzfree rather than its implementation
  (jsc#SLE-13430).
- staging: rtl8723bs: replace __inline by inline (jsc#SLE-13430).
- staging: r8188eu: use skb_put_data instead of skb_put/memcpy
  pair (jsc#SLE-13430).
- staging: rtl8192u: Fix indentation (jsc#SLE-13430).
- staging: rtl8192u: Add or remove blank lines as required
  (jsc#SLE-13430).
- staging: rtl8192u: Add or remove spaces to fix style issues
  (jsc#SLE-13430).
- staging: rtl8712: wifi: checkpatch style fix (jsc#SLE-13430).
- staging: rtl8192u: Add space around binary operators
  (jsc#SLE-13430).
- staging: rtl8192u: remove code under TO_DO_LIST (jsc#SLE-13430).
- staging: rtl8192u: Remove unnecessary blank lines
  (jsc#SLE-13430).
- staging: rtl8192u: remove redundant assignment to pointer crypt
  (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: Drop condition with no effect
  (jsc#SLE-13430).
- staging: rtl8723bs: hal: Drop condition with no effect
  (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: Remove unused declarations
  (jsc#SLE-13430).
- staging: rtl8192u: fix spacing in ieee80211 (jsc#SLE-13430).
- staging: rtl8192u: fix macro alignment in ieee80211
  (jsc#SLE-13430).
- staging: rtl8192u: fix OPEN_BRACE errors in ieee80211
  (jsc#SLE-13430).
- staging: rtl8192e: remove set but not used variable 'data_len'
  (jsc#SLE-13430).
- staging: rtl8192e: remove two set but not used variables
  (jsc#SLE-13430).
- staging: rtl8192u: ieee80211: remove set but not used variable
  'data_len' (jsc#SLE-13430).
- staging: rtl8712: Improve naming of include hearder guards
  (jsc#SLE-13430).
- staging: rtl8723bs: core: Remove unneeded declaration WFD_OUI
  (jsc#SLE-13430).
- staging: rtl8192e: rtllib_crypt_ccmp.c: Use crypto API ccm(aes)
  (jsc#SLE-13430).
- staging: rtl8192u: ieee80211: ieee80211_crypt_ccmp.c: Use
  crypto API ccm(aes) (jsc#SLE-13430).
- staging: rtl8192u: fix up indentation of a statement
  (jsc#SLE-13430).
- staging: rtl8723bs: remove redundant assignment to ret
  (jsc#SLE-13430).
- Staging: rtl8712: rtl8712_recv: fixed 80 character length
  warning (jsc#SLE-13430).
- staging: rtl8712: r8712_dump_aggr_xframe(): Change type to void
  (jsc#SLE-13430).
- staging: rtl8712: r8712_xmitframe_aggr_1st(): Change return
  type to void (jsc#SLE-13430).
- staging: rtl8712: r8712_append_mpdu_unit(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: xmitframe_addmic(): Change return values
  and type (jsc#SLE-13430).
- staging: rtl8723bs: Remove debugging information exposed via
  procfs (jsc#SLE-13430).
- staging: rtl8192u: fix spacing errors (jsc#SLE-13430).
- commit e32ced2
* Wed Sep 23 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/btrfs-require-only-sector-size-alignment-for-parent-.patch
- commit ee89c1f
* Wed Sep 23 2020 tiwai@suse.de
- staging: rtl8712: r8712_construct_txaggr_cmd_hdr(): Change
  return type (jsc#SLE-13430).
- staging: rtl8712: r8712_construct_txaggr_cmd_desc(): Change
  return type (jsc#SLE-13430).
- staging: rtl8712: r8712_xmit_direct(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: r8712_free_xmitbuf(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: make_wlanhdr(): Change return values and type
  (jsc#SLE-13430).
- staging: rtl8712: r8712_update_attrib(): Change return values
  and type (jsc#SLE-13430).
- staging: rtl8712: _r8712_init_xmit_priv(): Change return values
  and type (jsc#SLE-13430).
- staging: rtl8712: r8712_xmit_classifier(): Change return values
  and type (jsc#SLE-13430).
- staging: rtl8712: Remove while loop and check_cmd_fifo()
  (jsc#SLE-13430).
- staging: rtl8712: r8712_free_drv_sw(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: init_drv_sw(): Change return values
  (jsc#SLE-13430).
- staging: rtl8712: init_default_value(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: recvbuf2recvframe(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: r8712_recv_entry(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: r8712_wlanhdr_to_ethhdr(): Change return
  values (jsc#SLE-13430).
- staging: rtl8712: recv_indicatepkt_reorder(): Change return
  values (jsc#SLE-13430).
- staging: rtl8712: amsdu_to_msdu(): Change return type
  (jsc#SLE-13430).
- staging: rtl8723bs: fix brace position in enum declaration
  (jsc#SLE-13430).
- Staging: rtl8188eu: core: rtw_security: tidy up crc32_init()
  (jsc#SLE-13430).
- staging: rtl8192e: Make use kmemdup (jsc#SLE-13430).
- staging: rtl8723bs: core: add spaces around '-', '+', '&','|'
  and '?' (jsc#SLE-13430).
- staging: rtl8723bs: core: Remove Unnecessary parentheses
  (jsc#SLE-13430).
- staging: rtl8723bs: core: correct spelling mistake in rtw_ap.c
  (jsc#SLE-13430).
- staging: rtl8188eu: core: add spaces around '-', '+', '>>','<<'
  and '*' in rtw_efuse.c (jsc#SLE-13430).
- staging: rtl8712: Add spaces around << (jsc#SLE-13430).
- staging: rtl8188eu: core: rtw_recv.c: Remove Unnecessary
  parentheses (jsc#SLE-13430).
- staging: rtl8712: r8712_aes_decrypt(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: aes_decipher(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: aes_cipher(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: r8712_tkip_decrypt(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: r8712_os_recvbuf_resource_free(): Change
  return type (jsc#SLE-13430).
- staging: rtl8712: r8712_os_recvbuf_resource_alloc(): Change
  return values (jsc#SLE-13430).
- staging: rtl8712: r8712_init_recv_priv(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: _r8712_init_recv_priv(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: r8712_os_recv_resource_alloc(): Change return
  type (jsc#SLE-13430).
- staging: rtl8723bs: Replace hal_btcoex_Initialize()
  (jsc#SLE-13430).
- staging: rtl8723bs: Change return type of hal_btcoex_IsLpsOn()
  (jsc#SLE-13430).
- staging: rtl8723bs: Change return type of
  hal_btcoex_IsBtControlLps() (jsc#SLE-13430).
- staging: rtl8723bs: Change return type of hal_btcoex_IsBtExist()
  (jsc#SLE-13430).
- staging: rtl8723bs: remove set but not used variable
  'FirstConnect' (jsc#SLE-13430).
- staging: rtl8723bs: remove set but not used variables 'prspbuf'
  and 'auth' (jsc#SLE-13430).
- staging: rtl8192u: null check the kzalloc (jsc#SLE-13430).
- staging: rtl8723bs: remove set but not used variable
  'bEEPROMCheck' (jsc#SLE-13430).
- staging: rtl8188eu: remove redundant assignment to variable
  rtstatus (jsc#SLE-13430).
- staging: rtl8723bs: indicate disconnection when disconnecting
  (jsc#SLE-13430).
- staging: rtl8188eu: cleanup comparsion to NULL in usb_halinit.c
  (jsc#SLE-13430).
- staging: rtl8188eu: add spaces around '-' and '*' in
  usb_halinit.c (jsc#SLE-13430).
- staging: rtl8188eu: add spaces around '<<' and '>>' in
  usb_halinit.c (jsc#SLE-13430).
- staging: rtl8188eu: add spaces around '|' in usb_halinit.c
  (jsc#SLE-13430).
- staging: rtl8188eu: add spaces around '&' in usb_halinit.c
  (jsc#SLE-13430).
- commit 0611bb5
* Wed Sep 23 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/nfs-Fix-getxattr-kernel-panic-and-memory-overflow.patch
- commit 147bb89
* Wed Sep 23 2020 tiwai@suse.de
- staging: rtl8188eu: add spaces around '+' in usb_halinit.c
  (jsc#SLE-13430).
- staging: rtl8188eu: remove redundant assignment to rtstatus
  (jsc#SLE-13430).
- Staging: rtl8192e: fixed a function prototype definition issue
  (jsc#SLE-13430).
- staging: rtl8188eu: replace hal_EfusePgCheckAvailableAddr()
  (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: remove two set but not used
  variables (jsc#SLE-13430).
- staging: rtl8723bs: remove set but not used variable
  'pszBBRegMpFile' (jsc#SLE-13430).
- staging: rtl8723bs: remove set but not used variable 'bWifiBusy'
  (jsc#SLE-13430).
- staging: rtl8192*: display ESSIDs using %%pE (jsc#SLE-13430).
- staging: rtl8723bs: hal: Remove unneeded variable pU1Tmp
  (jsc#SLE-13430).
- staging: rtl8723bs: Remove unused function prototype
  ODM_SetAntenna() (jsc#SLE-13430).
- staging: rtl8723bs: Replace function ODM_TXPowerTrackingCheck()
  (jsc#SLE-13430).
- staging: rtl8723bs: Replace function odm_TXPowerTrackingInit()
  (jsc#SLE-13430).
- staging: rtl8723bs: Replace function beacon_timing_control()
  (jsc#SLE-13430).
- staging: rtl8723bs: hal: Replace function
  rtl8723b_set_ap_wowlan_cmd() (jsc#SLE-13430).
- staging: rtl8723bs: hal: Replace function
  rtl8723b_set_wowlan_cmd() (jsc#SLE-13430).
- staging: rtl8723bs: hal: Replace function PHY_GetTxPowerIndex()
  (jsc#SLE-13430).
- staging: rtl8723bs: hal: Replace function PHY_SetTxPowerIndex()
  (jsc#SLE-13430).
- staging: rtl8723bs: rtw_pwrctrl: Change true/false checks
  (jsc#SLE-13430).
- drivers/staging/rtl8192u: fix indentation issue, remove extra
  tab (jsc#SLE-13430).
- staging: rtl8192e: remove set but not used variable 'payload '
  (jsc#SLE-13430).
- staging: rtl8723bs: hal: remove redundant assignment to variable
  n (jsc#SLE-13430).
- staging: rtl8723bs: remove unused file hal_phy.c
  (jsc#SLE-13430).
- staging: rtl8723bs: core: Remove Unneeded variable ret
  (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: change return type of
  rtw_suspend_ap_wow (jsc#SLE-13430).
- staging: rtl8723bs: remove set but not used variable
  'cck_highpwr' (jsc#SLE-13430).
- staging: rtl8712: r8712_free_recvframe(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: r8712_init_recvbuf(): Change return type
  (jsc#SLE-13430).
- staging: rtl8712: r8712_set_802_11_add_wep(): Change return
  values (jsc#SLE-13430).
- staging: rtl8712: init_mp_priv(): Change return values
  (jsc#SLE-13430).
- staging: rtl8712: r8712_register_cmd_alive(): Change return
  values (jsc#SLE-13430).
- staging: rtl8712: r8712_set_key(): Change return values
  (jsc#SLE-13430).
- staging: rtl8712: r8712_set_auth(): Change return values
  (jsc#SLE-13430).
- staging: rtl8712: r8712_init_mlme_priv(): Change return values
  (jsc#SLE-13430).
- staging: rtl8712: Merge memcpy + be16_to_cpus to
  get_unaligned_be16 (jsc#SLE-13430).
- staging: rtl8712: recv_linux.c: Align * on block comment
  (jsc#SLE-13430).
- staging: rtl8188eu: Replace function rtl88eu_phy_rf_config()
  (jsc#SLE-13430).
- staging: rtl8188eu: Replace function rtl88e_phy_rf6052_config()
  (jsc#SLE-13430).
- staging: rtl8188eu: Replace function rtw_alloc_network()
  (jsc#SLE-13430).
- staging: rtl8188eu: Remove function rtw_modular64()
  (jsc#SLE-13430).
- staging: rtl8188eu: Remove function rtw_os_indicate_scan_done()
  (jsc#SLE-13430).
- staging: rtl8188eu: Replace function beacon_timing_control()
  (jsc#SLE-13430).
- staging: rtl8188eu: core: Remove function enable_rate_adaptive()
  (jsc#SLE-13430).
- staging: rtl8188eu: core: Replace function Set_MSR()
  (jsc#SLE-13430).
- staging: rtl8723bs: core: Change return type of
  init_mlme_ext_priv (jsc#SLE-13430).
- staging: rtl8723bs: os_dep: Remove code valid only for 5GHz
  (jsc#SLE-13430).
- staging: rtl8723bs: core: Remove code valid only for 5GHz
  (jsc#SLE-13430).
- staging: rtl8723bs: hal: Remove code valid only for 5GHz
  (jsc#SLE-13430).
- staging: rtl8188eu: remove unused definitions from
  hal8188e_phy_reg.h (jsc#SLE-13430).
- staging: rtl8712: remove redundant assignment to variable res
  (jsc#SLE-13430).
- commit 50b9043
* Wed Sep 23 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/ibmvnic-add-missing-parenthesis-in-do_reset.patch
- commit feb9790
* Wed Sep 23 2020 tiwai@suse.de
- mac80211_hwsim: report the WIPHY_FLAG_SUPPORTS_5_10_MHZ
  capability (jsc#SLE-13430).
- mac80211_hwsim: Claim support for setting Beacon frame TX
  legacy rate (jsc#SLE-13430).
- mac80211_hwsim: Advertise support for multicast RX registration
  (jsc#SLE-13430).
- mac80211_hwsim: indicate in IBSS that we have transmitted
  beacons (jsc#SLE-13430).
- mac80211_hwsim: notify wmediumd of used MAC addresses
  (jsc#SLE-13430).
- rndis_wlan: Replace zero-length array with flexible-array
  (jsc#SLE-13430).
- rndis_wlan: Remove logically dead code (jsc#SLE-13430).
- ray_cs: use true,false for bool variable (jsc#SLE-13430).
- mac80211_hwsim: use GFP_ATOMIC under spin lock (jsc#SLE-13430).
- wl3501_cs: Replace zero-length array with flexible-array member
  (jsc#SLE-13430).
- ray_cs: Replace zero-length array with flexible-array member
  (jsc#SLE-13430).
- virt_wifi: implement ndo_get_iflink (jsc#SLE-13430).
- mac80211_hwsim: add frame transmission support over virtio
  (jsc#SLE-13430).
- mac80211_hwsim: enable Beacon protection (jsc#SLE-13430).
- mac80211_hwsim: add power save support (jsc#SLE-13430).
- mac80211_hwsim: remove maximum TX power (jsc#SLE-13430).
- mac80211_hwsim: use DEFINE_DEBUGFS_ATTRIBUTE to define debugfs
  fops (jsc#SLE-13430).
- mac80211_hwsim: add support for OCB (jsc#SLE-13430).
- mac80211_hwsim: add more 5GHz channels, 5/10 MHz support
  (jsc#SLE-13430).
- mac80211_hwsim: fix incorrect dev_alloc_name failure goto
  (jsc#SLE-13430).
- mac80211_hwsim: Register support for HE meshpoint
  (jsc#SLE-13430).
- wl3501_cs: remove redundant variable rc (jsc#SLE-13430).
- mac80211_hwsim: fill boottime_ns in netlink RX path
  (jsc#SLE-13430).
- mac80211_hwsim: Fix a typo in the name of function
  'mac80211_hswim_he_capab()' (jsc#SLE-13430).
- commit 6ef3086
* Tue Sep 22 2020 msuchanek@suse.de
- Rename patches to same name as in SLE15-SP2.
- commit 92ec993
* Tue Sep 22 2020 tiwai@suse.de
- b43legacy: Replace HTTP links with HTTPS ones (jsc#SLE-13430).
- b43: Replace HTTP links with HTTPS ones (jsc#SLE-13430).
- brcm80211: brcmsmac: Move LEDs to GPIO descriptors
  (jsc#SLE-13430).
- brcmfmac: set pacing shift before transmitting skb to bus
  (jsc#SLE-13430).
- brcmfmac: reset SDIO bus on a firmware crash (jsc#SLE-13430).
- brcmfmac: do not disconnect for disassoc frame from unconnected
  AP (jsc#SLE-13430).
- brcmfmac: Fix for wrong disconnection event source information
  (jsc#SLE-13430).
- commit 251e0d1
* Tue Sep 22 2020 tiwai@suse.de
- brcmfmac: Fix for unable to return to visible SSID
  (jsc#SLE-13430).
- brcmfmac: initialize the requested dwell time (jsc#SLE-13430).
- brcmfmac: fix throughput zero stalls on PM 1 mode due to credit
  map (jsc#SLE-13430).
- brcmfmac: update tx status flags to sync with firmware
  (jsc#SLE-13430).
- brcmfmac: reserve 2 credits for host tx control path
  (jsc#SLE-13430).
- brcmfmac: increase message buffer size for control packets
  (jsc#SLE-13430).
- brcmfmac: allow credit borrowing for all access categories
  (jsc#SLE-13430).
- brcmfmac: reduce maximum station interface from 2 to 1 in RSDB
  mode (jsc#SLE-13430).
- brcmfmac: fix invalid permanent MAC address in wiphy
  (jsc#SLE-13430).
- brcmfmac: To fix kernel crash on out of boundary access
  (jsc#SLE-13430).
- commit cb19212
* Tue Sep 22 2020 tiwai@suse.de
- brcmfmac: 43012 Update MES Watermark (jsc#SLE-13430).
- brcmfmac: fix 43455 CRC error under SDIO 3.0 SDR104 mode
  (jsc#SLE-13430).
- brcmfmac: set F2 blocksize and watermark for 4354/4356 SDIO
  (jsc#SLE-13430).
- brcmfmac: fix 4339 CRC error under SDIO 3.0 SDR104 mode
  (jsc#SLE-13430).
- brcmfmac: set F2 blocksize for 4373 (jsc#SLE-13430).
- brcmfmac: fix WPA/WPA2-PSK 4-way handshake offload and SAE
  offload failures (jsc#SLE-13430).
- brcmfmac: remove Comparison to bool in
  brcmf_p2p_send_action_frame() (jsc#SLE-13430).
- brcmfmac: make non-global functions static (jsc#SLE-13430).
- commit 0257fe1
* Tue Sep 22 2020 tiwai@suse.de
- brcmfmac: Use seq/seq_len and set iv_initialize when plumbing
  of rxiv in (GTK) keys (jsc#SLE-13430).
- brcmfmac: use actframe_abort to cancel ongoing action frame
  (jsc#SLE-13430).
- brcmfmac: set security after reiniting interface
  (jsc#SLE-13430).
- brcmfmac: fix 802.1d priority to ac mapping for pcie dongles
  (jsc#SLE-13430).
- brcmfmac: map 802.1d priority to precedence level based on AP
  WMM params (jsc#SLE-13430).
- b43: remove Comparison of 0/1 to bool variable in pio.c
  (jsc#SLE-13430).
- b43: remove Comparison of 0/1 to bool variable in phy_n.c
  (jsc#SLE-13430).
- brcmsmac: remove Comparison to bool in brcms_b_txstatus()
  (jsc#SLE-13430).
- brcmfmac: Add P2P Action Frame retry delay to fix GAS Comeback
  Response failure issue (jsc#SLE-13430).
- brcmfmac: Fix P2P Group Formation failure via Go-neg method
  (jsc#SLE-13430).
- brcmfmac: support the second p2p connection (jsc#SLE-13430).
- brcmfmac: no need to check return value of debugfs_create
  functions (jsc#SLE-13430).
- brcmfmac: remove comparison to bool in brcmf_fws_attach()
  (jsc#SLE-13430).
- brcmfmac: add vendor ie for association responses
  (jsc#SLE-13430).
- brcmfmac: only generate random p2p address when needed
  (jsc#SLE-13430).
- brcmfmac: p2p cert 6.1.9-support GOUT handling p2p presence
  request (jsc#SLE-13430).
- brcmfmac: remove arp_hostip_clear from brcmf_netdev_stop
  (jsc#SLE-13430).
- brcmfmac: keep apsta enabled when AP starts with MCHAN feature
  (jsc#SLE-13430).
- brcmfmac: remove leading space (jsc#SLE-13430).
- brcmsmac: make brcms_c_stf_ss_update() void (jsc#SLE-13430).
- commit ebefb73
* Tue Sep 22 2020 tiwai@suse.de
- mmc: sdio: Move SDIO IDs from b43-sdio driver to common include
  file (jsc#SLE-13430).
- commit 31605aa
* Tue Sep 22 2020 tiwai@suse.de
- brcmsmac: Add missing annotation for brcms_down()
  (jsc#SLE-13430).
- brcmsmac: Add missing annotation for brcms_rfkill_set_hw_state()
  (jsc#SLE-13430).
- brcmsmac: make brcms_c_set_mac() void (jsc#SLE-13430).
- brcm80211: remove redundant pointer 'address' (jsc#SLE-13430).
- b43: remove dead function b43_rssinoise_postprocess()
  (jsc#SLE-13430).
- mmc: sdio: Fix Cypress SDIO IDs macros in common include file
  (jsc#SLE-13430).
- brcmfmac: add stub for monitor interface xmit (jsc#SLE-13430).
- brcmfmac: add USB autosuspend feature support (jsc#SLE-13430).
- brcmfmac: increase max hanger slots from 1K to 3K in fws layer
  (jsc#SLE-13430).
- commit 648736f
* Tue Sep 22 2020 tiwai@suse.de
- brcmfmac: fix the incorrect return value in
  brcmf_inform_single_bss() (jsc#SLE-13430).
- brcmfmac: Fix double freeing in the fmac usb data path
  (jsc#SLE-13430).
- brcmfmac: Fix driver crash on USB control transfer timeout
  (jsc#SLE-13430).
- brcmfmac: Replace zero-length array with flexible-array member
  (jsc#SLE-13430).
- b43legacy: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-13430).
- b43: Use scnprintf() for avoiding potential buffer overflow
  (jsc#SLE-13430).
- b43legacy: replace simple_strtol() with kstrtoint()
  (jsc#SLE-13430).
- brcmfmac: add the BRCM 4364 found in MacBook Pro 15,2
  (jsc#SLE-13430).
- brcmfmac: Remove always false 'idx < 0' statement
  (jsc#SLE-13430).
- brcmfmac: add initial support for monitor mode (jsc#SLE-13430).
- brcmfmac: simplify building interface combinations
  (jsc#SLE-13430).
- brcmfmac: use true,false for bool variable (jsc#SLE-13430).
- brcmfmac: Keep OOB wake-interrupt disabled when it shouldn't
  be enabled (jsc#SLE-13430).
- brcmfmac: not set mbss in vif if firmware does not support MBSS
  (jsc#SLE-13430).
- brcmfmac: add RSDB condition when setting interface combinations
  (jsc#SLE-13430).
- brcmfmac: add support for BCM4359 SDIO chipset (jsc#SLE-13430).
- brcmfmac: make errors when setting roaming parameters non-fatal
  (jsc#SLE-13430).
- brcmfmac: fix rambase for 4359/9 (jsc#SLE-13430).
- brcmfmac: set F2 blocksize and watermark for 4359
  (jsc#SLE-13430).
- brcmfmac: reset two D11 cores if chip has two D11 cores
  (jsc#SLE-13430).
- commit ad8493d
* Tue Sep 22 2020 tiwai@suse.de
- brcmfmac: set interface carrier to off by default
  (jsc#SLE-13430).
- brcmsmac: Remove always false 'channel < 0' statement
  (jsc#SLE-13430).
- brcmfmac: remove set but not used variable 'mpnum','nsp','nmp'
  (jsc#SLE-13430).
- brcmsmac: remove unnecessary return (jsc#SLE-13430).
- brcmsmac: remove set but not used variables (jsc#SLE-13430).
- b43: dma: Fix use true/false for bool type variable
  (jsc#SLE-13430).
- b43: main: Fix use true/false for bool type (jsc#SLE-13430).
- wireless: Remove call to memset after dma_alloc_coherent
  (jsc#SLE-13430).
- brcmfmac: add support for SAE authentication offload
  (jsc#SLE-13430).
- commit 7ede4db
* Tue Sep 22 2020 tiwai@suse.de
- brcmfmac: split brcmf_attach() and brcmf_detach() functions
  (jsc#SLE-13430).
- Refresh
  patches.suse/brcmfmac-sdio-Fix-OOB-interrupt-initialization-on-br.patch.
- commit e7b7a90
* Tue Sep 22 2020 nsaenzjulienne@suse.de
- tty: serial: imx: add imx earlycon driver (jsc#SLE-16106).
- Update config files
- tty: serial: imx: enable imx serial console port as module
  (jsc#SLE-16106).
- serial: imx: use hrtimers for rs485 delays (jsc#SLE-16106).
- serial: imx: implement rts delaying for rs485 (jsc#SLE-16106).
- tty: serial: imx: clear Ageing Timer Interrupt in handler
  (jsc#SLE-16106).
- serial: Allow uart_get_rs485_mode() to return errno
  (jsc#SLE-16106).
- serial: 8250: Avoid error message on reprobe (jsc#SLE-16106).
- tty: serial: imx: Add return value check for platform_get_irq()
  (jsc#SLE-16106).
- dt-bindings: reset: imx7: Document usage on i.MX8MP SoC
  (jsc#SLE-16106).
- serial: 8250: Optimize irq enable after console write
  (jsc#SLE-16106).
- serial: 8250: Fix rs485 delay after console write
  (jsc#SLE-16106).
- serial: 8250: Support console on software emulated rs485 ports
  (jsc#SLE-16106).
- serial: 8250: Generalize rs485 software emulation
  (jsc#SLE-16106).
- serial: 8250: Deduplicate rs485 active_timer assignment
  (jsc#SLE-16106).
- serial: 8250: Sanitize rs485 config harder (jsc#SLE-16106).
- serial: 8250: Deduplicate ->rs485_config() callback
  (jsc#SLE-16106).
- serial: 8250: Support rs485 devicetree properties
  (jsc#SLE-16106).
- serial: 8250: Don't touch RTS modem control while in rs485 mode
  (jsc#SLE-16106).
- tty: imx serial: Implement support for reversing TX and RX
  polarity (jsc#SLE-16106).
- tty: 8250_of: Use software emulated RS485 direction control
  (jsc#SLE-16106).
- Refresh: patches.suse/serial-8250_tegra-Create-Tegra-specific-8250-driver.patch
- serial: imx: adapt rx buffer and dma periods (jsc#SLE-16106).
- serial: imx: use Tx ready rather than Tx empty irq
  (jsc#SLE-16106).
- serial: imx: fix data breakage on termios change
  (jsc#SLE-16106).
- serial: imx: do not disable individual irqs during termios
  change (jsc#SLE-16106).
- serial: imx: do not stop Rx/Tx on termios change
  (jsc#SLE-16106).
- serial: imx: get rid of unbounded busy-waiting loop
  (jsc#SLE-16106).
- serial: imx: get rid of imx_uart_rts_auto() (jsc#SLE-16106).
- serial: imx: set_mctrl(): correctly restore autoRTS state
  (jsc#SLE-16106).
- serial: imx: set_termios(): do not enable autoRTS if RTS is
  unset (jsc#SLE-16106).
- commit 77cc11d
* Tue Sep 22 2020 tiwai@suse.de
- brcmsmac: remove duplicated if condition (jsc#SLE-13430).
- brcmfmac: fix suspend/resume when power is cut off
  (jsc#SLE-13430).
- brcmfmac: don't WARN when there are no requests (jsc#SLE-13430).
- brcmsmac: remove a useless test (jsc#SLE-13430).
- brcmfmac: send port authorized event for FT-802.1X
  (jsc#SLE-13430).
- brcmsmac: Use DIV_ROUND_CLOSEST directly to make it readable
  (jsc#SLE-13430).
- brcmfmac: don't realloc wiphy during PCIe reset (jsc#SLE-13430).
- brcmfmac: move "cfg80211_ops" pointer to another struct
  (jsc#SLE-13430).
- brcmfmac: use %%*ph to print small buffer (jsc#SLE-13430).
- brcmfmac: add "reset" debugfs entry for testing reset
  (jsc#SLE-13430).
- brcmfmac: add stub version of brcmf_debugfs_get_devdir()
  (jsc#SLE-13430).
- brcmfmac: replace strncpy() by strscpy() (jsc#SLE-13430).
- brcmfmac: remove redundant assignment to pointer hash
  (jsc#SLE-13430).
- brcm80211: Avoid possible null-pointer dereferences in
  wlc_phy_radio_init_2056() (jsc#SLE-13430).
- b43legacy: Remove pointless cond_resched() wrapper
  (jsc#SLE-13430).
- brcmsmac: remove three set but not used variables
  (jsc#SLE-13430).
- brcmfmac: remove set but not used variable 'dtim_period'
  (jsc#SLE-13430).
- brcmfmac: don't net_ratelimit() CONSOLE messages on firmware
  crash (jsc#SLE-13430).
- brcmfmac: remove unnecessary strlcpy() upon obtaining "ver"
  iovar (jsc#SLE-13430).
- brcmfmac: simply remove flowring if bus is down (jsc#SLE-13430).
- commit 3b02679
* Tue Sep 22 2020 tiwai@suse.de
- brcmfmac: change the order of things in brcmf_detach()
  (jsc#SLE-13430).
- Refresh
  patches.suse/brcmfmac-remove-monitor-interface-when-detaching.patch.
- commit a19507f
* Tue Sep 22 2020 tiwai@suse.de
- Revert "brcmfmac: fix NULL pointer derefence during USB
  disconnect" (jsc#SLE-13430).
- Refresh
  patches.suse/brcmfmac-remove-monitor-interface-when-detaching.patch.
- commit 35203f2
* Tue Sep 22 2020 tiwai@suse.de
- brcmfmac: avoid firmware commands when bus is down
  (jsc#SLE-13430).
- brcmfmac: clear events in brcmf_fweh_detach() will always fail
  (jsc#SLE-13430).
- brcmfmac: avoid firmware command in brcmf_netdev_open() when
  bus is down (jsc#SLE-13430).
- brcmfmac: allow 160MHz in custom regulatory rules
  (jsc#SLE-13430).
- brcmfmac: enable DFS_OFFLOAD extended feature if supported
  (jsc#SLE-13430).
- brcmfmac: add 160MHz in chandef_to_chanspec() (jsc#SLE-13430).
- commit d7ef69f
* Tue Sep 22 2020 tiwai@suse.de
- rtlwifi: btcoex: use %%*ph to print small buffer (jsc#SLE-13430).
- rtlwifi: btcoex: remove redundant initialization of variables
  ant_num and single_ant_path (jsc#SLE-13430).
- rtlwifi: 8821ae: remove unused path B parameters from swing
  table (jsc#SLE-13430).
- rtlwifi: Use const in 8188ee/8723be/8821ae swing_table
  declarations (jsc#SLE-13430).
- rtl818x_pci: use generic power management (jsc#SLE-13430).
- rtlwifi: rtl8192cu: Free ieee80211_hw if probing fails
  (jsc#SLE-13430).
- rtlwifi: rtl8192cu: Fix deadlock (jsc#SLE-13430).
- rtlwifi: rtl8188ee: Fix endian issue (jsc#SLE-13430).
- rtlwifi: Fix endian issue in ps.c (jsc#SLE-13430).
- rtlwifi: rtl8192ee: remove redundant for-loop (jsc#SLE-13430).
- rtl8187: Remove unused variable rtl8225z2_tx_power_ofdm
  (jsc#SLE-13430).
- rtlwifi: rtl8188ee: remove Comparison to bool in rf.c
  (jsc#SLE-13430).
- rtlwifi: remove comparison of 0/1 to bool variable
  (jsc#SLE-13430).
- rtlwifi: use true,false for bool variable in rtl_init_rfkill()
  (jsc#SLE-13430).
- rtlwifi: rtl8723ae: fix warning comparison to bool
  (jsc#SLE-13430).
- rtlwifi: rtl8821ae: use true,false for bool variables
  (jsc#SLE-13430).
- rtlwifi: rtl8723be: use true,false for bool variables
  (jsc#SLE-13430).
- rtlwifi: rtl8192ee: use true,false for bool variables
  (jsc#SLE-13430).
- rtlwifi: rtl8723ae: use true,false for bool variables
  (jsc#SLE-13430).
- rtlwifi: rtl8188ee: use true,false for bool variables
  (jsc#SLE-13430).
- rtlwifi: rtl8723ae: fix spelling mistake "chang" -> "change"
  (jsc#SLE-13430).
- rtl8xxxu: Feed current txrate information for mac80211
  (jsc#SLE-13430).
- rtl8xxxu: add enumeration for channel bandwidth (jsc#SLE-13430).
- rtl8xxxu: Fix sparse warning: cast from restricted __le16
  (jsc#SLE-13430).
- rtlwifi: rtl8188ee: Fix regression due to commit d1d1a96bdb44
  (jsc#SLE-13430).
- rtlwifi: btcoex: fix spelling mistake "initilized" ->
  "initialized" (jsc#SLE-13430).
- rtlwifi: rtl8723ae: remove unused variables (jsc#SLE-13430).
- rtlwifi: rtl8192ee: remove unused variables (jsc#SLE-13430).
- rtlwifi: rtl8821ae: remove unused variables (jsc#SLE-13430).
- rtlwifi: rtl8188ee: remove redundant assignment to variable cond
  (jsc#SLE-13430).
- rtlwifi: rtl8821ae: Make functions static & rm sw.h
  (jsc#SLE-13430).
- rtlwifi: rtl8723be: Make functions static & rm sw.h
  (jsc#SLE-13430).
- rtlwifi: rtl8723ae: Make functions static & rm sw.h
  (jsc#SLE-13430).
- rtlwifi: rtl8192se: Remove sw.h header (jsc#SLE-13430).
- rtlwifi: rtl8192ee: Make functions static & rm sw.h
  (jsc#SLE-13430).
- rtlwifi: rtl8192cu: Remove sw.h header (jsc#SLE-13430).
- rtlwifi: rtl8192ce: Make functions static & rm sw.h
  (jsc#SLE-13430).
- rtlwifi: rtl8188ee: Make functions static & rm sw.h
  (jsc#SLE-13430).
- rtlwifi: rtl8192cu: Fix typo (jsc#SLE-13430).
- rtlwifi: rtl8192de: use generic rtl_signal_scale_mapping
  (jsc#SLE-13430).
- rtlwifi: rtl8192cu: use generic rtl_signal_scale_mapping
  (jsc#SLE-13430).
- rtlwifi: rtl8192ce: use generic rtl_signal_scale_mapping
  (jsc#SLE-13430).
- rtlwifi: rtl8192de: use generic rtl_query_rxpwrpercentage
  (jsc#SLE-13430).
- rtlwifi: rtl8192cu: use generic rtl_query_rxpwrpercentage
  (jsc#SLE-13430).
- rtlwifi: rtl8192ce: use generic rtl_query_rxpwrpercentage
  (jsc#SLE-13430).
- rtlwifi: Remove last definitions of local bit manipulation
  macros (jsc#SLE-13430).
- rtlwifi: rtl8723be: Remove usage of private bit manipulation
  macros (jsc#SLE-13430).
- rtlwifi: rtl8723ae: Remove usage of private bit manipulation
  macros (jsc#SLE-13430).
- rtlwifi: rtl8192ee: Remove usage of private bit manipulation
  macros (jsc#SLE-13430).
- rtlwifi: rtl88821ae: Remove usage of private bit manipulation
  macros (jsc#SLE-13430).
- rtlwifi: Remove dependence on special bit manipulation macros
  for common driver (jsc#SLE-13430).
- rtlwifi: rtl8192ce: rtl8192c_com: Remove usage of private bit
  manipulation macros (jsc#SLE-13430).
- rtlwifi: rtl8188ee: Remove usage of private bit manipulation
  (jsc#SLE-13430).
- rtlwifi: rtl8192de: Remove usage of private bit manipulation
  macros (jsc#SLE-13430).
- commit 0e1e872
* Tue Sep 22 2020 tiwai@suse.de
- rtlwifi: rtl8192de: Convert inline routines to little-endian
  words (jsc#SLE-13430).
- rtlwifi: rtl8192de: Convert macros that set descriptor
  (jsc#SLE-13430).
- rtlwifi: rtl8192de: Replace local bit manipulation macros
  (jsc#SLE-13430).
- rtlwifi: rtl8192de: Remove unused GET_XXX and SET_XXX macros
  (jsc#SLE-13430).
- rtl8xxxu: Remove set but not used variable 'vif','dev','len'
  (jsc#SLE-13430).
- rtlwifi: set proper udelay within rf_serial_read
  (jsc#SLE-13430).
- rtlwifi: rf_lock use non-irqsave spin_lock (jsc#SLE-13430).
- rtl8xxxu: Remove set but not used variable 'rsr'
  (jsc#SLE-13430).
- rtl8xxxu: Add support for Edimax EW-7611ULB (jsc#SLE-13430).
- rtlwifi: rtl8225se: remove some unused const variables
  (jsc#SLE-13430).
- rtlwifi: rtl8821ae: Drop condition with no effect
  (jsc#SLE-13430).
- rtlwifi: rtl8192c: Drop condition with no effect
  (jsc#SLE-13430).
- rtl8xxxu: fix warnings for symbol not declared (jsc#SLE-13430).
- rtl8xxxu: remove set but not used variable 'rate_mask'
  (jsc#SLE-13430).
- rtlwifi: rtl8192se: Convert inline routines to little-endian
  words (jsc#SLE-13430).
- rtlwifi: rtl8192se: Convert macros that set descriptor
  (jsc#SLE-13430).
- rtlwifi: rtl8192se: Replace local bit manipulation macros
  (jsc#SLE-13430).
- rtlwifi: rtl8192se: Remove unused GET_XXX and SET_XXX
  (jsc#SLE-13430).
- rtlwifi: rtl8192ee: Remove set but not used variable 'err'
  (jsc#SLE-13430).
- rtlwifi: rtl8192ee: Remove set but not used variable 'cur_tx_wp'
  (jsc#SLE-13430).
- rtl8xxxu: make arrays static, makes object smaller
  (jsc#SLE-13430).
- rtl8xxxu: add bluetooth co-existence support for single antenna
  (jsc#SLE-13430).
- rtlwifi: rtl8723: Remove set but not used variable 'own'
  (jsc#SLE-13430).
- rtlwifi: btcoex: Remove set but not used variables
  'wifi_busy','bt_info_ext' (jsc#SLE-13430).
- rtlwifi: btcoex: Remove set but not used variable 'result'
  (jsc#SLE-13430).
- rtlwifi: rtl8188ee: Remove set but not used variable
  'h2c_parameter' (jsc#SLE-13430).
- rtlwifi: rtl8188ee: Remove set but not used variables
  'v3','rtstatus','reg_ecc','reg_ec4','reg_eac','b_pathb_ok'
  (jsc#SLE-13430).
- rtlwifi: rtl8192c: Remove set but not used variables
  'reg_ecc','reg_eac' (jsc#SLE-13430).
- rtlwifi: rtl8723ae: Remove set but not used variables
  'reg_ecc','reg_ec4','reg_eac','b_pathb_ok' (jsc#SLE-13430).
- rtlwifi: rtl8821ae: Remove set but not used variables
  'rtstatus','bd' (jsc#SLE-13430).
- rtl8xxxu: Improve TX performance of RTL8723BU on rtl8xxxu driver
  (jsc#SLE-13430).
- rtlwifi: rtl8723be: Remove set but not used variables
  'reg_ecc','reg_eac' (jsc#SLE-13430).
- rtlwifi: rtl8192ee: Remove set but not used variables
  'reg_ecc','reg_eac' (jsc#SLE-13430).
- rtlwifi: rtl8192ee: Remove set but not used variables
  'short_gi','buf_len' (jsc#SLE-13430).
- rtlwifi: Remove set but not used variables 'dataempty','hoffset'
  (jsc#SLE-13430).
- rtlwifi: Remove set but not used variable 'rtstate'
  (jsc#SLE-13430).
- rtlwifi: Remove excessive check in _rtl_ps_inactive_ps()
  (jsc#SLE-13430).
- rtlwifi: rtl8723ae: Remove unused 'rtstatus' variable
  (jsc#SLE-13430).
- rtlwifi: rtl8192de: replace _rtl92d_evm_db_to_percentage with
  generic version (jsc#SLE-13430).
- rtlwifi: rtl8192cu: replace _rtl92c_evm_db_to_percentage with
  generic version (jsc#SLE-13430).
- commit 86ed269
* Tue Sep 22 2020 tiwai@suse.de
- rtlwifi: rtl8192ce: replace _rtl92c_evm_db_to_percentage with
  generic version (jsc#SLE-13430).
- rtlwifi: rtl8188ee: rtl8192ce: rtl8192de: rtl8723ae: rtl8821ae:
  Remove some unused bit manipulation macros (jsc#SLE-13430).
- rtlwifi: rtl8723be: Convert inline routines to little-endian
  words (jsc#SLE-13430).
- rtlwifi: rtl8723be: Convert macros that set descriptor
  (jsc#SLE-13430).
- rtlwifi: rtl8723be: Replace local bit manipulation macros
  (jsc#SLE-13430).
- rtlwifi: rtl8723be: Remove unused SET_XXX and GET_XXX macros
  (jsc#SLE-13430).
- rtlwifi: rtl8723ae: Convert inline routines to little-endian
  words (jsc#SLE-13430).
- rtlwifi: rtl8723ae: Convert macros that set descriptor
  (jsc#SLE-13430).
- rtlwifi: rtl8723ae: Replace local bit manipulation macros
  (jsc#SLE-13430).
- rtlwifi: rtl8723ae: Remove unused GET_XXX and SET_XXX macros
  (jsc#SLE-13430).
- rtlwifi: rtl8821ae: make array static const and remove redundant
  assignment (jsc#SLE-13430).
- rtlwifi: rtl8192ce: Fix incorrect returned values
  (jsc#SLE-13430).
- rtlwifi: rtl8188ee: Fix incorrect returned values
  (jsc#SLE-13430).
- rtlwifi: rtl8192cu: Convert inline routines to little-endian
  words (jsc#SLE-13430).
- rtlwifi: rtl8192cu: Convert macros that set descriptor
  (jsc#SLE-13430).
- rtlwifi: rtl8192cu: Replace local bit manipulation macros
  (jsc#SLE-13430).
- rtlwifi: rtl8192cu: Remove unused GET_XXX and SET_XXX
  (jsc#SLE-13430).
- rtlwifi: rtl8192ee: Remove some variable initializations
  (jsc#SLE-13430).
- rtlwifi: rtl8192ee: Convert inline routines to little-endian
  words (jsc#SLE-13430).
- rtlwifi: rtl8192ee: Convert macros that set descriptor
  (jsc#SLE-13430).
- rtlwifi: rtl8192ee: Replace local bit manipulation macros
  (jsc#SLE-13430).
- rtlwifi: rtl8192ee: Remove unused GET_XXX and SET_XXX
  (jsc#SLE-13430).
- rtlwifi: rtl_pci: Fix memory leak when hardware init fails
  (jsc#SLE-13430).
- rtlwifi: remove unused variables 'RTL8712_SDIO_EFUSE_TABLE'
  and 'MAX_PGPKT_SIZE' (jsc#SLE-13430).
- rtlwifi: fix non-kerneldoc comment in usb.c (jsc#SLE-13430).
- rtlwifi: rtl8192ce: Convert inline routines to little-endian
  words (jsc#SLE-13430).
- rtlwifi: rtl8192ce: Convert macros that set descriptor
  (jsc#SLE-13430).
- rtlwifi: rtl8192ce: Replace local bit manipulation macros
  (jsc#SLE-13430).
- rtlwifi: rtl8192ce: Remove unused GET_XXX and SET_XXX
  (jsc#SLE-13430).
- rtlwifi: rtl8188ee: Remove local configuration variable
  (jsc#SLE-13430).
- rtlwifi: rtl8188ee: Convert inline routines to little-endian
  words (jsc#SLE-13430).
- rtlwifi: rtl8188ee: Convert macros that set descriptor
  (jsc#SLE-13430).
- rtlwifi: rtl88188ee: Replace local bit manipulation macros
  (jsc#SLE-13430).
- rtlwifi: rtl8188ee: Remove unused GET_XXX and SET_XXX descriptor
  macros (jsc#SLE-13430).
- rtlwifi: remove unneeded function _rtl_dump_channel_map()
  (jsc#SLE-13430).
- rtlwifi: rtl_pci: Use dev_get_drvdata (jsc#SLE-13430).
- rtlwifi: remove assignment to itself (jsc#SLE-13430).
- rtlwifi: btcoex: fix issue possible condition with no effect
  (if == else) (jsc#SLE-13430).
- rtl8xxxu: Fix wifi low signal strength issue of RTL8723BU
  (jsc#SLE-13430).
- commit f1d994b
* Tue Sep 22 2020 tiwai@suse.de
- mmc: sdio: Fix macro name for Marvell device with ID 0x9134
  (jsc#SLE-13430).
- Refresh
  patches.suse/mmc-sdio-Change-macro-names-for-Marvell-8688-modules.patch.
- Refresh
  patches.suse/mmc-sdio-Move-SDIO-IDs-from-btmrvl-driver-to-common-.patch.
- Refresh
  patches.suse/mmc-sdio-Move-SDIO-IDs-from-mwifiex-driver-to-common.patch.
- commit eaa2cfe
* Tue Sep 22 2020 tiwai@suse.de
- mmc: sdio: Move SDIO IDs from mwifiex driver to common include
  file (jsc#SLE-13430).
- Refresh
  patches.suse/mmc-sdio-Move-SDIO-IDs-from-btmrvl-driver-to-common-.patch.
- commit a47c531
* Tue Sep 22 2020 nsaenzjulienne@suse.de
- pwm: imx27: Use 64-bit division macro (jsc#SLE-16106).
- spi: imx: enable runtime pm support (jsc#SLE-16106).
- spi: imx/fsl-lpspi: Convert to GPIO descriptors (jsc#SLE-16106).
- spi: imx: add fallback feature (jsc#SLE-16106).
- pwm: imx27: Fix rounding behavior (jsc#SLE-16106).
- rtc: snvs: Add necessary clock operations for RTC APIs
  (jsc#SLE-16106).
- rtc: snvs: Make SNVS clock always prepared (jsc#SLE-16106).
- reset: imx7: Add support for i.MX8MP SoC (jsc#SLE-16106).
- spi: imx: fallback to PIO if dma setup failure (jsc#SLE-16106).
- pwm: imx27: Remove unused include of of_device.h
  (jsc#SLE-16106).
- pwm: imx27: Ensure clocks being on iff the PWM is on
  (jsc#SLE-16106).
- pwm: imx27: Don't disable clocks at device remove time
  (jsc#SLE-16106).
- pwm: imx27: Simplify helper function to enable and disable
  clocks (jsc#SLE-16106).
- pwm: imx27: Fix clock handling in pwm_imx27_apply()
  (jsc#SLE-16106).
- rtc: snvs: Use devm_add_action_or_reset() for calls to
  clk_disable_unprepare() (jsc#SLE-16106).
- rtc: snvs: Remove unused include of of_device.h (jsc#SLE-16106).
- clocksource/drivers/imx-sysctr: Remove unused includes
  (jsc#SLE-16106).
- pwm: imx27: Eliminate error message for defer probe
  (jsc#SLE-16106).
- pwm: imx27: Unconditionally write state to hardware
  (jsc#SLE-16106).
- pwm: imx27: Cache duty cycle register value (jsc#SLE-16106).
- spi: imx: use true,false for bool variable (jsc#SLE-16106).
- Input: snvs_pwrkey - remove gratuitous NULL initializers
  (jsc#SLE-16106).
- Input: snvs_pwrkey - send key events for i.MX6 S, DL and Q
  (jsc#SLE-16106).
- spi: imx: Use dma_request_chan() directly for channel request
  (jsc#SLE-16106).
- pwm: imx: Document known limitations (jsc#SLE-16106).
- rtc: snvs: switch to rtc_time64_to_tm/rtc_tm_to_time64
  (jsc#SLE-16106).
- rtc: snvs: set range (jsc#SLE-16106).
- Input: remove dev_err() usage after platform_get_irq()
  (jsc#SLE-16106).
- clocksource/drivers/imx-sysctr: Add internal clock divider
  handle (jsc#SLE-16106).
- dt-bindings: reset: Fix typo in imx8mq resets (jsc#SLE-16106).
- commit 3c3190a
* Tue Sep 22 2020 tiwai@suse.de
- mmc: sdio: Change macro names for Marvell 8688 modules
  (jsc#SLE-13430).
- Refresh
  patches.suse/mmc-sdio-Move-SDIO-IDs-from-btmrvl-driver-to-common-.patch.
- commit d9e72e1
* Tue Sep 22 2020 tiwai@suse.de
- mwifiex: 11n_rxreorder: Remove unnecessary cast in kfree()
  (jsc#SLE-13430).
- mwifiex: Fix reporting 'operation not supported' error code
  (jsc#SLE-13430).
- mwifiex: Use macro MWIFIEX_MAX_BSS_NUM for specifying limit
  of interfaces (jsc#SLE-13430).
- mwifiex: Add support for NL80211_ATTR_MAX_AP_ASSOC_STA
  (jsc#SLE-13430).
- mwifiex: Parse all API_VER_ID properties (jsc#SLE-13430).
- libertas: Use shared constant for rfc1042 header
  (jsc#SLE-13430).
- mwl8k: Replace zero-length array with flexible-array
  (jsc#SLE-13430).
- libertas: make lbs_process_event() void (jsc#SLE-13430).
- libertas: make lbs_init_mesh() void (jsc#SLE-13430).
- wireless: marvell: Replace zero-length array with flexible-array
  member (jsc#SLE-13430).
- libertas: Replace zero-length array with flexible-array member
  (jsc#SLE-13430).
- libertas: Use new structure for SPI transfer delays
  (jsc#SLE-13430).
- mwifiex: change license text from MARVELL to NXP
  (jsc#SLE-13430).
- mwifiex: Re-work support for SDIO HW reset (jsc#SLE-13430).
- libertas: remove redundant assignment to variable ret
  (jsc#SLE-13430).
- mwifiex: use 'total_ie_len' in mwifiex_update_bss_desc_with_ie()
  (jsc#SLE-13430).
- libertas: use mesh_wdev->ssid instead of priv->mesh_ssid
  (jsc#SLE-13430).
- libertas: Fix a double free in if_spi_c2h_data()
  (jsc#SLE-13430).
- mwifiex: pcie: Use dev_get_drvdata (jsc#SLE-13430).
- mwifiex: make error values consistent in
  mwifiex_update_bss_desc_with_ie() (jsc#SLE-13430).
- mwifiex: use eth_broadcast_addr() to assign broadcast address
  (jsc#SLE-13430).
- libertas: remove redundant assignment to variable ret
  (jsc#SLE-13430).
- commit 2008916
* Tue Sep 22 2020 tiwai@suse.de
- supported.conf: Add rtw88 modules explicitly
- commit b55ebc3
* Tue Sep 22 2020 tiwai@suse.de
- rtw88: 8821c: Add 8821CE to Kconfig and Makefile (jsc#SLE-13430,
  bsc#1176741).
- Update config files.
- commit 153835c
* Tue Sep 22 2020 tiwai@suse.de
- rtw88: 8821c: coex: add functions and parameters (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8821c: make symbol 'rtw8821c_rtw_pwr_track_tbl' static
  (jsc#SLE-13430, bsc#1176741).
- rtw88: add h2c command in debugfs (jsc#SLE-13430, bsc#1176741).
- rtw88: allows driver to enable/disable beacon (jsc#SLE-13430,
  bsc#1176741).
- rtw88: add ieee80211_ops::change_interface (jsc#SLE-13430,
  bsc#1176741).
- rtw88: coex: only skip coex triggered by BT info (jsc#SLE-13430,
  bsc#1176741).
- rtw88: update tx descriptor of mgmt and reserved page packets
  (jsc#SLE-13430, bsc#1176741).
- rtw88: coex: Fix ACL Tx pause during BT inquiry/page
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8822c: add new RFE type 6 (jsc#SLE-13430, bsc#1176741).
- rtw88: 8822ce: add support for device ID 0xc82f (jsc#SLE-13430,
  bsc#1176741).
- rtw88: pci: disable aspm for platform inter-op with module
  parameter (jsc#SLE-13430, bsc#1176741).
- rtw88: single rf path chips don't support TX STBC
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8821c: add beamformee support (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8821c: add power tracking (jsc#SLE-13430, bsc#1176741).
- rtw88: 8821c: add cck pd settings (jsc#SLE-13430, bsc#1176741).
- rtw88: 8821c: add phy calibration (jsc#SLE-13430, bsc#1176741).
- rtw88: 8821c: add false alarm statistics (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8821c: add query rx desc support (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8821c: add set channel support (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8821c: add dig related settings (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8821c: add set tx power index (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8821c: add basic functions (jsc#SLE-13430, bsc#1176741).
- commit fe0a9a2
* Tue Sep 22 2020 tiwai@suse.de
- rtw88: 8822c: remove CCK TX setting when switch channel
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8822c: fix missing brace warning for old compilers
  (jsc#SLE-13430, bsc#1176741).
- rtw88: fix EAPOL 4-way failure by finish IQK earlier
  (jsc#SLE-13430, bsc#1176741).
- rtw88: coex: 8723d: handle BT inquiry cases (jsc#SLE-13430,
  bsc#1176741).
- rtw88: coex: 8723d: set antanna control owner (jsc#SLE-13430,
  bsc#1176741).
- Revert "rtw88: no need to set registers for SDIO"
  (jsc#SLE-13430, bsc#1176741).
- rtw88: no need to set registers for SDIO (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8723d: fix incorrect setting of ldo_pwr (jsc#SLE-13430,
  bsc#1176741).
- rtw88: rename rtw88.ko/rtwpci.ko to rtw88_core.ko/rtw88_pci.ko
  (jsc#SLE-13430, bsc#1176741).
- rtw88: extract: remove the unused after extracting
  (jsc#SLE-13430, bsc#1176741).
- commit f9fba75
* Tue Sep 22 2020 nsaenzjulienne@suse.de
- dmaengine: imx-sdma: Correct formatting issue and provide 2
  new descriptions (jsc#SLE-16106).
- thermal: imx8mm: Support module autoloading (jsc#SLE-16106).
- thermal: imx8mm: Replace zero-length array with flexible-array
  (jsc#SLE-16106).
- dmaengine: imx-sdma: initialize all script addresses
  (jsc#SLE-16106).
- watchdog: imx2_wdt: Drop .remove callback (jsc#SLE-16106).
- thermal: imx8mm: Fix build warning of incorrect argument type
  (jsc#SLE-16106).
- thermal: imx8mm: Add i.MX8MP support (jsc#SLE-16106).
- thermal: imx8mm: Add support for i.MX8MM thermal monitoring unit
  (jsc#SLE-16106).
- supported.conf: Add imx8mm_thermal
- Update config files
- dmaengine: imx-sdma: Fix memory leak (jsc#SLE-16106).
- dmaengine: imx-sdma: find desc first in sdma_tx_status
  (jsc#SLE-16106).
- dmaengine: imx-sdma: rename function (jsc#SLE-16106).
- watchdog: imx2_wdt: Use 'dev' instead of dereferencing it
  repeatedly (jsc#SLE-16106).
- watchdog: imx2_wdt: Use __maybe_unused instead of #if
  CONFIG_PM_SLEEP (jsc#SLE-16106).
- watchdog: imx2_wdt: Remove unnecessary blank line
  (jsc#SLE-16106).
- dmaengine: imx-sdma: Remove call to memset after
  dma_alloc_coherent (jsc#SLE-16106).
- gpio: mxc: Use devm_clk_get_optional instead of devm_clk_get
  (jsc#SLE-16106).
- commit caad3c5
* Tue Sep 22 2020 nsaenzjulienne@suse.de
- blacklist.conf: Remove fixes
- commit cf12879
* Tue Sep 22 2020 tiwai@suse.de
- rtw88: 8723d: Add 8723DE to Kconfig and Makefile (jsc#SLE-13430,
  bsc#1176741).
- Update config files.
- commit 1f8352c
* Tue Sep 22 2020 tiwai@suse.de
- rtw88: extract: make 8723d an individual kernel module
  (jsc#SLE-13430, bsc#1176741).
- rtw88: extract: make 8822b an individual kernel module
  (jsc#SLE-13430, bsc#1176741).
- rtw88: extract: make 8822c an individual kernel module
  (jsc#SLE-13430, bsc#1176741).
- rtw88: extract: export symbols about pci interface
  (jsc#SLE-13430, bsc#1176741).
- rtw88: extract: export symbols used in chip functionalities
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: fix sparse warnings for power tracking
  (jsc#SLE-13430, bsc#1176741).
- rtw88: fill zeros to words 0x06 and 0x07 of security cam entry
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: Add coex support (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: set ltecoex register address in chip_info
  (jsc#SLE-13430, bsc#1176741).
- commit d9906ed
* Tue Sep 22 2020 tiwai@suse.de
- rtw88: 8723d: implement flush queue (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8723d: Add shutdown callback to disable BT USB suspend
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: Add power tracking (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: add IQ calibration (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: Add LC calibration (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: add interface configurations table (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8723d: Set IG register for CCK rate (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8723d: Add chip_ops::false_alarm_statistics
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: some chips don't support LDPC (jsc#SLE-13430,
  bsc#1176741).
- rtw88: handle C2H_CCX_TX_RPT to know if packet TX'ed
  successfully (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: Add set_channel (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: Add query_rx_desc (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: Add DIG parameter (jsc#SLE-13430, bsc#1176741).
- rtw88: Use udelay instead of usleep in atomic context
  (jsc#SLE-13430, bsc#1176741).
- rtw88: fix spelling mistake "fimrware" -> "firmware"
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8822c: update phy parameter tables to v50 (jsc#SLE-13430,
  bsc#1176741).
- rtw88: fix sparse warnings for download firmware routine
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: initialize mac/bb/rf basic functions
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: Organize chip TX/RX FIFO (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8723d: implement set_tx_power_index ops (jsc#SLE-13430,
  bsc#1176741).
- commit feaf8bd
* Tue Sep 22 2020 tiwai@suse.de
- iopoll: Introduce read_poll_timeout_atomic macro (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8723d: 11N chips don't support H2C queue (jsc#SLE-13430,
  bsc#1176741).
- rtw88: decompose while(1) loop of power sequence polling command
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: Add mac power-on/-off function (jsc#SLE-13430,
  bsc#1176741).
- rtw88: no need to send additional information to legacy firmware
  (jsc#SLE-13430, bsc#1176741).
- rtw88: add legacy firmware download for 8723D devices
  (jsc#SLE-13430, bsc#1176741).
- rtw88: set power trim according to efuse PG values
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: Add read_efuse to recognize efuse info from map
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: Add new chip op efuse_grant() to control efuse
  access (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: Add cfg_ldo25 to control LDO25 (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8723d: Add mac/bb/rf/agc/power_limit tables
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: Add RF read/write ops (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8723d: Add power sequence (jsc#SLE-13430, bsc#1176741).
- rtw88: 8723d: add beamform wrapper functions (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8723d: Add basic chip capabilities (jsc#SLE-13430,
  bsc#1176741).
- rtw88: add support for set/get antennas (jsc#SLE-13430,
  bsc#1176741).
- rtw88: make rtw_chip_ops::set_antenna return int (jsc#SLE-13430,
  bsc#1176741).
- rtw88: Add delay on polling h2c command status bit
  (jsc#SLE-13430, bsc#1176741).
- rtw88: Make two functions static (jsc#SLE-13430, bsc#1176741).
- rtw88: avoid unused function warnings (jsc#SLE-13430,
  bsc#1176741).
- rtw88: fix non-increase management packet sequence number
  (jsc#SLE-13430, bsc#1176741).
- iopoll: redefined readx_poll_timeout macro to simplify the code
  (jsc#SLE-13430, bsc#1176741).
- iopoll: introduce read_poll_timeout macro (jsc#SLE-13430,
  bsc#1176741).
- commit b67e00e
* Tue Sep 22 2020 tiwai@suse.de
- rtw88: add a debugfs entry to enable/disable coex mechanism
  (jsc#SLE-13430, bsc#1176741).
- rtw88: add a debugfs entry to dump coex's info (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8822c: config RF table path B before path A
  (jsc#SLE-13430, bsc#1176741).
- rtw88: kick off TX packets once for higher efficiency
  (jsc#SLE-13430, bsc#1176741).
- rtw88: pci: define a mask for TX/RX BD indexes (jsc#SLE-13430,
  bsc#1176741).
- rtw88: associate reserved pages with each vif (jsc#SLE-13430,
  bsc#1176741).
- rtw88: extract alloc rsvd_page and h2c skb routines
  (jsc#SLE-13430, bsc#1176741).
- rtw88: don't hold all IRQs disabled for PS operations
  (jsc#SLE-13430, bsc#1176741).
- wireless: realtek: Replace zero-length array with flexible-array
  member (jsc#SLE-13430, bsc#1176741).
- rtw88: remove unused member of struct rtw_hal (jsc#SLE-13430,
  bsc#1176741).
- rtw88: Fix incorrect beamformee role setting (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8822[bc]: Make tables const, reduce data object size
  (jsc#SLE-13430, bsc#1176741).
- rtw88: disable TX-AMSDU on 2.4G band (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8822c: modify rf protection setting (jsc#SLE-13430,
  bsc#1176741).
- rtw88: Use secondary channel offset enumeration (jsc#SLE-13430,
  bsc#1176741).
- rtw88: Use kfree_skb() instead of kfree() (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8822c: update power sequence to v16 (jsc#SLE-13430,
  bsc#1176741).
- rtw88: add ciphers to suppress error message (jsc#SLE-13430,
  bsc#1176741).
- rtw88: avoid holding mutex for cancel_delayed_work_sync()
  (jsc#SLE-13430, bsc#1176741).
- rtw88: move rtw_enter_ips() to the last when config
  (jsc#SLE-13430, bsc#1176741).
- commit 6eccf75
* Tue Sep 22 2020 tiwai@suse.de
- rtw88: pci: 8822c should set clock delay to zero (jsc#SLE-13430,
  bsc#1176741).
- rtw88: add rtw_read8_mask and rtw_read16_mask (jsc#SLE-13430,
  bsc#1176741).
- rtw88: remove unused parameter vif in rtw_lps_pg_info_get()
  (jsc#SLE-13430, bsc#1176741).
- rtw88: Fix return value of rtw_wow_check_fw_status
  (jsc#SLE-13430, bsc#1176741).
- rtw88: use shorter delay time to poll PS state (jsc#SLE-13430,
  bsc#1176741).
- rtw88: use true,false for bool variable (jsc#SLE-13430,
  bsc#1176741).
- rtw88: change max_num_of_tx_queue() definition to inline in
  pci.h (jsc#SLE-13430, bsc#1176741).
- rtw88: assign NULL to skb after being kfree()'ed (jsc#SLE-13430,
  bsc#1176741).
- rtw88: use rtw_hci_stop() instead of rtwdev->hci.ops->stop()
  (jsc#SLE-13430, bsc#1176741).
- rtw88: remove unused vif pointer in struct rtw_vif
  (jsc#SLE-13430, bsc#1176741).
- rtw88: remove unused variable 'in_lps' (jsc#SLE-13430,
  bsc#1176741).
- rtw88: remove unused spinlock (jsc#SLE-13430, bsc#1176741).
- rtw88: 8822c: update power sequence to v15 (jsc#SLE-13430,
  bsc#1176741).
- rtw88: fix TX secondary channel offset of 40M if current bw
  is 20M or 40M (jsc#SLE-13430, bsc#1176741).
- rtw88: Add wowlan net-detect support (jsc#SLE-13430,
  bsc#1176741).
- rtw88: Add wowlan pattern match support (jsc#SLE-13430,
  bsc#1176741).
- rtw88: support wowlan feature for 8822c (jsc#SLE-13430,
  bsc#1176741).
- rtw88: load wowlan firmware if wowlan is supported
  (jsc#SLE-13430, bsc#1176741).
- rtw88: add interface config for 8822c (jsc#SLE-13430,
  bsc#1176741).
- rtw88: pci: reset dma when reset pci trx ring (jsc#SLE-13430,
  bsc#1176741).
- commit ea5af20
* Tue Sep 22 2020 tiwai@suse.de
- rtw88: pci: reset ring index when release skbs in tx ring
  (jsc#SLE-13430, bsc#1176741).
- rtw88: allows to enable/disable HCI link PS mechanism
  (jsc#SLE-13430, bsc#1176741).
- rtw88: pci: enable CLKREQ function if host supports it
  (jsc#SLE-13430, bsc#1176741).
- rtw88: pci: use for loop instead of while loop for DBI/MDIO
  (jsc#SLE-13430, bsc#1176741).
- rtw88: pci: use macros to access PCI DBI/MDIO registers
  (jsc#SLE-13430, bsc#1176741).
- rtw88: remove duplicated include from ps.c (jsc#SLE-13430,
  bsc#1176741).
- rtw88: signal completion even on firmware-request failure
  (jsc#SLE-13430, bsc#1176741).
- rtw88: fix potential NULL pointer access for firmware
  (jsc#SLE-13430, bsc#1176741).
- rtw88: raise LPS threshold to 50, for less power consumption
  (jsc#SLE-13430, bsc#1176741).
- rtw88: remove redundant null pointer check on arrays
  (jsc#SLE-13430, bsc#1176741).
- rtw88: avoid FW info flood (jsc#SLE-13430, bsc#1176741).
- rtw88: fix potential read outside array boundary (jsc#SLE-13430,
  bsc#1176741).
- rtw88: rearrange if..else statements for rx rate indexes
  (jsc#SLE-13430, bsc#1176741).
- rtw88: use rtw_phy_pg_cfg_pair struct, not arrays
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8822b: add RFE type 3 support (jsc#SLE-13430,
  bsc#1176741).
- rtw88: fix sparse warnings for power tracking (jsc#SLE-13430,
  bsc#1176741).
- rtw88: fix sparse warnings for DPK (jsc#SLE-13430, bsc#1176741).
- rtw88: fix GENMASK_ULL for u64 (jsc#SLE-13430, bsc#1176741).
- rtw88: add phy_info debugfs to show Tx/Rx physical status
  (jsc#SLE-13430, bsc#1176741).
- rtw88: add set_bitrate_mask support (jsc#SLE-13430,
  bsc#1176741).
- commit 9b64909
* Tue Sep 22 2020 tiwai@suse.de
- rtw88: Enable 802.11ac beamformee support (jsc#SLE-13430,
  bsc#1176741).
- rtw88: add power tracking support (jsc#SLE-13430, bsc#1176741).
- rtw88: use macro to check the current band (jsc#SLE-13430,
  bsc#1176741).
- rtw88: mark rtw_fw_hdr __packed (jsc#SLE-13430, bsc#1176741).
- rtw88: include interrupt.h for tasklet_struct (jsc#SLE-13430,
  bsc#1176741).
- rtw88: use a for loop in rtw_power_mode_change(), not goto
  (jsc#SLE-13430, bsc#1176741).
- rtw88: coex: Set 4 slot mode for A2DP (jsc#SLE-13430,
  bsc#1176741).
- rtw88: pci: config phy after chip info is setup (jsc#SLE-13430,
  bsc#1176741).
- rtw88: Use rtw_write8_set to set SYS_FUNC (jsc#SLE-13430,
  bsc#1176741).
- rtw88: add NL80211_EXT_FEATURE_CAN_REPLACE_PTK0 support
  (jsc#SLE-13430, bsc#1176741).
- rtw88: config 8822c multicast address in MAC init flow
  (jsc#SLE-13430, bsc#1176741).
- rtw88: Fix an error message (jsc#SLE-13430, bsc#1176741).
- rtw88: use struct rtw_fw_hdr to access firmware header
  (jsc#SLE-13430, bsc#1176741).
- rtw88: raise firmware version debug level (jsc#SLE-13430,
  bsc#1176741).
- rtw88: configure TX queue EDCA parameters (jsc#SLE-13430,
  bsc#1176741).
- rtw88: Don't set RX_FLAG_DECRYPTED if packet has no encryption
  (jsc#SLE-13430, bsc#1176741).
- rtw88: flush hardware tx queues (jsc#SLE-13430, bsc#1176741).
- rtw88: add TX-AMSDU support (jsc#SLE-13430, bsc#1176741).
- rtw88: report tx rate to mac80211 stack (jsc#SLE-13430,
  bsc#1176741).
- rtw88: take over rate control from mac80211 (jsc#SLE-13430,
  bsc#1176741).
- commit 1c0fddd
* Tue Sep 22 2020 tiwai@suse.de
- rtw88: add driver TX queue support (jsc#SLE-13430, bsc#1176741).
- rtw88: allows to set RTS in TX descriptor (jsc#SLE-13430,
  bsc#1176741).
- rtw88: check firmware leave lps successfully (jsc#SLE-13430,
  bsc#1176741).
- rtw88: remove misleading module parameter rtw_fw_support_lps
  (jsc#SLE-13430, bsc#1176741).
- rtw88: add deep PS PG mode for 8822c (jsc#SLE-13430,
  bsc#1176741).
- rtw88: select deep PS mode when module is inserted
  (jsc#SLE-13430, bsc#1176741).
- rtw88: not to enter LPS by coex strategy (jsc#SLE-13430,
  bsc#1176741).
- rtw88: add deep power save support (jsc#SLE-13430, bsc#1176741).
- rtw88: leave PS state for dynamic mechanism (jsc#SLE-13430,
  bsc#1176741).
- rtw88: LPS enter/leave should be protected by lock
  (jsc#SLE-13430, bsc#1176741).
- rtw88: remove unused lps state check helper (jsc#SLE-13430,
  bsc#1176741).
- rtw88: not to control LPS by each vif (jsc#SLE-13430,
  bsc#1176741).
- rtw88: not to enter or leave PS under IRQ (jsc#SLE-13430,
  bsc#1176741).
- rtw88: pci: reset H2C queue indexes in a single write
  (jsc#SLE-13430, bsc#1176741).
- rtw88: remove redundant flag check helper function
  (jsc#SLE-13430, bsc#1176741).
- rtw88: 8822c: fix boolreturn.cocci warnings (jsc#SLE-13430,
  bsc#1176741).
- rtw88: configure firmware after HCI started (jsc#SLE-13430,
  bsc#1176741).
- rtw88: pci: release tx skbs DMAed when stop (jsc#SLE-13430,
  bsc#1176741).
- rtw88: pci: extract skbs free routine for trx rings
  (jsc#SLE-13430, bsc#1176741).
- commit f410f93
* Tue Sep 22 2020 tiwai@suse.de
- rtw88: report RX power for each antenna (jsc#SLE-13430,
  bsc#1176741).
- rtw88: allows to receive AMSDU in AMPDU (jsc#SLE-13430,
  bsc#1176741).
- rtw88: add dynamic cck pd mechanism (jsc#SLE-13430,
  bsc#1176741).
- rtw88: move IQK/DPK into phy_calibration (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8822c: add SW DPK support (jsc#SLE-13430, bsc#1176741).
- rtw88: 8822c: add FW IQK support (jsc#SLE-13430, bsc#1176741).
- rtw88: 8822c: Enable interrupt migration (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8822c: update pwr_seq to v13 (jsc#SLE-13430,
  bsc#1176741).
- rtw88: 8822c: update PHY parameter to v38 (jsc#SLE-13430,
  bsc#1176741).
- rtw88: pci: enable MSI interrupt (jsc#SLE-13430, bsc#1176741).
- rtw88: pci: Move a mass of jobs in hw IRQ to soft IRQ
  (jsc#SLE-13430, bsc#1176741).
- rtw88: remove redundant assignment to pointer debugfs_topdir
  (jsc#SLE-13430, bsc#1176741).
- rtw88: drop unused rtw_coex_coex_dm_reset() (jsc#SLE-13430,
  bsc#1176741).
- rtw88: Fix an error message (jsc#SLE-13430, bsc#1176741).
- rtw88: add BT co-existence support (jsc#SLE-13430, bsc#1176741).
- rtw88: enclose c2h cmd handle with mutex (jsc#SLE-13430,
  bsc#1176741).
- rtw88: allow c2h operation in irq context (jsc#SLE-13430,
  bsc#1176741).
- rtw88: pci: remove set but not used variable 'ip_sel'
  (jsc#SLE-13430, bsc#1176741).
- rtw88: use txpwr_lmt_cfg_pair struct, not arrays (jsc#SLE-13430,
  bsc#1176741).
- commit e7eb287
* Tue Sep 22 2020 tiwai@suse.de
- libata: Use per port sync for detach (jsc#SLE-14459).
- commit a98d7fd
* Tue Sep 22 2020 tiwai@suse.de
- libata: implement ATA_HORKAGE_MAX_TRIM_128M and apply to
  Sandisks (jsc#SLE-14459).
- ata: ahci: use ata_link_info() instead of ata_link_printk()
  (jsc#SLE-14459).
- commit e4929bb
* Tue Sep 22 2020 nsaenzjulienne@suse.de
- soc: imx-scu: Align imx sc msg structs to 4 (jsc#SLE-16106).
- commit 335f84a
* Tue Sep 22 2020 jroedel@suse.de
- Refresh
  patches.suse/vfio-fix-foll_longterm-use-simplify-get_user_pages_remote-call.
- commit 194b3fa
* Tue Sep 22 2020 nsaenzjulienne@suse.de
- soc: imx8m: fix build warning (jsc#SLE-16106).
- soc: imx8m: Correct i.MX8MP UID fuse offset (jsc#SLE-16106).
- soc: imx8m: No need to put node when of_find_compatible_node()
  failed (jsc#SLE-16106).
- soc: imx8: select SOC_BUS (jsc#SLE-16106).
- soc: imx: drop COMPILE_TEST for IMX_SCU_SOC (jsc#SLE-16106).
- soc: imx: increase build coverage for imx8m soc driver
  (jsc#SLE-16106).
- Update configs
- soc: imx: gpcv2: include linux/sizes.h (jsc#SLE-16106).
- soc: imx: Enable compile testing of IMX_SCU_SOC (jsc#SLE-16106).
- soc: imx: Add i.MX8MP SoC driver support (jsc#SLE-16106).
- soc: imx8: print SoC type and revision (jsc#SLE-16106).
- soc: imx8mq: Read SOC revision from TF-A (jsc#SLE-16106).
- soc: imx-scu: Using existing serial_number instead of UID
  (jsc#SLE-16106).
- soc: imx8: Using existing serial_number instead of UID
  (jsc#SLE-16106).
- soc: imx: imx-scu: Getting UID from SCU should have response
  (jsc#SLE-16106).
- soc: imx8: Add i.MX8MM UID(unique identifier) support
  (jsc#SLE-16106).
- soc: imx8: Add i.MX8MQ UID(unique identifier) support
  (jsc#SLE-16106).
- commit 4500a37
* Tue Sep 22 2020 tiwai@suse.de
- Update patch reference for most driver securiy fix (CVE-2020-0432 bsc#1176721)
- commit f4104d9
* Tue Sep 22 2020 tiwai@suse.de
- Update patch reference for pinctrl security fix (CVE-2020-0427, bsc#1176725)
- commit 13119a3
* Tue Sep 22 2020 tiwai@suse.de
- Update patch reference for HID security fix (CVE-2020-0431, bsc#1176722)
- commit 92b53fb
* Tue Sep 22 2020 tiwai@suse.de
- HID: core: fix dmesg flooding if report field larger than 32bit
  (bsc#1176775).
- HID: core: Add printk_once variants to hid_warn() etc
  (bsc#1176775).
- HID: core: reformat and reduce hid_printk macros (bsc#1176775).
- commit 37f3024
* Tue Sep 22 2020 nsaenzjulienne@suse.de
- pinctrl: freescale: Add i.MX8MP pinctrl driver support
  (jsc#SLE-16106).
- pinctrl: freescale: imx: Add of_node_put() before return
  (jsc#SLE-16106).
- commit d03fce8
* Tue Sep 22 2020 msuchanek@suse.de
- powerpc/pseries: new lparcfg key/value pair:
  partition_affinity_score (jsc#SLE-16360).
- powerpc/perf: consolidate GPCI hcall structs into asm/hvcall.h
  (jsc#SLE-16360).
- commit ab2ec63
* Tue Sep 22 2020 msuchanek@suse.de
- kernel-syms.spec.in: Also use bz compression (boo#1175882).
- commit ecaf78d
* Tue Sep 22 2020 jroedel@suse.de
- powerpc: use the generic dma_ops_bypass mode (bsc#1175713).
- Update config files.
- commit 73f34e8
* Tue Sep 22 2020 nsaenzjulienne@suse.de
- clk: imx8mq: Add VIDEO2_PLL clock (jsc#SLE-16106).
- Refresh: patches.suse/clk-imx-imx8mq-fix-sys3_pll_out_sels.patch
- commit 010f11f
* Tue Sep 22 2020 jroedel@suse.de
- dma-mapping: make support for dma ops optional (bsc#1175713).
- Update config files.
- commit 1f38426
* Tue Sep 22 2020 jroedel@suse.de
- x86/mm: unencrypted non-blocking DMA allocations use coherent
  pools (bsc#1175713).
- Update config files.
- commit ac7effe
* Tue Sep 22 2020 msuchanek@suse.de
- powerpc/pmem: Initialize pmem device on newer hardware
  (jsc#SLE-16402 bsc#1176109 ltc#187964).
- powerpc/pmem: Avoid the barrier in flush routines (jsc#SLE-16402
  bsc#1176109 ltc#187964).
- powerpc/pmem: Update ppc64 to use the new barrier instruction
  (jsc#SLE-16402 bsc#1176109 ltc#187964).
- libnvdimm/nvdimm/flush: Allow architecture to override the
  flush barrier (jsc#SLE-16402 bsc#1176109 ltc#187964).
- powerpc/pmem: Add flush routines using new pmem store and sync
  instruction (jsc#SLE-16402 bsc#1176109 ltc#187964).
- powerpc/pmem: Add new instructions for persistent storage and
  sync (jsc#SLE-16402 bsc#1176109 ltc#187964).
- powerpc/pmem: Restrict papr_scm to P8 and above (jsc#SLE-16402
  bsc#1176109 ltc#187964).
- commit bce8b0d
* Tue Sep 22 2020 bp@suse.de
- Update
  patches.suse/media-uvcvideo-Avoid-cyclic-entity-chains-due-to-mal.patch
  (bsc#1176423 CVE-2020-0404).
- commit 23cba3a
* Tue Sep 22 2020 jroedel@suse.de
- dma-remap: separate DMA atomic pools from direct remap code
  (bsc#1175713).
- Update config files.
- commit 652d23c
* Tue Sep 22 2020 jroedel@suse.de
- dma-direct: provide mmap and get_sgtable method overrides
  (bsc#1175713).
- Update config files.
- Refresh
  patches.suse/dma-direct-relax-addressability-checks-in-dma_direct_supported.patch.
- commit 640f342
* Tue Sep 22 2020 jeyu@suse.de
- oracleasm: reinstate bio_map_user_iov() declaration in
  include/linux/bio.h (bsc#1176792).
- commit 320783e
* Tue Sep 22 2020 jroedel@suse.de
- remoteproc: don't allow modular build (bsc#1175713).
- Update config files.
- commit 4fcba5f
* Tue Sep 22 2020 jslaby@suse.cz
- platform/x86: dcdbas: Check SMBIOS for protected buffer address
  (jsc#SLE-14407).
- commit 7f21c07
* Tue Sep 22 2020 wqu@suse.com
- btrfs: require only sector size alignment for parent eb  bytenr
  (bsc#1176789).
- commit 868a458
* Tue Sep 22 2020 wqu@suse.com
- btrfs: tree-checker: fix the error message for transid error
  (bsc#1176788).
- commit 96dd2e2
* Tue Sep 22 2020 glin@suse.com
- libbpf: Fix readelf output parsing for Fedora (bsc#1155518).
- commit 667b79c
* Tue Sep 22 2020 glin@suse.com
- libbpf: Fix readelf output parsing on powerpc with recent binutils (bsc#1155518).
- commit 20955ec
* Mon Sep 21 2020 neilb@suse.de
- nfs: Fix getxattr kernel panic and memory overflow (bsc#1176381
  CVE-2020-2521).
- commit 0de797a
* Mon Sep 21 2020 mkubecek@suse.cz
- hsr: use netdev_err() instead of WARN_ONCE() (bsc#1176659).
- commit fe91e40
* Mon Sep 21 2020 mkubecek@suse.cz
- netfilter: ipset: Fix forceadd evaluation path (bsc#1176587).
- commit 64d0b5f
* Mon Sep 21 2020 bp@suse.de
- x86/mmu: Allocate/free a PASID (jsc#13318).
- commit 5c3bca0
* Mon Sep 21 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/powerpc-book3s64-radix-Fix-boot-failure-with-large-a.patch
  patches.suse/powerpc-papr_scm-Limit-the-readability-of-perf_stats.patch
- commit 1c47455
* Mon Sep 21 2020 jroedel@suse.de
- dma-mapping: add a dma_ops_bypass flag to struct device
  (bsc#1175713).
- Refresh
  patches.suse/0003-kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
- commit 30eaa99
* Mon Sep 21 2020 jroedel@suse.de
- dma-mapping: drop the dev argument to arch_sync_dma_for_*
  (bsc#1175713).
- Refresh patches.suse/iommu-dma-iommu-handle-deferred-devices.
- Refresh
  patches.suse/iommu-dma-iommu-use-the-dev-coherent_dma_mask.
- commit f6fa05a
* Mon Sep 21 2020 jroedel@suse.de
- dma-mapping: remove the dma_declare_coherent_memory export
  (bsc#1175713).
- Refresh
  patches.suse/dma-mapping-fix-handling-of-dma-ranges-for-reserved-.patch.
- commit a59e7a9
* Mon Sep 21 2020 bp@suse.de
- x86/cpufeatures: Mark ENQCMD as disabled when configured out
  (jsc#13318).
- commit b9a8428
* Mon Sep 21 2020 jroedel@suse.de
- dma-mapping: remove dma_release_declared_memory (bsc#1175713).
- Refresh
  patches.suse/dma-mapping-fix-handling-of-dma-ranges-for-reserved-.patch.
- commit 07c01cd
* Mon Sep 21 2020 bp@suse.de
- mm: Add a pasid member to struct mm_struct (jsc#13318).
- commit 8b1797c
* Mon Sep 21 2020 jroedel@suse.de
- dma-pool: Fix an uninitialized variable bug in
  atomic_pool_expand() (bsc#1175713).
- PCI/P2PDMA: Fix build without DMA ops (bsc#1175713).
- dma-pool: Only allocate from CMA when in same memory zone
  (bsc#1175713).
- dma-pool: fix coherent pool allocations for IOMMU mappings
  (bsc#1175713).
- dma-mapping: consolidate the NO_DMA definition in
  kernel/dma/Kconfig (bsc#1175713).
- dma-debug: remove debug_dma_assert_idle() function
  (bsc#1175713).
- dma-debug: fix debug_dma_assert_idle(), use rcu_read_lock()
  (bsc#1175713).
- dma-contiguous: cleanup dma_alloc_contiguous (bsc#1175713).
- dma-debug: use named initializers for dir2name (bsc#1175713).
- dma-mapping: inline the fast path dma-direct calls
  (bsc#1175713).
- dma-mapping: move the remaining DMA API calls out of line
  (bsc#1175713).
- dma-pool: do not allocate pool memory from CMA (bsc#1175713).
- dma-pool: make sure atomic pool suits device (bsc#1175713).
- dma-pool: introduce dma_guess_pool() (bsc#1175713).
- dma-pool: get rid of dma_in_atomic_pool() (bsc#1175713).
- dma-direct: provide function to check physical memory area
  validity (bsc#1175713).
- xsk: Use dma_need_sync instead of reimplenting it (bsc#1175713).
- xsk: Replace the cheap_dma flag with a dma_need_sync flag
  (bsc#1175713).
- dma-mapping: Add a new dma_need_sync API (bsc#1175713).
- dma-mapping: warn when coherent pool is depleted (bsc#1175713).
- scsi: mptfusion: Don't use GFP_ATOMIC for larger DMA allocations
  (bsc#1175713).
- dma-remap: align the size in dma_common_*_remap() (bsc#1175713).
- dma-mapping: DMA_COHERENT_POOL should select GENERIC_ALLOCATOR
  (bsc#1175713).
- dma-direct: add missing set_memory_decrypted() for coherent
  mapping (bsc#1175713).
- dma-direct: check return value when encrypting or decrypting
  memory (bsc#1175713).
- dma-direct: re-encrypt memory if dma_direct_alloc_pages()
  fails (bsc#1175713).
- dma-direct: always align allocation size in
  dma_direct_alloc_pages() (bsc#1175713).
- dma-direct: mark __dma_direct_alloc_pages static (bsc#1175713).
- dma-direct: re-enable mmap for !CONFIG_MMU (bsc#1175713).
- dma-pool: decouple DMA_REMAP from DMA_COHERENT_POOL
  (bsc#1175713).
- dma-pool: fix too large DMA pools on medium memory size systems
  (bsc#1175713).
- dma-mapping: add generic helpers for mapping sgtable objects
  (bsc#1175713).
- dma-contiguous: fix comment for dma_release_from_contiguous
  (bsc#1175713).
- dma-pool: scale the default DMA coherent pool size with memory
  capacity (bsc#1175713).
- dma-pool: add pool sizes to debugfs (bsc#1175713).
- dma-direct: atomic allocations must come from atomic coherent
  pools (bsc#1175713).
- dma-pool: dynamically expanding atomic pools (bsc#1175713).
- dma-pool: add additional coherent pools to map to gfp mask
  (bsc#1175713).
- dma-debug: make __dma_entry_alloc_check_leak() static
  (bsc#1175713).
- dma-mapping: use vmap insted of reimplementing it (bsc#1175713).
- dma-direct: provide a arch_dma_clear_uncached hook
  (bsc#1175713).
- dma-direct: make uncached_kernel_address more general
  (bsc#1175713).
- dma-direct: consolidate the error handling in
  dma_direct_alloc_pages (bsc#1175713).
- dma-direct: remove the cached_kernel_address hook (bsc#1175713).
- dma-mapping: Fix dma_pgprot() for unencrypted coherent pages
  (bsc#1175713).
- dma-direct: improve DMA mask overflow reporting (bsc#1175713).
- dma-direct: improve swiotlb error reporting (bsc#1175713).
- lib/genalloc.c: rename addr_in_gen_pool to gen_pool_has_addr
  (bsc#1175713).
- dma-debug: clean up put_hash_bucket() (bsc#1175713).
- dma-debug: increase HASH_SIZE (bsc#1175713).
- dma-debug: reorder struct dma_debug_entry fields (bsc#1175713).
- dma-mapping: merge the generic remapping helpers into dma-direct
  (bsc#1175713).
- dma-direct: remove the dma_handle argument to
  __dma_direct_alloc_pages (bsc#1175713).
- dma-direct: remove __dma_direct_free_pages (bsc#1175713).
- kernel: dma-contiguous: mark CMA parameters
  __initdata/__initconst (bsc#1175713).
- dma-mapping: remove the DMA_ATTR_WRITE_BARRIER flag
  (bsc#1175713).
- dma-debug: Use pr_warn instead of pr_warning (bsc#1175713).
- dma-mapping: fix false positivse warnings in
  dma_common_free_remap() (bsc#1175713).
- arm64/ARM: configs: Change CONFIG_REMOTEPROC from m to y
  (bsc#1175713).
- dma-mapping: Remove dma_check_mask() (bsc#1175713).
- swiotlb: Remove call to sme_active() (bsc#1175713).
- arm64: use asm-generic/dma-mapping.h (bsc#1175713).
- swiotlb-xen: merge xen_unmap_single into xen_swiotlb_unmap_page
  (bsc#1175713).
- swiotlb-xen: simplify cache maintainance (bsc#1175713).
- swiotlb-xen: use the same foreign page check everywhere
  (bsc#1175713).
- swiotlb-xen: remove xen_swiotlb_dma_mmap and
  xen_swiotlb_dma_get_sgtable (bsc#1175713).
- xen: remove the exports for
  xen_{create,destroy}_contiguous_region (bsc#1175713).
- xen/arm: remove xen_dma_ops (bsc#1175713).
- xen/arm: simplify dma_cache_maint (bsc#1175713).
- xen/arm: use dev_is_dma_coherent (bsc#1175713).
- xen/arm: consolidate page-coherent.h (bsc#1175713).
- xen/arm: use dma-noncoherent.h calls for xen-swiotlb cache
  maintainance (bsc#1175713).
- dma-mapping: introduce a dma_common_find_pages helper
  (bsc#1175713).
- dma-mapping: always use VM_DMA_COHERENT for generic DMA remap
  (bsc#1175713).
- dma-mapping: provide a better default ->get_required_mask
  (bsc#1175713).
- dma-mapping: remove the dma_mmap_from_dev_coherent export
  (bsc#1175713).
- dma-mapping: remove dma_{alloc,free,mmap}_writecombine
  (bsc#1175713).
- dma-mapping: remove CONFIG_ARCH_NO_COHERENT_DMA_MMAP
  (bsc#1175713).
- dma-mapping: add a dma_can_mmap helper (bsc#1175713).
- dma-mapping: move the dma_get_sgtable API comments from arm
  to common code (bsc#1175713).
- dma-mapping: make dma_atomic_pool_init self-contained
  (bsc#1175713).
- dma-mapping: remove arch_dma_mmap_pgprot (bsc#1175713).
- dma-mapping: remove is_device_dma_capable (bsc#1175713).
- commit bf566c9
* Mon Sep 21 2020 bp@suse.de
- x86/msr-index: Define an IA32_PASID MSR (jsc#13318).
- commit 291d536
* Mon Sep 21 2020 bp@suse.de
- x86/fpu/xstate: Add supervisor PASID state for ENQCMD
  (jsc#13318).
- commit f6d0d32
* Mon Sep 21 2020 nsaenzjulienne@suse.de
- clk: imx8mp: add mu root clk (jsc#SLE-16106).
- clk: imx: use imx8m_clk_hw_composite_bus for i.MX8M bus clk
  slice (jsc#SLE-16106).
- clk: imx: add imx8m_clk_hw_composite_bus (jsc#SLE-16106).
- clk: imx: add mux ops for i.MX8M composite clk (jsc#SLE-16106).
- clk: imx8m: migrate A53 clk root to use composite core
  (jsc#SLE-16106).
- clk: imx8mp: use imx8m_clk_hw_composite_core to simplify code
  (jsc#SLE-16106).
- clk: imx8mp: Define gates for pll1/2 fixed dividers
  (jsc#SLE-16106).
- clk: imx: imx8mp: fix pll mux bit (jsc#SLE-16106).
- clk: imx8m: drop clk_hw_set_parent for A53 (jsc#SLE-16106).
- dt-bindings: clocks: imx8mp: Add ids for audiomix clocks
  (jsc#SLE-16106).
- clk: imx: Add helpers for passing the device as argument
  (jsc#SLE-16106).
- clk: imx: pll14xx: Add the device as argument when registering
  (jsc#SLE-16106).
- clk: imx: gate2: Allow single bit gating clock (jsc#SLE-16106).
- clk: imx8mq: A53 core clock no need to be critical
  (jsc#SLE-16106).
- clk: imx8mp: A53 core clock no need to be critical
  (jsc#SLE-16106).
- clk: imx8mm: A53 core clock no need to be critical
  (jsc#SLE-16106).
- clk: imx8mn: A53 core clock no need to be critical
  (jsc#SLE-16106).
- clk: imx: imx8mp: fix a53 cpu clock (jsc#SLE-16106).
- clk: imx: imx8mn: fix a53 cpu clock (jsc#SLE-16106).
- clk: imx: imx8mm: fix a53 cpu clock (jsc#SLE-16106).
- clk: imx: imx8mq: fix a53 cpu clock (jsc#SLE-16106).
- clk: imx8mp: Rename the IMX8MP_CLK_HDMI_27M clock
  (jsc#SLE-16106).
- clk: imx8mn: Remove unused includes (jsc#SLE-16106).
- clk: imx8mm: Remove unused includes (jsc#SLE-16106).
- clk: imx8mp: Include slab.h instead of clkdev.h (jsc#SLE-16106).
- clk: imx8mp: Add missing of_node_put() (jsc#SLE-16106).
- clk: imx8mn: Add missing of_node_put() (jsc#SLE-16106).
- clk: imx8mm: Add missing of_node_put() (jsc#SLE-16106).
- clk: imx8mq: Add missing of_node_put() (jsc#SLE-16106).
- clk: imx: Include clk-provider.h instead of clk.h for i.MX8M
  SoCs clock driver (jsc#SLE-16106).
- clk: imx8mm: Add CLKO2 support (jsc#SLE-16106).
- clk: imx: imx8mn: use imx8m_clk_hw_composite_core
  (jsc#SLE-16106).
- clk: imx: imx8mm: use imx8m_clk_hw_composite_core
  (jsc#SLE-16106).
- clk: imx: imx8mq: use imx8m_clk_hw_composite_core
  (jsc#SLE-16106).
- clk: imx: composite-8m: add imx8m_clk_hw_composite_core
  (jsc#SLE-16106).
- clk: imx: imx8mp: add ocotp root clk (jsc#SLE-16106).
- clk: imx8mn: add SNVS clock to clock tree (jsc#SLE-16106).
- dt-bindings: clock: imx8mn: add SNVS clock (jsc#SLE-16106).
- clk: imx8mp: Correct the enet_qos parent clock (jsc#SLE-16106).
- clk: imx8mp: Correct IMX8MP_CLK_HDMI_AXI clock parent
  (jsc#SLE-16106).
- clk: imx8mn: Fix incorrect clock defines (jsc#SLE-16106).
- clk: imx: Add support for i.MX8MP clock driver (jsc#SLE-16106).
- Update config
- dt-bindings: imx: Add clock binding doc for i.MX8MP
  (jsc#SLE-16106).
- clk: imx: gate4: Switch imx_clk_gate4_flags() to clk_hw based
  API (jsc#SLE-16106).
- clk: imx: imx8mq: Switch to clk_hw based API (jsc#SLE-16106).
- clk: imx: imx8mm: Switch to clk_hw based API (jsc#SLE-16106).
- Refresh: patches.suse/clk-imx8mm-Fix-the-CLKO1-source-select-list.patch
- clk: imx: imx8mn: Switch to clk_hw based API (jsc#SLE-16106).
- clk: imx: Remove __init for imx_obtain_fixed_clk_hw() API
  (jsc#SLE-16106).
- clk: imx: gate3: Switch to clk_hw based API (jsc#SLE-16106).
- clk: imx: add hw API imx_clk_hw_mux2_flags (jsc#SLE-16106).
- clk: imx: add imx_unregister_hw_clocks (jsc#SLE-16106).
- clk: imx: clk-composite-8m: Switch to clk_hw based API
  (jsc#SLE-16106).
- clk: imx: clk-pll14xx: Switch to clk_hw based API
  (jsc#SLE-16106).
- clk: imx: Rename the imx_clk_divider_gate to imply it's clk_hw
  based (jsc#SLE-16106).
- clk: imx: Rename the imx_clk_pfdv2 to imply it's clk_hw based
  (jsc#SLE-16106).
- clk: imx: Rename the imx_clk_pllv4 to imply it's clk_hw based
  (jsc#SLE-16106).
- clk: imx: Rename sccg and frac pll register to suggest clk_hw
  (jsc#SLE-16106).
- clk: imx: imx7ulp composite: Rename to show is clk_hw based
  (jsc#SLE-16106).
- clk: imx: pllv2: Switch to clk_hw based API (jsc#SLE-16106).
- clk: imx: pllv1: Switch to clk_hw based API (jsc#SLE-16106).
- clk: imx: Replace all the clk based helpers with macros
  (jsc#SLE-16106).
- clk: imx: Rename the SCCG to SSCG (jsc#SLE-16106).
- clk: imx: Add correct failure handling for clk based helpers
  (jsc#SLE-16106).
- clk: imx8mn: correct the usb1_ctrl parent to be usb_bus
  (jsc#SLE-16106).
- clk: imx8m: Suppress bind attrs (jsc#SLE-16106).
- clk: imx: Mark dram pll on 8mm and 8mn with CLK_GET_RATE_NOCACHE
  (jsc#SLE-16106).
- clk: imx8m: Set CLK_GET_RATE_NOCACHE on dram clocks
  (jsc#SLE-16106).
- clk: imx: imx8mq: mark sys1/2_pll as fixed clock
  (jsc#SLE-16106).
- Refresh: patches.suse/clk-imx-imx8mq-fix-sys3_pll_out_sels.patch
- clk: imx: imx8mn: mark sys_pll1/2 as fixed clock (jsc#SLE-16106).
- clk: imx: imx8mm: mark sys_pll1/2 as fixed clock
  (jsc#SLE-16106).
- clk: imx8mn: Define gates for pll1/2 fixed dividers
  (jsc#SLE-16106).
- clk: imx8mm: Define gates for pll1/2 fixed dividers
  (jsc#SLE-16106).
- clk: imx8mq: Define gates for pll1/2 fixed dividers
  (jsc#SLE-16106).
- clk: imx8mn: Use common 1443X/1416X PLL clock structure
  (jsc#SLE-16106).
- clk: imx8mm: Move 1443X/1416X PLL clock structure to common
  place (jsc#SLE-16106).
- clk: imx: imx8mn: drop unused pll enum (jsc#SLE-16106).
- clk: imx: imx8mn: fix pll mux bit (jsc#SLE-16106).
- clk: imx: imx8mn: fix audio pll setting (jsc#SLE-16106).
- clk: imx8mn: Add necessary frequency support for ARM PLL table
  (jsc#SLE-16106).
- clk: imx8mn: Add missing rate_count assignment for each PLL
  structure (jsc#SLE-16106).
- clk: imx8mn: fix int pll clk gate (jsc#SLE-16106).
- clk: imx8mn: Add GIC clock (jsc#SLE-16106).
- clk: imx8mn: Fix incorrect parents (jsc#SLE-16106).
- clk: imx8mq: Unregister clks when of_clk_add_provider failed
  (jsc#SLE-16106).
- clk: imx8mm: Unregister clks when of_clk_add_provider failed
  (jsc#SLE-16106).
- clk: imx8mn: Keep uart clocks on for early console
  (jsc#SLE-16106).
- clk: imx: Remove unused function statement (jsc#SLE-16106).
- clk: imx8mm: Switch to platform driver (jsc#SLE-16106).
- clk: imx: Remove unused clk based API (jsc#SLE-16106).
- clk: imx8mq: set correct parent for usb ctrl clocks
  (jsc#SLE-16106).
- clk: imx8mq: Remove CLK_IS_CRITICAL flag for IMX8MQ_CLK_TMU_ROOT
  (jsc#SLE-16106).
- clk: imx8mm: rename 'share_count_dcss' to 'share_count_disp'
  (jsc#SLE-16106).
- clk: imx8mm: correct the usb1_ctrl parent to be usb_bus
  (jsc#SLE-16106).
- clk: imx: Add support for i.MX8MN clock driver (jsc#SLE-16106).
- Update config
- clk: imx: Add API for clk unregister when driver probe fail
  (jsc#SLE-16106).
- clk: imx8mm: Make 1416X/1443X PLL macro definitions common
  for usage (jsc#SLE-16106).
- dt-bindings: imx: Add clock binding doc for i.MX8MN
  (jsc#SLE-16106).
- commit 354d173
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: Increment management interface revision
  (jsc#SLE-13430).
- Bluetooth: use the proper scan params when conn is pending
  (jsc#SLE-13430).
- Revert "Bluetooth: btusb: Disable runtime suspend on Realtek
  devices" (jsc#SLE-13430).
- Bluetooth: Enable controller RPA resolution using Experimental
  feature (jsc#SLE-13430).
- Bluetooth: Enable RPA Timeout (jsc#SLE-13430).
- Bluetooth: Enable/Disable address resolution during le create
  conn (jsc#SLE-13430).
- Bluetooth: Let controller creates RPA during le create conn
  (jsc#SLE-13430).
- Bluetooth: Translate additional address type during le_conn
  (jsc#SLE-13430).
- commit d8a924d
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: Update resolving list when updating whitelist
  (jsc#SLE-13430).
- Bluetooth: Configure controller address resolution if available
  (jsc#SLE-13430).
- Bluetooth: Translate additional address type correctly
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Stop collecting memdump again for command
  timeout during SSR (jsc#SLE-13430).
- Bluetooth: Fix suspend notifier race (jsc#SLE-13430).
- Bluetooth: Return NOTIFY_DONE for hci_suspend_notifier
  (jsc#SLE-13430).
- Bluetooth: btusb: Fix and detect most of the Chinese Bluetooth
  controllers (jsc#SLE-13430).
- Bluetooth: Add per-instance adv disable/remove (jsc#SLE-13430).
- Bluetooth: hci_qca: Bug fixes for SSR (jsc#SLE-13430).
- Bluetooth: btusb: add Realtek 8822CE to usb_device_id table
  (jsc#SLE-13430).
- commit 8ca4fb2
* Mon Sep 21 2020 tiwai@suse.de
- Replace HTTP links with HTTPS ones: BLUETOOTH SUBSYSTEM
  (jsc#SLE-13430).
- Bluetooth: Use fallthrough pseudo-keyword (jsc#SLE-13430).
- Bluetooth: RFCOMM: Use fallthrough pseudo-keyword
  (jsc#SLE-13430).
- Bluetooth: core: Use fallthrough pseudo-keyword (jsc#SLE-13430).
- Bluetooth: Use whitelist for scan policy when suspending
  (jsc#SLE-13430).
- Bluetooth: le_simult_central_peripheral experimental feature
  (jsc#SLE-13430).
- Bluetooth: Fix kernel oops triggered by hci_adv_monitors_clear()
  (jsc#SLE-13430).
- Bluetooth: btusb: USB alternate setting 1 for WBS
  (jsc#SLE-13430).
- Bluetooth: use configured default params for active scans
  (jsc#SLE-13430).
- Bluetooth: Adding a configurable autoconnect timeout
  (jsc#SLE-13430).
- commit 681caef
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: btusb: Comment on unbalanced pm reference
  (jsc#SLE-13430).
- Bluetooth: btusb: Refactor of firmware download flow for Intel
  conrollers (jsc#SLE-13430).
- Bluetooth: Don't restart scanning if paused (jsc#SLE-13430).
- Bluetooth: btusb: BTUSB_WAKEUP_DISABLE prevents wake
  (jsc#SLE-13430).
- Bluetooth: btusb: Reset port on cmd timeout (jsc#SLE-13430).
- Bluetooth: use configured params for ext adv (jsc#SLE-13430).
- Bluetooth: Add hci_dev_lock to get/set device flags
  (jsc#SLE-13430).
- Bluetooth: mgmt: Use command complete on success for set system
  config (jsc#SLE-13430).
- Bluetooth: Terminate the link if pairing is cancelled
  (jsc#SLE-13430).
- Bluetooth: Update background scan and report device based on
  advertisement monitors (jsc#SLE-13430).
- commit afbe025
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: Notify adv monitor removed event (jsc#SLE-13430).
- Bluetooth: Notify adv monitor added event (jsc#SLE-13430).
- Bluetooth: Add handler of MGMT_OP_REMOVE_ADV_MONITOR
  (jsc#SLE-13430).
- Bluetooth: Add handler of MGMT_OP_ADD_ADV_PATTERNS_MONITOR
  (jsc#SLE-13430).
- Bluetooth: Add handler of MGMT_OP_READ_ADV_MONITOR_FEATURES
  (jsc#SLE-13430).
- Bluetooth: Add definitions for advertisement monitor features
  (jsc#SLE-13430).
- Bluetooth: Add get/set device flags mgmt op (jsc#SLE-13430).
- Bluetooth: Replace wakeable in hci_conn_params (jsc#SLE-13430).
- Bluetooth: Replace wakeable list with flag (jsc#SLE-13430).
- Bluetooth: Add bdaddr_list_with_flags for classic whitelist
  (jsc#SLE-13430).
- Bluetooth: mgmt: Add commands for runtime configuration
  (jsc#SLE-13430).
- commit 5ed8ff4
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: implement read/set default system parameters mgmt
  (jsc#SLE-13430).
- Bluetooth: centralize default value initialization
  (jsc#SLE-13430).
- Bluetooth: mgmt: read/set system parameter definitions
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Request Tx clock vote off only when Tx is
  pending (jsc#SLE-13430).
- Bluetooth: hci_qca: Increase SoC idle timeout to 200ms
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Disable SoC debug logging for WCN3991
  (jsc#SLE-13430).
- Bluetooth: Use only 8 bits for the HCI CMSG state flags
  (jsc#SLE-13430).
- Bluetooth: Add support for BT_PKT_STATUS CMSG data for SCO
  connections (jsc#SLE-13430).
- Bluetooth: btmrvl_sdio: Refactor irq wakeup (jsc#SLE-13430).
- Bluetooth: btmrvl_sdio: Implement prevent_wake (jsc#SLE-13430).
- Bluetooth: btmrvl_sdio: Set parent dev to hdev (jsc#SLE-13430).
- commit 4216325
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: btusb: Configure Intel debug feature based on
  available support (jsc#SLE-13430).
- Bluetooth: btusb: Add support to read Intel debug feature
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Bug fix during SSR timeout (jsc#SLE-13430).
- Bluetooth: Allow suspend even when preparation has failed
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Refactor error handling in qca_suspend()
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Skip serdev wait when no transfer is pending
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Only remove TX clock vote after TX is
  completed (jsc#SLE-13430).
- Bluetooth: hci_qca: Simplify determination of serial clock
  on/off state from votes (jsc#SLE-13430).
- Bluetooth: hci_qca: Fix an error pointer dereference
  (jsc#SLE-13430).
- Bluetooth: Removing noisy dbg message (jsc#SLE-13430).
- commit 2418c75
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: Check scan state before disabling during suspend
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Fix QCA6390 memdump failure (jsc#SLE-13430).
- Bluetooth: btmtkuart: Use serdev_device_write_buf() instead
  of serdev_device_write() (jsc#SLE-13430).
- Bluetooth: hci_qca: Improve controller ID info log level
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Fix qca6390 enable failure after warm reboot
  (jsc#SLE-13430).
- Bluetooth: Acquire sk_lock.slock without disabling interrupts
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Fix suspend/resume functionality failure
  (jsc#SLE-13430).
- Bluetooth: btbcm: Added 003.006.007, changed 001.003.015
  (jsc#SLE-13430).
- commit 0223c8a
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: hci_qca: Fix uninitialized access to hdev
  (jsc#SLE-13430).
- Bluetooth: Fix assuming EIR flags can result in SSP
  authentication (jsc#SLE-13430).
- Bluetooth: hci_qca: Enable WBS support for wcn3991
  (jsc#SLE-13430).
- Bluetooth: Fix for GAP/SEC/SEM/BI-10-C (jsc#SLE-13430).
- Bluetooth: L2CAP: add support for waiting disconnection resp
  (jsc#SLE-13430).
- Bluetooth: Handle Inquiry Cancel error after Inquiry Complete
  (jsc#SLE-13430).
- Bluetooth: serdev: Constify serdev_device_ops (jsc#SLE-13430).
- Bluetooth: btusb: Add support for Intel Bluetooth Device
  Typhoon Peak (8087:0032) (jsc#SLE-13430).
- Bluetooth: btusb: Implement hdev->prevent_wake (jsc#SLE-13430).
- Bluetooth: Add hook for driver to prevent wake from suspend
  (jsc#SLE-13430).
- commit 6fab827
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: Rename BT_SUSPEND_COMPLETE (jsc#SLE-13430).
- Bluetooth: Modify LE window and interval for suspend
  (jsc#SLE-13430).
- Bluetooth: Fix incorrect type for window and interval
  (jsc#SLE-13430).
- Bluetooth: Introduce debug feature when dynamic debug is
  disabled (jsc#SLE-13430).
- Bluetooth: Add support for experimental features configuration
  (jsc#SLE-13430).
- Bluetooth: Replace BT_DBG with bt_dev_dbg for security manager
  support (jsc#SLE-13430).
- Bluetooth: Introduce HCI_MGMT_HDEV_OPTIONAL option
  (jsc#SLE-13430).
- Bluetooth: Replace BT_DBG with bt_dev_dbg for management support
  (jsc#SLE-13430).
- Bluetooth: Add MGMT_EV_PHY_CONFIGURATION_CHANGED to supported
  list (jsc#SLE-13430).
- Bluetooth: L2CAP: Fix errors during
  L2CAP_CREDIT_BASED_CONNECTION_REQ (0x17) (jsc#SLE-13430).
- commit 887ddc3
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: Fix advertising handle is set to 0 (jsc#SLE-13430).
- Bluetooth: hci_h5: Add support for binding RTL8723BS with
  device tree (jsc#SLE-13430).
- Bluetooth: hci_qca: allow max-speed to be set for QCA9377
  devices (jsc#SLE-13430).
- Bluetooth: hci_qca: add compatible for QCA9377 (jsc#SLE-13430).
- Bluetooth: btusb: Adding support for LE scatternet to Jfp and
  ThP (jsc#SLE-13430).
- Bluetooth: allow scatternet connections if supported
  (jsc#SLE-13430).
- Bluetooth: Adding driver and quirk defs for multi-role LE
  (jsc#SLE-13430).
- Bluetooth: btbcm: Try multiple Patch filenames when loading
  the Patch firmware (jsc#SLE-13430).
- Bluetooth: btbcm: Bail sooner from btbcm_initialize() when
  not loading fw (jsc#SLE-13430).
- Bluetooth: btbcm: Make btbcm_setup_patchram use btbcm_finalize
  (jsc#SLE-13430).
- commit dd9a6df
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: btbcm: Make btbcm_initialize() print local-name on
  re-init too (jsc#SLE-13430).
- Bluetooth: btbcm: Fold Patch loading + applying into
  btbcm_initialize() (jsc#SLE-13430).
- Bluetooth: btbcm: Move setting of USE_BDADDR_PROPERTY quirk
  to hci_bcm.c (jsc#SLE-13430).
- Bluetooth: btbcm: Drop upper nibble version check from
  btbcm_initialize() (jsc#SLE-13430).
- Bluetooth: Enhanced Connection Complete event belongs to LL
  Privacy (jsc#SLE-13430).
- Bluetooth: Enable LE Enhanced Connection Complete event
  (jsc#SLE-13430).
- Bluetooth: Use extra variable to make code more readable
  (jsc#SLE-13430).
- Bluetooth: btrtl: Add support for RTL8761B (jsc#SLE-13430).
- Bluetooth: log advertisement packet length if it gets corrected
  (jsc#SLE-13430).
- commit cae6fbf
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: Add framework for Microsoft vendor extension
  (jsc#SLE-13430).
- Update config files.
- commit aba2aed
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: Always request for user confirmation for Just Works
  (LE SC) (jsc#SLE-13430).
- Bluetooth: btusb: check for NULL in btusb_find_altsetting()
  (jsc#SLE-13430).
- Bluetooth: Simplify / fix return values from tk_request
  (jsc#SLE-13430).
- Bluetooth: debugfs option to unset MITM flag (jsc#SLE-13430).
- Bluetooth: Increment management interface revision
  (jsc#SLE-13430).
- Bluetooth: Add support for reading security information
  (jsc#SLE-13430).
- Bluetooth: Add support for Read Local Simple Pairing Options
  (jsc#SLE-13430).
- Bluetooth: btusb: Enable MSFT extension for Intel ThunderPeak
  devices (jsc#SLE-13430).
- Bluetooth: btusb: Enable Intel events even if already in
  operational mode (jsc#SLE-13430).
- commit 7b24e19
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: Move debugfs configuration above the selftests
  (jsc#SLE-13430).
- Bluetooth: btusb: handle mSBC audio over USB Endpoints
  (jsc#SLE-13430).
- Bluetooth: add support to notify using SCO air mode
  (jsc#SLE-13430).
- Bluetooth: fixing minor typo in comment (jsc#SLE-13430).
- Bluetooth: Prioritize SCO traffic (jsc#SLE-13430).
- Bluetooth: hci_bcm: respect IRQ polarity from DT
  (jsc#SLE-13430).
- Bluetooth: Always request for user confirmation for Just Works
  (jsc#SLE-13430).
- Bluetooth: Add BT_MODE socket option (jsc#SLE-13430).
- Bluetooth: L2CAP: Fix handling LE modes by L2CAP_OPTIONS
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Add support for Qualcomm Bluetooth SoC
  QCA6390 (jsc#SLE-13430).
- commit 2373a52
* Mon Sep 21 2020 tiwai@suse.de
- mmc: sdio: Move SDIO IDs from btmtksdio driver to common
  include file (jsc#SLE-13430).
- mmc: sdio: Move SDIO IDs from btmrvl driver to common include
  file (jsc#SLE-13430).
- Bluetooth: L2CAP: Use DEFER_SETUP to group ECRED connections
  (jsc#SLE-13430).
- Bluetooth: don't assume key size is 16 when the command fails
  (jsc#SLE-13430).
- Bluetooth: L2CAP: Add get_peer_pid callback (jsc#SLE-13430).
- Bluetooth: Fix incorrect branch in connection complete
  (jsc#SLE-13430).
- Bluetooth: Restore running state if suspend fails
  (jsc#SLE-13430).
- Bluetooth: Do not cancel advertising when starting a scan
  (jsc#SLE-13430).
- Bluetooth: btusb: print Intel fw build version in power-on boot
  (jsc#SLE-13430).
- commit 376fd3f
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: L2CAP: remove set but not used variable 'credits'
  (jsc#SLE-13430).
- Bluetooth: L2CAP: Fix a condition in l2cap_sock_recvmsg()
  (jsc#SLE-13430).
- Bluetooth: L2CAP: handle l2cap config request during open state
  (jsc#SLE-13430).
- Bluetooth: clean up connection in hci_cs_disconnect
  (jsc#SLE-13430).
- Bluetooth: Pause discovery and advertising during suspend
  (jsc#SLE-13430).
- Bluetooth: Handle LE devices during suspend (jsc#SLE-13430).
- Bluetooth: Handle BR/EDR devices during suspend (jsc#SLE-13430).
- Bluetooth: Handle PM_SUSPEND_PREPARE and PM_POST_SUSPEND
  (jsc#SLE-13430).
- Bluetooth: mgmt: add mgmt_cmd_status in add_advertising
  (jsc#SLE-13430).
- Bluetooth: fix off by one in err_data_reporting cmd masks
  (jsc#SLE-13430).
- commit 0788eae
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: L2CAP: Add definitions for Enhanced Credit Based Mode
  (jsc#SLE-13430).
- commit c0ca13e
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: hci_h5: Switch from BT_ERR to bt_dev_err where
  possible (jsc#SLE-13430).
- Bluetooth: Use bt_dev_err for RPA generation failure message
  (jsc#SLE-13430).
- Bluetooth: bfusb: Switch from BT_ERR to bt_dev_err where
  possible (jsc#SLE-13430).
- Bluetooth: L2CAP: Add module option to enable ECRED mode
  (jsc#SLE-13430).
- Bluetooth: L2CAP: Add initial code for Enhanced Credit Based
  Mode (jsc#SLE-13430).
- Bluetooth: Increment management interface revision
  (jsc#SLE-13430).
- Bluetooth: Enable erroneous data reporting if WBS is supported
  (jsc#SLE-13430).
- Bluetooth: Make use of skb_pull to parse L2CAP signaling PDUs
  (jsc#SLE-13430).
- Bluetooth: Fix calculation of SCO handle for packet processing
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Replace devm_gpiod_get() with
  devm_gpiod_get_optional() (jsc#SLE-13430).
- commit 3d31ac6
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: guard against controllers sending zero'd events
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Make bt_en and susclk not mandatory for
  QCA Rome (jsc#SLE-13430).
- Bluetooth: btqca: Fix the NVM baudrate tag offcet for wcn3991
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Not send vendor pre-shutdown command for
  QCA Rome (jsc#SLE-13430).
- Bluetooth: Support querying for WBS support through MGMT
  (jsc#SLE-13430).
- Bluetooth: btusb: Add flag to define wideband speech capability
  (jsc#SLE-13430).
- Bluetooth: hci_h4: Remove a redundant assignment in 'h4_flush()'
  (jsc#SLE-13430).
- Bluetooth: hci_h4: Fix a typo in a comment (jsc#SLE-13430).
- Bluetooth: During le_conn_timeout disable EXT_ADV
  (jsc#SLE-13430).
- Bluetooth: Remove adv set for directed advertising
  (jsc#SLE-13430).
- commit ddefef8
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: Use list_for_each_entry_rcu() to traverse RCU list
  in RCU read-side CS (jsc#SLE-13430).
- Bluetooth: Fix Suspicious RCU usage warnings (jsc#SLE-13430).
- Bluetooth: Replace zero-length array with flexible-array member
  (jsc#SLE-13430).
- Bluetooth: fix passkey uninitialized when used (jsc#SLE-13430).
- Bluetooth: RFCOMM: Use MTU auto tune logic (jsc#SLE-13430).
- Bluetooth: Fix crash when using new BT_PHY option
  (jsc#SLE-13430).
- Bluetooth: hci_h5: Move variable into local scope
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Bug fixes while collecting controller
  memory dump (jsc#SLE-13430).
- Bluetooth: Disable Extended Adv if enabled (jsc#SLE-13430).
- Bluetooth: hci_h5: btrtl: Add support for RTL8822C
  (jsc#SLE-13430).
- commit 7986d2b
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: Fix a typo in Kconfig (jsc#SLE-13430).
- Bluetooth: Add BT_PHY socket option (jsc#SLE-13430).
- Bluetooth: secure bluetooth stack from bluedump attack
  (jsc#SLE-13430).
- Bluetooth: hci_uart: Replace zero-length array with
  flexible-array member (jsc#SLE-13430).
- Bluetooth: hci_intel: Replace zero-length array with
  flexible-array member (jsc#SLE-13430).
- Bluetooth: btintel: Replace zero-length array with
  flexible-array member (jsc#SLE-13430).
- Bluetooth: btusb: Add support for 13d3:3548 Realtek 8822CE
  device (jsc#SLE-13430).
- Bluetooth: hci_qca: Optimized code while enabling clocks for
  BT SOC (jsc#SLE-13430).
- Bluetooth: remove __get_channel/dir and __dir (jsc#SLE-13430).
- Bluetooth: prefetch channel before killing sock (jsc#SLE-13430).
- commit a205cad
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: hci_qca: Enable clocks required for BT SOC
  (jsc#SLE-13430).
- Bluetooth: optimize barrier usage for Rmw atomics
  (jsc#SLE-13430).
- Bluetooth: Fix refcount use-after-free issue (jsc#SLE-13430).
- Bluetooth: SMP: Fix SALT value in some comments (jsc#SLE-13430).
- Bluetooth: Move {min,max}_key_size debugfs into
  hci_debugfs_create_le (jsc#SLE-13430).
- Bluetooth: Add missing checks for HCI_ISODATA_PKT packet type
  (jsc#SLE-13430).
- Bluetooth: btrtl: Use kvmalloc for FW allocations
  (jsc#SLE-13430).
- Bluetooth: fix appearance typo in mgmt.c (jsc#SLE-13430).
- Bluetooth: adding missing const decoration to mgmt_status_table
  (jsc#SLE-13430).
- Bluetooth: Increment management interface revision
  (jsc#SLE-13430).
- commit a4dae47
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: hci_qca: Enable power off/on support during hci
  down/up for QCA Rome (jsc#SLE-13430).
- Bluetooth: hci_qca: Retry btsoc initialize when it fails
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Add QCA Rome power off support to the
  qca_power_shutdown() (jsc#SLE-13430).
- Bluetooth: hci_bcm: enable IRQ capability from devicetree
  (jsc#SLE-13430).
- Bluetooth: btsdio: Check for valid packet type (jsc#SLE-13430).
- Bluetooth: hci_h5: Add support for ISO packets (jsc#SLE-13430).
- Bluetooth: hci_h4: Add support for ISO packets (jsc#SLE-13430).
- Bluetooth: Make use of __check_timeout on hci_sched_le
  (jsc#SLE-13430).
- Bluetooth: monitor: Add support for ISO packets (jsc#SLE-13430).
- Bluetooth: hci_vhci: Add support for ISO packets
  (jsc#SLE-13430).
- Bluetooth: Add definitions for CIS connections (jsc#SLE-13430).
- commit 05a79bb
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: Implementation of MGMT_OP_SET_BLOCKED_KEYS
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Add qca_power_on() API to support both
  wcn399x and Rome power up (jsc#SLE-13430).
- Bluetooth: btbcm : Fix warning about missing blank lines after
  declarations (jsc#SLE-13430).
- Bluetooth: hci_qca: Remove set but not used variable 'opcode'
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Use vfree() instead of kfree()
  (jsc#SLE-13430).
- Bluetooth: remove redundant assignment to variable icid
  (jsc#SLE-13430).
- Bluetooth: btusb: Add support for 04ca:3021 QCA_ROME device
  (jsc#SLE-13430).
- Bluetooth: Auto tune if input MTU is set to 0 (jsc#SLE-13430).
- Bluetooth: Add support for LE PHY Update Complete event
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Collect controller memory dump during SSR
  (jsc#SLE-13430).
- commit ca55cd8
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: hci_bcm: Support pcm params in dts (jsc#SLE-13430).
- Refresh
  patches.suse/Bluetooth-hci_bcm-Drive-RTS-only-for-BCM43438.patch.
- commit 5576d1a
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: btbcm: Add missing static inline in header
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Replace of_device_get_match_data with
  device_get_match_data (jsc#SLE-13430).
- Bluetooth: Remove usage of BT_ERR_RATELIMITED macro
  (jsc#SLE-13430).
- Bluetooth: Adding a bt_dev_warn_ratelimited macro
  (jsc#SLE-13430).
- Bluetooth: btusb: Disable runtime suspend on Realtek devices
  (jsc#SLE-13430).
- Bluetooth: btbcm: Support pcm configuration (jsc#SLE-13430).
- Bluetooth: btusb: Edit the logical value for Realtek Bluetooth
  reset (jsc#SLE-13430).
- compat_ioctl: move hci_sock handlers into driver
  (jsc#SLE-13430).
- compat_ioctl: move rfcomm handlers into driver (jsc#SLE-13430).
- commit 18f7407
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: btbcm: Add entry for BCM4334B0 UART Bluetooth
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Add support for Qualcomm Bluetooth SoC
  WCN3991 (jsc#SLE-13430).
- Bluetooth: btqca: Rename ROME specific variables to generic
  variables (jsc#SLE-13430).
- Bluetooth: btmtksdio: add MODULE_DEVICE_TABLE() (jsc#SLE-13430).
- Bluetooth: hci_qca: add PM support (jsc#SLE-13430).
- Bluetooth: Fix not using LE_ADV_NONCONN_IND for instance 0
  (jsc#SLE-13430).
- Bluetooth: Fix using advertising instance duration as timeout
  (jsc#SLE-13430).
- Bluetooth: btrtl: remove unneeded semicolon (jsc#SLE-13430).
- Revert "Bluetooth: hci_qca: Add delay for wcn3990 stability"
  (jsc#SLE-13430).
- Bluetooth: btusb: Remove return statement in
  btintel_reset_to_bootloader (jsc#SLE-13430).
- commit 1d579c1
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: btwilink: drop superseded driver (jsc#SLE-13430).
- Update config files and supported.conf for the dropped btwlink.
- commit f81b429
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: hci_qca: Split qca_power_setup() (jsc#SLE-13430).
- Bluetooth: hci_qca: Use regulator bulk enable/disable
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Don't vote for specific voltage
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Update regulator_set_load() usage
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Add delay for wcn3990 stability
  (jsc#SLE-13430).
- Bluetooth: btusb: Trigger Intel FW download error recovery
  (jsc#SLE-13430).
- Bluetooth: btusb: Use IS_ENABLED instead of #ifdef
  (jsc#SLE-13430).
- Bluetooth: btusb: avoid unused function warning (jsc#SLE-13430).
- Bluetooth: btusb: print FW version after FW download
  (jsc#SLE-13430).
- commit 9c38962
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: btrtl: Fix an issue for the incorrect error return
  code (jsc#SLE-13430).
- Bluetooth: hci_nokia: Save a few cycles in 'nokia_enqueue()'
  (jsc#SLE-13430).
- Bluetooth: btusb: Use cmd_timeout to reset Realtek device
  (jsc#SLE-13430).
- Bluetooth: btrtl: Fix an issue that failing to download the
  FW which size is over 32K bytes (jsc#SLE-13430).
- Bluetooth: mgmt: Use struct_size() helper (jsc#SLE-13430).
- Bluetooth: btrtl: Remove trailing newline from calls to rtl_dev
  macros (jsc#SLE-13430).
- Bluetooth: btrtl: Remove redundant prefix from calls to rtl_dev
  macros (jsc#SLE-13430).
- Bluetooth: btrtl: Add firmware version print (jsc#SLE-13430).
- commit 1c6c2d2
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: btusb: Fix suspend issue for Realtek devices
  (jsc#SLE-13430).
- commit 6fd3d2a
* Mon Sep 21 2020 tiwai@suse.de
- Bluetooth: btrtl: Set HCI_QUIRK_SIMULTANEOUS_DISCOVERY
  (jsc#SLE-13430).
- Bluetooth: hci_qca: wait for Pre shutdown complete event before
  sending the Power off pulse (jsc#SLE-13430).
- Bluetooth: hci_qca: Set HCI_QUIRK_SIMULTANEOUS_DISCOVERY for
  QCA UART Radio (jsc#SLE-13430).
- Bluetooth: hci_qca: Make structure qca_proto constant
  (jsc#SLE-13430).
- Bluetooth: 6lowpan: Make variable header_ops constant
  (jsc#SLE-13430).
- Bluetooth: hci_qca: Remove redundant initializations to zero
  (jsc#SLE-13430).
- Bluetooth: Add support for utilizing Fast Advertising Interval
  (jsc#SLE-13430).
- commit 19659bb
* Mon Sep 21 2020 msuchanek@suse.de
- libnvdimm/security: fix a typo (bsc#1171742 bsc#1167527).
- commit 7e506d7
* Mon Sep 21 2020 bp@suse.de
- x86/cpufeatures: Enumerate ENQCMD and ENQCMDS instructions
  (jsc#13318).
- commit 6cd5ed0
* Mon Sep 21 2020 msuchanek@suse.de
- Refresh sorted patches.
- Refresh patches.suse/powerpc-book3s64-radix-Fix-boot-failure-with-large-a.patch.
- Refresh patches.suse/powerpc-papr_scm-Limit-the-readability-of-perf_stats.patch.
- commit 50a09d4
* Mon Sep 21 2020 bp@suse.de
- Documentation/x86: Add documentation for SVA (Shared Virtual
  Addressing) (jsc#13318).
- commit 68e6144
* Mon Sep 21 2020 bp@suse.de
- iommu/vt-d: Change flags type to unsigned int in binding mm
  (jsc#13318).
- commit 8ec01a2
* Mon Sep 21 2020 tiwai@suse.de
- net/wireless: Delete unnecessary checks before the macro call
  “dev_kfree_skb” (jsc#SLE-13430).
- commit 9325aef
* Mon Sep 21 2020 bp@suse.de
- drm, iommu: Change type of pasid to u32 (jsc#13318).
- commit 6c8a27e
* Mon Sep 21 2020 dwagner@suse.de
- blacklist: Ignore doc update and build warning
  The offending commit for the build warning is in mainlince since 2.6.
- commit ecc1f19
* Mon Sep 21 2020 msuchanek@suse.de
- ibmvnic: add missing parenthesis in do_reset() (bsc#1176700
  ltc#188140).
- commit a96bd66
* Mon Sep 21 2020 glin@suse.com
- rpm/kernel-cert-subpackage: add CA check on key enrollment (bsc#1173115)
  To avoid the unnecessary key enrollment, when enrolling the signing key
  of the kernel package, "--ca-check" is added to mokutil so that mokutil
  will ignore the request if the CA of the signing key already exists in
  MokList or UEFI db.
  Since the macro, %%_suse_kernel_module_subpackage, is only defined in a
  kernel module package (KMP), it's used to determine whether the %%post
  script is running in a kernel package, or a kernel module package.
- commit b15c9bf
* Sun Sep 20 2020 colyli@suse.de
- libnvdimm: KASAN: global-out-of-bounds Read in
  internal_create_group (jsc#SLE-13338).
- libnvdimm/security: fix a typo (jsc#SLE-13338).
- commit 1df15be
* Sat Sep 19 2020 lduncan@suse.com
- scsi: libcxgbi: Fix a use after free in cxgbi_conn_xmit_pdu()
  (bsc#1176695 jsc#sle-15116).
- scsi: cxgb4i: Fix dereference of pointer tdata before it is
  null checked (bsc#1176695 jsc#sle-15116).
- commit 9d84ded
* Sat Sep 19 2020 colyli@suse.de
- md: improve io stats accounting (jsc#SLE-13702).
- series.conf: disable an in-house patch for similar fix
  patches.suse/mdraid-fix-read-write-bytes-accounting.patch
- commit 2a98d7d
* Sat Sep 19 2020 colyli@suse.de
- ACPI: NFIT: Add runtime firmware activate support
  (jsc#SLE-13338).
- PM, libnvdimm: Add runtime firmware activation support
  (jsc#SLE-13338).
- libnvdimm: Convert to DEVICE_ATTR_ADMIN_RO() (jsc#SLE-13338).
- driver-core: Introduce DEVICE_ATTR_ADMIN_{RO,RW}
  (jsc#SLE-13338).
- tools/testing/nvdimm: Emulate firmware activation commands
  (jsc#SLE-13338).
- tools/testing/nvdimm: Prepare nfit_ctl_test() for ND_CMD_CALL
  emulation (jsc#SLE-13338).
- tools/testing/nvdimm: Add command debug messages
  (jsc#SLE-13338).
- tools/testing/nvdimm: Cleanup dimm index passing
  (jsc#SLE-13338).
- ACPI: NFIT: Define runtime firmware activation commands
  (jsc#SLE-13338).
- ACPI: NFIT: Move bus_dsm_mask out of generic
  nvdimm_bus_descriptor (jsc#SLE-13338).
- libnvdimm: Validate command family indices (jsc#SLE-13338).
- commit 2bc0228
* Sat Sep 19 2020 colyli@suse.de
- PM: hibernate: Split off snapshot dev option (jsc#SLE-13338).
- Update configs for the above change,
  config/arm64/default
  config/x86_64/default
- commit 17f3cdc
* Sat Sep 19 2020 colyli@suse.de
- PM: hibernate: Incorporate concurrency handling (jsc#SLE-13338).
- Refresh for the above change,
  patches.suse/0007-PM-hibernate-encrypt-hidden-area.patch.
  patches.suse/0008-PM-hibernate-Generate-and-verify-signature-for-snaps.patch.
  patches.suse/0010-PM-hibernate-a-option-to-request-that-snapshot-image.patch.
- commit 394de48
* Sat Sep 19 2020 colyli@suse.de
- PM: hibernate: Add more logging on hibernation failure
  (jsc#SLE-13338).
- Refresh for the above change,
  patches.suse/0007-PM-hibernate-encrypt-hidden-area.patch.
  patches.suse/0008-PM-hibernate-Generate-and-verify-signature-for-snaps.patch.
- commit 3ce9bea
* Sat Sep 19 2020 colyli@suse.de
- libnvdimm: Move nvdimm_bus_attribute_group to device_type
  (jsc#SLE-13338).
- commit 80aefa3
* Sat Sep 19 2020 colyli@suse.de
- libnvdimm: Move nvdimm_attribute_group to device_type
  (jsc#SLE-13338).
- Refresh for the above change,
  patches.suse/0018-libnvdimm-region-Introduce-NDD_LABELING.patch.
  patches.suse/powerpc-papr_scm-Fetch-nvdimm-health-information-fro.patch.
- commit 804c6ef
* Sat Sep 19 2020 colyli@suse.de
- libnvdimm: Move nd_mapping_attribute_group to device_type
  (jsc#SLE-13338).
- libnvdimm: Move nd_region_attribute_group to device_type
  (jsc#SLE-13338).
- libnvdimm: Move nd_numa_attribute_group to device_type
  (jsc#SLE-13338).
- commit 64c5550
* Sat Sep 19 2020 colyli@suse.de
- libnvdimm: Move nd_device_attribute_group to device_type
  (jsc#SLE-13338).
- Refresh for the above change,
  patches.suse/0019-libnvdimm-region-Introduce-an-align-attribute.patch.
  patches.suse/powerpc-papr_scm-Fetch-nvdimm-health-information-fro.patch.
- commit 786a12d
* Sat Sep 19 2020 colyli@suse.de
- libnvdimm: Move region attribute group definition
  (jsc#SLE-13338).
- libnvdimm: Move attribute groups to device type (jsc#SLE-13338).
- libnvdimm/security: Consolidate 'security' operations
  (jsc#SLE-13338).
- libnvdimm/security: Tighten scope of nvdimm->busy vs security
  operations (jsc#SLE-13338).
- commit bef4418
* Sat Sep 19 2020 colyli@suse.de
- libnvdimm/security: Introduce a 'frozen' attribute
  (jsc#SLE-13338).
- Refresh for the above change,
  patches.suse/libnvdimm-prevent-nvdimm-from-requesting-key-when-se.patch
- commit ae64194
* Sat Sep 19 2020 tonyj@suse.de
- perf/x86/intel/uncore: Fix oops when counting IMC uncore events
  on some TGL (jsc#SLE-12682 (git-fixes)).
- commit 0462f0e
* Sat Sep 19 2020 lduncan@suse.com
- scsi: cxgb4i: Add support for iSCSI segmentation offload
  (bsc#1176695 jsc#sle-15116).
- scsi: cxgb4i: Remove superfluous null check (bsc#1176695
  jsc#sle-15116).
- scsi: cxgb4i: remove set but not used variable 'ppmax'
  (bsc#1176695 jsc#sle-15116).
- commit 3f9e76f
* Fri Sep 18 2020 mbrugger@suse.com
- arm64: Update config files. (bsc#1174764)
  Build the following driver as modules:
  CONFIG_UIO_PDRV_GENIRQ, CONFIG_UIO_NETX and CONFIG_UIO_MF624
- commit 6175cc7
* Fri Sep 18 2020 colyli@suse.de
- dm crypt: add flags to optionally bypass kcryptd workqueues
  (jsc#SLE-12226).
- commit 69cf363
* Fri Sep 18 2020 tzimmermann@suse.de
- Remove all DRM patches before upgrading the DRM subsystem
  This commit removes all patches that touch drivers/gpu/drm, include/drm
  and/or include/uapi/drm. Done in preparation of upgrading the DRM subsystem
  to a recent version.
  The exception is a handful of patches for IOMMU, include/linux/device.h and
  an AMD SPI driver. It's expected that these patches will require manual
  resolution of conflicts during the DRM upgrade.
- commit 815b4a1
* Fri Sep 18 2020 glin@suse.com
- rpm/macros.kernel-source: pass -c proerly in kernel module package (bsc#1176698)
  The "-c" option wasn't passed down to %%_kernel_module_package so the
  ueficert subpackage wasn't generated even if the certificate is
  specified in the spec file.
- commit 34808fb
* Thu Sep 17 2020 lduncan@suse.com
- scsi: csiostor: Add missing description for
  csio_rnode_fwevt_handler()'s 'fwevt' param (bsc#1176647
  jsc#sle-15113).
- scsi: csiostor: Remove 2 unused variables
  {mc,edc}_bist_status_rdata_reg (bsc#1176647 jsc#sle-15113).
- scsi: csiostor: Mark known unused variable as __always_unused
  (bsc#1176647 jsc#sle-15113).
- scsi: csiostor: Demote kerneldoc that fails to meet the criteria
  (bsc#1176647 jsc#sle-15113).
- scsi: csiostor: Fix misnamed function parameter (bsc#1176647
  jsc#sle-15113).
- scsi: csiostor: Remove set but not used variable 'rln'
  (bsc#1176647 jsc#sle-15113).
- scsi: csiostor: Return value not required for csio_dfs_destroy
  (bsc#1176647 jsc#sle-15113).
- scsi: csiostor: Fix NULL check before debugfs_remove_recursive
  (bsc#1176647 jsc#sle-15113).
- scsi: csiostor: clean up indentation issue (bsc#1176647
  jsc#sle-15113).
- scsi: csiostor: Fix spelling typos (bsc#1176647 jsc#sle-15113).
- commit b301104
* Thu Sep 17 2020 tonyj@suse.de
- perf/x86/intel/uncore: Add Comet Lake support (jsc#SLE-13316).
- commit 9a3bf9c
* Thu Sep 17 2020 tonyj@suse.de
- perf/x86/intel: Add more available bits for OFFCORE_RESPONSE
  of Intel Tremont (jsc#SLE-12921).
- commit 84ddb4a
* Thu Sep 17 2020 tonyj@suse.de
- perf/x86: Add Intel Tiger Lake uncore support (jsc#SLE-12682).
- Refresh
  patches.suse/perf-x86-intel-uncore-add-ice-lake-server-uncore-support.patch.
- Refresh
  patches.suse/x86-perf-events-convert-to-new-cpu-match-macros.patch.
- commit fae5e31
* Thu Sep 17 2020 tonyj@suse.de
- perf/x86/intel: Output LBR TOS information correctly
  (jsc#SLE-12718).
- commit 8c3cdb1
* Thu Sep 17 2020 tonyj@suse.de
- perf/core: Add new branch sample type for HW index of raw
  branch records (jsc#SLE-12718).
- commit 85c48fb
* Thu Sep 17 2020 tonyj@suse.de
- perf/x86/intel: Add Elkhart Lake support (jsc#SLE-12732).
- commit dd0ffdb
* Thu Sep 17 2020 tonyj@suse.de
- perf/x86/cstate: Add Tiger Lake CPU support (jsc#SLE-12681).
- Refresh
  patches.suse/x86-perf-events-convert-to-new-cpu-match-macros.patch.
- commit d3240f6
* Thu Sep 17 2020 tonyj@suse.de
- perf/x86/msr: Add Tiger Lake CPU support (jsc#SLE-12681).
- commit a6991ff
* Thu Sep 17 2020 tonyj@suse.de
- perf/x86/intel: Add Tiger Lake CPU support (jsc#SLE-12681).
- commit 9bf369b
* Thu Sep 17 2020 tonyj@suse.de
- perf/x86/msr: Add new CPU model numbers for Ice Lake (jsc#SLE-12679).
- commit 96e15be
* Thu Sep 17 2020 tonyj@suse.de
- Fix whitespace error (INTEL_FAM6_ICELAKE) in original backport.
  Remove original backport comment (no longer applies due to 424d9a3c91e2)
- Refresh
  patches.suse/perf-x86-cstate-update-c-state-counters-for-ice-lake.patch.
- Refresh
  patches.suse/x86-perf-events-convert-to-new-cpu-match-macros.patch.
- commit 9f5efc2
* Thu Sep 17 2020 tbogendoerfer@suse.de
- iavf: use generic power management (jsc#SLE-12877).
- iavf: Fix updating statistics (jsc#SLE-12877).
- iavf: fix error return code in iavf_init_get_resources()
  (jsc#SLE-12877).
- iavf: increase reset complete wait time (jsc#SLE-12877).
- iavf: Fix reporting 2.5 Gb and 5Gb speeds (jsc#SLE-12877).
- iavf: use appropriate enum for comparison (jsc#SLE-12877).
- iavf: fix speed reporting over virtchnl (jsc#SLE-12877).
- net: iavf: reject unsupported coalescing params (jsc#SLE-12877).
- iavf: Enable support for up to 16 queues (jsc#SLE-12877).
- iavf: use tc_cls_can_offload_and_chain0() instead of chain check
  (jsc#SLE-12877).
- commit bb1bf8a
* Thu Sep 17 2020 tbogendoerfer@suse.de
- ethtool: Don't omit the netlink reply if no features were
  changed (bsc#1176447).
- ethtool: Account for hw_features in netlink interface
  (bsc#1176447).
- ethtool: Fix preserving of wanted feature bits in netlink
  interface (bsc#1176447).
- ice: add documentation for device-caps region (jsc#SLE-12878).
- ethtool: fix genlmsg_put() failure handling in
  ethnl_default_dumpit() (bsc#1176447).
- net: ethtool: add missing NETIF_F_GSO_FRAGLIST feature string
  (bsc#1176447).
- mlxsw: spectrum_ptp: Fix build warnings (bsc#1176447).
- netlink: check for null extack in cookie helpers (bsc#1176447).
- commit 66fa0a6
* Thu Sep 17 2020 msuchanek@suse.de
- powerpc/watchpoint/ptrace: Introduce
  PPC_DEBUG_FEATURE_DATA_BP_ARCH_31 (jsc#SLE-12936).
- powerpc/watchpoint: Add hw_len wherever missing (jsc#SLE-12936).
- powerpc/watchpoint: Fix exception handling for
  CONFIG_HAVE_HW_BREAKPOINT=N (jsc#SLE-12936).
- powerpc/watchpoint: Move DAWR detection logic outside of
  hw_breakpoint.c (jsc#SLE-12936).
- powerpc/watchpoint/ptrace: Fix SETHWDEBUG when
  CONFIG_HAVE_HW_BREAKPOINT=N (jsc#SLE-12936).
- powerpc/watchpoint: Fix handling of vector instructions
  (jsc#SLE-12936).
- powerpc/watchpoint: Fix quadword instruction handling on p10
  predecessors (jsc#SLE-12936).
- powerpc/hw_breakpoint.h: delete duplicated word (jsc#SLE-12936).
- commit f79374c
* Thu Sep 17 2020 msuchanek@suse.de
- powerpc/pci: unmap legacy INTx interrupts when a PHB is removed
  (bsc#1172145 ltc#184630).
- commit 91fd12b
* Thu Sep 17 2020 tbogendoerfer@suse.de
- ice: Initialize Flow Director resources (jsc#SLE-12878).
- Refresh
  patches.suse/ice-Clear-and-free-XLT-entries-on-reset.patch.
- commit 1aa9b42
* Thu Sep 17 2020 tbogendoerfer@suse.de
- ethtool: add LINKINFO_NTF notification (bsc#1176447).
- Refresh
  patches.suse/ethtool-Factored-out-similar-ethtool-link-settings-f.patch.
- commit cc16e1d
* Thu Sep 17 2020 tbogendoerfer@suse.de
- i40e: Fix crash during removing i40e driver (jsc#SLE-13701).
- i40e: Set RX_ONLY mode for unicast promiscuous on VLAN
  (jsc#SLE-13701).
- i40e: introduce new dump desc XDP command (jsc#SLE-13701).
- i40e: add XDP ring statistics to dump VSI debug output
  (jsc#SLE-13701).
- i40e: add XDP ring statistics to VSI stats (jsc#SLE-13701).
- i40e: move check of full Tx ring to outside of send loop
  (jsc#SLE-13701).
- i40e: eliminate division in napi_poll data path (jsc#SLE-13701).
- i40e: optimize AF_XDP Tx completion path (jsc#SLE-13701).
- i40e: Add support for a new feature Total Port Shutdown
  (jsc#SLE-13701).
- ice: replace single-element array used for C struct hack
  (jsc#SLE-12878).
- ice: avoid unnecessary single-member variable-length structs
  (jsc#SLE-12878).
- ice: implement snapshot for device capabilities (jsc#SLE-12878).
- i40e: Remove scheduling while atomic possibility
  (jsc#SLE-13701).
- i40e: Add support for 5Gbps cards (jsc#SLE-13701).
- i40e: Add a check to see if MFS is set (jsc#SLE-13701).
- i40e: detect and log info about pre-recovery mode
  (jsc#SLE-13701).
- i40e: make PF wait reset loop reliable (jsc#SLE-13701).
- i40e: remove unused defines (jsc#SLE-13701).
- i40e: Move client header location (jsc#SLE-13701).
- i40e: fix crash when Rx descriptor count is changed
  (jsc#SLE-13701).
- ice: protect ring accesses with WRITE_ONCE (jsc#SLE-12878).
- i40e: protect ring accesses with READ- and WRITE_ONCE
  (jsc#SLE-13701).
- ixgbe: protect ring accesses with READ- and WRITE_ONCE
  (jsc#SLE-13706).
- ice: Ignore EMODE when setting PHY config (jsc#SLE-12878).
- ice: fix aRFS after flow director delete (jsc#SLE-12878).
- ice: Use coalesce values from q_vector 0 when increasing
  q_vectors (jsc#SLE-12878).
- ice: fix function signature style format (jsc#SLE-12878).
- ice: Allow VF to request reset as soon as it's initialized
  (jsc#SLE-12878).
- ice: Always clear QRXFLXP_CNTXT before writing new value
  (jsc#SLE-12878).
- ice: Reset VF for all port VLAN changes from host
  (jsc#SLE-12878).
- ice: Update ICE_PHY_TYPE_HIGH_MAX_INDEX value (jsc#SLE-12878).
- ice: Increase timeout after PFR (jsc#SLE-12878).
- ice: Fix transmit for all software offloaded VLANs
  (jsc#SLE-12878).
- ice: support adding 16 unicast/multicast filter on untrusted VF
  (jsc#SLE-12878).
- ice: allow host to clear administratively set VF MAC
  (jsc#SLE-12878).
- ice: Refactor VF VSI release and setup functions
  (jsc#SLE-12878).
- ice: Refactor VF reset (jsc#SLE-12878).
- ice: remove VM/VF disable command on CORER/GLOBR reset
  (jsc#SLE-12878).
- ice: Add functions to rebuild host VLAN/MAC config for a VF
  (jsc#SLE-12878).
- ice: Add function to set trust mode bit on reset
  (jsc#SLE-12878).
- ice: Renaming and simplification in VF init path
  (jsc#SLE-12878).
- ice: Separate VF VSI initialization/creation from reset flow
  (jsc#SLE-12878).
- ice: Add helper function for clearing VPGEN_VFRTRIG
  (jsc#SLE-12878).
- ice: Simplify ice_sriov_configure (jsc#SLE-12878).
- ice: Refactor ice_ena_vf_mappings to split MSIX and queue
  mappings (jsc#SLE-12878).
- ice: Declare functions static (jsc#SLE-12878).
- ice: fix kernel BUG if register_netdev fails (jsc#SLE-12878).
- ice: fix potential double free in probe unrolling
  (jsc#SLE-12878).
- ice: cleanup VSI context initialization (jsc#SLE-12878).
- ice: Poll for reset completion when DDP load fails
  (jsc#SLE-12878).
- i40e: Make i40e_shutdown_adminq() return void (jsc#SLE-13701).
- ixgbe: Remove unused inline function ixgbe_irq_disable_queues
  (jsc#SLE-13706).
- ixgbe: Use true, false for bool variable in
  __ixgbe_enable_sriov() (jsc#SLE-13706).
- ixgbe: Remove conversion to bool in
  ixgbe_device_supports_autoneg_fc() (jsc#SLE-13706).
- ixgbe: fix signed-integer-overflow warning (jsc#SLE-13706).
- i40e: trivial fixup of comments in i40e_xsk.c (jsc#SLE-13701).
- i40e: Use scnprintf() for avoiding potential buffer overflow
  (jsc#SLE-13701).
- ice: Check UMEM FQ size when allocating bufs (jsc#SLE-12878).
- ice: Refactor Rx checksum checks (jsc#SLE-12878).
- ice: avoid undefined behavior (jsc#SLE-12878).
- ice: Change number of XDP Tx queues to match number of Rx queues
  (jsc#SLE-12878).
- ice: Add XDP Tx to VSI ring stats (jsc#SLE-12878).
- ice: Change number of XDP TxQ to 0 when destroying rings
  (jsc#SLE-12878).
- ice: Handle critical FW error during admin queue initialization
  (jsc#SLE-12878).
- ice: Don't allow VLAN stripping change when pvid set
  (jsc#SLE-12878).
- ice: Add more Rx errors to netdev's rx_error counter
  (jsc#SLE-12878).
- ice: Fix for memory leaks and modify ICE_FREE_CQ_BUFS
  (jsc#SLE-12878).
- ice: Fix memory leak (jsc#SLE-12878).
- ice: fix MAC write command (jsc#SLE-12878).
- ice: set VF default LAN address (jsc#SLE-12878).
- ice: remove unused macro (jsc#SLE-12878).
- ice: fix signed vs unsigned comparisons (jsc#SLE-12878).
- ice: cleanup unsigned loops (jsc#SLE-12878).
- ice: fix usage of incorrect variable (jsc#SLE-12878).
- ice: Fix bad register reads (jsc#SLE-12878).
- ice: check for compatibility between DDP package and firmware
  (jsc#SLE-12878).
- ice: Check if unicast MAC exists before setting VF MAC
  (jsc#SLE-12878).
- ice: Fix Tx timeout when link is toggled on a VF's interface
  (jsc#SLE-12878).
- ice: print Rx MDD auto reset message before VF reset
  (jsc#SLE-12878).
- ice: Call ice_aq_set_mac_cfg (jsc#SLE-12878).
- ice: Implement aRFS (jsc#SLE-12878).
- ice: Restore filters following reset (jsc#SLE-12878).
- ice: Enable flex-bytes support (jsc#SLE-12878).
- ice: Support IPv6 Flow Director filters (jsc#SLE-12878).
- ice: Support IPv4 Flow Director filters (jsc#SLE-12878).
- ice: Support displaying ntuple rules (jsc#SLE-12878).
- ixgbe, xsk: Migrate to new MEM_TYPE_XSK_BUFF_POOL
  (jsc#SLE-13706).
- ice, xsk: Migrate to new MEM_TYPE_XSK_BUFF_POOL (jsc#SLE-12878).
- i40e, xsk: Migrate to new MEM_TYPE_XSK_BUFF_POOL
  (jsc#SLE-13701).
- i40e: Separate kernel allocated rx_bi rings from AF_XDP rings
  (jsc#SLE-13701).
- i40e: Refactor rx_bi accesses (jsc#SLE-13701).
- xsk: Introduce AF_XDP buffer allocation API (jsc#SLE-13706).
- xsk: Move defines only used by AF_XDP internals to xsk.h
  (jsc#SLE-13706).
- xsk: Move driver interface to xdp_sock_drv.h (bsc#1176447).
- xsk: Move xskmap.c to net/xdp/ (bsc#1176447).
- ice: Rename build_ctob to ice_build_ctob (jsc#SLE-12878).
- ice: remove unnecessary backslash (jsc#SLE-12878).
- ice: remove unnecessary check (jsc#SLE-12878).
- ice: remove unnecessary expression that is always true
  (jsc#SLE-12878).
- ice: Fix check for removing/adding mac filters (jsc#SLE-12878).
- ice: refactor filter functions (jsc#SLE-12878).
- ice: Fix resource leak on early exit from function
  (jsc#SLE-12878).
- ice: cleanup vf_id signedness (jsc#SLE-12878).
- ice: Fix casting issues (jsc#SLE-12878).
- ice: Provide more meaningful error message (jsc#SLE-12878).
- ice: Fix probe/open race condition (jsc#SLE-12878).
- ice: only drop link once when setting pauseparams
  (jsc#SLE-12878).
- ice: Fix check for contiguous TCs (jsc#SLE-12878).
- ice: Don't reset and rebuild for Tx timeout on PFC enabled queue
  (jsc#SLE-12878).
- ice: Add VF promiscuous support (jsc#SLE-12878).
- ice: Add support for tunnel offloads (jsc#SLE-12878).
- ice: report netlist version in .info_get (jsc#SLE-12878).
- xsk: Fix typo in xsk_umem_consume_tx and xsk_generic_xmit
  comments (jsc#SLE-13706).
- net: ethtool: self_test: Mark interface in testing operative
  status (bsc#1176447).
- net: Add IF_OPER_TESTING (bsc#1176447).
- ethtool: count header size in reply size estimate (bsc#1176447).
- ethtool: provide timestamping information with TSINFO_GET
  request (bsc#1176447).
- ethtool: add timestamping related string sets (bsc#1176447).
- ethtool: add EEE_NTF notification (bsc#1176447).
- ethtool: set EEE settings with EEE_SET request (bsc#1176447).
- ethtool: provide EEE settings with EEE_GET request
  (bsc#1176447).
- ethtool: add PAUSE_NTF notification (bsc#1176447).
- ethtool: set pause parameters with PAUSE_SET request
  (bsc#1176447).
- ethtool: provide pause parameters with PAUSE_GET request
  (bsc#1176447).
- ethtool: add COALESCE_NTF notification (bsc#1176447).
- ethtool: set coalescing parameters with COALESCE_SET request
  (bsc#1176447).
- ethtool: provide coalescing parameters with COALESCE_GET request
  (bsc#1176447).
- ethtool: fix reference leak in ethnl_set_privflags()
  (bsc#1176447).
- net: introduce the MACSEC netdev feature (bsc#1176447).
- ethtool: fix incorrect tx-checksumming settings reporting
  (bsc#1176447).
- ethtool: fix spelling mistake "exceeeds" -> "exceeds"
  (bsc#1176447).
- ethtool: add CHANNELS_NTF notification (bsc#1176447).
- ethtool: set device channel counts with CHANNELS_SET request
  (bsc#1176447).
- ethtool: provide channel counts with CHANNELS_GET request
  (bsc#1176447).
- ethtool: add RINGS_NTF notification (bsc#1176447).
- ethtool: set device ring sizes with RINGS_SET request
  (bsc#1176447).
- ethtool: provide ring sizes with RINGS_GET request
  (bsc#1176447).
- ethtool: add PRIVFLAGS_NTF notification (bsc#1176447).
- ethtool: set device private flags with PRIVFLAGS_SET request
  (bsc#1176447).
- ethtool: provide private flags with PRIVFLAGS_GET request
  (bsc#1176447).
- ethtool: add FEATURES_NTF notification (bsc#1176447).
- ethtool: set netdev features with FEATURES_SET request
  (bsc#1176447).
- ethtool: add ethnl_parse_bitset() helper (bsc#1176447).
- ethtool: provide netdev features with FEATURES_GET request
  (bsc#1176447).
- ethtool: update mapping of features to legacy ioctl requests
  (bsc#1176447).
- ethtool: rename ethnl_parse_header() to
  ethnl_parse_header_dev_get() (bsc#1176447).
- ethtool: Add support for low latency RS FEC (bsc#1176447).
- ethtool: fix reference leak in some *_SET handlers
  (bsc#1176447).
- ethtool: reject unrecognized request flags (bsc#1176447).
- netlink: add nl_set_extack_cookie_u32() (bsc#1176447).
- ethtool: limit bitset size (bsc#1176447).
- ethtool: fix application of verbose no_mask bitset
  (bsc#1176447).
- ethtool: add WOL_NTF notification (bsc#1176447).
- ethtool: set wake-on-lan settings with WOL_SET request
  (bsc#1176447).
- ethtool: provide WoL settings with WOL_GET request
  (bsc#1176447).
- ethtool: add DEBUG_NTF notification (bsc#1176447).
- ethtool: set message mask with DEBUG_SET request (bsc#1176447).
- ethtool: provide message mask with DEBUG_GET request
  (bsc#1176447).
- ethtool: fix kernel-doc descriptions (bsc#1176447).
- net: Add fraglist GRO/GSO feature flags (bsc#1176447).
- ethtool: potential NULL dereference in strset_prepare_data()
  (bsc#1176447).
- ethtool: fix ->reply_size() error handling (bsc#1176447).
- ethtool: fix a memory leak in ethnl_default_start()
  (bsc#1176447).
- ethtool: remove set but not used variable 'lsettings'
  (bsc#1176447).
- ethtool: provide link state with LINKSTATE_GET request
  (bsc#1176447).
- ethtool: add LINKMODES_NTF notification (bsc#1176447).
- ethtool: set link modes related data with LINKMODES_SET request
  (bsc#1176447).
- ethtool: provide link mode information with LINKMODES_GET
  request (bsc#1176447).
- ethtool: add default notification handler (bsc#1176447).
- ethtool: set link settings with LINKINFO_SET request
  (bsc#1176447).
- ethtool: provide link settings with LINKINFO_GET request
  (bsc#1176447).
- ethtool: provide string sets with STRSET_GET request
  (bsc#1176447).
- ethtool: default handlers for GET requests (bsc#1176447).
- ethtool: support for netlink notifications (bsc#1176447).
- ethtool: netlink bitset handling (bsc#1176447).
- ethtool: helper functions for netlink interface (bsc#1176447).
- net: Introduce peer to peer one step PTP time stamping
  (bsc#1176447).
- net: ethtool: Use the PHY time stamping interface (bsc#1176447).
- net: phy: Introduce helper functions for time stamping support
  (bsc#1176447).
- netlink: rename nl80211_validate_nested() to
  nla_validate_nested() (bsc#1176447).
- commit cb14dde
* Thu Sep 17 2020 tzimmermann@suse.de
- blacklist.conf: Append 'gpu: ipu-v3: image-convert: Wait for all EOFs before completing a tile'
- commit cd2ad4e
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/sun4i: backend: Disable alpha on the lowest plane on the A20 (bsc#1152472)
- commit a28c02e
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/sun4i: backend: Support alpha property on lowest plane (bsc#1152472)
- commit 081a7ef
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/sun4i: Fix dsi dcs long write function (bsc#1152472)
- commit 510ebc1
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/sun4i: add missing put_device() call in (bsc#1152472)
- commit 69345eb
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/virtio: fix missing dma_fence_put() in (bsc#1152489)
  * context changes
- commit 2d93b7f
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/ast: Initialize DRAM type before posting GPU (bsc#1152472)
  * context changes
- commit 933f31f
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/mgag200: Remove declaration of mgag200_mmap() from header file (bsc#1152472)
  * context changes
- commit 435259b
* Wed Sep 16 2020 fdmanana@suse.com
- Btrfs: implement full reflink support for inline extents
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-fix-lost-i_size-update-after-cloning-inline-ex.patch.
- commit 1499e64
* Wed Sep 16 2020 fdmanana@suse.com
- Btrfs: simplify inline extent handling when doing reflinks
  (bsc#1176019).
- commit 378e9bc
* Wed Sep 16 2020 fdmanana@suse.com
- Btrfs: move all reflink implementation code into its own file
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-fix-lost-i_size-update-after-cloning-inline-ex.patch.
- commit 24935c8
* Wed Sep 16 2020 msuchanek@suse.de
- powerpc/watchpoint: Disable all available watchpoints when
  !dawr_force_enable (jsc#SLE-12936).
- powerpc/watchpoint: Get watchpoint count dynamically while
  disabling them (jsc#SLE-12936).
- commit f5afb99
* Wed Sep 16 2020 msuchanek@suse.de
- powerpc/perf: Fix soft lockups due to missed interrupt
  accounting (jsc#SLE-13513).
- commit e1b68e3
* Tue Sep 15 2020 tbogendoerfer@suse.de
- xdp: Handle frame_sz in xdp_convert_zc_to_xdp_frame()
  (jsc#SLE-13706).
- ice: fix PCI device serial number to be lowercase values
  (jsc#SLE-12878).
- netdevsim: dev: Fix memory leak in nsim_dev_take_snapshot_write
  (jsc#SLE-15171).
- devlink: fix typos in qed documentation (jsc#SLE-12878).
- devlink: remove trigger command from devlink-region.rst
  (jsc#SLE-12878).
- devlink: document region snapshot triggering from userspace
  (jsc#SLE-12878).
- commit a0186de
* Tue Sep 15 2020 ematsumiya@suse.de
- nvme-pci: override the value of the controller's numa node
  (bsc#1176507).
- commit 1ad78c9
* Tue Sep 15 2020 nsaenzjulienne@suse.de
- usb: typec: intel_pmc_mux: Do not configure SBU and HSL
  Orientation in Alternate modes (jsc#SLE-13918).
- usb: typec: intel_pmc_mux: Do not configure Altmode HPD High
  (jsc#SLE-13918).
- usb: typec: intel_pmc_mux: Un-register the USB role switch
  (jsc#SLE-13918).
- watchdog: iTCO: fix link error (jsc#SLE-13918).
- blacklist.conf: b30c1a464c29 ("watchdog: iTCO: fix link error")
- commit fe95fa7
* Tue Sep 15 2020 msuchanek@suse.de
- Remove patch causing regression (bsc#1094244 ltc#168122).
- Delete patches.suse/powerpc-64s-machine-check-interrupt-update-NMI-accou.patch.
- Refresh patches.suse/powerpc-64s-machine-check-do-not-trace-real-mode-han.patch.
- commit f30b04b
* Tue Sep 15 2020 tbogendoerfer@suse.de
- mlx4: disable device on shutdown (git-fixes).
- commit 878fd39
* Tue Sep 15 2020 tbogendoerfer@suse.de
- devlink: promote "fw.bundle_id" to a generic info version
  (jsc#SLE-12878).
- Refresh patches.suse/devlink-add-macro-for-fw.roce.patch.
- commit 96ec267
* Tue Sep 15 2020 tbogendoerfer@suse.de
- ethtool: introduce ethtool netlink interface (bsc#1176447).
- Update config files.
- commit 9ce3138
* Tue Sep 15 2020 tbogendoerfer@suse.de
- xsk: Change names of validation functions (jsc#SLE-13706).
- Refresh
  patches.suse/xsk-Remove-unnecessary-READ_ONCE-of-data.patch.
- commit 03cafae
* Tue Sep 15 2020 tbogendoerfer@suse.de
- xsk: Simplify the consumer ring access functions
  (jsc#SLE-13706).
- Refresh
  patches.suse/xsk-Remove-unnecessary-READ_ONCE-of-data.patch.
- commit d84436a
* Tue Sep 15 2020 tbogendoerfer@suse.de
- docs: index.rst: don't use genindex for pdf output
  (jsc#SLE-12878).
- Refresh
  patches.suse/ionic-Add-basic-framework-for-IONIC-Network-device-d.patch.
- commit e3d78bb
* Tue Sep 15 2020 tbogendoerfer@suse.de
- mlx4: Mark PM functions as __maybe_unused (jsc#SLE-15171).
- mlx4: use generic power management (jsc#SLE-15171).
- RDMA/mlx4: Remove FMR support for memory registration
  (jsc#SLE-15171).
- xsk: Fix xsk_umem_xdp_frame_sz() (jsc#SLE-13706).
- xdp: For Intel AF_XDP drivers add XDP frame_sz (jsc#SLE-13706).
- ice: Add XDP frame size to driver (jsc#SLE-12878).
- i40e: Add XDP frame size to driver (jsc#SLE-13701).
- ixgbevf: Add XDP frame size to VF driver (jsc#SLE-13706).
- ixgbe: Add XDP frame size to driver (jsc#SLE-13706).
- ixgbe: Fix XDP redirect on archs with PAGE_SIZE above 4K
  (jsc#SLE-13706).
- mlx4: Add XDP frame size and adjust max XDP MTU (jsc#SLE-15171).
- xdp: Xdp_frame add member frame_sz and handle in
  convert_to_xdp_frame (jsc#SLE-13706).
- xdp: Add frame size to xdp_buff (jsc#SLE-13706).
- xsk: Remove unnecessary member in xdp_umem (jsc#SLE-13706).
- xsk: Change two variable names for increased clarity
  (jsc#SLE-13706).
- net: mlx4: remove unneeded variable "err" in
  mlx4_en_ethtool_add_mac_rule() (jsc#SLE-15171).
- net: mlx4: remove unneeded variable "err" in mlx4_en_get_rxfh()
  (jsc#SLE-15171).
- net/mlx4_core: Add missing iounmap() in error path
  (jsc#SLE-15171).
- net/mlx4_en: use napi_complete_done() in TX completion
  (jsc#SLE-15171).
- net/mlx4_core: fix a memory leak bug (jsc#SLE-15171).
- i40e: Remove unneeded conversion to bool (jsc#SLE-13701).
- mlx4: fix "initializer element not constant" compiler error
  (jsc#SLE-15171).
- ice: add a devlink region for dumping NVM contents
  (jsc#SLE-12878).
- devlink: implement DEVLINK_CMD_REGION_NEW (jsc#SLE-12878).
- devlink: track snapshot id usage count using an xarray
  (jsc#SLE-15171).
- devlink: report error once U32_MAX snapshot ids have been used
  (jsc#SLE-15171).
- devlink: extract snapshot id allocation to helper function
  (jsc#SLE-15171).
- devlink: use -ENOSPC to indicate no more room for snapshots
  (jsc#SLE-15171).
- devlink: add function to take snapshot while locked
  (jsc#SLE-15171).
- devlink: trivial: fix tab in function documentation
  (jsc#SLE-15171).
- devlink: convert snapshot destructor callback to region op
  (jsc#SLE-15171).
- devlink: prepare to support region operations (jsc#SLE-12878).
- devlink: Add API to register packet trap groups (jsc#SLE-12878).
- ice: add board identifier info to devlink .info_get
  (jsc#SLE-12878).
- ice: add basic handler for devlink .info_get (jsc#SLE-12878).
- ice: enable initial devlink support (jsc#SLE-12878).
- ice: implement full NVM read from ETHTOOL_GEEPROM
  (jsc#SLE-12878).
- ice: discover and store size of available flash (jsc#SLE-12878).
- ice: store NVM version info in extracted format (jsc#SLE-12878).
- ice: create function to read a section of the NVM and Shadow
  RAM (jsc#SLE-12878).
- ice: use __le16 types for explicitly Little Endian values
  (jsc#SLE-12878).
- net: ixgbevf: reject unsupported coalescing params
  (jsc#SLE-13706).
- net: ixgbe: reject unsupported coalescing params
  (jsc#SLE-13706).
- net: i40e: reject unsupported coalescing params (jsc#SLE-13701).
- net: mlx4: reject unsupported coalescing params (jsc#SLE-15171).
- net: liquidio: reject unsupported coalescing params
  (jsc#SLE-15171).
- ice: fix incorrect size description of ice_get_nvm_version
  (jsc#SLE-12878).
- ice: use variable name more descriptive than type
  (jsc#SLE-12878).
- ice: Use EOPNOTSUPP instead of ENOTSUPP (jsc#SLE-12878).
- ice: Fix format specifier (jsc#SLE-12878).
- ice: fix use of deprecated strlcpy() (jsc#SLE-12878).
- ice: Increase mailbox receive queue length to maximum
  (jsc#SLE-12878).
- ice: Correct setting VLAN pruning (jsc#SLE-12878).
- ice: renegotiate link after FW DCB on (jsc#SLE-12878).
- ice: Fix corner case when switching from IEEE to CEE
  (jsc#SLE-12878).
- ice: Display Link detected via Ethtool in safe mode
  (jsc#SLE-12878).
- ice: Fix removing driver while bare-metal VFs pass traffic
  (jsc#SLE-12878).
- ice: Improve clarity of prints and variables (jsc#SLE-12878).
- ice: allow bigger VFs (jsc#SLE-12878).
- ice: Cleanup unneeded parenthesis (jsc#SLE-12878).
- ixgbe: Use pci_get_dsn() (jsc#SLE-13706).
- ice: Use pci_get_dsn() (jsc#SLE-12878).
- PCI: Introduce pci_get_dsn (jsc#SLE-13706).
- ice: let core reject the unsupported coalescing parameters
  (jsc#SLE-12878).
- xdp: Replace zero-length array with flexible-array member
  (jsc#SLE-13706).
- devlink: add trap metadata type for cookie (jsc#SLE-12878).
- devlink: add ACL generic packet traps (jsc#SLE-12878).
- ice: fix define for E822 backplane device (jsc#SLE-12878).
- ice: add support for E823 devices (jsc#SLE-12878).
- ice: add backslash-n to strings (jsc#SLE-12878).
- ice: increase PF reset wait timeout to 300 milliseconds
  (jsc#SLE-12878).
- ice: Support XDP UMEM wake up mechanism (jsc#SLE-12878).
- ice: SW DCB, report correct max TC value (jsc#SLE-12878).
- ice: Report correct DCB mode (jsc#SLE-12878).
- ice: Add DCBNL ops required to configure ETS in CEE for SW DCB
  (jsc#SLE-12878).
- ice: Always clear the QRXFLXP_CNTXT register for VF Rx queues
  (jsc#SLE-12878).
- ice: Fix for TCAM entry management (jsc#SLE-12878).
- ice: update malicious driver detection event handling
  (jsc#SLE-12878).
- ice: Validate config for SW DCB map (jsc#SLE-12878).
- devlink: Force enclosing array on binary fmsg data
  (jsc#SLE-12878).
- ice: use true/false for bool types (jsc#SLE-12878).
- ice: add function argument description to function header
  comment (jsc#SLE-12878).
- ice: use proper format for function pointer as a function
  parameter (jsc#SLE-12878).
- ice: replace "fallthrough" comments with fallthrough reserved
  word (jsc#SLE-12878).
- ice: remove unnecessary fallthrough comments (jsc#SLE-12878).
- ice: Fix virtchnl_queue_select bitmap validation
  (jsc#SLE-12878).
- ice: Fix and refactor Rx queue disable for VFs (jsc#SLE-12878).
- ice: Handle LAN overflow event for VF queues (jsc#SLE-12878).
- ice: Fix implicit queue mapping mode in ice_vsi_get_qs
  (jsc#SLE-12878).
- ice: Add support to enable/disable all Rx queues before waiting
  (jsc#SLE-12878).
- ice: Only allow tagged bcast/mcast traffic for VF in port VLAN
  (jsc#SLE-12878).
- ice: Fix Port VLAN priority bits (jsc#SLE-12878).
- ice: Add helper to determine if VF link is up (jsc#SLE-12878).
- ice: Refactor port vlan configuration for the VF
  (jsc#SLE-12878).
- ice: Add initial support for QinQ (jsc#SLE-12878).
- net: mlx4: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-15171).
- xsk: Publish global consumer pointers when NAPI is finished
  (jsc#SLE-13706).
- ice: Wait for VF to be reset/ready before configuration
  (jsc#SLE-12878).
- ice: Don't tell the OS that link is going down (jsc#SLE-12878).
- ice: Don't reject odd values of usecs set by user
  (jsc#SLE-12878).
- xsk, net: Make sock_def_readable() have external linkage
  (jsc#SLE-13706).
- devlink: Add overlay source MAC is multicast trap
  (jsc#SLE-12878).
- devlink: Add tunnel generic packet traps (jsc#SLE-12878).
- devlink: Add non-routable packet trap (jsc#SLE-12878).
- ice: remove redundant assignment to variable xmit_done
  (jsc#SLE-12878).
- ice: Removing hung_queue variable to use txqueue function
  parameter (jsc#SLE-12878).
- i40e: Removing hung_queue variable to use txqueue function
  parameter (jsc#SLE-13701).
- devlink: introduce devlink-dpipe.rst documentation file
  (jsc#SLE-12878).
- devlink: add a devlink-resource.rst documentation file
  (jsc#SLE-12878).
- devlink: rename and expand devlink-trap-netdevsim.rst
  (jsc#SLE-12878).
- devlink: add documentation for ionic device driver
  (jsc#SLE-12878).
- devlink: add a file documenting devlink regions (jsc#SLE-12878).
- devlink: add a driver-specific file for the qed driver
  (jsc#SLE-12878).
- devlink: add parameter documentation for the mlx4 driver
  (jsc#SLE-12878).
- devlink: convert driver-specific files to reStructuredText
  (jsc#SLE-12878).
- devlink: convert devlink-params.txt to reStructuredText
  (jsc#SLE-12878).
- devlink: rename devlink-info-versions.rst and add a header
  (jsc#SLE-12878).
- devlink: convert devlink-health.txt to rst format
  (jsc#SLE-12878).
- devlink: move devlink documentation to subfolder
  (jsc#SLE-12878).
- xsk: Add function naming comments and reorder functions
  (jsc#SLE-13706).
- xsk: ixgbe: i40e: ice: mlx5: Xsk_umem_discard_addr to
  xsk_umem_release_addr (jsc#SLE-13706).
- xsk: Simplify xskq_nb_avail and xskq_nb_free (jsc#SLE-13706).
- xsk: Eliminate the RX batch size (jsc#SLE-13706).
- xsk: Standardize naming of producer ring access functions
  (jsc#SLE-13706).
- xsk: Consolidate to one single cached producer pointer
  (jsc#SLE-13706).
- xsk: Simplify detection of empty and full rings (jsc#SLE-13706).
- xsk: Eliminate the lazy update threshold (jsc#SLE-13706).
- xsk: Make xskmap flush_list common for all map instances
  (jsc#SLE-13706).
- mlx4: use new txqueue timeout argument (jsc#SLE-15171).
- Documentation: Add a section for devlink-trap testing
  (jsc#SLE-12878).
- commit 0954b47
* Tue Sep 15 2020 lpechacek@suse.com
- supported.conf: mark virtio-iommu supported on aarch64 (jsc#SLE-12152)
- commit f94b476
* Tue Sep 15 2020 dwagner@suse.de
- nvme-multipath: retry commands for dying queues (bsc#1171688).
- commit 50f2e12
* Tue Sep 15 2020 hare@suse.de
- bcache: Fix typo in Kconfig name (bsc#1175995,jsc#SLE-15608).
- Update config files.
- commit 70aed61
* Tue Sep 15 2020 aaptel@suse.com
- smb3: warn on confusing error scenario with sec=krb5
  (bsc#1176548).
- commit 87d97c1
* Tue Sep 15 2020 aaptel@suse.com
- cifs: Fix leak when handling lease break for cached root fid
  (bsc#1176242).
- commit 3f36e87
* Tue Sep 15 2020 aaptel@suse.com
- SMB3: Honor 'posix' flag for multiuser mounts (bsc#1176559).
- commit da99223
* Tue Sep 15 2020 aaptel@suse.com
- SMB3: Honor 'handletimeout' flag for multiuser mounts
  (bsc#1176558).
- commit 7fc229a
* Tue Sep 15 2020 mbenes@suse.cz
- x86/unwind/orc: Fix premature unwind stoppage due to IRET frames
  (bsc#1058115).
  Remove the commit from blacklist.conf too.
- commit f15a51f
* Tue Sep 15 2020 aaptel@suse.com
- SMB3: Honor persistent/resilient handle flags for multiuser
  mounts (bsc#1176546).
- Refresh
  patches.suse/SMB3-Honor-lease-disabling-for-multiuser-mounts.patch.
- commit 9b622c7
* Tue Sep 15 2020 aaptel@suse.com
- SMB3: Honor 'seal' flag for multiuser mounts (bsc#1176545).
- commit c2120ee
* Tue Sep 15 2020 aaptel@suse.com
- cifs/smb3: Fix data inconsistent when punch hole (bsc#1176544).
- commit a9ca8fc
* Tue Sep 15 2020 aaptel@suse.com
- cifs/smb3: Fix data inconsistent when zero file range
  (bsc#1176536).
- commit 92bbeda
* Tue Sep 15 2020 hare@suse.de
- xen-blkfront.c: Convert to use
  set_capacity_revalidate_and_notify (bsc#1175995,jsc#SLE-15608).
- commit 937dc91
* Tue Sep 15 2020 msuchanek@suse.de
- driver-core: Introduce DEVICE_ATTR_ADMIN_{RO,RW} (bsc#1176486
  ltc#188130).
- commit daeec95
* Tue Sep 15 2020 msuchanek@suse.de
- powerpc/papr_scm: Limit the readability of 'perf_stats' sysfs
  attribute (bsc#1176486 ltc#188130).
- commit 5a8c141
* Tue Sep 15 2020 jslaby@suse.cz
- net: initialize fastreuse on inet_inherit_port
  (networking-stable-20_08_15).
- net: refactor bind_bucket fastreuse into helper
  (networking-stable-20_08_15).
- net: Fix potential memory leak in proto_register()
  (networking-stable-20_08_15).
- net/nfc/rawsock.c: add CAP_NET_RAW check
  (networking-stable-20_08_15).
- net/tls: Fix kmap usage (networking-stable-20_08_15).
- tcp: correct read of TFO keys on big endian systems
  (networking-stable-20_08_15).
- net: Set fput_needed iff FDPUT_FPUT is set
  (networking-stable-20_08_15).
- commit 172e095
* Tue Sep 15 2020 lhenriques@suse.de
- rbd: require global CAP_SYS_ADMIN for mapping and unmapping
  (CVE-2020-25284 bsc#1176543).
- ceph: don't allow setlease on cephfs (bsc#1176537).
- ceph: handle zero-length feature mask in session messages
  (bsc#1176540).
- ceph: use frag's MDS in either mode (bsc#1176542).
- ceph: set sec_context xattr on symlink creation (bsc#1176541).
- ceph: fix use-after-free for fsc->mdsc (bsc#1176539).
- ceph: fix potential mdsc use-after-free crash (bsc#1176538).
- commit 87663ec
* Tue Sep 15 2020 msuchanek@suse.de
- Delete patches.suse/powerpc-Move-EXCEPTION_TABLE-to-RO_DATA-segment.patch.
  Delete patch that causes a warning about unknown section.
- commit a7b968e
* Tue Sep 15 2020 jroedel@suse.de
- vfio/pci: Cleanup .probe() exit paths (bsc#1175713).
- Refresh
  patches.suse/vfio-pci-fault-mmaps-to-enable-vma-tracking.
- Refresh
  patches.suse/vfio-pci-invalidate-mmaps-and-block-mmio-access-on-disabled-memory.
- commit 0446efa
* Tue Sep 15 2020 jroedel@suse.de
- vfio/pci: Add sriov_configure support (bsc#1175713).
- Refresh
  patches.suse/vfio-pci-fault-mmaps-to-enable-vma-tracking.
- Refresh
  patches.suse/vfio-pci-invalidate-mmaps-and-block-mmio-access-on-disabled-memory.
- commit 61e9a96
* Tue Sep 15 2020 jroedel@suse.de
- vfio/pci: Introduce VF token (bsc#1175713).
- Refresh
  patches.suse/vfio-pci-fault-mmaps-to-enable-vma-tracking.
- Refresh
  patches.suse/vfio-pci-invalidate-mmaps-and-block-mmio-access-on-disabled-memory.
- commit 8b91f2a
* Tue Sep 15 2020 jroedel@suse.de
- vfio: fix FOLL_LONGTERM use, simplify get_user_pages_remote()
  call (bsc#1175713).
- Refresh
  patches.suse/vfio-type1-Fix-VA-PA-translation-for-PFNMAP-VMAs-in-.patch.
- Refresh patches.suse/vfio-type1-support-faulting-pfnmap-vmas.
- commit 1136f3b
* Tue Sep 15 2020 jroedel@suse.de
- PCI: Add PCI_STD_NUM_BARS for the number of standard BARs
  (bsc#1175713).
- Refresh
  patches.suse/PCI-endpoint-Fix-set_msix-to-take-BIR-and-offset-as-.patch.
- Refresh
  patches.suse/vfio-pci-fault-mmaps-to-enable-vma-tracking.
- commit b6b26f9
* Tue Sep 15 2020 denis.kirjanov@suse.com
- thunderbolt: Use maximum USB3 link rate when reclaiming if
  link is not up (git-fixes).
- commit 6081a42
* Tue Sep 15 2020 denis.kirjanov@suse.com
- thunderbolt: Disable ports that are not implemented (git-fixes).
- commit 23a3be6
* Tue Sep 15 2020 jroedel@suse.de
- vfio/type1: untag user pointers in vaddr_get_pfn (bsc#1175713).
- Refresh patches.suse/vfio-type1-support-faulting-pfnmap-vmas.
- commit 8fab67f
* Tue Sep 15 2020 jroedel@suse.de
- vfio-ccw: add some logging (bsc#1175713).
- Refresh
  patches.suse/s390-cio-generate-delayed-uevent-for-vfio-ccw-subchannels.
- commit 947f744
* Tue Sep 15 2020 jroedel@suse.de
- vfio/pci: fix racy on error and request eventfd ctx
  (bsc#1175713).
- vfio-ccw: Fix a build error due to missing include of
  linux/slab.h (bsc#1175713).
- vfio/type1: Fix migration info capability ID (bsc#1175713).
- vfio/pci: Clear error and request eventfd ctx after releasing
  (bsc#1175713).
- vfio-ccw: make vfio_ccw_regops variables declarations static
  (bsc#1175713).
- vfio-ccw: Add trace for CRW event (bsc#1175713).
- vfio-ccw: Wire up the CRW irq and CRW region (bsc#1175713).
- vfio-ccw: Introduce a new CRW region (bsc#1175713).
- vfio-ccw: Refactor IRQ handlers (bsc#1175713).
- vfio-ccw: Introduce a new schib region (bsc#1175713).
- vfio-ccw: Refactor the unregister of the async regions
  (bsc#1175713).
- vfio-ccw: Register a chp_event callback for vfio-ccw
  (bsc#1175713).
- vfio-ccw: Introduce new helper functions to free/destroy regions
  (bsc#1175713).
- vfio-ccw: Enable transparent CCW IPL from DASD (bsc#1175713).
- vfio iommu: typecast corrections (bsc#1175713).
- vfio iommu: Use shift operation for 64-bit integer division
  (bsc#1175713).
- vfio: Selective dirty page tracking if IOMMU backed device
  pins pages (bsc#1175713).
- vfio iommu: Add migration capability to report supported
  features (bsc#1175713).
- vfio iommu: Update UNMAP_DMA ioctl to get dirty bitmap before
  unmap (bsc#1175713).
- vfio iommu: Implementation of ioctl for dirty pages tracking
  (bsc#1175713).
- vfio iommu: Add ioctl definition for dirty pages tracking
  (bsc#1175713).
- vfio iommu: Cache pgsize_bitmap in struct vfio_iommu
  (bsc#1175713).
- vfio iommu: Remove atomicity of ref_count of pinned pages
  (bsc#1175713).
- vfio: UAPI for migration interface for device state
  (bsc#1175713).
- vfio/pci: fix memory leaks of eventfd ctx (bsc#1175713).
- vfio-pci: Mask cap zero (bsc#1175713).
- vfio: checking of validity of user vaddr in vfio_dma_rw
  (bsc#1175713).
- vfio-pci/nvlink2: Allow fallback to ibm,mmio-atsd (bsc#1175713).
- vfio: avoid inefficient operations on VFIO group in
  vfio_pin/unpin_pages (bsc#1175713).
- vfio: introduce vfio_dma_rw to read/write a range of IOVAs
  (bsc#1175713).
- vfio: allow external user to get vfio group from device
  (bsc#1175713).
- vfio/pci: Remove dev_fmt definition (bsc#1175713).
- vfio: Introduce VFIO_DEVICE_FEATURE ioctl and first user
  (bsc#1175713).
- vfio/pci: Implement match ops (bsc#1175713).
- vfio: Include optional device match in vfio_device_ops callbacks
  (bsc#1175713).
- vfio: platform: fix __iomem in vfio_platform_amdxgbe.c
  (bsc#1175713).
- vfio/mdev: make create attribute static (bsc#1175713).
- vfio/spapr_tce: use mmgrab (bsc#1175713).
- vfio: vfio_pci_nvlink2: use mmgrab (bsc#1175713).
- vfio, mm: pin_user_pages (FOLL_PIN) and put_user_page()
  conversion (bsc#1175713).
- vfio/type1: remove hugepage checks in is_invalid_reserved_pfn()
  (bsc#1175713).
- vfio-ccw: Rework the io_fctl trace (bsc#1175713).
- vfio-ccw: Add a trace for asynchronous requests (bsc#1175713).
- vfio-ccw: Trace the FSM jumptable (bsc#1175713).
- vfio-ccw: Refactor how the traces are built (bsc#1175713).
- vfio/type1: Initialize resv_msi_base (bsc#1175713).
- vfio/type1: remove duplicate retrieval of reserved regions
  (bsc#1175713).
- vfio/type1: Add IOVA range capability support (bsc#1175713).
- vfio/type1: check dma map request is within a valid iova range
  (bsc#1175713).
- vfio/type1: Update iova list on detach (bsc#1175713).
- vfio/type1: Check reserved region conflict and update iova list
  (bsc#1175713).
- vfio/type1: Introduce iova list and add iommu aperture validity
  check (bsc#1175713).
- vfio: re-arrange vfio region definitions (bsc#1175713).
- powerpc/powernv/ioda: Remove obsolete iommu_table_ops::exchange
  callbacks (bsc#1175713).
- powerpc/pseries/iommu: Switch to xchg_no_kill (bsc#1175713).
- vfio/spapr_tce: Invalidate multiple TCEs at once (bsc#1175713).
- KVM: PPC: Book3S: Invalidate multiple TCEs at once
  (bsc#1175713).
- powerpc/powernv/ioda: Split out TCE invalidation from TCE
  updates (bsc#1175713).
- vfio-ccw: fix error return code in vfio_ccw_sch_init()
  (bsc#1175713).
- commit a14198d
* Tue Sep 15 2020 hare@suse.de
- dm crypt: Initialize crypto wait structures
  (bsc#1175995,jsc#SLE-15608).
- dm ebs: Fix incorrect checking for REQ_OP_FLUSH
  (bsc#1175995,jsc#SLE-15608).
- iocost: Fix check condition of iocg abs_vdebt
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: fix unused but set variable warnings
  (bsc#1175995,jsc#SLE-15608).
- cgroup: fix psi_show() crash on 32bit ino archs
  (bsc#1175995,jsc#SLE-15608).
- commit 91a1e51
* Tue Sep 15 2020 hare@suse.de
- xen/blkfront: fix ring info addressing
  (bsc#1175995,jsc#SLE-15608).
- commit c639ad9
* Tue Sep 15 2020 hare@suse.de
- dm: add dm-clone to the documentation index
  (bsc#1175995,jsc#SLE-15608).
- selftests/bpf: Don't hard-code root cgroup id
  (bsc#1175995,jsc#SLE-15608).
- writeback: fix -Wformat compilation warnings
  (bsc#1175995,jsc#SLE-15608).
- cgroup: fix incorrect WARN_ON_ONCE() in cgroup_setup_root()
  (bsc#1175995,jsc#SLE-15608).
- commit 4256b92
* Tue Sep 15 2020 hare@suse.de
- Update config files.
- commit 4aac74c
* Mon Sep 14 2020 tbogendoerfer@suse.de
- RDMA/bnxt_re: Remove set but not used variable 'qplib_ctx'
  (bsc#1170774).
- commit d51761b
* Mon Sep 14 2020 bp@suse.de
- blacklist.conf: 2356bb4b8221 tracing/kprobes, x86/ptrace: Fix regs argument order for i386
- commit c54f3f0
* Mon Sep 14 2020 tbogendoerfer@suse.de
- RDMA/bnxt_re: Remove the qp from list only if the qp destroy
  succeeds (bsc#1170774).
- RDMA/bnxt_re: Static NQ depth allocation (bsc#1170774).
- RDMA/mlx4: Read pkey table length instead of hardcoded value
  (git-fixes).
- commit d897d3a
* Mon Sep 14 2020 hare@suse.de
- dm writecache: improve performance on DDR persistent memory
  (Optane) (bsc#1175995,jsc#SLE-15608).
- commit 8d80b5c
* Mon Sep 14 2020 hare@suse.de
- dm writecache: remove superfluous test in
  persistent_memory_claim (bsc#1175995,jsc#SLE-15608).
- commit e8e49c1
* Mon Sep 14 2020 mbenes@suse.cz
- ftrace: Setup correct FTRACE_FL_REGS flags for module
  (git-fixes).
- commit b5a1bd1
* Mon Sep 14 2020 msuchanek@suse.de
- powerpc/kernel: Cleanup machine check function declarations
  (bsc#1065729).
- commit 05b1221
* Mon Sep 14 2020 hare@suse.de
- dm: add clone target (bsc#1175995,jsc#SLE-15608).
- Update config files.
- supported.conf: mark dm-clone as supported
- commit 8019105
* Mon Sep 14 2020 hare@suse.de
- dm: add emulated block size target (bsc#1175995,jsc#SLE-15608).
- Update config files.
- supported.conf: mark dm-ebs as supported
- commit 89f3ea1
* Mon Sep 14 2020 hare@suse.de
- dm mpath: add Historical Service Time Path Selector
  (bsc#1175995,jsc#SLE-15608).
- Update config files.
- Refresh patches.suse/dm-mpath-leastpending-path-update.
- supported.conf: mark dm-historcal-time-length as supported
- commit aca8751
* Mon Sep 14 2020 hare@suse.de
- blktrace: fix endianness for blk_log_remap()
  (bsc#1175995,jsc#SLE-15608).
- blktrace: fix endianness in get_pdu_int()
  (bsc#1175995,jsc#SLE-15608).
- blktrace: use errno instead of bi_status
  (bsc#1175995,jsc#SLE-15608).
- block/swim3: use set_current_state macro
  (bsc#1175995,jsc#SLE-15608).
- blktrace: Report pid with note messages
  (bsc#1175995,jsc#SLE-15608).
- commit 7405224
* Mon Sep 14 2020 hare@suse.de
- cgroup: use cgrp->kn->id as the cgroup ID
  (bsc#1175995,jsc#SLE-15608).
- kernfs: use 64bit inos if ino_t is 64bit
  (bsc#1175995,jsc#SLE-15608).
- kernfs: implement custom exportfs ops and fid type
  (bsc#1175995,jsc#SLE-15608).
- kernfs: combine ino/id lookup functions into
  kernfs_find_and_get_node_by_id() (bsc#1175995,jsc#SLE-15608).
- commit bbedf0f
* Mon Sep 14 2020 hare@suse.de
- kernfs: convert kernfs_node->id from union kernfs_node_id to
  u64 (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/blktrace-Protect-q-blk_trace-with-RCU.patch.
- commit a37bb3e
* Mon Sep 14 2020 hare@suse.de
- kernfs: kernfs_find_and_get_node_by_ino() should only look up
  activated nodes (bsc#1175995,jsc#SLE-15608).
- kernfs: use dumber locking for kernfs_find_and_get_node_by_ino()
  (bsc#1175995,jsc#SLE-15608).
- commit 57dfe26
* Mon Sep 14 2020 hare@suse.de
- netprio: use css ID instead of cgroup ID
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/netprio_cgroup-Fix-unlimited-memory-leak-of-v2-cgrou.patch.
- commit 3b76527
* Mon Sep 14 2020 hare@suse.de
- writeback: use ino_t for inodes in tracepoints
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/memcg-fix-a-crash-in-wb_workfn-when-a-device-disappe.patch.
- commit 3938e12
* Mon Sep 14 2020 hare@suse.de
- ata: sata_inic162x fix a spelling issue
  (bsc#1175995,jsc#SLE-15608).
- block: remove unused header (bsc#1175995,jsc#SLE-15608).
- bdev: Reduce time holding bd_mutex in sync in blkdev_close()
  (bsc#1175995,jsc#SLE-15608).
- ahci: Add Intel Comet Lake PCH-U PCI ID
  (bsc#1175995,jsc#SLE-15608).
- ahci: Add Intel Comet Lake PCH RAID PCI ID
  (bsc#1175995,jsc#SLE-15608).
- ata: ahci: Add sysfs attribute to show remapped NVMe device
  (bsc#1175995,jsc#SLE-15608).
- ata: ahci-imx: remove redundant assignment to ret
  (bsc#1175995,jsc#SLE-15608).
- commit 290a94c
* Mon Sep 14 2020 hare@suse.de
- nbd: requeue command if the soecket is changed
  (bsc#1175995,jsc#SLE-15608).
- nbd: enable replace socket if only one connection is
  (bsc#1175995,jsc#SLE-15608).
- libata: drop BPRINTK() (bsc#1175995,jsc#SLE-15608).
- xen/blkfront: limit allocated memory size to actual use case
  (bsc#1175995,jsc#SLE-15608).
- commit d81f216
* Mon Sep 14 2020 nsaenzjulienne@suse.de
- usb: typec: tcpm: Fix Fix source hard reset response for TDA
  2.3.1.1 and TDA 2.3.1.2 failures (jsc#SLE-13918).
- usb: typec: ucsi: Hold con->lock for the entire duration of
  ucsi_register_port() (jsc#SLE-13918).
- usb: typec: ucsi: Rework ppm_lock handling (jsc#SLE-13918).
- usb: typec: ucsi: Fix 2 unlocked ucsi_run_command calls
  (jsc#SLE-13918).
- usb: typec: ucsi: Fix AB BA lock inversion (jsc#SLE-13918).
- usb: typec: tcpm: Add WARN_ON ensure we are not trying to send
  2 VDM packets at the same time (jsc#SLE-13918).
- usb: typec: tcpm: Fix AB BA lock inversion between tcpm code
  and the alt-mode drivers (jsc#SLE-13918).
- usb: typec: tcpm: Refactor tcpm_handle_vdm_request
  (jsc#SLE-13918).
- usb: typec: tcpm: Refactor tcpm_handle_vdm_request payload
  handling (jsc#SLE-13918).
- usb: typec: tcpm: Add tcpm_queue_vdm_unlocked() helper
  (jsc#SLE-13918).
- usb: typec: tcpm: Move
  mod_delayed_work(&port->vdm_state_machine) call into
  tcpm_queue_vdm() (jsc#SLE-13918).
- usb: typec: tcpm: Stay in BIST mode till hardreset or unattached
  (jsc#SLE-13918).
- usb: typec: tcpci: Support BIST test data mode for compliance
  (jsc#SLE-13918).
- usb: typec: tcpm: Support bist test data mode for compliance
  (jsc#SLE-13918).
- usb: typec: tcpm: Error handling for
  tcpm_register_partner_altmodes (jsc#SLE-13918).
- usb: typec: Comment correction for
  typec_partner_register_altmode (jsc#SLE-13918).
- usb: typec: intel_pmc_mux: Avoid connect request on disconnect
  (jsc#SLE-13918).
- usb: typec: Replace HTTP links with HTTPS ones (jsc#SLE-13918).
- usb: typec: ucsi: ucsi: Staticify and stop export of ucsi_init()
  (jsc#SLE-13918).
- usb: typec: tcpm: fusb302: Use 'gnu_printf' format notation
  (jsc#SLE-13918).
- usb: typec: altmodes: displayport: Supply missing displayport.h
  include file (jsc#SLE-13918).
- usb: typec: altmodes: displayport: File headers are not good
  candidates for kerneldoc (jsc#SLE-13918).
- usb: typec: intel_pmc_mux: Add support for USB4 (jsc#SLE-13918).
- usb: typec: intel_pmc_mux: Definitions for response status bits
  (jsc#SLE-13918).
- usb: typec: Add data structure for Enter_USB message
  (jsc#SLE-13918).
- usb: typec: Combine the definitions for Accessory and USB modes
  (jsc#SLE-13918).
- usb: typec: mux: intel_pmc_mux: Fix DP alternate mode entry
  (jsc#SLE-13918).
- usb: typec: Ensure USB_ROLE_SWITCH is set as a dependency for
  tps6598x (jsc#SLE-13918).
- usb: typec: tps6598x: Add USB role switching logic
  (jsc#SLE-13918).
- usb: typec: tps6598x: Add OF probe binding (jsc#SLE-13918).
- usb: typec: mux: intel_pmc_mux: Support for static SBU/HSL
  orientation (jsc#SLE-13918).
- usb: typec: Add typec_find_orientation() (jsc#SLE-13918).
- usb: roles: Switch on role-switch uevent reporting
  (jsc#SLE-13918).
- usb: typec: ucsi: Fix the stub for ucsi_register_port_psy()
  (jsc#SLE-13918).
- usb: typec: ucsi: register with power_supply class
  (jsc#SLE-13918).
- usb: typec: ucsi: save power data objects in PD mode
  (jsc#SLE-13918).
- usb: typec: ucsi: Correct bit-mask for CCI (jsc#SLE-13918).
- usb: typec: ucsi: replace magic numbers (jsc#SLE-13918).
- usb: typec: ucsi: Workaround for missed op_mode change
  (jsc#SLE-13918).
- usb: typec: ucsi: set USB data role when partner type is power
  cable/ufp (jsc#SLE-13918).
- USB: typec: Use the correct style for SPDX License Identifier
  (jsc#SLE-13918).
- usb: fusb302: Convert to use GPIO descriptors (jsc#SLE-13918).
- MAINTAINERS: Update entry for Intel Broxton PMC driver
  (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Convert to MFD (jsc#SLE-13918).
- Update configs
- supported.conf: Remove reference to intel_pmc_ipc and add
  intel_pmc_bxt
- platform/x86: intel_telemetry: Add telemetry_get_pltdata()
  (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Move PCI IDs to intel_scu_pcidrv.c
  (jsc#SLE-13918).
- Update configs
- supported.conf: Add intel_mid_powerbtn, intel_mid_thermal and
  intel_scu_ipcutil
- x86/platform/intel-mid: Add empty stubs for
  intel_scu_devices_[create|destroy]() (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Drop intel_pmc_ipc_command()
  (jsc#SLE-13918).
- usb: typec: mux: Convert the Intel PMC Mux driver to use new
  SCU IPC API (jsc#SLE-13918).
- platform/x86: intel_telemetry: Convert to use new SCU IPC API
  (jsc#SLE-13918).
- mfd: intel_soc_pmic_bxtwc: Convert to use new SCU IPC API
  (jsc#SLE-13918).
- mfd: intel_soc_pmic: Add SCU IPC member to struct intel_soc_pmic
  (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Start using SCU IPC
  (jsc#SLE-13918).
- Update config files
- platform/x86: intel_scu_ipc: Add managed function to register
  SCU IPC (jsc#SLE-13918).
- platform/x86: intel_scu_ipcutil: Convert to use new SCU IPC API
  (jsc#SLE-13918).
- watchdog: intel-mid_wdt: Convert to use new SCU IPC API
  (jsc#SLE-13918).
- platform/x86: intel_mid_powerbtn: Convert to use new SCU IPC
  API (jsc#SLE-13918).
- platform/x86: intel_scu_ipc: Introduce new SCU IPC API
  (jsc#SLE-13918).
- platform/x86: intel_scu_ipc: Move legacy SCU IPC API to a
  separate header (jsc#SLE-13918).
- platform/x86: intel_scu_ipc: Log more information if SCU IPC
  command fails (jsc#SLE-13918).
- platform/x86: intel_scu_ipc: Split out SCU IPC functionality
  from the SCU driver (jsc#SLE-13918).
- usb: typec: mux: intel: Fix DP_HPD_LVL bit field
  (jsc#SLE-13918).
- usb: typec: mux: intel: Handle alt mode HPD_HIGH
  (jsc#SLE-13918).
- usb: typec: intel_pmc_mux: Fix the property names
  (jsc#SLE-13918).
- usb: typec: pi3usb30532: Set switch_ / mux_desc name field to
  NULL (jsc#SLE-13918).
- usb: typec: Correct the documentation for typec_cable_put()
  (jsc#SLE-13918).
- usb: typec: ucsi_ccg: workaround for NVIDIA test device
  (jsc#SLE-13918).
- usb: typec: driver for Intel PMC mux control (jsc#SLE-13918).
- Update config files
- supported.conf: Add intel_pmc_mux
- usb: typec: Add definitions for Thunderbolt 3 Alternate Mode
  (jsc#SLE-13918).
- usb: roles: Allow the role switches to be named (jsc#SLE-13918).
- usb: roles: Provide the switch drivers handle to the switch
  in the API (jsc#SLE-13918).
- usb: roles: Leave the private driver data pointer to the drivers
  (jsc#SLE-13918).
- usb: typec: mux: Allow the mux handles to be requested with
  fwnode (jsc#SLE-13918).
- usb: typec: mux: Add helpers for setting the mux state
  (jsc#SLE-13918).
- usb: typec: mux: Allow the muxes to be named (jsc#SLE-13918).
- usb: typec: tcpm: move to SNK_UNATTACHED if sink removed for
  DRP (jsc#SLE-13918).
- usb: typec: Add sysfs node to show cc orientation
  (jsc#SLE-13918).
- usb: ucsi: ccg: disable runtime pm during fw flashing
  (jsc#SLE-13918).
- usb: typec: ucsi: register DP only for NVIDIA DP VDO
  (jsc#SLE-13918).
- usb: typec: tcpm: set correct data role for non-DRD
  (jsc#SLE-13918).
- usb: use kobj_to_dev() API (jsc#SLE-13918).
- usb: typec: mux: Drop support for device name matching
  (jsc#SLE-13918).
- usb: typec: altmode: Remove the notification chain
  (jsc#SLE-13918).
- usb: typec: Fix the description of struct typec_capability
  (jsc#SLE-13918).
- usb: typec: Allow power role swapping even without USB PD
  (jsc#SLE-13918).
- usb: typec: Hide the port_type attribute when it's not supported
  (jsc#SLE-13918).
- usb: typec: Make the attributes read-only when writing is not
  possible (jsc#SLE-13918).
- usb: typec: ucsi: remove redundant assignment to variable num
  (jsc#SLE-13918).
- device property: Export fwnode_get_name() (jsc#SLE-13918).
- usb: typec: fusb302: fix "op-sink-microwatt" default that was
  in mW (jsc#SLE-13918).
- usb: typec: Provide definitions for the USB modes
  (jsc#SLE-13918).
- usb: typec: Give the mux drivers all the details regarding
  the port state (jsc#SLE-13918).
- usb: typec: Add definitions for the latest specification
  releases (jsc#SLE-13918).
- usb: typec: Add the Product Type VDOs to struct usb_pd_identity
  (jsc#SLE-13918).
- usb: pd: Add definitions for the Enter_USB message
  (jsc#SLE-13918).
- usb: typec: More API for cable handling (jsc#SLE-13918).
- usb: typec: Add parameter for the VDO to typec_altmode_enter()
  (jsc#SLE-13918).
- Refresh 0001-typeC-add-kABI-padding.patch
- usb: typec: Block mode entry if the port has the mode disabled
  (jsc#SLE-13918).
- usb: typec: ucsi: fix spelling mistake "connetor" -> "connector"
  (jsc#SLE-13918).
- usb: typec: ucsi: Actually enable all the interface
  notifications (jsc#SLE-13918).
- usb: typec: fix non-kernel-doc comments (jsc#SLE-13918).
- usb: typec: ucsi: add support for separate DP altmode devices
  (jsc#SLE-13918).
- usb: typec: ucsi: Store the notification mask (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Switch to use driver->dev_groups
  (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Propagate error from kstrtoul()
  (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Use octal permissions in sysfs
  attributes (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Get rid of unnecessary includes
  (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Drop ipc_data_readb()
  (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Drop intel_pmc_gcr_read() and
  intel_pmc_gcr_write() (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Make intel_pmc_ipc_raw_cmd()
  static (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Make intel_pmc_ipc_simple_command()
  static (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Make intel_pmc_gcr_update() static
  (jsc#SLE-13918).
- platform/x86: intel_scu_ipc: Reformat kernel-doc comments of
  exported functions (jsc#SLE-13918).
- platform/x86: intel_scu_ipc: Drop intel_scu_ipc_raw_command()
  (jsc#SLE-13918).
- platform/x86: intel_scu_ipc: Drop
  intel_scu_ipc_io[read|write][8|16]() (jsc#SLE-13918).
- platform/x86: intel_scu_ipc: Drop unused macros (jsc#SLE-13918).
- platform/x86: intel_scu_ipc: Drop unused prototype
  intel_scu_ipc_fw_update() (jsc#SLE-13918).
- platform/x86: intel_scu_ipc: Sleeping is fine when polling
  (jsc#SLE-13918).
- platform/x86: intel_scu_ipc: Drop intel_scu_ipc_i2c_cntrl()
  (jsc#SLE-13918).
- platform/x86: intel_scu_ipc: Remove Lincroft support
  (jsc#SLE-13918).
- platform/x86: intel_scu_ipc: Add constants for register offsets
  (jsc#SLE-13918).
- usb: typec: ucsi: Fix the notification bit offsets
  (jsc#SLE-13918).
- usb: typec: tcpm: Remove tcpc_config configuration mechanism
  (jsc#SLE-13918).
- usb: typec: ucsi: Optimise ucsi_unregister() (jsc#SLE-13918).
- usb: typec: ucsi: New error codes (jsc#SLE-13918).
- usb: typec: ucsi: Remove all bit-fields (jsc#SLE-13918).
- usb: typec: ucsi: Remove struct ucsi_control (jsc#SLE-13918).
- usb: typec: ucsi: Remove the old API (jsc#SLE-13918).
- usb: typec: ucsi: ccg: Move to the new API (jsc#SLE-13918).
- usb: typec: ucsi: acpi: Move to the new API (jsc#SLE-13918).
- usb: typec: ucsi: Simplified registration and I/O API
  (jsc#SLE-13918).
- usb: typec: hd3ss3220: Give the connector fwnode to the port
  device (jsc#SLE-13918).
- usb: typec: Remove unused members from struct typec_capability
  (jsc#SLE-13918).
- usb: typec: Remove the callback members from struct
  typec_capability (jsc#SLE-13918).
- Refresh 0001-typeC-add-kABI-padding.patch
- usb: typec: hd3ss3220: Start using struct typec_operations
  (jsc#SLE-13918).
- usb: typec: ucsi: Start using struct typec_operations
  (jsc#SLE-13918).
- usb: typec: tps6598x: Start using struct typec_operations
  (jsc#SLE-13918).
- usb: typec: tcpm: Start using struct typec_operations
  (jsc#SLE-13918).
- usb: typec: Separate the operations vector (jsc#SLE-13918).
- Refresh 0001-typeC-add-kABI-padding.patch
- usb: typec: Introduce typec_get_drvdata() (jsc#SLE-13918).
- usb: typec: Copy everything from struct typec_capability during
  registration (jsc#SLE-13918).
- usb: roles: Add usb_role_switch_find_by_fwnode()
  (jsc#SLE-13918).
- usb: typec: fix an IS_ERR() vs NULL bug in hd3ss3220_probe()
  (jsc#SLE-13918).
- usb: typec: remove duplicated include from hd3ss3220.c
  (jsc#SLE-13918).
- usb: typec: hd3ss3220: hd3ss3220_probe() warn: passing zero to
  'PTR_ERR' (jsc#SLE-13918).
- usb: typec: add dependency for TYPEC_HD3SS3220 (jsc#SLE-13918).
- usb: typec: hd3ss3220_irq() can be static (jsc#SLE-13918).
- usb: typec: driver for TI HD3SS3220 USB Type-C DRP port
  controller (jsc#SLE-13918).
- Update config files
- supported.conf: Add entry from usb/typec/hd3ss3220
- device property: Add fwnode_get_name for returning the name
  of a node (jsc#SLE-13918).
- usb: roles: get usb-role-switch from parent (jsc#SLE-13918).
- usb: roles: Add fwnode_usb_role_switch_get() function
  (jsc#SLE-13918).
- device connection: Add fwnode_connection_find_match()
  (jsc#SLE-13918).
- usb: roles: Introduce stubs for the exiting functions in role.h
  (jsc#SLE-13918).
- usb: roles: intel: Enable static DRD mode for role switch
  (jsc#SLE-13918).
- usb: typec: fusb302: Call fusb302_debugfs_init earlier
  (jsc#SLE-13918).
- usb: typec: fusb302: Use usb_debug_root as root for our debugfs
  entry (jsc#SLE-13918).
- usb: typec: tcpm: Use usb_debug_root as root for our debugfs
  entry (jsc#SLE-13918).
- usb: typec: fusb302: Always provide fwnode for the port
  (jsc#SLE-13918).
- usb: typec: fusb302: Remove unused properties (jsc#SLE-13918).
- USB: typec: ucsi_ccg: convert i2c driver to use dev_groups
  (jsc#SLE-13918).
- usb: Remove dev_err() usage after platform_get_irq()
  (jsc#SLE-13918).
- usb: typec: mux: Switch to use fwnode_property_count_uXX()
  (jsc#SLE-13918).
- usb: typec: tcpm: Switch to use fwnode_property_count_uXX()
  (jsc#SLE-13918).
- usb: roles: intel_xhci: Supplying software node for the role
  mux (jsc#SLE-13918).
- platform/x86: intel_pmc_ipc: Remove dev_err() usage after
  platform_get_irq() (jsc#SLE-13918).
- commit 4e0d82c
* Mon Sep 14 2020 hare@suse.de
- s390/dasd: fix typo in copyright statement
  (bsc#1175995,jsc#SLE-15608).
- s390/dasd: fix memleak in path handling error case
  (bsc#1175995,jsc#SLE-15608).
- s390/dasd/cio: Interpret ccw_device_get_mdc return value
  (bsc#1175995,jsc#SLE-15608).
- nvmet-loop: Avoid preallocating big SGL for data
  (bsc#1175995,jsc#SLE-15608).
- commit 5d9227b
* Mon Sep 14 2020 hare@suse.de
- nvmet: add another maintainer (bsc#1175995,jsc#SLE-15608).
- nvme-pci: Spelling s/resdicovered/rediscovered/
  (bsc#1175995,jsc#SLE-15608).
- commit e86eeab
* Mon Sep 14 2020 hare@suse.de
- block: mtip32xx: Spelling s/configration/configuration/
  (bsc#1175995,jsc#SLE-15608).
- commit 974c608
* Mon Sep 14 2020 hare@suse.de
- block: Document all members of blk_mq_tag_set and
  (bsc#1175995,jsc#SLE-15608).
- Refresh patches.suse/blk-mq-fill-header-with-kernel-doc.patch.
- commit f64ff43
* Mon Sep 14 2020 hare@suse.de
- nvme-tcp: fix possible leakage during error flow
  (bsc#1175995,jsc#SLE-15608).
- nvmet-loop: fix possible leakage during error flow
  (bsc#1175995,jsc#SLE-15608).
- commit b23a9e5
* Mon Sep 14 2020 hare@suse.de
- nbd: fix possible page fault for nbd disk
  (bsc#1175995,jsc#SLE-15608).
- commit 0f0f48c
* Mon Sep 14 2020 hare@suse.de
- nbd: rename the runtime flags as NBD_RT_ prefixed
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/nbd-Fix-memory-leak-in-nbd_add_socket.patch.
- commit 2e3ce4a
* Mon Sep 14 2020 hare@suse.de
- nbd: fix zero cmd timeout handling v2
  (bsc#1175995,jsc#SLE-15608).
- nbd: add function to convert blk req op to nbd cmd
  (bsc#1175995,jsc#SLE-15608).
- nbd: add set cmd timeout helper (bsc#1175995,jsc#SLE-15608).
- commit 02c86ee
* Mon Sep 14 2020 hare@suse.de
- block: optimise bvec_iter_advance() (bsc#1175995,jsc#SLE-15608).
- bdi: Do not use freezable workqueue (bsc#1175995,jsc#SLE-15608).
- block: pg: add header include guard (bsc#1175995,jsc#SLE-15608).
- scsi: core: remove dummy q->dev check
  (bsc#1175995,jsc#SLE-15608).
- lightnvm: print error when target is not found
  (bsc#1175995,jsc#SLE-15608).
- lightnvm: introduce pr_fmt for the prefix nvm
  (bsc#1175995,jsc#SLE-15608).
- writeback: don't access page->mapping directly in
  track_foreign_dirty TP (bsc#1175995,jsc#SLE-15608).
- writeback: add tracepoints for cgroup foreign writebacks
  (bsc#1175995,jsc#SLE-15608).
- writeback, cgroup: inode_switch_wbs() shouldn't give up on
  wb_switch_rwsem trylock fail (bsc#1175995,jsc#SLE-15608).
- writeback, cgroup: Adjust WB_FRN_TIME_CUT_DIV to accelerate
  foreign inode switching (bsc#1175995,jsc#SLE-15608).
- lightnvm: remove unused 'geo' variable
  (bsc#1175995,jsc#SLE-15608).
- lib: scatterlist: Fix to support no mapped sg
  (bsc#1175995,jsc#SLE-15608).
- lightnvm: remove set but not used variables 'data_len' and
  'rq_len' (bsc#1175995,jsc#SLE-15608).
- commit f22a41f
* Mon Sep 14 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move to sorted section:
  patches.suse/edac-ghes-setup-dimm-label-from-dmi-and-use-it-in-error-reports.patch
  patches.suse/edac-i10nm-update-driver-to-support-different-bus-number-config-register-offsets.patch
  patches.suse/edac-skx-i10nm-make-some-configurations-cpu-model-specific.patch
  patches.suse/firmware_loader-fix-memory-leak-for-paged-buffer.patch
  patches.suse/net-packet-fix-overflow-in-tpacket_rcv.patch
  patches.suse/x86-cpu-add-a-steppings-field-to-struct-x86_cpu_id.patch
  patches.suse/x86-cpu-add-table-argument-to-cpu_matches.patch
  patches.suse/x86-smpboot-remove-the-last-icpu-macro.patch
  patches.suse/x86-speculation-add-special-register-buffer-data-sampling-srbds-mitigation.patch
  patches.suse/x86-speculation-add-srbds-vulnerability-and-mitigation-documentation.patch
- move mainline backports into sorted section:
  patches.suse/revert-zram-convert-remaining-class_attr-to-class_attr_ro
  patches.suse/vgacon-fix-out-of-bounds-write-to-the-scrollback-buf.patch
  No effect on expanded tree.
- commit 0435bb2
* Sun Sep 13 2020 colyli@suse.de
- md/raid5: make sure stripe_size as power of two (jsc#SLE-13984).
- md: get sysfs entry after redundancy attr group create
  (jsc#SLE-13984).
- md: remove the kernel version of md_u.h (jsc#SLE-13984).
- md/raid5: Allow degraded raid6 to do rmw (jsc#SLE-13984).
- raid5: don't duplicate code for different paths in handle_stripe
  (jsc#SLE-13984).
- raid5-cache: hold spinlock instead of mutex in
  r5c_journal_mode_show (jsc#SLE-13984).
- commit d9e8fce
* Sun Sep 13 2020 colyli@suse.de
- md: print errno in super_written (jsc#SLE-13984).
- Refresh for the above change,
  patches.suse/md-display-timeout-error.patch.
- commit f15181b
* Sun Sep 13 2020 colyli@suse.de
- md/raid5: remove the redundant setting of STRIPE_HANDLE
  (jsc#SLE-13984).
- md: register new md sysfs file 'uuid' read-only (jsc#SLE-13984).
- md: fix max sectors calculation for super 1.0 (jsc#SLE-13984).
- md/raid5: use do_div() for 64 bit divisions in
  raid5_sync_request (jsc#SLE-13984).
- md/raid10: avoid deadlock on recovery (jsc#SLE-13984).
- raid: md_p.h: drop duplicated word in a comment (jsc#SLE-13984).
- md-cluster: fix rmmod issue when md_cluster convert bitmap to
  none (jsc#SLE-13984).
- md-cluster: fix safemode_delay value when converting to
  clustered bitmap (jsc#SLE-13984).
- md/raid5: support config stripe_size by sysfs entry
  (jsc#SLE-13984).
- md/raid5: set default stripe_size as 4096 (jsc#SLE-13984).
- commit 0b2ec9a
* Sun Sep 13 2020 colyli@suse.de
- md/raid456: convert macro STRIPE_* to RAID5_STRIPE_*
  (jsc#SLE-13984).
- Refresh for the above change,
  patches.suse/mdraid-fix-read-write-bytes-accounting.patch.
- commit 93078c6
* Sun Sep 13 2020 colyli@suse.de
- raid5: remove the meaningless check in raid5_make_request
  (jsc#SLE-13984).
- raid5: put the comment of clear_batch_ready to the right place
  (jsc#SLE-13984).
- raid5: call clear_batch_ready before set STRIPE_ACTIVE
  (jsc#SLE-13984).
- md: raid10: Fix compilation warning (jsc#SLE-13984).
- md: raid5: Fix compilation warning (jsc#SLE-13984).
- md: raid5-cache: Remove set but unused variable (jsc#SLE-13984).
- md: Fix compilation warning (jsc#SLE-13984).
- md-cluster: fix wild pointer of unlock_all_bitmaps()
  (jsc#SLE-13984).
- md/raid5-cache: clear MD_SB_CHANGE_PENDING before flushing
  stripes (jsc#SLE-13984).
- md: fix deadlock causing by sysfs_notify (jsc#SLE-13984).
- commit 33fc6ee
* Sun Sep 13 2020 colyli@suse.de
- md: raid0/linear: fix dereference before null check on pointer
  mddev (jsc#SLE-13984).
- commit ef43a0a
* Sun Sep 13 2020 colyli@suse.de
- md: switch to ->check_events for media change notifications
  (jsc#SLE-13984).
- commit 6feca60
* Sun Sep 13 2020 colyli@suse.de
- md/raid1: Replace zero-length array with flexible-array
  (jsc#SLE-13984).
- Refresh for the above change,
  patches.suse/md-display-timeout-error.patch.
- commit 3d214f8
* Sun Sep 13 2020 colyli@suse.de
- md: add a newline when printing parameter 'start_ro' by sysfs
  (jsc#SLE-13984).
- commit 39a4f77
* Sun Sep 13 2020 colyli@suse.de
- md: stop using ->queuedata (jsc#SLE-13984).
- Refresh for the above change,
  patches.suse/mdraid-fix-read-write-bytes-accounting.patch.
- commit 069a94e
* Sun Sep 13 2020 colyli@suse.de
- md/raid1: release pending accounting for an I/O only after
  write-behind is also finished (jsc#SLE-13984).
- md: remove redundant memalloc scope API usage (jsc#SLE-13984).
- raid5: update code comment of scribble_alloc() (jsc#SLE-13984).
- md: remove the extra line for ->hot_add_disk (jsc#SLE-13984).
- md: flush md_rdev_misc_wq for HOT_ADD_DISK case (jsc#SLE-13984).
- md: don't flush workqueue unconditionally in md_open
  (jsc#SLE-13984).
- md: add new workqueue for delete rdev (jsc#SLE-13984).
- md: add checkings before flush md_misc_wq (jsc#SLE-13984).
- md: remove __clear_page_buffers and use
  attach/detach_page_private (jsc#SLE-13984).
- include/linux/pagemap.h: introduce attach/detach_page_private
  (jsc#SLE-13984).
- md: check arrays is suspended in mddev_detach before call
  quiesce operations (jsc#SLE-13984).
- fs: Enable bmap() function to properly return errors
  (jsc#SLE-13984).
- md/raid1: introduce wait_for_serialization (jsc#SLE-13984).
- md/raid1: use bucket based mechanism for IO serialization
  (jsc#SLE-13984).
- md: introduce a new struct for IO serialization (jsc#SLE-13984).
- md: don't destroy serial_info_pool if serialize_policy is true
  (jsc#SLE-13984).
- raid1: serialize the overlap write (jsc#SLE-13984).
- md: reorgnize mddev_create/destroy_serial_pool (jsc#SLE-13984).
- md: add serialize_policy sysfs node for raid1 (jsc#SLE-13984).
- md: prepare for enable raid1 io serialization (jsc#SLE-13984).
- drivers/md/raid5-ppl.c: use the new spelling of
  RWH_WRITE_LIFE_NOT_SET (jsc#SLE-13984).
- commit d6eaca4
* Fri Sep 11 2020 trenn@suse.com
- cpufreq: intel_pstate: Add one more OOB control bit
  (jsc#SLE-13596).
- commit 371914e
* Fri Sep 11 2020 tbogendoerfer@suse.de
- qlge: Fix build error without CONFIG_ETHERNET (jsc#SLE-15139).
- commit 87b5d37
* Fri Sep 11 2020 hare@suse.de
- block: change REQ_OP_ZONE_RESET and REQ_OP_ZONE_RESET_ALL to
  (bsc#1175995,jsc#SLE-15608).
- block: integrate bd_start_claiming into __blkdev_get
  (bsc#1175995,jsc#SLE-15608).
- block: use bd_prepare_to_claim directly in the loop driver
  (bsc#1175995,jsc#SLE-15608).
- block: refactor bd_start_claiming (bsc#1175995,jsc#SLE-15608).
- commit 8336fd1
* Fri Sep 11 2020 hare@suse.de
- block: simplify the restart case in __blkdev_get
  (bsc#1175995,jsc#SLE-15608).
- temporarily disable patches.suse/bdev-add-open-finish.patch
- commit ded7f4c
* Fri Sep 11 2020 hare@suse.de
- block: always remove partitions from blk_drop_partitions()
  (bsc#1175995,jsc#SLE-15608).
- commit de6c3f7
* Fri Sep 11 2020 tbogendoerfer@suse.de
- gianfar: remove forward declarations (bsc#1176447).
- commit efbc835
* Fri Sep 11 2020 hare@suse.de
- writeback: remove bdi->congested_fn (bsc#1175995,jsc#SLE-15608).
- writeback: remove struct bdi_writeback_congested
  (bsc#1175995,jsc#SLE-15608).
- writeback: remove {set,clear}_wb_congested
  (bsc#1175995,jsc#SLE-15608).
- drbd: remove a bogus bdi_rw_congested call
  (bsc#1175995,jsc#SLE-15608).
- mmc: remove the call to check_disk_change
  (bsc#1175995,jsc#SLE-15608).
- xtensa/simdisk: remove the call to check_disk_change
  (bsc#1175995,jsc#SLE-15608).
- isofs: remove a stale comment (bsc#1175995,jsc#SLE-15608).
- block: remove flush_disk (bsc#1175995,jsc#SLE-15608).
- cdrom: remove the unused cdrom_media_changed function
  (bsc#1175995,jsc#SLE-15608).
- commit ea5de40
* Fri Sep 11 2020 hare@suse.de
- block: remove a bogus warning in __submit_bio_noacct_mq
  (bsc#1175995,jsc#SLE-15608).
- block: initialize current->bio_list[1] in
  (bsc#1175995,jsc#SLE-15608).
- dm: remove unused variable (bsc#1175995,jsc#SLE-15608).
- sbitmap: Consider cleared bits in sbitmap_bitmap_show()
  (bsc#1175995,jsc#SLE-15608).
- docs: block: update and fix tiny error for bfq
  (bsc#1175995,jsc#SLE-15608).
- commit 11634d2
* Fri Sep 11 2020 hare@suse.de
- block: remove the all_bdevs list (bsc#1175995,jsc#SLE-15608).
- block: remove the unused bd_private field from struct
  (bsc#1175995,jsc#SLE-15608).
- commit d9a7037
* Fri Sep 11 2020 hare@suse.de
- block: remove the bd_queue field from struct block_device
  (bsc#1175995,jsc#SLE-15608).
- commit 0349491
* Fri Sep 11 2020 hare@suse.de
- mm, swap: disallow swapon() on zoned block devices
  (bsc#1175995,jsc#SLE-15608).
- commit 84148c6
* Fri Sep 11 2020 tbogendoerfer@suse.de
- netdev: pass the stuck queue to the timeout handler
  (jsc#SLE-13536).
- Refresh patches.suse/sfc-move-various-functions.patch.
- commit a9067ff
* Fri Sep 11 2020 tbogendoerfer@suse.de
- ethtool: move to its own directory (bsc#1176447).
- Refresh
  patches.suse/ethtool-Factored-out-similar-ethtool-link-settings-f.patch.
- commit f7aabdb
* Fri Sep 11 2020 tbogendoerfer@suse.de
- igb: use eth_zero_addr() to clear mac address (jsc#SLE-13536).
- igb: Remove unnecessary usages of memset (jsc#SLE-13536).
- igbvf: use generic power management (jsc#SLE-13536).
- ptp: introduce a phase offset in the periodic output request
  (bsc#1176447).
- ptp: add ability to configure duty cycle for periodic output
  (bsc#1176447).
- ethernet/intel: Convert fallthrough code comments
  (jsc#SLE-13536).
- igb: reinit_locked() should be called with rtnl_lock
  (jsc#SLE-13536).
- igb: make igb_set_fc_watermarks() return void (jsc#SLE-13536).
- igb: Report speed and duplex as unknown when device is runtime
  suspended (jsc#SLE-13536).
- ptp: Add adjust_phase to ptp_clock_caps capability
  (bsc#1176447).
- ptp: Add adjphase function to support phase offset control
  (bsc#1176447).
- igb: convert to use i2c_new_client_device() (jsc#SLE-13536).
- net: igbvf: reject unsupported coalescing params
  (jsc#SLE-13536).
- net: igb: let core reject the unsupported coalescing parameters
  (jsc#SLE-13536).
- ethtool: add infrastructure for centralized checking of
  coalescing parameters (jsc#SLE-13536).
- intel: Replace zero-length array with flexible-array member
  (jsc#SLE-13536).
- ethtool: provide link mode names as a string set (bsc#1176447).
- ethtool: move string arrays into common file (bsc#1176447).
- staging: qlge: Avoid NULL comparison (jsc#SLE-15139).
- Staging: qlge: Rewrite two while loops as simple for loops
  (jsc#SLE-15139).
- igb: Reject requests that fail to enable time stamping on both
  edges (jsc#SLE-13536).
- ptp: Introduce strict checking of external time stamp options
  (bsc#1176447).
- renesas: reject unsupported external timestamp flags
  (bsc#1176447).
- mlx5: reject unsupported external timestamp flags
  (jsc#SLE-13536).
- igb: reject unsupported external timestamp flags
  (jsc#SLE-13536).
- dp83640: reject unsupported external timestamp flags
  (jsc#SLE-13536).
- mv88e6xxx: reject unsupported external timestamp flags
  (jsc#SLE-13536).
- net: reject PTP periodic output requests with unsupported flags
  (bsc#1176447).
- ptp: Validate requests to enable time stamping of external
  signals (bsc#1176447).
- ptp: correctly disable flags on old ioctls (bsc#1176447).
- PTP: add support for one-shot output (bsc#1176447).
- PTP: introduce new versions of IOCTLs (bsc#1176447).
- net: dsa: mv88e6xxx: add PTP support for MV88E6250 family
  (jsc#SLE-13536).
- net: dsa: mv88e6xxx: order ptp structs numerically ascending
  (jsc#SLE-13536).
- net: dsa: mv88e6xxx: setup message port is not supported in
  the 6250 familiy (jsc#SLE-13536).
- net: dsa: mv88e6xxx: introduce invalid_port_mask in
  mv88e6xxx_info (jsc#SLE-13536).
- net: dsa: mv88e6xxx: add support for MV88E6220 (jsc#SLE-13536).
- net: dsa: mv88e6xxx: call vtu_getnext directly in vlan_add
  (jsc#SLE-13536).
- net: dsa: mv88e6xxx: call vtu_getnext directly in vlan_del
  (jsc#SLE-13536).
- net: dsa: mv88e6xxx: call vtu_getnext directly in db load/purge
  (jsc#SLE-13536).
- net: dsa: mv88e6xxx: explicit entry passed to vtu_getnext
  (jsc#SLE-13536).
- net: dsa: mv88e6xxx: lock mutex in vlan_prepare (jsc#SLE-13536).
- net: dsa: mv88e6xxx: avoid some redundant vtu load/purge
  operations (jsc#SLE-13536).
- commit 3cb4ee5
* Fri Sep 11 2020 hare@suse.de
- block: remove the bd_block_size field from struct
  (bsc#1175995,jsc#SLE-15608).
- commit 7214ff1
* Fri Sep 11 2020 hare@suse.de
- block: simplify set_init_blocksize (bsc#1175995,jsc#SLE-15608).
- dcssblk: don't set bd_block_size in ->open
  (bsc#1175995,jsc#SLE-15608).
- floppy: use block_size (bsc#1175995,jsc#SLE-15608).
- commit 9020cc3
* Fri Sep 11 2020 hare@suse.de
- block: remove direct_make_request (bsc#1175995,jsc#SLE-15608).
- block: shortcut __submit_bio_noacct for blk-mq drivers
  (bsc#1175995,jsc#SLE-15608).
- block: refator submit_bio_noacct (bsc#1175995,jsc#SLE-15608).
- commit bd09ba5
* Fri Sep 11 2020 hare@suse.de
- dm mpath: pass IO start time to path selector
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/dm-do-not-use-waitqueue-for-request-based-dm.
- Refresh patches.suse/dm-mpath-leastpending-path-update.
- commit bf30dd1
* Fri Sep 11 2020 fdmanana@suse.com
- btrfs: reset tree root pointer after error in init_tree_roots
  (bsc#1176019).
- commit d323df2
* Fri Sep 11 2020 hare@suse.de
- block: rename generic_make_request to submit_bio_noacct
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/mdraid-fix-read-write-bytes-accounting.patch.
- commit 52119bc
* Fri Sep 11 2020 hare@suse.de
- dm writecache: add cond_resched to loop in
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: Fix reclaim zone selection
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: Fix random zone reclaim selection
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: Fix metadata zone size check
  (bsc#1175995,jsc#SLE-15608).
- dm ioctl: use struct_size() helper in retrieve_deps()
  (bsc#1175995,jsc#SLE-15608).
- dm writecache: skip writecache_wait when using pmem mode
  (bsc#1175995,jsc#SLE-15608).
- dm writecache: correct uncommitted_block when discarding
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: assign max_io_len correctly
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: fix uninitialized pointer dereference
  (bsc#1175995,jsc#SLE-15608).
- commit bf80b71
* Fri Sep 11 2020 hare@suse.de
- dm crypt: avoid truncating the logical block size
  (bsc#1175995,jsc#SLE-15608).
- dm mpath: add DM device name to Failing/Reinstating path log
  (bsc#1175995,jsc#SLE-15608).
- dm mpath: enhance queue_if_no_path debugging
  (bsc#1175995,jsc#SLE-15608).
- dm mpath: restrict queue_if_no_path state machine
  (bsc#1175995,jsc#SLE-15608).
- dm mpath: simplify __must_push_back (bsc#1175995,jsc#SLE-15608).
- dm zoned: check superblock location (bsc#1175995,jsc#SLE-15608).
- dm zoned: prefer full zones for reclaim
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: select reclaim zone based on device index
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: allocate zone by device index
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: support arbitrary number of devices
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: move random and sequential zones into struct
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: per-device reclaim (bsc#1175995,jsc#SLE-15608).
- dm zoned: add metadata pointer to struct dmz_dev
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: add device pointer to struct dm_zone
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: allocate temporary superblock for tertiary devices
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: convert to xarray (bsc#1175995,jsc#SLE-15608).
- dm zoned: add a 'reserved' zone flag
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: improve logging messages for reclaim
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: avoid unnecessary device recalulation for secondary
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: add debugging message for reading superblocks
  (bsc#1175995,jsc#SLE-15608).
- dm ebs: use dm_bufio_forget_buffers (bsc#1175995,jsc#SLE-15608).
- dm bufio: introduce forget_buffer_locked
  (bsc#1175995,jsc#SLE-15608).
- dm bufio: clean up rbtree block ordering
  (bsc#1175995,jsc#SLE-15608).
- dm bufio: delete unused and inefficient
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: remove leftover hunk for switching to sequential
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: terminate reclaim on congestion
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: start reclaim with sequential zones
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: reclaim random zones when idle
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: separate random and cache zones
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: return NULL if dmz_get_zone_for_reclaim() fails to
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: Avoid 64-bit division error in dmz_fixup_devices
  (bsc#1175995,jsc#SLE-15608).
- dm: use DMDEBUG macros now that they use pr_debug variants
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: remove spurious newlines from debugging messages
  (bsc#1175995,jsc#SLE-15608).
- dm: replace zero-length array with flexible-array
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: metadata version 2 (bsc#1175995,jsc#SLE-15608).
- dm zoned: ignore metadata zone in dmz_alloc_zone()
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: Reduce logging output on startup
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: add metadata logging functions
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: use dmz_zone_to_dev() when handling metadata I/O
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: replace 'target' pointer in the bio context
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: remove 'dev' argument from reclaim
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: Introduce dmz_dev_is_dying() and dmz_check_dev()
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: introduce dmz_metadata_label() to format device
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: move fields from struct dmz_dev to dmz_metadata
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: store device in struct dmz_sb
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: use array for superblock zones
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: store zone id within the zone structure and kill
  (bsc#1175995,jsc#SLE-15608).
- dm zoned: add 'message' callback (bsc#1175995,jsc#SLE-15608).
- dm zoned: add 'status' callback (bsc#1175995,jsc#SLE-15608).
- commit 3936716
* Fri Sep 11 2020 fdmanana@suse.com
- btrfs: rename btrfs_put_fs_root and btrfs_grab_fs_root
  (bsc#1176019).
- Refresh
  patches.suse/0001-btrfs-reloc-fix-reloc-root-leak-and-NULL-pointer-der.patch.
- Refresh
  patches.suse/0002-btrfs-reloc-clear-DEAD_RELOC_TREE-bit-for-orphan-roo.patch.
- Refresh
  patches.suse/btrfs-fix-corrupt-log-due-to-concurrent-fsync-of-ino.patch.
- commit 6d38357
* Fri Sep 11 2020 hare@suse.de
- dm verity: add root hash pkcs#7 signature verification
  (bsc#1175995,jsc#SLE-15608).
- Update config files: enable DM_VERITY_VERIFY_ROOTHASH_SIG
- commit 19d995f
* Fri Sep 11 2020 hare@suse.de
- dm mpath: Add timeout mechanism for queue_if_no_path
  (bsc#1175995,jsc#SLE-15608).
- commit 6e2660c
* Fri Sep 11 2020 nsaenzjulienne@suse.de
- thunderbolt: merge fix for kunix_resource changes
  (jsc#SLE-14130).
- thunderbolt: Fix old style declaration warning (jsc#SLE-14130).
- thunderbolt: Add support for authenticate on disconnect
  (jsc#SLE-14130).
- thunderbolt: Add support for separating the flush to SPI and
  authenticate (jsc#SLE-14130).
- thunderbolt: Ensure left shift of 512 does not overflow a 32
  bit int (jsc#SLE-14130).
- thunderbolt: Add support for on-board retimers (jsc#SLE-14130).
- thunderbolt: Implement USB4 port sideband operations for
  retimer access (jsc#SLE-14130).
- thunderbolt: Retry USB4 block read operation (jsc#SLE-14130).
- thunderbolt: Generalize usb4_switch_do_[read|write]_data()
  (jsc#SLE-14130).
- thunderbolt: Split common NVM functionality into a separate file
  (jsc#SLE-14130).
- thunderbolt: Add Intel USB-IF ID to the NVM upgrade supported
  list (jsc#SLE-14130).
- thunderbolt: Add KUnit tests for tunneling (jsc#SLE-14130).
- thunderbolt: Add USB3 bandwidth management (jsc#SLE-14130).
- thunderbolt: Make tb_port_get_link_speed() available to other
  files (jsc#SLE-14130).
- thunderbolt: Implement USB3 bandwidth negotiation routines
  (jsc#SLE-14130).
- thunderbolt: Increase DP DPRX wait timeout (jsc#SLE-14130).
- thunderbolt: Report consumed bandwidth in both directions
  (jsc#SLE-14130).
- thunderbolt: Make usb4_switch_map_pcie_down() also return
  enabled ports (jsc#SLE-14130).
- thunderbolt: Make usb4_switch_map_usb3_down() also return
  enabled ports (jsc#SLE-14130).
- thunderbolt: Do not tunnel USB3 if link is not USB4
  (jsc#SLE-14130).
- thunderbolt: Add DP IN resources for all routers
  (jsc#SLE-14130).
- thunderbolt: Add KUnit tests for path walking (jsc#SLE-14130).
- thunderbolt: Increase path length in discovery (jsc#SLE-14130).
- thunderbolt: Handle incomplete PCIe/USB3 paths correctly in
  discovery (jsc#SLE-14130).
- thunderbolt: Check that both ports are reachable when allocating
  path (jsc#SLE-14130).
- thunderbolt: Make tb_path_alloc() work with tree topologies
  (jsc#SLE-14130).
- thunderbolt: Make tb_next_port_on_path() work with tree
  topologies (jsc#SLE-14130).
- thunderbolt: Get rid of E2E workaround (jsc#SLE-14130).
- thunderbolt: NHI can use HopIDs 1-7 (jsc#SLE-14130).
- thunderbolt: No need to warn if NHI hop_count != 12 or hop_count
  != 32 (jsc#SLE-14130).
- thunderbolt: Build initial XDomain property block upon first
  connect (jsc#SLE-14130).
- thunderbolt: Improve USB4 config symbol help text
  (jsc#SLE-14130).
- commit 6f9f7c3
* Fri Sep 11 2020 hare@suse.de
- dm persistent data: switch exit_ro_spine to return void
  (bsc#1175995,jsc#SLE-15608).
- dm integrity: remove set but not used variables
  (bsc#1175995,jsc#SLE-15608).
- dm ebs: pass discards down to underlying device
  (bsc#1175995,jsc#SLE-15608).
- dm bufio: implement discard (bsc#1175995,jsc#SLE-15608).
- dm mpath: switch paths in dm_blk_ioctl() code path
  (bsc#1175995,jsc#SLE-15608).
- dm crypt: support using encrypted keys
  (bsc#1175995,jsc#SLE-15608).
- commit 10b5ba2
* Fri Sep 11 2020 fdmanana@suse.com
- btrfs: add a leak check for roots (bsc#1176019).
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch.
- commit 331ee79
* Fri Sep 11 2020 hare@suse.de
- dm multipath: use updated MPATHF_QUEUE_IO on mapping for
  (bsc#1175995,jsc#SLE-15608).
- dm integrity: fix logic bug in integrity tag testing
  (bsc#1175995,jsc#SLE-15608).
- dm integrity: fix ppc64le warning (bsc#1175995,jsc#SLE-15608).
- commit 81513cc
* Fri Sep 11 2020 hare@suse.de
- dm clone metadata: Fix return type of
  (bsc#1175995,jsc#SLE-15608).
- dm clone: Add missing casts to prevent overflows and data
  (bsc#1175995,jsc#SLE-15608).
- dm clone: Add overflow check for number of regions
  (bsc#1175995,jsc#SLE-15608).
- dm clone: Fix handling of partial region discards
  (bsc#1175995,jsc#SLE-15608).
- dm integrity: improve discard in journal mode
  (bsc#1175995,jsc#SLE-15608).
- dm integrity: add optional discard support
  (bsc#1175995,jsc#SLE-15608).
- dm integrity: allow resize of the integrity device
  (bsc#1175995,jsc#SLE-15608).
- dm integrity: factor out get_provided_data_sectors()
  (bsc#1175995,jsc#SLE-15608).
- dm integrity: don't replay journal data past the end of the
  (bsc#1175995,jsc#SLE-15608).
- dm integrity: remove sector type casts
  (bsc#1175995,jsc#SLE-15608).
- dm writecache: optimize superblock write
  (bsc#1175995,jsc#SLE-15608).
- dm writecache: implement gradual cleanup
  (bsc#1175995,jsc#SLE-15608).
- dm writecache: implement the "cleaner" policy
  (bsc#1175995,jsc#SLE-15608).
- dm writecache: do direct write if the cache is full
  (bsc#1175995,jsc#SLE-15608).
- commit a548ee3
* Fri Sep 11 2020 hare@suse.de
- dm writecache: improve performance of large linear writes on
  SSDs (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/0024-dm-writecache-verify-watermark-during-resume.patch.
- commit 2cee40d
* Fri Sep 11 2020 hare@suse.de
- dm integrity: print device name in integrity_metadata() error
  (bsc#1175995,jsc#SLE-15608).
- dm crypt: use crypt_integrity_aead() helper
  (bsc#1175995,jsc#SLE-15608).
- commit e7d5f36
* Fri Sep 11 2020 hare@suse.de
- dm: bump version of core and various targets
  (bsc#1175995,jsc#SLE-15608).
- dm integrity: use dm_bio_record and dm_bio_restore
  (bsc#1175995,jsc#SLE-15608).
- dm bio record: save/restore bi_end_io and bi_integrity
  (bsc#1175995,jsc#SLE-15608).
- commit 4321ad8
* Fri Sep 11 2020 hare@suse.de
- dm thin: change data device's flush_bio to be member of struct
  pool (bsc#1175995,jsc#SLE-15608).
- commit 48f9ea3
* Fri Sep 11 2020 hare@suse.de
- dm thin: fix use-after-free in metadata_pre_commit_callback
  (bsc#1175995,jsc#SLE-15608).
- blacklist.conf: remove patch from blacklist
- commit 1b460bb
* Fri Sep 11 2020 hare@suse.de
- dm thin: don't allow changing data device during thin-pool
  (bsc#1175995,jsc#SLE-15608).
- commit e25bd2d
* Fri Sep 11 2020 hare@suse.de
- dm crypt: Implement Elephant diffuser for Bitlocker
  (bsc#1175995,jsc#SLE-15608).
- dm verity: don't prefetch hash blocks for already-verified
  (bsc#1175995,jsc#SLE-15608).
- dm crypt: fix GFP flags passed to skcipher_request_alloc()
  (bsc#1175995,jsc#SLE-15608).
- dm thin metadata: Fix trivial math error in on-disk format
  (bsc#1175995,jsc#SLE-15608).
- dm thin metadata: use true/false for bool variable
  (bsc#1175995,jsc#SLE-15608).
- dm snapshot: use true/false for bool variable
  (bsc#1175995,jsc#SLE-15608).
- dm bio prison v2: use true/false for bool variable
  (bsc#1175995,jsc#SLE-15608).
- dm mpath: use true/false for bool variable
  (bsc#1175995,jsc#SLE-15608).
- dm raid: table line rebuild status fixes
  (bsc#1175995,jsc#SLE-15608).
- dm dust: change ret to r in dust_map_write
  (bsc#1175995,jsc#SLE-15608).
- commit afc3023
* Fri Sep 11 2020 hare@suse.de
- dm clone: Flush destination device before committing metadata
  (bsc#1175995,jsc#SLE-15608).
- dm clone metadata: Use a two phase commit
  (bsc#1175995,jsc#SLE-15608).
- dm clone metadata: Track exact changes per transaction
  (bsc#1175995,jsc#SLE-15608).
- commit a2a9cfa
* Fri Sep 11 2020 hare@suse.de
- dm: Fix Kconfig indentation (bsc#1175995,jsc#SLE-15608).
- dm thin: wakeup worker only when deferred bios exist
  (bsc#1175995,jsc#SLE-15608).
- dm integrity: fix excessive alignment of metadata runs
  (bsc#1175995,jsc#SLE-15608).
- dm raid: Remove unnecessary negation of a shift in
  (bsc#1175995,jsc#SLE-15608).
- dm dust: add limited write failure mode
  (bsc#1175995,jsc#SLE-15608).
- dm dust: change ret to r in dust_map_read and dust_map
  (bsc#1175995,jsc#SLE-15608).
- dm dust: change result vars to r (bsc#1175995,jsc#SLE-15608).
- dm cache: replace spin_lock_irqsave with spin_lock_irq
  (bsc#1175995,jsc#SLE-15608).
- dm bio prison: replace spin_lock_irqsave with spin_lock_irq
  (bsc#1175995,jsc#SLE-15608).
- dm thin: replace spin_lock_irqsave with spin_lock_irq
  (bsc#1175995,jsc#SLE-15608).
- dm clone: add bucket_lock_irq/bucket_unlock_irq helpers
  (bsc#1175995,jsc#SLE-15608).
- dm clone: replace spin_lock_irqsave with spin_lock_irq
  (bsc#1175995,jsc#SLE-15608).
- dm writecache: fix uninitialized variable warning
  (bsc#1175995,jsc#SLE-15608).
- dm stripe: use struct_size() in kmalloc()
  (bsc#1175995,jsc#SLE-15608).
- dm raid: streamline rs_get_progress() and its raid_status()
  (bsc#1175995,jsc#SLE-15608).
- dm raid: simplify rs_setup_recovery call chain
  (bsc#1175995,jsc#SLE-15608).
- dm raid: to ensure resynchronization, perform raid set grow
  (bsc#1175995,jsc#SLE-15608).
- dm raid: change rs_set_dev_and_array_sectors API and callers
  (bsc#1175995,jsc#SLE-15608).
- dm table: do not allow request-based DM to stack on
  (bsc#1175995,jsc#SLE-15608).
- dm clone: Make __hash_find static (bsc#1175995,jsc#SLE-15608).
- commit 6079524
* Fri Sep 11 2020 hare@suse.de
- dm: introduce DM_GET_TARGET_VERSION (bsc#1175995,jsc#SLE-15608).
- dm bufio: introduce a global cache replacement
  (bsc#1175995,jsc#SLE-15608).
- dm bufio: remove old-style buffer cleanup
  (bsc#1175995,jsc#SLE-15608).
- dm bufio: introduce a global queue (bsc#1175995,jsc#SLE-15608).
- dm bufio: refactor adjust_total_allocated
  (bsc#1175995,jsc#SLE-15608).
- dm bufio: call adjust_total_allocated from __link_buffer and
  (bsc#1175995,jsc#SLE-15608).
- commit 5403b07
* Fri Sep 11 2020 fdmanana@suse.com
- btrfs: make the init of static elements in fs_info separate
  (bsc#1176019).
- commit e201abc
* Fri Sep 11 2020 hare@suse.de
- dm writecache: skip writecache_wait for pmem mode
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/0014-dm-writecache-fix-incorrect-flush-sequence-when-doin.patch.
- commit ad60cb5
* Fri Sep 11 2020 hare@suse.de
- dm stats: use struct_size() helper (bsc#1175995,jsc#SLE-15608).
- dm crypt: omit parsing of the encapsulated cipher
  (bsc#1175995,jsc#SLE-15608).
- dm crypt: switch to ESSIV crypto API template
  (bsc#1175995,jsc#SLE-15608).
- dm space map common: remove check for impossible
  (bsc#1175995,jsc#SLE-15608).
- dm raid1: use struct_size() with kzalloc()
  (bsc#1175995,jsc#SLE-15608).
- commit eb38a31
* Fri Sep 11 2020 hare@suse.de
- dm writecache: optimize performance by sorting the blocks for
  (bsc#1175995,jsc#SLE-15608).
- dm writecache: add unlikely for getting two block with same
  (bsc#1175995,jsc#SLE-15608).
- dm writecache: remove unused member pointer in
  (bsc#1175995,jsc#SLE-15608).
- commit 85a30b6
* Fri Sep 11 2020 nsaenzjulienne@suse.de
- thunderbolt: Fix path indices used in USB3 tunnel discovery
  (jsc#SLE-14130).
- blacklist.conf: 8b94a4b92327 ("thunderbolt: Fix path indices used in USB3 tunnel discovery")
- PCI: Make pcie_find_root_port() work for Root Ports
  (jsc#SLE-14130).
- commit b683018
* Fri Sep 11 2020 hare@suse.de
- dm crypt: reuse eboiv skcipher for IV generation
  (bsc#1175995,jsc#SLE-15608).
- commit a93f863
* Fri Sep 11 2020 nsaenzjulienne@suse.de
- thunderbolt: Add trivial .shutdown (jsc#SLE-14130).
- thunderbolt: Update Kconfig to allow building on other
  architectures (jsc#SLE-14130).
- thunderbolt: Add support for Intel Tiger Lake (jsc#SLE-13135).
- Revert "thunderbolt: Prevent crash if non-active NVMem file
  is read" (jsc#SLE-14130).
- PCI: Unify pcie_find_root_port() and pci_find_pcie_root_port()
  (jsc#SLE-14130).
- thunderbolt: Check return value of tb_sw_read() in
  usb4_switch_op() (jsc#SLE-14130).
- thunderbolt: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-14130).
- thunderbolt: icm: Replace zero-length array with flexible-array
  member (jsc#SLE-14130).
- thunderbolt: eeprom: Replace zero-length array with
  flexible-array member (jsc#SLE-14130).
- thunderbolt: Add missing kernel-doc parameter descriptions
  (jsc#SLE-14130).
- thunderbolt: Fix error code in tb_port_is_width_supported()
  (jsc#SLE-14130).
- thunderbolt: fix memory leak of object sw (jsc#SLE-14130).
- thunderbolt: Fix xhci check in usb4_switch_setup()
  (jsc#SLE-14130).
- thunderbolt: Add support for USB 3.x tunnels (jsc#SLE-14130).
- thunderbolt: Add support for Time Management Unit
  (jsc#SLE-14130).
- thunderbolt: Make tb_switch_find_cap() available to other files
  (jsc#SLE-14130).
- thunderbolt: Update Kconfig entries to USB4 (jsc#SLE-14130).
- Update config files: Sync with new USB4/Thunderbolt Kconfig symbols
- thunderbolt: Add initial support for USB4 (jsc#SLE-14130).
- thunderbolt: Populate PG field in hot plug acknowledgment packet
  (jsc#SLE-14130).
- thunderbolt: Call tb_eeprom_get_drom_offset() from
  tb_eeprom_read_n() (jsc#SLE-14130).
- thunderbolt: Make tb_find_port() available to other files
  (jsc#SLE-14130).
- thunderbolt: Do not start firmware unless asked by the user
  (jsc#SLE-14130).
- thunderbolt: Add bandwidth management for Display Port tunnels
  (jsc#SLE-14130).
- thunderbolt: Add Display Port adapter pairing and resource
  management (jsc#SLE-14130).
- thunderbolt: Add Display Port CM handshake for Titan Ridge
  devices (jsc#SLE-14130).
- thunderbolt: Add downstream PCIe port mappings for Alpine and
  Titan Ridge (jsc#SLE-14130).
- thunderbolt: Expand controller name in tb_switch_is_xy()
  (jsc#SLE-14130).
- thunderbolt: Add default linking between lane adapters if not
  provided by DROM (jsc#SLE-14130).
- thunderbolt: Add support for lane bonding (jsc#SLE-14130).
- thunderbolt: Refactor add_switch() into two functions
  (jsc#SLE-14130).
- thunderbolt: Add helper macro to iterate over switch ports
  (jsc#SLE-14130).
- thunderbolt: Make tb_sw_write() take const parameter
  (jsc#SLE-14130).
- thunderbolt: Convert DP adapter register names to follow the
  USB4 spec (jsc#SLE-14130).
- thunderbolt: Convert PCIe adapter register names to follow
  the USB4 spec (jsc#SLE-14130).
- thunderbolt: Convert basic adapter register names to follow
  the USB4 spec (jsc#SLE-14130).
- thunderbolt: Log error if adding switch fails (jsc#SLE-14130).
- thunderbolt: Log switch route string on config read/write
  timeout (jsc#SLE-14130).
- thunderbolt: Introduce tb_switch_is_icm() (jsc#SLE-14130).
- thunderbolt: Add 'generation' attribute for devices
  (jsc#SLE-14130).
- commit 974266a
* Fri Sep 11 2020 hare@suse.de
- iocost: protect iocg->abs_vdebt with iocg->waitq.lock
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/blk-iocost-switch-to-fixed-non-auto-decaying-use_del.patch.
- commit 00d074b
* Fri Sep 11 2020 fdmanana@suse.com
- btrfs: move fs_info init work into it's own helper function
  (bsc#1176019).
- commit 83952d0
* Fri Sep 11 2020 hare@suse.de
- block: move struct block_device to blk_types.h
  (bsc#1175995,jsc#SLE-15608).
- commit 3306a2c
* Fri Sep 11 2020 hare@suse.de
- Update config files: enable BCACHE_ASYNC_REGISTRATION
- commit f631c86
* Fri Sep 11 2020 hare@suse.de
- block: move ->make_request_fn to struct
  (bsc#1175995,jsc#SLE-15608).
- Refresh patches.suse/bdev-add-open_finish.patch.
- Refresh
  patches.suse/mdraid-fix-read-write-bytes-accounting.patch.
- commit b5183e6
* Fri Sep 11 2020 fdmanana@suse.com
- btrfs: Streamline btrfs_fs_info::backup_root_index semantics
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit b8636e1
* Fri Sep 11 2020 hare@suse.de
- simdisk: stop using ->queuedata (bsc#1175995,jsc#SLE-15608).
- nvdimm/pmem: stop using ->queuedata (bsc#1175995,jsc#SLE-15608).
- nvdimm/btt: stop using ->queuedata (bsc#1175995,jsc#SLE-15608).
- nvdimm/blk: stop using ->queuedata (bsc#1175995,jsc#SLE-15608).
- commit 249a4a1
* Fri Sep 11 2020 hare@suse.de
- nvme: define constants for identification values
  (bsc#1175995,jsc#SLE-15608).
- nvme-multipath: stop using ->queuedata
  (bsc#1175995,jsc#SLE-15608).
- commit eafe5c7
* Fri Sep 11 2020 hare@suse.de
- block: reduce ifdef CONFIG_BLOCK madness in headers
  (bsc#1175995,jsc#SLE-15608).
- fs: move the buffer_heads_over_limit stub to buffer_head.h
  (bsc#1175995,jsc#SLE-15608).
- block: move block-related definitions out of fs.h
  (bsc#1175995,jsc#SLE-15608).
- block: simplify sb_is_blkdev_sb (bsc#1175995,jsc#SLE-15608).
- fs: remove the mount_bdev and kill_block_super stubs
  (bsc#1175995,jsc#SLE-15608).
- fs: remove the HAVE_UNLOCKED_IOCTL and HAVE_COMPAT_IOCTL
  (bsc#1175995,jsc#SLE-15608).
- fs: remove an unused block_device_operations forward
  (bsc#1175995,jsc#SLE-15608).
- tty/sysrq: emergency_thaw_all does not depend on CONFIG_BLOCK
  (bsc#1175995,jsc#SLE-15608).
- commit 0c04c26
* Fri Sep 11 2020 hare@suse.de
- bcache: pr_info() format clean up in bcache_device_init()
  (bsc#1175995,jsc#SLE-15608).
- bcache: use delayed kworker fo asynchronous devices
  (bsc#1175995,jsc#SLE-15608).
- bcache: check and adjust logical block size for backing
  (bsc#1175995,jsc#SLE-15608).
- bcache: configure the asynchronous registertion to be
  (bsc#1175995,jsc#SLE-15608).
- bcache: asynchronous devices registration
  (bsc#1175995,jsc#SLE-15608).
- bcache: fix refcount underflow in bcache_device_free()
  (bsc#1175995,jsc#SLE-15608).
- bcache: Convert pr_<level> uses to a more typical style
  (bsc#1175995,jsc#SLE-15608).
- bcache: remove redundant variables i and n
  (bsc#1175995,jsc#SLE-15608).
- bcache: remove dupplicated declaration from btree.h
  (bsc#1175995,jsc#SLE-15608).
- bcache: optimize barrier usage for atomic operations
  (bsc#1175995,jsc#SLE-15608).
- bcache: optimize barrier usage for Rmw atomic bitops
  (bsc#1175995,jsc#SLE-15608).
- bcache: Use scnprintf() for avoiding potential buffer
  (bsc#1175995,jsc#SLE-15608).
- bcache: make bch_sectors_dirty_init() to be multithreaded
  (bsc#1175995,jsc#SLE-15608).
- bcache: make bch_btree_check() to be multithreaded
  (bsc#1175995,jsc#SLE-15608).
- bcache: add bcache_ prefix to btree_root() and btree() macros
  (bsc#1175995,jsc#SLE-15608).
- bcache: move macro btree() and btree_root() into btree.h
  (bsc#1175995,jsc#SLE-15608).
- bcache: use read_cache_page_gfp to read the superblock
  (bsc#1175995,jsc#SLE-15608).
- bcache: store a pointer to the on-disk sb in the cache and
  (bsc#1175995,jsc#SLE-15608).
- bcache: return a pointer to the on-disk sb from read_super
  (bsc#1175995,jsc#SLE-15608).
- bcache: transfer the sb_page reference to
  (bsc#1175995,jsc#SLE-15608).
- bcache: fix use-after-free in register_bcache()
  (bsc#1175995,jsc#SLE-15608).
- bcache: properly initialize 'path' and 'err' in
  (bsc#1175995,jsc#SLE-15608).
- bcache: rework error unwinding in register_bcache
  (bsc#1175995,jsc#SLE-15608).
- bcache: use a separate data structure for the on-disk super
  (bsc#1175995,jsc#SLE-15608).
- bcache: cached_dev_free needs to put the sb page
  (bsc#1175995,jsc#SLE-15608).
- commit 9b2bdeb
* Fri Sep 11 2020 mkubecek@suse.cz
- series.conf: fix sort
- fix order of patches in sorted section
- commit 4d61931
* Fri Sep 11 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/bitfield.h-don-t-compile-time-validate-_val-in-FIELD_FIT.patch
  patches.suse/kernel-cpu_pm-Fix-uninitted-local-in-cpu_pm.patch
  patches.suse/mm-limit-boost_watermark-on-small-zones.patch
  patches.suse/mm-page_alloc-fix-core-hung-in-free_pcppages_bulk.patch
  patches.suse/mm-page_alloc-silence-a-KASAN-false-positive.patch
  patches.suse/mm-remove-VM_BUG_ON-PageSlab-from-page_mapcount.patch
  patches.suse/mm-shuffle-don-t-move-pages-between-zones-and-don-t-read-garbage-memmaps.patch
  patches.suse/mm-sparse-rename-pfn_present-to-pfn_in_present_section.patch
  patches.suse/mm-thp-fix-defrag-setting-if-newline-is-not-used.patch
- commit 8d21545
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Rename find_oldest_super_backup to init_backup_root_slot
  (bsc#1176019).
- commit dd087e3
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Remove unused next_root_backup function (bsc#1176019).
- commit fb3bd27
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Don't use objectid_mutex during mount (bsc#1176019).
- commit c44ea8c
* Thu Sep 10 2020 msuchanek@suse.de
- hw-breakpoints: Fix build warnings with clang (jsc#SLE-12936).
- commit 8ae9e21
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Factor out tree roots initialization during mount
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-free-more-things-in-btrfs_free_fs_info.patch.
- commit 10657bc
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: use bool argument in free_root_pointers() (bsc#1176019).
- commit 743977b
* Thu Sep 10 2020 msuchanek@suse.de
- Refresh sorted patches.
- commit b7a51fb
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Add read_backup_root (bsc#1176019).
- commit 3f9983e
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Remove newest_gen argument from find_oldest_super_backup
  (bsc#1176019).
- commit 58cb4f5
* Thu Sep 10 2020 msuchanek@suse.de
- powerpc: move common register copy functions from signal_32.c
  to signal.c (jsc#SLE-16200).
- commit ddd2ccd
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Cleanup and simplify find_newest_super_backup
  (bsc#1176019).
- commit 478d905
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: add __cold attribute to more functions (bsc#1176019).
- commit 71f76ab
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: free more things in btrfs_free_fs_info (bsc#1176019).
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit b6ec803
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: push btrfs_grab_fs_root into btrfs_get_fs_root
  (bsc#1176019).
- commit a76defc
* Thu Sep 10 2020 tbogendoerfer@suse.de
- qlge: Move drivers/net/ethernet/qlogic/qlge/ to
  drivers/staging/qlge/ (jsc#SLE-15139).
- staging: qlge: Remove useless memset (jsc#SLE-15139).
- supported.conf: qlge moved to staging
- Delete patches.suse/qlge-Remove-useless-memset.patch.
- commit 28f557c
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: use btrfs_put_fs_root to free roots always (bsc#1176019).
- Refresh
  patches.suse/btrfs-fix-corrupt-log-due-to-concurrent-fsync-of-ino.patch.
- commit 41b464c
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in open_ctree (bsc#1176019).
- commit f1db66d
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: export and rename free_fs_info (bsc#1176019).
- commit 0b624c8
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_check_uuid_tree_entry
  (bsc#1176019).
- commit eca88c1
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_recover_log_trees
  (bsc#1176019).
- commit 351a260
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in create_pending_snapshot
  (bsc#1176019).
- commit 8b70b77
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in get_subvol_name_from_objectid
  (bsc#1176019).
- commit faabe37
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_ioctl_send (bsc#1176019).
- commit 9a7a7b3
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in scrub_print_warning_inode
  (bsc#1176019).
- commit 3f0e119
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref for the root in btrfs_find_orphan_roots
  (bsc#1176019).
- commit 681f58e
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: push grab_fs_root into read_fs_root (bsc#1176019).
- Refresh
  patches.suse/0001-btrfs-reloc-fix-reloc-root-leak-and-NULL-pointer-der.patch.
- Refresh
  patches.suse/0002-btrfs-reloc-clear-DEAD_RELOC_TREE-bit-for-orphan-roo.patch.
- commit 4d5675a
* Thu Sep 10 2020 ptesarik@suse.cz
- blacklist.conf: user-visible change to perf
- commit caa4d65
* Thu Sep 10 2020 ptesarik@suse.cz
- blacklist.conf: cleanup need not be backported
- commit f1a5da2
* Thu Sep 10 2020 ptesarik@suse.cz
- net/smc: put slot when connection is killed (git-fixes).
- commit 8ddc482
* Thu Sep 10 2020 hare@suse.de
- block: remove the nr_sectors variable in
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/block-provide-plug-based-way-of-signaling-forced-no-.patch.
- commit ecd3bf0
* Thu Sep 10 2020 hare@suse.de
- block: remove the NULL queue check in
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/block-provide-plug-based-way-of-signaling-forced-no-.patch.
- commit b0bd574
* Thu Sep 10 2020 hare@suse.de
- fs: remove a weird comment in submit_bh_wbc
  (bsc#1175995,jsc#SLE-15608).
- dm: stop using ->queuedata (bsc#1175995,jsc#SLE-15608).
- bcache: stop setting ->queuedata (bsc#1175995,jsc#SLE-15608).
- nfblock: stop using ->queuedata (bsc#1175995,jsc#SLE-15608).
- commit 8120d8f
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_recover_relocation
  (bsc#1176019).
- commit 4544b15
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in create_reloc_inode
  (bsc#1176019).
- commit 5ad1c23
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in find_data_references
  (bsc#1176019).
- commit b847756
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in record_reloc_root_in_trans
  (bsc#1176019).
- commit ed6b331
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in merge_reloc_roots
  (bsc#1176019).
- Refresh
  patches.suse/0001-btrfs-reloc-fix-reloc-root-leak-and-NULL-pointer-der.patch.
- Refresh
  patches.suse/0002-btrfs-reloc-clear-DEAD_RELOC_TREE-bit-for-orphan-roo.patch.
- commit 6e65a90
* Thu Sep 10 2020 hare@suse.de
- scsi: core: Allow non-root users to perform ZBC commands
  (bsc#1175995,jsc#SLE-15608).
- commit 9798d5e
* Thu Sep 10 2020 mgorman@suse.de
- mm, page_alloc: fix core hung in free_pcppages_bulk() (git fixes
  (mm/pgalloc)).
- bitfield.h: don't compile-time validate _val in FIELD_FIT
  (git fixes (bitfield)).
- mm/page_alloc: silence a KASAN false positive (git fixes
  (mm/pgalloc)).
- mm/shuffle: don't move pages between zones and don't read
  garbage memmaps (git fixes (mm/pgalloc)).
- kernel/cpu_pm: Fix uninitted local in cpu_pm (git fixes
  (kernel/pm)).
- mm: remove VM_BUG_ON(PageSlab()) from page_mapcount() (git fixes
  (mm/compaction)).
- mm: limit boost_watermark on small zones (git fixes
  (mm/pgalloc)).
- mm/sparse: rename pfn_present() to pfn_in_present_section()
  (git fixes (mm/pgalloc)).
- mm, thp: fix defrag setting if newline is not used (git fixes
  (mm/thp)).
- commit 72b22a6
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in prepare_to_merge (bsc#1176019).
- commit 28b372d
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in build_backref_tree
  (bsc#1176019).
- commit abebe41
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold ref on root in btrfs_ioctl_default_subvol
  (bsc#1176019).
- commit c589a9c
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_ioctl_get_subvol_info
  (bsc#1176019).
- commit 390b892
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_search_path_in_tree_user
  (bsc#1176019).
- commit bbc4f14
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_search_path_in_tree
  (bsc#1176019).
- commit cd32183
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in search_ioctl (bsc#1176019).
- commit 8173466
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in create_subvol (bsc#1176019).
- commit 5cde960
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in fixup_tree_root_location
  (bsc#1176019).
- commit 320ca12
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in __btrfs_run_defrag_inode
  (bsc#1176019).
- commit 95a17fd
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a root ref in btrfs_get_dentry (bsc#1176019).
- commit 7aed71d
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in resolve_indirect_ref
  (bsc#1176019).
- commit 628db82
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on fs roots while they're in the radix tree
  (bsc#1176019).
- commit 3062c74
* Thu Sep 10 2020 mgorman@suse.de
- blacklist.conf: Theoritical issues that does not apply to kernel configuration
- commit 2c26708
* Thu Sep 10 2020 mgorman@suse.de
- blacklist.conf: Build fix that is not relevant to kernel configuration
- commit 758bef3
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: handle NULL roots in btrfs_put/btrfs_grab_fs_root
  (bsc#1176019).
- commit 58d4ba4
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: make the fs root init functions static (bsc#1176019).
- commit feb2dca
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: open code btrfs_read_fs_root_no_name (bsc#1176019).
- commit ab1f957
* Thu Sep 10 2020 msuchanek@suse.de
- powerpc: Add cputime_to_nsecs() (bsc#1065729).
- commit dee0106
* Thu Sep 10 2020 msuchanek@suse.de
- powerpc/64: Avoid isync in flush_dcache_range() (jsc#SLE-9246).
- commit 0961846
* Thu Sep 10 2020 mbenes@suse.cz
- livepatch: Add -fdump-ipa-clones to build (fate#323487).
  Add support for -fdump-ipa-clones GCC option.
  Update config files accordingly.
- commit 59bf95b
* Thu Sep 10 2020 ptesarik@suse.cz
- blacklist.conf: fix needed only if fake NUMA support is removed
- commit 458b58b
* Thu Sep 10 2020 ptesarik@suse.cz
- s390/dasd: fix inability to use DASD with DIAG driver
  (git-fixes).
- s390/mm: fix huge pte soft dirty copying (git-fixes).
- s390/setup: init jump labels before command line parsing
  (git-fixes).
- commit 0b57226
* Thu Sep 10 2020 ptesarik@suse.cz
- blacklist.conf: s390: PAGE_DEFAULT_KEY is always zero
- commit 047e63e
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/64: Make COMPAT user-selectable disabled on littleendian
  by default (jsc#SLE-16200).
- Update config files.
- commit 4848eb4
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc: Add back __ARCH_WANT_SYS_LLSEEK macro (jsc#SLE-16200).
- commit 79038ac
* Wed Sep  9 2020 jroedel@suse.de
- iommu/vt-d: Handle non-page aligned address (bsc#1176367).
- commit 8f4c091
* Wed Sep  9 2020 msuchanek@suse.de
- KVM: PPC: Book3SHV: Enable support for ISA v3.1 guests
  (jsc#SLE-13521).
- commit d8d95c0
* Wed Sep  9 2020 martin.wilck@suse.com
- scsi: hpsa: Correct ctrl queue depth (jsc#SLE-15150).
- scsi: hpsa: Bump version (jsc#SLE-15150).
- scsi: hpsa: Increase controller error handling timeout
  (jsc#SLE-15150).
- scsi: hpsa: Increase queue depth for external LUNs
  (jsc#SLE-15150).
- scsi: hpsa: Correct rare oob condition (jsc#SLE-15150).
- scsi: hpsa: hpsa_ioctl(): Tidy up a bit (jsc#SLE-15150).
- scsi: hpsa: Get rid of compat_alloc_user_space()
  (jsc#SLE-15150).
- scsi: hpsa: Don't bother with vmalloc for
  BIG_IOCTL_Command_struct (jsc#SLE-15150).
- scsi: hpsa: Lift {BIG_,}IOCTL_Command_struct copy{in,out}
  into hpsa_ioctl() (jsc#SLE-15150).
- scsi: hpsa: correct race condition in offload enabled
  (jsc#SLE-15150).
- commit d3ec2e7
* Wed Sep  9 2020 jroedel@suse.de
- blacklist.conf: Add de2b41be8fcc x86, vmlinux.lds: Page-align end of ..page_aligned sections
- commit 0f6cfca
* Wed Sep  9 2020 jroedel@suse.de
- iommu/vt-d: Handle 36bit addressing for x86-32 (bsc#1176362).
- iommu/amd: Do not use IOMMUv2 functionality when SME is active
  (bsc#1174358).
- iommu/amd: Do not force direct mapping when SME is active
  (bsc#1174358).
- iommu/amd: Use cmpxchg_double() when updating 128-bit IRTE
  (bsc#1176359).
- iommu/amd: Restore IRTE.RemapEn bit after programming IRTE
  (bsc#1176358).
- iommu/vt-d: Serialize IOMMU GCMD register modifications
  (bsc#1176364).
- vfio-pci: Avoid recursive read-lock usage (bsc#1176366).
- iommu/amd: Print extended features in one line to fix divergent
  log levels (bsc#1176357).
- iommu/vt-d: Fix PASID devTLB invalidation (bsc#1176361).
- iommu/vt-d: Remove global page support in devTLB flush
  (bsc#1176363).
- iommu/omap: Check for failure of a call to omap_iommu_dump_ctx
  (bsc#1176360).
- iommu/vt-d: Support flushing more translation cache types
  (bsc#1176365).
- commit d9d3306
* Wed Sep  9 2020 mkubecek@suse.cz
- refresh config files
- commit 09c22d1
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: remove btrfs_read_fs_root, not used anymore
  (bsc#1176019).
- commit 27b7c0e
* Wed Sep  9 2020 bp@suse.de
- x86/kvm: Expose TSX Suspend Load Tracking feature (jsc#16232).
- x86/cpufeatures: Enumerate TSX suspend load address tracking
  instructions (jsc#16232).
- commit 8defd29
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: make relocation use btrfs_read_tree_root() (bsc#1176019).
- commit 83c5766
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: export and use btrfs_read_tree_root for tree-log
  (bsc#1176019).
- commit c457d40
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc: Add POWER10 raw mode cputable entry (jsc#SLE-13521).
- powerpc/powernv: Machine check handler for POWER10
  (jsc#SLE-13521).
- commit 804052b
* Wed Sep  9 2020 mkubecek@suse.cz
- fix patch metadata
- change from "queued" to "never":
  patches.suse/0001-xen-don-t-reschedule-in-preemption-off-sections.patch
- commit 9a83f52
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: make btrfs_find_orphan_roots use btrfs_get_fs_root
  (bsc#1176019).
- commit 348b1af
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: move fs root init stuff into btrfs_init_fs_root
  (bsc#1176019).
- commit cb580c0
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: push __setup_root into btrfs_alloc_root (bsc#1176019).
- commit 062eab0
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/watchpoint: Don't allow concurrent perf and ptrace
  events (jsc#SLE-12936).
- commit 0b0d552
* Wed Sep  9 2020 mkubecek@suse.cz
- series.conf: cleanup
- move to sorted section:
  patches.suse/x86-asm-64-Align-start-of-__clear_user-loop-to-16-by.patch
- commit 3cee501
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: drop create parameter to btrfs_get_extent()
  (bsc#1176019).
- commit 051d33b
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/64: mark emergency stacks valid to unwind (bsc#1156395).
- commit cf61a29
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/watchpoint: Use loop for thread_struct->ptrace_bps
  (jsc#SLE-12936).
- powerpc/watchpoint/ptrace: Return actual num of available
  watchpoints (jsc#SLE-12936).
- commit 874ec7a
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/pseries/iommu: Allow bigger 64bit window by removing
  default DMA window (jsc#SLE-12943).
- powerpc/pseries/iommu: Move window-removing part of remove_ddw
  into remove_dma_window (jsc#SLE-12943).
- powerpc/pseries/iommu: Update call to ibm, query-pe-dma-windows
  (jsc#SLE-12943).
- powerpc/pseries/iommu: Create defines for operations in ibm,
  ddw-applicable (jsc#SLE-12943).
- commit 2727355
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc: Update documentation of ISA versions for Power10
  (jsc#SLE-13521).
- commit d5e7603
* Wed Sep  9 2020 hare@suse.de
- block: fix bdev_disk_changed for non-partitioned devices
  (bsc#1175995,jsc#SLE-15608).
- Refresh patches.suse/bdev-add-open_finish.patch.
- commit 67e87f9
* Wed Sep  9 2020 hare@suse.de
- ata: make "libata.force" kernel parameter optional
  (bsc#1175995,jsc#SLE-15608).
- Update config files.
- commit d59f362
* Wed Sep  9 2020 hare@suse.de
- blk-cgroup: separate out blkg_rwstat under
  CONFIG_BLK_CGROUP_RWSTAT (bsc#1175995,jsc#SLE-15608).
- Update config files.
- commit d89109c
* Wed Sep  9 2020 mbenes@suse.cz
- blacklist.conf: 318af7b80b6a ("Revert "kbuild: use -flive-patching when CONFIG_LIVEPATCH is enabled"")
  Contrary to the upstream we'll support the original patch, since it
  makes things easier for us as of now.
- commit 5f31678
* Wed Sep  9 2020 hare@suse.de
- block: merge invalidate_partitions into rescan_partitions
  (bsc#1175995,jsc#SLE-15608).
- Refresh patches.suse/bdev-add-open_finish.patch.
- commit fe53ad4
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/traps: Make unrecoverable NMIs die instead of panic
  (bsc#1094244 ltc#168122).
- powerpc/traps: Do not trace system reset (bsc#1094244
  ltc#168122).
- powerpc/64s: machine check do not trace real-mode handler
  (bsc#1094244 ltc#168122).
- powerpc: Implement ftrace_enabled() helpers (bsc#1094244
  ltc#168122).
- powerpc/64s: machine check interrupt update NMI accounting
  (bsc#1094244 ltc#168122).
- powerpc/pseries: Machine check use rtas_call_unlocked() with
  args on stack (bsc#1094244 ltc#168122).
- powerpc/pseries: Limit machine check stack to 4GB (bsc#1094244
  ltc#168122).
- powerpc/pseries/ras: fwnmi sreset should not interlock
  (bsc#1094244 ltc#168122).
- powerpc/pseries/ras: fwnmi avoid modifying r3 in error case
  (bsc#1094244 ltc#168122).
- powerpc/pseries/ras: Fix FWNMI_VALID off by one (bsc#1094244
  ltc#168122).
- powerpc/pseries/ras: Avoid calling rtas_token() in NMI paths
  (bsc#1094244 ltc#168122).
- commit a8046af
* Wed Sep  9 2020 ptesarik@suse.cz
- scsi: zfcp: Fix use-after-free in request timeout handlers
  (git-fixes).
- commit afdea91
* Wed Sep  9 2020 ptesarik@suse.cz
- blacklist.conf: zfcp comment fix
- commit 063b5f1
* Wed Sep  9 2020 hare@suse.de
- blk-stat: make q->stats->lock irqsafe
  (bsc#1175995,jsc#SLE-15608).
- block: fix locking in bdev_del_partition
  (bsc#1175995,jsc#SLE-15608).
- block: release disk reference in hd_struct_free_work
  (bsc#1175995,jsc#SLE-15608).
- commit 55667f3
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/signal64: Don't opencode page prefaulting
  (jsc#SLE-9246).
- powerpc/64/signal: Balance return predictor stack in signal
  trampoline (jsc#SLE-9246).
- powerpc/pseries: Mark accumulate_stolen_time() as notrace
  (jsc#SLE-9246).
- commit 48a612a
* Wed Sep  9 2020 hare@suse.de
- block: loop: set discard granularity and alignment for block
  (bsc#1175995,jsc#SLE-15608).
- block: blk-mq.c: fix @at_head kernel-doc warning
  (bsc#1175995,jsc#SLE-15608).
- commit 9c6b455
* Wed Sep  9 2020 hare@suse.de
- block: don't do revalidate zones on invalid devices
  (bsc#1175995,jsc#SLE-15608).
- nvme-rdma: fix controller reset hang during traffic
  (bsc#1175995,jsc#SLE-15608).
- nvme-tcp: fix controller reset hang during traffic
  (bsc#1175995,jsc#SLE-15608).
- bcache: use disk_{start,end}_io_acct() to count I/O for bcache
  device (bsc#1175995,jsc#SLE-15608).
- bcache: fix bio_{start,end}_io_acct with proper device
  (bsc#1175995,jsc#SLE-15608).
- commit 62cda5f
* Wed Sep  9 2020 hare@suse.de
- block: provide plug based way of signaling forced no-wait
  semantics (bsc#1175995,jsc#SLE-15608).
- block: blk-timeout: delete duplicated word
  (bsc#1175995,jsc#SLE-15608).
- block: blk-mq-sched: delete duplicated word
  (bsc#1175995,jsc#SLE-15608).
- block: genhd: delete duplicated words
  (bsc#1175995,jsc#SLE-15608).
- block: elevator: delete duplicated word and fix typos
  (bsc#1175995,jsc#SLE-15608).
- block: bio: delete duplicated words (bsc#1175995,jsc#SLE-15608).
- block: bfq-iosched: fix duplicated word
  (bsc#1175995,jsc#SLE-15608).
- block: Use non _rcu version of list functions for tag_set_list
  (bsc#1175995,jsc#SLE-15608).
- blk-cgroup: show global disk stats in root cgroup io.stat
  (bsc#1175995,jsc#SLE-15608).
- blk-cgroup: make iostat functions visible to stat printing
  (bsc#1175995,jsc#SLE-15608).
- block: defer flush request no matter whether we have elevator
  (bsc#1175995,jsc#SLE-15608).
- block: make blk_timeout_init() static
  (bsc#1175995,jsc#SLE-15608).
- block: remove retry loop in ioc_release_fn()
  (bsc#1175995,jsc#SLE-15608).
- block: remove unnecessary ioc nested locking
  (bsc#1175995,jsc#SLE-15608).
- Revert "blk-rq-qos: remove redundant finish_wait to
  rq_qos_wait." (bsc#1175995,jsc#SLE-15608).
- block: relax jiffies rounding for timeouts
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: remove redundant validation in __blk_mq_end_request()
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: Remove unnecessary local variable
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: streamline handling of q->mq_ops->queue_rq result
  (bsc#1175995,jsc#SLE-15608).
- blk-iolatency: only call ktime_get() if needed
  (bsc#1175995,jsc#SLE-15608).
- block: tidy up a warning in bio_check_ro
  (bsc#1175995,jsc#SLE-15608).
- block: remove the request_queue argument from blk_queue_split
  (bsc#1175995,jsc#SLE-15608).
- zram: stop using ->queuedata (bsc#1175995,jsc#SLE-15608).
- umem: stop using ->queuedata (bsc#1175995,jsc#SLE-15608).
- rsxx: stop using ->queuedata (bsc#1175995,jsc#SLE-15608).
- ps3vram: stop using ->queuedata (bsc#1175995,jsc#SLE-15608).
- null_blk: stop using ->queuedata for bio mode
  (bsc#1175995,jsc#SLE-15608).
- drbd: stop using ->queuedata (bsc#1175995,jsc#SLE-15608).
- blk-mq: remove pointless call of list_entry_rq() in
  hctx_show_busy_rq() (bsc#1175995,jsc#SLE-15608).
- blk-mq: centralise related handling into blk_mq_get_driver_tag
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: move blk_mq_get_driver_tag into blk-mq.c
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: support batching dispatch in case of io
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: pass obtained budget count to blk_mq_dispatch_rq_list
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: remove dead check from blk_mq_dispatch_rq_list
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: move getting driver tag and budget into one helper
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: pass hctx to blk_mq_dispatch_rq_list
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: pass request queue into get/put budget callback
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: put driver tag when this request is completed
  (bsc#1175995,jsc#SLE-15608).
- blk-cgroup: remove a dead check in blk_throtl_bio
  (bsc#1175995,jsc#SLE-15608).
- blk-cgroup: remove blkcg_bio_issue_check
  (bsc#1175995,jsc#SLE-15608).
- blk-cgroup: move rcu locking from blkcg_bio_issue_check to
  (bsc#1175995,jsc#SLE-15608).
- cgroup: unexport cgroup_rstat_updated
  (bsc#1175995,jsc#SLE-15608).
- blk-cgroup: remove the !bio->bi_blkg check in
  (bsc#1175995,jsc#SLE-15608).
- block: move the initial blkg lookup into blkg_tryget_closest
  (bsc#1175995,jsc#SLE-15608).
- block: bypass blkg_tryget_closest for the root_blkg
  (bsc#1175995,jsc#SLE-15608).
- block: merge blkg_lookup_create and __blkg_lookup_create
  (bsc#1175995,jsc#SLE-15608).
- block: move the bio cgroup associatation helpers to blk-cgroup.c
  (bsc#1175995,jsc#SLE-15608).
- block: move bio_associate_blkg_from_page to mm/page_io.c
  (bsc#1175995,jsc#SLE-15608).
- block: merge __bio_associate_blkg into
  bio_associate_blkg_from_css (bsc#1175995,jsc#SLE-15608).
- block: really clone the block cgroup in
  bio_clone_blkg_association (bsc#1175995,jsc#SLE-15608).
- block: remove bio_disassociate_blkg (bsc#1175995,jsc#SLE-15608).
- dm: use bio_uninit instead of bio_disassociate_blkg
  (bsc#1175995,jsc#SLE-15608).
- blk-rq-qos: remove redundant finish_wait to rq_qos_wait
  (bsc#1175995,jsc#SLE-15608).
- block: mark bd_finish_claiming static
  (bsc#1175995,jsc#SLE-15608).
- blk-iocost: Use struct_size() in kzalloc_node()
  (bsc#1175995,jsc#SLE-15608).
- block: bio: Use struct_size() in kmalloc()
  (bsc#1175995,jsc#SLE-15608).
- loop: be paranoid on exit and prevent new additions /
  (bsc#1175995,jsc#SLE-15608).
- block: revert back to synchronous request_queue removal
  (bsc#1175995,jsc#SLE-15608).
- block: clarify context for refcount increment helpers
  (bsc#1175995,jsc#SLE-15608).
- block: add docs for gendisk / request_queue refcount helpers
  (bsc#1175995,jsc#SLE-15608).
- nvme-rdma: factor out a nvme_rdma_end_request helper
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: add a new blk_mq_complete_request_remote API
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: factor out a blk_mq_complete_need_ipi helper
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: remove the get_cpu/put_cpu pair in
  blk_mq_complete_request (bsc#1175995,jsc#SLE-15608).
- blk-mq: move failure injection out of blk_mq_complete_request
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: merge the softirq vs non-softirq IPI logic
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: short cut the IPI path in blk_mq_force_complete_rq
  for !SMP (bsc#1175995,jsc#SLE-15608).
- blk-mq: complete polled requests directly
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: remove raise_blk_irq (bsc#1175995,jsc#SLE-15608).
- blk-mq: factor out a helper to reise the block softirq
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: merge blk-softirq.c into blk-mq.c
  (bsc#1175995,jsc#SLE-15608).
- commit 0cd699a
* Wed Sep  9 2020 hare@suse.de
- block: make function __bio_integrity_free() static
  (bsc#1175995,jsc#SLE-15608).
- blk-mq-debugfs: update blk_queue_flag_name[] accordingly for
  new flags (bsc#1175995,jsc#SLE-15608).
- block: release bip in a right way in error path
  (bsc#1175995,jsc#SLE-15608).
- dm: update original bio sector on Zone Append
  (bsc#1175995,jsc#SLE-15608).
- scsi: Wire up ata_scsi_dma_need_drain for SAS HBA drivers
  (bsc#1175995,jsc#SLE-15608).
- block: make function 'kill_bdev' static
  (bsc#1175995,jsc#SLE-15608).
- partitions/ldm: Replace uuid_copy() with import_uuid() where
  it makes sense (bsc#1175995,jsc#SLE-15608).
- block: update hctx map when use multiple maps
  (bsc#1175995,jsc#SLE-15608).
- trace/events/block.h: drop kernel-doc for dropped function
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: Remove redundant 'return' statement
  (bsc#1175995,jsc#SLE-15608).
- block: Replace zero-length array with flexible-array
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: fix blk_mq_all_tag_iter (bsc#1175995,jsc#SLE-15608).
- blk-mq: split out a __blk_mq_get_driver_tag helper
  (bsc#1175995,jsc#SLE-15608).
- commit 2fcf2bf
* Wed Sep  9 2020 hare@suse.de
- block: remove the error argument to the block_bio_complete
  tracepoint (bsc#1175995,jsc#SLE-15608).
- blacklist.conf:
- commit c0d6fb1
* Wed Sep  9 2020 hare@suse.de
- loop: Fix wrong masking of status flags
  (bsc#1175995,jsc#SLE-15608).
- commit b79539d
* Wed Sep  9 2020 hare@suse.de
- loop: remove redundant assignment to variable error
  (bsc#1175995,jsc#SLE-15608).
- block: remove ioctl_by_bdev (bsc#1175995,jsc#SLE-15608).
- s390/dasd: remove ioctl_by_bdev calls
  (bsc#1175995,jsc#SLE-15608).
- dasd: refactor dasd_ioctl_information
  (bsc#1175995,jsc#SLE-15608).
- loop: Add LOOP_CONFIGURE ioctl (bsc#1175995,jsc#SLE-15608).
- loop: Clean up LOOP_SET_STATUS lo_flags handling
  (bsc#1175995,jsc#SLE-15608).
- loop: Rework lo_ioctl() __user argument casting
  (bsc#1175995,jsc#SLE-15608).
- loop: Move loop_set_status_from_info() and friends up
  (bsc#1175995,jsc#SLE-15608).
- loop: Factor out configuring loop from status
  (bsc#1175995,jsc#SLE-15608).
- loop: Remove figure_loop_size() (bsc#1175995,jsc#SLE-15608).
- commit 6458d48
* Wed Sep  9 2020 hare@suse.de
- loop: Switch to set_capacity_revalidate_and_notify()
  (bsc#1175995,jsc#SLE-15608).
- loop: Factor out setting loop device size
  (bsc#1175995,jsc#SLE-15608).
- loop: Remove sector_t truncation checks
  (bsc#1175995,jsc#SLE-15608).
- loop: Call loop_config_discard() only after new config is
  (bsc#1175995,jsc#SLE-15608).
- commit 34d958e
* Wed Sep  9 2020 hare@suse.de
- block: mark bio_wouldblock_error() bio with BIO_QUIET
  (bsc#1175995,jsc#SLE-15608).
- blk-wbt: rename __wbt_update_limits to wbt_update_limits
  (bsc#1175995,jsc#SLE-15608).
- blk-wbt: remove wbt_update_limits (bsc#1175995,jsc#SLE-15608).
- blk-throttle: remove tg_drain_bios (bsc#1175995,jsc#SLE-15608).
- blk-throttle: remove blk_throtl_drain
  (bsc#1175995,jsc#SLE-15608).
- null_blk: force complete for timeout request
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: drain I/O when all CPUs in a hctx are offline
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: add blk_mq_all_tag_iter (bsc#1175995,jsc#SLE-15608).
- blk-mq: open code __blk_mq_alloc_request in
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: use BLK_MQ_NO_TAG in more places
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: rename BLK_MQ_TAG_FAIL to BLK_MQ_NO_TAG
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: move more request initialization to blk_mq_rq_ctx_init
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: simplify the blk_mq_get_request calling convention
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: remove the bio argument to ->prepare_request
  (bsc#1175995,jsc#SLE-15608).
- nvme: force complete cancelled requests
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: blk-mq: provide forced completion method
  (bsc#1175995,jsc#SLE-15608).
- block: fix a warning when blkdev.h is included for !CONFIG_BLOCK
  builds (bsc#1175995,jsc#SLE-15608).
- block: blk-crypto-fallback: remove redundant initialization
  of variable err (bsc#1175995,jsc#SLE-15608).
- block: reduce part_stat_lock() scope
  (bsc#1175995,jsc#SLE-15608).
- block: use __this_cpu_add() instead of access by
  smp_processor_id() (bsc#1175995,jsc#SLE-15608).
- block: remove rcu_read_lock() from part_stat_lock()
  (bsc#1175995,jsc#SLE-15608).
- block: add a blk_account_io_merge_bio helper
  (bsc#1175995,jsc#SLE-15608).
- block: account merge of two requests
  (bsc#1175995,jsc#SLE-15608).
- block: always use a percpu variable for disk stats
  (bsc#1175995,jsc#SLE-15608).
- block: move update_io_ticks to blk-core.c
  (bsc#1175995,jsc#SLE-15608).
- block: remove generic_{start,end}_io_acct
  (bsc#1175995,jsc#SLE-15608).
- zram: nvdimm: use bio_{start,end}_io_acct and
  disk_{start,end}_io_acct (bsc#1175995,jsc#SLE-15608).
- nvdimm: use bio_{start,end}_io_acct (bsc#1175995,jsc#SLE-15608).
- dm: use bio_{start,end}_io_acct (bsc#1175995,jsc#SLE-15608).
- bcache: use bio_{start,end}_io_acct (bsc#1175995,jsc#SLE-15608).
- lightnvm/pblk: use bio_{start,end}_io_acct
  (bsc#1175995,jsc#SLE-15608).
- rsxx: use bio_{start,end}_io_acct (bsc#1175995,jsc#SLE-15608).
- drbd: use bio_{start,end}_io_acct (bsc#1175995,jsc#SLE-15608).
- block: add disk/bio-based accounting helpers
  (bsc#1175995,jsc#SLE-15608).
- block: remove the disk and queue NULL checks in
  (bsc#1175995,jsc#SLE-15608).
- block: remove the error_sector argument to blkdev_issue_flush
  (bsc#1175995,jsc#SLE-15608).
- block: Remove unused flush_queue_delayed in struct
  blk_flush_queue (bsc#1175995,jsc#SLE-15608).
- null_blk: Zero-initialize read buffers in non-memory-backed mode
  (bsc#1175995,jsc#SLE-15608).
- block: Document the bio_vec properties
  (bsc#1175995,jsc#SLE-15608).
- bio.h: Declare the arguments of the bio iteration functions
  const (bsc#1175995,jsc#SLE-15608).
- block: merge part_{inc,dev}_in_flight into their only callers
  (bsc#1175995,jsc#SLE-15608).
- block: don't call part_{inc,dec}_in_flight for blk-mq devices
  (bsc#1175995,jsc#SLE-15608).
- block: move the blk-mq calls out of part_in_flight{,_rw}
  (bsc#1175995,jsc#SLE-15608).
- block: mark blk_account_io_completion static
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: allow blk_mq_make_request to consume the q_usage_counter
  reference (bsc#1175995,jsc#SLE-15608).
- blk-mq: remove a pointless queue enter pair in
  blk_mq_alloc_request_hctx (bsc#1175995,jsc#SLE-15608).
- blk-mq: remove a pointless queue enter pair in
  blk_mq_alloc_request (bsc#1175995,jsc#SLE-15608).
- blk-mq: move the call to blk_queue_enter_live out of
  blk_mq_get_request (bsc#1175995,jsc#SLE-15608).
- Documentation: Document the blk-crypto framework
  (bsc#1175995,jsc#SLE-15608).
- block: move blk_io_schedule() out of header file
  (bsc#1175995,jsc#SLE-15608).
- block: export bio_release_pages and bio_iov_iter_get_pages
  (bsc#1175995,jsc#SLE-15608).
- null_blk: Support REQ_OP_ZONE_APPEND
  (bsc#1175995,jsc#SLE-15608).
- scsi: sd_zbc: emulate ZONE_APPEND commands
  (bsc#1175995,jsc#SLE-15608).
- scsi: sd_zbc: factor out sanity checks for zoned commands
  (bsc#1175995,jsc#SLE-15608).
- block: Modify revalidate zones (bsc#1175995,jsc#SLE-15608).
- block: introduce blk_req_zone_write_trylock
  (bsc#1175995,jsc#SLE-15608).
- block: Introduce REQ_OP_ZONE_APPEND (bsc#1175995,jsc#SLE-15608).
- block: rename __bio_add_pc_page to bio_add_hw_page
  (bsc#1175995,jsc#SLE-15608).
- block: provide fallbacks for blk_queue_zone_is_seq and
  blk_queue_zone_no (bsc#1175995,jsc#SLE-15608).
- block: add blk_io_schedule() for avoiding task hung in sync dio
  (bsc#1175995,jsc#SLE-15608).
- block: don't hold part0's refcount in IO path
  (bsc#1175995,jsc#SLE-15608).
- block: re-organize fields of 'struct hd_part'
  (bsc#1175995,jsc#SLE-15608).
- block: only define 'nr_sects_seq' in hd_part for 32bit SMP
  (bsc#1175995,jsc#SLE-15608).
- block: fix use-after-free on cached last_lookup partition
  (bsc#1175995,jsc#SLE-15608).
- block: reset mapping if failed to update hardware queue count
  (bsc#1175995,jsc#SLE-15608).
- bdi: fix up for "remove the name field in struct
  backing_dev_info" (bsc#1175995,jsc#SLE-15608).
- hfs: stop using ioctl_by_bdev (bsc#1175995,jsc#SLE-15608).
- bdi: remove the name field in struct backing_dev_info
  (bsc#1175995,jsc#SLE-15608).
- bdi: simplify bdi_alloc (bsc#1175995,jsc#SLE-15608).
- bdi: remove bdi_register_owner (bsc#1175995,jsc#SLE-15608).
- bdi: unexport bdi_register_va (bsc#1175995,jsc#SLE-15608).
- driver core: remove device_create_vargs
  (bsc#1175995,jsc#SLE-15608).
- block: rename blk_mq_alloc_rq_maps (bsc#1175995,jsc#SLE-15608).
- block: rename __blk_mq_alloc_rq_map (bsc#1175995,jsc#SLE-15608).
- block: alloc map and request for new hardware queue
  (bsc#1175995,jsc#SLE-15608).
- block: save previous hardware queue count before udpate
  (bsc#1175995,jsc#SLE-15608).
- block: free both rq_map and request (bsc#1175995,jsc#SLE-15608).
- udf: stop using ioctl_by_bdev (bsc#1175995,jsc#SLE-15608).
- isofs: stop using ioctl_by_bdev (bsc#1175995,jsc#SLE-15608).
- hfsplus: stop using ioctl_by_bdev (bsc#1175995,jsc#SLE-15608).
- cdrom: factor out a cdrom_multisession helper
  (bsc#1175995,jsc#SLE-15608).
- cdrom: factor out a cdrom_read_tocentry helper
  (bsc#1175995,jsc#SLE-15608).
- ide-cd: rename cdrom_read_tocentry (bsc#1175995,jsc#SLE-15608).
- block: add a cdrom_device_info pointer to struct gendisk
  (bsc#1175995,jsc#SLE-15608).
- iocost_monitor: drop string wrap around numbers when outputting
  json (bsc#1175995,jsc#SLE-15608).
- iocost_monitor: exit successfully if interval is zero
  (bsc#1175995,jsc#SLE-15608).
- blk-iocost: account for IO size when testing latencies
  (bsc#1175995,jsc#SLE-15608).
- blk-iocost: switch to fixed non-auto-decaying use_delay
  (bsc#1175995,jsc#SLE-15608).
- block: add a bio_queue_enter helper (bsc#1175995,jsc#SLE-15608).
- block: replace BIO_QUEUE_ENTERED with BIO_CGROUP_ACCT
  (bsc#1175995,jsc#SLE-15608).
- block: cleanup the memory stall accounting in submit_bio
  (bsc#1175995,jsc#SLE-15608).
- block: improve the submit_bio and generic_make_request
  documentation (bsc#1175995,jsc#SLE-15608).
- blk-mq: make function '__blk_mq_sched_dispatch_requests' static
  (bsc#1175995,jsc#SLE-15608).
- block: bypass ->make_request_fn for blk-mq drivers
  (bsc#1175995,jsc#SLE-15608).
- dm: remove the make_request_fn check in device_area_is_invalid
  (bsc#1175995,jsc#SLE-15608).
- bcache: remove a duplicate ->make_request_fn assignment
  (bsc#1175995,jsc#SLE-15608).
- block: remove create_io_context (bsc#1175995,jsc#SLE-15608).
- block: Limit number of items taken from the I/O scheduler in
  one go (bsc#1175995,jsc#SLE-15608).
- block: move dma_pad handling from blk_rq_map_sg into the callers
  (bsc#1175995,jsc#SLE-15608).
- block: move dma drain handling to scsi
  (bsc#1175995,jsc#SLE-15608).
- scsi: merge scsi_init_sgtable into scsi_init_io
  (bsc#1175995,jsc#SLE-15608).
- block: provide a blk_rq_map_sg variant that returns the last
  element (bsc#1175995,jsc#SLE-15608).
- block: remove RQF_COPY_USER (bsc#1175995,jsc#SLE-15608).
- block: fold bdev_unhash_inode into invalidate_partition
  (bsc1175995,jsc#SLE-15608).
- block: mark invalidate_partition static
  (bsc#1175995,jsc#SLE-15608).
- block: simplify block device syncing in bdev_del_partition
  (bsc#1175995,jsc#SLE-15608).
- block: don't call invalidate_partition from blk_drop_partitions
  (bsc#1175995,jsc#SLE-15608).
- dasd: use blk_drop_partitions instead of badly reimplementing it
  (bsc#1175995,jsc#SLE-15608).
- block: remove the disk argument from blk_drop_partitions
  (bsc#1175995,jsc#SLE-15608).
- block: remove hd_struct_kill (bsc#1175995,jsc#SLE-15608).
- block: cleanup hd_struct freeing (bsc#1175995,jsc#SLE-15608).
- block: pass a hd_struct to delete_partition
  (bsc#1175995,jsc#SLE-15608).
- block: refactor blkpg_ioctl (bsc#1175995,jsc#SLE-15608).
- Revert "scsi: core: run queue if SCSI device queue isn't ready
  and queue is idle" (bsc#1175995,jsc#SLE-15608).
- blk-mq: Rerun dispatching in the case of budget contention
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: Add blk_mq_delay_run_hw_queues() API call
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: In blk_mq_dispatch_rq_list() "no budget" is a reason
  to kick (bsc#1175995,jsc#SLE-15608).
- commit 319a85f
* Wed Sep  9 2020 hare@suse.de
- Revert "block: end bio with BLK_STS_AGAIN in case of non-mq
  devs and REQ_NOWAIT" (bsc#1175995,jsc#SLE-15608).
- null_blk: don't allow discard for zoned mode
  (bsc#1175995,jsc#SLE-15608).
- null_blk: return error for invalid zone size
  (bsc#1175995,jsc#SLE-15608).
- commit ef12ab4
* Wed Sep  9 2020 hare@suse.de
- block: remove the bd_openers checks in blk_drop_partitions
  (bsc#1175995,jsc#SLE-15608).
- blacklist.conf:
- commit 9c44fbf
* Wed Sep  9 2020 hare@suse.de
- null_blk: Cleanup zoned device initialization
  (bsc#1175995,jsc#SLE-15608).
- null_blk: Fix zoned command handling
  (bsc#1175995,jsc#SLE-15608).
- scsi: hisi_sas: Fix build error without SATA_HOST
  (bsc#1175995,jsc#SLE-15608).
- blk-wbt: Drop needless newlines from tracepoint format strings
  (bsc#1175995,jsc#SLE-15608).
- blk-wbt: Use tracepoint_string() for wbt_step tracepoint string
  literals (bsc#1175995,jsc#SLE-15608).
- s390/dasd: remove IOSCHED_DEADLINE from DASD Kconfig
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: Put driver tag in blk_mq_dispatch_rq_list() when no
  budget (bsc#1175995,jsc#SLE-15608).
- commit cd72425
* Wed Sep  9 2020 hare@suse.de
- block: fix busy device checking in blk_drop_partitions again
  (bsc#1175995,jsc#SLE-15608).
- blacklist.conf:
- commit 3bc658c
* Wed Sep  9 2020 hare@suse.de
- block: fix busy device checking in blk_drop_partitions
  (bsc#1175995,jsc#SLE-15608).
- blacklist.conf:
- blk-mq: don't commit_rqs() if none were queued
  (bsc#1175995,jsc#SLE-15608).
- loop: Better discard support for block devices
  (bsc#1175995,jsc#SLE-15608).
- loop: Report EOPNOTSUPP properly (bsc#1175995,jsc#SLE-15608).
- commit 8e3eb83
* Wed Sep  9 2020 colyli@suse.de
- blacklist.conf: add cafe01ef8fcb248583038e1be071383530fe355a
- commit 5a7e3c7
* Wed Sep  9 2020 hare@suse.de
- blkcg: don't offline parent blkcg first
  (bsc#1175995,jsc#SLE-15608).
- blkcg: rename blkcg->cgwb_refcnt to ->online_pin and always
  use it (bsc#1175995,jsc#SLE-15608).
- commit 45ef8ed
* Wed Sep  9 2020 hare@suse.de
- pmem: Add functions for reading/writing page to/from pmem
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: Fix typo in comment (bsc#1175995,jsc#SLE-15608).
- uuid: Add inline helpers to import / export UUIDs
  (bsc#1175995,jsc#SLE-15608).
- null_blk: add trace in null_blk_zoned.c
  (bsc#1175995,jsc#SLE-15608).
- null_blk: add tracepoint helpers for zoned mode
  (bsc#1175995,jsc#SLE-15608).
- block: add a zone condition debug helper
  (bsc#1175995,jsc#SLE-15608).
- commit c1325db
* Wed Sep  9 2020 hare@suse.de
- null_blk: describe the usage of fault injection param
  (bsc#1175995,jsc#SLE-15608).
- null_blk: fix spurious IO errors after failed past-wp access
  (bsc#1175995,jsc#SLE-15608).
- lightnvm: pblk: Use scnprintf() for avoiding potential buffer
  (bsc#1175995,jsc#SLE-15608).
- block: aoe: Use scnprintf() for avoiding potential buffer
  (bsc#1175995,jsc#SLE-15608).
- loop: Only freeze block queue when needed
  (bsc#1175995,jsc#SLE-15608).
- commit 19247ef
* Wed Sep  9 2020 hare@suse.de
- block: return NULL in blk_alloc_queue() on error
  (bsc#1175995,jsc#SLE-15608).
- commit db2a0a7
* Wed Sep  9 2020 hare@suse.de
- block: simplify queue allocation (bsc#1175995,jsc#SLE-15608).
- bcache: pass the make_request methods to blk_queue_make_request
  (bsc#1175995,jsc#SLE-15608).
- null_blk: use blk_mq_init_queue_data
  (bsc#1175995,jsc#SLE-15608).
- block: add a blk_mq_init_queue_data helper
  (bsc#1175995,jsc#SLE-15608).
- block: move the ->devnode callback to struct
  block_device_operations (bsc#1175995,jsc#SLE-15608).
- block: move the part_stat* helpers from genhd.h to a new header
  (bsc#1175995,jsc#SLE-15608).
- commit 641b897
* Wed Sep  9 2020 hare@suse.de
- block: move guard_bio_eod to bio.c (bsc#1175995,jsc#SLE-15608).
- block: unexport get_gendisk (bsc#1175995,jsc#SLE-15608).
- block: unexport disk_map_sector_rcu (bsc#1175995,jsc#SLE-15608).
- block: unexport disk_get_part (bsc#1175995,jsc#SLE-15608).
- block: mark part_in_flight and part_in_flight_rw static
  (bsc#1175995,jsc#SLE-15608).
- block: mark block_depr static (bsc#1175995,jsc#SLE-15608).
- block: factor out requeue handling from dispatch code
  (bsc#1175995,jsc#SLE-15608).
- block/diskstats: replace time_in_queue with sum of request times
  (bsc#1175995,jsc#SLE-15608).
- block/diskstats: accumulate all per-cpu counters in one pass
  (bsc#1175995,jsc#SLE-15608).
- block: merge partition-generic.c and check.c
  (bsc#1175995,jsc#SLE-15608).
- block: move the various x86 Unix label formats out of genhd.h
  (bsc#1175995,jsc#SLE-15608).
- partitions/msdos: remove LINUX_SWAP_PARTITION
  (bsc#1175995,jsc#SLE-15608).
- block: move the *_PARTITION enum out of genhd.h
  (bsc#1175995,jsc#SLE-15608).
- block: move struct partition out of genhd.h
  (bsc#1175995,jsc#SLE-15608).
- block: remove block/partitions/sun.h
  (bsc#1175995,jsc#SLE-15608).
- block: remove block/partitions/sgi.h
  (bsc#1175995,jsc#SLE-15608).
- block: remove block/partitions/osf.h
  (bsc#1175995,jsc#SLE-15608).
- block: remove block/partitions/karma.h
  (bsc#1175995,jsc#SLE-15608).
- block: declare all partition detection routines in check.h
  (bsc#1175995,jsc#SLE-15608).
- block: remove warn_no_part (bsc#1175995,jsc#SLE-15608).
- block: cleanup how md_autodetect_dev is called
  (bsc#1175995,jsc#SLE-15608).
- block: unexport read_dev_sector and put_dev_sector
  (bsc#1175995,jsc#SLE-15608).
- scsi: simplify scsi_partsize (bsc#1175995,jsc#SLE-15608).
- scsi: move scsicam_bios_param to the end of scsicam.c
  (bsc#1175995,jsc#SLE-15608).
- scsi: simplify scsi_bios_ptable (bsc#1175995,jsc#SLE-15608).
- commit 865fdca
* Wed Sep  9 2020 hare@suse.de
- block: move sysfs methods shared by disks and partitions to
  genhd.c (bsc#1175995,jsc#SLE-15608).
- block: move disk_name and related helpers out of
  partition-generic.c (bsc#1175995,jsc#SLE-15608).
- block: remove __bdevname (bsc#1175995,jsc#SLE-15608).
- block: remove the blk_lookup_devt export
  (bsc#1175995,jsc#SLE-15608).
- commit d7835cf
* Wed Sep  9 2020 hare@suse.de
- block, bfq: move forward the getting of an extra ref in
  bfq_bfqq_move (bsc#1175995,jsc#SLE-15608).
- scsi: Convert to use set_capacity_revalidate_and_notify
  (bsc#1175995,jsc#SLE-15608).
- nvme: Convert to use set_capacity_revalidate_and_notify
  (bsc#1175995,jsc#SLE-15608).
- virtio_blk.c: Convert to use set_capacity_revalidate_and_notify
  (bsc#1175995,jsc#SLE-15608).
- block/genhd: Notify udev about capacity change
  (bsc#1175995,jsc#SLE-15608).
- block: Prevent hung_check firing during long sync IO
  (bsc#1175995,jsc#SLE-15608).
- block: fix a device invalidation regression
  (bsc#1175995,jsc#SLE-15608).
- block, zoned: fix integer overflow with BLKRESETZONE et al
  (bsc#1175995,jsc#SLE-15608).
- blk-iocost: remove duplicated lines in comments
  (bsc#1175995,jsc#SLE-15608).
- block: sed-opal: Change the check condition for regular session
  validity (bsc#1175995,jsc#SLE-15608).
- block: Document genhd capability flags
  (bsc#1175995,jsc#SLE-15608).
- block: cleanup comment for blk_flush_complete_seq
  (bsc#1175995,jsc#SLE-15608).
- block: remove unneeded argument from blk_alloc_flush_queue
  (bsc#1175995,jsc#SLE-15608).
- block: cleanup for _blk/blk_rq_prep_clone
  (bsc#1175995,jsc#SLE-15608).
- block: remove redundant setting of QUEUE_FLAG_DYING
  (bsc#1175995,jsc#SLE-15608).
- block: use bio_{wouldblock,io}_error in direct_make_request
  (bsc#1175995,jsc#SLE-15608).
- block: fix comment for blk_cloned_rq_check_limits
  (bsc#1175995,jsc#SLE-15608).
- block: Fix use-after-free issue accessing struct io_cq
  (bsc#1175995,jsc#SLE-15608).
- null_blk: Add support for init_hctx() fault injection
  (bsc#1175995,jsc#SLE-15608).
- null_blk: Handle null_add_dev() failures properly
  (bsc#1175995,jsc#SLE-15608).
- null_blk: Fix changing the number of hardware queues
  (bsc#1175995,jsc#SLE-15608).
- null_blk: Suppress an UBSAN complaint triggered when setting
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: Fix a recently introduced regression in
  blk_mq_realloc_hw_ctxs() (bsc#1175995,jsc#SLE-15608).
- blk-mq: Fix a comment in include/linux/blk-mq.h
  (bsc#1175995,jsc#SLE-15608).
- ata: move ata_eh_analyze_ncq_error() & co. to libata-sata.c
  (bsc#1175995,jsc#SLE-15608).
- ata: start separating SATA specific code from libata-eh.c
  (bsc#1175995,jsc#SLE-15608).
- ata: move ata_sas_*() to libata-sata.c
  (bsc#1175995,jsc#SLE-15608).
- ata: start separating SATA specific code from libata-scsi.c
  (bsc#1175995,jsc#SLE-15608).
- ata: move sata_deb_timing_*() to libata-sata.c
  (bsc#1175995,jsc#SLE-15608).
- ata: move ata_qc_complete_multiple() to libata-sata.c
  (bsc#1175995,jsc#SLE-15608).
- ata: move sata_link_hardreset() to libata-sata.c
  (bsc#1175995,jsc#SLE-15608).
- ata: move sata_link_{debounce,resume}() to libata-sata.c
  (bsc#1175995,jsc#SLE-15608).
- ata: move *sata_set_spd*() to libata-sata.c
  (bsc#1175995,jsc#SLE-15608).
- ata: move sata_scr_*() to libata-sata.c
  (bsc#1175995,jsc#SLE-15608).
- ata: start separating SATA specific code from libata-core.c
  (bsc#1175995,jsc#SLE-15608).
- ata: let compiler optimize out ata_eh_set_lpm() on non-SATA
  hosts (bsc#1175995,jsc#SLE-15608).
- ata: let compiler optimize out ata_dev_config_ncq() on non-SATA
  hosts (bsc#1175995,jsc#SLE-15608).
- ata: add CONFIG_SATA_HOST=n version of ata_ncq_enabled()
  (bsc#1175995,jsc#SLE-15608).
- ata: separate PATA timings code from libata-core.c
  (bsc#1175995,jsc#SLE-15608).
- ata: fix CodingStyle issues in PATA timings code
  (bsc#1175995,jsc#SLE-15608).
- ata: remove EXPORT_SYMBOL_GPL()s not used by modules
  (bsc#1175995,jsc#SLE-15608).
- ata: move EXPORT_SYMBOL_GPL()s close to exported code
  (bsc#1175995,jsc#SLE-15608).
- ata: optimize ata_scsi_rbuf[] size (bsc#1175995,jsc#SLE-15608).
- ata: optimize struct ata_force_param size
  (bsc#1175995,jsc#SLE-15608).
- ata: use COMMAND_LINE_SIZE for ata_force_param_buf[] size
  (bsc#1175995,jsc#SLE-15608).
- ata: simplify ata_scsiop_inq_89() (bsc#1175995,jsc#SLE-15608).
- sata_promise: use ata_cable_sata() (bsc#1175995,jsc#SLE-15608).
- ata: make SATA_PMP option selectable only if any SATA host
  driver is enabled (bsc#1175995,jsc#SLE-15608).
- ata: expose ncq_enable_prio sysfs attribute only on NCQ capable
  hosts (bsc#1175995,jsc#SLE-15608).
- ata: remove stale maintainership information from core code
  (bsc#1175995,jsc#SLE-15608).
- ahci: Add Intel Comet Lake PCH-V PCI ID
  (bsc#1175995,jsc#SLE-15608).
- ahci: Add Intel Comet Lake PCH-H PCI ID
  (bsc#1175995,jsc#SLE-15608).
- libata: Assign OF node to the SCSI device
  (bsc#1175995,jsc#SLE-15608).
- AHCI: Add support for Loongson 7A1000 SATA controller
  (bsc#1175995,jsc#SLE-15608).
- libata: transport: Use scnprintf() for avoiding potential
  (bsc#1175995,jsc#SLE-15608).
- commit 75956e8
* Wed Sep  9 2020 hare@suse.de
- blk-mq: insert flush request to the front of dispatch queue
  (bsc#1175995,jsc#SLE-15608).
- block, bfq: fix overwrite of bfq_group pointer in
  bfq_find_set_group() (bsc#1175995,jsc#SLE-15608).
- block: Remove used kblockd_schedule_work_on()
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: Remove some unused function arguments
  (bsc#1175995,jsc#SLE-15608).
- null_blk: remove unused fields in 'nullb_cmd'
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: insert passthrough request into hctx->dispatch directly
  (bsc#1175995,jsc#SLE-15608).
- commit 9de5f0d
* Wed Sep  9 2020 hare@suse.de
- ata: pata_arasan_cf: Use dma_request_chan() instead
  (bsc#1175995,jsc#SLE-15608).
- pata_pcmia: add SanDisk High (>8G) CF card to supported list
  (bsc#1175995,jsc#SLE-15608).
- drivers/block/null_blk_main.c: fix uninitialized var warnings
  (bsc#1175995,jsc#SLE-15608).
- drivers/block/null_blk_main.c: fix layout
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: bsg: add handler (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: block: add blkdev_compat_ptr_ioctl
  (bsc#1175995,jsc#SLE-15608).
- scsi: sd_zbc: Rename sd_zbc_check_zones()
  (bsc#1175995,jsc#SLE-15608).
- scsi: sd_zbc: Simplify sd_zbc_check_zones()
  (bsc#1175995,jsc#SLE-15608).
- ata/acard_ahci: remove unused variable n_elem
  (bsc#1175995,jsc#SLE-15608).
- ata: pata_macio: fix comparing pointer to 0
  (bsc#1175995,jsc#SLE-15608).
- ata: ahci_brcm: BCM7216 reset is self de-asserting
  (bsc#1175995,jsc#SLE-15608).
- ata: ahci_brcm: Perform reset after obtaining resources
  (bsc#1175995,jsc#SLE-15608).
- ata: brcm: fix reset controller API usage
  (bsc#1175995,jsc#SLE-15608).
- ata: brcm: mark PM functions as __maybe_unused
  (bsc#1175995,jsc#SLE-15608).
- ata: ahci_brcm: Support BCM7216 reset controller name
  (bsc#1175995,jsc#SLE-15608).
- ata: ahci_brcm: Add a shutdown callback
  (bsc#1175995,jsc#SLE-15608).
- ata: ahci_brcm: Manage reset line during suspend/resume
  (bsc#1175995,jsc#SLE-15608).
- commit 6ebf273
* Wed Sep  9 2020 hare@suse.de
- partitions/ldm: fix spelling mistake "to" -> "too"
  (bsc#1175995,jsc#SLE-15608).
- block, bfq: improve arithmetic division in bfq_delta()
  (bsc#1175995,jsc#SLE-15608).
- block/bfq: remove unused bfq_class_rt which never used
  (bsc#1175995,jsc#SLE-15608).
- block: mark zone-mgmt bios with REQ_SYNC
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: Document functions for sending request
  (bsc#1175995,jsc#SLE-15608).
- commit 0991616
* Wed Sep  9 2020 hare@suse.de
- null_blk: Fix zone write handling (bsc#1175995,jsc#SLE-15608).
- fs: move guard_bio_eod() after bio_set_op_attrs
  (bsc#1175995,jsc#SLE-15608).
- block: remove unused mp_bvec_last_segment
  (bsc#1175995,jsc#SLE-15608).
- null_blk: Fix REQ_OP_ZONE_CLOSE handling
  (bsc#1175995,jsc#SLE-15608).
- block: add bio_truncate to fix guard_bio_eod
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: block: handle add zone open, close and finish
  ioctl (bsc#1175995,jsc#SLE-15608).
- block: fix memleak when __blk_rq_map_user_iov() is failed
  (bsc#1175995,jsc#SLE-15608).
- block: Fix a lockdep complaint triggered by request queue
  flushing (bsc#1175995,jsc#SLE-15608).
- block: end bio with BLK_STS_AGAIN in case of non-mq devs and
  REQ_NOWAIT (bsc#1175995,jsc#SLE-15608).
- blk-cgroup: remove blkcg_drain_queue
  (bsc#1175995,jsc#SLE-15608).
- block: fix NULL pointer dereference in account statistics with
  IDE (bsc#1175995,jsc#SLE-15608).
- scsi: sd_zbc: Improve report zones error printout
  (bsc#1175995,jsc#SLE-15608).
- commit f7001e1
* Wed Sep  9 2020 hare@suse.de
- bfq-iosched: Ensure bio->bi_blkg is valid before using it
  (bsc#1175995,jsc#SLE-15608).
- null_blk: remove unused variable warning on
  !CONFIG_BLK_DEV_ZONED (bsc#1175995,jsc#SLE-15608).
- brd: warn on un-aligned buffer (bsc#1175995,jsc#SLE-15608).
- brd: remove max_hw_sectors queue limit
  (bsc#1175995,jsc#SLE-15608).
- block: set the zone size in blk_revalidate_disk_zones atomically
  (bsc#1175995,jsc#SLE-15608).
- block: don't handle bio based drivers in
  blk_revalidate_disk_zones (bsc#1175995,jsc#SLE-15608).
- block: allocate the zone bitmaps lazily
  (bsc#1175995,jsc#SLE-15608).
- block: replace seq_zones_bitmap with conv_zones_bitmap
  (bsc#1175995,jsc#SLE-15608).
- block: simplify blkdev_nr_zones (bsc#1175995,jsc#SLE-15608).
- block: remove the empty line at the end of blk-zoned.c
  (bsc#1175995,jsc#SLE-15608).
- null_blk: cleanup null_gendisk_register
  (bsc#1175995,jsc#SLE-15608).
- null_blk: fix zone size paramter check
  (bsc#1175995,jsc#SLE-15608).
- block: don't send uevent for empty disk when not invalidating
  (bsc#1175995,jsc#SLE-15608).
- commit ad5fd19
* Wed Sep  9 2020 hare@suse.de
- ata: ahci-imx: Covert to use GPIO descriptor
  (bsc#1175995,jsc#SLE-15608).
- compat_ioctl: reimplement SG_IO handling
  (bsc#1175995,jsc#SLE-15608).
- block: move clearing bd_invalidated into check_disk_size_change
  (bsc#1175995,jsc#SLE-15608).
- block: remove (__)blkdev_reread_part as an exported API
  (bsc#1175995,jsc#SLE-15608).
- block: move rescan_partitions to fs/block_dev.c
  (bsc#1175995,jsc#SLE-15608).
- scsi: sd_zbc: Remove set but not used variable 'buflen'
  (bsc#1175995,jsc#SLE-15608).
- scsi: sd_zbc: Cleanup sd_zbc_alloc_report_buffer()
  (bsc#1175995,jsc#SLE-15608).
- null_blk: Add zone_nr_conv to features
  (bsc#1175995,jsc#SLE-15608).
- commit a39b51e
* Wed Sep  9 2020 hare@suse.de
- null_blk: add zone open, close, and finish support
  (bsc#1175995,jsc#SLE-15608).
- dm: add zone open, close and finish support
  (bsc#1175995,jsc#SLE-15608).
- commit d1eb54b
* Wed Sep  9 2020 hare@suse.de
- null_blk: Enable modifying 'submit_queues' after an instance
  has been configured (bsc#1175995,jsc#SLE-15608).
- null_blk: Improve nullb_device_##NAME##_store() readability
  (bsc#1175995,jsc#SLE-15608).
- commit 7c2a4d9
* Wed Sep  9 2020 hare@suse.de
- Revert "block: split bio if the only bvec's length is > SZ_4K"
  (bsc#1175995,jsc#SLE-15608).
- block: add iostat counters for flush requests
  (bsc#1175995,jsc#SLE-15608).
- block,bfq: Skip tracing hooks if possible
  (bsc#1175995,jsc#SLE-15608).
- block: sed-opal: Introduce SUM_SET_LIST parameter and append
  it using 'add_token_u64' (bsc#1175995,jsc#SLE-15608).
- blk-cgroup: cgroup_rstat_updated() shouldn't be called on
  (bsc#1175995,jsc#SLE-15608).
- sbitmap: Delete sbitmap_any_bit_clear()
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: Delete blk_mq_has_free_tags() and blk_mq_can_queue()
  (bsc#1175995,jsc#SLE-15608).
- block: split bio if the only bvec's length is > SZ_4K
  (bsc#1175995,jsc#SLE-15608).
- block: still try to split bio if the bvec crosses pages
  (bsc#1175995,jsc#SLE-15608).
- blk-cgroup: reimplement basic IO stats using cgroup rstat
  (bsc#1175995,jsc#SLE-15608).
- blk-cgroup: remove now unused
  blkg_print_stat_{bytes|ios}_recursive()
  (bsc#1175995,jsc#SLE-15608).
- blk-throtl: stop using blkg->stat_bytes and ->stat_ios
  (bsc#1175995,jsc#SLE-15608).
- bfq-iosched: stop using blkg->stat_bytes and ->stat_ios
  (bsc#1175995,jsc#SLE-15608).
- bfq-iosched: relocate bfqg_*rwstat*() helpers
  (bsc#1175995,jsc#SLE-15608).
- block: add zone open, close and finish ioctl support
  (bsc#1175995,jsc#SLE-15608).
- block: avoid blk_bio_segment_split for small I/O operations
  (bsc#1175995,jsc#SLE-15608).
- block: sed-opal: Introduce Opal Datastore UID
  (bsc#1175995,jsc#SLE-15608).
- block: sed-opal: Add support to read/write opal tables
  generically (bsc#1175995,jsc#SLE-15608).
- block: sed-opal: Generalizing write data to any opal table
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: Make blk_mq_run_hw_queue() return void
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: fill header with kernel-doc (bsc#1175995,jsc#SLE-15608).
- blk-mq: remove needless goto from blk_mq_get_driver_tag
  (bsc#1175995,jsc#SLE-15608).
- block: reorder bio::__bi_remaining for better packing
  (bsc#1175995,jsc#SLE-15608).
- block: Reduce the amount of memory used for tag sets
  (bsc#1175995,jsc#SLE-15608).
- block: Reduce the amount of memory required per request queue
  (bsc#1175995,jsc#SLE-15608).
- block: Remove the synchronize_rcu() call from
  __blk_mq_update_nr_hw_queues() (bsc#1175995,jsc#SLE-15608).
- block: account statistics for passthrough requests
  (bsc#1175995,jsc#SLE-15608).
- blk-stat: Optimise blk_stat_add() (bsc#1175995,jsc#SLE-15608).
- blk-mq: Embed counters into struct mq_inflight
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: Reuse callback in blk_mq_in_flight*()
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: Inline status checkers (bsc#1175995,jsc#SLE-15608).
- block: Reduce sysfs_lock locking inside blk_cleanup_queue()
  (bsc#1175995,jsc#SLE-15608).
- block: Remove "dying" checks from sysfs callbacks
  (bsc#1175995,jsc#SLE-15608).
- block: Remove request_queue.nr_queues
  (bsc#1175995,jsc#SLE-15608).
- block: Fix three kernel-doc warnings
  (bsc#1175995,jsc#SLE-15608).
- ata: pata_artop: make arrays static const, makes object
  (bsc#1175995,jsc#SLE-15608).
- ata_piix: remove open-coded dmi_match(DMI_OEM_STRING)
  (bsc#1175995,jsc#SLE-15608).
- ata: sata_mv, avoid trigerrable BUG_ON
  (bsc#1175995,jsc#SLE-15608).
- ata: make qc_prep return ata_completion_errors
  (bsc#1175995,jsc#SLE-15608).
- ata: define AC_ERR_OK (bsc#1175995,jsc#SLE-15608).
- ata: Documentation, fix function names
  (bsc#1175995,jsc#SLE-15608).
- commit bdb6a8c
* Wed Sep  9 2020 hare@suse.de
- ata: libahci_platform: Fix regulator_get_optional() misuse
  (bsc#1175995,jsc#SLE-15608).
- block: Fix elv_support_iosched() (bsc#1175995,jsc#SLE-15608).
- parisc: Remove 32-bit DMA enforcement from sba_iommu
  (bsc#1175995,jsc#SLE-15608).
- rq-qos: get rid of redundant wbt_update_limits()
  (bsc#1175995,jsc#SLE-15608).
- ata: libahci_platform: Add of_node_put() before loop exit
  (bsc#1175995,jsc#SLE-15608).
- null_blk: format pr_* logs with pr_fmt
  (bsc#1175995,jsc#SLE-15608).
- null_blk: match the type of parameter nr_devices
  (bsc#1175995,jsc#SLE-15608).
- null_blk: do not fail the module load with zero devices
  (bsc#1175995,jsc#SLE-15608).
- null_blk: validate the number of devices
  (bsc#1175995,jsc#SLE-15608).
- null_blk: fix module name at log message
  (bsc#1175995,jsc#SLE-15608).
- docs: block: null_blk: enhance document style
  (bsc#1175995,jsc#SLE-15608).
- commit 05df433
* Wed Sep  9 2020 hare@suse.de
- null_blk: create a helper for badblocks
  (bsc#1175995,jsc#SLE-15608).
- commit e742a9e
* Wed Sep  9 2020 hare@suse.de
- null_blk: create a helper for throttling
  (bsc#1175995,jsc#SLE-15608).
- commit c77d602
* Wed Sep  9 2020 hare@suse.de
- libata: switch remaining drivers to use
  dma_set_mask_and_coherent (bsc#1175995,jsc#SLE-15608).
- sata_sil24: use dma_set_mask_and_coherent
  (bsc#1175995,jsc#SLE-15608).
- sata_qstor: use dma_set_mask_and_coherent
  (bsc#1175995,jsc#SLE-15608).
- sata_nv: use dma_set_mask_and_coherent
  (bsc#1175995,jsc#SLE-15608).
- sata_mv: use dma_set_mask_and_coherent
  (bsc#1175995,jsc#SLE-15608).
- pdc_adma: use dma_set_mask_and_coherent
  (bsc#1175995,jsc#SLE-15608).
- ahci: use dma_set_mask_and_coherent (bsc#1175995,jsc#SLE-15608).
- acard_ahci: use dma_set_mask_and_coherent
  (bsc#1175995,jsc#SLE-15608).
- ata/pata_buddha: Probe via modalias instead of initcall
  (bsc#1175995,jsc#SLE-15608).
- commit 922a0a1
* Wed Sep  9 2020 nsaenzjulienne@suse.de
- Update config files (jsc#SLE-15887).
- commit 244ffd7
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/perf: Fix reading of MSR[HV/PR] bits in trace-imc
  (jsc#SLE-13513).
- powerpc/perf: Add kernel support for new MSR[HV PR] bits in
  trace-imc (jsc#SLE-13513).
- commit b6f4472
* Wed Sep  9 2020 colyli@suse.de
- dm: don't call report zones for more than the user requested
  (git fixes (block drivers)).
- dm rq: don't call blk_mq_queue_stopped() in dm_stop_queue()
  (git fixes (block drivers)).
- md: raid0/linear: fix dereference before null check on pointer
  mddev (git fixes (block drivers)).
- sbitmap: Consider cleared bits in sbitmap_bitmap_show()
  (git fixes (block drivers)).
- blktrace: fix debugfs use after free (git fixes (block
  drivers)).
- block: revert back to synchronous request_queue removal (git
  fixes (block drivers)).
- block: add docs for gendisk / request_queue refcount helpers
  (git fixes (block drivers)).
- dm integrity: fix integrity recalculation that is improperly
  skipped (git fixes (block drivers)).
- virtio-blk: free vblk-vqs in error path of virtblk_probe()
  (git fixes (block drivers)).
- dm writecache: add cond_resched to loop in
  persistent_memory_claim() (git fixes (block drivers)).
- dm writecache: correct uncommitted_block when discarding
  uncommitted entry (git fixes (block drivers)).
- dm zoned: assign max_io_len correctly (git fixes (block
  drivers)).
- bcache: Convert pr_<level> uses to a more typical style (git
  fixes (block drivers)).
- commit 35db4b2
* Wed Sep  9 2020 colyli@suse.de
- blacklist.conf: add 7bf137298cb73afdb8c5536e474f7ba71ab1c235
- commit cdf662f
* Wed Sep  9 2020 dwagner@suse.de
- scsi: lpfc: Fix setting IRQ affinity with an empty CPU mask
  (git-fixes).
- scsi: qla2xxx: Fix regression on sparc64 (git-fixes).
- commit b922436
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/xmon: Use `dcbf` inplace of `dcbi` instruction for
  64bit Book3S (bsc#1065729).
- commit 9cbba57
* Wed Sep  9 2020 dwagner@suse.de
- scsi: libfc: Fix for double free() (bsc#1174899).
- commit 941605d
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/watchpoint/xmon: Support 2nd DAWR (jsc#SLE-12936).
- powerpc/watchpoint/xmon: Don't allow breakpoint overwriting
  (jsc#SLE-12936).
- powerpc/xmon: Allow listing and clearing breakpoints in
  read-only mode (jsc#SLE-15857 jsc#SLE-13618).
- commit 1c156c6
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/book3s64/radix: Add kernel command line option
  to disable radix GTSE (bsc#1055186 ltc#153436 FATE#323286
  jsc#SLE-13512).
- powerpc/mm/radix: Create separate mappings for hot-plugged
  memory (bsc#1055186 ltc#153436 FATE#323286).
- powerpc/mm/radix: Remove split_kernel_mapping() (bsc#1055186
  ltc#153436 FATE#323286).
- powerpc/mm/radix: Free PUD table when freeing pagetable
  (bsc#1055186 ltc#153436 FATE#323286).
- powerpc/mm/radix: Fix PTE/PMD fragment count for early page
  table mappings (bsc#1055186 ltc#153436 FATE#323286).
- powerpc/prom: Enable Radix GTSE in cpu pa-features (bsc#1055186
  ltc#153436 FATE#323286 jsc#SLE-13512).
- powerpc/mm: Enable radix GTSE only if supported (bsc#1055186
  ltc#153436 FATE#323286 jsc#SLE-13512).
- commit d06aeea
* Wed Sep  9 2020 msuchanek@suse.de
- Refresh patches.suse/nvdimm-Avoid-race-between-probe-and-reading-device-a.patch
  Update submit URL to v2
- commit f6fe239
* Wed Sep  9 2020 tiwai@suse.de
- blacklist.conf: Add an inapplicable entry
- commit de0e335
* Wed Sep  9 2020 tiwai@suse.de
- nl80211: fix NL80211_ATTR_HE_6GHZ_CAPABILITY usage
  (jsc#SLE-13430).
- staging: rtl8723bs: remove mgmt_frame_register method
  (jsc#SLE-13430).
- commit 808babd
* Wed Sep  9 2020 tiwai@suse.de
- cfg80211: Adjust 6 GHz frequency to channel conversion
  (jsc#SLE-13430).
- mac80211: reduce packet loss event false positives
  (jsc#SLE-13430).
- cfg80211: regulatory: reject invalid hints (jsc#SLE-13430).
- wireless: fix wrong 160/80+80 MHz setting (jsc#SLE-13430).
- mac80211: improve AQL aggregation estimation for low data rates
  (jsc#SLE-13430).
- mac80211: factor out code to look up the average packet length
  duration for a rate (jsc#SLE-13430).
- mac80211: use rate provided via status->rate on
  ieee80211_tx_status_ext for AQL (jsc#SLE-13430).
- ipw2x00: switch from 'pci_' to 'dma_' API (jsc#SLE-13430).
- ipw2100: Use GFP_KERNEL instead of GFP_ATOMIC in some memory
  allocation (jsc#SLE-13430).
- iwlwifi: yoyo: don't print failure if debug firmware is missing
  (jsc#SLE-13430).
- mac80211: Do not report beacon loss if beacon filtering enabled
  (jsc#SLE-13430).
- mac80211: fix misplaced while instead of if (jsc#SLE-13430).
- nl80211: use eth_zero_addr() to clear mac address
  (jsc#SLE-13430).
- mac80211: use eth_zero_addr() to clear mac address
  (jsc#SLE-13430).
- mac8211: fix struct initialisation (jsc#SLE-13430).
- mac80211: Handle special status codes in SAE commit
  (jsc#SLE-13430).
- mac80211: warn only once in check_sdata_in_driver() at each
  caller (jsc#SLE-13430).
- nl80211: support 4-way handshake offloading for WPA/WPA2-PSK
  in AP mode (jsc#SLE-13430).
- mac80211: add a function for running rx without passing skbs
  to the stack (jsc#SLE-13430).
- cfg80211: Add support to advertize OCV support (jsc#SLE-13430).
- commit 2f17042
* Wed Sep  9 2020 tiwai@suse.de
- mac80211: parse radiotap header when selecting Tx queue
  (jsc#SLE-13430).
- mac80211: remove unused flags argument in transmit functions
  (jsc#SLE-13430).
- mac80211: use same flag everywhere to avoid sequence number
  overwrite (jsc#SLE-13430).
- mac80211: do not overwrite the sequence number if requested
  (jsc#SLE-13430).
- mac80211: add radiotap flag to prevent sequence number overwrite
  (jsc#SLE-13430).
- mac80211: never drop injected frames even if normally not
  allowed (jsc#SLE-13430).
- cfg80211/mac80211: avoid bss color setting in non-HE modes
  (jsc#SLE-13430).
- mac80211: calculate skb hash early when using itxq
  (jsc#SLE-13430).
- mac80211: improve AQL tx airtime estimation (jsc#SLE-13430).
- cfg80211/mac80211: add connected to auth server to station info
  (jsc#SLE-13430).
- cfg80211/mac80211: add connected to auth server to meshconf
  (jsc#SLE-13430).
- cfg80211/mac80211: add mesh_param "mesh_nolearn" to skip path
  discovery (jsc#SLE-13430).
- cfg80211: allow the low level driver to flush the BSS table
  (jsc#SLE-13430).
- mac80211: Use fallthrough pseudo-keyword (jsc#SLE-13430).
- nl80211: Simplify error handling path in
  'nl80211_trigger_scan()' (jsc#SLE-13430).
- nl80211: Remove a misleading label in 'nl80211_trigger_scan()'
  (jsc#SLE-13430).
- net/wireless: mac80211.h: drop duplicate words in comments
  (jsc#SLE-13430).
- net/wireless: cfg80211.h: drop duplicate words in comments
  (jsc#SLE-13430).
- net/wireless: wireless.h: drop duplicate word in comments
  (jsc#SLE-13430).
- cfg80211: allow vendor dumpit to terminate by returning 0
  (jsc#SLE-13430).
- mac80211: remove the need for variable rates_idx
  (jsc#SLE-13430).
- nl80211: S1G band and channel definitions (jsc#SLE-13430).
- iwlegacy: remove redundant initialization of variable tid
  (jsc#SLE-13430).
- ipw2200: use generic power management (jsc#SLE-13430).
- ipw2100: use generic power management (jsc#SLE-13430).
- net: wireless: intel: fix wiki website url (jsc#SLE-13430).
- iwlwifi: Replace zero-length array with flexible-array
  (jsc#SLE-13430).
- iwlwifi: mvm: Remove unused inline function
  iwl_mvm_tid_to_ac_queue (jsc#SLE-13430).
- iwlwifi: mvm: fix gcc-10 zero-length-bounds warning
  (jsc#SLE-13430).
- iwlwifi: mvm: remove redundant assignment to variable ret
  (jsc#SLE-13430).
- iwlwifi: fix config variable name in comment (jsc#SLE-13430).
- iwlwifi: mvm: Fix avg-power report (jsc#SLE-13430).
- iwlwifi: Don't IWL_WARN on FW reconfiguration (jsc#SLE-13430).
- iwlwifi: Extended Key ID support for mvm and dvm
  (jsc#SLE-13430).
- net: wireless: kerneldoc fixes (jsc#SLE-13430).
- net: mac80211: kerneldoc fixes (jsc#SLE-13430).
- commit d7dd6fe
* Wed Sep  9 2020 tiwai@suse.de
- mac80211: remove STA txq pending airtime underflow warning
  (jsc#SLE-13430).
- mac80211: Fix bug in Tx ack status reporting in 802.3 xmit path
  (jsc#SLE-13430).
- cfg80211: check vendor command doit pointer before use
  (jsc#SLE-13430).
- mac80211: mesh: Free pending skb when destroying a mpath
  (jsc#SLE-13430).
- mac80211: mesh: Free ie data when leaving mesh (jsc#SLE-13430).
- mac80211: fix warning in 6 GHz IE addition in mesh mode
  (jsc#SLE-13430).
- iwlwifi: Make some Killer Wireless-AC 1550 cards work again
  (jsc#SLE-13430).
- iwlwifi: fix crash in iwl_dbg_tlv_alloc_trigger (jsc#SLE-13430).
- iwlwifi: mvm: don't call iwl_mvm_free_inactive_queue() under
  RCU (jsc#SLE-13430).
- nl80211: fix memory leak when parsing NL80211_ATTR_HE_BSS_COLOR
  (jsc#SLE-13430).
- nl80211: don't return err unconditionally in nl80211_start_ap()
  (jsc#SLE-13430).
- mac80211: allow rx of mesh eapol frames with default rx key
  (jsc#SLE-13430).
- mac80211: skip mpath lookup also for control port tx
  (jsc#SLE-13430).
- mac80211: Fix dropping broadcast packets in 802.11 encap
  (jsc#SLE-13430).
- mac80211: simplify mesh code (jsc#SLE-13430).
- mac80211: fix control port tx status check (jsc#SLE-13430).
- ieee80211: Add missing and new AKM suite selector definitions
  (jsc#SLE-13430).
- net: fix wiki website url mac80211 and wireless files
  (jsc#SLE-13430).
- mac80211: initialize return flags in HE 6 GHz operation parsing
  (jsc#SLE-13430).
- cfg80211: fix management registrations deadlock (jsc#SLE-13430).
- cfg80211: support bigger kek/kck key length (jsc#SLE-13430).
- mac80211: set short_slot for 6 GHz band (jsc#SLE-13430).
- mac80211: Consider 6 GHz band when handling power constraint
  (jsc#SLE-13430).
- mac80211: accept aggregation sessions on 6 GHz (jsc#SLE-13430).
- cfg80211: require HE capabilities for 6 GHz band
  (jsc#SLE-13430).
- cfg80211: reject HT/VHT capabilities on 6 GHz band
  (jsc#SLE-13430).
- cfg80211: treat 6 GHz channels as valid regardless of capability
  (jsc#SLE-13430).
- mac80211: Add HE 6GHz capabilities element to probe request
  (jsc#SLE-13430).
- mac80211: use HE 6 GHz band capability and pass it to the driver
  (jsc#SLE-13430).
- mac80211: check the correct bit for EMA AP (jsc#SLE-13430).
- mac80211: determine chandef from HE 6 GHz operation
  (jsc#SLE-13430).
- mac80211: avoid using ext NSS high BW if not supported
  (jsc#SLE-13430).
- mac80211: do not allow HT/VHT IEs in 6 GHz mesh mode
  (jsc#SLE-13430).
- mac80211: build HE operation with 6 GHz oper information
  (jsc#SLE-13430).
- mac80211: add HE 6 GHz Band Capability element (jsc#SLE-13430).
- cfg80211: add and expose HE 6 GHz band capabilities
  (jsc#SLE-13430).
- mac80211: add HE 6 GHz Band Capabilities into parse extension
  (jsc#SLE-13430).
- cfg80211: handle 6 GHz capability of new station
  (jsc#SLE-13430).
- ieee80211: add HE ext EIDs and 6 GHz capability defines
  (jsc#SLE-13430).
- ieee80211: add code to obtain and parse 6 GHz operation field
  (jsc#SLE-13430).
- ieee80211: definitions for reduced neighbor reports
  (jsc#SLE-13430).
- cfg80211: add a helper to identify 6 GHz PSCs (jsc#SLE-13430).
- nl80211: really allow client-only BIGTK support (jsc#SLE-13430).
- mac80211: Add new AMPDU factor macro for HE peer caps
  (jsc#SLE-13430).
- ieee80211: S1G defines (jsc#SLE-13430).
- cfg80211: fix debugfs rename crash (jsc#SLE-13430).
- mac80211: mesh: fix discovery timer re-arming issue / crash
  (jsc#SLE-13430).
- ieee80211: add WPA3 OWE AKM suite selector (jsc#SLE-13430).
- ieee80211: fix 'the' doubling in comments (jsc#SLE-13430).
- trivial: mac80211: fix indentation (jsc#SLE-13430).
- ieee80211: fix HE SPR size calculation (jsc#SLE-13430).
- mac80211: fix ieee80211_he_oper_size() comment (jsc#SLE-13430).
- commit 6bf91a5
* Wed Sep  9 2020 tiwai@suse.de
- cfg80211: adapt to new channelization of the 6GHz band
  (jsc#SLE-13430).
- cfg80211: fix 6 GHz frequencies to kHz (jsc#SLE-13430).
- mac80211: support control port TX status reporting
  (jsc#SLE-13430).
- mac80211: fix HT-Control field reception for management frames
  (jsc#SLE-13430).
- wireless: Use linux/stddef.h instead of stddef.h
  (jsc#SLE-13430).
- cfg80211: fix CFG82011_CRDA_SUPPORT still mentioning internal
  regdb (jsc#SLE-13430).
- nl80211: Add support to configure TID specific Tx rate
  configuration (jsc#SLE-13430).
- mac80211: allow SA-QUERY processing in userspace
  (jsc#SLE-13430).
- nl80211: add ability to report TX status for control port TX
  (jsc#SLE-13430).
- mac80211: Replace zero-length array with flexible-array
  (jsc#SLE-13430).
- cfg80211: Replace zero-length array with flexible-array
  (jsc#SLE-13430).
- nl80211: support scan frequencies in KHz (jsc#SLE-13430).
- nl80211: add KHz frequency offset for most wifi commands
  (jsc#SLE-13430).
- cfg80211: add KHz variants of frame RX API (jsc#SLE-13430).
- nl80211: simplify peer specific TID configuration
  (jsc#SLE-13430).
- cfg80211: add support for TID specific AMSDU configuration
  (jsc#SLE-13430).
- mac80211: fix variable names in TID config methods
  (jsc#SLE-13430).
- cfg80211: fix mask type in cfg80211_tid_cfg structure
  (jsc#SLE-13430).
- iwlwifi: bump FW API to 56 for AX devices (jsc#SLE-13430).
- iwlwifi: mvm: add support for range request version 10
  (jsc#SLE-13430).
- iwlwifi: mvm: fix aux station leak (jsc#SLE-13430).
- iwlwifi: move txq-specific from trans_pcie to common trans
  (jsc#SLE-13430).
- iwlwifi: move iwl_txq and substructures to a common trans header
  (jsc#SLE-13430).
- iwlwifi: pcie: gen3: indicate 8k/12k RB size to device
  (jsc#SLE-13430).
- iwlwifi: acpi: evaluate dsm to enable 5.2 bands in Indonesia
  (jsc#SLE-13430).
- iwlwifi: acpi: support device specific method (DSM)
  (jsc#SLE-13430).
- iwlwifi: pcie: keep trans instead of trans_pcie in iwl_txq
  (jsc#SLE-13430).
- iwlwifi: pcie: don't count on the FW to set persistence mode
  (jsc#SLE-13430).
- iwlwifi: set NO_HE if the regulatory domain forbids it
  (jsc#SLE-13430).
- mac80211: TX legacy rate control for Beacon frames
  (jsc#SLE-13430).
- mac80211: fix two missing documentation entries (jsc#SLE-13430).
- cfg80211: reject channels/chandefs with KHz offset >= 1000
  (jsc#SLE-13430).
- mac80211: add freq_offset to RX status (jsc#SLE-13430).
- mac80211: handle channel frequency offset (jsc#SLE-13430).
- cfg80211: express channels with a KHz component (jsc#SLE-13430).
- ieee80211: share 802.11 unit conversion helpers (jsc#SLE-13430).
- mac80211: minstrel_ht_assign_best_tp_rates: remove redundant
  test (jsc#SLE-13430).
- mac80211: Fail association when AP has no legacy rates
  (jsc#SLE-13430).
- mac80211: agg-tx: add an option to defer ADDBA transmit
  (jsc#SLE-13430).
- mac80211: agg-tx: refactor sending addba (jsc#SLE-13430).
- commit 5968d38
* Wed Sep  9 2020 tiwai@suse.de
- mac80211: Skip entries with HE membership selector
  (jsc#SLE-13430).
- cfg80211: Parse HE membership selector (jsc#SLE-13430).
- mac80211: Don't destroy auth data in case of anti-clogging
  (jsc#SLE-13430).
- mac80211: add twt_protected flag to the bss_conf structure
  (jsc#SLE-13430).
- mac80211: implement Operating Mode Notification extended NSS
  support (jsc#SLE-13430).
- mac80211: Process multicast RX registration for Action frames
  (jsc#SLE-13430).
- nl80211: allow client-only BIGTK support (jsc#SLE-13430).
- cfg80211: support multicast RX registration (jsc#SLE-13430).
- cfg80211: change internal management frame registration API
  (jsc#SLE-13430).
- mac80211: Report beacon protection failures to user space
  (jsc#SLE-13430).
- cfg80211: Unprotected Beacon frame RX indication
  (jsc#SLE-13430).
- mac80211: fix drv_config_iface_filter() behaviour
  (jsc#SLE-13430).
- mac80211: mlme: remove duplicate AID bookkeeping
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: differentiate ax210 hw with same hw type
  (jsc#SLE-13430).
- iwlwifi: pcie: skip fragmented receive buffers (jsc#SLE-13430).
- iwlwifi: remove outdated copyright print/module statement
  (jsc#SLE-13430).
- iwlwifi: mvm: don't transmit on unallocated queue
  (jsc#SLE-13430).
- iwlwifi: tx: enable A-MSDU in low latency mode (jsc#SLE-13430).
- iwlwifi: use longer queues for 256-BA (jsc#SLE-13430).
- iwlwifi: pcie: gen2: use DMA pool for byte-count tables
  (jsc#SLE-13430).
- iwlwifi: pcie: remove some dead code (jsc#SLE-13430).
- iwlwifi: dbg: mark a variable __maybe_unused (jsc#SLE-13430).
- iwlwifi: mvm: attempt to allocate smaller queues
  (jsc#SLE-13430).
- iwlwifi: pcie: allocate much smaller byte-count table
  (jsc#SLE-13430).
- iwlwifi: dump api version in yaml format (jsc#SLE-13430).
- iwlwifi: pcie: convert all AX101 devices to the device tables
  (jsc#SLE-13430).
- iwlwifi: pcie: remove occurrences of 22000 in the FW name
  defines (jsc#SLE-13430).
- iwlwifi: pcie: convert QnJ with Hr to the device table
  (jsc#SLE-13430).
- iwlwifi: pcie: remove mangling for iwl_ax101_cfg_qu_hr
  (jsc#SLE-13430).
- iwlwifi: pcie: remove outdated comment about PCI RTPM reference
  (jsc#SLE-13430).
- iwlwifi: mvm: add IML/ROM information to the assertion dumps
  (jsc#SLE-13430).
- iwlwifi: move iwl_set_soc_latency to iwl-drv to be used by
  other op_modes (jsc#SLE-13430).
- iwlwifi: yoyo: remove magic number (jsc#SLE-13430).
- iwlwifi: mvm: initialize iwl_dev_tx_power_cmd to zero
  (jsc#SLE-13430).
- iwlwifi: dbg: set debug descriptor to NULL outside of
  iwl_fw_free_dump_desc (jsc#SLE-13430).
- iwlwifi: bump FW API to 55 for AX devices (jsc#SLE-13430).
- iwlwifi: yoyo: add D3 resume timepoint (jsc#SLE-13430).
- iwlwifi: mvm: set properly station flags in STA_HE_CTXT_CMD
  (jsc#SLE-13430).
- iwlwifi: avoid debug max amsdu config overwriting itself
  (jsc#SLE-13430).
- iwlwifi: mvm: remove iwlmvm's tfd_q_hang_detect module parameter
  (jsc#SLE-13430).
- commit 582f1cf
* Tue Sep  8 2020 tiwai@suse.de
- iwlwifi: mvm: stop supporting swcrypto and bt_coex_active
  module parameters (jsc#SLE-13430).
- iwlwifi: mvm: add support for range request command version 9
  (jsc#SLE-13430).
- iwlwifi: yoyo: don't access TLV before verifying len
  (jsc#SLE-13430).
- iwlwifi: remove antenna_coupling module parameter
  (jsc#SLE-13430).
- iwlwifi: yoyo: use hweight_long instead of bit manipulating
  (jsc#SLE-13430).
- iwlwifi: yoyo: add support for parsing SHARED_MEM_ALLOC version
  4 (jsc#SLE-13430).
- iwlwifi: fw api: fix PHY data 2/3 position (jsc#SLE-13430).
- ipw2x00: Fix comment for CLOCK_BOOTTIME constant
  (jsc#SLE-13430).
- iwlegacy: Replace zero-length array with flexible-array
  (jsc#SLE-13430).
- ipw2x00: Replace zero-length array with flexible-array
  (jsc#SLE-13430).
- ipw2x00: Remove a memory allocation failure log message
  (jsc#SLE-13430).
- iwlwifi: debug: set NPK buffer in context info (jsc#SLE-13430).
- iwlwifi: pcie: add new structs for So devices with long latency
  (jsc#SLE-13430).
- iwlwifi: pcie: add new structure for Qu devices with medium
  latency (jsc#SLE-13430).
- iwlwifi: mvm: tell firmware about required LTR delay
  (jsc#SLE-13430).
- iwlwifi: update few product names in AX family (jsc#SLE-13430).
- iwlwifi: pcie: add cfgs for SoCs with device ID 0x4FD0
  (jsc#SLE-13430).
- iwlwifi: add new cards for AX family (jsc#SLE-13430).
- iwlwifi: acpi: read TAS table from ACPI and send it to the FW
  (jsc#SLE-13430).
- iwlwifi: remove fw_monitor module parameter (jsc#SLE-13430).
- iwlwifi: remove deprecated and unused iwl_mvm_keyinfo struct
  (jsc#SLE-13430).
- iwlwifi: mvm: add framework for specific phy configuration
  (jsc#SLE-13430).
- iwlwifi: pcie: move iwl_pcie_ctxt_info_alloc_dma() to user
  (jsc#SLE-13430).
- iwlwifi: yoyo: support IWL_FW_INI_TIME_POINT_HOST_ALIVE_TIMEOUT
  time point (jsc#SLE-13430).
- iwlwifi: mvm: add DCM flag to rate pretty-print (jsc#SLE-13430).
- iwlwifi: pcie: gen2: minor code cleanups in byte table update
  (jsc#SLE-13430).
- iwlwifi: pcie: add n_window/ampdu to tx_queue debugfs
  (jsc#SLE-13430).
- iwlwifi: pcie: use seq_file for tx_queue debugfs file
  (jsc#SLE-13430).
- iwlwifi: support version 9 of WOWLAN_GET_STATUS notification
  (jsc#SLE-13430).
- iwlwifi: dbg: support multiple dumps in legacy dump flow
  (jsc#SLE-13430).
- iwlwifi: move API version lookup to common code (jsc#SLE-13430).
- iwlwifi: nvm: use iwl_nl80211_band_from_channel_idx
  (jsc#SLE-13430).
- iwlwifi: scan: remove support for fw scan api v13
  (jsc#SLE-13430).
- ipw2x00: make ipw_setup_deferred_work() void (jsc#SLE-13430).
- ipw2x00: make ipw_qos_association_resp() void (jsc#SLE-13430).
- netlink: remove NLA_EXACT_LEN_WARN (jsc#SLE-13430).
- nl80211: link recursive netlink nested policy (jsc#SLE-13430).
- iwlwifi: pcie: handle QuZ configs with killer NICs as well
  (jsc#SLE-13430).
- commit bb00397
* Tue Sep  8 2020 tiwai@suse.de
- mac80211: populate debugfs only after cfg80211 init
  (jsc#SLE-13430).
- iwlwifi: fix WGDS check when WRDS is disabled (jsc#SLE-13430).
- iwlwifi: mvm: fix inactive TID removal return value usage
  (jsc#SLE-13430).
- iwlwifi: mvm: Do not declare support for ACK Enabled Aggregation
  (jsc#SLE-13430).
- iwlwifi: mvm: limit maximum queue appropriately (jsc#SLE-13430).
- iwlwifi: pcie: indicate correct RB size to device
  (jsc#SLE-13430).
- iwlwifi: mvm: beacon statistics shouldn't go backwards
  (jsc#SLE-13430).
- iwlwifi: pcie: actually release queue memory in TVQM
  (jsc#SLE-13430).
- iwlwifi: actually check allocated conf_tlv pointer
  (jsc#SLE-13430).
- mac80211: fix channel switch trigger from unknown mesh peer
  (jsc#SLE-13430).
- mac80211: fix race in ieee80211_register_hw() (jsc#SLE-13430).
- cfg80211: fix kernel-doc notation (jsc#SLE-13430).
- nl80211: fix NL80211_ATTR_FTM_RESPONDER policy (jsc#SLE-13430).
- mac80211: fix authentication with iwlwifi/mvm (jsc#SLE-13430).
- iwlwifi: mvm: remove newline from rs_pretty_print_rate()
  (jsc#SLE-13430).
- iwlwifi: pcie: make iwl_pcie_cmdq_reclaim static
  (jsc#SLE-13430).
- iwlwifi: bump FW API to 53 for 22000 series (jsc#SLE-13430).
- iwlwifi: remove IWL_FW_DBG_DOMAIN macro (jsc#SLE-13430).
- iwlwifi: yoyo: enable yoyo by default (jsc#SLE-13430).
- iwlwifi: scan: support FW APIs with variable number of profiles
  (jsc#SLE-13430).
- iwlwifi: yoyo: don't block dumping internal memory when not
  in SRAM mode (jsc#SLE-13430).
- iwlwifi: remove support for QnJ HR FPGA (jsc#SLE-13430).
- iwlwifi: remove support for QnJ Hr STEP A (jsc#SLE-13430).
- iwlwifi: add trans_cfg for devices with long latency
  (jsc#SLE-13430).
- iwlwifi: add support for version 2 of SOC_CONFIGURATION_CMD
  (jsc#SLE-13430).
- iwlwifi: mvm: add support for non EDCA based measurements
  (jsc#SLE-13430).
- iwlwifi: remove unnecessary cfg mangling for Qu C and QuZ with
  Jf (jsc#SLE-13430).
- iwlwifi: convert QnJ with Jf devices to new config table
  (jsc#SLE-13430).
- iwlwifi: convert all Qu with Jf devices to the new config table
  (jsc#SLE-13430).
- iwlwifi: add HW step to new cfg device table (jsc#SLE-13430).
- iwlwifi: remove some unused extern declarations from
  iwl-config.h (jsc#SLE-13430).
- iwlwifi: move integrated, extra_phy and soc_latency to trans_cfg
  (jsc#SLE-13430).
- iwlwifi: mvm: enable SF also when we have HE (jsc#SLE-13430).
- iwlwifi: remove redundant iwl9560_2ac_cfg struct
  (jsc#SLE-13430).
- iwlwifi: mvm: rs-fw: fix some indentation (jsc#SLE-13430).
- iwlwifi: scan: support scan req cmd ver 14 (jsc#SLE-13430).
- commit 97ba9e0
* Tue Sep  8 2020 tiwai@suse.de
- iwlwifi: pass trans and NVM data to HE capability parsing
  (jsc#SLE-13430).
- iwlwifi: pcie: implement read_config32 (jsc#SLE-13430).
- iwlwifi: yoyo: add PCI config space region type (jsc#SLE-13430).
- iwlwifi: mvm: add soc latency support (jsc#SLE-13430).
- iwlwifi: move AX200 devices to the new table (jsc#SLE-13430).
- iwlwifi: remove trans entries from COMMON 9260 macro
  (jsc#SLE-13430).
- iwlwifi: move shared clock entries to new table (jsc#SLE-13430).
- iwlwifi: move pu devices to new table (jsc#SLE-13430).
- iwlwifi: remove 9260 devices with 0x1010 and 0x1210 subsytem
  IDs (jsc#SLE-13430).
- iwlwifi: convert the 9260-1x1 device to use the new parameters
  (jsc#SLE-13430).
- iwlwifi: move TH1 devices to the new table (jsc#SLE-13430).
- iwlwifi: map 9461 and 9462 using RF type and RF ID
  (jsc#SLE-13430).
- iwlwifi: add Pu/PnJ/Th device values to differentiate them
  (jsc#SLE-13430).
- iwlwifi: add GNSS differentiation to the device tables
  (jsc#SLE-13430).
- iwlwifi: add mac/rf types and 160MHz to the device tables
  (jsc#SLE-13430).
- iwlwifi: combine 9260 cfgs that only change names
  (jsc#SLE-13430).
- iwlwifi: move the remaining 0x2526 configs to the new table
  (jsc#SLE-13430).
- ipw2x00: Use scnprintf() for avoiding potential buffer overflow
  (jsc#SLE-13430).
- iwlegacy: Remove unneeded variable ret (jsc#SLE-13430).
- mac80211: driver can remain on channel if not using chan_ctx
  (jsc#SLE-13430).
- nl80211: clarify code in nl80211_del_station() (jsc#SLE-13430).
- cfg80211: Configure PMK lifetime and reauth threshold for
  PMKSA entries (jsc#SLE-13430).
- mac80211: Read rx_stats with perCPU pointers (jsc#SLE-13430).
- mac80211: Allow deleting stations in ibss mode to reset their
  state (jsc#SLE-13430).
- cfg80211: Add support for userspace to reset stations in IBSS
  mode (jsc#SLE-13430).
- mac80211: consider WLAN_EID_EXT_HE_OPERATION for parsing CRC
  (jsc#SLE-13430).
- nl80211: add PROTECTED_TWT nl80211 extended feature
  (jsc#SLE-13430).
- mac80211: HE: set missing bss_conf fields in AP mode
  (jsc#SLE-13430).
- nl80211: pass HE operation element to the driver
  (jsc#SLE-13430).
- nl80211/cfg80211: add support for non EDCA based ranging
  measurement (jsc#SLE-13430).
- mac80211: don't leave skb->next/prev pointing to stack
  (jsc#SLE-13430).
- mac80211: update documentation about tx power (jsc#SLE-13430).
- mac80211: handle no-preauth flag for control port
  (jsc#SLE-13430).
- nl80211: add no pre-auth attribute and ext. feature flag for
  ctrl. port (jsc#SLE-13430).
- cfg80211: fix documentation format (jsc#SLE-13430).
- mac80211: Add api to support configuring TID specific
  configuration (jsc#SLE-13430).
- nl80211: Add support to configure TID specific RTSCTS
  configuration (jsc#SLE-13430).
- nl80211: Add support to configure TID specific AMPDU
  configuration (jsc#SLE-13430).
- nl80211: Add support to configure TID specific retry
  configuration (jsc#SLE-13430).
- nl80211: modify TID-config API (jsc#SLE-13430).
- nl80211: Add NL command to support TID speicific configurations
  (jsc#SLE-13430).
- commit 5b09d8a
* Tue Sep  8 2020 tiwai@suse.de
- mac80211: Beacon protection using the new BIGTK (STA)
  (jsc#SLE-13430).
- mac80211: Beacon protection using the new BIGTK (AP)
  (jsc#SLE-13430).
- mac80211: Update BIP to support Beacon frames (jsc#SLE-13430).
- mac80211: Support BIGTK configuration for Beacon protection
  (jsc#SLE-13430).
- cfg80211: Support key configuration for Beacon protection
  (BIGTK) (jsc#SLE-13430).
- cfg80211: More error messages for key addition failures
  (jsc#SLE-13430).
- cfg80211: fix indentation errors (jsc#SLE-13430).
- cfg80211: merge documentations of field "dev" (jsc#SLE-13430).
- cfg80211: merge documentations of field "debugfsdir"
  (jsc#SLE-13430).
- cfg80211: drop duplicated documentation of field "reg_notifier"
  (jsc#SLE-13430).
- cfg80211: drop duplicated documentation of field "perm_addr"
  (jsc#SLE-13430).
- cfg80211: drop duplicated documentation of field "_net"
  (jsc#SLE-13430).
- cfg80211: drop duplicated documentation of field "registered"
  (jsc#SLE-13430).
- cfg80211: drop duplicated documentation of field "privid"
  (jsc#SLE-13430).
- cfg80211: drop duplicated documentation of field
  "probe_resp_offload" (jsc#SLE-13430).
- Revert "nl80211: add src and dst addr attributes for control
  port tx/rx" (jsc#SLE-13430).
- Revert "mac80211: support
  NL80211_EXT_FEATURE_CONTROL_PORT_OVER_NL80211_MAC_ADDRS"
  (jsc#SLE-13430).
- cfg80211: remove support for adjacent channel compensation
  (jsc#SLE-13430).
- mac80211: check vif pointer before airtime calculation
  (jsc#SLE-13430).
- net: use netif_is_bridge_port() to check for IFF_BRIDGE_PORT
  (jsc#SLE-13430).
- mac80211: allow setting queue_len for drivers not using
  wake_tx_queue (jsc#SLE-13430).
- mac80211: Fix setting txpower to zero (jsc#SLE-13430).
- mac80211: support
  NL80211_EXT_FEATURE_CONTROL_PORT_OVER_NL80211_MAC_ADDRS
  (jsc#SLE-13430).
- nl80211: add src and dst addr attributes for control port tx/rx
  (jsc#SLE-13430).
- mac80211: parse also the RSNXE IE (jsc#SLE-13430).
- cfg80211/mac80211: Allow user space to register for station
  Rx authentication (jsc#SLE-13430).
- mac80211: Remove support for changing AP SMPS mode
  (jsc#SLE-13430).
- mac80211: Handle SMPS mode changes only in AP mode
  (jsc#SLE-13430).
- mac80211: Accept broadcast probe responses on 6GHz band
  (jsc#SLE-13430).
- mac80211: HE: set RX NSS (jsc#SLE-13430).
- mac80211: set station bandwidth from HE capability
  (jsc#SLE-13430).
- mac80211: remove supported channels element in 6 GHz if ECSA
  support (jsc#SLE-13430).
- mac80211: update condition for HE disablement (jsc#SLE-13430).
- mac80211: make ieee80211_wep_init() return void (jsc#SLE-13430).
- mac80211: allow changing TX-related netdev features
  (jsc#SLE-13430).
- mac80211: check whether HE connection is allowed by the reg
  domain (jsc#SLE-13430).
- mac80211: refactor extended element parsing (jsc#SLE-13430).
- mac80211: simplify and improve HT/VHT/HE disable code
  (jsc#SLE-13430).
- cfg80211: Enhance the AKM advertizement to support per interface
  (jsc#SLE-13430).
- commit 3d7842f
* Tue Sep  8 2020 tiwai@suse.de
- cfg80211: add no HE indication to the channel flag
  (jsc#SLE-13430).
- mac80211: fix 11w when using encapsulation offloading
  (jsc#SLE-13430).
- mac80211: add ieee80211_is_any_nullfunc() (jsc#SLE-13430).
- mac80211: fix tx status for no ack cases (jsc#SLE-13430).
- mac80211: add handling for BSS color (jsc#SLE-13430).
- nl80211: add handling for BSS color (jsc#SLE-13430).
- mac80211: debugfs: improve airtime_flags handler readability
  (jsc#SLE-13430).
- mac80211: Remove redundant assertion (jsc#SLE-13430).
- mac80211: add 802.11 encapsulation offloading support
  (jsc#SLE-13430).
- mac80211: Always show airtime debugfs file when TXQs are enabled
  (jsc#SLE-13430).
- wireless: Use offsetof instead of custom macro (jsc#SLE-13430).
- mac80211: set IEEE80211_TX_CTRL_PORT_CTRL_PROTO for nl80211 TX
  (jsc#SLE-13430).
- mac80211: mark station unauthorized before key removal
  (jsc#SLE-13430).
- mac80211: Check port authorization in the ieee80211_tx_dequeue()
  case (jsc#SLE-13430).
- cfg80211: Do not warn on same channel at the end of CSA
  (jsc#SLE-13430).
- mac80211: drop data frames without key on encrypted links
  (jsc#SLE-13430).
- nl80211: fix NL80211_ATTR_CHANNEL_WIDTH attribute type
  (jsc#SLE-13430).
- iwlwifi: don't send GEO_TX_POWER_LIMIT if no wgds table
  (jsc#SLE-13430).
- iwlwifi: pcie: add 0x2526/0x401* devices back to cfg detection
  (jsc#SLE-13430).
- iwlwifi: cfg: use antenna diversity with all AX101 devices
  (jsc#SLE-13430).
- iwlwifi: mvm: Fix rate scale NSS configuration (jsc#SLE-13430).
- iwlwifi: dbg: don't abort if sending DBGC_SUSPEND_RESUME fails
  (jsc#SLE-13430).
- iwlwifi: yoyo: don't add TLV offset when reading FIFOs
  (jsc#SLE-13430).
- iwlwifi: check allocated pointer when allocating conf_tlvs
  (jsc#SLE-13430).
- iwlwifi: consider HE capability when setting LDPC
  (jsc#SLE-13430).
- iwlwifi: mvm: take the required lock when clearing time event
  data (jsc#SLE-13430).
- mac80211: Do not send mesh HWMP PREQ if HWMP is disabled
  (jsc#SLE-13430).
- nl80211: add missing attribute validation for channel switch
  (jsc#SLE-13430).
- nl80211: add missing attribute validation for beacon report
  scanning (jsc#SLE-13430).
- nl80211: add missing attribute validation for critical protocol
  indication (jsc#SLE-13430).
- iwlwifi: mvm: Do not require PHY_SKU NVM section for 3168
  devices (jsc#SLE-13430).
- mac80211: rx: avoid RCU list traversal under mutex
  (jsc#SLE-13430).
- nl80211: explicitly include if_vlan.h (jsc#SLE-13430).
- mac80211: Remove a redundant mutex unlock (jsc#SLE-13430).
- cfg80211: check reg_rule for NULL in handle_channel_custom()
  (jsc#SLE-13430).
- nl80211: fix potential leak in AP start (jsc#SLE-13430).
- mac80211: fix wrong 160/80+80 MHz setting (jsc#SLE-13430).
- cfg80211: add missing policy for NL80211_ATTR_STATUS_CODE
  (jsc#SLE-13430).
- cfg80211: check wiphy driver existence for drvinfo report
  (jsc#SLE-13430).
- commit 5425628
* Tue Sep  8 2020 tiwai@suse.de
- mac80211: consider more elements in parsing CRC (jsc#SLE-13430).
- mac80211: fix quiet mode activation in action frames
  (jsc#SLE-13430).
- mac80211: use more bits for ack_frame_id (jsc#SLE-13430).
- iwlwifi: d3: read all FW CPUs error info (jsc#SLE-13430).
- iwlwifi: mvm: fix TDLS discovery with the new firmware API
  (jsc#SLE-13430).
- iwlwifi: mvm: Check the sta is not NULL in iwl_mvm_cfg_he_sta()
  (jsc#SLE-13430).
- iwlwifi: mvm: avoid use after free for pmsr request
  (jsc#SLE-13430).
- iwlwifi: mvm: update the DTS measurement type (jsc#SLE-13430).
- iwlwifi: don't throw error when trying to remove IGTK
  (jsc#SLE-13430).
- iwlwifi: mvm: Fix thermal zone registration (jsc#SLE-13430).
- iwlwifi: add device name to device_info (jsc#SLE-13430).
- iwlwifi: implement a new device configuration table
  (jsc#SLE-13430).
- iwlwifi: assume the driver_data is a trans_cfg, but allow full
  cfg (jsc#SLE-13430).
- iwlwifi: prph: remove some unused register definitions
  (jsc#SLE-13430).
- iwlwifi: mvm: print out extended secboot status before dump
  (jsc#SLE-13430).
- iwlwifi: incorporate firmware filename into version
  (jsc#SLE-13430).
- iwlwifi: yoyo: check for the domain on all TLV types during init
  (jsc#SLE-13430).
- iwlwifi: add new iwlax411 struct for type SoSnj (jsc#SLE-13430).
- iwlwifi: yoyo: remove the iwl_dbg_tlv_gen_active_trigs()
  function (jsc#SLE-13430).
- iwlwifi: yoyo: remove unnecessary active triggers status flag
  (jsc#SLE-13430).
- iwlwifi: yoyo: don't allow changing the domain via debugfs
  (jsc#SLE-13430).
- iwlwifi: mvm: Update BEACON_TEMPLATE_CMD firmware API
  (jsc#SLE-13430).
- iwlwifi: remove CSR registers abstraction (jsc#SLE-13430).
- iwlwifi: remove some outdated iwl22000 configurations
  (jsc#SLE-13430).
- iwlwifi: pcie: validate queue ID before array deref/bit ops
  (jsc#SLE-13430).
- iwlwifi: pcie: use partial pages if applicable (jsc#SLE-13430).
- iwlwifi: pcie: map only used part of RX buffers (jsc#SLE-13430).
- iwlwifi: allocate more receive buffers for HE devices
  (jsc#SLE-13430).
- iwlwifi: mvm: add support for responder config command version 7
  (jsc#SLE-13430).
- iwlwifi: mvm: add support for location range request version 8
  (jsc#SLE-13430).
- iwlwifi: scan: remove support for fw scan api v11
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: don't skip a TX FIFO when dumping
  (jsc#SLE-13430).
- iwlwifi: mvm: update powersave correctly for D3 (jsc#SLE-13430).
- net: mac80211: use skb_list_walk_safe helper for gso segments
  (jsc#SLE-13430).
- net: iwlwifi: use skb_list_walk_safe helper for gso segments
  (jsc#SLE-13430).
- commit 8a47fb8
* Tue Sep  8 2020 tiwai@suse.de
- iwlwifi: mvm: don't send the IWL_MVM_RXQ_NSSN_SYNC notif to
  Rx queues (jsc#SLE-13430).
- Revert "iwlwifi: mvm: fix scan config command size"
  (jsc#SLE-13430).
- iwlwifi: fw: make pos static in iwl_sar_get_ewrd_table() loop
  (jsc#SLE-13430).
- iwlwifi: remove lar_disable module parameter (jsc#SLE-13430).
- iwlwifi: dbg: force stop the debug monitor HW (jsc#SLE-13430).
- iwlwifi: pcie: always disable L0S states (jsc#SLE-13430).
- iwlwifi: pcie: rename L0S_ENABLED bit to L0S_DISABLED
  (jsc#SLE-13430).
- iwlwifi: mvm: fix potential SKB leak on TXQ TX (jsc#SLE-13430).
- iwlwifi: mvm: fix SKB leak on invalid queue (jsc#SLE-13430).
- iwlwifi: pcie: extend hardware workaround to context-info
  (jsc#SLE-13430).
- iwlwifi: Don't ignore the cap field upon mcc update
  (jsc#SLE-13430).
- iwlwifi: mvm: report TX rate to mac80211 directly for RS offload
  (jsc#SLE-13430).
- iwlwifi: mvm: fix NVM check for 3168 devices (jsc#SLE-13430).
- iwlwifi: fix TLV fragment allocation loop (jsc#SLE-13430).
- iwlwifi: pcie: allocate smaller dev_cmd for TX headers
  (jsc#SLE-13430).
- iwlwifi: pcie: detect the DMA bug and warn if it happens
  (jsc#SLE-13430).
- iwlwifi: pcie: work around DMA hardware bug (jsc#SLE-13430).
- iwlwifi: pcie: move page tracking into get_page_hdr()
  (jsc#SLE-13430).
- iwlwifi: don't send PPAG command if disabled (jsc#SLE-13430).
- net: Fix packet reordering caused by GRO and listified RX
  cooperation (jsc#SLE-13430).
- cfg80211: fix page refcount issue in A-MSDU decap
  (jsc#SLE-13430).
- cfg80211: check for set_wiphy_params (jsc#SLE-13430).
- cfg80211: fix memory leak in cfg80211_cqm_rssi_update
  (jsc#SLE-13430).
- cfg80211: fix memory leak in nl80211_probe_mesh_link
  (jsc#SLE-13430).
- cfg80211: fix deadlocks in autodisconnect work (jsc#SLE-13430).
- wireless: wext: avoid gcc -O3 warning (jsc#SLE-13430).
- mac80211: Fix TKIP replay protection immediately after key setup
  (jsc#SLE-13430).
- cfg80211: Fix radar event during another phy CAC
  (jsc#SLE-13430).
- wireless: fix enabling channel 12 for custom regulatory domain
  (jsc#SLE-13430).
- mac80211: mesh: restrict airtime metric to peered established
  plinks (jsc#SLE-13430).
- iwlwifi: pcie: move power gating workaround earlier in the flow
  (jsc#SLE-13430).
- Revert "iwlwifi: assign directly to iwl_trans->cfg in QuZ
  detection" (jsc#SLE-13430).
- mac80211: Turn AQL into an NL80211_EXT_FEATURE (jsc#SLE-13430).
- mac80211: airtime: Fix an off by one in
  ieee80211_calc_rx_airtime() (jsc#SLE-13430).
- cfg80211: fix double-free after changing network namespace
  (jsc#SLE-13430).
- mac80211: fix TID field in monitor mode transmit
  (jsc#SLE-13430).
- net: wireless: intel: iwlwifi: fix GRO_NORMAL packet stalling
  (jsc#SLE-13430).
- mac80211: Use debugfs_create_xul() helper (jsc#SLE-13430).
- commit 67b1384
* Tue Sep  8 2020 tiwai@suse.de
- blacklist.conf: drop an iwlwifi patch to be backported
- commit 6130493
* Tue Sep  8 2020 tiwai@suse.de
- iwlwifi: bump FW API to 52 for 22000 series (jsc#SLE-13430).
- iwlwifi: check kasprintf() return value (jsc#SLE-13430).
- iwlwifi: mvm: remove outdated comment referring to wake lock
  (jsc#SLE-13430).
- iwlwifi: pcie: trace IOVA for iwlwifi_dev_tx_tb (jsc#SLE-13430).
- iwlwifi: dvm: excessive if in rs_bt_update_lq() (jsc#SLE-13430).
- iwlwifi: mvm: Report tx/rx antennas (jsc#SLE-13430).
- iwlwifi: pcie: rx: use rxq queue_size instead of constant
  (jsc#SLE-13430).
- iwlwifi: mvm: remove left-over non-functional email alias
  (jsc#SLE-13430).
- iwlwifi: config: remove max_rx_agg_size (jsc#SLE-13430).
- iwlwifi: pcie: make some RX functions static (jsc#SLE-13430).
- iwlwifi: scan: support scan req FW API ver 13 (jsc#SLE-13430).
- iwlwifi: pcie: fix support for transmitting SKBs with fraglist
  (jsc#SLE-13430).
- ipw2x00: remove set but not used variable 'force_update'
  (jsc#SLE-13430).
- ipw2x00: remove set but not used variable 'reason'
  (jsc#SLE-13430).
- mac80211: Use Airtime-based Queue Limits (AQL) on packet dequeue
  (jsc#SLE-13430).
- mac80211: Implement Airtime-based Queue Limit (AQL)
  (jsc#SLE-13430).
- mac80211: Import airtime calculation code from mt76
  (jsc#SLE-13430).
- mac80211: consider QoS Null frames for STA_NULLFUNC_ACKED
  (jsc#SLE-13430).
- mac80211: expose HW conf flags through debugfs (jsc#SLE-13430).
- mac80211: Add new sta_info getter by sta/vif addrs
  (jsc#SLE-13430).
- mac80211: add a comment about monitor-to-dev injection
  (jsc#SLE-13430).
- iwlwifi: mvm: fix non-ACPI function (jsc#SLE-13430).
- iwlwifi: 22000: fix some indentation (jsc#SLE-13430).
- iwlwifi: remove IWL_DEVICE_22560/IWL_DEVICE_FAMILY_22560
  (jsc#SLE-13430).
- iwlwifi: mvm: sync the iwl_mvm_session_prot_notif layout
  (jsc#SLE-13430).
- iwlwifi: mvm: start CTDP budget from 2400mA (jsc#SLE-13430).
- iwlwifi: mvm: don't skip mgmt tid when flushing all tids
  (jsc#SLE-13430).
- iwlwifi: mvm: scan: enable adaptive dwell in p2p
  (jsc#SLE-13430).
- iwlwifi: refactor the SAR tables from mvm to acpi
  (jsc#SLE-13430).
- iwlwifi: scan: support scan req cmd ver 12 (jsc#SLE-13430).
- iwlwifi: scan: make new scan req versioning flow
  (jsc#SLE-13430).
- iwlwifi: mvm: fix unaligned read of rx_pkt_status
  (jsc#SLE-13430).
- iwlwifi: remove redundant assignment to variable bufsz
  (jsc#SLE-13430).
- iwlwifi: bump FW API to 51 for 22000 series (jsc#SLE-13430).
- iwlwifi: FW API: reference enum in docs of modify_mask
  (jsc#SLE-13430).
- iwlwifi: mvm: print rate_n_flags in a pretty format
  (jsc#SLE-13430).
- iwlwifi: scan: adapt the code to use api ver 11 (jsc#SLE-13430).
- iwlwifi: scan: Create function to build scan cmd
  (jsc#SLE-13430).
- iwlwifi: scan: create function for scan scheduling params
  (jsc#SLE-13430).
- iwlwifi: pcie: don't consider IV len in A-MSDU (jsc#SLE-13430).
- commit 292e14d
* Tue Sep  8 2020 tiwai@suse.de
- iwlwifi: dbg_ini: support dump collection upon assert during D3
  (jsc#SLE-13430).
- iwlwifi: pcie: make iwl_pcie_gen2_update_byte_tbl static
  (jsc#SLE-13430).
- iwlwifi: mvm: in VHT connection use only VHT capabilities
  (jsc#SLE-13430).
- iwlwifi: nvm: update iwl_uhb_nvm_channels (jsc#SLE-13430).
- iwlwifi: mvm: remove else-if in iwl_send_phy_cfg_cmd()
  (jsc#SLE-13430).
- iwlwifi: mvm: fix support for single antenna diversity
  (jsc#SLE-13430).
- iwlegacy: Remove redundant variable "ret" (jsc#SLE-13430).
- ipw2x00: Remove redundant variable "rc" (jsc#SLE-13430).
- cfg80211: VLAN offload support for set_key and set_sta_vlan
  (jsc#SLE-13430).
- mac80211: Shrink the size of ack_frame_id to make room for
  tx_time_est (jsc#SLE-13430).
- mac80211: don't re-parse elems in ieee80211_assoc_success()
  (jsc#SLE-13430).
- mac80211: move store skb ack code to its own function
  (jsc#SLE-13430).
- mac80211: fix a typo of "function" (jsc#SLE-13430).
- mac80211: typo fixes in kerneldoc comments (jsc#SLE-13430).
- iwlwifi: rx: use new api to get band from rx mpdu
  (jsc#SLE-13430).
- iwlwifi: nvm: create function to convert channel index to
  nl80211_band (jsc#SLE-13430).
- iwlwifi: mvm: Invert the condition for OFDM rate
  (jsc#SLE-13430).
- iwlwifi: mvm: create function to convert nl80211 band to phy
  band (jsc#SLE-13430).
- iwlwifi: dbg_ini: use vzalloc to allocate dumping memory regions
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: add user trigger support (jsc#SLE-13430).
- iwlwifi: mvm: add notification for missed VAP (jsc#SLE-13430).
- iwlwifi: mvm: fix old-style declaration (jsc#SLE-13430).
- iwlwifi: mvm: use the new session protection command
  (jsc#SLE-13430).
- iwlwifi: mvm: remove leftover rs_remove_sta_debugfs() prototype
  (jsc#SLE-13430).
- iwlwifi: mvm: add support for new version for D0I3_END_CMD
  (jsc#SLE-13430).
- iwlwifi: mvm: consider ieee80211 station max amsdu value
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: support FW notification dumping in case of
  missed beacon (jsc#SLE-13430).
- iwlwifi: dbg_ini: remove old API and some related code
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: rename external debug configuration file
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: support FW response/notification region type
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: support domain changing via debugfs
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: add periodic trigger new API support
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: implement monitor allocation flow
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: implement time point handling (jsc#SLE-13430).
- iwlwifi: dbg_ini: add TLV allocation new API support
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: use new API in dump info (jsc#SLE-13430).
- iwlwifi: dbg_ini: add error tables dumping support
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: add monitor dumping support (jsc#SLE-13430).
- mac80211: fix station inactive_time shortly after boot
  (jsc#SLE-13430).
- mac80211: fix ieee80211_txq_setup_flows() failure path
  (jsc#SLE-13430).
- commit 363b44c
* Tue Sep  8 2020 tiwai@suse.de
- iwlwifi: dbg: remove multi buffers infra (jsc#SLE-13430).
- iwlwifi: dbg_ini: use new trigger TLV in dump flow
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: use new region TLV in dump flow
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: load external dbg cfg after internal cfg is
  loaded (jsc#SLE-13430).
- iwlegacy: make array interval static, makes object smaller
  (jsc#SLE-13430).
- net: Fix misspellings of "configure" and "configuration"
  (jsc#SLE-13430).
- iwlwifi: fw api: support new API for scan config cmd
  (jsc#SLE-13430).
- iwlwifi: pcie: 0x2720 is qu and 0x30DC is not (jsc#SLE-13430).
- iwlwifi: pcie: add workaround for power gating in integrated
  22000 (jsc#SLE-13430).
- iwlwifi: mvm: handle iwl_mvm_tvqm_enable_txq() error return
  (jsc#SLE-13430).
- iwlwifi: pcie: fix all 9460 entries for qnj (jsc#SLE-13430).
- iwlwifi: pcie: fix PCI ID 0x2720 configs that should be soc
  (jsc#SLE-13430).
- iwlwifi: pcie: fix merge damage on making QnJ exclusive
  (jsc#SLE-13430).
- nl80211: fix validation of mesh path nexthop (jsc#SLE-13430).
- nl80211: Disallow setting of HT for channel 14 (jsc#SLE-13430).
- iwlwifi: pcie: change qu with jf devices to use qu configuration
  (jsc#SLE-13430).
- iwlwifi: exclude GEO SAR support for 3168 (jsc#SLE-13430).
- iwlwifi: pcie: fix memory leaks in iwl_pcie_ctxt_info_gen3_init
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: fix memory leak in alloc_sgtable
  (jsc#SLE-13430).
- iwlwifi: pcie: fix rb_allocator workqueue allocation
  (jsc#SLE-13430).
- iwlwifi: pcie: fix indexing in command dump for new HW
  (jsc#SLE-13430).
- iwlwifi: mvm: fix race in sync rx queue notification
  (jsc#SLE-13430).
- iwlwifi: mvm: force single phy init (jsc#SLE-13430).
- iwlwifi: fix ACPI table revision checks (jsc#SLE-13430).
- iwlwifi: don't access trans_cfg via cfg (jsc#SLE-13430).
- mac80211: fix scan when operating on DFS channels in ETSI
  domains (jsc#SLE-13430).
- mac80211: accept deauth frames in IBSS mode (jsc#SLE-13430).
- cfg80211: fix a bunch of RCU issues in multi-bssid code
  (jsc#SLE-13430).
- nl80211: fix memory leak in nl80211_get_ftm_responder_stats
  (jsc#SLE-13430).
- commit c33c351
* Tue Sep  8 2020 tiwai@suse.de
- mac80211: minstrel_ht: rename prob_ewma to prob_avg, use it
  for the new average (jsc#SLE-13430).
- mac80211: minstrel_ht: replace rate stats ewma with a better
  moving average (jsc#SLE-13430).
- mac80211: minstrel: remove divisions in tx status path
  (jsc#SLE-13430).
- nl80211: trivial: Remove redundant loop (jsc#SLE-13430).
- mac80211: simplify TX aggregation start (jsc#SLE-13430).
- mac80211: pass internal sta to ieee80211_tx_frags()
  (jsc#SLE-13430).
- mac80211: IBSS: avoid unneeded return value processing
  (jsc#SLE-13430).
- cfg80211: wext: avoid copying malformed SSIDs (jsc#SLE-13430).
- mac80211: Reject malformed SSID elements (jsc#SLE-13430).
- mac80211: keep BHs disabled while calling drv_tx_wake_queue()
  (jsc#SLE-13430).
- mac80211: fix txq null pointer dereference (jsc#SLE-13430).
- nl80211: fix null pointer dereference (jsc#SLE-13430).
- cfg80211: initialize on-stack chandefs (jsc#SLE-13430).
- cfg80211: validate SSID/MBSSID element ordering assumption
  (jsc#SLE-13430).
- nl80211: validate beacon head (jsc#SLE-13430).
- iwlwifi: fw: don't send GEO_TX_POWER_LIMIT command to FW
  version 36 (jsc#SLE-13430).
- iwlwifi: mvm: fix build w/o CONFIG_THERMAL (jsc#SLE-13430).
- cfg80211: Purge frame registrations on iftype change
  (jsc#SLE-13430).
- nl80211: Fix possible Spectre-v1 for CQM RSSI thresholds
  (jsc#SLE-13430).
- mac80211: allow drivers to set max MTU (jsc#SLE-13430).
- cfg80211: Do not compare with boolean in
  nl80211_common_reg_change_event (jsc#SLE-13430).
- mac80211: IBSS: send deauth when expiring inactive STAs
  (jsc#SLE-13430).
- mac80211: don't check if key is NULL in ieee80211_key_link()
  (jsc#SLE-13430).
- mac80211: clear crypto tx tailroom counter upon keys enable
  (jsc#SLE-13430).
- mac80211: remove unnecessary key condition (jsc#SLE-13430).
- mac80211: list features in WEP/TKIP disable in better order
  (jsc#SLE-13430).
- cfg80211: always shut down on HW rfkill (jsc#SLE-13430).
- mac80211: vht: add support VHT EXT NSS BW in parsing VHT
  (jsc#SLE-13430).
- cfg80211: fix boundary value in ieee80211_frequency_to_channel()
  (jsc#SLE-13430).
- cfg80211: add local BSS receive time to survey information
  (jsc#SLE-13430).
- nl80211: add NL80211_CMD_UPDATE_FT_IES to supported commands
  (jsc#SLE-13430).
- mac80211: minstrel_ht: fix infinite loop because supported is
  not being shifted (jsc#SLE-13430).
- iwlwifi: dbg: remove iwl_fw_cancel_dumps function
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: remove periodic trigger (jsc#SLE-13430).
- iwlwifi: dbg_ini: fix dump structs doc (jsc#SLE-13430).
- iwlwifi: fw api: add DRAM buffer allocation command
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: remove apply point, switch to time point API
  (jsc#SLE-13430).
- iwlwifi: add iwl_tlv_array_len() (jsc#SLE-13430).
- iwlwifi: mvm: don't log un-decrypted frames (jsc#SLE-13430).
- iwlwifi: mvm: add support for single antenna diversity
  (jsc#SLE-13430).
- iwlwifi: mvm: handle BAR_FRAME_RELEASE (0xc2) notification
  (jsc#SLE-13430).
- iwlwifi: mvm: drop BA sessions on too many old-SN frames
  (jsc#SLE-13430).
- iwlwifi: add sta_id to WOWLAN_CONFIG_CMD (jsc#SLE-13430).
- iwlwifi: add support for suspend-resume flow for new device
  generation (jsc#SLE-13430).
- iwlwifi: fix warning iwl-trans.h is included more than once
  (jsc#SLE-13430).
- iwlwifi: always access the trans configuration via trans
  (jsc#SLE-13430).
- iwlwifi: pass the iwl_trans instead of cfg to some functions
  (jsc#SLE-13430).
- iwlwifi: add a pointer to the trans_cfg directly in trans
  (jsc#SLE-13430).
- mac80211_hwsim: Extended Key ID API update (jsc#SLE-13430).
- commit 10eee37
* Tue Sep  8 2020 ptesarik@suse.cz
- crypto: ecc - SP800-56A rev 3 local public key validation
  (bsc#1175718).
- crypto: dh - SP800-56A rev 3 local public key validation
  (bsc#1175718).
- crypto: dh - check validity of Z before export (bsc#1175718).
- lib/mpi: Add mpi_sub_ui() (bsc#1175718).
- crypto: ecdh - check validity of Z before export (bsc#1175718).
- commit 1b908a3
* Tue Sep  8 2020 tiwai@suse.de
- iwlwifi: pass the iwl_config_trans_params when needed
  (jsc#SLE-13430).
- iwlwifi: pcie: set iwl_trans->cfg later in the probe function
  (jsc#SLE-13430).
- iwlwifi: pcie: move some cfg mangling from trans_pcie_alloc
  to probe (jsc#SLE-13430).
- iwlwifi: pcie: use the cfg we passed to iwl_trans_pcie_alloc()
  (jsc#SLE-13430).
- iwlwifi: separate elements from cfg that are needed by
  trans_alloc (jsc#SLE-13430).
- iwlwifi: dbg_ini: use regions ops array instead of switch case
  in dump flow (jsc#SLE-13430).
- iwlwifi: dbg_ini: make a single ops struct for paging collect
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: move tx fifo data into fw runtime
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: use linked list for dump TLVs during dump
  creation (jsc#SLE-13430).
- iwlwifi: dbg_ini: separate cfg and dump flows to different
  modules (jsc#SLE-13430).
- iwlwifi: mvm: look for the first supported channel when
  add/remove phy ctxt (jsc#SLE-13430).
- iwlwifi: allocate bigger nvm data in case of UHB
  (jsc#SLE-13430).
- iwlwifi: remove unnecessary IWL_DEVICE_AX200_COMMON definition
  (jsc#SLE-13430).
- iwlwifi: dbg: align wrt log prints to the same format
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: remove debug flow TLV (jsc#SLE-13430).
- iwlwifi: dbg_ini: verify debug TLVs at allocation phase
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: use function to check if ini dbg mode is on
  (jsc#SLE-13430).
- iwlwifi: remove duplicate FW string definitions (jsc#SLE-13430).
- iwlwifi: bump FW API to 50 for 22000 series (jsc#SLE-13430).
- iwlwifi: api: fix FTM struct documentation (jsc#SLE-13430).
- iwlwifi: support per-platform antenna gain (jsc#SLE-13430).
- iwlwifi: mvm: remove check for lq_sta in
  __iwl_mvm_rs_tx_status() (jsc#SLE-13430).
- iwlwifi: mvm: simplify the channel switch flow for newer
  firmware (jsc#SLE-13430).
- iwlwifi: stop passing bogus gfp flags arguments to
  dma_alloc_coherent (jsc#SLE-13430).
- iwlwifi: dbg_ini: remove periphery phy and aux regions handling
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: use linked list to store debug TLVs
  (jsc#SLE-13430).
- iwlwifi: dbg_ini: maintain buffer allocations from trans
  instead of TLVs buffer (jsc#SLE-13430).
- iwlwifi: dbg: add debug periphery registers to 9000 device
  family (jsc#SLE-13430).
- iwlwifi: remove unused regdb_ptrs allocation (jsc#SLE-13430).
- iwlwifi: dbg_ini: align dbg tlv functions names to a single
  format (jsc#SLE-13430).
- iwlwifi: scan: don't pass large argument by value
  (jsc#SLE-13430).
- iwlwifi: remove pm_runtime completely (jsc#SLE-13430).
- iwlwifi: remove the d0i3 related module parameters
  (jsc#SLE-13430).
- iwlwifi: pcie: remove some more d0i3 code from the transport
  (jsc#SLE-13430).
- iwlwifi: pcie: remove the refs / unrefs from the transport
  (jsc#SLE-13430).
- iwlwifi: remove the opmode's d0i3 handlers (jsc#SLE-13430).
- iwlwifi: remove runtime_pm_mode (jsc#SLE-13430).
- iwlwifi: Set w-pointer upon resume according to SN
  (jsc#SLE-13430).
- iwlwifi: mvm: use FW thermal monitoring regardless of
  CONFIG_THERMAL (jsc#SLE-13430).
- iwlwifi: mvm: name magic numbers with enum (jsc#SLE-13430).
- commit a03925d
* Tue Sep  8 2020 tiwai@suse.de
- iwlwifi: scan: add support for new scan request command version
  (jsc#SLE-13430).
- iwlwifi: LTR updates (jsc#SLE-13430).
- iwlwifi: remove the code under IWLWIFI_PCIE_RTPM
  (jsc#SLE-13430).
- iwlwifi: trans: remove suspending flag (jsc#SLE-13430).
- iwlwifi: remove CMD_HIGH_PRIO (jsc#SLE-13430).
- iwlwifi: mvm: remove last leftovers of d0i3 (jsc#SLE-13430).
- iwlwifi: mvm: remove iwl_mvm_update_d0i3_power_mode
  (jsc#SLE-13430).
- iwlwifi: mvm: remove d0i3_ap_sta_id (jsc#SLE-13430).
- iwlwifi: mvm: iwl_mvm_wowlan_config_key_params is for wowlan
  only (jsc#SLE-13430).
- iwlwifi: mvm: remove the d0i3 entry/exit flow (jsc#SLE-13430).
- iwlwifi: mvm: remove the tx defer for d0i3 (jsc#SLE-13430).
- iwlwifi: remove all the d0i3 references (jsc#SLE-13430).
- iwlwifi: mvm: start to remove the code for d0i3 (jsc#SLE-13430).
- iwlwifi: mvm: add the skb length to a print (jsc#SLE-13430).
- iwlwifi: mvm: fix scan config command size (jsc#SLE-13430).
- iwlwifi: add ldbg config cmd debug print (jsc#SLE-13430).
- iwlwifi: dbg: support debug recording suspend resume command
  (jsc#SLE-13430).
- iwlwifi: dbg: move debug recording stop from trans to op mode
  (jsc#SLE-13430).
- iwlwifi: dbg: move monitor recording functionality from header
  file (jsc#SLE-13430).
- iwlwifi: mvm: remove unnecessary forward declarations
  (jsc#SLE-13430).
- iwlwifi: mvm: Block 26-tone RU OFDMA transmissions
  (jsc#SLE-13430).
- iwlwifi: mvm: remove redundant condition in
  iwl_mvm_set_hw_rfkill_state (jsc#SLE-13430).
- iwlwifi: Send DQA enable command only if TVL is on
  (jsc#SLE-13430).
- iwlwifi: bump FW API to 49 for 22000 series (jsc#SLE-13430).
- ipw2x00: fix spelling mistake "initializationg" ->
  "initialization" (jsc#SLE-13430).
- mac80211: minstrel_ht: improve rate probing for devices with
  static fallback (jsc#SLE-13430).
- mac80211: minstrel_ht: fix default max throughput rate indexes
  (jsc#SLE-13430).
- mac80211: minstrel_ht: reduce unnecessary rate probing attempts
  (jsc#SLE-13430).
- mac80211: minstrel_ht: fix per-group max throughput rate
  initialization (jsc#SLE-13430).
- nl80211: Add support for EDMG channels (jsc#SLE-13430).
- mac80211: fix possible NULL pointerderef in obss pd code
  (jsc#SLE-13430).
- mac80211: add assoc-at support (jsc#SLE-13430).
- cfg80211: Support assoc-at timer in sta-info (jsc#SLE-13430).
- cfg80211: apply same mandatory rate flags for 5GHz and 6GHz
  (jsc#SLE-13430).
- cfg80211: ibss: use 11a mandatory rates for 6GHz band operation
  (jsc#SLE-13430).
- cfg80211: use same IR permissive rules for 6GHz band
  (jsc#SLE-13430).
- cfg80211: add 6GHz in code handling array with NUM_NL80211_BANDS
  entries (jsc#SLE-13430).
- cfg80211: extend ieee80211_operating_class_to_band() for 6GHz
  (jsc#SLE-13430).
- cfg80211: util: add 6GHz channel to freq conversion and vice
  versa (jsc#SLE-13430).
- cfg80211: add 6GHz UNII band definitions (jsc#SLE-13430).
- commit 5fa9b00
* Tue Sep  8 2020 tiwai@suse.de
- mac80211: reject zero MAC address in add station
  (jsc#SLE-13430).
- commit 48ef5ee
* Tue Sep  8 2020 tiwai@suse.de
- nl80211: add 6GHz band definition to enum nl80211_band
  (jsc#SLE-13430).
- mac80211: add missing length field increment when generating
  Radiotap header (jsc#SLE-13430).
- mac80211: 80Mhz was not reported properly when using
  tx_status_ext (jsc#SLE-13430).
- mac80211: fix bad guard when reporting legacy rates
  (jsc#SLE-13430).
- mac80211: fix TX legacy rate reporting when tx_status_ext is
  used (jsc#SLE-13430).
- ipw2x00: remove redundant assignment to err (jsc#SLE-13430).
- iwlegacy: Use dev_get_drvdata where possible (jsc#SLE-13430).
- mac80211: HE STA disassoc due to QOS NULL not sent
  (jsc#SLE-13430).
- mac80211: allow setting spatial reuse parameters from bss_conf
  (jsc#SLE-13430).
- nl80211: add strict start type (jsc#SLE-13430).
- cfg80211: add support for parsing OBBS_PD attributes
  (jsc#SLE-13430).
- cfg80211: use parallel_ops for genl (jsc#SLE-13430).
- mac80211: add missing null return check from call to
  ieee80211_get_sband (jsc#SLE-13430).
- mac80211: add support for the ADDBA extension element
  (jsc#SLE-13430).
- mac80211: propagate HE operation info into bss_conf
  (jsc#SLE-13430).
- cfg80211: fix dfs channels remain DFS_AVAILABLE after ch_switch
  (jsc#SLE-13430).
- cfg80211: fix duplicated scan entries after channel switch
  (jsc#SLE-13430).
- cfg80211: refactor cfg80211_bss_update (jsc#SLE-13430).
- nl80211: Include wiphy address setup in NEW_WIPHY
  (jsc#SLE-13430).
- mac80211: implement HE support for mesh (jsc#SLE-13430).
- mac80211: add IEEE80211_KEY_FLAG_GENERATE_MMIE to
  ieee80211_key_flags (jsc#SLE-13430).
- mac80211: HE: add Spatial Reuse element parsing support
  (jsc#SLE-13430).
- mac80211: add struct ieee80211_tx_status support to
  ieee80211_add_tx_radiotap_header (jsc#SLE-13430).
- mac80211: propagate struct ieee80211_tx_status into
  ieee80211_tx_monitor() (jsc#SLE-13430).
- mac80211: add xmit rate to struct ieee80211_tx_status
  (jsc#SLE-13430).
- mac80211: add support for parsing ADDBA_EXT IEs (jsc#SLE-13430).
- cfg80211: give all multi-BSSID BSS entries the same timestamp
  (jsc#SLE-13430).
- cfg80211: don't parse MBSSID if transmitting BSS isn't created
  (jsc#SLE-13430).
- cfg80211: clean up cfg80211_inform_single_bss_frame_data()
  (jsc#SLE-13430).
- cfg80211: no need to check return value of debugfs_create
  functions (jsc#SLE-13430).
- mac80211: AMPDU handling for rekeys with Extended Key ID
  (jsc#SLE-13430).
- mac80211: Simplify Extended Key ID API (jsc#SLE-13430).
- mac80211: add tx dequeue function for process context
  (jsc#SLE-13430).
- lib80211: use crypto API ccm(aes) transform for CCMP processing
  (jsc#SLE-13430).
- mac80211: remove unused and unneeded remove_sta_debugfs callback
  (jsc#SLE-13430).
- iwlwifi: mvm: remove unused .remove_sta_debugfs callback
  (jsc#SLE-13430).
- iwlwifi: dvm: no need to check return value of debugfs_create
  functions (jsc#SLE-13430).
- mac80211: pass the vif to cancel_remain_on_channel
  (jsc#SLE-13430).
- commit cae3467
* Tue Sep  8 2020 mbrugger@suse.com
- gpio: gpio-mlxbf2.c: Provide __releases() annotation to stop
  confusing Sparse (jsc#SLE-16098).
- gpio: gpio-mlxbf2: Tell the compiler that ACPI functions may
  not be use (jsc#SLE-16098).
- gpio: mlxbf2: fix return value check in
  mlxbf2_gpio_get_lock_res() (jsc#SLE-16098).
- gpio: mlxbf2: remove unused including <linux/version.h>
  (jsc#SLE-16098).
- gpio: mlxbf2: Fix sleeping while holding spinlock
  (jsc#SLE-16098).
- commit efe083f
* Tue Sep  8 2020 mbrugger@suse.com
- gpio: add driver for Mellanox BlueField 2 GPIO controller
  (jsc#SLE-16098).
- Update config files.
  Build driver as module
- supported.conf: Add gpio-mlxbf2
- commit ef4c9cc
* Tue Sep  8 2020 tiwai@suse.de
- Preliminary removal of iwlwifi and wireless patches for a bulk upgrade (jsc#SLE-13430)
- commit 2a8b9bc
* Tue Sep  8 2020 dwagner@suse.de
- nvme-fc: set max_segments to lldd max value (bsc#1176038).
- commit d7e9e95
* Tue Sep  8 2020 msuchanek@suse.de
- powerpc/64s: Fix crash in load_fp_state() due to fpexc_mode
  (jsc#SLE-9246).
- powerpc/32s: Fix CONFIG_BOOK3S_601 uses (jsc#SLE-9246).
- powerpc: Use trap metadata to prevent double restart rather
  than zeroing trap (jsc#SLE-9246).
- powerpc: trap_is_syscall() helper to hide syscall trap number
  (jsc#SLE-9246).
- powerpc: Use set_trap() and avoid open-coding trap masking
  (jsc#SLE-9246).
- powerpc/64s: Always has full regs, so remove remnant checks
  (jsc#SLE-9246).
- powerpc/64s: Disable sanitisers for C syscall/interrupt
  entry/exit code (jsc#SLE-9246).
- commit 055aa3a
* Tue Sep  8 2020 ptesarik@suse.cz
- s390/qeth: don't process empty bridge port events (git-fixes).
- s390/qeth: integrate RX refill worker with NAPI (git-fixes).
- s390/qeth: tolerate pre-filled RX buffer (git-fixes).
- commit 0d5daa2
* Tue Sep  8 2020 hare@suse.de
- block, bfq: extend incomplete name of field on_st
  (bsc#1175995,jsc#SLE-15608).
- Refresh patches.suse/bfq-fix-blkio-cgroup-leakage-v4.patch.
- Refresh
  patches.suse/block-bfq-get-a-ref-to-a-group-when-adding-it-to-a-s.patch.
- commit 1c9dd9d
* Tue Sep  8 2020 mbenes@suse.cz
- rpm/kernel-binary.spec.in: pack .ipa-clones files for live patching
  When -fdump-ipa-clones option is enabled, GCC reports about its cloning
  operation during IPA optimizations. We use the information for live
  patches preparation, because it is crucial to know if and how functions
  are optimized.
  Currently, we create the needed .ipa-clones dump files manually. It is
  unnecessary, because the files may be created automatically during our
  kernel build. Prepare for the step and provide the resulting files in
  - livepatch-devel package.
- commit 98e5a9d
* Tue Sep  8 2020 hare@suse.de
- supported.conf: mark 't10-pi' as supported.
- commit 9714c3a
* Tue Sep  8 2020 dwagner@suse.de
- s390: fix GENERIC_LOCKBREAK dependency typo in Kconfig
  (git-fixes).
- x86/hotplug: Silence APIC only after all interrupts are migrated
  (git-fixes).
- test_kmod: avoid potential double free in
  trigger_config_run_type() (git-fixes).
- initramfs: remove clean_rootfs (git-fixes).
- initramfs: remove the populate_initrd_image and clean_rootfs
  stubs (git-fixes).
- scsi: lpfc: Add dependency on CPU_FREQ (git-fixes).
- block: Use non _rcu version of list functions for tag_set_list
  (git-fixes).
- scsi: qla2xxx: Suppress two recently introduced compiler
  warnings (git-fixes).
- commit de8f3c2
* Tue Sep  8 2020 dwagner@suse.de
- blacklist.conf: Add documenation fixes and kabi breaker
- commit dba74e9
* Tue Sep  8 2020 tbogendoerfer@suse.de
- tg3: Fix soft lockup when tg3_reset_task() fails (git-fixes).
- cxgb4: fix thermal zone device registration (git-fixes).
- bnxt: don't enable NAPI until rings are ready (git-fixes).
- taprio: Fix using wrong queues in gate mask (bsc#1154353).
- bnxt_en: fix HWRM error when querying VF temperature
  (git-fixes).
- bnxt_en: Fix possible crash in bnxt_fw_reset_task()
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix PCI AER error recovery flow (git-fixes).
- bnxt_en: Check for zero dir entries in NVRAM (git-fixes).
- bnxt_en: Don't query FW when netif_running() is false
  (git-fixes).
- bonding: fix a potential double-unregister (git-fixes).
- i40e: Fix crash during removing i40e driver (git-fixes).
- i40e: Set RX_ONLY mode for unicast promiscuous on VLAN
  (git-fixes).
- commit 4d82728
* Tue Sep  8 2020 msuchanek@suse.de
- powerpc/ppc_asm.h: delete duplicated word (jsc#SLE-9246).
- powerpc/64s/exception: treat NIA below __end_interrupts as
  soft-masked (jsc#SLE-9246).
- powerpc: Select ARCH_HAS_MEMBARRIER_SYNC_CORE (jsc#SLE-9246).
- Update config files.
- powerpc/64: Fix an out of date comment about MMIO ordering
  (jsc#SLE-9246).
- powerpc/book3s64/keys/kuap: Reset AMR/IAMR values on kexec
  (jsc#SLE-9246).
- powerpc: re-initialise lazy FPU/VEC counters on every fault
  (jsc#SLE-9246).
- powerpc/64s: Fix restore_math unnecessarily changing MSR
  (jsc#SLE-9246).
- powerpc/64s: restore_math remove TM test (jsc#SLE-9246).
- powerpc/64: indirect function call use bctrl rather than blrl
  in ret_from_kernel_thread (jsc#SLE-9246).
- powerpc/64s/hash: Fix hash_preload running with interrupts
  enabled (jsc#SLE-9246).
- powerpc/64s/exception: Fix 0x1500 interrupt handler crash
  (jsc#SLE-9246).
- powerpc/64s: Fix KVM interrupt using wrong save area
  (jsc#SLE-9246).
- powerpc/32: Blacklist functions running with MMU disabled for
  kprobe (jsc#SLE-9246).
- powerpc/64s/kuap: Conditionally restore AMR in kuap_restore_amr
  asm (jsc#SLE-9246).
- powerpc/64/kuap: Conditionally restore AMR in interrupt exit
  (jsc#SLE-9246).
- powerpc/64s/kuap: Add missing isync to KUAP restore paths
  (jsc#SLE-9246).
- powerpc/64: Refactor interrupt exit irq disabling sequence
  (jsc#SLE-9246).
- powerpc/mm: Don't be too strict with _etext alignment on PPC32
  (jsc#SLE-9246).
- powerpc/uaccess: Don't use "m<>" constraint (jsc#SLE-9246).
- powerpc/uaccess: Implement user_read_access_begin and
  user_write_access_begin (jsc#SLE-9246).
- powerpc/uaccess: Implement unsafe_copy_to_user() as a simple
  loop (jsc#SLE-9246).
- powerpc/uaccess: Implement unsafe_put_user() using 'asm goto'
  (jsc#SLE-9246).
- powerpc/64s/exceptions: Machine check reconcile irq state
  (jsc#SLE-9246).
- powerpc/64s/exceptions: Change irq reconcile for NMIs from
  reusing _DAR to RESULT (jsc#SLE-9246).
- powerpc/64s/exceptions: Fix in_mce accounting in unrecoverable
  path (jsc#SLE-9246).
- powerpc/64: Don't initialise init_task->thread.regs
  (jsc#SLE-9246).
- powerpc/64s: Fix restore of NV GPRs after facility unavailable
  exception (jsc#SLE-9246).
- powerpc/64s/kuap: Restore AMR in fast_interrupt_return
  (jsc#SLE-9246).
- powerpc/64/kuap: Move kuap checks out of MSR[RI]=0 regions of
  exit code (jsc#SLE-9246).
- powerpc/64s: Fix unrecoverable SLB crashes due to preemption
  check (jsc#SLE-9246).
- powerpc/uaccess: Evaluate macro arguments once, before user
  access is allowed (jsc#SLE-9246).
- powerpc: Improve ppc_save_regs() (jsc#SLE-9246).
- powerpc/perf: split callchain.c by bitness (jsc#SLE-9246).
- powerpc/64: make buildable without CONFIG_COMPAT (jsc#SLE-9246).
- Refresh patches.suse/powerpc-pseries-Add-KVM-guest-doorbell-restrictions.patch.
- powerpc/perf: consolidate valid_user_sp -> invalid_user_sp
  (jsc#SLE-9246).
- powerpc/perf: consolidate read_user_stack_32 (jsc#SLE-9246).
- powerpc/64s: Fix doorbell wakeup msgclr optimisation
  (jsc#SLE-9246).
- powerpc/64/syscall: Reconcile interrupts (jsc#SLE-9246).
- powerpc/64s/exception: Remove lite interrupt return
  (jsc#SLE-9246).
- powerpc/64s: Implement interrupt exit logic in C (jsc#SLE-9246).
- powerpc/64: Implement soft interrupt replay in C (jsc#SLE-9246).
- powerpc/64/syscall: Zero volatile registers when returning
  (jsc#SLE-9246).
- powerpc/64/sycall: Implement syscall entry/exit logic in C
  (jsc#SLE-9246).
- Refresh patches.suse/powerpc-Move-ptrace-into-a-subdirectory.patch.
- Refresh patches.suse/powerpc-pseries-Add-KVM-guest-doorbell-restrictions.patch
- powerpc/64/syscall: Remove non-volatile GPR save optimisation
  (jsc#SLE-9246).
- powerpc/64s/exception: Soft NMI interrupt should not use
  ret_from_except (jsc#SLE-9246).
- powerpc/64s/exception: Reconcile interrupts in system_reset
  (jsc#SLE-9246).
- powerpc/64s/exception: Only test KVM in SRR interrupts when
  PR KVM is supported (jsc#SLE-9246).
- powerpc/64s/exception: Add more comments for interrupt handlers
  (jsc#SLE-9246).
- powerpc/64s/exception: Clean up SRR specifiers (jsc#SLE-9246).
- Refresh patches.suse/powerpc-64s-kuap-Restore-AMR-in-system-reset-excepti.patch.
- powerpc/64s/exception: Re-inline some handlers (jsc#SLE-9246).
- powerpc/64s/exception: Avoid touching the stack in hdecrementer
  (jsc#SLE-9246).
- powerpc/64s/exception: Trim unused arguments from KVMTEST macro
  (jsc#SLE-9246).
- powerpc/64s/exception: Remove the SPR saving patch code macros
  (jsc#SLE-9246).
- powerpc/64s/exception: Remove confusing IEARLY option
  (jsc#SLE-9246).
- powerpc/64s/exception: Move KVM test to common code
  (jsc#SLE-9246).
- powerpc/64s/exception: Move soft-mask test to common code
  (jsc#SLE-9246).
- powerpc/64s/exception: Move real to virt switch into the common
  handler (jsc#SLE-9246).
- powerpc/64s/exception: Add ISIDE option (jsc#SLE-9246).
- powerpc/64s/exception: Remove old INT_KVM_HANDLER
  (jsc#SLE-9246).
- powerpc/64s/exception: Remove old INT_COMMON macro
  (jsc#SLE-9246).
- powerpc/64s/exception: Remove old INT_ENTRY macro
  (jsc#SLE-9246).
- powerpc/64s/exception: Move all interrupt handlers to new
  style code gen macros (jsc#SLE-9246).
- powerpc/64s/exception: Expand EXC_COMMON and EXC_COMMON_ASYNC
  macros (jsc#SLE-9246).
- powerpc/64s/exception: Add GEN_KVM macro that uses INT_DEFINE
  parameters (jsc#SLE-9246).
- powerpc/64s/exception: Add GEN_COMMON macro that uses INT_DEFINE
  parameters (jsc#SLE-9246).
- powerpc/64s/exception: Introduce INT_DEFINE parameter block
  for code generation (jsc#SLE-9246).
- powerpc: Implement user_access_save() and user_access_restore()
  (jsc#SLE-9246).
- powerpc: Implement user_access_begin and friends (jsc#SLE-9246).
- powerpc/32s: Prepare prevent_user_access() for user_access_end()
  (jsc#SLE-9246).
- powerpc/32s: Drop NULL addr verification (jsc#SLE-9246).
- powerpc: align stack to 2 * THREAD_SIZE with VMAP_STACK
  (jsc#SLE-9246).
- powerpc/64s: Reimplement power4_idle code in C (jsc#SLE-9246).
- Update config files.
- powerpc/64: Use {SAVE,REST}_NVGPRS macros (jsc#SLE-9246).
- powerpc: cleanup hw_irq.h (jsc#SLE-9246).
- powerpc: unify definition of M_IF_NEEDED (jsc#SLE-9246).
- powerpc/perf: remove current_is_64bit() (jsc#SLE-9246).
- powerpc/64s/exception: Fix kaup -> kuap typo (jsc#SLE-9246).
- powerpc: Move EXCEPTION_TABLE to RO_DATA segment (jsc#SLE-9246).
- powerpc: Rename PT_LOAD identifier "kernel" to "text"
  (jsc#SLE-9246).
- powerpc: Remove PT_NOTE workaround (jsc#SLE-9246).
- powerpc: Rename "notes" PT_NOTE to "note" (jsc#SLE-9246).
- powerpc/64: remove support for kernel-mode syscalls
  (jsc#SLE-9246).
- powerpc/32s: get rid of CPU_FTR_601 feature (jsc#SLE-9246).
- powerpc/prom: convert PROM_BUG() to standard trap
  (jsc#SLE-9246).
- Refresh patches.suse/powerpc-64s-Fix-section-mismatch-warnings-from-boot-.patch.
- powerpc/64: optimise LOAD_REG_IMMEDIATE_SYM() (jsc#SLE-9246).
- powerpc: rewrite LOAD_REG_IMMEDIATE() as an intelligent macro
  (jsc#SLE-9246).
- commit 8d00749
* Tue Sep  8 2020 jslaby@suse.cz
- selftests/net: relax cpu affinity requirement in msg_zerocopy
  test (networking-stable-20_08_08).
- dpaa2-eth: Fix passing zero to 'PTR_ERR' warning
  (networking-stable-20_08_08).
- net: thunderx: use spin_lock_bh in nicvf_set_rx_mode_task()
  (networking-stable-20_08_08).
- tcp: apply a floor of 1 for RTT samples from TCP timestamps
  (networking-stable-20_08_08).
- net: gre: recompute gre csum for sctp over gre tunnels
  (networking-stable-20_08_08).
- openvswitch: Prevent kernel-infoleak in ovs_ct_put_key()
  (networking-stable-20_08_08).
- net: ethernet: mtk_eth_soc: fix MTU warnings
  (networking-stable-20_08_08).
- rxrpc: Fix race between recvmsg and sendmsg on immediate call
  failure (networking-stable-20_08_08).
- ipv6: fix memory leaks on IPV6_ADDRFORM path
  (networking-stable-20_08_08).
- ipv4: Silence suspicious RCU usage warning
  (networking-stable-20_08_08).
- vxlan: Ensure FDB dump is performed under RCU
  (networking-stable-20_08_08).
- ipv6: Fix nexthop refcnt leak when creating ipv6 route info
  (networking-stable-20_08_08).
- commit a270aeb
* Tue Sep  8 2020 hare@suse.de
- blacklist.conf: add aad4b4d15f30 ("scsi: libata: Fix the ata_scsi_dma_need_drain stub")
- commit 7742dc4
* Tue Sep  8 2020 hare@suse.de
- blacklist.conf: add 78ed001d9e71 ("compat: scsi: sg: fix v3 compat read/write interface")
- commit e45fc40
* Tue Sep  8 2020 jslaby@suse.cz
- dev: Defer free of skbs in flush_backlog
  (networking-stable-20_07_29).
- qrtr: orphan socket in qrtr_release()
  (networking-stable-20_07_29).
- bonding: check return value of register_netdevice() in
  bond_newlink() (networking-stable-20_07_29).
- sctp: shrink stream outq when fails to do addstream reconf
  (networking-stable-20_07_29).
- sctp: shrink stream outq only when new outcnt < old outcnt
  (networking-stable-20_07_29).
- enetc: Remove the mdio bus on PF probe bailout
  (networking-stable-20_07_29).
- drivers/net/wan/x25_asy: Fix to make it work
  (networking-stable-20_07_29).
- net: dsa: microchip: call phy_remove_link_mode during probe
  (networking-stable-20_07_29).
- kABI: net: dsa: microchip: call phy_remove_link_mode during
  probe (kabi).
- net: udp: Fix wrong clean up for IS_UDPLITE macro
  (networking-stable-20_07_29).
- net-sysfs: add a newline when printing 'tx_timeout' by sysfs
  (networking-stable-20_07_29).
- mlxsw: destroy workqueue when trap_register in mlxsw_emad_init
  (networking-stable-20_07_29).
- rxrpc: Fix sendmsg() returning EPIPE due to recvmsg() returning
  ENODATA (networking-stable-20_07_29).
- bonding: check error value of register_netdevice() immediately
  (networking-stable-20_07_29).
- net: dp83640: fix SIOCSHWTSTAMP to update the struct with
  actual configuration (networking-stable-20_07_29).
- vsock/virtio: annotate 'the_virtio_vsock' RCU pointer
  (networking-stable-20_07_29).
- bnxt_en: Fix completion ring sizing with TPA enabled
  (networking-stable-20_07_29).
- bnxt_en: Fix race when modifying pause settings
  (networking-stable-20_07_29).
- commit 15b35e2
* Tue Sep  8 2020 hare@suse.de
- Update config files.
- commit 190f3ff
* Tue Sep  8 2020 bp@suse.de
- EDAC: Fix reference count leaks (bsc#1152489).
- commit 3f4ad8e
* Tue Sep  8 2020 hare@suse.de
- block: remove alloc_part_info and free_part_info
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/block-diskstats-more-accurate-approximation-of-io_ti.patch.
- commit 7743f0b
* Tue Sep  8 2020 hare@suse.de
- Updated iostats docs (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/block-diskstats-more-accurate-approximation-of-io_ti.patch.
- commit f5c3489
* Mon Sep  7 2020 martin.wilck@suse.com
- Delete patches.suse/megaraid-mbox-fix-SG_IO.
  This patch is only necessary for i386 with CONFIG_HIGHMEM.
- commit 0e7ced3
* Mon Sep  7 2020 martin.wilck@suse.com
- scsi: megaraid_sas: Clear affinity hint (jsc#SLE-15391).
- scsi: megaraid: Remove set but unused variable (jsc#SLE-15391).
- scsi: megaraid: Fix compilation warnings (jsc#SLE-15391).
- scsi: megaraid: Fix kdoc comments format (jsc#SLE-15391).
- scsi: megaraid_sas: Remove undefined ENABLE_IRQ_POLL macro
  (jsc#SLE-15391).
- scsi: megaraid_sas: Update driver version to 07.714.04.00-rc1
  (jsc#SLE-15391).
- scsi: megaraid_sas: TM command refire leads to controller
  firmware crash (jsc#SLE-15391).
- scsi: megaraid_sas: Remove IO buffer hole detection logic
  (jsc#SLE-15391).
- scsi: megaraid_sas: Limit device queue depth to controller
  queue depth (jsc#SLE-15391).
- scsi: megaraid: Use true, false for bool variables
  (jsc#SLE-15391).
- scsi: megaraid: make two symbols static in megaraid_sas_base.c
  (jsc#SLE-15391).
- scsi: megaraid: make some symbols static in
  megaraid_sas_fusion.c (jsc#SLE-15391).
- scsi: megaraid: make some symbols static in megaraid_sas_fp.c
  (jsc#SLE-15391).
- scsi: megaraid: make two symbols static in megaraid_mbox.c
  (jsc#SLE-15391).
- scsi: megaraid_sas: Use scnprintf() for avoiding potential
  buffer overflow (jsc#SLE-15391).
- scsi: megaraid_sas: fix indentation issue (jsc#SLE-15391).
- scsi: megaraid_sas: silence a warning (jsc#SLE-15391).
- scsi: megaraid_sas: Make poll_aen_lock static (jsc#SLE-15391).
- compat_ioctl: use correct compat_ptr() translation in drivers
  (jsc#SLE-15391).
- commit f78ceb4
* Mon Sep  7 2020 bp@suse.de
- x86/mce/inject: Fix a wrong assignment of i_mce.status
  (bsc#1152489).
- commit 64f04e6
* Mon Sep  7 2020 bp@suse.de
- blacklist.conf: 2accfa69050c cpu/speculation: Add prototype for cpu_show_srbds()
- commit 12941df
* Mon Sep  7 2020 dwagner@suse.de
- scsi: libfc: Free skb in fc_disc_gpn_id_resp() for valid cases
  (bsc#1174899).
- scsi: fcoe: Memory leak fix in fcoe_sysfs_fcf_del()
  (bsc#1174899).
- commit f5d1493
* Mon Sep  7 2020 dwagner@suse.de
- series.conf: Update meta-data
  and corresponding patches
- commit 397e951
* Mon Sep  7 2020 bp@suse.de
- Refresh
  patches.suse/x86-asm-64-Align-start-of-__clear_user-loop-to-16-by.patch.
- commit e3c9d3b
* Mon Sep  7 2020 bp@suse.de
- blacklist.conf: cc5277fe66cf x86/resctrl: Fix a NULL vs IS_ERR() static checker warning in rdt_cdp_peer_get()
- commit 67c6df6
* Mon Sep  7 2020 bp@suse.de
- blacklist.conf: 2c18bd525c47 x86/resctrl: Fix memory bandwidth counter width for AMD
  Fix moved to SP3, see bsc#1172757
- commit bacb8af
* Mon Sep  7 2020 mgorman@suse.de
- x86/vector: Remove warning on managed interrupt migration
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit d3e98fd
* Mon Sep  7 2020 tiwai@suse.de
- mei: me: add jasper point DID (jsc#SLE-13387).
- Refresh patches.suse/mei-me-add-cedar-fork-device-ids.patch.
- commit e2c84b3
* Mon Sep  7 2020 tiwai@suse.de
- mei: add device kind to sysfs (jsc#SLE-13387).
- mei: hw: don't use one element arrays (jsc#SLE-13387).
- mei: hw: use sizeof of variable instead of struct type
  (jsc#SLE-13387).
- mei: client: use sizeof of variable instead of struct type
  (jsc#SLE-13387).
- mei: bus: use sizeof of variable instead of struct type
  (jsc#SLE-13387).
- mei: ioctl: use sizeof of variable instead of struct type
  (jsc#SLE-13387).
- mei: hbm: use sizeof of variable instead of struct type
  (jsc#SLE-13387).
- Revert "mei: Avoid the use of one-element arrays"
  (jsc#SLE-13387).
- mei: Avoid the use of one-element arrays (jsc#SLE-13387).
- mei: Replace HTTP links with HTTPS ones (jsc#SLE-13387).
- mei: me: add MEI device for KBP with ITPS capability
  (jsc#SLE-13387).
- mei: me: add MEI device for SPT with ITPS capability
  (jsc#SLE-13387).
- mei: me: add kdoc for mei_me_fw_type_nm() (jsc#SLE-13387).
- mei: me: make mei_me_fw_sku_sps_4() less cryptic
  (jsc#SLE-13387).
- mei: me: constify the device parameter to the probe quirk
  (jsc#SLE-13387).
- mei: hdcp: Constify struct mei_cl_device_id (jsc#SLE-13387).
- mei: me: add tiger lake point device ids for H platforms
  (jsc#SLE-13387).
- mei: me: fix irq number stored in hw struct (jsc#SLE-13387).
- misc: Replace zero-length array with flexible-array member
  (jsc#SLE-13387).
- mei: remove unused includes from pci-{me,txe}.c (jsc#SLE-13387).
- mei: limit number of bytes in mei header (jsc#SLE-13387).
- mei: bus: replace zero-length array with flexible-array member
  (jsc#SLE-13387).
- mei: bus: use simple sprintf for sysfs (jsc#SLE-13387).
- mei: bus: add more client attributes to sysfs (jsc#SLE-13387).
- commit dcfc3cc
* Mon Sep  7 2020 tiwai@suse.de
- mei: add trc detection register to sysfs (jsc#SLE-13387).
- Refresh patches.suse/mei-me-add-cedar-fork-device-ids.patch.
- Refresh
  patches.suse/mei-me-disable-mei-interface-on-LBG-servers.patch.
- Refresh
  patches.suse/mei-me-disable-mei-interface-on-Mehlow-server-platfo.patch.
- commit ae70d68
* Mon Sep  7 2020 tiwai@suse.de
- mei: abstract fw status register read (jsc#SLE-13387).
- mei: me: store irq number in the hw struct (jsc#SLE-13387).
- commit 98bd172
* Mon Sep  7 2020 tiwai@suse.de
- mei: me: mei_me_dev_init() use struct device instead of struct
  pci_dev (jsc#SLE-13387).
- Refresh
  patches.suse/mei-me-disable-mei-interface-on-Mehlow-server-platfo.patch.
- commit a824d21
* Mon Sep  7 2020 tiwai@suse.de
- mei: me: fix me_intr_clear function name in KDoc
  (jsc#SLE-13387).
- mei: buf: drop 'running hook' debug messages (jsc#SLE-13387).
- mei: Use dev_get_drvdata where possible (jsc#SLE-13387).
- commit f572c0c
* Mon Sep  7 2020 tiwai@suse.de
- dmaengine: idxd: reset states after device disable or reset
  (git-fixes).
- commit 4d22d31
* Mon Sep  7 2020 mgorman@suse.de
- isolcpus: Affine unbound kernel threads to housekeeping
  cpus (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- kthread: Switch to cpu_possible_mask (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched/idle,stop: Remove .get_rr_interval from sched_class
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/core: Remove redundant 'preempt' param from
  sched_class->yield_to_task() (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- genirq, sched/isolation: Isolate from handling managed
  interrupts (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- commit fe4d107
* Mon Sep  7 2020 jroedel@suse.de
- epoll: call final ep_events_available() check under the lock
  (bsc#1176237).
- epoll: atomically remove wait entry on wake up (bsc#1176236).
- commit 86b758b
* Mon Sep  7 2020 msuchanek@suse.de
- ima: Fail rule parsing when appraise_flag=blacklist is
  unsupportable (jsc#SLE-15857 jsc#SLE-13618).
- powerpc/ima: Fix secure boot rules in ima arch policy
  (jsc#SLE-15857 jsc#SLE-13618).
- commit 08d5ef7
* Mon Sep  7 2020 msuchanek@suse.de
- rpm/kernel-source.spec.in: Also use bz compression (boo#1175882).
- commit 375ec84
* Mon Sep  7 2020 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Also sign ppc64 kernels (jsc#SLE-15857
  jsc#SLE-13618).
- commit 971fc3d
* Mon Sep  7 2020 msuchanek@suse.de
- powerpc/pseries: Detect secure and trusted boot state of the
  system (jsc#SLE-15857 jsc#SLE-13618).
- powerpc/ima: Indicate kernel modules appended signatures are
  enforced (jsc#SLE-15857 jsc#SLE-13618).
- powerpc/ima: Update ima arch policy to check for blacklist
  (jsc#SLE-15857 jsc#SLE-13618).
- ima: Check against blacklisted hashes for files with modsig
  (jsc#SLE-15857 jsc#SLE-13618).
- certs: Add wrapper function to check blacklisted binary hash
  (jsc#SLE-15857 jsc#SLE-13618).
- ima: Make process_buffer_measurement() generic (jsc#SLE-15857
  jsc#SLE-13618).
- powerpc/ima: Define trusted boot policy (jsc#SLE-15857
  jsc#SLE-13618).
- powerpc: Detect the trusted boot state of the system
  (jsc#SLE-15857 jsc#SLE-13618).
- powerpc/ima: Add support to initialize ima policy rules
  (jsc#SLE-15857 jsc#SLE-13618).
- powerpc: Detect the secure boot mode of the system
  (jsc#SLE-15857 jsc#SLE-13618).
- powerpc/xmon: Restrict when kernel is locked down (jsc#SLE-15857
  jsc#SLE-13618).
- Refresh patches.suse/powerpc-xmon-Reset-RCU-and-soft-lockup-watchdogs.patch
- commit a1e1f59
* Mon Sep  7 2020 jeyu@suse.de
- Delete patches.kabi/* workarounds
- commit db6ec16
* Mon Sep  7 2020 bp@suse.de
- EDAC/amd64: Read back the scrub rate PCI register on F15h
  (bsc#1152489).
- commit dae70cc
* Mon Sep  7 2020 bp@suse.de
- EDAC/amd64: Add AMD family 17h model 60h PCI IDs (bsc#1152489).
- commit 059d4f2
* Mon Sep  7 2020 jgross@suse.com
- XEN uses irqdesc::irq_data_common::handler_data to store a
  per interrupt XEN data pointer which contains XEN specific
  information (bsc#1065600).
- commit b863d57
* Mon Sep  7 2020 jgross@suse.com
- xen: don't reschedule in preemption off sections (bsc#1175749).
- commit 2a68c8d
* Mon Sep  7 2020 tiwai@suse.de
- include/asm-generic/vmlinux.lds.h: align ro_after_init
  (git-fixes).
- include/linux/poison.h: remove obsolete comment (git-fixes).
- include/linux/bitops.h: avoid clang shift-count-overflow
  warnings (git-fixes).
- thermal: qcom-spmi-temp-alarm: Don't suppress negative temp
  (git-fixes).
- thermal: ti-soc-thermal: Fix bogus thermal shutdowns for
  omap4430 (git-fixes).
- dmaengine: dw-edma: Fix scatter-gather address calculation
  (git-fixes).
- dmaengine: pl330: Fix burst length if burst size is smaller
  than bus width (git-fixes).
- dmaengine: at_hdmac: check return value of
  of_find_device_by_node() in at_dma_xlate() (git-fixes).
- dmaengine: of-dma: Fix of_dma_router_xlate's of_dma_xlate
  handling (git-fixes).
- drm/radeon: Prefer lower feedback dividers (git-fixes).
- batman-adv: bla: use netif_rx_ni when not in interrupt context
  (git-fixes).
- batman-adv: Fix own OGM check in aggregated OGMs (git-fixes).
- batman-adv: Avoid uninitialized chaddr when handling DHCP
  (git-fixes).
- media: cedrus: Add missing v4l2_ctrl_request_hdl_put()
  (git-fixes).
- HID: core: Sanitize event code and type when mapping input
  (git-fixes).
- HID: core: Correctly handle ReportSize being zero (git-fixes).
- usb: storage: Add unusual_uas entry for Sony PSZ drives
  (git-fixes).
- USB: gadget: u_f: Unbreak offset calculation in VLAs
  (git-fixes).
- USB: gadget: f_ncm: add bounds checks to ncm_unwrap_ntb()
  (git-fixes).
- USB: gadget: u_f: add overflow checks to VLA macros (git-fixes).
- xhci: Do warm-reset when both CAS and XDEV_RESUME are set
  (git-fixes).
- usb: uas: Add quirk for PNY Pro Elite (git-fixes).
- USB: lvtest: return proper error code in probe (git-fixes).
- USB: quirks: Add no-lpm quirk for another Raydium touchscreen
  (git-fixes).
- USB: yurex: Fix bad gfp argument (git-fixes).
- drm/amdgpu: Fix buffer overflow in INFO ioctl (git-fixes).
- drm/amd/pm: correct the thermal alert temperature limit settings
  (git-fixes).
- drm/amdgpu/gfx10: refine mgcg setting (git-fixes).
- drm/amd/pm: correct Vega20 swctf limit setting (git-fixes).
- drm/amd/pm: correct Vega12 swctf limit setting (git-fixes).
- drm/amd/pm: correct Vega10 swctf limit setting (git-fixes).
- fbcon: prevent user font height or width change from causing
  potential out-of-bounds access (git-fixes).
- vt: defer kfree() of vc_screenbuf in vc_do_resize() (git-fixes).
- HID: hiddev: Fix slab-out-of-bounds write in
  hiddev_ioctl_usage() (git-fixes).
- HID: i2c-hid: Always sleep 60ms after I2C_HID_PWR_ON commands
  (git-fixes).
- drm/amd/display: Switch to immediate mode for updating
  infopackets (git-fixes).
- drm/amd/powerplay: correct UVD/VCE PG state on custom pptable
  uploading (git-fixes).
- drm/amd/powerplay: correct Vega20 cached smu feature state
  (git-fixes).
- spi: stm32: always perform registers configuration prior to
  transfer (git-fixes).
- spi: stm32: fix stm32_spi_prepare_mbr in case of odd clk_rate
  (git-fixes).
- spi: stm32: fix fifo threshold level in case of short transfer
  (git-fixes).
- spi: stm32h7: fix race condition at end of transfer (git-fixes).
- spi: stm32: clear only asserted irq flags on interrupt
  (git-fixes).
- mfd: intel-lpss: Add Intel Emmitsburg PCH PCI IDs (git-fixes).
- fbmem: pull fbcon_update_vcs() out of fb_set_var() (git-fixes).
- HID: quirks: add NOGET quirk for Logitech GROUP (git-fixes).
- PCI: Fix pci_create_slot() reference count leak (git-fixes).
- media: davinci: vpif_capture: fix potential double free
  (git-fixes).
- media: pci: ttpci: av7110: fix possible buffer overflow caused
  by bad DMA value in debiirq() (git-fixes).
- ASoC: tegra: Fix reference count leaks (git-fixes).
- ASoC: img-parallel-out: Fix a reference count leak (git-fixes).
- ASoC: img: Fix a reference count leak in img_i2s_in_set_fmt
  (git-fixes).
- rtlwifi: rtl8192cu: Prevent leaking urb (git-fixes).
- drm/nouveau: Fix reference count leak in
  nouveau_connector_detect (git-fixes).
- drm/nouveau: fix reference count leak in nv50_disp_atomic_commit
  (git-fixes).
- drm/nouveau/drm/noveau: fix reference count leak in
  nouveau_fbcon_open (git-fixes).
- omapfb: fix multiple reference count leaks due to
  pm_runtime_get_sync (git-fixes).
- drm/amdgpu/display: fix ref count leak when pm_runtime_get_sync
  fails (git-fixes).
- drm/amdgpu: fix ref count leak in amdgpu_display_crtc_set_config
  (git-fixes).
- drm/amd/display: fix ref count leak in amdgpu_drm_ioctl
  (git-fixes).
- drm/amdgpu: fix ref count leak in amdgpu_driver_open_kms
  (git-fixes).
- drm/radeon: fix multiple reference count leak (git-fixes).
- drm/amdkfd: Fix reference count leaks (git-fixes).
- USB: sisusbvga: Fix a potential UB casued by left shifting a
  negative value (git-fixes).
- media: gpio-ir-tx: improve precision of transmitted signal
  due to scheduling (git-fixes).
- drm/sched:  Fix passing zero to 'PTR_ERR' warning v2
  (git-fixes).
- commit aa50939
* Mon Sep  7 2020 shung-hsi.yu@suse.com
- net: ethernet: mlx4: Fix memory allocation in mlx4_buddy_init()
  (git-fixes).
- commit 4a76c88
* Sun Sep  6 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/ibmvnic-fix-NULL-tx_pools-and-rx_tools-issue-at-do_r.patch
- commit 8ff6392
* Sun Sep  6 2020 tiwai@suse.de
- ALSA: hda/realtek - Improved routing for Thinkpad X1 7th/8th
  Gen (git-fixes).
- ALSA: hda: fix a runtime pm issue in SOF when integrated GPU
  is disabled (git-fixes).
- ALSA: hda: hdmi - add Rocketlake support (git-fixes).
- ALSA: pcm: oss: Remove superfluous WARN_ON() for mulaw sanity
  check (git-fixes).
- ALSA: hda - Fix silent audio output and corrupted input on
  MSI X570-A PRO (git-fixes).
- ALSA: hda/hdmi: always check pin power status in i915 pin fixup
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Samsung Galaxy Book Ion
  NT950XCJ-X716A (git-fixes).
- ALSA: usb-audio: Add basic capture support for Pioneer DJ
  DJM-250MK2 (git-fixes).
- ALSA: usb-audio: Add implicit feedback quirk for UR22C
  (git-fixes).
- Revert "ALSA: hda: Add support for Loongson 7A1000 controller"
  (git-fixes).
- ALSA: hda/tegra: Program WAKEEN register for Tegra (git-fixes).
- ALSA: hda: Fix 2 channel swapping for Tegra (git-fixes).
- ALSA: ca0106: fix error code handling (git-fixes).
- ALSA: usb-audio: Disable autosuspend for Lenovo ThinkStation
  P620 (git-fixes).
- ALSA: firewire-digi00x: exclude Avid Adrenaline from detection
  (git-fixes).
- ALSA; firewire-tascam: exclude Tascam FE-8 from detection
  (git-fixes).
- ASoC: SOF: Intel: add PCI ID for CometLake-S (git-fixes).
- commit 56f2f52
* Fri Sep  4 2020 hare@suse.de
- loop: Refactor loop_set_status() size calculation
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/loop-replace-kill_bdev-with-invalidate_bdev.patch.
- commit 8d199d1
* Fri Sep  4 2020 hare@suse.de
- loop: Only change blocksize when needed
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/loop-replace-kill_bdev-with-invalidate_bdev.patch.
- commit fd7bc41
* Fri Sep  4 2020 msuchanek@suse.de
- blacklist.conf: Fixes for complex PTEs with atomic READ_ONCE
  55ca22633a9f mm/gup: Use huge_ptep_get() in gup_hugepte()
  481e980a7c19 mm: Allow arches to provide ptep_get()
  c0e1c8c22beb powerpc/8xx: Provide ptep_get() with 16k pages
  9449c9cb420b mm/debug_vm_pgtable: fix build failure with powerpc 8xx
- commit 71415e0
* Fri Sep  4 2020 msuchanek@suse.de
- powerpc/pseries: Add KVM guest doorbell restrictions
  (jsc#SLE-15869).
- powerpc/pseries: Use doorbells even if XIVE is available
  (jsc#SLE-15869).
- powerpc: Inline doorbell sending functions (jsc#SLE-15869).
- commit 5689aaf
* Fri Sep  4 2020 hare@suse.de
- Revert "blkdev: check for valid request queue before issuing
  (bsc#1175995,jsc#SLE-15608).
- blacklist.conf:
- commit 23f3a1c
* Thu Sep  3 2020 mkubecek@suse.cz
- net/packet: fix overflow in tpacket_rcv (CVE-2020-14386
  bsc#1176069).
- commit b3a3711
* Thu Sep  3 2020 msuchanek@suse.de
- powerpc/xive: Enforce load-after-store ordering when StoreEOI
  is active (jsc#SLE-13294).
- commit e3468cc
* Thu Sep  3 2020 msuchanek@suse.de
- fault_inject: Don't rely on "return value" from WRITE_ONCE()
  (jsc#SLE-15848).
- netfilter: Avoid assigning 'const' pointer to non-const pointer
  (jsc#SLE-15848).
- commit a86b9c2
* Thu Sep  3 2020 msuchanek@suse.de
- xsk: Remove unnecessary READ_ONCE of data (jsc#SLE-15848).
- commit 10a2558
* Thu Sep  3 2020 msuchanek@suse.de
- powerpc/perf: Add extended regs support for power10 platform
  (jsc#SLE-13513).
- powerpc/perf: Add support for outputting extended regs in perf
  intr_regs (jsc#SLE-13513).
- powerpc/perf: Fix MMCRA_BHRB_DISABLE define for binutils <
  2.28 (jsc#SLE-13513).
- powerpc/perf: Initialize power10 PMU registers in cpu setup
  routine (jsc#SLE-13513).
- powerpc/perf: BHRB control to disable BHRB logic when not used
  (jsc#SLE-13513).
- powerpc/perf: Add Power10 BHRB filter support for
  PERF_SAMPLE_BRANCH_IND_CALL/COND (jsc#SLE-13513).
- powerpc/perf: Ignore the BHRB kernel address filtering for P10
  (jsc#SLE-13513).
- powerpc/perf: power10 Performance Monitoring support
  (jsc#SLE-13513).
- powerpc/perf: Add Power10 PMU feature to DT CPU features
  (jsc#SLE-13513).
- powerpc/xmon: Add PowerISA v3.1 PMU SPRs (jsc#SLE-13513).
- KVM: PPC: Book3S HV: Save/restore new PMU registers
  (jsc#SLE-13513).
- powerpc/perf: Add support for ISA3.1 PMU SPRs (jsc#SLE-13513).
- powerpc/perf: Update Power PMU cache_events to u64 type
  (jsc#SLE-13513).
- KVM: PPC: Book3S HV: Cleanup updates for kvm vcpu MMCR
  (jsc#SLE-13513).
- powerpc/perf: Update cpu_hw_event to use `struct` for storing
  MMCR registers (jsc#SLE-13513).
- Documentation: Document sysfs interfaces purr, spurr, idle_purr,
  idle_spurr (jsc#SLE-13522).
- powerpc/sysfs: Show idle_purr and idle_spurr for every CPU
  (jsc#SLE-13522).
- powerpc/pseries: Account for SPURR ticks on idle CPUs
  (jsc#SLE-13522).
- powerpc/idle: Store PURR snapshot in a per-cpu global variable
  (jsc#SLE-13522).
- powerpc: Move idle_loop_prolog()/epilog() functions to header
  file (jsc#SLE-13522).
- powerpc/kernel/sysfs: Add new config option PMU_SYSFS to enable
  PMU SPRs sysfs file creation (jsc#SLE-13513).
- Update config files.
- powerpc/kernel/sysfs: Refactor current sysfs.c (jsc#SLE-13513).
- powerpc: Fix Kconfig indentation (jsc#SLE-13513).
- commit 89a40bf
* Thu Sep  3 2020 ailiop@suse.com
- xfs: fix boundary test in xfs_attr_shortform_verify
  (CVE-2020-14385 bsc#1176137).
- commit e45cbdb
* Thu Sep  3 2020 msuchanek@suse.de
- powerpc: Remove IBM405 Erratum #77 (jsc#SLE-15848).
- commit 024cbd5
* Thu Sep  3 2020 msuchanek@suse.de
- powerpc: Implement smp_cond_load_relaxed() (jsc#SLE-15848).
- powerpc/qspinlock: Optimised atomic_try_cmpxchg_lock() that
  adds the lock hint (jsc#SLE-15848).
- commit 781c4c2
* Thu Sep  3 2020 msuchanek@suse.de
- powerpc/pseries: Implement paravirt qspinlocks for SPLPAR
  (jsc#SLE-15848).
- Update config files.
- commit 4460c97
* Thu Sep  3 2020 msuchanek@suse.de
- powerpc/64s: Implement queued spinlocks and rwlocks
  (jsc#SLE-15848).
- Update config files.
- commit c9e6aca
* Thu Sep  3 2020 msuchanek@suse.de
- powerpc: Move spinlock implementation to simple_spinlock
  (jsc#SLE-15848).
- commit f492c92
* Thu Sep  3 2020 msuchanek@suse.de
- powerpc/pseries: Move some PAPR paravirt functions to their
  own file (jsc#SLE-15848).
- commit 1dc4f21
* Thu Sep  3 2020 msuchanek@suse.de
- READ_ONCE: Drop pointer qualifiers when reading from scalar
  types (jsc#SLE-15848).
- READ_ONCE: Enforce atomicity for {READ,WRITE}_ONCE() memory
  accesses (jsc#SLE-15848).
- READ_ONCE: Simplify implementations of {READ,WRITE}_ONCE()
  (jsc#SLE-15848).
- commit 5e2d541
* Thu Sep  3 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/sched-Add-a-tracepoint-to-track-rq-nr_running.patch
  patches.suse/sched-Better-document-ttwu.patch
  patches.suse/sched-Fix-use-of-count-for-nr_running-tracepoint.patch
  patches.suse/sched-cputime-Improve-cputime_adjust.patch
  patches.suse/sched-debug-Add-new-tracepoints-to-track-util_est.patch
  patches.suse/sched-debug-Fix-the-alignment-of-the-show-state-debug-output.patch
  patches.suse/sched-fair-Remove-unused-sd-parameter-from-scale_rt_capacity.patch
  patches.suse/sched-fair-update_pick_idlest-Select-group-with-lowest-group_util-when-idle_cpus-are-equal.patch
  patches.suse/sched-nohz-stop-passing-around-unused-ticks-parameter.patch
  patches.suse/sched-pelt-Remove-redundant-cap_scale-definition.patch
- commit 1ab5af9
* Thu Sep  3 2020 hare@suse.de
- block: blk-crypto-fallback for Inline Encryption
  (bsc#1175995,jsc#SLE-15608).
- Update config files.
- block: Make blk-integrity preclude hardware inline encryption
  (bsc#1175995,jsc#SLE-15608).
- block: Inline encryption support for blk-mq
  (bsc#1175995,jsc#SLE-15608).
- commit b9e8717
* Thu Sep  3 2020 hare@suse.de
- block: Keyslot Manager for Inline Encryption
  (bsc#1175995,jsc#SLE-15608).
- Update config files.
- commit a4fb9c0
* Thu Sep  3 2020 hare@suse.de
- scsi: sd_zbc: add zone open, close, and finish support
  (bsc#1175995,jsc#SLE-15608).
- Refresh patches.suse/0014-block-rework-zone-reporting.patch.
- commit 657b21c
* Thu Sep  3 2020 pmladek@suse.com
- blacklist.conf: dma-debug: speed up debug code that is disabled in SUSE kernels
- commit aa33a0d
* Thu Sep  3 2020 pmladek@suse.com
- blacklist.conf: kstrto*: comment fix
- commit 26002cd
* Thu Sep  3 2020 pmladek@suse.com
- blacklist.conf: kthread: comment fix
- commit 7fd20f3
* Thu Sep  3 2020 vliaskovitis@suse.com
- mei: me: disable mei interface on Mehlow server platforms
  (bsc#1175952).
- commit a2053ac
* Thu Sep  3 2020 vliaskovitis@suse.com
- mei: fix CNL itouch device number to match the spec
  (bsc#1175952).
- commit a4a5282
* Thu Sep  3 2020 vliaskovitis@suse.com
- mei: me: disable mei interface on LBG servers (bsc#1175952).
- commit e28fa12
* Thu Sep  3 2020 msuchanek@suse.de
- powerpc/perf/hv-24x7: Move cpumask file to top folder of
  hv-24x7 driver (jsc#SLE-13610).
- commit 3655af6
* Thu Sep  3 2020 msuchanek@suse.de
- powerpc/hv-24x7: Add sysfs files inside hv-24x7 device to show
  cpumask (jsc#SLE-13610).
- powerpc/perf/hv-24x7: Add cpu hotplug support (jsc#SLE-13610).
- commit ea29484
* Thu Sep  3 2020 msuchanek@suse.de
- powerpc/test_emulate_sstep: Fix build error (jsc#SLE-13847).
- commit ada7d37
* Thu Sep  3 2020 tiwai@suse.de
- Update config files: sync some missing kconfigs with Leap (bsc#1175697)
  CONFIG_CHELSIO_T4_DCB=y
  CONFIG_CHELSIO_T4_FCOE=y
  CONFIG_CEPH_LIB_PRETTYDEBUG=y
- commit 802acd7
* Thu Sep  3 2020 hare@suse.de
- block: move bio_map_* to blk-map.c (bsc#1175995,jsc#SLE-15608).
- Refresh patches.suse/0001-oracleasm-4.0-compat-changes.patch.
- commit 1b4712e
* Thu Sep  3 2020 msuchanek@suse.de
- powerpc/xmon: Improve dumping prefixed instructions
  (jsc#SLE-13847).
- powerpc: Add a ppc_inst_as_str() helper (jsc#SLE-13847).
- powerpc/sstep: Add tests for Prefixed Add Immediate
  (jsc#SLE-13847).
- powerpc/sstep: Let compute tests specify a required cpu feature
  (jsc#SLE-13847).
- powerpc/sstep: Set NIP in instruction emulation tests
  (jsc#SLE-13847).
- powerpc/sstep: Add tests for prefixed floating-point load/stores
  (jsc#SLE-13847).
- powerpc/sstep: Add tests for prefixed integer load/stores
  (jsc#SLE-13847).
- commit 2cee177
* Thu Sep  3 2020 hare@suse.de
- brd: check and limit max_part par (bsc#1175995,jsc#SLE-15608).
- commit 572eb85
* Thu Sep  3 2020 mgorman@suse.de
- sched/debug: Fix the alignment of the show-state debug output
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched: Fix use of count for nr_running tracepoint (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: update_pick_idlest() Select group with lowest
  group_util when idle_cpus are equal (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched: nohz: stop passing around unused "ticks" parameter
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched: Better document ttwu() (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched: Add a tracepoint to track rq->nr_running (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/debug: Add new tracepoints to track util_est (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Remove unused 'sd' parameter from
  scale_rt_capacity() (bnc#1155798 (CPU scheduler functional
  and performance backports)).
- sched/pelt: Remove redundant cap_scale() definition (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/cputime: Improve cputime_adjust() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- commit 7ea4247
* Thu Sep  3 2020 wqu@suse.com
- Update
  patches.suse/btrfs-Move-free_pages_out-label-in-inline-extent-han.patch
  (bsc#1174484).
  Fix wrong bsc reference number exposed by Filipe:
  https://bugzilla.suse.com/show_bug.cgi?id=1175263#c1
- commit 8c0ade9
* Thu Sep  3 2020 hare@suse.de
- null_blk: return fixed zoned reads > write pointer
  (bsc#1175995,jsc#SLE-15608).
- Refresh patches.suse/0013-null_blk-clean-up-report-zones.patch.
- Refresh patches.suse/0014-block-rework-zone-reporting.patch.
- commit ac93d69
* Wed Sep  2 2020 bp@suse.de
- x86/Kconfig: Update config and kernel doc for MPK feature on
  AMD (jsc#13716).
- commit 390ffeb
* Wed Sep  2 2020 hare@suse.de
- null_blk: create a helper for req completion
  (bsc#1175995,jsc#SLE-15608).
- commit 9063449
* Wed Sep  2 2020 hare@suse.de
- null_blk: create a helper for mem-backed ops
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/0002-null_blk-create-a-helper-for-zoned-devices.patch.
- commit 424d58c
* Wed Sep  2 2020 bp@suse.de
- x86/delay: Introduce TPAUSE delay (jsc#13475).
- commit 4f037e7
* Wed Sep  2 2020 bp@suse.de
- x86/delay: Refactor delay_mwaitx() for TPAUSE support
  (jsc#13475).
- commit 9ceeede
* Wed Sep  2 2020 dwagner@suse.de
- scsi: lpfc: Update lpfc version to 12.8.0.3 (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Fix LUN loss after cable pull (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Fix validation of bsg reply lengths (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Fix retry of PRLI when status indicates its
  unsupported (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix oops when unloading driver while running
  mds diags (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix RSCN timeout due to incorrect gidft counter
  (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000
  jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix no message shown for lpfc_hdw_queue out of
  range value (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix FCoE speed reporting (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Add missing misc_deregister() for lpfc_init()
  (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000
  jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: nvmet: Avoid hang / use-after-free again when
  destroying targetport (bsc#1171558 bsc#1136666 bsc#1174486
  bsc#1175787 bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix typo in comment for ULP (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Add description for lpfc_release_rpi()'s 'ndlpl
  param (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix a bunch of kerneldoc misdemeanors (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Add and rename a whole bunch of function parameter
  descriptions (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Use __printf() format notation (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Fix kerneldoc parameter formatting/misnaming/missing
  issues (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix some function parameter descriptions
  (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000
  jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Ensure variable has the same stipulations as code
  using it (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix-up formatting/docrot where appropriate
  (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000
  jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Provide description for lpfc_mem_alloc()'s
  'align' param (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix-up around 120 documentation issues (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Remove unused variable 'pg_addr' (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Correct some pretty obvious misdocumentation
  (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000
  jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: NVMe remote port devloss_tmo from lldd (bcs#1173060 bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
  Replace patches.suse/lpfc-synchronize-nvme-transport-and-lpfc-driver-devloss_tmo.patch
  with upstream version of the fix.
- scsi: lpfc: Quieten some printks (bsc#1171558 bsc#1136666
  bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Avoid another null dereference in
  lpfc_sli4_hba_unset() (bsc#1171558 bsc#1136666 bsc#1174486
  bsc#1175787 bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- commit b565a9f
* Wed Sep  2 2020 hare@suse.de
- block: move block layer internals out of include/linux/genhd.h
  (bsc#1175995,jsc#SLE-15608).
- Refresh
  patches.suse/block-nr_sects_write-Disable-preemption-on-seqcount-.patch.
- commit 6bceeb5
* Wed Sep  2 2020 bp@suse.de
- x86/delay: Preparatory code cleanup (jsc#13475).
- commit edc96e8
* Wed Sep  2 2020 yousaf.kaukab@suse.com
- kabi/severities: ignore kABI for net/ethernet/mscc/
  References: bsc#1176001,bsc#1175999
  Exported symbols from drivers/net/ethernet/mscc/ are
  only used by drivers/net/dsa/ocelot/
- commit 16c1e85
* Wed Sep  2 2020 jack@suse.cz
- ext4: handle read only external journal device (bsc#1176063).
- commit 06e42e2
* Wed Sep  2 2020 jslaby@suse.cz
- platform/x86: dcdbas: Check SMBIOS for protected buffer address
  (jsc#SLE-14458).
- commit a83abd2
* Wed Sep  2 2020 dwagner@suse.de
- Update patches.suse/firmware-smccc-drop-smccc_version-enum-and-use-arm_smccc_version_1_x-instead.patch
  By the time the backport happened the file of SMCCC v1.2
  'arm64/kernel/paravirt.c' didn't exist.  It was introduced later on
  with 94bebd30479. Add missing hunk to fix compile breaks on aarch64.
- commit 3d16a74
* Wed Sep  2 2020 hare@suse.de
- block, bfq: clarify the goal of bfq_split_bfqq()
  (bsc#1175995,jsc#SLE-15608).
- commit dd4e4ab
* Wed Sep  2 2020 hare@suse.de
- block, bfq: get extra ref to prevent a queue from being freed
  during a group move (bsc#1175995,jsc#SLE-15608).
- block, bfq: do not insert oom queue into position tree
  (bsc#1175995,jsc#SLE-15608).
- commit ecee8c8
* Tue Sep  1 2020 bp@suse.de
- x86/fpu/xstate: Restore supervisor states for signal return
  (jsc#13212).
- commit d5168c3
* Tue Sep  1 2020 msuchanek@suse.de
- powerpc/book3s64/radix: Fix boot failure with large amount of
  guest memory (bsc#1176022 ltc#187208).
- commit 8bb9577
* Tue Sep  1 2020 tiwai@suse.de
- mtd: spi-nor: intel-spi: Add support for Intel Jasper Lake
  SPI serial flash (jsc#SLE-12602).
- Refresh
  patches.suse/mtd-spi-nor-intel-spi-Add-support-for-Intel-Emmitsbu.patch.
- Refresh
  patches.suse/mtd-spi-nor-intel-spi-Add-support-for-Intel-TGL-H.patch.
- commit 5fe52f3
* Tue Sep  1 2020 tiwai@suse.de
- powercap/intel_rapl: add support for JasperLake (jsc#SLE-12602).
- Refresh
  patches.suse/powercap-intel_rapl-convert-to-new-x86-cpu-match-macros.patch.
- commit bc42846
* Tue Sep  1 2020 tiwai@suse.de
- mfd: intel-lpss: Update LPSS UART #2 PCI ID for Jasper Lake
  (jsc#SLE-12602).
- commit dc38d6c
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: rename btrfs_block_group_cache (bsc#1176019).
- Refresh
  patches.suse/btrfs-scrub-Don-t-check-free-space-before-marking-a-.patch.
- commit 1e82a09
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: use btrfs_block_group_cache_done in update_block_group
  (bsc#1176019).
- Update
  patches.suse/btrfs-add-dedicated-members-for-start-and-length-of-.patch
  (bsc#1176019).
- commit 9bd7aef
* Tue Sep  1 2020 hare@suse.de
- block: Allow t10-pi to be modular (bsc#1175995,jsc#SLE-15608).
- blk-mq: optimise blk_mq_flush_plug_list()
  (bsc#1175995,jsc#SLE-15608).
- list: introduce list_for_each_continue()
  (bsc#1175995,jsc#SLE-15608).
- blk-mq: optimise rq sort function (bsc#1175995,jsc#SLE-15608).
- commit 0bac65d
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: block-group: Reuse the item key from caller of
  read_one_block_group() (bsc#1176019).
- commit a94961e
* Tue Sep  1 2020 tiwai@suse.de
- ACPI: fan: Fix Tiger Lake ACPI device ID (jsc#SLE-13387).
- ACPI: DPTF: Add battery participant for TigerLake
  (jsc#SLE-13387).
- ACPI: Update Tiger Lake ACPI device IDs (jsc#SLE-13387).
- ACPI: fan: Add Tiger Lake ACPI device ID (jsc#SLE-13387).
- ACPI: DPTF: Add Tiger Lake ACPI device IDs (jsc#SLE-13387).
- commit 3d8432e
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: block-group: Refactor btrfs_read_block_groups()
  (bsc#1176019).
- commit 29102c4
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: add dedicated members for start and length of a block
  group (bsc#1176019).
- Refresh
  patches.suse/0001-btrfs-scrub-Require-mandatory-block-group-RO-for-dev.patch.
- Refresh
  patches.suse/0002-btrfs-kill-min_allocable_bytes-in-inc_block_group_ro.patch.
- Refresh
  patches.suse/0002-btrfs-take-overcommit-into-account-in-inc_block_grou.patch.
- Refresh
  patches.suse/Btrfs-fix-block-group-remaining-RO-forever-after-err.patch.
- Refresh
  patches.suse/btrfs-fix-a-block-group-ref-counter-leak-after-failu.patch.
- Refresh
  patches.suse/btrfs-fix-race-between-block-group-removal-and-block.patch.
- commit 1e9fcdd
* Tue Sep  1 2020 tiwai@suse.de
- xhci-pci: Allow host runtime PM as default for Intel Tiger
  Lake xHCI (jsc#SLE-13387).
- commit 91055c7
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: rename extent buffer block group item accessors
  (bsc#1176019).
- commit 8b22e32
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: rename block_group_item on-stack accessors to follow
  naming (bsc#1176019).
- commit 93bdcbc
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: remove embedded block_group_cache::item (bsc#1176019).
- commit 667dac6
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: move block_group_item::flags to block group
  (bsc#1176019).
- commit 6f39840
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: move block_group_item::used to block group (bsc#1176019).
- Refresh
  patches.suse/0002-btrfs-take-overcommit-into-account-in-inc_block_grou.patch.
- commit 225cb14
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: drop unused parameter is_new from btrfs_iget
  (bsc#1176019).
- commit 3fe9dc3
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: stop clearing EXTENT_DIRTY in inode I/O tree
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-qgroup-fix-data-leak-caused-by-race-between-wr.patch.
- commit 8d60367
* Tue Sep  1 2020 tiwai@suse.de
- sdhci: tegra: Add missing TMCLK for data timeout (git-fixes).
- sdhci: tegra: Remove SDHCI_QUIRK_DATA_TIMEOUT_USES_SDCLK for
  Tegra186 (git-fixes).
- sdhci: tegra: Remove SDHCI_QUIRK_DATA_TIMEOUT_USES_SDCLK for
  Tegra210 (git-fixes).
- mmc: mediatek: add optional module reset property (git-fixes).
- mmc: dt-bindings: Add resets/reset-names for Mediatek MMC
  bindings (git-fixes).
- mmc: sdhci-acpi: Fix HS400 tuning for AMDI0040 (git-fixes).
- commit c4a6eec
* Tue Sep  1 2020 tiwai@suse.de
- thermal: int340x: processor_thermal: fix: update Jasper Lake
  PCI id (jsc#SLE-13387).
- thermal/int340x_thermal: Prevent page fault on .set_mode() op
  (jsc#SLE-13387).
- thermal/int340x_thermal: Don't require IDSP to exist
  (jsc#SLE-13387).
- thermal/int340x_thermal: Export OEM vendor variables
  (jsc#SLE-13387).
- thermal/int340x_thermal: Export GDDV (jsc#SLE-13387).
- thermal: int3400_thermal: Statically initialize
  .get_mode()/.set_mode() ops (jsc#SLE-13387).
- thermal: int340x_thermal: Use scnprintf() for avoiding potential
  buffer overflow (jsc#SLE-13387).
- thermal: int340x: processor_thermal: Add Tiger Lake support
  (jsc#SLE-13387).
- thermal: int340x_thermal: fix: Update Tiger Lake ACPI device
  IDs (jsc#SLE-13387).
- thermal: int340x: processor_thermal: Add Jasper Lake support
  (jsc#SLE-13387).
- thermal: int340x_thermal: Add Tiger Lake ACPI device IDs
  (jsc#SLE-13387).
- thermal: intel: int3403: replace printk(KERN_WARN...) with
  pr_warn(...) (jsc#SLE-13387).
- thermal: intel: int340x_thermal: Remove unnecessary
  acpi_has_method() uses (jsc#SLE-13387).
- thermal: int340x: processor_thermal: Add Ice Lake support
  (jsc#SLE-13387).
- drivers: thermal: processor_thermal_device: Export sysfs
  interface for TCC offset (jsc#SLE-13387).
- commit 6e3819d
* Tue Sep  1 2020 tiwai@suse.de
- platform/x86: intel-hid: fix: Update Tiger Lake ACPI device ID
  (jsc#SLE-13387).
- platform/x86: intel-hid: Move MODULE_DEVICE_TABLE() closer to
  the table (jsc#SLE-13387).
- platform/x86: intel-hid: Add Tiger Lake ACPI device ID
  (jsc#SLE-13387).
- commit 0b4c6a8
* Tue Sep  1 2020 tiwai@suse.de
- Add a few already cherry-picked commits for intel_pmc_core
- commit 68146d5
* Tue Sep  1 2020 tiwai@suse.de
- platform/x86: intel_pmc_core: fix bound check in
  pmc_core_mphy_pg_show() (jsc#SLE-13387).
- platform/x86: intel_pmc_core: update TGL's LPM0 reg bit map name
  (jsc#SLE-13387).
- platform/x86: intel_pmc_core: avoid unused-function warnings
  (jsc#SLE-13387).
- platform/x86: intel_pmc_core: Change Jasper Lake S0ix debug
  reg map back to ICL (jsc#SLE-13387).
- platform/x86: intel_pmc_core: Make pmc_core_substate_res_show()
  generic (jsc#SLE-13387).
- platform/x86: intel_pmc_core: Make pmc_core_lpm_display()
  generic for platforms that support sub-states (jsc#SLE-13387).
- platform/x86: intel_pmc_core: Add slp_s0_offset attribute back
  to tgl_reg_map (jsc#SLE-13387).
- platform/x86: intel_pmc_core: Remove duplicate 'if' to create
  debugfs entry (jsc#SLE-13387).
- platform/x86: intel_pmc_core: Relocate pmc_core_*_display()
  to outside of CONFIG_DEBUG_FS (jsc#SLE-13387).
- platform/x86: intel_pmc_core: Add debugfs support to access
  live status registers (jsc#SLE-13387).
- commit 9811ea8
* Tue Sep  1 2020 tiwai@suse.de
- platform/x86: intel_pmc_core: Add debugfs entry to access
  sub-state residencies (jsc#SLE-13387).
- Refresh
  patches.suse/platform-x86-intel_pmc_core-Add-an-additional-parame.patch.
- Refresh
  patches.suse/platform-x86-intel_pmc_core-Add-debugfs-entry-for-lo.patch.
- commit 5a82a09
* Tue Sep  1 2020 tiwai@suse.de
- platform/x86: intel_pmc_core: Add Atom based Jasper Lake (JSL)
  platform support (jsc#SLE-13387).
- commit b614cfa
* Tue Sep  1 2020 tiwai@suse.de
- platform/x86: intel_pmc_core: Put more stuff under #ifdef
  DEBUG_FS (jsc#SLE-13387).
- Refresh
  patches.suse/platform-x86-intel_pmc_core-Add-debugfs-entry-for-lo.patch.
- commit c4d083d
* Tue Sep  1 2020 tiwai@suse.de
- platform/x86: intel-ips: Use the correct style for SPDX License
  Identifier (jsc#SLE-13387).
- platform/x86: intel_pmc_core: Fix spelling of MHz unit
  (jsc#SLE-13387).
- platform/x86: intel_pmc_core: Fix indentation in function
  definitions (jsc#SLE-13387).
- platform/x86: intel_pmc_core: Respect error code of
  kstrtou32_from_user() (jsc#SLE-13387).
- platform/x86: intel_pmc_core: Remove unnecessary assignments
  (jsc#SLE-13387).
- commit ad91e0a
* Tue Sep  1 2020 tiwai@suse.de
- mtd: spi-nor: intel-spi: Add support for Intel Tiger Lake-H
  SPI serial flash (jsc#SLE-13387).
- commit 89d37fc
* Tue Sep  1 2020 tiwai@suse.de
- mtd: spi-nor: intel-spi: add support for Intel Cannon Lake
  SPI flash (jsc#SLE-13387).
- commit 2ace8dd
* Tue Sep  1 2020 tiwai@suse.de
- pinctrl: tigerlake: Add support for Tiger Lake-H
  (jsc#SLE-13387).
- commit bd689cb
* Tue Sep  1 2020 tiwai@suse.de
- pinctrl: tigerlake: Use generic flag for special GPIO base
  treatment (jsc#SLE-13387).
- commit 5fc21cc
* Tue Sep  1 2020 bp@suse.de
- x86/fpu/xstate: Preserve supervisor states for the slow path
  in __fpu__restore_sig() (jsc#13212).
- commit 6d83775
* Tue Sep  1 2020 hare@suse.de
- Refresh commit IDs for smartpqi update
- Refresh
  patches.suse/scsi-smartpqi-add-id-support-for-smartraid-3152-8i.patch.
- Refresh
  patches.suse/scsi-smartpqi-add-raid-bypass-counter.patch.
- Refresh
  patches.suse/scsi-smartpqi-avoid-crashing-kernel-for-controller-issues.patch.
- Refresh
  patches.suse/scsi-smartpqi-bump-version-to-1-2-16-010.patch.
- Refresh
  patches.suse/scsi-smartpqi-identify-physical-devices-without-issuing-inquiry.patch.
- Refresh
  patches.suse/scsi-smartpqi-support-device-deletion-via-sysfs.patch.
- Refresh
  patches.suse/scsi-smartpqi-update-logical-volume-size-after-expansion.patch.
- commit 362c3dd
* Tue Sep  1 2020 yousaf.kaukab@suse.com
- dpaa_eth: Fix one possible memleak in dpaa_eth_probe
  (bsc#1175996).
- net: dsa: felix: send VLANs on CPU port as egress-tagged
  (bsc#1175998).
- felix: Fix initialization of ioremap resources (bsc#1175997).
- net: dsa: ocelot: the MAC table on Felix is twice as large
  (bsc#1175999).
- net: enetc: fix an issue about leak system resources
  (bsc#1176000).
- net: mscc: ocelot: fix untagged packet drops when enslaving
  to vlan aware bridge (bsc#1176001).
- commit 6defddf
* Tue Sep  1 2020 bp@suse.de
- x86/fpu: Introduce copy_supervisor_to_kernel() (jsc#13212).
- commit 82d1c75
* Tue Sep  1 2020 yousaf.kaukab@suse.com
- blacklist.conf: arm64: add coresight fixes
  Coresight is not enabled in SLE15-SP2
- commit 973814d
* Tue Sep  1 2020 bp@suse.de
- x86/fpu/xstate: Fix XSAVES offsets in setup_xstate_comp()
  (jsc#13212).
- commit 33ea0eb
* Tue Sep  1 2020 bp@suse.de
- x86/fpu/xstate: Update copy_kernel_to_xregs_err() for supervisor
  states (jsc#13212).
- commit 79adb6d
* Tue Sep  1 2020 bp@suse.de
- x86/fpu/xstate: Update sanitize_restored_xstate() for supervisor
  xstates (jsc#13212).
- commit 2f40b80
* Tue Sep  1 2020 bp@suse.de
- x86/fpu/xstate: Define new functions for clearing fpregs and
  xstates (jsc#13212).
- commit bcebfbb
* Mon Aug 31 2020 bp@suse.de
- x86/fpu/xstate: Introduce XSAVES supervisor states (jsc#13212).
- commit 5498f5d
* Mon Aug 31 2020 bp@suse.de
- x86/fpu/xstate: Separate user and supervisor xfeatures mask
  (jsc#13212).
- commit 4e12fe7
* Mon Aug 31 2020 jroedel@suse.de
- Update config files.
- supported.conf: Rename amd_iommu_v2 driver
- commit a1051bd
* Mon Aug 31 2020 bp@suse.de
- x86/fpu/xstate: Define new macros for supervisor and user
  xstates (jsc#13212).
- commit fdcec4f
* Mon Aug 31 2020 bp@suse.de
- x86/fpu/xstate: Rename validate_xstate_header() to
  validate_user_xstate_header() (jsc#13212).
- commit 5a884c0
* Mon Aug 31 2020 bp@suse.de
- x86/fpu: Shrink space allocated for xstate_comp_offsets
  (jsc#13212).
- commit 2949e7a
* Mon Aug 31 2020 jroedel@suse.de
- drm/prime: fix extracting of the DMA addresses from a
  scatterlist (bsc#1175713).
- commit f2498a0
* Mon Aug 31 2020 msuchanek@suse.de
- char: virtio: Select VIRTIO from VIRTIO_CONSOLE (bsc#1175667).
- commit 254a9e5
* Mon Aug 31 2020 msuchanek@suse.de
- Set VIRTIO_CONSOLE=y (bsc#1175667).
- commit 73ac49e
* Mon Aug 31 2020 tiwai@suse.de
- i2c: rcar: in slave mode, clear NACK earlier (git-fixes).
- i2c: core: Don't fail PRP0001 enumeration when no ID table exist
  (git-fixes).
- device property: Fix the secondary firmware node handling in
  set_primary_fwnode() (git-fixes).
- drm/amd/powerplay: Fix hardmins not being sent to SMU for RV
  (git-fixes).
- drm/msm/a6xx: fix crashdec section name typo (git-fixes).
- drm/msm/gpu: make ringbuffer readonly (git-fixes).
- drm/msm/adreno: fix updating ring fence (git-fixes).
- commit 861fb8e
* Mon Aug 31 2020 msuchanek@suse.de
- tpm: Export tpm2_get_cc_attrs_tbl for ibmvtpm driver as module
  (jsc#SLE-13630).
- commit e1003a9
* Mon Aug 31 2020 tiwai@suse.de
- PCI: Mark AMD Navi10 GPU rev 0x00 ATS as broken (git-fixes).
- PCI: Add device even if driver attach failed (git-fixes).
- PCI: Avoid Pericom USB controller OHCI/EHCI PME# defect
  (git-fixes).
- commit 0174122
* Mon Aug 31 2020 tiwai@suse.de
- PM: sleep: core: Fix the handling of pending runtime resume
  requests (git-fixes).
- commit 0dfcb13
* Mon Aug 31 2020 tiwai@suse.de
- regulator: fix memory leak on error path of regulator_register()
  (git-fixes).
- commit 924cca3
* Mon Aug 31 2020 tiwai@suse.de
- USB: Ignore UAS for JMicron JMS567 ATA/ATAPI Bridge (git-fixes).
- usb: host: ohci-exynos: Fix error handling in
  exynos_ohci_probe() (git-fixes).
- USB: quirks: Ignore duplicate endpoint on Sound Devices MixPre-D
  (git-fixes).
- xhci: Always restore EP_SOFT_CLEAR_TOGGLE even if ep reset
  failed (git-fixes).
- usb: host: xhci: fix ep context print mismatch in debugfs
  (git-fixes).
- usb: gadget: f_tcm: Fix some resource leaks in some error paths
  (git-fixes).
- USB: cdc-acm: rework notification_buffer resizing (git-fixes).
- virtio_pci_modern: Fix the comment of
  virtio_pci_find_capability() (git-fixes).
- USB: serial: ftdi_sio: fix break and sysrq handling (git-fixes).
- USB: serial: ftdi_sio: clean up receive processing (git-fixes).
- USB: serial: ftdi_sio: make process-packet buffer unsigned
  (git-fixes).
- USB: rename USB quirk to USB_QUIRK_ENDPOINT_IGNORE (git-fixes).
- commit 139c620
* Mon Aug 31 2020 msuchanek@suse.de
- tpm: ibmvtpm: Wait for ready buffer before probing for TPM2
  attributes (jsc#SLE-13630).
- tpm: ibmvtpm: Add support for TPM2 (jsc#SLE-13630).
- commit be4f2a9
* Mon Aug 31 2020 jgross@suse.com
- Fix build error when CONFIG_ACPI is not set/enabled:
  (bsc#1065600).
- commit b05ccc4
* Mon Aug 31 2020 bp@suse.de
- x86/fpu/xstate: Fix small issues (jsc#13212).
- commit f18a9bd
* Mon Aug 31 2020 jgross@suse.com
- efi: avoid error message when booting under Xen (bsc#1172419).
- commit e2269b0
* Mon Aug 31 2020 jgross@suse.com
- drm/xen-front: Fix misused IS_ERR_OR_NULL checks (bsc#1065600).
- commit 495693e
* Mon Aug 31 2020 bp@suse.de
- x86/resctrl: Enable user to view thread or core throttling mode
  (jsc#13356).
- x86/resctrl: Enumerate per-thread MBA controls (jsc#13356).
- commit aeb5e9f
* Mon Aug 31 2020 msuchanek@suse.de
- powerpc/perf: Fix crashes with generic_compat_pmu & BHRB
  (bsc#1156395).
- commit 823dc81
* Mon Aug 31 2020 jgross@suse.com
- xen/gntdev: Fix dmabuf import with non-zero sgt offset
  (bsc#1065600).
- commit 4c3d2e5
* Mon Aug 31 2020 jgross@suse.com
- Revert "xen/balloon: Fix crash when ballooning on x86 32 bit
  PAE" (bsc#1065600).
- commit 92eacc3
* Mon Aug 31 2020 jgross@suse.com
- xen/balloon: make the balloon wait interruptible (bsc#1065600).
- commit e8237de
* Mon Aug 31 2020 jgross@suse.com
- xen/balloon: fix accounting in alloc_xenballooned_pages error
  path (bsc#1065600).
- commit eda7ced
* Mon Aug 31 2020 mkubecek@suse.cz
- fix patch metadata
- fix upstream reference:
  patches.suse/0002-dax-do-not-print-error-message-for-non-persistent-me.patch
- commit be9f703
* Sun Aug 30 2020 mkubecek@suse.cz
- Update kabi files.
- update to September 2020 maintenance update submission (commit 8bb516dc7a0a)
- commit 77f2936
* Sun Aug 30 2020 bp@suse.de
- x86/mce/amd: Add PPIN support for AMD MCE (jsc#13575).
- commit 261b6ca
* Sun Aug 30 2020 colyli@suse.de
- bcache: allocate meta data pages as compound pages
  (bsc#1172873).
- commit 55a313b
* Sun Aug 30 2020 colyli@suse.de
- block: check queue's limits.discard_granularity in
  __blkdev_issue_discard() (bsc#1152148).
- block: improve discard bio alignment in __blkdev_issue_discard()
  (bsc#1152148).
- commit 7c62217
* Sun Aug 30 2020 colyli@suse.de
- dax: do not print error message for non-persistent memory
  block device (bsc#1171073).
- dax: print error message by pr_info() in
  __generic_fsdax_supported() (bsc#1171073).
- commit d1ad35e
* Sat Aug 29 2020 bp@suse.de
- x86/cpu: Use SERIALIZE in sync_core() when available
  (jsc#13365).
- commit 20100a4
* Sat Aug 29 2020 bp@suse.de
- x86/cpu: Refactor sync_core() for readability (jsc#13365).
- commit f8518c2
* Fri Aug 28 2020 bp@suse.de
- x86/cpu: Relocate sync_core() to sync_core.h (jsc#13365).
- commit 2df7ed4
* Fri Aug 28 2020 bp@suse.de
- x86/cpufeatures: Add enumeration for SERIALIZE instruction
  (jsc#13365).
- Refresh
  patches.suse/x86-speculation-add-special-register-buffer-data-sampling-srbds-mitigation.patch.
- commit 1427522
* Fri Aug 28 2020 msuchanek@suse.de
- obsolete_kmp: provide newer version than the obsoleted one
  (boo#1170232).
- commit c5ecb27
* Fri Aug 28 2020 jroedel@suse.de
- iommu/vt-d: Move Intel IOMMU driver into subdirectory
  (bsc#1175713).
- Refresh
  patches.suse/iommu-vt-d-enable-pci-acs-for-platform-opt-in-hint.
- Refresh
  patches.suse/iommu-vt-d-update-scalable-mode-paging-structure-coherency.
- commit be917c8
* Fri Aug 28 2020 jroedel@suse.de
- iommu: Add Allwinner H6 IOMMU driver (bsc#1175713).
- Update config files.
- commit 19bb9a4
* Fri Aug 28 2020 jroedel@suse.de
- iommu/virtio: Build virtio-iommu as module (bsc#1175713).
- Update config files.
- supported.conf: Add vrtio-iommu driver as unsupported
- commit 362d7b0
* Fri Aug 28 2020 tiwai@suse.de
- cpuidle: Fix cpuidle_driver_state_disabled() (jsc#SLE-12679).
- commit 0245db2
* Fri Aug 28 2020 tiwai@suse.de
- cpuidle: Introduce cpuidle_driver_state_disabled() for driver
  quirks (jsc#SLE-12679).
- commit 39e01d4
* Fri Aug 28 2020 tiwai@suse.de
- intel_idle: Customize IceLake server support (jsc#SLE-12679).
- intel_idle: Annotate init time data structures (jsc#SLE-12679).
- commit e6ebfe6
* Fri Aug 28 2020 tiwai@suse.de
- Documentation: admin-guide: PM: Add intel_idle document
  (jsc#SLE-12679).
- commit 11728dd
* Fri Aug 28 2020 tiwai@suse.de
- intel_idle: Use ACPI _CST on server systems (jsc#SLE-12679).
- Refresh
  patches.suse/intel_idle-convert-to-new-x86-cpu-match-macros.patch.
- commit 9a99f1a
* Fri Aug 28 2020 tiwai@suse.de
- intel_idle: Add module parameter to prevent ACPI _CST from
  being used (jsc#SLE-12679).
- intel_idle: Allow ACPI _CST to be used for selected known
  processors (jsc#SLE-12679).
- cpuidle: Allow idle states to be disabled by default
  (jsc#SLE-12679).
- intel_idle: Use ACPI _CST for processor models without C-state
  tables (jsc#SLE-12679).
- intel_idle: Refactor intel_idle_cpuidle_driver_init()
  (jsc#SLE-12679).
- ACPI: processor: Export acpi_processor_evaluate_cst()
  (jsc#SLE-12679).
- ACPI: processor: Make ACPI_PROCESSOR_CSTATE depend on
  ACPI_PROCESSOR (jsc#SLE-12679).
- ACPI: processor: Clean up acpi_processor_evaluate_cst()
  (jsc#SLE-12679).
- ACPI: processor: Introduce acpi_processor_evaluate_cst()
  (jsc#SLE-12679).
- ACPI: processor: Export function to claim _CST control
  (jsc#SLE-12679).
- cpuidle: Drop disabled field from struct cpuidle_state
  (jsc#SLE-12679).
- cpuidle: Consolidate disabled state checks (jsc#SLE-12679).
- commit 0460fc7
* Fri Aug 28 2020 jroedel@suse.de
- iommu/vt-d: Add set domain DOMAIN_ATTR_NESTING attr
  (bsc#1175713).
- Refresh patches.suse/iommu-vt-d-add-attach_deferred-helper.
- commit 0aae24b
* Fri Aug 28 2020 jroedel@suse.de
- iommu/vt-d: Add Kconfig option to enable/disable scalable mode
  (bsc#1175713).
- Update config files.
- commit 5972e43
* Fri Aug 28 2020 jroedel@suse.de
- iommu/arm-smmu: Allow building as a module (bsc#1175713).
- Update config files.
- commit 86b1580
* Fri Aug 28 2020 jroedel@suse.de
- iommu/arm-smmu-v3: Unregister IOMMU and bus ops on device
  removal (bsc#1175713).
- Refresh
  patches.suse/iommu-arm-smmu-v3-don-t-reserve-implementation-defined-register-space.
- commit 5d54ca4
* Fri Aug 28 2020 jroedel@suse.de
- iommu/vt-d: Use pci_real_dma_dev() for mapping (bsc#1175713).
- Refresh patches.suse/iommu-vt-d-add-attach_deferred-helper.
- commit f7f5bb2
* Fri Aug 28 2020 jroedel@suse.de
- iommu/amd: Support multiple PCI DMA aliases in device table
  (bsc#1175713).
- Refresh
  patches.suse/iommu-amd-update-device-table-in-increase_address_space.
- commit 1ba83e7
* Fri Aug 28 2020 jroedel@suse.de
- iommu/amd: Convert AMD iommu driver to the dma-iommu api
  (bsc#1175713).
- Refresh
  patches.suse/iommu-amd-call-domain_flush_complete-in-update_domain.
- Refresh
  patches.suse/iommu-amd-fix-race-in-increase_address_space-fetch_pte.
- Refresh
  patches.suse/iommu-amd-update-device-table-in-increase_address_space.
- commit b6faeff
* Fri Aug 28 2020 jroedel@suse.de
- iommu: Add gfp parameter to iommu_ops::map (bsc#1175713).
- Refresh
  patches.suse/iommu-amd-fix-race-in-increase_address_space-fetch_pte.
- commit e8cad6b
* Fri Aug 28 2020 jroedel@suse.de
- iommu/amd: Remove unnecessary locking from AMD iommu driver
  (bsc#1175713).
- Refresh
  patches.suse/iommu-amd-fix-race-in-increase_address_space-fetch_pte.
- commit 835616f
* Fri Aug 28 2020 jroedel@suse.de
- firmware: qcom_scm: Fix some typos in docs and printks
  (bsc#1175713).
- Refresh
  patches.suse/firmware-qcom_scm-fix-bogous-abuse-of-dma-direct-int.patch.
- commit e7b646b
* Fri Aug 28 2020 jroedel@suse.de
- iommu: Remove wrong default domain comments (bsc#1175713).
- Refresh
  patches.suse/iommu-set-group-default-domain-before-creating-direct-mappings.
- commit f3dbc57
* Fri Aug 28 2020 jroedel@suse.de
- iommu/vt-d: Use bounce buffer for untrusted devices
  (bsc#1175713).
- Refresh
  patches.suse/dma-mapping-explicitly-wire-up-mmap-and-get_sgtable.patch.
- commit 430d080
* Fri Aug 28 2020 jroedel@suse.de
- iommu/vt-d: Don't switch off swiotlb if bounce page is used
  (bsc#1175713).
- Refresh
  patches.suse/iommu-vt-d-unnecessary-to-handle-default-identity-domain.
- commit 656a21a
* Fri Aug 28 2020 jroedel@suse.de
- iommu/vt-d: Check whether device requires bounce buffer
  (bsc#1175713).
- Refresh
  patches.suse/iommu-vt-d-unnecessary-to-handle-default-identity-domain.
- commit 082ae7d
* Fri Aug 28 2020 jroedel@suse.de
- swiotlb: Split size parameter to map/unmap APIs (bsc#1175713).
- Refresh
  patches.suse/dma-direct-exclude-dma_direct_map_resource-from-the-min_low_pfn-check.patch.
- commit 439017e
* Fri Aug 28 2020 ohering@suse.de
- hv_netvsc: Fix the queue_mapping in netvsc_vf_xmit()
  (git-fixes).
- hv_netvsc: Remove "unlikely" from netvsc_select_queue
  (git-fixes).
- hv_netvsc: do not use VF device if link is down (git-fixes).
- commit 83af1e6
* Fri Aug 28 2020 jroedel@suse.de
- iommu/mediatek: Add mt8183 IOMMU support (bsc#1175713).
- Refresh
  patches.suse/iommu-mediatek-fix-vld_pa_rng-register-backup-when-suspend.
- commit 54fdef6
* Fri Aug 28 2020 tiwai@suse.de
- dmaengine: idxd: Init and probe for Intel data accelerators
  (jsc#SLE-12688).
- Update config files: CONFIG_INTEL_IDXD=m for x86_64
- supported.conf: add idxd module
- commit 9a6d5fa
* Fri Aug 28 2020 tiwai@suse.de
- dmaengine: dmatest: Add support for completion polling
  (jsc#SLE-12688).
- Refresh
  patches.suse/dmaengine-dmatest-Fix-iteration-non-stop-logic.patch.
- commit f4347c1
* Fri Aug 28 2020 tiwai@suse.de
- dmaengine: idxd: move idxd interrupt handling to mask instead
  of ignore (jsc#SLE-12688).
- dmaengine: idxd: add work queue drain support (jsc#SLE-12688).
- dmaengine: idxd: move submission to sbitmap_queue
  (jsc#SLE-12688).
- dmaengine: cookie bypass for out of order completion
  (jsc#SLE-12688).
- commit d2c733b
* Fri Aug 28 2020 jroedel@suse.de
- iommu: Pass struct iommu_iotlb_gather to ->unmap() and
  - >iotlb_sync() (bsc#1175713).
- Refresh
  patches.suse/iommu-amd-fix-race-in-increase_address_space-fetch_pte.
- Refresh
  patches.suse/iommu-amd-lock-code-paths-traversing-protection_domain-dev_list.
- Refresh
  patches.suse/iommu-mediatek-correct-the-flush_iotlb_all-callback.
- commit 0f6ef66
* Fri Aug 28 2020 jroedel@suse.de
- iommu: Remove empty iommu_tlb_range_add() callback from
  iommu_ops (bsc#1175713).
- Refresh
  patches.suse/iommu-amd-lock-code-paths-traversing-protection_domain-dev_list.
- commit 3c406b0
* Fri Aug 28 2020 tiwai@suse.de
- dmaengine: idxd: fix misc interrupt handler thread unmasking
  (jsc#SLE-12688).
- dmaengine: idxd: cleanup workqueue config after disabling
  (jsc#SLE-12688).
- dmaengine: idxd: fix cdev locking for open and release
  (jsc#SLE-12688).
- dmaengine: idxd: export hw version through sysfs
  (jsc#SLE-12688).
- dmaengine: idxd: fix interrupt completion after unmasking
  (jsc#SLE-12688).
- dmaengine: idxd: remove global token limit check
  (jsc#SLE-12688).
- dmaengine: idxd: reflect shadow copy of traffic class
  programming (jsc#SLE-12688).
- dmaengine: idxd: expose general capabilities register in sysfs
  (jsc#SLE-12688).
- dmaengine: idxd: check return result from check_vma() in cdev
  (jsc#SLE-12688).
- dmaengine: idxd: remove set but not used variable 'idxd_cdev'
  (jsc#SLE-12688).
- dmaengine: idxd: remove set but not used variable 'group'
  (jsc#SLE-12688).
- dmaengine: idxd: fix off by one on cdev dwq refcount
  (jsc#SLE-12688).
- dmaengine: idxd: wq size configuration needs to check global
  max size (jsc#SLE-12688).
- dmaengine: idxd: sysfs input of wq incorrect wq type should
  return error (jsc#SLE-12688).
- dmaengine: idxd: correct reserved token calculation
  (jsc#SLE-12688).
- dmaengine: idxd: Fix error handling in idxd_wq_cdev_dev_setup()
  (jsc#SLE-12688).
- dmaengine: idxd: fix runaway module ref count on device driver
  bind (jsc#SLE-12688).
- dmaengine: idxd: fix boolconv.cocci warnings (jsc#SLE-12688).
- dmaengine: idxd: add char driver to expose submission portal
  to userland (jsc#SLE-12688).
- dmaengine: idxd: connect idxd to dmaengine subsystem
  (jsc#SLE-12688).
- dmaengine: idxd: add descriptor manipulation routines
  (jsc#SLE-12688).
- dmaengine: idxd: add configuration component of driver
  (jsc#SLE-12688).
- commit 7bdb2b2
* Fri Aug 28 2020 tiwai@suse.de
- dmaengine: fix channel index enumeration (jsc#SLE-12688).
- commit f7388ad
* Fri Aug 28 2020 tiwai@suse.de
- dmaengine: fix null ptr check for
  __dma_async_device_channel_register() (jsc#SLE-12688).
- dmaengine: add support to dynamic register/unregister of
  channels (jsc#SLE-12688).
- dmaengine: break out channel registration (jsc#SLE-12688).
- dmaengine: print more meaningful error message (jsc#SLE-12688).
- dmaengine: move module_/dma_device_put() after route free
  (jsc#SLE-12688).
- dmaengine: Add reference counting to dma_device struct
  (jsc#SLE-12688).
- dmaengine: Move dma_channel_rebalance() infrastructure up in
  code (jsc#SLE-12688).
- dmaengine: Call module_put() after device_free_chan_resources()
  (jsc#SLE-12688).
- commit 83e441c
* Fri Aug 28 2020 jroedel@suse.de
- iommu/arm-smmu: Add implementation infrastructure (bsc#1175713).
- Refresh
  patches.suse/iommu-amd-Override-wrong-IVRS-IOAPIC-on-Raven-Ridge-.patch.
- commit 8c03e81
* Fri Aug 28 2020 tiwai@suse.de
- x86/asm: add iosubmit_cmds512() based on MOVDIR64B CPU
  instruction (jsc#SLE-12688).
- commit 39a557f
* Fri Aug 28 2020 jroedel@suse.de
- iommu/omap: fix boot issue on remoteprocs with AMMU/Unicache
  (bsc#1175713).
- Refresh
  patches.suse/ARM-OMAP2-move-platform-specific-asm-offset.h-to-arc.patch.
- commit b599a74
* Fri Aug 28 2020 tiwai@suse.de
- mtd: spi-nor: intel-spi: Add support for Intel Emmitsburg SPI
  serial flash (jsc#SLE-13361).
- commit af6591b
* Fri Aug 28 2020 tiwai@suse.de
- i2c: i801: Add support for Intel Emmitsburg PCH (jsc#SLE-13361).
- commit e25f03a
* Fri Aug 28 2020 tiwai@suse.de
- mfd: intel-lpss: Add Intel Emmitsburg PCH PCI IDs
  (jsc#SLE-13361).
- commit c8f66ce
* Fri Aug 28 2020 tiwai@suse.de
- pinctrl: intel: Add Intel Emmitsburg pin controller support
  (jsc#SLE-13361).
- Update config files: CONFIG_PINCTRL_EMMITSBURG=m
- supported.conf: add pinctrl-emmitsburg module
- commit f051905
* Fri Aug 28 2020 jroedel@suse.de
- s390/Kconfig: add missing ZCRYPT dependency to VFIO_AP
  (bsc#1175713).
- iommu: Move sg_table wrapper out of CONFIG_IOMMU_SUPPORT
  (bsc#1175713).
- iommu/vt-d: Disable multiple GPASID-dev bind (bsc#1175713).
- iommu/vt-d: Warn on out-of-range invalidation address
  (bsc#1175713).
- iommu/vt-d: Fix devTLB flush for vSVA (bsc#1175713).
- iommu/vt-d: Handle non-page aligned address (bsc#1175713).
- firmware: qcom_scm: Fix legacy convention SCM accessors
  (bsc#1175713).
- iommu/qcom: Use domain rather than dev as tlb cookie
  (bsc#1175713).
- iommu/arm-smmu: Mark qcom_smmu_client_of_match as possibly
  unused (bsc#1175713).
- iommu: Fix use-after-free in iommu_release_device (bsc#1175713).
- iommu/amd: Make amd_iommu_apply_ivrs_quirks() static inline
  (bsc#1175713).
- iommu: SUN50I_IOMMU should depend on HAS_DMA (bsc#1175713).
- iommu/sun50i: Remove unused variable (bsc#1175713).
- iommu/sun50i: Change the readl timeout to the atomic variant
  (bsc#1175713).
- iommu/vt-d: Fix misuse of iommu_domain_identity_map()
  (bsc#1175713).
- iommu/vt-d: Don't apply gfx quirks to untrusted devices
  (bsc#1175713).
- iommu/vt-d: Set U/S bit in first level page table by default
  (bsc#1175713).
- iommu/vt-d: Make Intel SVM code 64-bit only (bsc#1175713).
- iommu/amd: Move AMD IOMMU driver into subdirectory
  (bsc#1175713).
- iommu: Check for deferred attach in iommu_group_do_dma_attach()
  (bsc#1175713).
- iommu/amd: Remove redundant devid checks (bsc#1175713).
- iommu/amd: Store dev_data as device iommu private data
  (bsc#1175713).
- iommu/amd: Merge private header files (bsc#1175713).
- iommu/amd: Remove PD_DMA_OPS_MASK (bsc#1175713).
- iommu/amd: Consolidate domain allocation/freeing (bsc#1175713).
- iommu/amd: Free page-table in protection_domain_free()
  (bsc#1175713).
- iommu/amd: Allocate page-table in protection_domain_init()
  (bsc#1175713).
- iommu/amd: Let free_pagetable() not rely on domain->pt_root
  (bsc#1175713).
- iommu/amd: Unexport get_dev_data() (bsc#1175713).
- iommu/amd: Unify format of the printed messages (bsc#1175713).
- iommu: Remove iommu_sva_ops::mm_exit() (bsc#1175713).
- iommu/vt-d: Use pci_ats_supported() (bsc#1175713).
- iommu/arm-smmu-v3: Use pci_ats_supported() (bsc#1175713).
- iommu/amd: Use pci_ats_supported() (bsc#1175713).
- PCI/ATS: Only enable ATS for trusted devices (bsc#1175713).
- iommu: Don't take group reference in
  iommu_alloc_default_domain() (bsc#1175713).
- iommu: Don't call .probe_finalize() under group->mutex
  (bsc#1175713).
- iommu/mediatek-v1: Fix a build warning for a unused variable
  'data' (bsc#1175713).
- iommu/mediatek-v1: Add def_domain_type (bsc#1175713).
- iommu/omap: Add registration for DT fwnode pointer
  (bsc#1175713).
- iommu/omap: Add check for iommu group when no IOMMU in use
  (bsc#1175713).
- iommu/hyper-v: Constify hyperv_ir_domain_ops (bsc#1175713).
- iommu/vt-d: Fix compile warning (bsc#1175713).
- iommu/vt-d: Remove real DMA lookup in find_domain (bsc#1175713).
- iommu/vt-d: Allocate domain info for real DMA sub-devices
  (bsc#1175713).
- iommu/vt-d: Only clear real DMA device's context entries
  (bsc#1175713).
- iommu/vt-d: fix a GCC warning (bsc#1175713).
- iommu/vt-d: Fix pointer cast warnings on 32 bit (bsc#1175713).
- iommu/vt-d: Remove IOVA handling code from the non-dma_ops path
  (bsc#1175713).
- iommu/vt-d: Remove duplicated check in intel_svm_bind_mm()
  (bsc#1175713).
- iommu/vt-d: Remove redundant IOTLB flush (bsc#1175713).
- iommu/vt-d: Add page request draining support (bsc#1175713).
- iommu/vt-d: Disable non-recoverable fault processing before
  unbind (bsc#1175713).
- iommu/vt-d: debugfs: Add support to show inv queue internals
  (bsc#1175713).
- iommu/vt-d: Multiple descriptors per qi_submit_sync()
  (bsc#1175713).
- iommu/vt-d: Replace intel SVM APIs with generic SVA APIs
  (bsc#1175713).
- iommu/vt-d: Report SVA feature with generic flag (bsc#1175713).
- iommu/vt-d: Add get_domain_info() helper (bsc#1175713).
- iommu/vt-d: Add custom allocator for IOASID (bsc#1175713).
- iommu/vt-d: Enlightened PASID allocation (bsc#1175713).
- iommu/vt-d: Add svm/sva invalidate function (bsc#1175713).
- iommu/vt-d: Support flushing more translation cache types
  (bsc#1175713).
- iommu/vt-d: Add bind guest PASID support (bsc#1175713).
- iommu/vt-d: Add nested translation helper function
  (bsc#1175713).
- iommu/vt-d: Use a helper function to skip agaw for SL
  (bsc#1175713).
- iommu/vt-d: Move domain helper to header (bsc#1175713).
- iommu: Remove functions that support private domain
  (bsc#1175713).
- iommu/vt-d: Unify format of the printed messages (bsc#1175713).
- iommu/vt-d: Apply per-device dma_ops (bsc#1175713).
- iommu/vt-d: Allow PCI sub-hierarchy to use DMA domain
  (bsc#1175713).
- iommu/vt-d: Allow 32bit devices to uses DMA domain
  (bsc#1175713).
- iommu/arm-smmu-v3: Manage ASIDs with xarray (bsc#1175713).
- iommu/arm-smmu-qcom: Request direct mapping for modem device
  (bsc#1175713).
- iommu/arm-smmu-v3: remove set but not used variable 'smmu'
  (bsc#1175713).
- iommu/arm-smmu: Allow client devices to select direct mapping
  (bsc#1175713).
- iommu/arm-smmu: Implement iommu_ops->def_domain_type call-back
  (bsc#1175713).
- iommu: arm-smmu-impl: Convert to a generic reset implementation
  (bsc#1175713).
- iommu/arm-smmu: Make remove callback message more informative
  (bsc#1175713).
- iommu/sun50i: Constify sun50i_iommu_ops (bsc#1175713).
- iommu/sun50i: Fix return value check in sun50i_iommu_probe()
  (bsc#1175713).
- iommu/sun50i: Use __GFP_ZERO instead of memset() (bsc#1175713).
- iommu/sun50i: Fix compile warnings (bsc#1175713).
- iommu/iova: Unify format of the printed messages (bsc#1175713).
- iommu/renesas: Fix unused-function warning (bsc#1175713).
- iommu: Do not probe devices on IOMMU-less busses (bsc#1175713).
- iommu/amd: Fix variable "iommu" set but not used (bsc#1175713).
- iommu: Unexport iommu_group_get_for_dev() (bsc#1175713).
- iommu: Move more initialization to __iommu_probe_device()
  (bsc#1175713).
- iommu: Remove add_device()/remove_device() code-paths
  (bsc#1175713).
- iommu/exynos: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/exynos: Use first SYSMMU in controllers list for IOMMU
  core (bsc#1175713).
- iommu/omap: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/omap: Remove orphan_dev tracking (bsc#1175713).
- iommu/renesas: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/tegra: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/rockchip: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/qcom: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/mediatek-v1 Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/mediatek: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/msm: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/virtio: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/s390: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/pamu: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/arm-smmu: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/vt-d: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/amd: Convert to probe/release_device() call-backs
  (bsc#1175713).
- iommu/amd: Remove dev_data->passthrough (bsc#1175713).
- iommu: Export bus_iommu_probe() and make is safe for re-probing
  (bsc#1175713).
- iommu: Move iommu_group_create_direct_mappings() out of
  iommu_group_add_device() (bsc#1175713).
- iommu: Split off default domain allocation from group assignment
  (bsc#1175713).
- iommu: Move new probe_device path to separate function
  (bsc#1175713).
- iommu: Keep a list of allocated groups in __iommu_probe_device()
  (bsc#1175713).
- iommu: Move default domain allocation to iommu_probe_device()
  (bsc#1175713).
- iommu: Add probe_device() and release_device() call-backs
  (bsc#1175713).
- iommu/amd: Return -ENODEV in add_device when device is not
  handled by IOMMU (bsc#1175713).
- iommu/amd: Remove dma_mask check from check_device()
  (bsc#1175713).
- iommu/vt-d: Wire up iommu_ops->def_domain_type (bsc#1175713).
- iommu/amd: Implement iommu_ops->def_domain_type call-back
  (bsc#1175713).
- iommu: Add def_domain_type() callback in iommu_ops
  (bsc#1175713).
- iommu: Move default domain allocation to separate function
  (bsc#1175713).
- iommu/msm: Make msm_iommu_lock static (bsc#1175713).
- iommu: add generic helper for mapping sgtable objects
  (bsc#1175713).
- firmware: qcom_scm-legacy: Replace zero-length array with
  flexible-array (bsc#1175713).
- firmware: qcom_scm: Remove unneeded conversion to bool
  (bsc#1175713).
- x86: Hide the archdata.iommu field behind generic IOMMU_API
  (bsc#1175713).
- iommu: Fix deferred domain attachment (bsc#1175713).
- iommu/amd: Fix get_acpihid_device_id() (bsc#1175713).
- iommu: Properly export iommu_group_get_for_dev() (bsc#1175713).
- iommu/vt-d: Use right Kconfig option name (bsc#1175713).
- iommu: spapr_tce: Disable compile testing to fix build on
  book3s_32 config (bsc#1175713).
- iommu/mediatek: Fix MTK_IOMMU dependencies (bsc#1175713).
- iommu: Fix the memory leak in dev_iommu_free() (bsc#1175713).
- iommu: Move fwspec->iommu_priv to struct dev_iommu
  (bsc#1175713).
- iommu/virtio: Use accessor functions for iommu private data
  (bsc#1175713).
- iommu/qcom: Use accessor functions for iommu private data
  (bsc#1175713).
- iommu/mediatek: Use accessor functions for iommu private data
  (bsc#1175713).
- iommu/renesas: Use accessor functions for iommu private data
  (bsc#1175713).
- iommu/arm-smmu: Use accessor functions for iommu private data
  (bsc#1175713).
- iommu/arm-smmu: Refactor master_cfg/fwspec usage (bsc#1175713).
- iommu/arm-smmu-v3: Use accessor functions for iommu private data
  (bsc#1175713).
- iommu: Introduce accessors for iommu private data (bsc#1175713).
- iommu/arm-smmu: Fix uninitilized variable warning (bsc#1175713).
- iommu: Move iommu_fwspec to struct dev_iommu (bsc#1175713).
- iommu: Rename struct iommu_param to dev_iommu (bsc#1175713).
- iommu/tegra-gart: Remove direct access of dev->iommu_fwspec
  (bsc#1175713).
- ACPI/IORT: Remove direct access of dev->iommu_fwspec
  (bsc#1175713).
- iommu: Define dev_iommu_fwspec_get() for !CONFIG_IOMMU_API
  (bsc#1175713).
- iommu: Use C99 flexible array in fwspec (bsc#1175713).
- iommu/virtio: Reject IOMMU page granule larger than PAGE_SIZE
  (bsc#1175713).
- iommu/vt-d: Add build dependency on IOASID (bsc#1175713).
- iommu/arm-smmu-v3: Add SMMUv3.2 range invalidation support
  (bsc#1175713).
- iommu/arm-smmu-v3: Batch ATC invalidation commands
  (bsc#1175713).
- iommu/arm-smmu-v3: Batch context descriptor invalidation
  (bsc#1175713).
- iommu/arm-smmu-v3: Add command queue batching helpers
  (bsc#1175713).
- iommu/arm-smmu-v3: Write level-1 descriptors atomically
  (bsc#1175713).
- iommu/arm-smmu-v3: Add support for PCI PASID (bsc#1175713).
- iommu: Enable compile testing for some of drivers (bsc#1175713).
- iommu/omap: Fix -Woverflow warnings when compiling on 64-bit
  architectures (bsc#1175713).
- iommu/omap: Fix printing format for size_t on 64-bit
  (bsc#1175713).
- iommu/omap: Fix pointer cast -Wpointer-to-int-cast warnings
  on 64 bit (bsc#1175713).
- iommu/qcom: Replace zero-length array with flexible-array member
  (bsc#1175713).
- drm/radeon: fix scatter-gather mapping with user pages
  (bsc#1175713).
- drm/amdgpu: fix scatter-gather mapping with user pages
  (bsc#1175713).
- drm/prime: use dma length macro when mapping sg (bsc#1175713).
- iommu/amd: Fix IOMMU AVIC not properly update the is_run bit
  in IRTE (bsc#1175713).
- iommu/vt-d: dmar_parse_one_rmrr: replace WARN_TAINT with
  pr_warn + add_taint (bsc#1175713).
- iommu/io-pgtable-arm: Fix IOVA validation for 32-bit
  (bsc#1175713).
- iommu/arm-smmu: Restore naming of driver parameter prefix
  (bsc#1175713).
- iommu/amd: Disable IOMMU on Stoney Ridge systems (bsc#1175713).
- firmware: qcom_scm: Dynamically support SMCCC and legacy
  conventions (bsc#1175713).
- firmware: qcom_scm: Remove thin wrappers (bsc#1175713).
- firmware: qcom_scm: Order functions, definitions by
  service/command (bsc#1175713).
- firmware: qcom_scm-32: Add device argument to atomic calls
  (bsc#1175713).
- firmware: qcom_scm-32: Create common legacy atomic call
  (bsc#1175713).
- firmware: qcom_scm-32: Move SMCCC register filling to
  qcom_scm_call (bsc#1175713).
- firmware: qcom_scm-32: Use qcom_scm_desc in non-atomic calls
  (bsc#1175713).
- firmware: qcom_scm-32: Add funcnum IDs (bsc#1175713).
- firmware: qcom_scm-32: Use SMC arch wrappers (bsc#1175713).
- firmware: qcom_scm-64: Improve SMC convention detection
  (bsc#1175713).
- firmware: qcom_scm-64: Move SMC register filling to
  qcom_scm_call_smccc (bsc#1175713).
- firmware: qcom_scm-64: Add SCM results struct (bsc#1175713).
- firmware: qcom_scm-64: Move svc/cmd/owner into qcom_scm_desc
  (bsc#1175713).
- firmware: qcom_scm-64: Make SMC macros less magical
  (bsc#1175713).
- firmware: qcom_scm: Remove unused qcom_scm_get_version
  (bsc#1175713).
- firmware: qcom_scm: Apply consistent naming scheme to command
  IDs (bsc#1175713).
- firmware: qcom_scm: Rename macros and structures (bsc#1175713).
- firmware: scm: Add stubs for OCMEM and restore_sec_cfg_available
  (bsc#1175713).
- x86/PCI: Define to_pci_sysdata() even when !CONFIG_PCI
  (bsc#1175713).
- iommu: virtio: Use generic_iommu_put_resv_regions()
  (bsc#1175713).
- iommu: intel: Use generic_iommu_put_resv_regions()
  (bsc#1175713).
- iommu: amd: Use generic_iommu_put_resv_regions() (bsc#1175713).
- iommu: arm: Use generic_iommu_put_resv_regions() (bsc#1175713).
- iommu: Implement generic_iommu_put_resv_regions() (bsc#1175713).
- iommu/iova: Silence warnings under memory pressure
  (bsc#1175713).
- iommu: Fix Kconfig indentation (bsc#1175713).
- iommu/vt-d: Remove unnecessary WARN_ON_ONCE() (bsc#1175713).
- iommu/vt-d: Add RMRR base and end addresses sanity check
  (bsc#1175713).
- iommu/vt-d: Mark firmware tainted if RMRR fails sanity check
  (bsc#1175713).
- iommu/vt-d: Don't reject Host Bridge due to scope mismatch
  (bsc#1175713).
- iommu/vt-d: debugfs: Add support to show page table internals
  (bsc#1175713).
- iommu/vt-d: Use iova over first level (bsc#1175713).
- iommu/vt-d: Update first level super page capability
  (bsc#1175713).
- iommu/vt-d: Make first level IOVA canonical (bsc#1175713).
- iommu/vt-d: Flush PASID-based iotlb for iova over first level
  (bsc#1175713).
- iommu/vt-d: Setup pasid entries for iova over first level
  (bsc#1175713).
- iommu/vt-d: Add PASID_FLAG_FL5LP for first-level pasid setup
  (bsc#1175713).
- iommu/vt-d: Identify domains using first level page table
  (bsc#1175713).
- iommu/vt-d: Loose requirement for flush queue initializaton
  (bsc#1175713).
- iommu/vt-d: Avoid iova flush queue in strict mode (bsc#1175713).
- iommu/vt-d: trace: Extend map_sg trace event (bsc#1175713).
- iommu/vt-d: Misc macro clean up for SVM (bsc#1175713).
- iommu/vt-d: Replace Intel specific PASID allocator with IOASID
  (bsc#1175713).
- iommu/vt-d: Avoid duplicated code for PASID setup (bsc#1175713).
- iommu/vt-d: Reject SVM bind for failed capability check
  (bsc#1175713).
- iommu/vt-d: Fix CPU and IOMMU SVM feature matching checks
  (bsc#1175713).
- iommu/amd: Remove the unnecessary assignment (bsc#1175713).
- iommu/amd: Remove unused struct member (bsc#1175713).
- iommu/amd: Replace two consecutive readl calls with one readq
  (bsc#1175713).
- iommu/amd: Fix typos for PPR macros (bsc#1175713).
- iommu/amd: Remove local variables (bsc#1175713).
- iommu/amd: Remove unused variable (bsc#1175713).
- iommu/amd: Treat per-device exclusion ranges as r/w unity-mapped
  regions (bsc#1175713).
- iommu/arm-smmu-v3: Return -EBUSY when trying to re-add a device
  (bsc#1175713).
- iommu/arm-smmu-v3: Improve add_device() error handling
  (bsc#1175713).
- iommu/arm-smmu-v3: Use WRITE_ONCE() when changing validity of
  an STE (bsc#1175713).
- iommu/arm-smmu-v3: Add second level of context descriptor table
  (bsc#1175713).
- iommu/arm-smmu-v3: Prepare for handling
  arm_smmu_write_ctx_desc() failure (bsc#1175713).
- iommu/arm-smmu-v3: Propagate ssid_bits (bsc#1175713).
- iommu/arm-smmu-v3: Add support for Substream IDs (bsc#1175713).
- iommu/arm-smmu-v3: Add context descriptor tables allocators
  (bsc#1175713).
- iommu/arm-smmu-v3: Prepare arm_smmu_s1_cfg for SSID support
  (bsc#1175713).
- iommu/arm-smmu-v3: Parse PASID devicetree property of platform
  devices (bsc#1175713).
- iommu/arm-smmu-v3: Drop __GFP_ZERO flag from DMA allocation
  (bsc#1175713).
- iommu/arm-smmu: Improve SMR mask test (bsc#1175713).
- iommu/io-pgtable-arm: Prepare for TTBR1 usage (bsc#1175713).
- iommu/io-pgtable-arm: Rationalise VTCR handling (bsc#1175713).
- iommu/arm-smmu: Rename public #defines under ARM_SMMU_ namespace
  (bsc#1175713).
- iommu/io-pgtable-arm: Rationalise TCR handling (bsc#1175713).
- iommu/io-pgtable-arm: Ensure ARM_64_LPAE_S2_TCR_RES1 is unsigned
  (bsc#1175713).
- iommu/io-pgtable-arm: Improve attribute handling (bsc#1175713).
- iommu/io-pgtable-arm: Support non-coherent stage-2 page tables
  (bsc#1175713).
- iommu/io-pgtable-arm: Rationalise TTBRn handling (bsc#1175713).
- iommu/arm-smmu: Fix -Wunused-const-variable warning
  (bsc#1175713).
- iommu/arm-smmu-v3: Remove useless of_match_ptr() (bsc#1175713).
- iommu/arm-smmu-v3: Fix resource_size check (bsc#1175713).
- drivers/iommu: Initialise module 'owner' field in
  iommu_device_set_ops() (bsc#1175713).
- iommu/arm-smmu: Update my email address in MODULE_AUTHOR()
  (bsc#1175713).
- iommu/arm-smmu: Unregister IOMMU and bus ops on device removal
  (bsc#1175713).
- iommu/arm-smmu-v3: Allow building as a module (bsc#1175713).
- iommu/arm-smmu: Support SMMU module probing from the IORT
  (bsc#1175713).
- iommu/arm-smmu: Prevent forced unbinding of Arm SMMU drivers
  (bsc#1175713).
- Revert "iommu/arm-smmu: Make arm-smmu explicitly non-modular"
  (bsc#1175713).
- Revert "iommu/arm-smmu: Make arm-smmu-v3 explicitly non-modular"
  (bsc#1175713).
- drivers/iommu: Allow IOMMU bus ops to be unregistered
  (bsc#1175713).
- iommu/of: Take a ref to the IOMMU driver during ->of_xlate()
  (bsc#1175713).
- drivers/iommu: Take a ref to the IOMMU driver prior to
  - >add_device() (bsc#1175713).
- iommu/of: Request ACS from the PCI core when configuring IOMMU
  linkage (bsc#1175713).
- drivers/iommu: Export core IOMMU API symbols to permit modular
  drivers (bsc#1175713).
- x86/PCI: Remove X86_DEV_DMA_OPS (bsc#1175713).
- PCI: vmd: Remove dma_map_ops overrides (bsc#1175713).
- iommu/vt-d: Remove VMD child device sanity check (bsc#1175713).
- PCI: Introduce pci_real_dma_dev() (bsc#1175713).
- x86/PCI: Expose VMD's pci_dev in struct pci_sysdata
  (bsc#1175713).
- x86/PCI: Add to_pci_sysdata() helper (bsc#1175713).
- iommu/dma: fix variable 'cookie' set but not used (bsc#1175713).
- iommu/dma: Relax locking in iommu_dma_prepare_msi()
  (bsc#1175713).
- iommu/dma: Rationalise types for DMA masks (bsc#1175713).
- iommu: fix KASAN use-after-free in iommu_insert_resv_region
  (bsc#1175713).
- firmware: qcom: scm: add support to restore secure config to
  qcm_scm-32 (bsc#1175713).
- firmware: qcom: scm: add OCMEM lock/unlock interface
  (bsc#1175713).
- iommu/vt-d: Select PCI_PRI for INTEL_IOMMU_SVM (bsc#1175713).
- iommu: Introduce guest PASID bind function (bsc#1175713).
- iommu/ioasid: Add custom allocators (bsc#1175713).
- iommu: Add I/O ASID allocator (bsc#1175713).
- iommu: Introduce cache_invalidate API (bsc#1175713).
- iommu/virtio: Remove unused variable (bsc#1175713).
- iommu/vt-d: Turn off translations at shutdown (bsc#1175713).
- iommu/vt-d: Check VT-d RMRR region in BIOS is reported as
  reserved (bsc#1175713).
- iommu/amd: Support multiple PCI DMA aliases in IRQ Remapping
  (bsc#1175713).
- iommu/amd: Do not re-fetch iommu->cmd_buf_tail (bsc#1175713).
- iommu/amd: Pass gfp flags to iommu_map_page() in amd_iommu_map()
  (bsc#1175713).
- iommu/amd: Simpify decoding logic for INVALID_PPR_REQUEST event
  (bsc#1175713).
- iommu/dma-iommu: Use the dev->coherent_dma_mask (bsc#1175713).
- iommu/dma-iommu: Handle deferred devices (bsc#1175713).
- iommu/io-pgtable-arm: Rename IOMMU_QCOM_SYS_CACHE and improve
  doc (bsc#1175713).
- iommu/io-pgtable-arm: Rationalise MAIR handling (bsc#1175713).
- iommu/io-pgtable-arm: Simplify level indexing (bsc#1175713).
- iommu/io-pgtable-arm: Simplify PGD size handling (bsc#1175713).
- iommu/io-pgtable-arm: Simplify start level lookup (bsc#1175713).
- iommu/io-pgtable-arm: Simplify bounds checks (bsc#1175713).
- iommu/io-pgtable-arm: Rationalise size check (bsc#1175713).
- iommu/io-pgtable: Make selftest gubbins consistently __init
  (bsc#1175713).
- iommu: arm-smmu-impl: Add sdm845 implementation hook
  (bsc#1175713).
- firmware/qcom_scm: Add scm call to handle smmu errata
  (bsc#1175713).
- firmware: qcom_scm-64: Add atomic version of qcom_scm_call
  (bsc#1175713).
- iommu/arm-smmu: Avoid pathological RPM behaviour for unmaps
  (bsc#1175713).
- iommu/arm-smmu: Axe a useless test in
  'arm_smmu_master_alloc_smes()' (bsc#1175713).
- iommu/io-pgtable: Move some initialization data to .init.rodata
  (bsc#1175713).
- iommu/arm-smmu: Report USF more clearly (bsc#1175713).
- iommu/arm-smmu: Remove arm_smmu_flush_ops (bsc#1175713).
- iommu/arm-smmu: Move .tlb_sync method to implementation
  (bsc#1175713).
- iommu/arm-smmu: Remove "leaf" indirection (bsc#1175713).
- iommu/arm-smmu: Remove .tlb_inv_range indirection (bsc#1175713).
- iommu/mediatek: Reduce the tlb flush timeout value
  (bsc#1175713).
- iommu/mediatek: Get rid of the pgtlock (bsc#1175713).
- iommu/mediatek: Move the tlb_sync into tlb_flush (bsc#1175713).
- iommu/mediatek: Delete the leaf in the tlb_flush (bsc#1175713).
- iommu/mediatek: Use gather to achieve the tlb range flush
  (bsc#1175713).
- iommu/mediatek: Add a new tlb_lock for tlb_flush (bsc#1175713).
- memory: mtk-smi: Add PM suspend and resume ops (bsc#1175713).
- iommu/rockchip: Don't provoke WARN for harmless IRQs
  (bsc#1175713).
- iommu: rockchip: Free domain on .domain_free (bsc#1175713).
- iommu/ipmmu-vmsa: Add utlb_offset_base (bsc#1175713).
- iommu/ipmmu-vmsa: Add helper functions for "uTLB" registers
  (bsc#1175713).
- iommu/ipmmu-vmsa: Calculate context registers' offset instead
  of a macro (bsc#1175713).
- iommu/ipmmu-vmsa: Add helper functions for MMU "context"
  registers (bsc#1175713).
- iommu/ipmmu-vmsa: tidyup register definitions (bsc#1175713).
- iommu/ipmmu-vmsa: Remove all unused register definitions
  (bsc#1175713).
- iommu/ipmmu-vmsa: Hook up r8a774b1 DT matching code
  (bsc#1175713).
- iommu/qcom: Simplify a test in 'qcom_iommu_add_device()'
  (bsc#1175713).
- drivers: iommu: hyperv: Make HYPERV_IOMMU only available on x86
  (bsc#1175713).
- iommu/amd: Switch to use acpi_dev_hid_uid_match() (bsc#1175713).
- ACPI / utils: Introduce acpi_dev_hid_uid_match() helper
  (bsc#1175713).
- iommu/ipmmu-vmsa: Remove dev_err() on platform_get_irq()
  failure (bsc#1175713).
- iommu/vt-d: Return the correct dma mask when we are bypassing
  the IOMMU (bsc#1175713).
- iommu/arm-smmu: Free context bitmap in the err path of
  arm_smmu_init_domain_context (bsc#1175713).
- iommu: pass cell_count = -1 to of_for_each_phandle with
  cells_name (bsc#1175713).
- firmware: qcom_scm: Cleanup code in qcom_scm_assign_mem()
  (bsc#1175713).
- iommu: Revisit iommu_insert_resv_region() implementation
  (bsc#1175713).
- iommu: Remove dev_err() usage after platform_get_irq()
  (bsc#1175713).
- iommu/vt-d: Declare Broadwell igfx dmar support snafu
  (bsc#1175713).
- iommu/amd: Re-factor guest virtual APIC (de-)activation code
  (bsc#1175713).
- iommu/ipmmu-vmsa: Disable cache snoop transactions on R-Car Gen3
  (bsc#1175713).
- iommu/qcom: Use struct_size() helper (bsc#1175713).
- iommu/mediatek: Clean up struct mtk_smi_iommu (bsc#1175713).
- memory: mtk-smi: Get rid of need_larbid (bsc#1175713).
- memory: mtk-smi: Add bus_sel for mt8183 (bsc#1175713).
- memory: mtk-smi: Invoke pm runtime_callback to enable clocks
  (bsc#1175713).
- iommu/mediatek: Add mmu1 support (bsc#1175713).
- memory: mtk-smi: Add gals support (bsc#1175713).
- iommu/mediatek: Move vld_pa_rng into plat_data (bsc#1175713).
- iommu/mediatek: Move reset_axi into plat_data (bsc#1175713).
- iommu/mediatek: Refine protect memory definition (bsc#1175713).
- iommu/mediatek: Add larb-id remapped support (bsc#1175713).
- iommu/mediatek: Add bclk can be supported optionally
  (bsc#1175713).
- iommu/mediatek: Adjust the PA for the 4GB Mode (bsc#1175713).
- iommu/io-pgtable-arm-v7s: Extend to support PA[33:32] for
  MediaTek (bsc#1175713).
- iommu/io-pgtable-arm-v7s: Rename the quirk from MTK_4GB to
  MTK_EXT (bsc#1175713).
- iommu/io-pgtable-arm-v7s: Use ias/oas to check the valid iova/pa
  (bsc#1175713).
- iommu/io-pgtable-arm-v7s: Add paddr_to_iopte and iopte_to_paddr
  helpers (bsc#1175713).
- memory: mtk-smi: Use a struct for the platform data for
  smi-common (bsc#1175713).
- memory: mtk-smi: Use a general config_port interface
  (bsc#1175713).
- iommu/mediatek: Use a struct as the platform data (bsc#1175713).
- dt-bindings: mediatek: Add binding for mt8183 IOMMU and SMI
  (bsc#1175713).
- iommu/arm-smmu-v3: Fix build error without CONFIG_PCI_ATS
  (bsc#1175713).
- Revert "iommu/arm-smmu-v3: Disable detection of ATS and PRI"
  (bsc#1175713).
- iommu/arm-smmu-v3: Avoid locking on invalidation path when
  not using ATS (bsc#1175713).
- iommu/arm-smmu-v3: Fix ATC invalidation ordering wrt main TLBs
  (bsc#1175713).
- iommu/arm-smmu-v3: Rework enabling/disabling of ATS for PCI
  masters (bsc#1175713).
- iommu/arm-smmu-v3: Don't issue CMD_SYNC for zero-length
  invalidations (bsc#1175713).
- iommu/arm-smmu-v3: Remove boolean bitfield for 'ats_enabled'
  flag (bsc#1175713).
- iommu/arm-smmu-v3: Document ordering guarantees of command
  insertion (bsc#1175713).
- iommu/arm-smmu-v3: Defer TLB invalidation until ->iotlb_sync()
  (bsc#1175713).
- iommu/arm-smmu-v3: Reduce contention during command-queue
  insertion (bsc#1175713).
- iommu/arm-smmu-v3: Operate directly on low-level queue where
  possible (bsc#1175713).
- iommu/arm-smmu-v3: Move low-level queue fields out of
  arm_smmu_queue (bsc#1175713).
- iommu/arm-smmu-v3: Drop unused 'q' argument from Q_OVF macro
  (bsc#1175713).
- iommu/arm-smmu-v3: Separate s/w and h/w views of prod and cons
  indexes (bsc#1175713).
- iommu/io-pgtable: Pass struct iommu_iotlb_gather to
  - >tlb_add_page() (bsc#1175713).
- iommu/io-pgtable: Pass struct iommu_iotlb_gather to ->unmap()
  (bsc#1175713).
- iommu/io-pgtable: Remove unused ->tlb_sync() callback
  (bsc#1175713).
- iommu/io-pgtable: Replace ->tlb_add_flush() with
  - >tlb_add_page() (bsc#1175713).
- iommu/io-pgtable-arm: Call ->tlb_flush_walk() and
  - >tlb_flush_leaf() (bsc#1175713).
- iommu/io-pgtable: Hook up ->tlb_flush_walk() and
  - >tlb_flush_leaf() in drivers (bsc#1175713).
- iommu/io-pgtable: Introduce tlb_flush_walk() and
  tlb_flush_leaf() (bsc#1175713).
- iommu: Introduce iommu_iotlb_gather_add_page() (bsc#1175713).
- iommu: Introduce struct iommu_iotlb_gather for batching TLB
  flushes (bsc#1175713).
- iommu/io-pgtable: Rename iommu_gather_ops to iommu_flush_ops
  (bsc#1175713).
- iommu/io-pgtable-arm: Remove redundant call to
  io_pgtable_tlb_sync() (bsc#1175713).
- iommu/arm-smmu: Ensure 64-bit I/O accessors are available on
  32-bit CPU (bsc#1175713).
- iommu/arm-smmu: Make private implementation details static
  (bsc#1175713).
- iommu/arm-smmu: Add context init implementation hook
  (bsc#1175713).
- iommu/arm-smmu: Add reset implementation hook (bsc#1175713).
- iommu/arm-smmu: Add configuration implementation hook
  (bsc#1175713).
- iommu/arm-smmu: Move Secure access quirk to implementation
  (bsc#1175713).
- iommu/arm-smmu: Rename arm-smmu-regs.h (bsc#1175713).
- iommu/arm-smmu: Abstract GR0 accesses (bsc#1175713).
- iommu/arm-smmu: Abstract context bank accesses (bsc#1175713).
- iommu/arm-smmu: Abstract GR1 accesses (bsc#1175713).
- iommu/arm-smmu: Get rid of weird "atomic" write (bsc#1175713).
- iommu/arm-smmu: Split arm_smmu_tlb_inv_range_nosync()
  (bsc#1175713).
- iommu/arm-smmu: Rework cb_base handling (bsc#1175713).
- iommu/arm-smmu: Convert context bank registers to bitfields
  (bsc#1175713).
- iommu/arm-smmu: Convert GR1 registers to bitfields
  (bsc#1175713).
- iommu/arm-smmu: Convert GR0 registers to bitfields
  (bsc#1175713).
- iommu/qcom: Mask TLBI addresses correctly (bsc#1175713).
- iommu/arm-smmu: Mask TLBI address correctly (bsc#1175713).
- iommu/exynos: Remove __init annotation from
  exynos_sysmmu_probe() (bsc#1175713).
- iommu/omap: Mark pm functions __maybe_unused (bsc#1175713).
- iommu/omap: Use the correct type for SLAB_HWCACHE_ALIGN
  (bsc#1175713).
- iommu/omap: Fix compilation warnings (bsc#1175713).
- iommu/omap: remove pm_runtime_irq_safe flag for OMAP IOMMUs
  (bsc#1175713).
- iommu/omap: add support for late attachment of iommu devices
  (bsc#1175713).
- iommu/omap: introduce new API for runtime suspend/resume control
  (bsc#1175713).
- iommu/omap: Add system suspend/resume support (bsc#1175713).
- iommu/omap: add logic to save/restore locked TLBs (bsc#1175713).
- iommu/omap: streamline enable/disable through runtime pm
  callbacks (bsc#1175713).
- commit 617f34e
* Fri Aug 28 2020 mkubecek@suse.cz
- update upstream reference
- update "net" repository URL:
  patches.suse/ibmvnic-fix-NULL-tx_pools-and-rx_tools-issue-at-do_r.patch
- commit f299d68
* Fri Aug 28 2020 yousaf.kaukab@suse.com
- soc/tegra: pmc: Enable PMIC wake event on Tegra194
  (bsc#1175834).
- commit e2e5a5c
* Fri Aug 28 2020 msuchanek@suse.de
- ibmvnic fix NULL tx_pools and rx_tools issue at do_reset
  (bsc#1175873 ltc#187922).
- commit eff0cb0
* Fri Aug 28 2020 dwagner@suse.de
- kabi/severities: ignore qla2xxx as all symbols are internal
- commit cbc9e8b
* Thu Aug 27 2020 ddiss@suse.de
- scsi: target/iblock: fix WRITE SAME zeroing (bsc#1169790).
- commit 3f94600
* Thu Aug 27 2020 tonyj@suse.de
- blacklist.conf:  Update for perf userspace git-fixes
- commit 981209c
* Thu Aug 27 2020 dwagner@suse.de
- scsi/fc: kABI fixes for new ELS_RPD definition
  (bsc#1171688 bsc#1174003).
- commit 6839081
* Thu Aug 27 2020 mbrugger@suse.com
- efi: libstub/tpm: enable tpm eventlog function for ARM platforms
  (bsc#1173267).
- commit 1168a55
* Thu Aug 27 2020 dwagner@suse.de
- Revert "scsi: qla2xxx: Disable T10-DIF feature with FC-NVMe
  during probe" (bsc#1171688 bsc#1174003).
- Revert "scsi: qla2xxx: Fix crash on qla2x00_mailbox_command"
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix null pointer access during disconnect from
  subsystem (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Check if FW supports MQ before enabling
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix WARN_ON in qla_nvme_register_hba (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Allow ql2xextended_error_logging special value
  1 to be set anytime (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Reduce noisy debug message (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix login timeout (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Indicate correct supported speeds for Mezz card
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Flush I/O on zone disable (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Flush all sessions on zone disable (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Use MBX_TOV_SECONDS for mailbox command timeout
  values (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Address a set of sparse warnings (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: SAN congestion management implementation
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Change in PUREX to handle FPIN ELS requests
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Introduce a function for computing the debug
  message prefix (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Make qla2x00_restart_isp() easier to read
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix a Coverity complaint in qla2100_fw_dump()
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Make __qla2x00_alloc_iocbs() initialize 32 bits
  of request_t.handle (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Remove a superfluous cast (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Initialize 'n' before using it (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Make qla82xx_flash_wait_write_finish() easier
  to read (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Remove the __packed annotation from struct
  fcp_hdr and fcp_hdr_le (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Check the size of struct fcp_hdr at compile time
  (bsc#1171688 bsc#1174003).
- scsi: Fix trivial spelling (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix a condition in qla2x00_find_all_fabric_devs()
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Keep initiator ports after RSCN (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Remove return value from qla_nvme_ls()
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Remove an unused function (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix endianness annotations in source files
  (bsc#1171688 bsc#1174003).
  Refresh patches.suse/scsi-qla2xxx-Set-NVMe-status-code-for-failed-NVMe-FC.patch
- scsi: qla2xxx: Fix endianness annotations in header files
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Use make_handle() instead of open-coding it
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Cast explicitly to uint16_t / uint32_t
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Change {RD,WRT}_REG_*() function names from
  upper case into lower case (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix the code that reads from mailbox registers
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Use register names instead of register offsets
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Change two hardcoded constants into offsetof()
  / sizeof() expressions (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Increase the size of struct qla_fcp_prio_cfg
  to FCP_PRIO_CFG_SIZE (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Make a gap in struct qla2xxx_offld_chain explicit
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Add more BUILD_BUG_ON() statements (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Sort BUILD_BUG_ON() statements alphabetically
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Simplify the functions for dumping firmware
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix spelling of a variable name (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Make qlafx00_process_aen() return void
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Use true, false for ha->fw_dumped (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Use true, false for need_mpi_reset (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Make qla_set_ini_mode() return void (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix issue with adapter's stopping state
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix failure message in qlt_disable_vha()
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix warning after FC target reset (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: make 1-bit bit-fields unsigned int (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix MPI failure AEN (8200) handling (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Use ARRAY_SIZE() instead of open-coding it
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Split qla2x00_configure_local_loop() (bsc#1171688
  bsc#1174003).
- commit 675dd78
* Thu Aug 27 2020 tiwai@suse.de
- serial: 8250: change lock order in serial8250_do_startup()
  (git-fixes).
- serial: pl011: Fix oops on -EPROBE_DEFER (git-fixes).
- serial: pl011: Don't leak amba_ports entry on driver register
  error (git-fixes).
- kernel/relay.c: fix memleak on destroy relay channel
  (git-fixes).
- drm/amd/display: fix pow() crashing when given base 0
  (git-fixes).
- drm/amd/display: Fix EDID parsing after resume from suspend
  (git-fixes).
- rtc: goldfish: Enable interrupt in set_alarm() when necessary
  (git-fixes).
- Input: psmouse - add a newline when printing 'proto' by sysfs
  (git-fixes).
- media: camss: fix memory leaks on error handling paths in probe
  (git-fixes).
- media: vpss: clean up resources in init (git-fixes).
- media: rockchip: rga: Only set output CSC mode for RGB input
  (git-fixes).
- media: rockchip: rga: Introduce color fmt macros and refactor
  CSC mode logic (git-fixes).
- media: budget-core: Improve exception handling in
  budget_register() (git-fixes).
- commit 0974903
* Thu Aug 27 2020 jslaby@suse.cz
- x86/cpufeatures: Add support for fast short REP; MOVSB
  (jsc#SLE-12692).
- Refresh
  patches.suse/x86-speculation-add-special-register-buffer-data-sampling-srbds-mitigation.patch.
- commit 6a5fd30
* Thu Aug 27 2020 firo.yang@suse.com
- mm, vmstat: reduce zone->lock holding time by /proc/pagetypeinfo
  (bsc#1175691).
- commit e293f1c
* Wed Aug 26 2020 bp@suse.de
- x86/entry/64: Do not use RDPID in paranoid entry to accomodate
  KVM (jsc#SLE-14846).
- commit 4fc39c9
* Wed Aug 26 2020 bp@suse.de
- x86/fsgsbase: Fix Xen PV support (jsc#SLE-14846).
- commit 3bc63e5
* Wed Aug 26 2020 bp@suse.de
- x86/ptrace: Fix 32-bit PTRACE_SETREGS vs fsbase and gsbase
  (jsc#SLE-14846).
- commit a2d9b1c
* Wed Aug 26 2020 tiwai@suse.de
- spi: spi-amd: Add AMD SPI controller driver support
  (jsc#SLE-15356).
- Update config files: CONFIG_SPI_AMD=m for arm64/default
- supported.conf: add spi-amd
- commit 8fc8fcc
* Wed Aug 26 2020 tiwai@suse.de
- spi: spi-amd: Do not define 'struct acpi_device_id' when
  !CONFIG_ACPI (jsc#SLE-15356).
- spi: amd: Drop superfluous member from struct amd_spi
  (jsc#SLE-15356).
- spi: amd: Fix refcount underflow on remove (jsc#SLE-15356).
- spi: amd: Drop duplicate driver data assignments
  (jsc#SLE-15356).
- spi: amd: Pass probe errors back to driver core (jsc#SLE-15356).
- spi: amd: Fix duplicate iounmap in error path (jsc#SLE-15356).
- spi: spi-amd: Fix a NULL vs IS_ERR() check in amd_spi_probe()
  (jsc#SLE-15356).
- spi: spi-amd: fix warning (jsc#SLE-15356).
- commit 9cf167d
* Wed Aug 26 2020 martin.wilck@suse.com
- Refresh
  patches.suse/nvme-multipath-round-robin-eliminate-fallback-variable.patch.
- commit f3c5d53
* Wed Aug 26 2020 martin.wilck@suse.com
- Refresh
  patches.suse/nvme-multipath-round-robin-fix-single-non-optimized-path-case.patch.
- commit d615e5c
* Wed Aug 26 2020 msuchanek@suse.de
- powerpc/iommu: Allow bypass-only for DMA (bsc#1156395).
- commit 70ae27e
* Wed Aug 26 2020 msuchanek@suse.de
- powerpc/fadump: Fix build error with CONFIG_PRESERVE_FA_DUMP=y
  (bsc#1156395).
- commit a889646
* Wed Aug 26 2020 msuchanek@suse.de
- powerpc/perf: Fix missing is_sier_aviable() during build
  (bsc#1065729).
- pseries: Fix 64 bit logical memory block panic (bsc#1065729).
- KVM: PPC: Book3S PR: Remove uninitialized_var() usage
  (bsc#1065729).
- commit 45994c6
* Wed Aug 26 2020 mbenes@suse.cz
- selftests/livepatch: fix mem leaks in test-klp-shadow-vars
  (bsc#1071995).
- commit 0e9c3d5
* Wed Aug 26 2020 msuchanek@suse.de
- powerpc/pseries/hotplug-cpu: wait indefinitely for vCPU death
  (fate#322438 bsc#1085030 ltC#165630).
- commit d3a8444
* Wed Aug 26 2020 mbenes@suse.cz
- selftests/livepatch: more verification in test-klp-shadow-vars
  (bsc#1071995).
- commit fead416
* Wed Aug 26 2020 mbenes@suse.cz
- selftests/livepatch: rework test-klp-shadow-vars (bsc#1071995).
- commit c5a8b83
* Wed Aug 26 2020 mbenes@suse.cz
- selftests/livepatch: simplify test-klp-callbacks busy target
  tests (bsc#1071995).
- commit ab54a11
* Wed Aug 26 2020 msuchanek@suse.de
- powerpc/64s: Don't init FSCR_DSCR in __init_FSCR()
  (bsc#1065729).
- commit a21209e
* Wed Aug 26 2020 mbenes@suse.cz
- tracing: Use trace_sched_process_free() instead of exit()
  for pid tracing (git-fixes).
- commit 6da73c8
* Wed Aug 26 2020 mbenes@suse.cz
- tracepoint: Mark __tracepoint_string's __used (git-fixes).
- commit 9722e3c
* Wed Aug 26 2020 mbenes@suse.cz
- blacklist.conf: 96b4833b6827 ("tracing/hwlat: Honor the tracing_cpumask")
  CONFIG_HWLAT_TRACER is not set anywhere.
- commit 314fc84
* Wed Aug 26 2020 mbenes@suse.cz
- blacklist.conf: 7ef282e05132 ("tracing: Move pipe reference to trace array instead of current_tracer")
  As mentioned in the changelog, it is a cleanup and not really a critical
  fix.
- commit 9fc5f45
* Wed Aug 26 2020 alnovak@suse.cz
- Mark the SLE15-SP2 kernel properly released.
  There perhaps was a typo, when SUSE_KERNEL_RELEASED missed the trailing
  "D" - this leads to our kernels being marked as "Unreleased kernel".
  SUSE_KERNEL_RELEASED is defined in rpm/kernel-binary.spec.in.
  To fix that, it should be enough to switch from SUSE_KERNEL_RELEASE to
  SUSE_KERNEL_RELEASED.
- commit 2de2687
* Wed Aug 26 2020 jack@suse.cz
- bfq: fix blkio cgroup leakage v4 (bsc#1175775).
- commit 78cc5b1
* Wed Aug 26 2020 jack@suse.cz
- kernfs: do not call fsnotify() with name without a parent
  (bsc#1175770).
- commit 7f9fdb0
* Wed Aug 26 2020 jack@suse.cz
- ext4: fix checking of directory entry validity for inline
  directories (bsc#1175771).
- commit 50ef0f0
* Wed Aug 26 2020 jack@suse.cz
- ext2: fix missing percpu_counter_inc (bsc#1175774).
- commit 5a50871
* Wed Aug 26 2020 jack@suse.cz
- mm: filemap: clear idle flag for writes (bsc#1175769).
- commit 7a6a0d8
* Wed Aug 26 2020 jack@suse.cz
- jbd2: add the missing unlock_buffer() in the error path of
  jbd2_write_superblock() (bsc#1175772).
- commit feb29da
* Wed Aug 26 2020 jack@suse.cz
- dlm: Fix kobject memleak (bsc#1175768).
- commit 88c29e9
* Wed Aug 26 2020 bp@suse.de
- selftests/x86/fsgsbase: Add a missing memory constraint
  (jsc#SLE-14846).
- commit 110c3f7
* Wed Aug 26 2020 bp@suse.de
- blacklist.conf: 979c2c4247ca ("selftests/x86/fsgsbase: Fix a comment in	the ptrace_write_gsbase test")
  Just a comment fix, drop it.
- commit 9f764a4
* Wed Aug 26 2020 bp@suse.de
- selftests/x86: Add a syscall_arg_fault_64 test for negative
  GSBASE (jsc#SLE-14846).
- commit 1eb8813
* Wed Aug 26 2020 bp@suse.de
- selftests/x86/fsgsbase: Test ptracer-induced GS base write
  with FSGSBASE (jsc#SLE-14846).
- commit 2e37bcc
* Wed Aug 26 2020 tiwai@suse.de
- mfd: intel-lpss: Add Intel Tiger Lake PCH-H PCI IDs
  (jsc#SLE-13411).
- i2c: i801: Add support for Intel Tiger Lake PCH-H
  (jsc#SLE-13411).
- i2c: i801: Add support for Intel Emmitsburg PCH (jsc#SLE-13411).
- spi: pxa2xx: Add support for Intel Tiger Lake PCH-H
  (jsc#SLE-13411).
- i2c: i801: Add support for Intel Comet Lake PCH-V
  (jsc#SLE-13411).
- commit ec0755f
* Wed Aug 26 2020 jslaby@suse.cz
- ip6_gre: fix null-ptr-deref in ip6gre_init_net() (git-fixes).
- commit 7f7d231
* Tue Aug 25 2020 mkubecek@suse.cz
- update upstream references after rebase
  Once again, scsi maintainer branch got rebased, leaving our Git-commit tags
  invalid and git_sort complaining heavily. Update the tags to rebased
  branch.
- commit 9c95c04
* Tue Aug 25 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/md-cluster-Fix-potential-error-pointer-dereference-i.patch
  patches.suse/md-raid5-Fix-Force-reconstruct-write-io-stuck-in-deg.patch
- commit 5986388
* Tue Aug 25 2020 bp@suse.de
- selftests/x86/fsgsbase: Test GS selector on ptracer-induced
  GS base write (jsc#SLE-14846).
- commit 683d481
* Tue Aug 25 2020 jack@suse.cz
- ext4: check journal inode extents more carefully (bsc#1173485).
- commit 17c289f
* Tue Aug 25 2020 jack@suse.cz
- ext4: don't allow overlapping system zones (bsc#1173485).
- commit d96644e
* Tue Aug 25 2020 jack@suse.cz
- ext4: handle error of ext4_setup_system_zone() on remount
  (bsc#1173485).
- commit 6d00054
* Tue Aug 25 2020 jack@suse.cz
- ext4: fix potential negative array index in do_split()
  (bsc#1173798 CVE-2020-14314).
- commit 078f390
* Tue Aug 25 2020 jack@suse.cz
- ext4: don't BUG on inconsistent journal feature (bsc#1171634).
- commit f410395
* Tue Aug 25 2020 bp@suse.de
- Documentation/x86/64: Add documentation for GS/FS addressing
  mode (jsc#SLE-14846).
- commit deb1390
* Tue Aug 25 2020 tiwai@suse.de
- serial: 8250_lpss: Add ->setup() for Elkhart Lake ports
  (jsc#SLE-13436).
- serial: 8250_lpss: Switch over to MSI interrupts
  (jsc#SLE-13436).
- serial: 8250_lpss: Enable HS UART on Elkhart Lake
  (jsc#SLE-13436).
- serial: 8250_lpss: Get rid of custom LPSS_DEVICE() macro
  (jsc#SLE-13436).
- serial: 8250_lpss: add fractional divisor support
  (jsc#SLE-13436).
- commit bbd3666
* Tue Aug 25 2020 tiwai@suse.de
- serial: 8250_lpss: switch to use 8250_dwlib library
  (jsc#SLE-13436).
- Update config files: CONFIG_SERIAL_8250_DWLIB=y for x86_64
- commit 2ff99d9
* Tue Aug 25 2020 tiwai@suse.de
- serial: 8250_dw: split Synopsys DesignWare 8250 common functions
  (jsc#SLE-13436).
- commit 4a3eae5
* Tue Aug 25 2020 tiwai@suse.de
- Sort and refresh upstreamed patches
- commit 7f88fbb
* Tue Aug 25 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-Optimize-dequeue_task_fair.patch.
- commit bdf744b
* Tue Aug 25 2020 mgorman@suse.de
- sched/fair: fix NOHZ next idle balance (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- commit 54284ef
* Tue Aug 25 2020 jroedel@suse.de
- blacklist.conf: Remove IOMMU commits which are about to be backported
- commit ed28211
* Tue Aug 25 2020 mgorman@suse.de
- update upstream references and move into sorted section:
  patches.suse/0001-proc-meminfo-avoid-open-coded-reading-of-mv_committed_as.patch.
  patches.suse/0002-mm-util-make-vm_memory_comitted-more-accurate.patch.
  patches.suse/0003-mm-adjust-vm_committed_as_batch-according-to-vm-overcommit-policy.patch.
  patches.suse/fsnotify-Rearrange-fast-path-to-minimise-overhead-when-there-is-no-watcher.patch.
- commit 400e8aa
* Tue Aug 25 2020 jslaby@suse.cz
- mlxsw: pci: Fix use-after-free in case of failed devlink reload
  (networking-stable-20_07_17).
- mlxsw: spectrum_router: Remove inappropriate usage of WARN_ON()
  (networking-stable-20_07_17).
- bnxt_en: fix NULL dereference in case SR-IOV configuration fails
  (networking-stable-20_07_17).
- net/mlx5e: Fix 50G per lane indication
  (networking-stable-20_07_17).
- net/mlx5: Fix eeprom support for SFP module
  (networking-stable-20_07_17).
- tcp: make sure listeners don't initialize congestion-control
  state (networking-stable-20_07_17).
- net_sched: fix a memory leak in atm_tc_init()
  (networking-stable-20_07_17).
- l2tp: remove skb_dst_set() from l2tp_xmit_skb()
  (networking-stable-20_07_17).
- vlan: consolidate VLAN parsing code and limit max parsing depth
  (networking-stable-20_07_17).
- net: Added pointer check for dst->ops->neigh_lookup in
  dst_neigh_lookup_skb (networking-stable-20_07_17).
- ipv4: fill fl4_icmp_{type,code} in ping_v4_sendmsg
  (networking-stable-20_07_17).
- ipv6: Fix use of anycast address with loopback
  (networking-stable-20_07_17).
- net: usb: qmi_wwan: add support for Quectel EG95 LTE modem
  (networking-stable-20_07_17).
- ipv6: fib6_select_path can not use out path for nexthop objects
  (networking-stable-20_07_17).
- sched: consistently handle layer3 header accesses in the
  presence of VLANs (networking-stable-20_07_17).
- net: dsa: microchip: set the correct number of ports
  (networking-stable-20_07_17).
- tcp: fix SO_RCVLOWAT possible hangs under high mem pressure
  (networking-stable-20_07_17).
- tcp: md5: do not send silly options in SYNCOOKIES
  (networking-stable-20_07_17).
- tcp: md5: refine tcp_md5_do_add()/tcp_md5_hash_key() barriers
  (networking-stable-20_07_17).
- genetlink: remove genl_bind (networking-stable-20_07_17).
- kABI: genetlink: remove genl_bind (kabi).
- net: qrtr: Fix an out of bounds read qrtr_endpoint_post()
  (networking-stable-20_07_17).
- tcp: md5: add missing memory barriers
  in tcp_md5_do_add()/tcp_md5_hash_key()
  (networking-stable-20_07_17).
- net: mvneta: fix use of state->speed
  (networking-stable-20_07_17).
- llc: make sure applications use ARPHRD_ETHER
  (networking-stable-20_07_17).
- commit ce8586d
* Tue Aug 25 2020 jslaby@suse.cz
- x86/bugs/multihit: Fix mitigation reporting when VMX is not
  in use (git-fixes).
- commit 52699f0
* Mon Aug 24 2020 bp@suse.de
- x86/elf: Enumerate kernel FSGSBASE capability in AT_HWCAP2
  (jsc#SLE-14846).
- commit 15cf537
* Mon Aug 24 2020 tbogendoerfer@suse.de
- net: ena: Make missed_tx stat incremental (git-fixes).
- net: ena: Change WARN_ON expression in ena_del_napi_in_range()
  (bsc#1154492).
- net: ena: Prevent reset after device destruction (git-fixes).
- commit 25750c1
* Mon Aug 24 2020 bp@suse.de
- x86/cpu: Enable FSGSBASE on 64bit by default and add a chicken
  bit (jsc#SLE-14846).
- commit 32888b4
* Mon Aug 24 2020 bp@suse.de
- x86/entry/64: Handle FSGSBASE enabled paranoid entry/exit
  (jsc#SLE-14846).
- commit 41abd14
* Mon Aug 24 2020 msuchanek@suse.de
- mm/vunmap: add cond_resched() in vunmap_pmd_range (bsc#1175654
  ltc#184617).
- commit 313860f
* Mon Aug 24 2020 neilb@suse.de
- md-cluster: Fix potential error pointer dereference in
  resize_bitmaps() (git-fixes).
- md/raid5: Fix Force reconstruct-write io stuck in degraded raid5
  (git-fixes).
- commit 5f598a1
* Mon Aug 24 2020 mkubecek@suse.cz
- Update kabi files.
- update to released maintenance update (commit dbe0add4c655)
- commit d427f85
* Mon Aug 24 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/bonding-fix-active-backup-failover-for-current-ARP-s.patch
  patches.suse/powerpc-pseries-Do-not-initiate-shutdown-when-system.patch
- commit 1f2a0f0
* Sun Aug 23 2020 bp@suse.de
- x86/entry/64: Introduce the FIND_PERCPU_BASE macro
  (jsc#SLE-14846).
- commit d965683
* Sun Aug 23 2020 bp@suse.de
- x86/entry/64: Switch CR3 before SWAPGS in paranoid entry
  (jsc#SLE-14846).
- commit ce4dac6
* Sun Aug 23 2020 bp@suse.de
- x86/speculation/swapgs: Check FSGSBASE in enabling SWAPGS
  mitigation (jsc#SLE-14846).
- commit c0d84fd
* Sun Aug 23 2020 bp@suse.de
- x86/process/64: Use FSGSBASE instructions on thread copy and
  ptrace (jsc#SLE-14846).
- commit 575fffe
* Sun Aug 23 2020 mkubecek@suse.cz
- update patch metadata
- update Git-repo tag:
  patches.suse/bonding-fix-active-backup-failover-for-current-ARP-s.patch
- commit 9d16d24
* Sat Aug 22 2020 bp@suse.de
- x86/process/64: Use FSBSBASE in switch_to() if available
  (jsc#SLE-14846).
- commit 546524c
* Sat Aug 22 2020 bp@suse.de
- x86/process/64: Make save_fsgs_for_kvm() ready for FSGSBASE
  (jsc#SLE-14846).
- commit 1cb0d6c
* Sat Aug 22 2020 bp@suse.de
- x86/fsgsbase/64: Enable FSGSBASE instructions in helper
  functions (jsc#SLE-14846).
- commit 5167bb7
* Sat Aug 22 2020 bp@suse.de
- x86/fsgsbase/64: Add intrinsics for FSGSBASE instructions
  (jsc#SLE-14846).
- commit 124049f
* Sat Aug 22 2020 bp@suse.de
- x86/cpu: Add 'unsafe_fsgsbase' to enable CR4.FSGSBASE
  (jsc#SLE-14846).
- commit a804e17
* Sat Aug 22 2020 bp@suse.de
- x86/ptrace: Prevent ptrace from clearing the FS/GS selector
  (jsc#SLE-14846).
- commit 32e7e65
* Fri Aug 21 2020 tiwai@suse.de
- ALSA: hda: avoid reset of sdo_limit (git-fixes).
- ALSA: hda/realtek: Add quirk for Samsung Galaxy Book Ion
  (git-fixes).
- ASoC: intel: Fix memleak in sst_media_open (git-fixes).
- ASoC: wm8994: Avoid attempts to read unreadable registers
  (git-fixes).
- ASoC: msm8916-wcd-analog: fix register Interrupt offset
  (git-fixes).
- ASoC: q6routing: add dummy register read/write function
  (git-fixes).
- ASoC: q6afe-dai: mark all widgets registers as SND_SOC_NOPM
  (git-fixes).
- ALSA: usb-audio: ignore broken processing/extension unit
  (git-fixes).
- ALSA: hda/realtek: Add model alc298-samsung-headphone
  (git-fixes).
- ALSA: usb-audio: Update documentation comment for MS2109 quirk
  (git-fixes).
- ALSA: isa: fix spelling mistakes in the comments (git-fixes).
- ALSA: usb-audio: Add capture support for Saffire 6 (USB 1.1)
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Samsung Galaxy Flex Book
  (git-fixes).
- commit 2cf9c73
* Fri Aug 21 2020 tbogendoerfer@suse.de
- RDMA/mlx5: Fix typo in enum name (git-fixes).
- cpumap: Use non-locked version __ptr_ring_consume_batched
  (git-fixes).
- commit b117316
* Fri Aug 21 2020 tbogendoerfer@suse.de
- igc: Fix PTP initialization (bsc#1160634).
- vmxnet3: use correct tcp hdr length when packet is encapsulated
  (bsc#1175199).
- RDMA/mlx5: Add missing srcu_read_lock in ODP implicit flow
  (jsc#SLE-8446).
- net/mlx5: DR, Change push vlan action sequence (jsc#SLE-8464).
- ice: Graceful error handling in HW table calloc failure
  (jsc#SLE-7926).
- ice: Clear and free XLT entries on reset (jsc#SLE-7926).
- commit da2585a
* Fri Aug 21 2020 jwiesner@suse.com
- bonding: fix active-backup failover for current ARP slave
  (bsc#1174771).
- commit 2837560
* Fri Aug 21 2020 jslaby@suse.cz
- enetc: Fix tx rings bitmap iteration range, irq handling
  (networking-stable-20_06_28).
- sch_cake: don't call diffserv parsing code when it is not needed
  (networking-stable-20_06_28).
- sch_cake: don't try to reallocate or unshare skb unconditionally
  (networking-stable-20_06_28).
- sctp: Don't advertise IPv4 addresses if ipv6only is set on
  the socket (networking-stable-20_06_28).
- tcp_cubic: fix spurious HYSTART_DELAY exit upon drop in min RTT
  (networking-stable-20_06_28).
- net: bridge: enfore alignment for ethernet address
  (networking-stable-20_06_28).
- tcp: don't ignore ECN CWR on pure ACK
  (networking-stable-20_06_28).
- openvswitch: take into account de-fragmentation/gso_size in
  execute_check_pkt_len (networking-stable-20_06_28).
- net: Do not clear the sock TX queue in sk_set_socket()
  (networking-stable-20_06_28).
- net: increment xmit_recursion level in dev_direct_xmit()
  (networking-stable-20_06_28).
- net: Fix the arp error in some cases
  (networking-stable-20_06_28).
- ip_tunnel: fix use-after-free in ip_tunnel_lookup()
  (networking-stable-20_06_28).
- ip6_gre: fix use-after-free in ip6gre_tunnel_lookup()
  (networking-stable-20_06_28).
- net: core: reduce recursion limit value
  (networking-stable-20_06_28).
- net: fix memleak in register_netdevice()
  (networking-stable-20_06_28).
- net: usb: ax88179_178a: fix packet alignment padding
  (networking-stable-20_06_28).
- tcp: grow window for OOO packets only for SACK flows
  (networking-stable-20_06_28).
- mvpp2: ethtool rxtx stats fix (networking-stable-20_06_28).
- rocker: fix incorrect error handling in dma_rings_init
  (networking-stable-20_06_28).
- mld: fix memory leak in ipv6_mc_destroy_dev()
  (networking-stable-20_06_28).
- commit 1f17d28
* Fri Aug 21 2020 lyan@suse.com
- KVM: arm64: Stop clobbering x0 for HVC_SOFT_RESTART
  (bsc#1133021).
- KVM: x86: Fix APIC page invalidation race (bsc#1133021).
- KVM: Reinstall old memslots if arch preparation fails
  (bsc#1133021).
- commit 8362c5b
* Fri Aug 21 2020 firo.yang@suse.com
- ipvs: fix the connection sync failed in some cases (bsc#1174699).
- commit d96eaab
* Thu Aug 20 2020 msuchanek@suse.de
- powerpc/pseries: Do not initiate shutdown when system is
  running on UPS (bsc#1175440 ltc#187574).
- commit 738b1b0
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: fix memory leaks after failure to lookup checksums
  during inode logging (bsc#1175550).
- commit 91d88bc
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: remove useless check for copy_items() return value
  (bsc#1175546).
- commit 564c2ae
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: make full fsyncs always operate on the entire file again
  (bsc#1175546).
- commit 75261f5
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: make ranged full fsyncs more efficient (bsc#1175546).
- commit 4839ec4
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: factor out inode items copy loop from btrfs_log_inode()
  (bsc#1175546).
- commit 269fe12
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: add helper to get the end offset of a file extent item
  (bsc#1175546).
- commit 60d1bb0
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: fix missing file extent item for hole after ranged fsync
  (bsc#1175546).
- commit dd0a610
* Thu Aug 20 2020 martin.wilck@suse.com
- scsi: smartpqi: Use scnprintf() for avoiding potential buffer
  overflow (bsc#1172418).
- commit 408e9b4
* Thu Aug 20 2020 tiwai@suse.de
- spi: stm32: fixes suspend/resume management (git-fixes).
- HID: input: Fix devices that return multiple bytes in battery
  report (git-fixes).
- Bluetooth: add a mutex lock to avoid UAF in do_enale_set
  (git-fixes).
- iwlegacy: Check the return value of pcie_capability_read_*()
  (git-fixes).
- brcmfmac: set state of hanger slot to FREE when flushing PSQ
  (git-fixes).
- brcmfmac: To fix Bss Info flag definition Bug (git-fixes).
- brcmfmac: keep SDIO watchdog running when console_interval is
  non-zero (git-fixes).
- drm: msm: a6xx: fix gpu failure after system resume (git-fixes).
- drm/msm: ratelimit crtc event overflow error (git-fixes).
- drm/ttm/nouveau: don't call tt destroy callback on alloc failure
  (git-fixes bsc#1175232).
- drm/nouveau: fix reference count leak in
  nouveau_debugfs_strap_peek (git-fixes).
- drm/nouveau: fix multiple instances of reference count leaks
  (git-fixes).
- gpu: host1x: debug: Fix multiple channels emitting messages
  simultaneously (git-fixes).
- drm/amd/powerplay: fix compile error with ARCH=arc (git-fixes).
- drm/etnaviv: fix ref count leak via pm_runtime_get_sync
  (git-fixes).
- drm/nouveau/kms/nv50-: Fix disabling dithering (git-fixes).
- video: fbdev: neofb: fix memory leak in neo_scan_monitor()
  (git-fixes).
- video: fbdev: savage: fix memory leak on error handling path
  in probe (git-fixes).
- drm/amdgpu/display bail early in dm_pp_get_static_clocks
  (git-fixes).
- drm/radeon: Fix reference count leaks caused by
  pm_runtime_get_sync (git-fixes).
- drm/amdgpu: avoid dereferencing a NULL pointer (git-fixes).
- drm/radeon: disable AGP by default (git-fixes).
- drm/tilcdc: fix leak & null ref in panel_connector_get_modes
  (git-fixes).
- drm/debugfs: fix plain echo to connector "force" attribute
  (git-fixes).
- mmc: sdhci-pci-o2micro: Bug fix for O2 host controller Seabird1
  (git-fixes).
- mmc: sdhci-cadence: do not use hardware tuning for SD mode
  (git-fixes).
- usb: mtu3: clear dual mode of u3port when disable device
  (git-fixes).
- usb: bdc: Halt controller on suspend (git-fixes).
- bdc: Fix bug causing crash after multiple disconnects
  (git-fixes).
- usb: gadget: net2280: fix memory leak on probe error handling
  paths (git-fixes).
- dyndbg: fix a BUG_ON in ddebug_describe_flags (git-fixes).
- ACPICA: Do not increment operation_region reference counts
  for field units (git-fixes).
- spi: spidev: Align buffers for DMA (git-fixes).
- soc: qcom: rpmh-rsc: Set suppress_bind_attrs flag (git-fixes).
- platform/x86: asus-nb-wmi: add support for ASUS ROG Zephyrus
  G14 and G15 (git-fixes).
- crypto: aesni - Fix build with LLVM_IAS=1 (git-fixes).
- crypto: aesni - add compatibility with IAS (git-fixes).
- platform/x86: ISST: Add new PCI device ids (git-fixes).
- commit 6acba4d
* Wed Aug 19 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/nvme-multipath-do-not-fall-back-to-__nvme_find_path-.patch
  patches.suse/nvme-multipath-fix-logic-for-non-optimized-paths.patch
- fix Git-commit after rebase and moved into "almost mainline" section:
  patches.suse/nvme-multipath-round-robin-eliminate-fallback-variable.patch
  patches.suse/nvme-multipath-round-robin-fix-single-non-optimized-path-case.patch
- commit 8eb0dea
* Wed Aug 19 2020 fdmanana@suse.com
- btrfs: treat RWF_{,D}SYNC writes as sync for CRCs (bsc#1175493).
- commit f823fb0
* Wed Aug 19 2020 ohering@suse.de
- PCI: hv: Fix a timing issue which causes kdump to fail
  occasionally (bsc#1172871, git-fixes).
- commit e5d6bfd
* Wed Aug 19 2020 nstange@suse.de
- rpm/kernel-binary.spec.in: restrict livepatch metapackage to default flavor
  It has been reported that the kernel-*-livepatch metapackage got
  erroneously enabled for SLE15-SP3's new -preempt flavor, leading to a
  unresolvable dependency to a non-existing kernel-livepatch-x.y.z-preempt
  package.
  As SLE12 and SLE12-SP1 have run out of livepatching support, the need to
  build said metapackage for the -xen flavor is gone and the only remaining
  flavor for which they're still wanted is -default.
  Restrict the build of the kernel-*-livepatch metapackage to the -default
  flavor.
- commit 58949f3
* Wed Aug 19 2020 bp@suse.de
- x86/process: Unify copy_thread_tls() (jsc#SLE-14846).
- commit e42e565
* Wed Aug 19 2020 ohering@suse.de
- Drivers: hv: vmbus: Only notify Hyper-V for die events that
  are oops (bsc#1175128).
- commit 0bc8a06
* Wed Aug 19 2020 jlee@suse.com
- kABI: Fix kABI after EFI_RT_PROPERTIES table backport
  (bsc#1174029, bsc#1174110, bsc#1174111).
- commit b284d8a
* Tue Aug 18 2020 martin.wilck@suse.com
- scsi_dh_alua: set 'transitioning' state on unit attention
  (bsc#1171000, bsc#1165933).
- commit cf7ac61
* Tue Aug 18 2020 martin.wilck@suse.com
- scsi_dh_alua: return BLK_STS_AGAIN for ALUA transitioning state
  (bsc#1165933, bsc#1171000).
- commit f6e8a74
* Tue Aug 18 2020 martin.wilck@suse.com
- block: return status code in blk_mq_end_request() (bsc#1171000,
  bsc#1165933).
- commit 0b97993
* Tue Aug 18 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/ALSA-usb-audio-fix-overeager-device-match-for-MacroS.patch
- commit 3e22b20
* Tue Aug 18 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/btrfs-Move-free_pages_out-label-in-inline-extent-han.patch
- commit 113168c
* Tue Aug 18 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline and drop Git-repo:
  patches.suse/xfrm-policy-match-with-both-mark-and-mask-on-user-in.patch
- commit 18fa7c9
* Tue Aug 18 2020 denis.kirjanov@suse.com
- Refresh
  patches.suse/ALSA-usb-audio-fix-overeager-device-match-for-MacroS.patch.
  Update the patch metadata
- commit 9466e22
* Tue Aug 18 2020 jlee@suse.com
- efi/efivars: Expose RT service availability via efivars
  abstraction (bsc#1174029, bsc#1174110, bsc#1174111).
- commit 7b1e418
* Tue Aug 18 2020 jlee@suse.com
- efi: Mark all EFI runtime services as unsupported on non-EFI
  boot (bsc#1174029, bsc#1174110, bsc#1174111).
- commit 4f0f2d2
* Tue Aug 18 2020 tzimmermann@suse.de
- Revert "drm/amd/display: Expose connector VRR range via debugfs" (bsc#1152489)
  * refreshed for context changes
- commit c657a41
* Tue Aug 18 2020 tzimmermann@suse.de
- drm/ingenic: Fix incorrect assumption about plane->index (bsc#1152489)
  * refreshed for context changes
- commit bc5c9df
* Tue Aug 18 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi: Don't cleanup i2c adapter and ddc ptr in (bsc#1152472)
  * refreshed for context changes
- commit 44aa1b6
* Tue Aug 18 2020 tzimmermann@suse.de
- drm/vgem: Replace opencoded version of drm_gem_dumb_map_offset() (bsc#1152489)
  * refreshed for context changes
- commit e3e1287
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Move cec_notifier to intel_hdmi_connector_unregister, v2.'
- commit a8c7d52
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gt: Only swap to a random sibling once upon creation'
- commit d52efd4
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: fix a crash when overclocking Vega M'
- commit e5e21f4
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/radeon: fix double free'
- commit 280a51f
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/fbc: Fix fence_y_offset handling'
- commit 479361f
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gt: Do not schedule normal requests immediately along virtual'
- commit 23a91d5
* Tue Aug 18 2020 tbogendoerfer@suse.de
- net: ena: support new LLQ acceleration mode (bsc#1174852).
- net: ena: move llq configuration from ena_probe to
  ena_device_init() (bsc#1174852).
- net: ena: enable support of rss hash key and function changes
  (bsc#1174852).
- net: ena: add support for traffic mirroring (bsc#1174852).
- net: ena: cosmetic: change ena_com_stats_admin stats to u64
  (bsc#1174852).
- net: ena: cosmetic: satisfy gcc warning (bsc#1174852).
- net: ena: add reserved PCI device ID (bsc#1174852).
- net: ena: avoid unnecessary rearming of interrupt vector when
  busy-polling (bsc#1174852).
- net: ena: Fix using plain integer as NULL pointer in
  ena_init_napi_in_range (bsc#1174852).
- net: ena: reduce driver load time (bsc#1174852).
- net: ena: cosmetic: minor code changes (bsc#1174852).
- net: ena: cosmetic: fix spacing issues (bsc#1174852).
- net: ena: cosmetic: code reorderings (bsc#1174852).
- net: ena: cosmetic: remove unnecessary code (bsc#1174852).
- net: ena: cosmetic: fix line break issues (bsc#1174852).
- net: ena: cosmetic: fix spelling and grammar mistakes in
  comments (bsc#1174852).
- net: ena: cosmetic: set queue sizes to u32 for consistency
  (bsc#1174852).
- net: ena: cosmetic: rename
  ena_update_tx/rx_rings_intr_moderation() (bsc#1174852).
- net: ena: simplify ena_com_update_intr_delay_resolution()
  (bsc#1174852).
- net: ena: fix ena_com_comp_status_to_errno() return value
  (bsc#1174852).
- net: ena: use explicit variable size for clarity (bsc#1174852).
- net: ena: rename ena_com_free_desc to make API more uniform
  (bsc#1174852).
- net: ena: add support for the rx offset feature (bsc#1174852).
- net: ena: cosmetic: extract code to ena_indirection_table_set()
  (bsc#1174852).
- net: ena: cosmetic: remove unnecessary spaces and tabs in
  ena_com.h macros (bsc#1174852).
- net: ena: use SHUTDOWN as reset reason when closing interface
  (bsc#1174852).
- net: ena: drop superfluous prototype (bsc#1174852).
- net: ena: add support for reporting of packet drops
  (bsc#1174852).
- net: ena: add unmask interrupts statistics to ethtool
  (bsc#1174852).
- net: ena: remove code that does nothing (bsc#1174852).
- net: ena: changes to RSS hash key allocation (bsc#1174852).
- net: ena: change default RSS hash function to Toeplitz
  (bsc#1174852).
- net: ena: allow setting the hash function without changing
  the key (bsc#1174852).
- net: ena: fix error returning in ena_com_get_hash_function()
  (bsc#1174852).
- net: ena: avoid unnecessary admin command when RSS function
  set fails (bsc#1174852).
- net/ena: Fix build warning in ena_xdp_set() (bsc#1174852).
- net: ena: Make some functions static (bsc#1174852).
- net: ena: ethtool: clean up minor indentation issue
  (bsc#1174852).
- net: ena: ethtool: remove redundant non-zero check on rc
  (bsc#1174852).
- net: ena: remove set but not used variable 'hash_key'
  (bsc#1174852).
- net: ena: fix continuous keep-alive resets (bsc#1174852).
- net: ena: avoid memory access violation by validating req_id
  properly (bsc#1174852).
- net: ena: fix request of incorrect number of IRQ vectors
  (bsc#1174852).
- commit c12b7e0
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/radeon: fix fb_div check in ni_init_smc_spll_table()'
- commit 85aef32
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/amd/display: disable dcn20 abm feature for bring up"'
- commit 196a32f
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm: encoder_slave: fix refcouting error for modules'
- commit 29d30a2
* Tue Aug 18 2020 tzimmermann@suse.de
- drm/amdgpu/display: use blanked rather than plane state for sync (bsc#1152489)
  * refreshed for context changes
  * protect code with CONFIG_DRM_AMD_DC_DCN2_0
- commit 481d44a
* Tue Aug 18 2020 tzimmermann@suse.de
- drm/bridge: ti-sn65dsi86: Fix off-by-one error in clock choice (bsc#1152489)
  * refreshed for context changes
- commit fa0e7b9
* Tue Aug 18 2020 tzimmermann@suse.de
- drm/dbi: Fix SPI Type 1 (9-bit) transfer (bsc#1152472)
  * move drm_mipi_dbi.c -> tinydrm/mipi-dbi.c
- commit 7401aea
* Tue Aug 18 2020 msuchanek@suse.de
- powerpc: Fix P10 PVR revision in /proc/cpuinfo for SMT4 cores
  (jsc#SLE-13521).
- commit 1807c9f
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: fix lost i_size update after cloning inline extent
  (bsc#1175377).
- commit c827d4a
* Mon Aug 17 2020 fdmanana@suse.com
- Btrfs: avoid unnecessary splits when setting bits on an extent
  io tree (bsc#1175377).
- commit 2f40ee4
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: delete the ordered isize update code (bsc#1175377).
- commit cd0b66c
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: replace all uses of btrfs_ordered_update_i_size
  (bsc#1175377).
- Refresh
  patches.suse/0004-btrfs-change-timing-for-qgroup-reserved-space-for-or.patch.
- commit ea0db18
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: don't set path->leave_spinning for truncate
  (bsc#1175377).
- commit d3721b5
* Mon Aug 17 2020 fdmanana@suse.com
- Btrfs: fix deadlock during fast fsync when logging prealloc
  extents beyond eof (bsc#1175377).
- commit dd561f7
* Mon Aug 17 2020 fdmanana@suse.com
- Btrfs: fix race between shrinking truncate and fiemap
  (bsc#1175377).
- commit 09d1d3a
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: Rename btrfs_join_transaction_nolock (bsc#1175377).
- Refresh
  patches.suse/0004-btrfs-change-timing-for-qgroup-reserved-space-for-or.patch.
- Refresh
  patches.suse/btrfs-improve-global-reserve-stealing-logic.patch.
- Refresh
  patches.suse/btrfs-make-btrfs_ordered_extent-naming-consistent-wi.patch.
- commit fb4625a
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: use the file extent tree infrastructure (bsc#1175377).
- Refresh
  patches.suse/0002-btrfs-inode-move-qgroup-reserved-space-release-to-th.patch.
- commit ac53cba
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: introduce per-inode file extent tree (bsc#1175377).
- Refresh
  patches.suse/btrfs-fix-corrupt-log-due-to-concurrent-fsync-of-ino.patch.
- commit add4417
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: use btrfs_ordered_update_i_size in
  clone_finish_inode_update (bsc#1175377).
- commit 266b2b3
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: move extent_io_tree defs to their own header
  (bsc#1175377).
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- Refresh
  patches.suse/btrfs-fix-corrupt-log-due-to-concurrent-fsync-of-ino.patch.
- commit 4f0dd59
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: separate out the extent io init function (bsc#1175377).
- commit 82311bf
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: separate out the extent leak code (bsc#1175377).
- commit 210fc6b
* Mon Aug 17 2020 fdmanana@suse.com
- Btrfs: remove unnecessary delalloc mutex for inodes
  (bsc#1175377).
- commit 0e0ed2f
* Mon Aug 17 2020 msuchanek@suse.de
- Delete patches.suse/powerpc-add-link-stack-flush-mitigation-in-debugfs.patch (jsc#SLE-14727).
  To be replaced with upstream bcctr mitigation updates.
- commit 3a0d973
* Mon Aug 17 2020 martin.wilck@suse.com
- scsi: dh: Add Fujitsu device to devinfo and dh lists
  (bsc#1174026).
- commit 64f1b61
* Mon Aug 17 2020 mkoutny@suse.com
- kABI fix for sock_cgroup_data (bsc#1175213 CVE-2020-14356).
- cgroup: Fix sock_cgroup_data on big-endian (bsc#1175213
  CVE-2020-14356).
- cgroup: fix cgroup_sk_alloc() for sk_clone_lock() (bsc#1175213
  CVE-2020-14356).
- commit a3b6e53
* Mon Aug 17 2020 tiwai@suse.de
- firmware_loader: fix memory leak for paged buffer (bsc#1175367).
- commit 8b7305c
* Mon Aug 17 2020 martin.wilck@suse.com
- nvme: add a Identify Namespace Identification Descriptor list
  quirk (git-fixes).
- commit 7a85489
* Mon Aug 17 2020 msuchanek@suse.de
- powerpc/security: Allow for processors that flush the link
  stack using the special bcctr (jsc#SLE-14727).
- powerpc/64s: Move branch cache flushing bcctr variant to
  ppc-ops.h (jsc#SLE-14727).
- powerpc/security: split branch cache flush toggle from code
  patching (jsc#SLE-14727).
- powerpc/security: make display of branch cache flush more
  consistent (jsc#SLE-14727).
- powerpc/security: change link stack flush state to the flush
  type enum (jsc#SLE-14727).
- powerpc/security: re-name count cache flush to branch cache
  flush (jsc#SLE-14727).
- commit 2457b97
* Mon Aug 17 2020 msuchanek@suse.de
- scsi: ipr: remove unneeded semicolon (jsc#SLE-13654).
- scsi: ipr: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-13654).
- scsi: ipr: Fix softlockup when rescanning devices in petitboot
  (jsc#SLE-13654).
- commit 48dc40d
* Mon Aug 17 2020 martin.wilck@suse.com
- nvme: fix a crash in nvme_mpath_add_disk (git-fixes, bsc#1159058).
- commit 9afbddd
* Mon Aug 17 2020 martin.wilck@suse.com
- nvme: fix identify error status silent ignore (git-fixes,
  bsc#1159058).
- commit 1c12147
* Mon Aug 17 2020 mhocko@suse.com
- Refresh patches.suse/mm-fix-protection-usage-propagation.patch.
  add upstream references
- commit 8e0bfa9
* Mon Aug 17 2020 ailiop@suse.com
- xfs: preserve rmapbt swapext block reservation from freed blocks
  (git-fixes).
- commit 86a5ed2
* Mon Aug 17 2020 ailiop@suse.com
- xfs: don't eat an EIO/ENOSPC writeback error when scrubbing
  data fork (git-fixes).
- commit 5f2713c
* Mon Aug 17 2020 ailiop@suse.com
- xfs: fix inode allocation block res calculation precedence
  (git-fixes).
- commit 575ee59
* Mon Aug 17 2020 ailiop@suse.com
- xfs: fix reflink quota reservation accounting error (git-fixes).
- commit 887a853
* Mon Aug 17 2020 mbrugger@suse.com
- arm64: dts: clearfog-gt-8k: set gigabit PHY reset deassert delay
  (bsc#1175347).
- commit 4c9be8d
* Mon Aug 17 2020 mbrugger@suse.com
- arm64: dts: exynos: Fix silent hang after boot on Espresso
  (bsc#1175346).
- arm64: dts: imx8qxp-mek: Remove unexisting Ethernet PHY
  (bsc#1175345).
- arm64: dts: uDPU: fix broken ethernet (bsc#1175344).
- commit ebcb713
* Mon Aug 17 2020 mbrugger@suse.com
- blacklist.conf: arm64: add intel DTS
- commit d0107a6
* Mon Aug 17 2020 mbrugger@suse.com
- blacklist.conf: fix ignored arm64 devicetree folders
- commit 1175c5d
* Mon Aug 17 2020 wqu@suse.com
- btrfs: trim: fix underflow in trim length to prevent access
  beyond device boundary (bsc#1175263).
- btrfs: inode: fix NULL pointer dereference if inode doesn't
  need compression (bsc#1174484).
- btrfs: Move free_pages_out label in inline extent handling
  branch in compress_file_range (bsc#1175263).
- commit 0b38364
* Mon Aug 17 2020 dbueso@suse.de
- locktorture: Print ratio of acquisitions, not failures
  (bsc#1149032).
- commit 7698a26
* Sun Aug 16 2020 bp@suse.de
- x86/resctrl: Fix memory bandwidth counter width for AMD
  (bsc#1172757).
- commit dcea15d
* Sun Aug 16 2020 tiwai@suse.de
- mfd: dln2: Run event handler loop under spinlock (git-fixes).
- mfd: arizona: Ensure 32k clock is put on driver unbind and error
  (git-fixes).
- pwm: bcm-iproc: handle clk_get_rate() return (git-fixes).
- commit a79237e
* Sun Aug 16 2020 bp@suse.de
- x86/split_lock: Enable the split lock feature on Sapphire
  Rapids and Alder Lake CPUs (jsc#SLE-13597).
- x86/cpu: Add Lakefield, Alder Lake and Rocket Lake models to
  the to Intel CPU family (jsc#SLE-13597).
- x86/cpu: Add Sapphire Rapids CPU model number (jsc#SLE-13597).
- commit ffaff8d
* Sun Aug 16 2020 bp@suse.de
- x86/split_lock: Don't write MSR_TEST_CTRL on CPUs that aren't
  whitelisted (jsc#SLE-12677).
- commit 5c09fa6
* Sun Aug 16 2020 bp@suse.de
- x86/split_lock: Add Icelake microserver and Tigerlake CPU models
  (jsc#SLE-12677).
- commit 9f5f8fe
* Sun Aug 16 2020 bp@suse.de
- x86/split_lock: Add Tremont family CPU models (jsc#SLE-12677).
- x86/cpu: Add Jasper Lake to Intel family (jsc#SLE-12677).
- commit 13dbd33
* Sun Aug 16 2020 bp@suse.de
- x86/split_lock: Bits in IA32_CORE_CAPABILITIES are not
  architectural (jsc#SLE-12677).
- commit 5221fb3
* Sun Aug 16 2020 bp@suse.de
- x86/split_lock: Update to use X86_MATCH_INTEL_FAM6_MODEL()
  (jsc#SLE-12677).
- commit 816c882
* Sun Aug 16 2020 bp@suse.de
- x86/cpu: Align cpu_caps_cleared and cpu_caps_set to unsigned
  long (jsc#SLE-12677).
- commit 2d99029
* Sat Aug 15 2020 bp@suse.de
- drivers/net/b44: Change to non-atomic bit operations on
  pwol_mask (jsc#SLE-12677).
- commit c0658d1
* Sat Aug 15 2020 bp@suse.de
- x86/cpu: Align the x86_capability array to size of unsigned long
  (jsc#SLE-12677).
- commit ba83944
* Sat Aug 15 2020 bp@suse.de
- x86/split_lock: Avoid runtime reads of the TEST_CTRL MSR
  (jsc#SLE-12677).
- commit 18d1659
* Sat Aug 15 2020 bp@suse.de
- x86/split_lock: Rework the initialization flow of split lock
  detection (jsc#SLE-12677).
- commit f71b405
* Sat Aug 15 2020 bp@suse.de
- x86/split_lock: Enable split lock detection by kernel
  (jsc#SLE-12677).
- Refresh
  patches.suse/x86-resctrl-query-llc-monitoring-properties-once-during-boot.patch.
- Refresh
  patches.suse/x86-speculation-add-special-register-buffer-data-sampling-srbds-mitigation.patch.
- commit 372670f
* Sat Aug 15 2020 bp@suse.de
- x86/resctrl: Support wider MBM counters (jsc#SLE-13205).
- commit 3a1d478
* Sat Aug 15 2020 bp@suse.de
- x86/resctrl: Support CPUID enumeration of MBM counter width
  (jsc#SLE-13205).
- commit 5142bca
* Sat Aug 15 2020 bp@suse.de
- x86/resctrl: Maintain MBM counter width per resource
  (jsc#SLE-13205).
- commit ea11b84
* Sat Aug 15 2020 bp@suse.de
- x86/resctrl: Query LLC monitoring properties once during boot
  (jsc#SLE-13205).
- commit 6ef2c2f
* Sat Aug 15 2020 bp@suse.de
- x86/resctrl: Remove unnecessary RMID checks (jsc#SLE-13205).
- commit 51d9230
* Sat Aug 15 2020 bp@suse.de
- x86/cpu: Move resctrl CPUID code to resctrl/ (jsc#SLE-13205).
- commit 2a7e1c0
* Sat Aug 15 2020 tiwai@suse.de
- ALSA: echoaudio: Fix potential Oops in snd_echo_resume()
  (git-fixes).
- ALSA: hda/hdmi: Use force connectivity quirk on another HP
  desktop (git-fixes).
- ALSA: hda/realtek - Fix unused variable warning (git-fixes).
- ALSA: hda - reverse the setting value in the micmute_led_set
  (git-fixes).
- ALSA: echoaduio: Drop superfluous volatile modifier (git-fixes).
- ALSA: usb-audio: Disable Lenovo P620 Rear line-in volume control
  (git-fixes).
- ALSA: usb-audio: add quirk for Pioneer DDJ-RB (git-fixes).
- ALSA: usb-audio: work around streaming quirk for MacroSilicon
  MS2109 (git-fixes).
- ALSA: hda - fix the micmute led status for Lenovo ThinkCentre
  AIO (git-fixes).
- ALSA: hda/realtek: Fix pin default on Intel NUC 8 Rugged
  (git-fixes).
- ALSA: usb-audio: Creative USB X-Fi Pro SB1095 volume knob
  support (git-fixes).
- ALSA: usb-audio: fix spelling mistake "buss" -> "bus"
  (git-fixes).
- commit 9eb0560
* Sat Aug 15 2020 tiwai@suse.de
- Re-sort and refresh the upstreamed USB-audio patch
- commit 56623bd
* Sat Aug 15 2020 bp@suse.de
- x86/resctrl: Rename asm/resctrl_sched.h to asm/resctrl.h
  (jsc#SLE-13205).
- commit fef5c1c
* Fri Aug 14 2020 tiwai@suse.de
- r8169: read common register for PCI commit (bsc#1175296).
- commit 33be6a7
* Fri Aug 14 2020 tiwai@suse.de
- r8169: move disabling interrupt coalescing to RTL8169/RTL8168
  init (bsc#1175296).
- commit 150a24b
* Fri Aug 14 2020 tiwai@suse.de
- r8169: fix rtl_hw_jumbo_disable for RTL8168evl (bsc#1175296).
- r8169: fix resume on cable plug-in (bsc#1175296).
- r8169: fix jumbo configuration for RTL8168evl (bsc#1175296).
- r8169: fix jumbo packet handling on resume from suspend
  (bsc#1175296).
- commit 205974e
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: bump version to 1.2.16-010 (bsc#1172418).
- commit c7cf3da
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: add RAID bypass counter (bsc#1172418).
- commit 626afe0
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: support device deletion via sysfs (bsc#1172418).
- commit a628df1
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: avoid crashing kernel for controller issues
  (bsc#1172418).
- commit bfa2645
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: update logical volume size after expansion
  (bsc#1172418).
- commit 2f4b5a4
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: add id support for SmartRAID 3152-8i (bsc#1172418).
- commit 2eeedae
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: Identify physical devices without issuing INQUIRY
  (bsc#1172418).
- commit 34ee136
* Fri Aug 14 2020 shung-hsi.yu@suse.com
- kABI: restore signature of xfrm_policy_bysel_ctx() and
  xfrm_policy_byid() (bsc#1174645).
- xfrm: policy: match with both mark and mask on user interfaces
  (bsc#1174645).
- commit b412835
* Fri Aug 14 2020 martin.wilck@suse.com
- block: Fix the type of 'sts' in bsg_queue_rq() (git-fixes).
- commit 1ab9963
* Fri Aug 14 2020 msuchanek@suse.de
- powerpc/nvdimm: use H_SCM_QUERY hcall on H_OVERLAP error
  (bsc#1175284).
- powerpc/nvdimm: Use HCALL error as the return value
  (bsc#1175284).
- commit 619bc4d
* Fri Aug 14 2020 tiwai@suse.de
- net: phy: fix memory leak in device-create error path
  (git-fixes).
- i2c: iproc: fix race between client unreg and isr (git-fixes).
- i2c: rcar: avoid race when unregistering slave (git-fixes).
- i2c: rcar: slave: only send STOP event when we have been
  addressed (git-fixes).
- net: phy: Check harder for errors in get_phy_id() (git-fixes).
- commit a5bf009
* Fri Aug 14 2020 jslaby@suse.cz
- Update patches.suse/PCI-Program-MPS-for-RCiEP-devices.patch
  (git-fixes jsc#SLE-12860).
  Add jsc reference.
- commit 0152307
* Thu Aug 13 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/clk-bcm2835-do-not-use-prediv-with-bcm2711-s-plls.patch
- commit f0a312b
* Thu Aug 13 2020 jslaby@suse.cz
- x86/cpu: Add Elkhart Lake to Intel family (jsc#SLE-12700).
- commit 30f1f10
* Thu Aug 13 2020 jslaby@suse.cz
- platform/x86: intel_pmc_core: Add Intel Elkhart Lake support
  (jsc#SLE-12700).
- Refresh
  patches.suse/platform-x86-convert-to-new-cpu-match-macros.patch.
- platform/x86: intel_pmc_core: Make debugfs entry for
  pch_ip_power_gating_status conditional (jsc#SLE-12700).
- platform/x86: intel_pmc_core: Clean up: Remove comma after
  the termination line (jsc#SLE-12700).
- Refresh
  patches.suse/platform-x86-intel_pmc_core-Create-platform-dependen.patch.
- commit bb5c02e
* Thu Aug 13 2020 tiwai@suse.de
- clk: at91: sckc: register slow_rc with accuracy option
  (git-fixes).
- clk: at91: sam9x60: fix main rc oscillator frequency
  (git-fixes).
- clk: at91: sam9x60-pll: check fcore against ranges (git-fixes).
- clk: at91: sam9x60-pll: use logical or for range check
  (git-fixes).
- clk: at91: clk-generated: check best_rate against ranges
  (git-fixes).
- clk: at91: clk-generated: continue if __clk_determine_rate()
  returns error (git-fixes).
- clk: clk-atlas6: fix return value check in atlas6_clk_init()
  (git-fixes).
- clk: iproc: round clock rate to the closest (git-fixes).
- clk: rockchip: Revert "fix wrong mmc sample phase shift for
  rk3328" (git-fixes).
- clk: actions: Fix h_clk for Actions S500 SoC (git-fixes).
- clk: qcom: gcc-sdm660: Fix up gcc_mss_mnoc_bimc_axi_clk
  (git-fixes).
- clk: qcom: gcc-sdm660: Add missing modem reset (git-fixes).
- watchdog: initialize device before misc_register (git-fixes).
- watchdog: f71808e_wdt: clear watchdog timeout occurred flag
  (git-fixes).
- watchdog: f71808e_wdt: remove use of wrong watchdog_info option
  (git-fixes).
- watchdog: f71808e_wdt: indicate WDIOF_CARDRESET support in
  watchdog_info.options (git-fixes).
- drm/vmwgfx: Fix two list_for_each loop exit tests (git-fixes).
- drm/vmwgfx: Use correct vmw_legacy_display_unit pointer
  (git-fixes).
- drm: fix drm_dp_mst_port refcount leaks in
  drm_dp_mst_allocate_vcpi (git-fixes).
- kernel.h: remove duplicate include of asm/div64.h (git-fixes).
- platform/chrome: cros_ec_ishtp: Fix a double-unlock issue
  (git-fixes).
- remoteproc: qcom: q6v5: Update running state before requesting
  stop (git-fixes).
- remoteproc: qcom_q6v5_mss: Validate modem blob firmware size
  before load (git-fixes).
- remoteproc: qcom_q6v5_mss: Validate MBA firmware size before
  load (git-fixes).
- Input: sentelic - fix error return when fsp_reg_write fails
  (git-fixes).
- drm/i915/gt: Unlock engine-pm after queuing the kernel context
  switch (git-fixes).
- drm/i915/gt: Close race between engine_park and
  intel_gt_retire_requests (git-fixes).
- drm/i915/gt: Move new timelines to the end of active_list
  (git-fixes).
- commit 760f8de
* Thu Aug 13 2020 msuchanek@suse.de
- powerpc/dt_cpu_ftrs: Add MMA feature (jsc#SLE-13521).
- commit 4b102b3
* Thu Aug 13 2020 msuchanek@suse.de
- compiler_attributes.h: Add 'fallthrough' pseudo keyword for
  switch/case use (jsc#SLE-13847).
- commit 881e310
* Thu Aug 13 2020 msuchanek@suse.de
- net: sctp: Rename fallthrough label to unhandled
  (jsc#SLE-13847).
- commit 9db514c
* Thu Aug 13 2020 msuchanek@suse.de
- powerpc/kvm: Fix kvmppc_vcore->in_guest value in
  kvmhv_switch_to_host (jsc#SLE-13521).
- commit 6e044ae
* Thu Aug 13 2020 msuchanek@suse.de
- powerpc/watchpoint: Add SPRN macros for second DAWR
  (jsc#SLE-12936).
- commit 402a5c1
* Thu Aug 13 2020 msuchanek@suse.de
- powerpc/dt_cpu_ftrs: Advertise support for ISA v3.1 if selected
  (jsc#SLE-13521).
- powerpc: Add new HWCAP bits (jsc#SLE-13521).
- commit a311da7
* Thu Aug 13 2020 mbrugger@suse.com
- irqchip/gic: Atomically update affinity (bsc#1175195).
- commit 5ad8b58
* Thu Aug 13 2020 msuchanek@suse.de
- powerpc/watchpoint: Remove 512 byte boundary (jsc#SLE-12936).
- powerpc/watchpoint: Return available watchpoints dynamically
  (jsc#SLE-12936).
- powerpc/watchpoint: Guest support for 2nd DAWR hcall
  (jsc#SLE-12936).
- powerpc/watchpoint: Rename current H_SET_MODE DAWR macro
  (jsc#SLE-12936).
- powerpc/watchpoint: Set CPU_FTR_DAWR1 based on pa-features bit
  (jsc#SLE-12936).
- powerpc/dt_cpu_ftrs: Add feature for 2nd DAWR (jsc#SLE-12936).
- powerpc/watchpoint: Enable watchpoint functionality on power10
  guest (jsc#SLE-12936).
- powerpc/watchpoint: Fix DAWR exception for CACHEOP
  (jsc#SLE-12936).
- powerpc/watchpoint: Fix DAWR exception constraint
  (jsc#SLE-12936).
- powerpc/watchpoint: Fix 512 byte boundary limit (jsc#SLE-12936).
- powerpc: Add POWER10 architected mode (jsc#SLE-13521).
- powerpc/dt_cpu_ftrs: Enable Prefixed Instructions
  (jsc#SLE-13847).
- powerpc: Add support for ISA v3.1 (jsc#SLE-13521).
- powerpc/64s: Don't init FSCR_DSCR in __init_FSCR()
  (jsc#SLE-13521).
- powerpc: Add ppc_inst_as_u64() (jsc#SLE-13847).
- powerpc: Add ppc_inst_next() (jsc#SLE-13847).
- powerpc/watchpoint: Prepare handler to handle more than one
  watchpoint (jsc#SLE-12936).
- powerpc/watchpoint: Use builtin ALIGN*() macros (jsc#SLE-12936).
- powerpc/watchpoint: Introduce is_ptrace_bp() function
  (jsc#SLE-12936).
- powerpc/watchpoint: Convert thread_struct->hw_brk to an array
  (jsc#SLE-12936).
- powerpc/watchpoint: Provide DAWR number to __set_breakpoint
  (jsc#SLE-12936).
- powerpc/watchpoint: Provide DAWR number to set_dawr
  (jsc#SLE-12936).
- powerpc/watchpoint: Introduce function to get nr watchpoints
  dynamically (jsc#SLE-12936).
- powerpc/watchpoint: Rename current DAWR macros (jsc#SLE-12936).
- powerpc sstep: Add support for prefixed fixed-point arithmetic
  (jsc#SLE-13847).
- powerpc sstep: Add support for prefixed load/stores
  (jsc#SLE-13847).
- powerpc: Support prefixed instructions in alignment handler
  (jsc#SLE-13847).
- powerpc/kprobes: Don't allow breakpoints on suffixes
  (jsc#SLE-13847).
- powerpc/xmon: Don't allow breakpoints on suffixes
  (jsc#SLE-13847).
- powerpc: Test prefixed instructions in feature fixups
  (jsc#SLE-13847).
- powerpc: Test prefixed code patching (jsc#SLE-13847).
- powerpc: Add prefixed instructions to instruction data type
  (jsc#SLE-13847).
- powerpc/optprobes: Add register argument to
  patch_imm64_load_insns() (jsc#SLE-13847).
- powerpc: Define new SRR1 bits for a ISA v3.1 (jsc#SLE-13847).
- powerpc: Enable Prefixed Instructions (jsc#SLE-13847).
- powerpc: Make test_translate_branch() independent of instruction
  length (jsc#SLE-13847).
- powerpc/xmon: Move insertion of breakpoint for xol'ing
  (jsc#SLE-13847).
- powerpc/xmon: Use a function for reading instructions
  (jsc#SLE-13847).
- powerpc: Introduce a function for reporting instruction length
  (jsc#SLE-13847).
- powerpc: Define and use get_user_instr() et. al (jsc#SLE-13847).
- powerpc/kprobes: Use patch_instruction() (jsc#SLE-13847).
- powerpc: Add a probe_kernel_read_inst() function
  (jsc#SLE-13847).
- powerpc: Add a probe_user_read_inst() function (jsc#SLE-13847).
- powerpc: Use a function for reading instructions
  (jsc#SLE-13847).
- powerpc: Use a datatype for instructions (jsc#SLE-13847).
- powerpc: Introduce functions for instruction equality
  (jsc#SLE-13847).
- powerpc: Use a function for byte swapping instructions
  (jsc#SLE-13847).
- powerpc: Use a function for getting the instruction op code
  (jsc#SLE-13847).
- powerpc: Use an accessor for instructions (jsc#SLE-13847).
- powerpc: Use a macro for creating instructions from u32s
  (jsc#SLE-13847).
- powerpc: Change calling convention for create_branch() et. al
  (jsc#SLE-13847).
- powerpc/xmon: Use bitwise calculations in_breakpoint_table()
  (jsc#SLE-13847).
- powerpc/xmon: Move breakpoints to text section (jsc#SLE-13847).
- powerpc/xmon: Move breakpoint instructions to own array
  (jsc#SLE-13847).
- powerpc/xmon: Remove store_inst() for patch_instruction()
  (jsc#SLE-13847).
- powerpc/ptrace: move ptrace_triggered() into hw_breakpoint.c
  (jsc#SLE-12936 jsc#SLE-13847).
- powerpc/ptrace: create ppc_gethwdinfo() (jsc#SLE-12936
  jsc#SLE-13847).
- powerpc/ptrace: create ptrace_get_debugreg() (jsc#SLE-12936
  jsc#SLE-13847).
- powerpc/ptrace: split out ADV_DEBUG_REGS related functions
  (jsc#SLE-12936 jsc#SLE-13847).
- powerpc/ptrace: move register viewing functions out of ptrace.c
  (jsc#SLE-12936 jsc#SLE-13847).
- powerpc/ptrace: split out TRANSACTIONAL_MEM related functions
  (jsc#SLE-12936 jsc#SLE-13847).
- powerpc/ptrace: split out SPE related functions (jsc#SLE-12936
  jsc#SLE-13847).
- powerpc/ptrace: split out ALTIVEC related functions
  (jsc#SLE-12936 jsc#SLE-13847).
- powerpc/ptrace: split out VSX related functions (jsc#SLE-12936
  jsc#SLE-13847).
- powerpc/ptrace: drop PARAMETER_SAVE_AREA_OFFSET (jsc#SLE-12936
  jsc#SLE-13847).
- powerpc/ptrace: drop unnecessary #ifdefs CONFIG_PPC64
  (jsc#SLE-12936 jsc#SLE-13847).
- powerpc/ptrace: remove unused header includes (jsc#SLE-12936
  jsc#SLE-13847).
- powerpc: Move ptrace into a subdirectory (jsc#SLE-12936
  jsc#SLE-13847).
- powerpc/watchpoint: Don't call dar_within_range() for Book3S
  (jsc#SLE-12936).
- powerpc/8xx: Use alternative scratch registers in DTLB miss
  handler (jsc#SLE-12936).
- powerpc: use probe_user_read() and probe_user_write()
  (jsc#SLE-12936).
- powerpc/hw_breakpoints: Rewrite 8xx breakpoints to allow any
  address range size (jsc#SLE-12936).
- powerpc: permanently include 8xx registers in reg.h
  (jsc#SLE-12936).
- powerpc/watchpoint: Don't ignore extraneous exceptions blindly
  (jsc#SLE-12936).
- powerpc/watchpoint: Fix ptrace code that muck around with
  address/len (jsc#SLE-12936).
- powerpc/watchpoint: Fix length calculation for unaligned target
  (jsc#SLE-12936).
- powerpc/watchpoint: Introduce macros for watchpoint length
  (jsc#SLE-12936).
- powerpc: Add build-time check of ptrace PT_xx defines
  (jsc#SLE-12936).
- powerpc/ptrace: Add prototype for function pt_regs_check
  (jsc#SLE-12936 jsc#SLE-13847).
- KVM: PPC: Book3S: Define and use SRR1_MSR_BITS (jsc#SLE-13521).
- powerpc/64s: Set reserved PCR bits (jsc#SLE-13521).
- powerpc: Fix definition of PCR bits to work with old binutils
  (jsc#SLE-13521).
- powerpc/watchpoint: Disable watchpoint hit by larx/stcx
  instructions (jsc#SLE-12936).
- powerpc/hw_breakpoint: move instruction stepping out of
  hw_breakpoint_handler() (jsc#SLE-12936).
- commit e00d912
* Thu Aug 13 2020 jlee@suse.com
- integrity: Check properly whether EFI GetVariable() is available
  (bsc#1174029, bsc#1174110, bsc#1174111).
- Refresh
  patches.suse/0003-MODSIGN-load-blacklist-from-MOKx.patch.
- commit 3c8f305
* Thu Aug 13 2020 jlee@suse.com
- x86/ima: Use EFI GetVariable only when available (bsc#1174029,
  bsc#1174110, bsc#1174111).
- commit bc28a75
* Thu Aug 13 2020 jlee@suse.com
- efi: Use EFI ResetSystem only when available (bsc#1174029,
  bsc#1174110, bsc#1174111).
- commit ff49d51
* Thu Aug 13 2020 jlee@suse.com
- scsi: iscsi: Use EFI GetVariable only when available
  (bsc#1174029, bsc#1174110, bsc#1174111).
- commit 4afad03
* Wed Aug 12 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/btrfs-Remove-delalloc_end-argument-from-extent_clear.patch
  patches.suse/btrfs-Remove-leftover-of-in-band-dedupe.patch
  patches.suse/btrfs-fix-a-block-group-ref-counter-leak-after-failu.patch
  patches.suse/btrfs-fix-block-group-leak-when-removing-fails.patch
  patches.suse/btrfs-fix-bytes_may_use-underflow-when-running-balan.patch
  patches.suse/btrfs-fix-corrupt-log-due-to-concurrent-fsync-of-ino.patch
  patches.suse/btrfs-fix-data-block-group-relocation-failure-due-to.patch
  patches.suse/btrfs-fix-double-free-on-ulist-after-backref-resolut.patch
  patches.suse/btrfs-fix-fatal-extent_buffer-readahead-vs-releasepa.patch
  patches.suse/btrfs-fix-page-leaks-after-failure-to-lock-page-for-.patch
  patches.suse/btrfs-fix-race-between-block-group-removal-and-block.patch
  patches.suse/btrfs-fix-space_info-bytes_may_use-underflow-after-n.patch
  patches.suse/btrfs-fix-space_info-bytes_may_use-underflow-during-.patch
  patches.suse/btrfs-fix-wrong-file-range-cleanup-after-an-error-fi.patch
- commit d629da8
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix page leaks after failure to lock page for delalloc
  (bsc#1175149).
- commit 11c5046
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix double free on ulist after backref resolution failure
  (bsc#1175149).
- commit e175c08
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix fatal extent_buffer readahead vs releasepage race
  (bsc#1175149).
- commit 6894e62
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix bytes_may_use underflow when running balance and
  scrub in parallel (bsc#1175149).
- commit 3c1d24d
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix data block group relocation failure due to concurrent
  scrub (bsc#1175149).
- commit e7dccf4
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix race between block group removal and block group
  creation (bsc#1175149).
- commit 22ed64a
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix a block group ref counter leak after failure to
  remove block group (bsc#1175149).
- commit 5c3ef7d
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix block group leak when removing fails (bsc#1175149).
- commit 03037b8
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix space_info bytes_may_use underflow during space
  cache writeout (bsc#1175149).
- commit 9586d9c
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix space_info bytes_may_use underflow after nocow
  buffered write (bsc#1175149).
- commit 457cc33
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix wrong file range cleanup after an error filling
  dealloc range (bsc#1175149).
- commit e7b219b
* Wed Aug 12 2020 mbrugger@suse.com
- arm64: csum: Fix handling of bad packets (bsc#1175192).
- arm64: kgdb: Fix single-step exception handling oops
  (bsc#1175191).
- KVM: arm64: Annotate hyp NMI-related functions as
  __always_inline (bsc#1175190).
- arm64: hw_breakpoint: Don't invoke overflow handler on uaccess
  watchpoints (bsc#1175189).
- arm64: cacheflush: Fix KGDB trap detection (bsc#1175188).
- arm64: kexec_file: print appropriate variable (bsc#1175187).
- arm64: insn: Fix two bugs in encoding 32-bit logical immediates
  (bsc#1175186).
- arm64: Fix PTRACE_SYSEMU semantics (bsc#1175185).
- arm64: fix the flush_icache_range arguments in machine_kexec
  (bsc#1175184).
- arm64: hugetlb: avoid potential NULL dereference (bsc#1175183).
- arm64: vdso: Add -fasynchronous-unwind-tables to cflags
  (bsc#1175182).
- arm64: vdso: don't free unallocated pages (bsc#1175181).
- arm64: armv8_deprecated: Fix undef_hook mask for thumb setend
  (bsc#1175180).
- commit 5e20125
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: Remove leftover of in-band dedupe (bsc#1175149).
- refresh patches.suse/btrfs-move-basic-block_group-definitions-to-their-own-header.patch
- commit f3a05f0
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: Remove delalloc_end argument from
  extent_clear_unlock_delalloc (bsc#1175149).
- commit 24d05e3
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix corrupt log due to concurrent fsync of inodes with
  shared extents (bsc#1175149).
- commit af1520b
* Wed Aug 12 2020 mbrugger@suse.com
- blacklist: ignore Spreadtrum clk fix with wrong SHA
- commit 418cf06
* Wed Aug 12 2020 lhenriques@suse.de
- fuse: Fix parameter for FS_IOC_{GET,SET}FLAGS (bsc#1175176).
- fuse: fix weird page warning (bsc#1175175).
- commit ec519b8
* Wed Aug 12 2020 msuchanek@suse.de
- ibmveth: Fix use of ibmveth in a bridge (bsc#1174387
  ltc#187506).
- commit 60cd53b
* Wed Aug 12 2020 msuchanek@suse.de
- genirq/affinity: Remove const qualifier from node_to_cpumask
  argument (bsc#1174897 ltc#187090).
- genirq/affinity: Spread vectors on node according to nr_cpu
  ratio (bsc#1174897 ltc#187090).
- genirq/affinity: Improve __irq_build_affinity_masks()
  (bsc#1174897 ltc#187090).
- commit 5d5f43f
* Wed Aug 12 2020 glin@suse.com
- bpfilter: reject kernel addresses (bsc#1155518).
- net/bpfilter: split __bpfilter_process_sockopt (bsc#1155518).
- bpfilter: fix up a sparse annotation (bsc#1155518).
- bpfilter: Initialize pos variable (bsc#1155518).
- net/bpfilter: Initialize pos in __bpfilter_process_sockopt
  (bsc#1155518).
- bpfilter: switch to kernel_write (bsc#1155518).
- commit 00f0f2f
* Wed Aug 12 2020 duwe@suse.de
- rpm/modules.fips:
  * add ecdh_generic (boo#1173813)
- commit 5b147f9
* Wed Aug 12 2020 tiwai@suse.de
- media: omap3isp: Add missed v4l2_ctrl_handler_free() for
  preview_init_entities() (git-fixes).
- staging: rtl8712: handle firmware load failure (git-fixes).
- Bluetooth: Prevent out-of-bounds read in
  hci_inquiry_result_with_rssi_evt() (git-fixes).
- Bluetooth: Prevent out-of-bounds read in
  hci_inquiry_result_evt() (git-fixes).
- Bluetooth: Fix slab-out-of-bounds read in
  hci_extended_inquiry_result_evt() (git-fixes).
- usb: xhci: Fix ASMedia ASM1142 DMA addressing (git-fixes).
- usb: xhci: define IDs for various ASMedia host controllers
  (git-fixes).
- USB: serial: qcserial: add EM7305 QDL product ID (git-fixes).
- mtd: properly check all write ioctls for permissions
  (git-fixes).
- cfg80211: check vendor command doit pointer before use
  (git-fixes).
- atm: fix atm_dev refcnt leaks in atmtcp_remove_persistent
  (git-fixes).
- net: lan78xx: replace bogus endpoint lookup (git-fixes).
- usb: hso: check for return value in hso_serial_common_create()
  (git-fixes).
- i2c: slave: add sanity check when unregistering (git-fixes).
- i2c: slave: improve sanity check when registering (git-fixes).
- firmware: Fix a reference count leak (git-fixes).
- drm/nouveau/fbcon: zero-initialise the mode_cmd2 structure
  (git-fixes).
- drm/nouveau/fbcon: fix module unload when fbcon init has failed
  for some reason (git-fixes).
- AX.25: Prevent integer overflows in connect and sendmsg
  (git-fixes).
- AX.25: Prevent out-of-bounds read in ax25_sendmsg() (git-fixes).
- AX.25: Fix out-of-bounds read in ax25_connect() (git-fixes).
- commit 01f7466
* Wed Aug 12 2020 jlee@suse.com
- infiniband: hfi1: Use EFI GetVariable only when available
  (bsc#1174029, bsc#1174110, bsc#1174111).
- commit 5f092e5
* Wed Aug 12 2020 jslaby@suse.cz
- vgacon: Fix for missing check in scrollback handling
  (bsc#1174205 CVE-2020-14331).
  Update upstream status.
- commit e6ac692
* Tue Aug 11 2020 ykaukab@suse.de
- soc/tegra: pmc: Enable PMIC wake event on Tegra210
  (bsc#1175116).
- commit af9a16c
* Tue Aug 11 2020 msuchanek@suse.de
- powerpc/pseries/hotplug-cpu: Remove double free in error path
  (bsc#1065729).
- powerpc/boot: Fix CONFIG_PPC_MPC52XX references (bsc#1065729).
- powerpc: Allow 4224 bytes of stack expansion for the signal
  frame (bsc#1065729).
- powerpc/book3s64/pkeys: Use PVR check instead of cpu feature
  (bsc#1065729).
- powerpc/vdso: Fix vdso cpu truncation (bsc#1065729).
- powerpc/rtas: don't online CPUs for partition suspend
  (bsc#1065729).
- powerpc/pseries: remove cede offline state for CPUs
  (bsc#1065729).
- ibmvnic: Fix IRQ mapping disposal in error path (bsc#1175112
  ltc#187459).
- powerpc/64s: Fix early_init_mmu section mismatch (bsc#1065729).
- commit 59a966b
* Tue Aug 11 2020 jlee@suse.com
- efi: Register EFI rtc platform device only when available
  (bsc#1174029, bsc#1174110, bsc#1174111).
- commit 7ac188a
* Tue Aug 11 2020 jslaby@suse.cz
- PCI/AER: Fix the broken interrupt injection (jsc#SLE-13222).
- blacklist.conf: remove it, we have the prerequisity now
- Update config files.
  GENERIC_IRQ_INJECTION gets autoselected.
- genirq: Provide interrupt injection mechanism (jsc#SLE-13222).
- genirq: Sanitize state handling in check_irq_resend()
  (jsc#SLE-13222).
- genirq: Add return value to check_irq_resend() (jsc#SLE-13222).
- x86/apic/vector: Force interupt handler invocation to irq
  context (jsc#SLE-13222).
- genirq: Add protection against unsafe usage of
  generic_handle_irq() (jsc#SLE-13222).
- genirq/debugfs: Add missing sanity checks to interrupt injection
  (jsc#SLE-13222).
- commit cb839fb
* Tue Aug 11 2020 jslaby@suse.cz
- platform/x86: intel_pmc_core: Add an additional parameter to
  pmc_core_lpm_display() (jsc#SLE-12699).
- commit f319609
* Tue Aug 11 2020 jslaby@suse.cz
- platform/x86: intel_pmc_core: Add Intel Tiger Lake support
  (jsc#SLE-12599).
- Refresh
  patches.suse/platform-x86-convert-to-new-cpu-match-macros.patch.
- platform/x86: intel_pmc_core: Create platform dependent bitmap
  structs (jsc#SLE-12599).
- commit 4bbece2
* Tue Aug 11 2020 jlee@suse.com
- efi: Use more granular check for availability for variable
  services (bsc#1174029, bsc#1174110, bsc#1174111).
- commit 90067a7
* Tue Aug 11 2020 jslaby@suse.cz
- platform/x86: intel_pmc_core: Add debugfs entry for low power
  mode status registers (jsc#SLE-12699).
- commit 4b79939
* Tue Aug 11 2020 jslaby@suse.cz
- platform/x86: intel_pmc_core: Dump low power status registers
  on an S0ix.y failure (jsc#SLE-12699).
- platform/x86: intel_pmc_core: Remove slp_s0 attributes from
  tgl_reg_map (jsc#SLE-12699).
- platform/x86: intel_pmc_core: Refactor the driver by removing
  redundant code (jsc#SLE-12699).
- commit e23c42f
* Tue Aug 11 2020 jslaby@suse.cz
- blacklist.conf: add sparse warning fixes
- commit 301555e
* Tue Aug 11 2020 jslaby@suse.cz
- PCI: rcar: Fix runtime PM imbalance on error (git-fixes).
- PCI: cadence: Fix updating Vendor ID and Subsystem Vendor ID
  register (git-fixes).
- commit 272b523
* Tue Aug 11 2020 jslaby@suse.cz
- arm64: dts: qcom: msm8998-clamshell: Fix label on l15 regulator
  (git-fixes).
- commit 8896400
* Tue Aug 11 2020 jlee@suse.com
- efi: Add support for EFI_RT_PROPERTIES table (bsc#1174029,
  bsc#1174110, bsc#1174111).
- commit 4e5fc8c
* Tue Aug 11 2020 jlee@suse.com
- efi: Store mask of supported runtime services in struct efi
  (bsc#1174029, bsc#1174110, bsc#1174111).
- Refresh
  patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch.
- commit 738249f
* Mon Aug 10 2020 msuchanek@suse.de
- powerpc/kexec_file: Enable early kernel OPAL calls
  (jsc#SLE-13848 bsc#1174914).
- powerpc/kexec_file: Fix kexec load failure with lack of memory
  hole (jsc#SLE-13848 bsc#1174914).
- powerpc/kexec_file: Add appropriate regions for memory reserve
  map (jsc#SLE-13848 bsc#1174914).
- powerpc/kexec_file: Prepare elfcore header for crashing kernel
  (jsc#SLE-13848 bsc#1174914).
- powerpc/kexec_file: Setup backup region for kdump kernel
  (jsc#SLE-13848 bsc#1174914).
- powerpc/kexec_file: Restrict memory usage of kdump kernel
  (jsc#SLE-13848 bsc#1174914).
- powerpc/drmem: Make LMB walk a bit more flexible (jsc#SLE-13848
  bsc#1174914).
- powerpc/kexec_file: Avoid stomping memory used by special
  regions (jsc#SLE-13848 bsc#1174914).
- powerpc/kexec_file: Add helper functions for getting memory
  ranges (jsc#SLE-13848 bsc#1174914).
- powerpc/kexec_file: Mark PPC64 specific code (jsc#SLE-13848
  bsc#1174914).
- kexec_file: Allow archs to handle special regions while locating
  memory hole (jsc#SLE-13848 bsc#1174914).
- kexec: restore arch_kexec_kernel_image_probe declaration
  (jsc#SLE-13848 bsc#1174914).
- commit ef98bc7
* Mon Aug 10 2020 msuchanek@suse.de
- powerpc/mm/pkeys: Make pkey access check work on
  execute_only_key (jsc#SLE-16556 bsc#1078248 FATE#322447).
- Refresh patches.suse/powerpc-book3s64-pkeys-Fix-pkey_access_permitted-for.patch
- commit d15e47c
* Mon Aug 10 2020 tiwai@suse.de
- blacklist.conf: Add inapplicable drm/i915 commit for git-fixes
- commit 89499be
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Drop no-semaphore boosting (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Reorder-await_execution-before-await_reques.patch.
- commit abd8209
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Prevent using semaphores to chain up to external
  fences (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Reorder-await_execution-before-await_reques.patch.
- commit 8cf5766
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Peel dma-fence-chains for await (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Reorder-await_execution-before-await_reques.patch.
- commit 1951d28
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Pull waiting on an external dma-fence into its routine
  (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Reorder-await_execution-before-await_reques.patch.
- commit b2bfc63
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Ignore submit-fences on the same timeline
  (bsc#1174737).
- commit fae2bcb
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Rely on direct submission to the queue (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Remove-wait-priority-boosting.patch.
- commit a8208d8
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Remove wait priority boosting (bsc#1174737).
- commit 0fea26e
* Mon Aug 10 2020 tiwai@suse.de
- pinctrl: ingenic: Enhance support for IRQ_TYPE_EDGE_BOTH
  (git-fixes).
- pinctrl: single: fix function name in documentation (git-fixes).
- pinctrl-single: fix pcs_parse_pinconf() return value
  (git-fixes).
- mtd: rawnand: qcom: avoid write to unavailable register
  (git-fixes).
- mtd: rawnand: fsl_upm: Remove unused mtd var (git-fixes).
- power: supply: check if calc_soc succeeded in
  pm860x_init_battery (git-fixes).
- PCI: tegra: Revert tegra124 raw_violation_fixup (git-fixes).
- PCI: qcom: Add support for tx term offset for rev 2.1.0
  (git-fixes).
- PCI: qcom: Define some PARF params needed for ipq8064 SoC
  (git-fixes).
- PCI: qcom: Add missing reset for ipq806x (git-fixes).
- PCI: qcom: Add missing ipq806x clocks in PCIe driver
  (git-fixes).
- PCI: switchtec: Add missing __iomem tag to fix sparse warnings
  (git-fixes).
- PCI: switchtec: Add missing __iomem and __user tags to fix
  sparse warnings (git-fixes).
- PCI: Release IVRS table in AMD ACS quirk (git-fixes).
- PCI: Fix pci_cfg_wait queue locking problem (git-fixes).
- PCI/ASPM: Add missing newline in sysfs 'policy' (git-fixes).
- clk: bcm63xx-gate: fix last clock availability (git-fixes).
- go7007: add sanity checking for endpoints (git-fixes).
- media: exynos4-is: Add missed check for pinctrl_lookup_state()
  (git-fixes).
- media: nuvoton-cir: remove setting tx carrier functions
  (git-fixes).
- media: vsp1: dl: Fix NULL pointer dereference on unbind
  (git-fixes).
- media: firewire: Using uninitialized values in node_probe()
  (git-fixes).
- media: media-request: Fix crash if memory allocation fails
  (git-fixes).
- media: marvell-ccic: Add missed v4l2_async_notifier_cleanup()
  (git-fixes).
- media: cxusb-analog: fix V4L2 dependency (git-fixes).
- iio: improve IIO_CONCENTRATION channel type description
  (git-fixes).
- staging: vchiq_arm: Add a matching unregister call (git-fixes).
- integrity: remove redundant initialization of variable ret
  (git-fixes).
- omapfb: dss: Fix max fclk divider for omap36xx (git-fixes).
- media: sur40: Remove uninitialized_var() usage (git-fixes).
- clk: spear: Remove uninitialized_var() usage (git-fixes).
- clk: st: Remove uninitialized_var() usage (git-fixes).
- ide: Remove uninitialized_var() usage (git-fixes).
- rtlwifi: rtl8192cu: Remove uninitialized_var() usage
  (git-fixes).
- drbd: Remove uninitialized_var() usage (git-fixes).
- random32: move the pseudo-random 32-bit definitions to prandom.h
  (git-fixes).
- PCI: hotplug: ACPI: Fix context refcounting in
  acpiphp_grab_context() (git-fixes).
- random32: remove net_rand_state from the latent entropy gcc
  plugin (git-fixes).
- commit 5480d4c
* Mon Aug 10 2020 msuchanek@suse.de
- powerpc/pseries: Update hv-24x7 information after migration
  (jsc#SLE-13661).
- Refresh patches.suse/powerpc-pseries-mobility-notify-network-peers-after-.patch
- Documentation/ABI: Add ABI documentation for chips and sockets
  (jsc#SLE-13661).
- powerpc/hv-24x7: Add sysfs files inside hv-24x7 device to show
  processor details (jsc#SLE-13661).
- powerpc/hv-24x7: Add rtas call in hv-24x7 driver to get
  processor details (jsc#SLE-13661).
- powerpc/perf/hv-24x7: Fix inconsistent output values incase
  multiple hv-24x7 events run (jsc#SLE-13661).
- commit 2eeacd0
* Mon Aug 10 2020 msuchanek@suse.de
- powerpc/papr_scm: Add support for fetching nvdimm 'fuel-gauge'
  metric (bsc#1175052 jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- powerpc/papr_scm: Fetch nvdimm performance stats from PHYP
  (bsc#1175052 jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- powerpc/papr_scm: Implement support for PAPR_PDSM_HEALTH
  (bsc#1175052 jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- ndctl/papr_scm,uapi: Add support for PAPR nvdimm specific
  methods (bsc#1175052 jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- powerpc/papr_scm: Improve error logging and handling
  papr_scm_ndctl() (bsc#1175052 jsc#SLE-13823 bsc#1174969
  jsc#SLE-12769).
- powerpc/papr_scm: Fetch nvdimm health information from PHYP
  (bsc#1175052 jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- seq_buf: Export seq_buf_printf (bsc#1175052 jsc#SLE-13823
  bsc#1174969 jsc#SLE-12769).
- powerpc: Document details on H_SCM_HEALTH hcall (bsc#1175052
  jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- powerpc/papr_scm: Mark papr_scm_ndctl() as static (bsc#1175052
  jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- commit 83564d9
* Mon Aug 10 2020 tiwai@suse.de
- ALSA: usb-audio: fix overeager device match for MacroSilicon
  MS2109 (bsc#1174625).
- commit 2c2144c
* Mon Aug 10 2020 ghe@suse.com
- ocfs2: fix remounting needed after setfacl command
  (bsc#1173954).
- commit 5e09cdc
* Sun Aug  9 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/powerpc-fadump-fix-race-between-pstore-write-and-fad.patch
  patches.suse/powerpc-pseries-PCIE-PHB-reset.patch
  patches.suse/powerpc-xmon-Reset-RCU-and-soft-lockup-watchdogs.patch
- commit fe82dc0
* Sun Aug  9 2020 mkubecek@suse.cz
- fix patch metadata
- fix confusing References tags:
  patches.suse/arm64-dts-allwinner-a64-Remove-unused-SPDIF-sound-ca.patch
  patches.suse/arm64-dts-imx8mm-evk-correct-ldo1-ldo2-voltage-range.patch
  patches.suse/arm64-dts-librem5-devkit-add-a-vbus-supply-to-usb0.patch
  patches.suse/arm64-dts-ls1028a-delete-extraneous-interrupt-cells-.patch
  patches.suse/arm64-dts-rockchip-Rename-dwc3-device-nodes-on-rk339.patch
  patches.suse/arm64-dts-rockchip-Replace-RK805-PMIC-node-name-with.patch
  patches.suse/arm64-dts-rockchip-fix-rk3399-puma-gmac-reset-gpio.patch
  patches.suse/arm64-dts-rockchip-fix-rk3399-puma-vcc5v0-host-gpio.patch
  patches.suse/arm64-dts-uniphier-Set-SCSSI-clock-and-reset-IDs-for.patch
  patches.suse/arm64-tegra-Enable-I2C-controller-for-EEPROM.patch
  patches.suse/arm64-tegra-Fix-Tegra194-PCIe-compatible-string.patch
  patches.suse/arm64-tegra-Fix-ethernet-phy-mode-for-Jetson-Xavier.patch
  patches.suse/arm64-tegra-Fix-flag-for-64-bit-resources-in-ranges-.patch
- commit 176f025
* Fri Aug  7 2020 lyan@suse.com
- KVM: arm64: Select TASK_DELAY_ACCT+TASKSTATS rather than
  SCHEDSTATS (bsc#1172197 jsc#SLE-13593).
- arm64: Retrieve stolen time as paravirtualized guest
  (bsc#1172197 jsc#SLE-13593).
- KVM: arm64: Provide VCPU attributes for stolen time (bsc#1172197
  jsc#SLE-13593).
- KVM: Allow kvm_device_ops to be const (bsc#1172197
  jsc#SLE-13593).
- KVM: arm64: Support stolen time reporting via shared structure
  (bsc#1172197 jsc#SLE-13593).
- KVM: Implement kvm_put_guest() (bsc#1172197 jsc#SLE-13593).
- KVM: arm64: Implement PV_TIME_FEATURES call (bsc#1172197
  jsc#SLE-13593).
  Refresh:
  patches.suse/arm-arm64-provide-a-wrapper-for-smccc-1-1-calls.patch
  patches.suse/firmware-smccc-add-the-definition-for-smcccv1-2-version-error-codes.patch
- KVM: arm/arm64: Factor out hypercall handling from PSCI code
  (bsc#1172197 jsc#SLE-13593).
- KVM: arm64: Document PV-time interface (bsc#1172197
  jsc#SLE-13593).
- commit f17479f
* Fri Aug  7 2020 mbrugger@suse.com
- arm64: dts: rockchip: fix rk3399-puma gmac reset gpio (none
  bsc#1175021).
- arm64: dts: rockchip: fix rk3399-puma vcc5v0-host gpio (none
  bsc#1175020).
- arm64: dts: imx8mm-evk: correct ldo1/ldo2 voltage range
  (none bsc#1175019).
- arm64: tegra: Fix flag for 64-bit resources in 'ranges' property
  (none bsc#1175018).
- arm64: tegra: Fix ethernet phy-mode for Jetson Xavier (none
  bsc#1175017).
- arm64: dts: allwinner: a64: Remove unused SPDIF sound card
  (none bsc#1175016).
- arm64: dts: rockchip: Rename dwc3 device nodes on rk3399 to
  make dtc happy (none bsc#1175015).
- arm64: dts: rockchip: Replace RK805 PMIC node name with "pmic"
  on rk3328 boards (none bsc#1175014).
- arm64: dts: librem5-devkit: add a vbus supply to usb0 (none
  bsc#1175013).
- arm64: dts: ls1028a: delete extraneous #interrupt-cells for
  ENETC RCIE (none bsc#1175012).
- arm64: dts: uniphier: Set SCSSI clock and reset IDs for each
  channel (none bsc#1175011).
- arm64: tegra: Enable I2C controller for EEPROM (none
  bsc#1175010).
- arm64: tegra: Fix Tegra194 PCIe compatible string (none
  bsc#1175009).
- commit a5198b8
* Fri Aug  7 2020 mbrugger@suse.com
- blacklist.conf: ignore rk3368 dts fixes
- commit ee22702
* Fri Aug  7 2020 mbrugger@suse.com
- blacklist.conf: add unsupported Arm devicetree folder
- commit b7cfb90
* Fri Aug  7 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/brcmfmac-set-timeout-value-when-configuring-power-save.patch
- commit 3eb2862
* Fri Aug  7 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/brcmfmac-Transform-compatible-string-for-FW-loading.patch
  patches.suse/scsi-lpfc-Add-an-internal-trace-log-buffer.patch
  patches.suse/scsi-lpfc-Add-blk_io_poll-support-for-latency-improv.patch
  patches.suse/scsi-lpfc-Add-support-to-display-if-adapter-dumps-ar.patch
  patches.suse/scsi-lpfc-Allow-applications-to-issue-Common-Set-Fea.patch
  patches.suse/scsi-lpfc-Fix-NVMe-rport-deregister-and-registration.patch
  patches.suse/scsi-lpfc-Fix-inconsistent-indenting.patch
  patches.suse/scsi-lpfc-Fix-interrupt-assignments-when-multiple-ve.patch
  patches.suse/scsi-lpfc-Fix-kdump-hang-on-PPC.patch
  patches.suse/scsi-lpfc-Fix-language-in-0373-message-to-reflect-no.patch
  patches.suse/scsi-lpfc-Fix-less-than-zero-comparison-of-unsigned-.patch
  patches.suse/scsi-lpfc-Fix-missing-MDS-functionality.patch
  patches.suse/scsi-lpfc-Fix-oops-due-to-overrun-when-reading-SLI3-.patch
  patches.suse/scsi-lpfc-Fix-shost-refcount-mismatch-when-deleting-.patch
  patches.suse/scsi-lpfc-Fix-stack-trace-seen-while-setting-rrq-act.patch
  patches.suse/scsi-lpfc-Fix-unused-assignment-in-lpfc_sli4_bsg_lin.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.2.patch
- commit adcc571
* Fri Aug  7 2020 tiwai@suse.de
- thermal: ti-soc-thermal: Fix reversed condition in
  ti_thermal_expose_sensor() (git-fixes).
- Staging: rtl8188eu: rtw_mlme: Fix uninitialized variable
  authmode (git-fixes).
- staging: rtl8192u: fix a dubious looking mask before a shift
  (git-fixes).
- spi: lantiq-ssc: Fix warning by using WQ_MEM_RECLAIM
  (git-fixes).
- spi: davinci: Remove uninitialized_var() usage (git-fixes).
- commit e403b7a
* Fri Aug  7 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/btrfs-make-btrfs_ordered_extent-naming-consistent-wi.patch
- commit 3f5df49
* Fri Aug  7 2020 tiwai@suse.de
- ALSA: echoaudio: Race conditions around "opencount" (git-fixes).
- commit 9c2eff2
* Fri Aug  7 2020 tiwai@suse.de
- ALSA: pci: delete repeated words in comments (git-fixes).
- ALSA: isa: delete repeated words in comments (git-fixes).
- ALSA: seq: oss: Serialize ioctls (git-fixes).
- ALSA: hda/hdmi: Add quirk to force connectivity (git-fixes).
- ALSA: usb-audio: add startech usb audio dock name (git-fixes).
- ALSA: usb-audio: Add support for Lenovo ThinkStation P620
  (git-fixes).
- ASoC: hdac_hda: fix deadlock after PCM open error (git-fixes).
- ALSA: hda: fix snd_hda_codec_cleanup() documentation
  (git-fixes).
- ASoC: Intel: bxt_rt298: add missing .owner field (git-fixes).
- ASoC: SOF: nocodec: add missing .owner field (git-fixes).
- ASoC: fsl_sai: Fix value of FSL_SAI_CR1_RFW_MASK (git-fixes).
- ASoC: meson: axg-tdmin: fix g12a skew (git-fixes).
- ASoC: meson: axg-tdm-interface: fix link fmt setup (git-fixes).
- ASoC: meson: fixes the missed kfree() for
  axg_card_add_tdm_loopback (git-fixes).
- Revert "ALSA: hda: call runtime_allow() for all hda controllers"
  (git-fixes).
- ALSA: hda/ca0132 - Fix AE-5 microphone selection commands
  (git-fixes).
- ALSA: hda/ca0132 - Add new quirk ID for Recon3D (git-fixes).
- ALSA: hda/ca0132 - Fix ZxR Headphone gain control get value
  (git-fixes).
- ALSA: usb-audio: endpoint : remove needless check before
  usb_free_coherent() (git-fixes).
- ALSA: asihpi: delete duplicated word (git-fixes).
- ALSA: line6: Use kmemdup in podhd_set_monitor_level()
  (git-fixes).
- ALSA: hda: Add support for Loongson 7A1000 controller
  (git-fixes).
- ALSA: hda/tegra: Disable sync-write operation (git-fixes).
- ALSA: echoaudio: re-enable IRQs on failure path (git-fixes).
- ALSA: line6: add hw monitor volume control for POD HD500
  (git-fixes).
- ALSA: xen: Remove superfluous fall through comments (git-fixes).
- ALSA: atmel: Remove invalid "fall through" comments (git-fixes).
- ALSA: echoaudio: Address bugs in the interrupt handling
  (git-fixes).
- ALSA: echoaudio: Prevent some noise on unloading the module
  (git-fixes).
- ALSA: echoaudio: Prevent races in calls to set_audio_format()
  (git-fixes).
- ALSA: echoaudio: Remove redundant check (git-fixes).
- ALSA: usb/line6: remove 'defined but not used' warning
  (git-fixes).
- ALSA: pci/au88x0: remove "defined but not used" warnings
  (git-fixes).
- ALSA: vx_core: remove warning for empty loop body (git-fixes).
- ALSA: pcmcia/pdaudiocf: fix kernel-doc (git-fixes).
- ALSA: pci/via82xx: remove 'set but not used' warnings
  (git-fixes).
- ALSA: pci/fm801: fix kernel-doc (git-fixes).
- ALSA: pci/es1938: remove 'set but not used' warning (git-fixes).
- ALSA: xen: remove 'set but not used' warning (git-fixes).
- ALSA: pci/oxygen/xonar_wm87x6: remove always true condition
  (git-fixes).
- ALSA: pci/rme9652/hdspm: remove always true condition
  (git-fixes).
- ALSA: pci/korg1212: remove 'set but not used' warnings
  (git-fixes).
- ALSA: pci/emu10k1: remove 'set but not used' warning
  (git-fixes).
- ALSA: firewire: fix kernel-doc (git-fixes).
- ALSA: pci/ctxfi: fix kernel-doc warnings (git-fixes).
- ALSA: pci/ctxfi/ctatc: fix kernel-doc (git-fixes).
- ALSA: pci/aw2-saa7146: remove 'set but not used' warning
  (git-fixes).
- ALSA: pci/echoaudio: remove 'set but not used' warning
  (git-fixes).
- ALSA: pci/asihpi: remove 'set but not used' warning (git-fixes).
- ALSA: pci/asihpi: fix kernel-doc (git-fixes).
- ALSA: pci/asihpi: remove 'set but not used' warnings
  (git-fixes).
- ALSA: isa/gus: remove 'set but not used' warning (git-fixes).
- ALSA: isa/gus: remove -Wmissing-prototypes warnings (git-fixes).
- ALSA: core: pcm_iec958: fix kernel-doc (git-fixes).
- ALSA: usb-audio: Fix some typos (git-fixes).
- ALSA: hda: Enable sync-write operation as default for all
  controllers (git-fixes).
- ALSA: hda/realtek: Add alc269/alc662 pin-tables for Loongson-3
  laptops (git-fixes).
- commit 49b9124
* Fri Aug  7 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/rhashtable-Document-the-right-function-parameters.patch
  patches.suse/rhashtable-Fix-unprotected-RCU-dereference-in-__rht_.patch
- commit 1af1b05
* Thu Aug  6 2020 tiwai@suse.de
- Re-sort another cherry-picked i915 patch in the upstream
  Refresh patches.suse/drm-i915-Actually-emit-the-await_start.patch
- commit 46112ad
* Thu Aug  6 2020 tiwai@suse.de
- Resort the i915 cherry-picked patch
  Refresh
  patches.suse/drm-i915-Protect-i915_request_await_start-from-early.patch
  patches.suse/drm-i915-Return-early-for-await_start-on-same-timeli.patch
- commit 20cca9b
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Return early for await_start on same timeline
  (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Protect-i915_request_await_start-from-early.patch.
- commit 06dbabf
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Improve the start alignment of bonded pairs
  (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Reorder-await_execution-before-await_reques.patch.
- commit 44313fe
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Mark up unlocked update of i915_request.hwsp_seqno
  (bsc#1174737).
- commit 50bee7f
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Mark racy read of intel_engine_cs.saturated
  (bsc#1174737).
- commit e5038ad
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Do not poison i915_request.link on removal
  (bsc#1174737).
- commit 808ecc5
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Actually emit the await_start (bsc#1174737).
- commit f0424b5
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Protect i915_request_await_start from early waits
  (bsc#1174737).
- commit 03accf1
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Flush execution tasklets before checking request
  status (bsc#1174737).
- drm/i915: Flush tasklet submission before sleeping on
  i915_request_wait (bsc#1174737).
- commit 140a397
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915/gt: Flush submission tasklet before waiting/retiring
  (bsc#1174737).
- commit b17d2a1
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Keep track of request among the scheduling lists
  (bsc#1174737).
- commit 4388a9e
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Eliminate the trylock for awaiting an earlier request
  (bsc#1174737).
- Refresh
  patches.suse/0002-drm-i915-gt-Do-not-schedule-normal-requests-immediat.patch.
- commit 590b628
* Thu Aug  6 2020 jgross@suse.com
- xen/pvcalls-back: test for errors when calling backend_connect()
  (bsc#1065600).
- commit cbfa27b
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Use EAGAIN for trylock failures (bsc#1174737).
- commit d8a7f90
* Thu Aug  6 2020 martin.wilck@suse.com
- kabi/severities: ignore KABI for NVMe, except nvme-fc (bsc#1174777)
  Exported symbols under drivers/nvme/host/ are only used by the
  nvme subsystem itself, except for the nvme-fc symbols.
- commit 16ddcd8
* Thu Aug  6 2020 martin.wilck@suse.com
- nvme-multipath: round-robin: eliminate "fallback" variable
  (bsc#1172108).
- commit 4cdac03
* Thu Aug  6 2020 martin.wilck@suse.com
- nvme: multipath: round-robin: fix single non-optimized path case
  (bsc#1172108).
- commit 3d56aa0
* Thu Aug  6 2020 tbogendoerfer@suse.de
- ionic: unlock queue mutex in error path (bsc#1167773).
- devlink: ignore -EOPNOTSUPP errors on dumpit (bsc#1154353).
- net/mlx5e: Fix kernel crash when setting vf VLANID on a VF dev
  (jsc#SLE-8464).
- net/mlx5: E-switch, Destroy TSAR when fail to enable the mode
  (jsc#SLE-8464).
- RDMA/mlx5: Fix prefetch memory leak if get_prefetchable_mr fails
  (jsc#SLE-8446).
- commit 23bdd26
* Thu Aug  6 2020 glin@suse.com
- libbpf: Wrap source argument of BPF_CORE_READ macro in
  parentheses (bsc#1155518).
- bpf: Fix map leak in HASH_OF_MAPS map (bsc#1155518).
- net, sk_msg: Don't use RCU_INIT_POINTER on sk_user_data
  (bsc#1155518).
- commit a6677ae
* Thu Aug  6 2020 tiwai@suse.de
- wireless: Use linux/stddef.h instead of stddef.h (git-fixes).
- commit ec3012b
* Thu Aug  6 2020 tiwai@suse.de
- wl1251: fix always return 0 error (git-fixes).
- video: pxafb: Fix the function used to balance a
  'dma_alloc_coherent()' call (git-fixes).
- video: fbdev: sm712fb: fix an issue about iounmap for a wrong
  address (git-fixes).
- USB: serial: iuu_phoenix: fix led-activity helpers (git-fixes).
- USB: serial: cp210x: re-enable auto-RTS on open (git-fixes).
- USB: serial: cp210x: enable usb generic throttle/unthrottle
  (git-fixes).
- USB: iowarrior: fix up report size handling for some devices
  (git-fixes).
- usb: gadget: f_uac2: fix AC Interface Header Descriptor
  wTotalLength (git-fixes).
- usb: core: fix quirks_param_set() writing to a const pointer
  (git-fixes).
- usb: dwc2: gadget: Make use of GINTMSK2 (git-fixes).
- usbip: tools: fix module name in man page (git-fixes).
- usb: hso: Fix debug compile warning on sparc32 (git-fixes).
- wireless: Use offsetof instead of custom macro (git-fixes).
- commit 0511c57
* Thu Aug  6 2020 tiwai@suse.de
- rtw88: fix short GI capability based on current bandwidth
  (git-fixes).
- rtw88: fix LDPC field for RA info (git-fixes).
- mac80211: fix misplaced while instead of if (git-fixes).
- liquidio: Fix wrong return value in cn23xx_get_pf_num()
  (git-fixes).
- mwifiex: Fix firmware filename for sd8997 chipset (git-fixes).
- mwifiex: Fix firmware filename for sd8977 chipset (git-fixes).
- mwifiex: Prevent memory corruption handling keys (git-fixes).
- leds: gpio: Fix semantic error (git-fixes).
- leds: core: Flush scheduled work for system suspend (git-fixes).
- leds: wm831x-status: fix use-after-free on unbind (git-fixes).
- leds: lm36274: fix use-after-free on unbind (git-fixes).
- leds: lm3533: fix use-after-free on unbind (git-fixes).
- leds: da903x: fix use-after-free on unbind (git-fixes).
- phy: armada-38x: fix NETA lockup when repeatedly switching
  speeds (git-fixes).
- phy: renesas: rcar-gen3-usb2: move irq registration to init
  (git-fixes).
- phy: exynos5-usbdrd: Calibrating makes sense only for USB2.0
  PHY (git-fixes).
- net: lan78xx: fix transfer-buffer memory leak (git-fixes).
- net: lan78xx: add missing endpoint sanity check (git-fixes).
- drivers/net/wan: lapb: Corrected the usage of skb_cow
  (git-fixes).
- nfc: s3fwrn5: add missing release on skb in s3fwrn5_recv_frame
  (git-fixes).
- commit ffa42ff
* Thu Aug  6 2020 tiwai@suse.de
- drm/etnaviv: Fix error path on failure to enable bus clk
  (git-fixes).
- drm/imx: imx-ldb: Disable both channels for split mode in
  enc->disable() (git-fixes).
- drm/imx: tve: fix regulator_disable error path (git-fixes).
- drm/imx: fix use after free (git-fixes).
- drm/bridge: sil_sii8620: initialize return of sii8620_readb
  (git-fixes).
- drm: panel: simple: Fix bpc for LG LB070WV8 panel (git-fixes).
- drm/stm: repair runtime power management (git-fixes).
- drm/mipi: use dcs write for mipi_dsi_dcs_set_tear_scanline
  (git-fixes).
- drm/radeon: fix array out-of-bounds read and write issues
  (git-fixes).
- drm/panel: otm8009a: Drop unnessary
  backlight_device_unregister() (git-fixes).
- drm/arm: fix unintentional integer overflow on left shift
  (git-fixes).
- drm/bridge: ti-sn65dsi86: Don't use kernel-doc comment for
  local array (git-fixes).
- drm/bridge: ti-sn65dsi86: Clear old error bits before AUX
  transfers (git-fixes).
- drm/gem: Fix a leak in drm_gem_objects_lookup() (git-fixes).
- leds: 88pm860x: fix use-after-free on unbind (git-fixes).
- leds: lm355x: avoid enum conversion warning (git-fixes).
- gpio: max77620: Fix missing release of interrupt (git-fixes).
- kobject: Avoid premature parent object freeing in
  kobject_cleanup() (git-fixes).
- commit 004490b
* Thu Aug  6 2020 tiwai@suse.de
- appletalk: Fix atalk_proc_init() return path (git-fixes).
- Bluetooth: hci_serdev: Only unregister device if it was
  registered (git-fixes).
- Bluetooth: hci_h5: Set HCI_UART_RESET_ON_INIT to correct flags
  (git-fixes).
- Bluetooth: Fix update of connection state in `hci_encrypt_cfm`
  (git-fixes).
- Bluetooth: btmtksdio: fix up firmware download sequence
  (git-fixes).
- Bluetooth: btusb: fix up firmware download sequence (git-fixes).
- btmrvl: Fix firmware filename for sd8997 chipset (git-fixes).
- btmrvl: Fix firmware filename for sd8977 chipset (git-fixes).
- ath10k: Acquire tx_lock in tx error paths (git-fixes).
- agp/intel: Fix a memory leak on module initialisation failure
  (git-fixes).
- console: newport_con: fix an issue about leak related system
  resources (git-fixes).
- driver core: Avoid binding drivers to dead devices (git-fixes).
- devres: keep both device name and resource name in pretty name
  (git-fixes).
- b43: Remove uninitialized_var() usage (git-fixes).
- Bluetooth: fix kernel oops in store_pending_adv_report
  (git-fixes).
- drm: hold gem reference until object is no longer accessed
  (git-fixes).
- dlm: remove BUG() before panic() (git-fixes).
- ath10k: enable transmit data ack RSSI for QCA9884 (git-fixes).
- commit 964f75f
* Wed Aug  5 2020 nsaenzjulienne@suse.de
- firmware: smccc: Add ARCH_SOC_ID support (bsc#1174906).
- Update arm64 config
- firmware: smccc: Add function to fetch SMCCC version
  (bsc#1174906).
- firmware: smccc: Refactor SMCCC specific bits into separate file
  (bsc#1174906).
- firmware: smccc: Drop smccc_version enum and use
  ARM_SMCCC_VERSION_1_x instead (bsc#1174906).
- firmware: smccc: Add the definition for SMCCCv1.2 version/error
  codes (bsc#1174906).
- firmware: smccc: Update link to latest SMCCC specification
  (bsc#1174906).
- firmware: smccc: Add HAVE_ARM_SMCCC_DISCOVERY to identify SMCCC v1.1 and above (bsc#1174906).
- Update arm64 config
- arm/arm64: Make use of the SMCCC 1.1 wrapper (bsc#1174906).
- arm/arm64: Provide a wrapper for SMCCC 1.1 calls (bsc#1174906).
- firmware: arm_sdei: use common SMCCC_CONDUIT_* (bsc#1174906).
- firmware/psci: use common SMCCC_CONDUIT_* (bsc#1174906).
- arm: spectre-v2: use arm_smccc_1_1_get_conduit() (bsc#1174906).
- arm64: errata: use arm_smccc_1_1_get_conduit() (bsc#1174906).
- arm/arm64: smccc/psci: add arm_smccc_1_1_get_conduit()
  (bsc#1174906).
- commit 91485ab
* Wed Aug  5 2020 mbrugger@suse.com
- blacklist.conf: ignore documentation fixes
- commit da3606d
* Wed Aug  5 2020 wqu@suse.com
- btrfs: qgroup: remove ASYNC_COMMIT mechanism in favor of
  reserve retry-after-EDQUOT (bsc#1120163).
- commit a0c01d8
* Wed Aug  5 2020 wqu@suse.com
- btrfs: qgroup: try to flush qgroup space when we get  -EDQUOT
  (bsc#1120163).
- commit 110b26f
* Wed Aug  5 2020 wqu@suse.com
- btrfs: qgroup: allow to unreserve range without releasing
  other ranges (bsc#1120163).
- commit 292ee83
* Wed Aug  5 2020 wqu@suse.com
- btrfs: qgroup: fix data leak caused by race between writeback
  and truncate (bsc#1172247).
- commit e7691a1
* Wed Aug  5 2020 wqu@suse.com
- btrfs: change timing for qgroup reserved space for  ordered
  extents to fix reserved space leak (bsc#1172247).
- commit 5f13741
* Wed Aug  5 2020 wqu@suse.com
- btrfs: file: reserve qgroup space after the hole punch  range
  is locked (bsc#1172247).
- commit c1e305c
* Wed Aug  5 2020 wqu@suse.com
- btrfs: inode: move qgroup reserved space release to the  callers
  of insert_reserved_file_extent() (bsc#1172247).
- commit c77d18c
* Wed Aug  5 2020 wqu@suse.com
- btrfs: inode: refactor the parameters of
  insert_reserved_file_extent() (bsc#1172247).
- commit 999728e
* Wed Aug  5 2020 wqu@suse.com
- btrfs: make btrfs_ordered_extent naming consistent with
  btrfs_file_extent_item (bsc#1172247).
- commit 3a23bcd
* Wed Aug  5 2020 glin@suse.com
- bpf: net: Avoid incorrect bpf_sk_reuseport_detach call
  (bsc#1155518).
- bpf: net: Avoid copying sk_user_data of reuseport_array during
  sk_clone (bsc#1155518).
- net, sk_msg: Clear sk_user_data pointer on clone if tagged
  (bsc#1155518).
- commit 9a81f17
* Wed Aug  5 2020 dbueso@suse.de
- rhashtable: Restore RCU marking on rhash_lock_head
  (bsc#1174880).
- rhashtable: Fix unprotected RCU dereference in __rht_ptr
  (bsc#1174880).
- rhashtable: drop duplicated word in <linux/rhashtable.h>
  (bsc#1174880).
- rhashtable: Drop raw RCU deref in nested_table_free
  (bsc#1174880).
- rhashtable: Document the right function parameters
  (bsc#1174880).
- commit c0ec5b4
* Tue Aug  4 2020 lyan@suse.com
- KVM: arm64: Make vcpu_cp1x() work on Big Endian hosts
  (bsc#1133021).
- KVM: arm64: Stop writing aarch32's CSSELR into ACTLR
  (bsc#1133021).
- KVM: arm64: Fix 32bit PC wrap-around (bsc#1133021).
- KVM: arm: vgic: Fix limit condition when writing to
  GICD_IACTIVER (bsc#1133021).
- KVM: arm64: Use the correct timer structure to access the
  physical counter (bsc#1133021).
- KVM: arm/arm64: Correct AArch32 SPSR on exception entry
  (bsc#1133021).
- KVM: arm/arm64: Correct CPSR on exception entry (bsc#1133021).
- KVM: arm64: Correct PSTATE on exception entry (bsc#1133021).
- KVM: Play nice with read-only memslots when querying host page
  size (bsc#1133021).
- commit 854e6da
* Tue Aug  4 2020 tiwai@suse.de
- drm/i915: Reorder await_execution before await_request
  (bsc#1174737).
- commit 75817a8
* Tue Aug  4 2020 tiwai@suse.de
- drm/i915: Copy across scheduler behaviour flags across submit
  fences (bsc#1174737).
- commit 718e478
* Tue Aug  4 2020 tiwai@suse.de
- drm/i915: Lock signaler timeline while navigating (bsc#1174737).
- commit d0600f4
* Tue Aug  4 2020 tiwai@suse.de
- drm/i915: Mark i915_request.timeline as a volatile, rcu pointer
  (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Hold-reference-to-intel_frontbuffer-as-we-t.patch.
- Refresh
  patches.suse/drm-i915-Protect-context-while-grabbing-its-name-for.patch.
- Refresh
  patches.suse/drm-i915-Reduce-nested-prepare_remote_context-to-a-t.patch.
- commit fce086e
* Tue Aug  4 2020 lyan@suse.com
- KVM: s390: Remove false WARN_ON_ONCE for the PQAP instruction
  (bsc#1133021).
- commit f7e204d
* Tue Aug  4 2020 nsaenzjulienne@suse.de
- clk: bcm2835: Do not use prediv with bcm2711's PLLs
  (bsc#1174865).
- brcmfmac: Set timeout value when configuring power save
  (bsc#1173468).
- commit 4d732a9
* Tue Aug  4 2020 tbogendoerfer@suse.de
- IB/rdmavt: Fix RQ counting issues causing use of an invalid RWQE
  (bsc#1174770).
- commit 4c02379
* Tue Aug  4 2020 tiwai@suse.de
- spi: rockchip: Fix error in SPI slave pio read (git-fixes).
- spi: sun4i: update max transfer size reported (git-fixes).
- spi: lantiq: fix: Rx overflow error in full duplex mode
  (git-fixes).
- spi: spi-geni-qcom: Actually use our FIFO (git-fixes).
- regulator: gpio: Honor regulator-boot-on property (git-fixes).
- clk: scmi: Fix min and max rate when registering clocks with
  discrete rates (git-fixes).
- firmware: arm_scmi: Keep the discrete clock rates sorted
  (git-fixes).
- firmware: arm_scmi: Fix SCMI genpd domain probing (git-fixes).
- platform/x86: intel-vbtn: Fix return value check in
  check_acpi_dev() (git-fixes).
- platform/x86: intel-hid: Fix return value check in
  check_acpi_dev() (git-fixes).
- crypto: qat - fix double free in qat_uclo_create_batch_init_list
  (git-fixes).
- crypto: ccp - Fix use of merged scatterlists (git-fixes).
- crypto: ccree - fix resource leak on error path (git-fixes).
- crypto: hisilicon - don't sleep of CRYPTO_TFM_REQ_MAY_SLEEP
  was not specified (git-fixes).
- crypto: cpt - don't sleep of CRYPTO_TFM_REQ_MAY_SLEEP was not
  specified (git-fixes).
- crypto: caam - Fix argument type in handle_imx6_err005766
  (git-fixes).
- crc-t10dif: Fix potential crypto notify dead-lock (git-fixes).
- tpm: Require that all digests are present in TCG_PCR_EVENT2
  structures (git-fixes).
- commit 64bac7f
* Mon Aug  3 2020 lyan@suse.com
- kABI workaround for struct kvm_device (git-fixes).
  Just change an variable to "const" type in kvm_device.
- commit 1c95856
* Mon Aug  3 2020 lyan@suse.com
- kABI workaround for enum cpuhp_state (git-fixes).
- commit 889dc24
* Mon Aug  3 2020 lyan@suse.com
- kABI workaround for struct kvm_vcpu_arch (git-fixes).
  Add a struct variable to the end of kvm_vcpu_arch and kvm_vcpu_arch
  is embedded into kvm_vcpu at the end. It is usually used by pointer
  and allocated dynamically, so this change should be fine even for
  external kvm module.
- commit c324264
* Mon Aug  3 2020 jack@suse.cz
- patches.suse/revert-zram-convert-remaining-class_attr-to-class_attr_ro:
  Update tags
- commit 3b99445
* Mon Aug  3 2020 jack@suse.cz
- gfs2: fix gfs2_find_jhead that returns uninitialized jhead
  with seq 0 (bsc#1174825).
- commit 796da2e
* Mon Aug  3 2020 jack@suse.cz
- gfs2: Another gfs2_find_jhead fix (bsc#1174824).
- commit eb92077
* Mon Aug  3 2020 lhenriques@suse.de
- blacklist.conf: mtd kernel-doc fixes
- commit 12371a2
* Mon Aug  3 2020 jslaby@suse.cz
- Fix for missing check in vgacon scrollback handling (bsc#1174205
  CVE-2020-14331).
  Update to the latest findings/submission.
- commit 2b80031
* Mon Aug  3 2020 shung-hsi.yu@suse.com
- ubsan: check panic_on_warn (bsc#1174805).
- commit 4b3b09b
* Sun Aug  2 2020 tiwai@suse.de
- af_key: pfkey_dump needs parameter validation (git-fixes).
- mac80211: mesh: Free pending skb when destroying a mpath
  (git-fixes).
- mac80211: mesh: Free ie data when leaving mesh (git-fixes).
- i2c: also convert placeholder function to return errno
  (git-fixes).
- drm/amd/display: Clear dm_state for fast updates (git-fixes).
- drm/amdgpu: Prevent kernel-infoleak in amdgpu_info_ioctl()
  (git-fixes).
- regmap: debugfs: check count when read regmap file (git-fixes).
- PM: wakeup: Show statistics for deleted wakeup sources again
  (git-fixes).
- commit f22517a
* Sun Aug  2 2020 tiwai@suse.de
- ALSA: hda/realtek - Fixed HP right speaker no sound (git-fixes).
- ALSA: hda: fix NULL pointer dereference during suspend
  (git-fixes).
- ALSA: hda/hdmi: Fix keep_power assignment for non-component
  devices (git-fixes).
- ALSA: hda: Workaround for spurious wakeups on some Intel
  platforms (git-fixes).
- ALSA: hda/realtek: Fix add a "ultra_low_power" function for
  intel reference board (alc256) (git-fixes).
- ALSA: hda/realtek: typo_fix: enable headset mic of ASUS ROG
  Zephyrus G14(GA401) series with ALC289 (git-fixes).
- ALSA: hda/realtek: enable headset mic of ASUS ROG Zephyrus
  G15(GA502) series with ALC289 (git-fixes).
- ALSA: usb-audio: Add implicit feedback quirk for SSL2
  (git-fixes).
- commit 7cc8f61
* Fri Jul 31 2020 mkoutny@suse.com
- mm: Fix protection usage propagation (bsc#1174002).
- commit 446569c
* Fri Jul 31 2020 tiwai@suse.de
- Revert "drm/amdgpu: Fix NULL dereference in dpm sysfs handlers"
  (git-fixes).
- ARM: percpu.h: fix build error (git-fixes).
- random: fix circular include dependency on arm64 after addition
  of percpu.h (git-fixes).
- commit a78809a
* Fri Jul 31 2020 mbrugger@suse.com
- uio_pdrv_genirq: Remove warning when irq is not specified
  (bsc#1174762).
- commit 31bf7b7
* Fri Jul 31 2020 tiwai@suse.de
- random32: update the net random state on interrupt and activity
  (CVE-2020-16166 bsc#1174757).
- commit 81d991d
* Fri Jul 31 2020 tiwai@suse.de
- PCI/ASPM: Disable ASPM on ASMedia ASM1083/1085 PCIe-to-PCI
  bridge (git-fixes).
- commit f661820
* Thu Jul 30 2020 tiwai@suse.de
- 9p/trans_fd: Fix concurrency del of req_list in
  p9_fd_cancelled/p9_read_work (git-fixes).
- staging: wlan-ng: properly check endpoint types (git-fixes).
- serial: exar: Fix GPIO configuration for Sealevel cards based
  on XR17V35X (git-fixes).
- fbdev: Detect integer underflow at "struct
  fbcon_ops"->clear_margins (git-fixes).
- serial: 8250_mtk: Fix high-speed baud rates clamping
  (git-fixes).
- serial: 8250: fix null-ptr-deref in serial8250_start_tx()
  (git-fixes).
- serial: tegra: fix CREAD handling for PIO (git-fixes).
- vt: Reject zero-sized screen buffer size (git-fixes).
- usb: xhci: Fix ASM2142/ASM3142 DMA addressing (git-fixes).
- drm/amdgpu: Fix NULL dereference in dpm sysfs handlers
  (git-fixes).
- usb: gadget: udc: gr_udc: fix memleak on error handling path
  in gr_ep_init() (git-fixes).
- usb: dwc3: pci: add support for the Intel Jasper Lake
  (git-fixes).
- usb: dwc3: pci: add support for the Intel Tiger Lake PCH -H
  variant (git-fixes).
- hwmon: (scmi) Fix potential buffer overflow in
  scmi_hwmon_probe() (git-fixes).
- hwmon: (nct6775) Accept PECI Calibration as temperature source
  for NCT6798D (git-fixes).
- hwmon: (adm1275) Make sure we are reading enough data for
  different chips (git-fixes).
- hwmon: (aspeed-pwm-tacho) Avoid possible buffer overflow
  (git-fixes).
- spi: mediatek: use correct SPI_CFG2_REG MACRO (git-fixes).
- regmap: dev_get_regmap_match(): fix string comparison
  (git-fixes).
- HID: apple: Disable Fn-key key-re-mapping on clone keyboards
  (git-fixes).
- HID: steam: fixes race in handling device list (git-fixes).
- HID: alps: support devices with report id 2 (git-fixes).
- HID: i2c-hid: add Mediacom FlexBook edge13 to descriptor
  override (git-fixes).
- drm/amdgpu: fix preemption unit test (git-fixes).
- drm/amdgpu/gfx10: fix race condition for kiq (git-fixes).
- serial: mxs-auart: add missed iounmap() in probe failure and
  remove (git-fixes).
- dmaengine: ioat setting ioat timeout as module parameter
  (git-fixes).
- dmaengine: fsl-edma: fix wrong tcd endianness for big-endian
  cpu (git-fixes).
- dmaengine: tegra210-adma: Fix runtime PM imbalance on error
  (git-fixes).
- Input: elan_i2c - only increment wakeup count on touch
  (git-fixes).
- Input: synaptics - enable InterTouch for ThinkPad X1E 1st gen
  (git-fixes).
- mac80211: allow rx of mesh eapol frames with default rx key
  (git-fixes).
- pinctrl: amd: fix npins for uart0 in kerncz_groups (git-fixes).
- gpio: arizona: put pm_runtime in case of failure (git-fixes).
- gpio: arizona: handle pm_runtime_get_sync failure case
  (git-fixes).
- drivers/firmware/psci: Fix memory leakage in
  alloc_init_cpu_groups() (git-fixes).
- drm/nouveau/i2c/g94-: increase NV_PMGR_DP_AUXCTL_TRANSACTREQ
  timeout (git-fixes).
- serial: amba-pl011: Make sure we initialize the port.lock
  spinlock (git-fixes).
- serial: 8250_pci: Move Pericom IDs to pci_ids.h (git-fixes).
- commit 5b7d8a8
* Thu Jul 30 2020 hare@suse.de
- nvme: kABI fixes for nvme_ctrl (bsc#1159058).
- commit dc7531f
* Thu Jul 30 2020 ghe@suse.com
- ocfs2: fix panic on nfs server over ocfs2 (bsc#1172963).
- ocfs2: load global_inode_alloc (bsc#1172963).
- ocfs2: avoid inode removal while nfsd is accessing it
  (bsc#1172963).
- commit 1a01c78
* Thu Jul 30 2020 aherrmann@suse.com
- docs: fix memory.low description in cgroup-v2.rst (git-fixes).
  (SLE documentation might refer to cgroup-v2.rst.)
- commit 1c58dff
* Thu Jul 30 2020 aherrmann@suse.com
- net: Fix a documentation bug wrt. ip_unprivileged_port_start (git-fixes).
  (SLES tuning guide refers to ip-sysctl.txt.)
- commit b51f83b
* Thu Jul 30 2020 aherrmann@suse.com
- blacklist.conf: Add dc8d37ed304ee ("cpu/SMT: Fix x86 link error without CONFIG_SYSFS")
- commit 24e5ac8
* Thu Jul 30 2020 aherrmann@suse.com
- blacklist.conf: Add 98919f4c9a342 ("Documentation: debugfs: Document debugfs helper for unsigned long values")
- commit 5a3f2df
* Thu Jul 30 2020 aherrmann@suse.com
- io-mapping: indicate mapping failure (git-fixes).
- commit b3a6154
* Wed Jul 29 2020 dwagner@suse.de
- powerpc/pseries: PCIE PHB reset (bsc#1174689).
- powerpc/eeh: Fix pseries_eeh_configure_bridge() (bsc#1174689).
- commit ba8e81b
* Wed Jul 29 2020 hare@suse.de
- nvme: consolodate io settings (bsc#1159058).
- nvme: revalidate namespace stream parameters (bsc#1159058).
- nvme: consolidate chunk_sectors settings (bsc#1159058).
- nvme: revalidate after verifying identifiers (bsc#1159058).
- nvme-multipath: set bdi capabilities once (bsc#1159058).
- nvme: check namespace head shared property (bsc#1159058).
- nvme: always search for namespace head (bsc#1159058).
- nvme: release namespace head reference on error (bsc#1159058).
- nvme: unlink head after removing last namespace (bsc#1159058).
- nvme: remove the magic 1024 constant in nvme_scan_ns_list
  (bsc#1159058).
- nvme: avoid an Identify Controller command for each namespace
  (bsc#1159058).
- nvme: factor out a nvme_ns_remove_by_nsid helper (bsc#1159058).
- nvme: clean up nvme_scan_work (bsc#1159058).
- nvme: refine the Qemu Identify CNS quirk (bsc#1159058).
- nvme: remove unused parameter (bsc#1159058).
- commit fe17413
* Wed Jul 29 2020 rgoldwyn@suse.com
- Delete patches.suse/apparmor-Fix-memory-leak-of-profile-proxy.patch (bsc#1174627)
- commit dbe0add
* Wed Jul 29 2020 hare@suse.de
- nvme-multipath: do not fall back to __nvme_find_path() for non-optimized paths (bsc#1172108).
- nvme-multipath: fix logic for non-optimized paths (bsc#1172108).
- commit a2fe085
* Wed Jul 29 2020 dwagner@suse.de
- xfrm: fix a warning in xfrm_policy_insert_list (bsc#1174645).
- commit e77828e
* Wed Jul 29 2020 tbogendoerfer@suse.de
- IB/mlx5: Fix DEVX support for MLX5_CMD_OP_INIT2INIT_QP command
  (git-fixes).
- i40iw: fix null pointer dereference on a null wqe pointer
  (git-fixes).
- commit 76175e9
* Wed Jul 29 2020 mbenes@suse.cz
- x86/stacktrace: Fix reliable check for empty user task stacks
  (bsc#1058115).
- commit 4883ff2
* Wed Jul 29 2020 tbogendoerfer@suse.de
- qed: suppress false-positives interrupt error messages on HW
  init (git-fixes).
- qed: suppress "don't support RoCE & iWARP" flooding on HW init
  (git-fixes).
- netdevsim: fix unbalaced locking in nsim_create() (git-fixes).
- net: hns3: fix return value error when query MAC link status
  fail (git-fixes).
- net: hns3: fix error handling for desc filling (git-fixes).
- net: hns3: fix for not calculating TX BD send size correctly
  (git-fixes).
- ionic: use mutex to protect queue operations (bsc#1167773).
- ionic: keep rss hash after fw update (bsc#1167773).
- ionic: update filter id after replay (bsc#1167773).
- ionic: fix up filter locks and debug msgs (bsc#1167773).
- ionic: use offset for ethtool regs data (bsc#1167773).
- mlxsw: core: Fix wrong SFP EEPROM reading for upper pages 1-3
  (bsc#1154488).
- rtnetlink: Fix memory(net_device) leak when ->newlink fails
  (bsc#1154353).
- bnxt_en: Init ethtool link settings after reading updated PHY
  configuration (jsc#SLE-8371 bsc#1153274).
- RDMA/mlx5: Prevent prefetch from racing with implicit
  destruction (jsc#SLE-8446).
- RDMA/core: Fix race in rdma_alloc_commit_uobject() (git-fixes).
- RDMA/mlx5: Use xa_lock_irq when access to SRQ table (git-fixes).
- IB/mlx5: Fix 50G per lane indication (git-fixes).
- RDMA/siw: Fix reporting vendor_part_id (git-fixes).
- IB/sa: Resolv use-after-free in ib_nl_make_request()
  (git-fixes).
- IB/mad: Fix use after free when destroying MAD agent
  (git-fixes).
- RDMA/counter: Query a counter before release (git-fixes).
- RDMA/mad: Fix possible memory leak in ib_mad_post_receive_mads()
  (git-fixes).
- RDMA/cma: Protect bind_list and listen_list while finding
  matching cm id (git-fixes).
- RDMA/qedr: Fix KASAN: use-after-free in ucma_event_handler+0x532
  (git-fixes).
- RDMA/efa: Set maximum pkeys device attribute (git-fixes).
- RDMA/rvt: Fix potential memory leak caused by rvt_alloc_rq
  (git-fixes).
- RDMA/siw: Fix pointer-to-int-cast warning in siw_rx_pbl()
  (git-fixes).
- IB/cma: Fix ports memory leak in cma_configfs (git-fixes).
- RDMA/mlx5: Add init2init as a modify command (git-fixes).
- RDMA/hns: Fix cmdq parameter of querying pf timer resource
  (git-fixes).
- RDMA/hns: Bugfix for querying qkey (git-fixes).
- RDMA/uverbs: Fix create WQ to use the given user handle
  (git-fixes).
- RDMA/mlx5: Verify that QP is created with RQ or SQ (git-fixes).
- RDMA/mlx5: Fix udata response upon SRQ creation (git-fixes).
- RDMA/rxe: Set default vendor ID (git-fixes).
- IB/ipoib: Fix double free of skb in case of multicast traffic
  in CM mode (git-fixes).
- RDMA/core: Fix double destruction of uobject (git-fixes).
- RDMA/pvrdma: Fix missing pci disable in pvrdma_pci_probe()
  (git-fixes).
- IB/qib: Call kobject_put() when kobject_init_and_add() fails
  (git-fixes).
- RDMA/iw_cxgb4: Fix incorrect function parameters (git-fixes).
- RDMA/core: Fix double put of resource (git-fixes).
- IB/core: Fix potential NULL pointer dereference in pkey cache
  (git-fixes).
- IB/mlx4: Test return value of calls to ib_get_cached_pkey
  (git-fixes).
- RDMA/rxe: Always return ERR_PTR from rxe_create_mmap_info()
  (git-fixes).
- i40iw: Fix error handling in i40iw_manage_arp_cache()
  (git-fixes).
- RDMA/core: Fix race between destroy and release FD object
  (git-fixes).
- IB/rdmavt: Always return ERR_PTR from rvt_create_mmap_info()
  (git-fixes).
- RDMA/core: Prevent mixed use of FDs between shared ufiles
  (git-fixes).
- RDMA/mlx5: Set GRH fields in query QP on RoCE (git-fixes).
- RDMA/siw: Fix potential siw_mem refcnt leak in siw_fastreg_mr()
  (git-fixes).
- RDMA/mlx4: Initialize ib_spec on the stack (git-fixes).
- RDMA/cm: Fix an error check in cm_alloc_id_priv() (git-fixes).
- IB/hfi1: Fix memory leaks in sysfs registration and
  unregistration (git-fixes).
- RDMA/rxe: Set sys_image_guid to be aligned with HW IB devices
  (git-fixes).
- RDMA/cm: Update num_paths in cma_resolve_iboe_route error flow
  (git-fixes).
- IB/rdmavt: Delete unused routine (git-fixes).
- i40iw: Report correct firmware version (git-fixes).
- RDMA/cm: Add missing locking around id.state in
  cm_dup_req_handler (git-fixes).
- RDMA/cm: Read id.state under lock when doing pr_debug()
  (git-fixes).
- RDMA/cm: Remove a race freeing timewait_info (git-fixes).
- RDMA/cm: Fix checking for allowed duplicate listens (git-fixes).
- RDMA/cm: Fix ordering of xa_alloc_cyclic() in ib_create_cm_id()
  (git-fixes).
- IB/mlx5: Replace tunnel mpls capability bits for tunnel_offloads
  (git-fixes).
- RDMA/siw: Fix passive connection establishment (git-fixes).
- IB/mlx5: Fix missing congestion control debugfs on rep rdma
  device (git-fixes).
- RDMA/ucma: Put a lock around every call to the rdma_cm layer
  (git-fixes).
- RDMA/siw: Fix setting active_{speed, width} attributes
  (git-fixes).
- RDMA/rxe: Fix configuration of atomic queue pair attributes
  (git-fixes).
- RDMA/siw: Fix setting active_mtu attribute (git-fixes).
- i40iw: Do an RCU lookup in i40iw_add_ipv4_addr (git-fixes).
- RDMA/mlx5: Fix access to wrong pointer while performing flush
  due to error (git-fixes).
- IB/hfi1: Ensure pq is not left on waitlist (git-fixes).
- RDMA/mad: Do not crash if the rdma device does not have a umad
  interface (git-fixes).
- RDMA/core: Fix missing error check on dev_set_name()
  (git-fixes).
- RDMA/mlx5: Fix the number of hwcounters of a dynamic counter
  (git-fixes).
- RDMA/iwcm: Fix iwcm work deallocation (git-fixes).
- RDMA/siw: Fix failure handling during device creation
  (git-fixes).
- RDMA/nldev: Fix crash when set a QP to a new counter but QPN
  is missing (git-fixes).
- RDMA/core: Fix protection fault in ib_mr_pool_destroy
  (git-fixes).
- IB/hfi1, qib: Ensure RCU is locked when accessing list
  (git-fixes).
- RMDA/cm: Fix missing ib_cm_destroy_id() in ib_cm_insert_listen()
  (git-fixes).
- Revert "RDMA/cma: Simplify rdma_resolve_addr() error flow"
  (git-fixes).
- commit 3509d43
* Wed Jul 29 2020 mbenes@suse.cz
- x86/unwind/orc: Fix ORC for newly forked tasks (bsc#1058115).
- commit c9872a0
* Tue Jul 28 2020 tzimmermann@suse.de
- drm/amd/powerplay: fix a crash when overclocking Vega M (bsc#1152472)
- commit e5783e4
* Tue Jul 28 2020 tzimmermann@suse.de
- drm/i915: Move cec_notifier to intel_hdmi_connector_unregister, v2. (bsc#1152489)
  * context changes
- commit 832eb1e
* Tue Jul 28 2020 tzimmermann@suse.de
- drm/i915/gt: Only swap to a random sibling once upon creation (bsc#1152489)
  * context changes
- commit b0d94d8
* Tue Jul 28 2020 tzimmermann@suse.de
- drm/i915/fbc: Fix fence_y_offset handling (bsc#1152489)
  * context changes
- commit c4ded04
* Tue Jul 28 2020 tiwai@suse.de
- rtnetlink: Fix memory(net_device) leak when ->newlink fails
  (git-fixes).
- commit 11a9564
* Tue Jul 28 2020 tiwai@suse.de
- NTB: ntb_test: Fix bug when counting remote files (git-fixes).
- NTB: perf: Fix race condition when run with ntb_test
  (git-fixes).
- NTB: perf: Fix support for hardware that doesn't have port
  numbers (git-fixes).
- NTB: perf: Don't require one more memory window than number
  of peers (git-fixes).
- NTB: ntb_pingpong: Choose doorbells based on port number
  (git-fixes).
- NTB: Fix the default port and peer numbers for legacy drivers
  (git-fixes).
- NTB: Revert the change to use the NTB device dev for DMA
  allocations (git-fixes).
- NTB: ntb_tool: reading the link file should not end in a NULL
  byte (git-fixes).
- ntb_tool: pass correct struct device to dma_alloc_coherent
  (git-fixes).
- ntb_perf: pass correct struct device to dma_alloc_coherent
  (git-fixes).
- ntb: hw: remove the code that sets the DMA mask (git-fixes).
- NTB: Fix static check warning in perf_clear_test (git-fixes).
- habanalabs: increase timeout during reset (git-fixes).
- commit 6d2dc2c
* Tue Jul 28 2020 tiwai@suse.de
- geneve: fix an uninitialized value in geneve_changelink()
  (git-fixes).
- ieee802154: fix one possible memleak in adf7242_probe
  (git-fixes).
- nfc: nci: add missed destroy_workqueue in nci_register_device
  (git-fixes).
- hippi: Fix a size used in a 'pci_free_consistent()' in an
  error handling path (git-fixes).
- i2c: i2c-qcom-geni: Fix DMA transfer race (git-fixes).
- i2c: rcar: always clear ICSAR to avoid side effects (git-fixes).
- Revert "i2c: cadence: Fix the hold bit setting" (git-fixes).
- drm/amd/powerplay: fix a crash when overclocking Vega M
  (git-fixes).
- drm: sun4i: hdmi: Fix inverted HPD result (git-fixes).
- phy: sun4i-usb: fix dereference of pointer phy0 before it is
  null checked (git-fixes).
- commit ce8f443
* Tue Jul 28 2020 tiwai@suse.de
- fpga: dfl: fix bug in port reset handshake (git-fixes).
- staging: comedi: addi_apci_1564: check INSN_CONFIG_DIGITAL_TRIG
  shift (git-fixes).
- staging: comedi: addi_apci_1500: check INSN_CONFIG_DIGITAL_TRIG
  shift (git-fixes).
- staging: comedi: addi_apci_1032: check INSN_CONFIG_DIGITAL_TRIG
  shift (git-fixes).
- staging: comedi: ni_6527: fix INSN_CONFIG_DIGITAL_TRIG support
  (git-fixes).
- usb: tegra: Fix allocation for the FPCI context (git-fixes).
- usb: xhci-mtk: fix the failure of bandwidth allocation
  (git-fixes).
- commit c8a893b
* Tue Jul 28 2020 tiwai@suse.de
- ath9k: Fix regression with Atheros 9271 (git-fixes).
- ath9k: Fix general protection fault in ath9k_hif_usb_rx_cb
  (git-fixes).
- commit 86f66b0
* Tue Jul 28 2020 tiwai@suse.de
- blacklist.conf: remove ath9k commit and add phy/realtek commit
- commit d6994a7
* Tue Jul 28 2020 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: Enable overlayfs
  Overlayfs is needed for podman or docker builds when no more specific
  driver can be used (like lvm or btrfs). As the default build fs is ext4
  currently, we need overlayfs kernel modules to be available.
- commit 29474aa
* Tue Jul 28 2020 jslaby@suse.cz
- vgacon: fix out of bounds write to the scrollback buffer
  (bsc#1174205 CVE-2020-14331).
- commit ffe1c3f
* Mon Jul 27 2020 tiwai@suse.de
- tpm_crb: fix fTPM on AMD Zen+ CPUs (bsc#1174362).
- commit 244d11a
* Mon Jul 27 2020 dwagner@suse.de
- scsi: libfc: Skip additional kref updating work event
  (bsc#1173849).
- scsi: libfc: Handling of extra kref (bsc#1173849).
- scsi: libfc: rport state move to PLOGI if all PRLI retry
  exhausted (bsc#1173849).
- scsi: libfc: If PRLI rejected, move rport to PLOGI state
  (bsc#1173849).
- scsi: libfc: free response frame from GPN_ID (bsc#1173849).
- commit e4b0418
* Mon Jul 27 2020 jslaby@suse.cz
- /dev/mem: Add missing memory barriers for devmem_inode
  (git-fixes).
- commit faada70
* Mon Jul 27 2020 mkubecek@suse.cz
- fix paches metadata
- fix Patch-mainline:
  patches.suse/NFS-Fix-interrupted-slots-by-sending-a-solo-SEQUENCE.patch
  patches.suse/sunrpc-Fix-gss_unwrap_resp_integ-again.patch
- commit 8700f50
* Mon Jul 27 2020 jslaby@suse.cz
- /dev/mem: Revoke mappings when a driver claims the region
  (git-fixes).
- commit 12e79d4
* Mon Jul 27 2020 vbabka@suse.cz
- mm/mmap.c: close race between munmap() and
  expand_upwards()/downwards() (bsc#1174527).
- commit 8d322cd
* Mon Jul 27 2020 acho@suse.com
- Bluetooth: Disconnect if E0 is used for Level 4 (bsc#1171988
  CVE-2020-10135).
- Bluetooth: Consolidate encryption handling in hci_encrypt_cfm
  (bsc#1171988 CVE-2020-10135).
- commit 247f41e
* Mon Jul 27 2020 jslaby@suse.cz
- udp: Improve load balancing for SO_REUSEPORT (git-fixes).
- udp: Copy has_conns in reuseport_grow() (git-fixes).
- net/smc: fix restoring of fallback changes (git-fixes).
- ax88172a: fix ax88172a_unbind() failures (git-fixes).
- ovl: inode reference leak in ovl_is_inuse true case (git-fixes).
- commit 8886a83
* Mon Jul 27 2020 tbogendoerfer@suse.de
- IB/hfi1: Fix module use count flaw due to leftover module put
  calls (bsc#1174407).
- IB/hfi1: Fix another case where pq is left on waitlist
  (bsc#1174411).
- commit 4615f3f
* Mon Jul 27 2020 tiwai@suse.de
- PCI/EDR: Log only ACPI_NOTIFY_DISCONNECT_RECOVER events
  (bsc#1174513).
- commit 4124752
* Mon Jul 27 2020 neilb@suse.de
- kabi fix for SUNRPC-dont-update-timeout-value-on-connection-reset.patch
  (bsc1174263).
- commit b2c60a4
* Mon Jul 27 2020 neilb@suse.de
- SUNRPC dont update timeout value on connection reset
  (bsc#1174263).
- NFS: Fix interrupted slots by sending a solo SEQUENCE operation
  (bsc#1174264).
- commit a34253a
* Mon Jul 27 2020 neilb@suse.de
- sunrpc: Fix gss_unwrap_resp_integ() again (bsc#1174116).
- commit 74de0ef
* Mon Jul 27 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into sorted section:
  patches.suse/sched-Fix-race-against-ptrace_freeze_trace.patch
- commit d3c68dc
* Sun Jul 26 2020 tiwai@suse.de
- arm64: dts: ls1046ardb: set RGMII interfaces to RGMII_ID mode
  (bsc#1174398).
- arm64: dts: ls1043a-rdb: correct RGMII delay mode to rgmii-id
  (bsc#1174398).
- net: fsl/fman: treat all RGMII modes in memac_adjust_link()
  (bsc#1174398).
- commit 9181d93
* Sun Jul 26 2020 tiwai@suse.de
- net: phy: realtek: add support for configuring the RX delay
  on RTL8211F (bsc#1174398).
- commit f56681f
* Sat Jul 25 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/sched-fair-handle-case-of-task_h_load-returning-0.patch
- commit 48a221d
* Fri Jul 24 2020 mgorman@suse.de
- sched/fair: handle case of task_h_load() returning 0
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit ea548c6
* Fri Jul 24 2020 mgorman@suse.de
- Refresh patches.suse/sched-Fix-loadavg-accounting-race.patch.
- commit 1d3f65b
* Fri Jul 24 2020 tbogendoerfer@suse.de
- IB/hfi1: Do not destroy link_wq when the device is shut down
  (bsc#1174409).
- IB/hfi1: Do not destroy hfi1_wq when the device is shut down
  (bsc#1174409).
- commit 469cd59
* Fri Jul 24 2020 tiwai@suse.de
- Update patch reference tag for cdev security fix (CVE-2020-0305, bsc#1174462)
- commit 589a02e
* Thu Jul 23 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/btrfs-add-assertions-for-tree-inode-io_tree-to-exten.patch
  patches.suse/btrfs-drop-argument-tree-from-btrfs_lock_and_flush_o.patch
  patches.suse/btrfs-use-correct-count-in-btrfs_file_write_iter.patch
- commit 06e9b7f
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: fix RWF_NOWAIT writes blocking on extent locks and
  waiting for IO (bsc#1174438).
- commit 6283198
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: drop argument tree from
  btrfs_lock_and_flush_ordered_range (bsc#1174438).
- commit fddc7a9
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: add assertions for tree == inode->io_tree to extent IO
  helpers (bsc#1174438).
- commit b6577c1
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: fix RWF_NOWAIT write not failling when we need to cow
  (bsc#1174438).
- commit 5cd33df
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: fix failure of RWF_NOWAIT write into prealloc extent
  beyond eof (bsc#1174438).
- commit e8b9f70
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: fix hang on snapshot creation after RWF_NOWAIT write
  (bsc#1174438).
- commit b6d39e5
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: use correct count in btrfs_file_write_iter()
  (bsc#1174438).
- commit b0f2e4b
* Thu Jul 23 2020 ykaukab@suse.de
- dpaa_eth: Make dpaa_a050385_wa static (bsc#1174396).
- dpaa_eth: FMan erratum A050385 workaround (bsc#1174396).
- commit 28d087a
* Thu Jul 23 2020 ykaukab@suse.de
- fsl/fman: detect FMan erratum A050385 (bsc#1174396)
  Update arm64 config file
- commit f586da0
* Thu Jul 23 2020 ohering@suse.de
- PCI: hv: Add support for protocol 1.3 and support
  PCI_BUS_RELATIONS2 (bsc#1172201).
- commit 901fe3f
* Thu Jul 23 2020 oneukum@suse.com
- media: cec: silence shift wrapping warning in
  __cec_s_log_addrs() (git-fixes).
- commit 78dd0ad
* Thu Jul 23 2020 oneukum@suse.com
- blacklist.conf: for future infrastructure, and will need kABI workarounds in each user, only if we really need it
- commit 5125020
* Thu Jul 23 2020 oneukum@suse.com
- blacklist.conf: cleanup removing unused exported symbols, unavoidable kABI breakage
- commit 5042b86
* Thu Jul 23 2020 tiwai@suse.de
- ALSA: hda/realtek: Fixed ALC298 sound bug by adding quirk for
  Samsung Notebook Pen S (git-fixes).
- ASoC: rt5682: Report the button event in the headset type only
  (git-fixes).
- ASoC: Intel: bytcht_es8316: Add missed put_device() (git-fixes).
- ASoC: rt286: fix unexpected interrupt happens (git-fixes).
- ASoC: wm8974: remove unsupported clock mode (git-fixes).
- ASoC: wm8974: fix Boost Mixer Aux Switch (git-fixes).
- ASoC: topology: fix tlvs in error handling for widget_dmixer
  (git-fixes).
- ASoC: topology: fix kernel oops on route addition error
  (git-fixes).
- ASoc: codecs: max98373: remove Idle_bias_on to let codec suspend
  (git-fixes).
- ASoC: codecs: max98373: Removed superfluous volume control
  from chip default (git-fixes).
- ASoC: rockchip: add format and rate constraints on rk3399
  (git-fixes).
- ASoC: rt5670: Fix dac- and adc- vol-tlv values being off by
  a factor of 10 (git-fixes).
- ASoC: rt5670: Add new gpio1_is_ext_spk_en quirk and enable it
  on the Lenovo Miix 2 10 (git-fixes).
- ASoC: rt5670: Correct RT5670_LDO_SEL_MASK (git-fixes).
- ALSA: info: Drop WARN_ON() from buffer NULL sanity check
  (git-fixes).
- USB: serial: option: add Quectel EG95 LTE modem (git-fixes).
- USB: serial: ch341: add new Product ID for CH340 (git-fixes).
- USB: serial: option: add GosunCn GM500 series (git-fixes).
- USB: serial: cypress_m8: enable Simply Automated UPB PIM
  (git-fixes).
- HID: quirks: Ignore Simply Automated UPB PIM (git-fixes).
- HID: magicmouse: do not set up autorepeat (git-fixes).
- HID: quirks: Always poll Obins Anne Pro 2 keyboard (git-fixes).
- drm/amdgpu/sdma5: fix wptr overwritten in ->get_wptr()
  (git-fixes).
- intel_th: pci: Add Emmitsburg PCH support (git-fixes).
- intel_th: pci: Add Tiger Lake PCH-H support (git-fixes).
- intel_th: pci: Add Jasper Lake CPU support (git-fixes).
- mei: bus: don't clean driver pointer (git-fixes).
- thermal: int3403_thermal: Downgrade error message (git-fixes).
- Input: elan_i2c - add more hardware ID for Lenovo laptops
  (git-fixes).
- Input: i8042 - add Lenovo XiaoXin Air 12 to i8042 nomux list
  (git-fixes).
- i2c: eg20t: Load module automatically if ID matches (git-fixes).
- drm/exynos: fix ref count leak in mic_pre_enable (git-fixes).
- drm/exynos: Properly propagate return value in
  drm_iommu_attach_device() (git-fixes).
- drm/msm/dpu: allow initialization of encoder locks during
  encoder init (git-fixes).
- drm/msm: fix potential memleak in error branch (git-fixes).
- tpm_tis: extra chip->ops check on error path in
  tpm_tis_core_init (git-fixes).
- thermal/drivers: imx: Fix missing of_node_put() at probe time
  (git-fixes).
- ALSA: usb-audio: Add registration quirk for Kingston HyperX
  Cloud Flight S (git-fixes).
- spi: spidev: fix a potential use-after-free in spidev_release()
  (git-fixes).
- spi: spidev: fix a race between spidev_release and spidev_remove
  (git-fixes).
- Input: mms114 - add extra compatible for mms345l (git-fixes).
- ACPI: video: Use native backlight on Acer TravelMate 5735Z
  (git-fixes).
- Input: goodix - fix touch coordinates on Cube I15-TC
  (git-fixes).
- ACPI: video: Use native backlight on Acer Aspire 5783z
  (git-fixes).
- drm/sun4i: tcon: Separate quirks for tcon0 and tcon1 on A20
  (git-fixes).
- HID: quirks: Remove ITE 8595 entry from hid_have_special_driver
  (git-fixes).
- mmc: sdhci: do not enable card detect interrupt for gpio cd type
  (git-fixes).
- commit d00f168
* Wed Jul 22 2020 lduncan@suse.com
- blk-mq: consider non-idle request as "inflight" in
  blk_mq_rq_inflight() (bsc#1165933).
- dm: do not use waitqueue for request-based DM (bsc#1165933).
- commit 07e428e
* Wed Jul 22 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/brcmfmac-Transform-compatible-string-for-FW-loading.patch
- commit 75a973a
* Wed Jul 22 2020 tbogendoerfer@suse.de
- net/mlx5e: Fix CPU mapping after function reload to avoid aRFS
  RX crash (jsc#SLE-8464).
- net/mlx5e: Fix VXLAN configuration restore after function reload
  (jsc#SLE-8464).
- ionic: centralize queue reset code (bsc#1167773).
- net: hns3: check reset pending after FLR prepare (bsc#1154353).
- net: ipv4: Fix wrong type conversion from hint to rt in
  ip_route_use_hint() (bsc#1154353).
- ionic: update the queue count on open (bsc#1167773).
- commit 7491bf6
* Tue Jul 21 2020 tiwai@suse.de
- pci: Revive pci_dev __aer_firmware_first* fields for kABI
  (bsc#1174356).
- commit 4d2fe32
* Tue Jul 21 2020 tiwai@suse.de
- PCI/AER: Remove HEST/FIRMWARE_FIRST parsing for AER ownership
  (bsc#1174356).
- PCI/AER: Use only _OSC to determine AER ownership (bsc#1174356).
- commit 6e69c19
* Tue Jul 21 2020 ykaukab@suse.de
- Refresh
  patches.suse/clk-qoriq-add-cpufreq-platform-device.patch.
- commit 5dec1a6
* Tue Jul 21 2020 ykaukab@suse.de
- Refresh
  patches.suse/cpufreq-qoriq-convert-to-a-platform-driver.patch.
- commit cf18c2c
* Tue Jul 21 2020 ykaukab@suse.de
- Refresh
  patches.suse/gpio-tegra186-export-MODULE_DEVICE_TABLE.patch.
- commit 3a8c8f1
* Tue Jul 21 2020 ykaukab@suse.de
- Refresh
  patches.suse/soc-tegra-pmc-Enable-PMIC-wake-event-on-Tegra186.patch.
- commit d3492b2
* Tue Jul 21 2020 ykaukab@suse.de
- Refresh
  patches.suse/cpufreq-tegra186-add-CPUFREQ_NEED_INITIAL_FREQ_CHECK.patch.
- commit 8dcc9fc
* Tue Jul 21 2020 mgorman@suse.de
- sched: Fix race against ptrace_freeze_trace() (bsc#1174345).
- commit 2138587
* Tue Jul 21 2020 jslaby@suse.cz
- net/mlx5e: Fix repeated XSK usage on one channel
  (networking-stable-20_06_16).
- net/mlx5: Fix fatal error handling during device load
  (networking-stable-20_06_16).
- net/mlx5: drain health workqueue in case of driver load error
  (networking-stable-20_06_16).
- selftests/net: in rxtimestamp getopt_long needs terminating
  null entry (networking-stable-20_06_16).
- dccp: Fix possible memleak in dccp_init and dccp_fini
  (networking-stable-20_06_16).
- mlxsw: core: Use different get_trend() callbacks for different
  thermal zones (networking-stable-20_06_10).
- net_failover: fixed rollback in net_failover_open()
  (networking-stable-20_06_10).
- vxlan: Avoid infinite loop when suppressing NS messages with
  invalid options (networking-stable-20_06_10).
- bridge: Avoid infinite loop when suppressing NS messages with
  invalid options (networking-stable-20_06_10).
- l2tp: add sk_family checks to l2tp_validate_socket
  (networking-stable-20_06_07).
- l2tp: do not use inet_hash()/inet_unhash()
  (networking-stable-20_06_07).
- kABI: reintroduce inet_hashtables.h include to l2tp_ip (kabi).
- devinet: fix memleak in inetdev_init()
  (networking-stable-20_06_07).
- net: be more gentle about silly gso requests coming from user
  (networking-stable-20_06_07).
- vsock: fix timeout in vsock_accept()
  (networking-stable-20_06_07).
- nfp: flower: fix used time of merge flow statistics
  (networking-stable-20_06_07).
- net: usb: qmi_wwan: add Telit LE910C1-EUX composition
  (networking-stable-20_06_07).
- net: check untrusted gso_size at kernel entry
  (networking-stable-20_06_07).
- net: stmmac: enable timestamp snapshot for required PTP packets
  in dwmac v5.10a (networking-stable-20_06_07).
- commit 9e80866
* Tue Jul 21 2020 tiwai@suse.de
- USB: serial: iuu_phoenix: fix memory corruption (git-fixes).
- usb: gadget: function: fix missing spinlock in f_uac1_legacy
  (git-fixes).
- usb: gadget: udc: atmel: fix uninitialized read in debug printk
  (git-fixes).
- usb: gadget: udc: atmel: remove outdated comment in
  usba_ep_disable() (git-fixes).
- usb: dwc2: Fix shutdown callback in platform (git-fixes).
- USB: c67x00: fix use after free in c67x00_giveback_urb
  (git-fixes).
- usb: chipidea: core: add wakeup support for extcon (git-fixes).
- hwmon: (emc2103) fix unable to change fan pwm1_enable attribute
  (git-fixes).
- intel_th: Fix a NULL dereference when hub driver is not loaded
  (git-fixes).
- virt: vbox: Fix guest capabilities mask check (git-fixes).
- virt: vbox: Fix VBGL_IOCTL_VMMDEV_REQUEST_BIG and _LOG req
  numbers to match upstream (git-fixes).
- iio: adc: ad7780: Fix a resource handling path in
  'ad7780_probe()' (git-fixes).
- iio:pressure:ms5611 Fix buffer element alignment (git-fixes).
- iio:humidity:hts221 Fix alignment and data leak issues
  (git-fixes).
- iio:humidity:hdc100x Fix alignment and data leak issues
  (git-fixes).
- iio:magnetometer:ak8974: Fix alignment and data leak issues
  (git-fixes).
- iio: pressure: zpa2326: handle pm_runtime_get_sync failure
  (git-fixes).
- iio: core: add missing IIO_MOD_H2/ETHANOL string identifiers
  (git-fixes).
- iio: magnetometer: ak8974: Fix runtime PM imbalance on error
  (git-fixes).
- iio: mma8452: Add missed iio_device_unregister() call in
  mma8452_probe() (git-fixes).
- iio:health:afe4404 Fix timestamp alignment and prevent data leak
  (git-fixes).
- dmaengine: dmatest: stop completed threads when running without
  set channel (git-fixes).
- dmaengine: fsl-edma-common: correct DSIZE_32BYTE (git-fixes).
- dmaengine: dw: Initialize channel before each transfer
  (git-fixes).
- dmaengine: mcf-edma: Fix NULL pointer exception in
  mcf_edma_tx_handler (git-fixes).
- dmaengine: fsl-edma: Fix NULL pointer exception in
  fsl_edma_tx_handler (git-fixes).
- dmaengine: sh: usb-dmac: set tx_result parameters (git-fixes).
- dmaengine: imx-sdma: Fix: Remove 'always true' comparison
  (git-fixes).
- keys: asymmetric: fix error return code in software_key_query()
  (git-fixes).
- mmc: meson-gx: limit segments to 1 when dram-access-quirk is
  needed (git-fixes).
- usbnet: smsc95xx: Fix use-after-free after removal (git-fixes).
- hwrng: ks-sa - Fix runtime PM imbalance on error (git-fixes).
- drm/amd/display: Use kfree() to free rgb_user in
  calculate_user_regamma_ramp() (git-fixes).
- usb: gadget: Fix issue with config_ep_by_speed function
  (git-fixes).
- ACPICA: Dispatcher: add status checks (git-fixes).
- ACPI/IORT: Fix PMCG node single ID mapping handling (git-fixes).
- commit b0f8c80
* Mon Jul 20 2020 dbueso@suse.de
- percpu: Separate decrypted varaibles anytime encryption can
  be enabled (bsc#1174332).
- selinux: fall back to ref-walk if audit is required
  (bsc#1174333).
- selinux: revert "stop passing MAY_NOT_BLOCK to the AVC upon
  follow_link" (bsc#1174333).
- lib: Reduce user_access_begin() boundaries in
  strncpy_from_user() and strnlen_user() (bsc#1174331).
- commit 444a65c
* Mon Jul 20 2020 msuchanek@suse.de
- powerpc/book3s64/pkeys: Fix pkey_access_permitted() for execute
  disable pkey (bsc#1065729).
- commit c00b49a
* Sat Jul 18 2020 mkubecek@suse.cz
- fix bdev inode reference count disbalance regression (bsc#1174244)
  Update patches.suse/bdev-add-open_finish.patch to adapt to changes
  introduced by patches.suse/block-Fix-use-after-free-in-blkdev_get.patch
  (backport of mainline commit 2d3a8e2dedde).
- commit 7efbe7b
* Sat Jul 18 2020 tiwai@suse.de
- bus: ti-sysc: Do not disable on suspend for no-idle (git-fixes).
- spi: spi-sun6i: sun6i_spi_transfer_one(): fix setting of clock
  rate (git-fixes).
- regmap: debugfs: Don't sleep while atomic for fast_io regmaps
  (git-fixes).
- HID: logitech-hidpp: avoid repeated "multiplier = " log messages
  (git-fixes).
- drm/i915/gt: Ignore irq enabling on the virtual engines
  (git-fixes).
- virtio: virtio_console: add missing MODULE_DEVICE_TABLE()
  for rproc serial (git-fixes).
- soundwire: intel: fix memory leak with devm_kasprintf
  (git-fixes).
- staging: comedi: verify array index is correct before using it
  (git-fixes).
- Revert "thermal: mediatek: fix register index error"
  (git-fixes).
- gpio: pca953x: Fix GPIO resource leak on Intel Galileo Gen 2
  (git-fixes).
- gpio: pca953x: disable regmap locking for automatic address
  incrementing (git-fixes).
- gpio: pca953x: Override IRQ for one of the expanders on Galileo
  Gen 2 (git-fixes).
- drm/amdgpu: don't do soft recovery if gpu_recovery=0
  (git-fixes).
- drm/radeon: fix double free (git-fixes).
- drm/mediatek: Check plane visibility in atomic_update
  (git-fixes).
- drm/amdgpu: use %%u rather than %%d for sclk/mclk (git-fixes).
- drm/amdgpu/atomfirmware: fix vram_info fetching for renoir
  (git-fixes).
- usb: dwc3: pci: Fix reference count leak in dwc3_pci_resume_work
  (git-fixes).
- drm: panel-orientation-quirks: Use generic orientation-data
  for Acer S1003 (git-fixes).
- drm: panel-orientation-quirks: Add quirk for Asus T101HA panel
  (git-fixes).
- drm: mcde: Fix display initialization problem (git-fixes).
- gpu: host1x: Detach driver on unregister (git-fixes).
- drm/tegra: hub: Do not enable orphaned window group (git-fixes).
- regmap: Fix memory leak from regmap_register_patch (git-fixes).
- regmap: fix alignment issue (git-fixes).
- commit c917659
* Sat Jul 18 2020 tiwai@suse.de
- ALSA: hda/realtek - fixup for yet another Intel reference board
  (git-fixes).
- ALSA: hda/realtek - Enable Speaker for ASUS UX563 (git-fixes).
- ALSA: hda/realtek - Enable Speaker for ASUS UX533 and UX534
  (git-fixes).
- ALSA: hda/realtek: Enable headset mic of Acer TravelMate
  B311R-31 with ALC256 (git-fixes).
- ALSA: hda/realtek: enable headset mic of ASUS ROG Zephyrus
  G14(G401) series with ALC289 (git-fixes).
- ALSA: hda/realtek - change to suitable link model for ASUS
  platform (git-fixes).
- ALSA: usb-audio: Fix race against the error recovery URB
  submission (git-fixes).
- ALSA: line6: Sync the pending work cancel at disconnection
  (git-fixes).
- ALSA: line6: Perform sanity check for each URB creation
  (git-fixes).
- commit 9ce2855
* Fri Jul 17 2020 ptesarik@suse.cz
- scsi: zfcp: Fix panic on ERP timeout for previously dismissed
  ERP action (git-fixes).
- s390/qeth: fix error handling for isolation mode cmds
  (git-fixes).
- s390: fix syscall_get_error for compat processes (git-fixes).
- s390/qdio: put thinint indicator after early error (git-fixes).
- s390/qdio: tear down thinint indicator after early error
  (git-fixes).
- s390/qdio: consistently restore the IRQ handler (git-fixes).
- s390/kaslr: add support for R_390_JMP_SLOT relocation type
  (git-fixes).
- s390/pci: Fix s390_mmio_read/write with MIO (git-fixes).
- s390/ism: fix error return code in ism_probe() (git-fixes).
- commit 06ae989
* Fri Jul 17 2020 tiwai@suse.de
- blacklist.conf: Add superfluous stable commit IDs
- commit 89408b6
* Fri Jul 17 2020 mkubecek@suse.cz
- netfilter: ip6tables: Add a .pre_exit hook in all ip6table_foo.c
  (bsc#1171857).
- netfilter: ip6tables: Split ip6t_unregister_table() into
  pre_exit and exit helpers (bsc#1171857).
- netfilter: iptables: Add a .pre_exit hook in all iptable_foo.c
  (bsc#1171857).
- netfilter: iptables: Split ipt_unregister_table() into pre_exit
  and exit helpers (bsc#1171857).
- commit cb31b4c
* Fri Jul 17 2020 glin@suse.com
- bpf: Do not allow btf_ctx_access with __int128 types
  (bsc#1155518).
- commit 60b474b
* Thu Jul 16 2020 msuchanek@suse.de
- powerpc/fadump: fix race between pstore write and fadump crash
  trigger (bsc#1168959 ltc#185010).
- commit 2b958e4
* Thu Jul 16 2020 msuchanek@suse.de
- powerpc/xmon: Reset RCU and soft lockup watchdogs (bsc#1065729).
- commit 6d8c5ea
* Thu Jul 16 2020 kbuild@suse.de
- Delete patches.kabi/* workarounds
- commit db10c36
* Thu Jul 16 2020 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section
  patches.suse/revert-zram-convert-remaining-class_attr-to-class_attr_ro
- commit 2caa587
* Thu Jul 16 2020 tiwai@suse.de
- platform/x86: ISST: Increase timeout (bsc#1174185).
- commit 1a0cfdb
* Thu Jul 16 2020 tiwai@suse.de
- Update patch reference tag for ACPI configfs security fix (CVE-2020-15780, bsc#1173573).
- commit 4d52b6d
* Wed Jul 15 2020 tiwai@suse.de
- mfd: intel-lpss: Add Intel Jasper Lake PCI IDs (jsc#SLE-12602).
- commit f068576
* Wed Jul 15 2020 tiwai@suse.de
- pinctrl: intel: Add Intel Jasper Lake pin controller support
  (jsc#SLE-12984).
- Update config files: enable CONFIG_PINCTRL_JASPERLAKE=m
- supported.conf: add pinctrl-jasperlake
- commit 3eef821
* Wed Jul 15 2020 tiwai@suse.de
- pinctrl: intel: Introduce new flag to force GPIO base to be 0
  (jsc#SLE-12984).
- pinctrl: intel: Introduce common flags for GPIO mapping scheme
  (jsc#SLE-12984).
- commit b69818a
* Wed Jul 15 2020 jslaby@suse.cz
- bridge: mcast: Fix MLD2 Report IPv6 payload length check
  (git-fixes).
- tcp: md5: allow changing MD5 keys in all socket states
  (git-fixes).
- nbd: Fix memory leak in nbd_add_socket (git-fixes).
- SMB3: Honor lease disabling for multiuser mounts (git-fixes).
- net: macb: call pm_runtime_put_sync on failure path (git-fixes).
- net: dsa: bcm_sf2: Fix node reference count (git-fixes).
- scsi: ufs-bsg: Fix runtime PM imbalance on error (git-fixes).
- tty: hvc_console, fix crashes on parallel open/close
  (git-fixes).
- workqueue: Remove unnecessary kfree() call in rcu_free_wq()
  (git-fixes).
- powerpc/kasan: Fix issues by lowering KASAN_SHADOW_END
  (git-fixes).
- KVM: nVMX: always update CR3 in VMCS (git-fixes).
- net/tls: free record only on encryption error (git-fixes).
- net/tls: fix encryption error checking (git-fixes).
- commit ed61f4d
* Wed Jul 15 2020 mbrugger@suse.com
- brcmfmac: Transform compatible string for FW loading
  (bsc#1169771).
- commit 6bdc85b
* Tue Jul 14 2020 rgoldwyn@suse.com
- exfat: move setting VOL_DIRTY over exfat_remove_entries()
  (git-fixes).
- exfat: add missing brelse() calls on error paths  (git-fixes).
- fuse: copy_file_range should truncate cache  (git-fixes).
- fuse: fix copy_file_range cache issues  (git-fixes).
- exfat: fix incorrect update of stream entry in
  __exfat_truncate()  (git-fixes).
- exfat: fix memory leak in exfat_parse_param()  (git-fixes).
- apparmor: Fix memory leak of profile proxy  (git-fixes).
- apparmor: fix introspection of of task mode for unconfined tasks
  (git-fixes).
- apparmor: ensure that dfa state tables have entries
  (git-fixes).
- apparmor: remove useless aafs_create_symlink  (git-fixes).
- apparmor: Fix use-after-free in aa_audit_rule_init  (git-fixes).
- commit 094ca51
* Tue Jul 14 2020 jroedel@suse.de
- blacklist.conf: Add 9486727f5981 iommu/vt-d: Make Intel SVM code 64-bit only
- commit 6287dc6
* Tue Jul 14 2020 jroedel@suse.de
- vfio/pci: Fix SR-IOV VF handling with MMIO blocking
  (bsc#1174129).
- iommu/vt-d: Update scalable mode paging structure coherency
  (bsc#1174128).
- iommu/vt-d: Enable PCI ACS for platform opt in hint
  (bsc#1174127).
- iommu/arm-smmu-v3: Don't reserve implementation defined register
  space (bsc#1174126).
- commit 4b65886
* Tue Jul 14 2020 lduncan@suse.com
- Revert "zram: convert remaining CLASS_ATTR() to CLASS_ATTR_RO()"
  (bsc#1173074 CVE-2020-10781).
- commit d59a129
* Tue Jul 14 2020 oneukum@suse.com
- padata: kABI fixup for struct padata_instance splitting nodes
  (git-fixes).
- commit 03321ff
* Tue Jul 14 2020 oneukum@suse.com
- padata: add separate cpuhp node for CPUHP_PADATA_DEAD
  (git-fixes).
- commit 3966f99
* Tue Jul 14 2020 msuchanek@suse.de
- Remove 15 SP2 kABI files.
- commit 1ebbbe1
* Mon Jul 13 2020 mkubecek@suse.cz
- Update kabi files.
- update to first maintenance update submission (commit eabfb0896fac)
- commit 9da6523
* Mon Jul 13 2020 tiwai@suse.de
- watchdog: iTCO: Add support for Cannon Lake PCH iTCO
  (jsc#SLE-13202).
- commit e9c44ca
* Mon Jul 13 2020 tiwai@suse.de
- ALSA: hda: Intel: add missing PCI IDs for ICL-H, TGL-H and EKL
  (jsc#SLE-13261).
- commit 137c3b6
* Mon Jul 13 2020 ykaukab@suse.de
- serial: 8250_tegra: Create Tegra specific 8250 driver (bsc#1173941).
- Update config files.
- commit 3b0dd22
* Mon Jul 13 2020 ykaukab@suse.de
- net: stmmac: don't attach interface until resume finishes
  (bsc#1174072).
- net: stmmac: dwc-qos: avoid clk and reset for acpi device
  (bsc#1174072).
- net: stmmac: dwc-qos: use generic device api (bsc#1174072).
- net: stmmac: platform: fix probe for ACPI devices (bsc#1174072).
- commit 05074b1
* Mon Jul 13 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/net-smc-tolerate-future-smcd-versions
- commit 83f40de
* Mon Jul 13 2020 mkubecek@suse.cz
- Fix
  patches.suse/media-mtk-vpu-avoid-unaligned-access-to-DTCM-buffer.patch
  (fix build without the kabi fix)
- Refresh
  patches.kabi/kABI-fixup-mtk-vpu-avoid-unaligned-access-to-DTCM-buffer.patch
  This commit has no effect on expanded tree but it fixes build without
  patches.kabi/* (so that it will be needed for SLE15-SP3).
- commit 62b468e
* Mon Jul 13 2020 ptesarik@suse.cz
- net/smc: tolerate future SMCD versions (bsc#1172543 LTC#186069).
- commit fd05166
* Mon Jul 13 2020 ohering@suse.de
- hv_netvsc: Fix netvsc_start_xmit's return type (git-fixes).
- commit 5b7bc98
* Mon Jul 13 2020 msuchanek@suse.de
- dm writecache: reject asynchronous pmem devices (bsc#1156395).
- commit 26f82f2
* Fri Jul 10 2020 mkoutny@suse.com
- fork: prevent accidental access to clone3 features
  (bsc#1174018).
- commit 8b81b50
* Fri Jul 10 2020 mkoutny@suse.com
- signal: Avoid corrupting si_pid and si_uid in do_notify_parent
  (bsc#1171529).
- commit eb37c8d
* Fri Jul 10 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/ALSA-usb-audio-Fix-packet-size-calculation.patch
- commit f5de6d1
* Fri Jul 10 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/NFSv4-fix-CLOSE-not-waiting-for-direct-IO-compeletio.patch
  patches.suse/SUNRPC-Properly-set-the-subbuf-parameter-of-xdr_buf_.patch
  patches.suse/libceph-don-t-omit-recovery_deletes-in-target_copy.patch
  patches.suse/nfsd-apply-umask-on-fs-without-ACL-support.patch
  patches.suse/nfsd-fix-nfsdfs-inode-reference-count-leak.patch
  patches.suse/nfsd4-fix-nfsdfs-reference-count-loop.patch
  patches.suse/pNFS-flexfiles-Fix-list-corruption-if-the-mirror-cou.patch
  patches.suse/sunrpc-fixed-rollback-in-rpc_gssd_dummy_populate.patch
  patches.suse/xprtrdma-Fix-handling-of-RDMA_ERROR-replies.patch
- commit ad850c9
* Fri Jul 10 2020 dwagner@suse.de
- net: core: device_rename: Use rwsem instead of a seqcount
  (bsc#1162702).
- commit 7a01d9d
* Fri Jul 10 2020 ohering@suse.de
- kabi: hv: prevent struct device_node to become defined
  (bsc#1172871).
- PCI: hv: Retry PCI bus D0 entry on invalid device state
  (bsc#1172871).
- PCI: hv: Fix the PCI HyperV probe failure path to release
  resource properly (bsc#1172871).
- PCI: hv: Introduce hv_msi_entry (bsc#1172871).
- PCI: hv: Move retarget related structures into tlfs header
  (bsc#1172871).
- PCI: hv: Move hypercall related definitions into tlfs header
  (bsc#1172871).
- PCI: hv: Decouple the func definition in hv_dr_state from VSP
  message (bsc#1172871).
- PCI: hv: Change pci_protocol_version to per-hbus (bsc#1172871).
- PCI: hv: Reorganize the code in preparation of hibernation
  (bsc#1172871).
- commit 35a7d93
* Fri Jul 10 2020 ohering@suse.de
- Drivers: hv: Change flag to write log level in panic msg to
  false (bsc#1170617).
- commit bcd509e
* Thu Jul  9 2020 tiwai@suse.de
- Fix boot crash with MD (bsc#1173860)
  Refresh patches.suse/mdraid-fix-read-write-bytes-accounting.patch
- commit 119f164
* Thu Jul  9 2020 dwagner@suse.de
- scsi: lpfc: Fix less-than-zero comparison of unsigned value
  (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix interrupt assignments when multiple vectors
  are supported on same CPU (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix inconsistent indenting (bsc#1172687
  bsc#1171530).
- scsi: lpfc: Update lpfc version to 12.8.0.2 (bsc#1172687
  bsc#1171530).
- scsi: lpfc: Add an internal trace log buffer (bsc#1172687
  bsc#1171530).
- scsi: lpfc: Add blk_io_poll support for latency improvment
  (bsc#1172687 bsc#1171530).
- scsi: lpfc: Add support to display if adapter dumps are
  available (bsc#1172687 bsc#1171530).
- scsi: lpfc: Allow applications to issue Common Set Features
  mailbox command (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix language in 0373 message to reflect non-error
  message (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix kdump hang on PPC (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix shost refcount mismatch when deleting vport
  (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix stack trace seen while setting rrq active
  (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix oops due to overrun when reading SLI3 data
  (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix NVMe rport deregister and registration during
  ADISC (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix missing MDS functionality (bsc#1172687
  bsc#1171530).
- scsi: lpfc: Fix unused assignment in
  lpfc_sli4_bsg_link_diag_test (bsc#1172687 bsc#1171530).
- commit fa0f156
* Thu Jul  9 2020 dwagner@suse.de
- Refresh metadata of patches.suse/ALSA-usb-audio-Fix-packet-size-calculation.patch
- commit 964e72b
* Thu Jul  9 2020 mgorman@suse.de
- series.conf: cleanup (sort)
- patches.suse/sched-core-Check-cpus_mask-not-cpus_ptr-in-__set_cpus_allowed_ptr-to-fix-mask-corruption.patch
- commit 451a6ea
* Thu Jul  9 2020 mgorman@suse.de
- sched: Fix loadavg accounting race (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- commit 38a840e
* Thu Jul  9 2020 tzimmermann@suse.de
- drm: sun4i: hdmi: Remove extra HPD polling (bsc#1152489)
- commit 9f8314c
* Thu Jul  9 2020 tzimmermann@suse.de
- drm/i915/gvt: Fix two CFL MMIO handling caused by regression. (bsc#1152489)
- commit 5522961
* Thu Jul  9 2020 tzimmermann@suse.de
- drm/msm/dpu: fix error return code in dpu_encoder_init (bsc#1152489)
- commit c65f050
* Thu Jul  9 2020 tiwai@suse.de
- ALSA: usb-audio: Add implicit feedback quirk for RTX6001
  (git-fixes).
- ALSA: usb-audio: add quirk for MacroSilicon MS2109 (git-fixes).
- ALSA: hda/realtek: Enable headset mic of Acer Veriton N4660G
  with ALC269VC (git-fixes).
- ALSA: hda/realtek: Enable headset mic of Acer C20-820 with
  ALC269VC (git-fixes).
- ALSA: hda/realtek - Enable audio jacks of Acer vCopperbox with
  ALC269VC (git-fixes).
- ALSA: hda/realtek - Fix Lenovo Thinkpad X1 Carbon 7th quirk
  subdevice id (git-fixes).
- ALSA: hda/hdmi: improve debug traces for stream lookups
  (git-fixes).
- ALSA: hda/hdmi: fix failures at PCM open on Intel ICL and later
  (git-fixes).
- ALSA: opl3: fix infoleak in opl3 (git-fixes).
- ALSA: usb-audio: Replace s/frame/packet/ where appropriate
  (git-fixes).
- ALSA: hda - let hs_mic be picked ahead of hp_mic (git-fixes).
- commit 6ae71bb
* Thu Jul  9 2020 tiwai@suse.de
- Refresh and move an upstreamed sound fix patch
- commit 7719bb1
* Wed Jul  8 2020 tiwai@suse.de
- regualtor: pfuze100: correct sw1a/sw2 on pfuze3000 (git-fixes).
- remoteproc: qcom_q6v5_mss: map/unmap mpss segments before/after
  use (git-fixes).
- slimbus: ngd: get drvdata from correct device (git-fixes).
- watchdog: da9062: No need to ping manually before setting
  timeout (git-fixes).
- commit 086dd89
* Wed Jul  8 2020 tiwai@suse.de
- drm/amd/display: Only revalidate bandwidth on medium and fast
  updates (git-fixes).
- drm/amdgpu: drop redundant cg/pg ungate on runpm enter
  (git-fixes).
- drm/amdgpu: move kfd suspend after ip_suspend_phase1
  (git-fixes).
- commit 8b89f9a
* Wed Jul  8 2020 tiwai@suse.de
- drm/amdgpu: fix the hw hang during perform system reboot and
  reset (git-fixes).
- commit edc269e
* Wed Jul  8 2020 tiwai@suse.de
- pwm: img: Call pm_runtime_put() in pm_runtime_get_sync()
  failed case (git-fixes).
- PCI: Don't disable decoding when mmio_always_on is set
  (git-fixes).
- PCI: Add Loongson vendor ID (git-fixes).
- PCI: vmd: Add device id for VMD device 8086:9A0B (git-fixes).
- commit c92f65d
* Wed Jul  8 2020 tiwai@suse.de
- media: dvbdev: Fix tuner->demod media controller link
  (git-fixes).
- media: imx: imx7-mipi-csis: Cleanup and fix subdev pad format
  handling (git-fixes).
- media: staging: imgu: do not hold spinlock during freeing mmu
  page table (git-fixes).
- media: ov5640: fix use of destroyed mutex (git-fixes).
- media: staging/intel-ipu3: Implement lock for stream on/off
  operations (git-fixes).
- commit 615fb19
* Wed Jul  8 2020 tiwai@suse.de
- Revert "i2c: tegra: Fix suspending in active runtime PM state"
  (git-fixes).
- gpio: pca953x: fix handling of automatic address incrementing
  (git-fixes).
- ipmi: use vzalloc instead of kmalloc for user creation
  (git-fixes).
- HID: Add quirks for Trust Panora Graphic Tablet (git-fixes).
- iwlwifi: mvm: fix aux station leak (git-fixes).
- commit 667aa89
* Wed Jul  8 2020 tiwai@suse.de
- drm: sun4i: hdmi: Remove extra HPD polling (git-fixes).
- drm/i915/gvt: Fix two CFL MMIO handling caused by regression
  (git-fixes).
- drm/msm/dpu: fix error return code in dpu_encoder_init
  (git-fixes).
- bus: ti-sysc: Ignore clockactivity unless specified as a quirk
  (git-fixes).
- drm/amd: fix potential memleak in err branch (git-fixes).
- drm/amdgpu: add fw release for sdma v5_0 (git-fixes).
- drm/msm/mdp5: Fix mdp5_init error path for failed mdp5_kms
  allocation (git-fixes).
- drm/amd/display: Revalidate bandwidth before commiting DC
  updates (git-fixes).
- drm/nouveau/disp/gm200-: fix NV_PDISP_SOR_HDMI2_CTRL(n)
  selection (git-fixes).
- batman-adv: Revert "disable ethtool link speed detection when
  auto negotiation off" (git-fixes).
- ath10k: fix kernel null pointer dereference (git-fixes).
- ath10k: Fix the race condition in firmware dump work queue
  (git-fixes).
- drm/amd/powerpay: Disable gfxoff when setting manual mode on
  picasso and raven (git-fixes).
- drm/amdgpu: Init data to avoid oops while reading pp_num_states
  (git-fixes).
- cpufreq: Fix up cpufreq_boost_set_sw() (git-fixes).
- cpuidle: Fix three reference count leaks (git-fixes).
- cpufreq: intel_pstate: Only mention the BIOS disabling turbo
  mode once (git-fixes).
- drm/amdgpu: fix gfx hang during suspend with video playback (v2)
  (git-fixes).
- cpufreq: powernv: Fix frame-size-overflow in
  powernv_cpufreq_work_fn (git-fixes).
- commit 8cd5c7d
* Wed Jul  8 2020 tbogendoerfer@suse.de
- bnxt_en: fix firmware message length endianness (bsc#1173894).
- bnxt_en: Fix return code to "flash_device" (bsc#1173894).
- commit 69ae6c0
* Wed Jul  8 2020 tiwai@suse.de
- Revert commit e918e570415c ("tpm_tis: Remove the HID IFX0102")
  (git-fixes).
- commit 8dc0431
* Wed Jul  8 2020 tbogendoerfer@suse.de
- ixgbe: don't check firmware errors (bsc#1170284).
- commit 37dfeb2
* Wed Jul  8 2020 tiwai@suse.de
- usb: usbtest: fix missing kfree(dev->buf) in usbtest_disconnect
  (CVE-2020-15393 bsc#1173514).
- commit 0265130
* Wed Jul  8 2020 tiwai@suse.de
- Update patch reference tag for ACPI lockdown fix (bsc#1173573)
- commit 9a83bf0
* Wed Jul  8 2020 tiwai@suse.de
- media: dvbsky: add support for eyeTV Geniatech T2 lite
  (bsc#1173776).
- media: dvbsky: add support for Mygica T230C v2 (bsc#1173776).
- media: si2168: add support for Mygica T230C v2 (bsc#1173776).
- commit d3b7a06
* Wed Jul  8 2020 oneukum@suse.com
- media: vicodec: Fix error codes in probe function (git-fixes).
- commit b82f6d2
* Wed Jul  8 2020 neilb@suse.de
- nfsd: fix nfsdfs inode reference count leak (git-fixes).
- nfsd4: fix nfsdfs reference count loop (git-fixes).
- nfsd: apply umask on fs without ACL support (git-fixes).
- SUNRPC: Properly set the @subbuf parameter of
  xdr_buf_subsegment() (git-fixes).
- NFSv4 fix CLOSE not waiting for direct IO compeletion
  (git-fixes).
- pNFS/flexfiles: Fix list corruption if the mirror count changes
  (git-fixes).
- sunrpc: fixed rollback in rpc_gssd_dummy_populate() (git-fixes).
- xprtrdma: Fix handling of RDMA_ERROR replies (git-fixes).
- libceph: don't omit recovery_deletes in target_copy()
  (git-fixes).
- commit 04a6d04
* Tue Jul  7 2020 jack@suse.cz
- jbd2: Preserve kABI when adding j_abort_mutex (bsc#1173833).
- commit 60b0b9e
* Tue Jul  7 2020 jack@suse.cz
- blacklist.conf: Blacklist 3c597282887f
- commit 4979dd4
* Tue Jul  7 2020 tiwai@suse.de
- Drop ath9k backport patch that leads to a broken WiFi (bko#208251)
  Deleted and blacklisted:
  patches.suse/ath9k-Fix-general-protection-fault-in-ath9k_hif_usb_.patch
- commit 3c2d65b
* Tue Jul  7 2020 oneukum@suse.com
- input: i8042 - Remove special PowerPC handling (git-fixes).
- commit 6f410a4
* Tue Jul  7 2020 tiwai@suse.de
- usb: renesas_usbhs: getting residue from callback_result
  (git-fixes).
- xhci: Poll for U0 after disabling USB2 LPM (git-fixes).
- xhci: Return if xHCI doesn't support LPM (git-fixes).
- usb: host: xhci-mtk: avoid runtime suspend when removing hcd
  (git-fixes).
- xhci: Fix enumeration issue when setting max packet size for
  FS devices (git-fixes).
- xhci: Fix incorrect EP_STATE_MASK (git-fixes).
- USB: ohci-sm501: Add missed iounmap() in remove (git-fixes).
- USB: ehci: reopen solution for Synopsys HC bug (git-fixes).
- usb: add USB_QUIRK_DELAY_INIT for Logitech C922 (git-fixes).
- usb: host: ehci-exynos: Fix error check in exynos_ehci_probe()
  (git-fixes).
- usb/ehci-platform: Set PM runtime as active on resume
  (git-fixes).
- usb/xhci-plat: Set PM runtime as active on resume (git-fixes).
- usb/ohci-platform: Fix a warning when hibernating (git-fixes).
- usblp: poison URBs upon disconnect (git-fixes).
- usb: host: ehci-platform: add a quirk to avoid stuck
  (git-fixes).
- commit 89437cf
* Tue Jul  7 2020 tiwai@suse.de
- ALSA: usb-audio: Fix packet size calculation (bsc#1173847).
- commit 72eb911
* Tue Jul  7 2020 tiwai@suse.de
- ASoC: Intel: bytcr_rt5640: Add quirk for Toshiba Encore WT8-A
  tablet (git-fixes).
- Refresh
  patches.suse/ASoC-Intel-bytcr_rt5640-Add-quirk-for-Toshiba-Encore.patch.
- commit 9af3c7c
* Tue Jul  7 2020 tiwai@suse.de
- spi: dw: Return any value retrieved from the dma_transfer
  callback (git-fixes).
- Refresh
  patches.suse/spi-dw-Add-SPI-Rx-done-wait-method-to-DMA-based-tran.patch.
- Refresh
  patches.suse/spi-dw-Add-SPI-Tx-done-wait-method-to-DMA-based-tran.patch.
- commit 62c15de
* Tue Jul  7 2020 jack@suse.cz
- blacklist.conf: Blacklist 32302085a8d9
- commit 856ff38
* Tue Jul  7 2020 tiwai@suse.de
- i2c: mlxcpld: check correct size of maximum RECV_LEN packet
  (git-fixes).
- i2c: algo-pca: Add 0x78 as SCL stuck low status for PCA9665
  (git-fixes).
- hwmon: (pmbus) fix a typo in Kconfig SENSORS_IR35221 option
  (git-fixes).
- hwmon: (acpi_power_meter) Fix potential memory leak in
  acpi_power_meter_add() (git-fixes).
- hwmon: (max6697) Make sure the OVERT mask is set correctly
  (git-fixes).
- tpm_tis: Remove the HID IFX0102 (git-fixes).
- tpm: Fix TIS locality timeout problems (git-fixes).
- thermal/drivers/rcar_gen3: Fix undefined temperature if negative
  (git-fixes).
- thermal/drivers/mediatek: Fix bank number settings on mt8183
  (git-fixes).
- i2c: core: check returned size of emulated smbus block read
  (git-fixes).
- i2c: fsi: Fix the port number field in status register
  (git-fixes).
- Staging: rtl8723bs: prevent buffer overflow in
  update_sta_support_rate() (git-fixes).
- cdc-acm: Add DISABLE_ECHO quirk for Microchip/SMSC chip
  (git-fixes).
- clk: sifive: allocate sufficient memory for struct __prci_data
  (git-fixes).
- ACPI: sysfs: Fix pm_profile_attr type (git-fixes).
- ACPI: configfs: Disallow loading ACPI tables when locked down
  (git-fixes).
- geneve: allow changing DF behavior after creation (git-fixes).
- ALSA: usb-audio: Fix OOB access of mixer element list
  (git-fixes).
- ALSA: usb-audio: add quirk for Samsung USBC Headset (AKG)
  (git-fixes).
- ASoC: rockchip: Fix a reference count leak (git-fixes).
- ASoC: fsl_ssi: Fix bclk calculation for mono channel
  (git-fixes).
- ASoc: q6afe: add support to get port direction (git-fixes).
- ASoC: q6asm: handle EOS correctly (git-fixes).
- ALSA: hda/realtek: Add mute LED and micmute LED support for
  HP systems (git-fixes).
- ALSA: usb-audio: Fix potential use-after-free of streams
  (git-fixes).
- ALSA: hda/realtek - Add quirk for MSI GE63 laptop (git-fixes).
- ALSA: usb-audio: add quirk for Denon DCD-1500RE (git-fixes).
- ALSA: usb-audio: Add implicit feedback quirk for SSL2+
  (git-fixes).
- ALSA: hda: Add NVIDIA codec IDs 9a & 9d through a0 to patch
  table (git-fixes).
- spi: sprd: switch the sequence of setting WDG_LOAD_LOW and _HIGH
  (git-fixes).
- pinctrl: tegra: Use noirq suspend/resume callbacks (git-fixes).
- ata/libata: Fix usage of page address by page_address in
  ata_scsi_mode_select_xlat function (git-fixes).
- sata_rcar: handle pm_runtime_get_sync failure cases (git-fixes).
- i2c: pxa: clear all master action bits in i2c_pxa_stop_message()
  (git-fixes).
- i2c: pxa: fix i2c_pxa_scream_blue_murder() debug output
  (git-fixes).
- i2c: piix4: Detect secondary SMBus controller on AMD AM4
  chipsets (git-fixes).
- hwmon: (k10temp) Add AMD family 17h model 60h PCI match
  (git-fixes).
- x86/amd_nb: Add AMD family 17h model 60h PCI IDs (git-fixes).
- thermal/drivers/ti-soc-thermal: Avoid dereferencing ERR_PTR
  (git-fixes).
- amdgpu: a NULL ->mm does not mean a thread is a kthread
  (git-fixes).
- ASoC: SOF: nocodec: conditionally set dpcm_capture/dpcm_playback
  flags (git-fixes).
- ASoC: core: only convert non DPCM link to DPCM link (git-fixes).
- crypto: omap-sham - add proper load balancing support for
  multicore (git-fixes).
- clk: qcom: msm8916: Fix the address location of pll->config_reg
  (git-fixes).
- clk: ti: composite: fix memory leak (git-fixes).
- clk: zynqmp: fix memory leak in zynqmp_register_clocks
  (git-fixes).
- clk: samsung: exynos5433: Add IGNORE_UNUSED flag to sclk_i2s1
  (git-fixes).
- geneve: change from tx_error to tx_dropped on missing metadata
  (git-fixes).
- pinctrl: rockchip: fix memleak in rockchip_dt_node_to_map
  (git-fixes).
- drivers: base: Fix NULL pointer exception in
  __platform_driver_probe() if a driver developer is foolish
  (git-fixes).
- iio: bmp280: fix compensation of humidity (git-fixes).
- PCI: pci-bridge-emul: Fix PCIe bit conflicts (git-fixes).
- PCI: dwc: Fix inner MSI IRQ domain registration (git-fixes).
- PCI: aardvark: Don't blindly enable ASPM L0s and don't write
  to read-only register (git-fixes).
- PCI: Add ACS quirk for Intel Root Complex Integrated Endpoints
  (git-fixes).
- PCI: Avoid FLR for AMD Starship USB 3.0 (git-fixes).
- PCI: Avoid FLR for AMD Matisse HD Audio & USB 3.0 (git-fixes).
- PCI/ASPM: Allow ASPM on links to PCIe-to-PCI/PCI-X Bridges
  (git-fixes).
- ASoC: qcom: q6asm-dai: kCFI fix (git-fixes).
- ASoC: fsl_asrc_dma: Fix dma_chan leak when config DMA channel
  failed (git-fixes).
- ASoC: SOF: Do nothing when DSP PM callbacks are not set
  (git-fixes).
- ASoC: ti: omap-mcbsp: Fix an error handling path in
  'asoc_mcbsp_probe()' (git-fixes).
- ASoC: tegra: tegra_wm8903: Support nvidia, headset property
  (git-fixes).
- ASoC: max98373: reorder max98373_reset() in resume (git-fixes).
- ASoC: davinci-mcasp: Fix dma_chan refcnt leak when getting
  dma type (git-fixes).
- ALSA: isa/wavefront: prevent out of bounds write in ioctl
  (git-fixes).
- backlight: lp855x: Ensure regulators are disabled on probe
  failure (git-fixes).
- mfd: wm8994: Fix driver operation if loaded as modules
  (git-fixes).
- media: si2157: Better check for running tuner in init
  (git-fixes).
- Bluetooth: Add SCO fallback for invalid LMP parameters error
  (git-fixes).
- b43_legacy: Fix connection problem with WPA3 (git-fixes).
- b43: Fix connection problem with WPA3 (git-fixes).
- e1000e: Relax condition to trigger reset for ME workaround
  (git-fixes).
- Bluetooth: btbcm: Add 2 missing models to subver tables
  (git-fixes).
- carl9170: remove P2P_GO support (git-fixes).
- Crypto/chcr: fix for ccm(aes) failed test (git-fixes).
- e1000: Distribute switch variables for initialization
  (git-fixes).
- clocksource: dw_apb_timer: Make CPU-affiliation being optional
  (git-fixes).
- drm: bridge: adv7511: Extend list of audio sample rates
  (git-fixes).
- platform/x86: asus_wmi: Reserve more space for struct bias_args
  (git-fixes).
- platform/x86: intel-hid: Add a quirk to support HP Spectre X2
  (2015) (git-fixes).
- platform/x86: hp-wmi: Convert simple_strtoul() to kstrtou32()
  (git-fixes).
- mmc: via-sdmmc: Respect the cmd->busy_timeout from the mmc core
  (git-fixes).
- mmc: sdhci-msm: Set SDHCI_QUIRK_MULTIBLOCK_READ_ACMD12 quirk
  (git-fixes).
- spi: dw: Fix Rx-only DMA transfers (git-fixes).
- spi: dw: Enable interrupts in accordance with DMA xfer mode
  (git-fixes).
- spi: pxa2xx: Apply CS clk quirk to BXT (git-fixes).
- commit 303666a
* Tue Jul  7 2020 jack@suse.cz
- jbd2: avoid leaking transaction credits when unreserving handle
  (bsc#1173845).
- commit 1c291c0
* Tue Jul  7 2020 jack@suse.cz
- mm: fix NUMA node file count error in replace_page_cache()
  (bsc#1173844).
- commit e3f2d50
* Tue Jul  7 2020 jack@suse.cz
- ext4: avoid utf8_strncasecmp() with unstable name (bsc#1173843).
- commit 92563f1
* Tue Jul  7 2020 jack@suse.cz
- ext4: stop overwrite the errcode in ext4_setup_super
  (bsc#1173841).
- commit aaa2254
* Tue Jul  7 2020 jack@suse.cz
- ext4: fix partial cluster initialization when splitting extent
  (bsc#1173839).
- commit 563be96
* Tue Jul  7 2020 jack@suse.cz
- ext4: fix race between ext4_sync_parent() and rename()
  (bsc#1173838).
- commit 722d064
* Tue Jul  7 2020 jack@suse.cz
- ext4: fix error pointer dereference (bsc#1173837).
- commit 70157c5
* Tue Jul  7 2020 jack@suse.cz
- ext4: fix EXT_MAX_EXTENT/INDEX to check for zeroed eh_max
  (bsc#1173836).
- commit a460d9c
* Tue Jul  7 2020 jack@suse.cz
- block: Fix use-after-free in blkdev_get() (bsc#1173834).
- commit 2225310
* Tue Jul  7 2020 jack@suse.cz
- ext4, jbd2: ensure panic by fix a race between jbd2 abort and
  ext4 error handlers (bsc#1173833).
- commit 13dac57
* Tue Jul  7 2020 jack@suse.cz
- io_uring: use kvfree() in io_sqe_buffer_register()
  (bsc#1173832).
- commit 307ffb6
* Tue Jul  7 2020 jack@suse.cz
- fat: don't allow to mount if the FAT length == 0 (bsc#1173831).
- commit b0aa8d0
* Tue Jul  7 2020 jack@suse.cz
- proc: Use new_inode not new_inode_pseudo (bsc#1173830).
- commit 3016fa7
* Tue Jul  7 2020 jack@suse.cz
- aio: fix async fsync creds (bsc#1173828).
- commit 61a9adb
* Tue Jul  7 2020 jack@suse.cz
- ubifs: fix wrong use of crypto_shash_descsize() (bsc#1173827).
- commit bbe5f1d
* Tue Jul  7 2020 jack@suse.cz
- ubifs: remove broken lazytime support (bsc#1173826).
- commit e41be50
* Tue Jul  7 2020 jack@suse.cz
- fix multiplication overflow in copy_fdtable() (bsc#1173825).
- commit 8426c92
* Tue Jul  7 2020 jack@suse.cz
- namei: only return -ECHILD from follow_dotdot_rcu()
  (bsc#1173824).
- commit ff263dd
* Tue Jul  7 2020 jack@suse.cz
- gfs2: fix glock reference problem in gfs2_trans_remove_revoke
  (bsc#1173823).
- commit cfd9533
* Tue Jul  7 2020 jack@suse.cz
- gfs2: Multi-block allocations in gfs2_page_mkwrite
  (bsc#1173822).
- commit 403212e
* Tue Jul  7 2020 jack@suse.cz
- loop: replace kill_bdev with invalidate_bdev (bsc#1173820).
- commit 7ce51fe
* Tue Jul  7 2020 jack@suse.cz
- block: nr_sects_write(): Disable preemption on seqcount write
  (bsc#1173818).
- commit fe385e8
* Tue Jul  7 2020 jack@suse.cz
- block/bio-integrity: don't free 'buf' if
  bio_integrity_add_page() failed (bsc#1173817).
- commit 181e153
* Tue Jul  7 2020 jeyu@suse.de
- README.BRANCH: Update Denis Kirjanov's email.
- commit 97dda27
* Mon Jul  6 2020 tbogendoerfer@suse.de
- debugfs: Check module state before warning in
  {full/open}_proxy_open() (bsc#1173746).
- commit 8445625
* Mon Jul  6 2020 oneukum@suse.com
- kABI fixup mtk-vpu: avoid unaligned access to DTCM buffer
  (git-fixes).
- media: mtk-vpu: avoid unaligned access to DTCM buffer
  (git-fixes).
- commit 347e1e1
* Mon Jul  6 2020 colyli@suse.de
- bcache: fix potential deadlock problem in btree_gc_coalesce
  (bsc#1171732, CVE-2020-12771).
- commit 34f5bd2
* Fri Jul  3 2020 pmladek@suse.com
- bpf: Restrict bpf_trace_printk()'s %%s usage and add %%pks,
  %%pus specifier (bsc#1172344).
- commit df79955
* Thu Jul  2 2020 tbogendoerfer@suse.de
- IB/rdmavt: Free kernel completion queue when done (bsc#1173625).
- commit d6f112e
* Thu Jul  2 2020 mkubecek@suse.cz
- Fix
  patches.suse/0001-video-vt8500lcdfb-fix-fallthrough-warning.patch.
  Fix openSUSE-15.2 build breakage by using a fall through comment instead of
  the "fallthrough" macro which is not defined in SLE15-SP2 and openSUSE-15.2.
- commit 668daf6
* Thu Jul  2 2020 tbogendoerfer@suse.de
- ionic: add pcie_print_link_status (bsc#1167773).
- wil6210: use after free in wil_netif_rx_any() (bsc#1154353).
- commit 23910ad
* Thu Jul  2 2020 tbogendoerfer@suse.de
- wil6210: account for napi_gro_receive never returning GRO_DROP
  (bsc#1154353).
- socionext: account for napi_gro_receive never returning GRO_DROP
  (bsc#1154353).
- ionic: tame the watchdog timer on reconfig (bsc#1167773).
- tg3: driver sleeps indefinitely when EEH errors exceed
  eeh_max_freezes (bsc#1173284).
- ionic: export features for vlans to use (bsc#1167773).
- ionic: no link check while resetting queues (bsc#1167773).
- devmap: Use bpf_map_area_alloc() for allocating hash buckets
  (bsc#1154353).
- RDMA/core: Check that type_attrs is not NULL prior access
  (jsc#SLE-8449).
- mvpp2: remove module bugfix (bsc#1154353).
- bnxt_en: Return from timer if interface is not in open state
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix AER reset logic on 57500 chips (bsc#1171150).
- bnxt_en: Re-enable SRIOV during resume (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Simplify bnxt_resume() (jsc#SLE-8371 bsc#1153274).
- bpf: Fix an error code in check_btf_func() (bsc#1154353).
- net/mlx5: Disable reload while removing the device
  (jsc#SLE-8464).
- net/mlx5: DR, Fix freeing in dr_create_rc_qp() (jsc#SLE-8464).
- ionic: remove support for mgmt device (bsc#1167773).
- ionic: wait on queue start until after IFF_UP (bsc#1167773).
- wil6210: add wil_netif_rx() helper function (bsc#1154353).
- commit fe9e2ce
* Thu Jul  2 2020 dwagner@suse.de
- scsi: qla2xxx: Set NVMe status code for failed NVMe FCP request
  (bsc#1158983).
- commit 3de702e
* Thu Jul  2 2020 glin@suse.com
- bpf: Document optval > PAGE_SIZE behavior for sockopt hooks
  (bsc#1155518).
- selftests/bpf: Make sure optvals > PAGE_SIZE are bypassed
  (bsc#1155518).
- bpf: Don't return EINVAL from {get,set}sockopt when optlen >
  PAGE_SIZE (bsc#1155518).
- bpf, xdp, samples: Fix null pointer dereference in *_user code
  (bsc#1155518).
- commit 525d7c1
* Wed Jul  1 2020 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: do not run klp-symbols for configs with no modules
  Starting with 5.8-rc1, s390x/zfcpdump builds fail because rpm/klp-symbols
  script does not find .tmp_versions directory. This is missing because
  s390x/zfcpdump is built without modules (CONFIG_MODULES disabled).
  As livepatching cannot work without modules, the cleanest solution is
  setting %%klp_symbols to 0 if CONFIG_MODULES is disabled. (We cannot simply
  add another condition to the place where %%klp_symbols is set as it can be
  already set to 1 from prjconf.)
- commit a048c4b
* Wed Jul  1 2020 msuchanek@suse.de
- rpm/config.sh: Update OBS build project.
- commit c470a01
* Wed Jul  1 2020 msuchanek@suse.de
- Update config files with new product.
- commit c9208a9
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/radeon: fix fb_div check in ni_init_smc_spll_table() (bsc#1152472)
- commit f188884
* Wed Jul  1 2020 tzimmermann@suse.de
- drm: rcar-du: Fix build error (bsc#1152472)
- commit 6214328
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/amdgpu: Replace invalid device ID with a valid device ID (bsc#1152472)
- commit 8b94e6d
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/i915/icl+: Fix hotplug interrupt disabling after storm detection (bsc#1152489)
- commit c7ec144
* Wed Jul  1 2020 msuchanek@suse.de
- rpm/config.sh: Update product and build project.
- commit 0b8b835
* Wed Jul  1 2020 msuchanek@suse.de
- README.BRANCH: Update branch name and maintainers.
- commit c6682c1
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/connector: notify userspace on hotplug after register complete (bsc#1152489)
  * context changes
- commit ab4aef3
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/msm: Check for powered down HW in the devfreq callbacks (bsc#1152489)
- commit 8647289
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/i915/gt: Do not schedule normal requests immediately along (bsc#1152489)
- commit 9c3d561
* Wed Jul  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gt: Stage the transfer of the virtual breadcrumb'
- commit d2de202
* Wed Jul  1 2020 tzimmermann@suse.de
- drm: amd/display: fix Kconfig help text (bsc#1152489)
  * context changes
- commit 6439719
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/qxl: Use correct notify port address when creating cursor ring (bsc#1152472)
- commit 600c22c
* Wed Jul  1 2020 tzimmermann@suse.de
- video: vt8500lcdfb: fix fallthrough warning (bsc#1152489)
- commit 476a73c
* Wed Jul  1 2020 mhocko@suse.com
- mm/memory_hotplug: refrain from adding memory into an impossible
  node (bsc#1173552).
- commit 65546dc
* Tue Jun 30 2020 oneukum@suse.com
- crypto: algif_skcipher - Cap recv SG list at ctx->used
  (git-fixes).
- commit 63acd01
* Tue Jun 30 2020 oneukum@suse.com
- crypto - Avoid free() namespace collision (git-fixes).
- commit 08a9f27
* Tue Jun 30 2020 jslaby@suse.cz
- dpaa_eth: fix usage as DSA master, try 3
  (networking-stable-20_05_27).
- net/tls: fix race condition causing kernel panic
  (networking-stable-20_05_27).
- net/mlx5: Fix error flow in case of function_setup failure
  (networking-stable-20_05_27).
- net/mlx5e: Update netdev txq on completions during closure
  (networking-stable-20_05_27).
- net/mlx5: Fix memory leak in mlx5_events_init
  (networking-stable-20_05_27).
- net/mlx5e: Fix inner tirs handling (networking-stable-20_05_27).
- net/mlx5e: kTLS, Destroy key object after destroying the TIS
  (networking-stable-20_05_27).
- net/mlx5: Add command entry handling completion
  (networking-stable-20_05_27).
- kABI: protect struct mlx5_cmd_work_ent (kabi).
- net: ethernet: ti: cpsw: fix ASSERT_RTNL() warning during
  suspend (networking-stable-20_05_27).
- sctp: Start shutdown on association restart if in SHUTDOWN-SENT
  state and socket is closed (networking-stable-20_05_27).
- tipc: block BH before using dst_cache
  (networking-stable-20_05_27).
- net: mvpp2: fix RX hashing for non-10G ports
  (networking-stable-20_05_27).
- net: don't return invalid table id error when we fall back to
  PF_UNSPEC (networking-stable-20_05_27).
- kABI: protect struct fib_dump_filter (kabi).
- net: ipip: fix wrong address family in init error path
  (networking-stable-20_05_27).
- net: qrtr: Fix passing invalid reference to qrtr_local_enqueue()
  (networking-stable-20_05_27).
- net: nlmsg_cancel() if put fails for nhmsg
  (networking-stable-20_05_27).
- sctp: Don't add the shutdown timer if its already been added
  (networking-stable-20_05_27).
- __netif_receive_skb_core: pass skb by reference
  (networking-stable-20_05_27).
- net: inet_csk: Fix so_reuseport bind-address cache in tb->fast*
  (networking-stable-20_05_27).
- net sched: fix reporting the first-time use timestamp
  (networking-stable-20_05_27).
- nexthop: Fix attribute checking for groups
  (networking-stable-20_05_27).
- net: dsa: mt7530: fix roaming from DSA user ports
  (networking-stable-20_05_27).
- commit 8e6293e
* Tue Jun 30 2020 jslaby@suse.cz
- dpaa2-eth: properly handle buffer size restrictions
  (networking-stable-20_05_16).
- tcp: fix error recovery in tcp_zerocopy_receive()
  (networking-stable-20_05_16).
- pppoe: only process PADT targeted at local interfaces
  (networking-stable-20_05_16).
- net: stmmac: fix num_por initialization
  (networking-stable-20_05_16).
- net: phy: fix aneg restart in phy_ethtool_set_eee
  (networking-stable-20_05_16).
- tcp: fix SO_RCVLOWAT hangs with fat skbs
  (networking-stable-20_05_16).
- hinic: fix a bug of ndo_stop (networking-stable-20_05_16).
- net: dsa: loop: Add module soft dependency
  (networking-stable-20_05_16).
- netprio_cgroup: Fix unlimited memory leak of v2 cgroups
  (networking-stable-20_05_16).
- dpaa2-eth: prevent array underflow in update_cls_rule()
  (networking-stable-20_05_16).
- nfp: abm: fix error return code in nfp_abm_vnic_alloc()
  (networking-stable-20_05_16).
- net: tcp: fix rx timestamp behavior for tcp_recvmsg
  (networking-stable-20_05_16).
- net: fix a potential recursive NETDEV_FEAT_CHANGE
  (networking-stable-20_05_16).
- Revert "ipv6: add mtu lock check in __ip6_rt_update_pmtu"
  (networking-stable-20_05_16).
- virtio_net: fix lockdep warning on 32 bit
  (networking-stable-20_05_16).
- hinic: fix wrong para of wait_for_completion_timeout
  (networking-stable-20_05_16).
- commit 8a9049d
* Tue Jun 30 2020 jslaby@suse.cz
- net: dsa: Do not leave DSA master with NULL netdev_ops
  (networking-stable-20_05_12).
- net: stricter validation of untrusted gso packets
  (networking-stable-20_05_12).
- net: mvpp2: cls: Prevent buffer overflow in
  mvpp2_ethtool_cls_rule_del() (networking-stable-20_05_12).
- net: mvpp2: prevent buffer overflow in mvpp22_rss_ctx()
  (networking-stable-20_05_12).
- neigh: send protocol value in neighbor create notification
  (networking-stable-20_05_12).
- nfp: abm: fix a memory leak bug (networking-stable-20_05_12).
- net/mlx4_core: Fix use of ENOSPC around mlx4_counter_alloc()
  (networking-stable-20_05_12).
- tipc: fix partial topology connection closure
  (networking-stable-20_05_12).
- net: macb: fix an issue about leak related system resources
  (networking-stable-20_05_12).
- net: usb: qmi_wwan: add support for DW5816e
  (networking-stable-20_05_12).
- net_sched: sch_skbprio: add message validation to
  skbprio_change() (networking-stable-20_05_12).
- devlink: fix return value after hitting end in region read
  (networking-stable-20_05_12).
- mlxsw: spectrum_acl_tcam: Position vchunk in a vregion list
  properly (networking-stable-20_05_12).
- tunnel: Propagate ECT(1) when decapsulating as recommended by
  RFC6040 (networking-stable-20_05_12).
- net: macsec: preserve ingress frame ordering
  (networking-stable-20_05_12).
- net/mlx5: Fix command entry leak in Internal Error State
  (networking-stable-20_05_12).
- net/mlx5: Fix forced completion access non initialized command
  entry (networking-stable-20_05_12).
- net: tc35815: Fix phydev supported/advertising mask
  (networking-stable-20_05_12).
- sch_sfq: validate silly quantum values
  (networking-stable-20_05_12).
- sch_choke: avoid potential panic in choke_reset()
  (networking-stable-20_05_12).
- fq_codel: fix TCA_FQ_CODEL_DROP_BATCH_SIZE sanity checks
  (networking-stable-20_05_12).
- net/tls: Fix sk_psock refcnt leak when in tls_data_ready()
  (networking-stable-20_05_12).
- net/tls: Fix sk_psock refcnt leak in bpf_exec_tx_verdict()
  (networking-stable-20_05_12).
- commit 01407a0
* Mon Jun 29 2020 oneukum@suse.com
- usb: gadget: udc: Potential Oops in error handling code
  (git-fixes).
- commit e68d3a3
* Mon Jun 29 2020 mgorman@suse.de
- Delete
  patches.suse/fs-Do-not-check-if-there-is-a-fsnotify-watcher-on-pseudo-inodes.patch.
  This patch (mainline commit e9c15badbb7b) breaks chromium browser:
  http://lkml.kernel.org/r/7b4aa1e985007c6d582fffe5e8435f8153e28e0f.camel@redhat.com
- commit e23a2e5
* Mon Jun 29 2020 oneukum@suse.com
- usb: typec: tcpci_rt1711h: avoid screaming irq causing boot
  hangs (git-fixes).
- commit 9bf110f
* Mon Jun 29 2020 oneukum@suse.com
- USB: serial: ch341: add basis for quirk detection (git-fixes).
- commit 5fcb9a5
* Mon Jun 29 2020 fvogt@suse.de
- efi/tpm: Verify event log header before parsing (bsc#1173461).
- commit 855e4d4
* Mon Jun 29 2020 mbenes@suse.cz
- blacklist.conf: aadf9dcef9d4 ("rxrpc: Fix trace string")
  Cosmetic change only.
- commit 3492fbc
* Mon Jun 29 2020 mbrugger@suse.com
- brcmfmac: expose RPi firmware config files through modinfo
  (bsc#1169094).
- commit ceefe76
* Mon Jun 29 2020 mbenes@suse.cz
- tracing: Fix event trigger to accept redundant spaces
  (git-fixes).
- commit b441336
* Mon Jun 29 2020 mbenes@suse.cz
- ring-buffer: Zero out time extend if it is nested and not
  absolute (git-fixes).
- commit 4f656dc
* Mon Jun 29 2020 mgorman@suse.de
- sched/core: Fix PI boosting between RT and DEADLINE tasks
  (git fixes (sched)).
- commit 55e2b0c
* Mon Jun 29 2020 mgorman@suse.de
- sched/deadline: Initialize ->dl_boosted (git fixes (sched)).
- commit d7f40dc
* Mon Jun 29 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-cfs-change-initial-value-of-runnable_avg.patch.
- Refresh
  patches.suse/sched-core-Check-cpus_mask-not-cpus_ptr-in-__set_cpus_allowed_ptr-to-fix-mask-corruption.patch.
- Refresh patches.suse/sched-core-Fix-ttwu-race.patch.
- Refresh patches.suse/sched-core-s-WF_ON_RQ-WQ_ON_CPU.patch.
- commit 302ff9b
* Mon Jun 29 2020 ptesarik@suse.cz
- s390/pci: Log new handle in clp_disable_fh() (git-fixes).
- commit 0747f74
* Mon Jun 29 2020 dwagner@suse.de
- sched/core: Fix PI boosting between RT and DEADLINE tasks
  (bsc#1172823).
- sched/deadline: Initialize ->dl_boosted (bsc#1172823).
- commit b64bd29
* Mon Jun 29 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/ibmvnic-continue-to-init-in-CRQ-reset-returns-H_CLOS.patch
- commit 8848a5a
* Mon Jun 29 2020 bp@suse.de
- EDAC/skx: Use the mcmtr register to retrieve
  close_pg/bank_xor_enable (bsc#1152489).
- commit ba796e7
* Sun Jun 28 2020 dbueso@suse.de
- rcu: Use WRITE_ONCE() for assignments to ->pprev for hlist_nulls
  (bsc#1173438).
- commit f9be02d
* Sun Jun 28 2020 dbueso@suse.de
- selftests/timens: handle a case when alarm clocks are not
  supported (bsc#1164648,jsc#SLE-11493).
- eventpoll: fix missing wakeup for ovflist in ep_poll_callback
  (bsc#1159867).
- random: fix data races at timer_rand_state (bsc#1173438).
- timer: Use hlist_unhashed_lockless() in timer_pending()
  (bsc#1173438).
- jbd2: fix data races at struct journal_head (bsc#1173438).
- list: Add hlist_unhashed_lockless() (bsc#1173438).
- rcu: Fix data-race due to atomic_t copy-by-value (bsc#1171828).
- tick/sched: Annotate lockless access to last_jiffies_update
  (bsc#1173438).
- commit ea6eb59
* Fri Jun 26 2020 msuchanek@suse.de
- Refresh metadata of patches.suse/ibmvnic-continue-to-init-in-CRQ-reset-returns-H_CLOS.patch.
- commit 9767e8e
* Fri Jun 26 2020 msuchanek@suse.de
- ibmveth: Fix max MTU limit (bsc#1173428 ltc#186397).
- commit 79145c1
* Fri Jun 26 2020 bp@suse.de
- EDAC/ghes: Setup DIMM label from DMI and use it in error reports
  (bsc#1168779).
- commit a469a1d
* Fri Jun 26 2020 dwagner@suse.de
- wireguard: receive: account for napi_gro_receive never returning
  GRO_DROP (git-fixes).
- wireguard: device: avoid circular netns references (git-fixes).
- wireguard: noise: do not assign initiation time in if condition
  (git-fixes).
- wireguard: send/receive: use explicit unlikely branch instead
  of implicit coalescing (git-fixes).
  Update context:
  patches.suse/wireguard-noise-separate-receive-counter-from-send-c.patch
- wireguard: selftests: initalize ipv6 members to NULL to squelch
  clang warning (git-fixes).
- commit 4d2639d
* Wed Jun 24 2020 mgorman@suse.de
- sched/cfs: change initial value of runnable_avg (bsc#1158765).
- commit daa01a4
* Wed Jun 24 2020 tiwai@suse.de
- spi: dw-pci: Fix Chip Select amount on Intel Elkhart Lake PSE
  SPI (jsc#SLE-12735).
- spi: dw-pci: Add runtime power management support
  (jsc#SLE-12735).
- SPI: designware: pci: Switch over to MSI interrupts
  (jsc#SLE-12735).
- spi: dw-pci: Add MODULE_DEVICE_TABLE (jsc#SLE-12735).
- spi: dw-pci: Add support for Intel Elkhart Lake PSE SPI
  (jsc#SLE-12735).
- commit fb43301
* Wed Jun 24 2020 tiwai@suse.de
- thermal: intel: intel_pch_thermal: Add Comet Lake (CML)
  platform support (jsc#SLE-12668).
- commit fd37b6c
* Wed Jun 24 2020 tiwai@suse.de
- ntb: intel: fix static declaration (jsc#SLE-12710).
- ntb: intel: add hw workaround for NTB BAR alignment
  (jsc#SLE-12710).
- commit 2f0e6e8
* Wed Jun 24 2020 mhocko@suse.com
- mm: adjust vm_committed_as_batch according to vm overcommit
  policy (bnc#1173271).
- mm/util.c: make vm_memory_committed() more accurate
  (bnc#1173271).
- proc/meminfo: avoid open coded reading of vm_committed_as
  (bnc#1173271).
- commit aef113d
* Wed Jun 24 2020 mkubecek@suse.cz
- series.conf: refresh
  No effect on expanded tree.
- commit c2d8ecc
* Wed Jun 24 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/net-revert-net-get-rid-of-an-signed-integer-overflow-in-ip_idents_reserve.patch
- commit b3deae9
* Wed Jun 24 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/nvme-fc-avoid-gcc-10-zero-length-bounds-warning.patch
  patches.suse/scsi-sd_zbc-Fix-sd_zbc_complete.patch
- fix bugzilla reference (bsc1173206 -> bsc#1173206):
  patches.suse/iocost-don-t-let-vrate-run-wild-while-there-s-no-sat.patch
- commit 7891a6f
* Wed Jun 24 2020 mgorman@suse.de
- sched/core: s/WF_ON_RQ/WQ_ON_CPU/ (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- commit dfd878b
* Wed Jun 24 2020 mgorman@suse.de
- sched/core: Fix ttwu() race (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- commit 2e88482
* Wed Jun 24 2020 mgorman@suse.de
- sched/core: Check cpus_mask, not cpus_ptr in
  __set_cpus_allowed_ptr(), to fix mask corruption (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit 1ad19c5
* Wed Jun 24 2020 mgorman@suse.de
- net: revert "net: get rid of an signed integer overflow in
  ip_idents_reserve()" (bnc#1158748 (network regression)).
- commit 1b123ac
* Tue Jun 23 2020 msuchanek@suse.de
- ibmvnic: continue to init in CRQ reset returns H_CLOSED
  (bsc#1173280 ltc#185369).
- commit 39f977e
* Tue Jun 23 2020 jroedel@suse.de
- vfio-pci: Invalidate mmaps and block MMIO access on disabled
  memory (CVE-2020-12888 bsc#1171868).
- vfio-pci: Fault mmaps to enable vma tracking (CVE-2020-12888
  bsc#1171868).
- vfio/type1: Support faulting PFNMAP vmas (CVE-2020-12888
  bsc#1171868).
- commit d737eb2
* Tue Jun 23 2020 tiwai@suse.de
- Fix a regression of AF_ALG crypto interface hang with aes_s390 (bsc#1167651)
  The upstream fix backported via git-fixes seems causing a trouble with
  s390 aes crypto module.  The problem is generic and should be addressed
  in the upstream, but now we drop the patch as a quick resolution.
  The commit ID is added in blacklist, too.
  Deleted:
  patches.suse/0001-crypto-algif_skcipher-Use-chunksize-instead-of-block.patch
- commit 59211f8
* Tue Jun 23 2020 tiwai@suse.de
- i2c: designware-pci: Fix BUG_ON during device removal
  (jsc#SLE-12734).
- commit 7d1f12c
* Tue Jun 23 2020 tiwai@suse.de
- i2c: designware-pci: Add support for Elkhart Lake PSE I2C
  (jsc#SLE-12734).
- i2c: designware-pci: Switch over to MSI interrupts
  (jsc#SLE-12734).
- commit 7f79de2
* Tue Jun 23 2020 tiwai@suse.de
- ntb: intel: Add Icelake (gen4) support for Intel NTB
  (jsc#SLE-12710).
- commit 37883e6
* Mon Jun 22 2020 tiwai@suse.de
- Revert "pinctrl: freescale: imx: Use 'devm_of_iomap()' to avoid
  a resource leak in case of error in 'imx_pinctrl_probe()'"
  (git-fixes).
- crypto: algboss - don't wait during notifier callback
  (git-fixes).
- drm: encoder_slave: fix refcouting error for modules
  (git-fixes).
- drm/i915: work around false-positive maybe-uninitialized warning
  (git-fixes).
- commit 18a77fa
* Mon Jun 22 2020 dwagner@suse.de
- lpfc: Synchronize NVME transport and lpfc driver devloss_tmo
  (bcs#1173060).
- commit 124f086
* Mon Jun 22 2020 tiwai@suse.de
- r8169: Revive default chip version for r8168 (bsc#1173085).
- commit c0956cb
* Mon Jun 22 2020 hare@suse.de
- scsi: megaraid_sas: Replace undefined MFI_BIG_ENDIAN macro
  with __BIG_ENDIAN_BITFIELD macro (bsc#1173206).
- nvme-fc: avoid gcc-10 zero-length-bounds warning (bsc#1173206).
- iocost: don't let vrate run wild while there's no saturation
  signal (bsc1173206).
- blk-iocost: Fix error on iocost_ioc_vrate_adj (bsc#1173206).
- blk-iocost: fix incorrect vtime comparison in iocg_is_idle()
  (bsc#1173206).
- iocost: over-budget forced IOs should schedule async delay
  (bsc#1173206).
- scsi: smartpqi: Update attribute name to `driver_version`
  (bsc#1173206).
- iocost: check active_list of all the ancestors in
  iocg_activate() (bsc#1173206).
- scsi: sd_zbc: Fix sd_zbc_complete() (bsc#1173206).
- commit 7abe8d4
* Mon Jun 22 2020 hare@suse.de
- blacklist.conf: Add commit for git-fixes (bsc#1173206)
- commit 4a864a5
* Mon Jun 22 2020 ykaukab@suse.de
- irqchip/al-fic: Add support for irq retrigger (jsc#SLE-10505).
- commit 8ec37c7
* Mon Jun 22 2020 mgorman@suse.de
- sched/fair: Optimize dequeue_task_fair() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- commit 3b10cba
* Fri Jun 19 2020 tiwai@suse.de
- Update patch reference for intel_th patch (jsc#SLE-12705)
- commit 2f7215f
* Thu Jun 18 2020 ptesarik@suse.cz
- s390/bpf: Maintain 8-byte stack alignment (bsc#1169194,
  LTC#185911).
- commit 58beb12
* Thu Jun 18 2020 tiwai@suse.de
- Update patch reference for s390 security fix (CVE-2020-10773 bsc#1172999)
- commit 7370304
* Thu Jun 18 2020 tiwai@suse.de
- firmware: imx-scu: Support one TX and one RX (git-fixes).
- Refresh
  patches.suse/firmware-imx-scu-Fix-corruption-of-header.patch.
- commit 0e40d23
* Thu Jun 18 2020 tiwai@suse.de
- ACPI: GED: use correct trigger type field in _Exx / _Lxx
  handling (git-fixes).
- commit 510ece6
* Thu Jun 18 2020 tiwai@suse.de
- lib/lzo: fix ambiguous encoding bug in lzo-rle (git-fixes).
- x86/reboot/quirks: Add MacBook6,1 reboot quirk (git-fixes).
- x86/PCI: Mark Intel C620 MROMs as having non-compliant BARs
  (git-fixes).
- ASoC: max9867: fix volume controls (git-fixes).
- ath9k: Fix general protection fault in ath9k_hif_usb_rx_cb
  (git-fixes).
- ath9x: Fix stack-out-of-bounds Write in ath9k_hif_usb_rx_cb
  (git-fixes).
- ath9k: Fix use-after-free Write in ath9k_htc_rx_msg (git-fixes).
- ath9k: Fix use-after-free Read in ath9k_wmi_ctrl_rx (git-fixes).
- ath9k: Fix use-after-free Read in htc_connect_service
  (git-fixes).
- drm/vkms: Hold gem object while still in-use (git-fixes).
- ACPI: GED: add support for _Exx / _Lxx handler methods
  (git-fixes).
- mmc: tmio: Further fixup runtime PM management at remove
  (git-fixes).
- mmc: sdio: Fix several potential memory leaks in
  mmc_sdio_init_card() (git-fixes).
- efi/efivars: Add missing kobject_put() in sysfs entry creation
  error path (git-fixes).
- spi: bcm-qspi: Handle clock probe deferral (git-fixes).
- Input: synaptics - add a second working PNP_ID for Lenovo T470s
  (git-fixes).
- Input: mms114 - fix handling of mms345l (git-fixes).
- firmware: imx: warn on unexpected RX (git-fixes).
- commit c722a2d
* Thu Jun 18 2020 tiwai@suse.de
- pinctrl: tigerlake: Tiger Lake uses _HID enumeration
  (jsc#SLE-12737).
- commit 6831e2b
* Thu Jun 18 2020 tiwai@suse.de
- pinctrl: intel: Add Intel Tiger Lake pin controller support
  (jsc#SLE-12737).
- Update config files: Add CONFIG_PINCTRL_TIGERLAKE=m
- supported.conf: Add pinctrl-tigerlake as supported
- commit 2966fcc
* Thu Jun 18 2020 tiwai@suse.de
- mfd: intel-lpss: Add Intel Tiger Lake PCI IDs (jsc#SLE-12737).
- mtd: spi-nor: intel-spi: Add support for Intel Tiger Lake SPI
  serial flash (jsc#SLE-12737).
- commit c6209c3
* Thu Jun 18 2020 tiwai@suse.de
- Update the patch reference for ish-hid fix (jsc#SLE-12683)
- commit 4a77970
* Thu Jun 18 2020 tiwai@suse.de
- Update patch reference for can driver security fix (CVE-2020-14416 bsc#1162002)
- commit f86a41b
* Wed Jun 17 2020 dwagner@suse.de
- rcutorture: Make kvm-find-errors.sh abort on bad directory
  (bsc#1173068).
- rcutorture: Summarize summary of build and run results
  (bsc#1173068).
- rcutorture: Add 100-CPU configuration (bsc#1173068).
- torture: Make results-directory date format completion-friendly
  (bsc#1173068).
- locktorture: Allow CPU-hotplug to be disabled via --bootargs
  (bsc#1173068).
- torture: Hoist calls to lscpu to higher-level kvm.sh script
  (bsc#1173068).
- torture: Allow "CFLIST" to specify default list of scenarios
  (bsc#1173068).
- rcutorture: Add worst-case call_rcu() forward-progress results
  (bsc#1173068).
- torture: Handle systems lacking the mpstat command
  (bsc#1173068).
- torture: Handle jitter for CPUs that cannot be offlined
  (bsc#1173068).
- rcutorture: Dispense with Dracut for initrd creation
  (bsc#1173068).
- torture: Use gawk instead of awk for systime() function
  (bsc#1173068).
- rcutorture: Remove CONFIG_HOTPLUG_CPU=n from scenarios
  (bsc#1173068).
- rcutorture: Test TREE03 with the threadirqs kernel boot
  parameter (bsc#1173068).
- torture: Expand last_ts variable in kvm-test-1-run.sh
  (bsc#1173068).
- commit 937076b
* Wed Jun 17 2020 msuchanek@suse.de
- ibmvnic: Harden device login requests (bsc#1170011 ltc#183538).
- commit f073312
* Wed Jun 17 2020 duwe@suse.de
- rpm/modules.fips:
  * add aes-ce-ccm and des3_ede-x86_64 (boo#173030)
  * add aes_ti and aes_neon_bs (boo#1172956)
- commit 9492a4d
* Wed Jun 17 2020 mbenes@suse.cz
- objtool: Allow no-op CFI ops in alternatives (bsc#1169514).
- commit b40dd12
* Wed Jun 17 2020 tiwai@suse.de
- firmware: imx: scu: Fix corruption of header (git-fixes).
- commit bd25a67
* Wed Jun 17 2020 tiwai@suse.de
- e1000e: Do not wake up the system via WOL if device wakeup is
  disabled (git-fixes).
- commit 8a4bb5a
* Wed Jun 17 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/NFS-Fix-fscache-super_cookie-index_key-from-changing.patch
  patches.suse/NFSv4-Fix-fscache-cookie-aux_data-to-ensure-change_a.patch
  patches.suse/NFSv4.1-fix-rpc_call_done-assignment-for-BIND_CONN_T.patch
  patches.suse/SUNRPC-Signalled-ASYNC-tasks-need-to-exit.patch
  patches.suse/nfs-fscache-use-timespec64-in-inode-auxdata.patch
  patches.suse/nfs-set-invalid-blocks-after-NFSv4-writes.patch
  patches.suse/nfsd4-make-drc_slab-global-not-per-net.patch
  patches.suse/svcrdma-Fix-leak-of-svc_rdma_recv_ctxt-objects.patch
- commit 91ef650
* Wed Jun 17 2020 mbenes@suse.cz
- objtool: Fix ORC vs alternatives (bsc#1169514).
- commit 0222f6e
* Wed Jun 17 2020 mbenes@suse.cz
- objtool: Uniquely identify alternative instruction groups
  (bsc#1169514).
- commit 862a5a6
* Wed Jun 17 2020 mbenes@suse.cz
- objtool: Remove check preventing branches within alternative
  (bsc#1169514).
- commit c794e66
* Tue Jun 16 2020 mbenes@suse.cz
- objtool: Fix !CFI insn_state propagation (bsc#1169514).
- commit 52c95b4
* Tue Jun 16 2020 mbenes@suse.cz
- objtool: Rename struct cfi_state (bsc#1169514).
- commit faa0120
* Tue Jun 16 2020 lhenriques@suse.com
- ceph: skip checking caps when session reconnecting and releasing
  reqs (bsc#1172990).
- ceph: make sure mdsc->mutex is nested in s->s_mutex to fix
  dead lock (bsc#1172989).
- ceph: don't return -ESTALE if there's still an open file
  (bsc#1171915).
- ceph: allow rename operation under different quota realms
  (bsc#1172988).
- ceph: normalize 'delta' parameter usage in check_quota_exceeded
  (bsc#1172987).
- ceph: ceph_kick_flushing_caps needs the s_mutex (bsc#1172986).
- ceph: request expedited service on session's last cap flush
  (bsc#1172985 bsc#1167104).
- ceph: convert mdsc->cap_dirty to a per-session list (bsc#1172984
  bsc#1167104).
- ceph: reset i_requested_max_size if file write is not wanted
  (bsc#1172983).
- ceph: throw a warning if we destroy session with mutex still
  locked (bsc#1172940).
- ceph: fix potential race in ceph_check_caps (bsc#1172940).
- ceph: document what protects i_dirty_item and i_flushing_item
  (bsc#1172940).
- ceph: don't take i_ceph_lock in handle_cap_import (bsc#1172940).
- ceph: don't release i_ceph_lock in handle_cap_trunc
  (bsc#1172940).
- ceph: add comments for handle_cap_flush_ack logic (bsc#1172940).
- ceph: split up __finish_cap_flush (bsc#1172940).
- ceph: reorganize __send_cap for less spinlock abuse
  (bsc#1172940).
- ceph: flush release queue when handling caps for unknown inode
  (bsc#1172939).
- libceph: ignore pool overlay and cache logic on redirects
  (bsc#1172938).
- commit 14735c0
* Tue Jun 16 2020 tiwai@suse.de
- media: cedrus: Program output format during each run
  (git-fixes).
- clk: renesas: cpg-mssr: Fix STBCR suspend/resume handling
  (git-fixes).
- serial: 8250: Fix max baud limit in generic 8250 port
  (git-fixes).
- drivers: phy: sr-usb: do not use internal fsm for USB2 phy init
  (git-fixes).
- HID: multitouch: enable multi-input as a quirk for some devices
  (git-fixes).
- tun: correct header offsets in napi frags mode (git-fixes).
- r8152: support additional Microsoft Surface Ethernet Adapter
  variant (git-fixes).
- staging: kpc2000: fix error return code in kp2000_pcie_probe()
  (git-fixes).
- irqchip/ti-sci-inta: Fix processing of masked irqs (git-fixes).
- irqchip/versatile-fpga: Apply clear-mask earlier (git-fixes).
- irqchip/versatile-fpga: Handle chained IRQs properly
  (git-fixes).
- ktest: Add timeout for ssh sync testing (git-fixes).
- commit ac894fa
* Tue Jun 16 2020 mgorman@suse.de
- fs: Do not check if there is a fsnotify watcher on pseudo inodes
  (bsc#1158765).
- commit 7b8d90d
* Tue Jun 16 2020 denis.kirjanov@suse.com
- bpf, sockhash: Synchronize_rcu before free'ing map (git-fixes).
- bpf, sockmap: Check update requirements after locking
  (git-fixes).
- rxrpc: Fix call RCU cleanup using non-bh-safe locks (git-fixes).
- netfilter: nft_tunnel: add the missing ERSPAN_VERSION nla_policy
  (git-fixes).
- netfilter: nft_tproxy: Fix port selector on Big Endian
  (git-fixes).
- netfilter: nf_tables_offload: return EOPNOTSUPP if rule
  specifies no actions (git-fixes).
- netfilter: nf_queue: enqueue skbs with NULL dst (git-fixes).
- af_unix: add compat_ioctl support (git-fixes).
- ipvs: Improve robustness to the ipvs sysctl (git-fixes).
- commit 988684c
* Tue Jun 16 2020 glin@suse.com
- bpf: Undo internal BPF_PROBE_MEM in BPF insns dump (bsc#1155518).
- commit 3b9919e
* Tue Jun 16 2020 neilb@suse.de
- blacklist.conf: mark commit with incorrect Fixes line
- commit 0804266
* Tue Jun 16 2020 neilb@suse.de
- nfs: set invalid blocks after NFSv4 writes (git-fixes).
- NFSv4.1 fix rpc_call_done assignment for BIND_CONN_TO_SESSION
  (git-fixes).
- nfsd4: make drc_slab global, not per-net (git-fixes).
- NFSv4: Fix fscache cookie aux_data to ensure change_attr is
  included (git-fixes).
- NFS: Fix fscache super_cookie index_key from changing after
  umount (git-fixes).
- SUNRPC: Signalled ASYNC tasks need to exit (git-fixes).
- svcrdma: Fix leak of svc_rdma_recv_ctxt objects (git-fixes).
- nfs: fscache: use timespec64 in inode auxdata (git-fixes).
- commit a77a576
* Tue Jun 16 2020 neilb@suse.de
- blacklist.conf: add uninteresting commit
- commit 3cb617b
* Mon Jun 15 2020 mkubecek@suse.cz
- genetlink: clean up family attributes allocations (git-fixes).
- commit f616c3b
* Mon Jun 15 2020 jeyu@suse.de
- panic: do not print uninitialized taint_flags (bsc#1172814).
- commit 045c8db
* Mon Jun 15 2020 msuchanek@suse.de
- ibmvnic: Flush existing work items before device removal
  (bsc#1065729).
- commit 3f9ece1
* Mon Jun 15 2020 msuchanek@suse.de
- powerpc/fadump: Account for memory_limit while reserving memory
  (jsc#SLE-9099 git-fixes).
- commit 3bdf3b7
* Mon Jun 15 2020 msuchanek@suse.de
- powerpc/fadump: consider reserved ranges while reserving memory
  (jsc#SLE-9099 git-fixes).
- powerpc/fadump: use static allocation for reserved memory ranges
  (jsc#SLE-9099 git-fixes).
- commit 5e676b4
* Mon Jun 15 2020 msuchanek@suse.de
- powerpc/powernv: Fix a warning message (bsc#1156395).
- commit c1f8cea
* Mon Jun 15 2020 msuchanek@suse.de
- powerpc/64s: Save FSCR to init_task.thread.fscr after feature
  init (bsc#1065729).
- powerpc/64s: Don't let DT CPU features set FSCR_DSCR
  (bsc#1065729).
- commit 054bf6b
* Mon Jun 15 2020 msuchanek@suse.de
- powerpc/64s/exception: Fix machine check no-loss idle wakeup
  (bsc#1156395).
- commit 81b4c8f
* Mon Jun 15 2020 msuchanek@suse.de
- asm-gemeric/tlb: remove stray function declarations
  (bsc#1156395).
- commit 72eefc6
* Mon Jun 15 2020 msuchanek@suse.de
- include/asm-generic/topology.h: guard cpumask_of_node() macro
  argument (bsc#1148868).
- commit 8cdd828
* Mon Jun 15 2020 msuchanek@suse.de
- powerpc/xive: Clear the page tables for the ESB IO mapping
  (fate#322438 bsc#1085030).
- commit e1d4bd5
* Mon Jun 15 2020 dwagner@suse.de
- nvme-fc: don't call nvme_cleanup_cmd() for AENs (bsc#1171688).
- commit abf08ba
* Mon Jun 15 2020 bp@suse.de
- x86/cpu/amd: Make erratum #1054 a legacy erratum (bsc#1152489).
- commit f243f91
* Mon Jun 15 2020 bp@suse.de
- blacklist.conf: 5214028dd89e x86/boot: Correct relocation destination on old linkers
- commit 741883d
* Mon Jun 15 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/scsi-ibmvscsi-Don-t-send-host-info-in-adapter-info-M.patch
  patches.suse/sunrpc-clean-up-properly-in-gss_mech_unregister.patch
  patches.suse/sunrpc-svcauth_gss_register_pseudoflavor-must-reject.patch
- commit 1bb600f
* Mon Jun 15 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/sched-fair-Fix-enqueue_task_fair-warning-some-more.patch
- commit f581127
* Mon Jun 15 2020 neilb@suse.de
- work around mvfs bug (bsc#1162063).
- commit 5a1f922
* Mon Jun 15 2020 mkubecek@suse.cz
- rpm: drop execute permissions on source files
  Sometimes a source file with execute permission appears in upstream
  repository and makes it into our kernel-source packages. This is caught by
  OBS build checks and may even result in build failures.
  Sanitize the source tree by removing execute permissions from all C source
  and header files.
- commit 771e293
* Fri Jun 12 2020 bp@suse.de
- x86/speculation: PR_SPEC_FORCE_DISABLE enforcement for indirect
  branches (bsc#1172783 CVE-2020-10768).
- commit 1ce088f
* Fri Jun 12 2020 tiwai@suse.de
- drm/i915: Limit audio CDCLK>=2*BCLK constraint back to GLK only
  (git-fixes).
- drm/i915: extend audio CDCLK>=2*BCLK constraint to more
  platforms (git-fixes).
- commit 9b79e3a
* Fri Jun 12 2020 mgorman@suse.de
- sched/cpuacct: Fix charge cpuacct.usage_sys (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/pelt: Sync util/runnable_sum with PELT window when
  propagating (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/fair: Optimize enqueue_task_fair() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched: Make newidle_balance() static again (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/fair: find_idlest_group(): Remove unused sd_flag parameter
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Simplify the code of should_we_balance()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Fix enqueue_task_fair() warning some more
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit 6d2135e
* Fri Jun 12 2020 bp@suse.de
- x86/speculation: Prevent rogue cross-process SSBD shutdown
  (bsc#1172781 CVE-2020-10766).
- commit 9163040
* Fri Jun 12 2020 tbogendoerfer@suse.de
- RDMA/nl: Do not permit empty devices names during
  RDMA_NLDEV_CMD_NEWLINK/SET (bsc#1172841).
- commit 543b194
* Fri Jun 12 2020 tiwai@suse.de
- crypto: cavium/nitrox - Fix 'nitrox_get_first_device()' when
  ndevlist is fully iterated (git-fixes).
- e1000e: Disable TSO for buffer overrun workaround (git-fixes).
- commit 1f86986
* Fri Jun 12 2020 tbogendoerfer@suse.de
- vmxnet3: allow rx flow hash ops only when rss is enabled
  (bsc#1172484).
- net: vmxnet3: fix possible buffer overflow caused by bad DMA
  value in vmxnet3_get_rss() (bsc#1172484).
- vmxnet3: use correct hdr reference when packet is encapsulated
  (bsc#1172484).
- vmxnet3: update to version 4 (bsc#1172484).
- vmxnet3: add geneve and vxlan tunnel offload support
  (bsc#1172484).
- vmxnet3: add support to get/set rx flow hash (bsc#1172484).
- vmxnet3: prepare for version 4 changes (bsc#1172484).
- commit f2fe4cd
* Fri Jun 12 2020 tbogendoerfer@suse.de
- net: ena: xdp: update napi budget for DROP and ABORTED
  (bsc#1154492).
- net: ena: xdp: XDP_TX: fix memory leak (bsc#1154492).
- genetlink: fix memory leaks in genl_family_rcv_msg_dumpit()
  (bsc#1154353).
- RDMA/core: Move and rename trace_cm_id_create() (jsc#SLE-8449).
- RDMA/srpt: Fix disabling device management (jsc#SLE-8449).
- RDMA/bnxt_re: Remove dead code from rcfw (bsc#1170774).
- RDMA/uverbs: Make the event_queue fds return POLLERR when
  disassociated (jsc#SLE-8449).
- ipv6: fix IPV6_ADDRFORM operation logic (bsc#1171662).
- ice: Fix inability to set channels when down (jsc#SLE-7926).
- bnxt_en: Improve TQM ring context memory sizing formulas
  (jsc#SLE-8371 bsc#1153274).
- ice: Fix error return code in ice_add_prof() (jsc#SLE-7926).
- net/mlx5e: replace EINVAL in mlx5e_flower_parse_meta()
  (jsc#SLE-8464).
- net/mlx5e: Fix stats update for matchall classifier
  (jsc#SLE-8464).
- net/mlx5: Fix crash upon suspend/resume (bsc#1172365).
- net: dsa: declare lockless TX feature for slave ports
  (bsc#1154353).
- RDMA/mlx5: Fix NULL pointer dereference in destroy_prefetch_work
  (jsc#SLE-8446).
- net/mlx5: Fix cleaning unmanaged flow tables (jsc#SLE-8464).
- net: phy: propagate an error back to the callers of
  phy_sfp_probe (bsc#1154353).
- commit 2741342
* Fri Jun 12 2020 tiwai@suse.de
- mailbox: zynqmp-ipi: Fix NULL vs IS_ERR() check in
  zynqmp_ipi_mbox_probe() (git-fixes).
- drm/sun4i: hdmi ddc clk: Fix size of m divider (git-fixes).
- ACPI: PM: Avoid using power resources if there are none for D0
  (git-fixes).
- Input: edt-ft5x06 - fix get_default register write access
  (git-fixes).
- mtd: rawnand: brcmnand: fix CS0 layout (git-fixes).
- mtd: rawnand: xway: Fix the probe error path (git-fixes).
- mtd: rawnand: tmio: Fix the probe error path (git-fixes).
- mtd: rawnand: sunxi: Fix the probe error path (git-fixes).
- mtd: rawnand: socrates: Fix the probe error path (git-fixes).
- mtd: rawnand: sharpsl: Fix the probe error path (git-fixes).
- mtd: rawnand: plat_nand: Fix the probe error path (git-fixes).
- mtd: rawnand: pasemi: Fix the probe error path (git-fixes).
- mtd: rawnand: oxnas: Release all devices in the _remove() path
  (git-fixes).
- mtd: rawnand: oxnas: Keep track of registered devices
  (git-fixes).
- mtd: rawnand: orion: Fix the probe error path (git-fixes).
- mtd: rawnand: mtk: Fix the probe error path (git-fixes).
- mtd: rawnand: ingenic: Fix the probe error path (git-fixes).
- mtd: rawnand: diskonchip: Fix the probe error path (git-fixes).
- mtd: rawnand: Fix nand_gpio_waitrdy() (git-fixes).
- mtd: rawnand: brcmnand: correctly verify erased pages
  (git-fixes).
- mtd: rawnand: brcmnand: fix hamming oob layout (git-fixes).
- mtd: rawnand: onfi: Fix redundancy detection check (git-fixes).
- mtd: rawnand: timings: Fix default tR_max and tCCS_min timings
  (git-fixes).
- mtd: rawnand: marvell: Fix probe error path (git-fixes).
- mtd: rawnand: marvell: Use nand_cleanup() when the device is
  not yet registered (git-fixes).
- mtd: rawnand: marvell: Fix the condition on a return code
  (git-fixes).
- clk: mediatek: assign the initial value to clk_init_data of
  mtk_mux (git-fixes).
- clk: qcom: Add missing msm8998 ufs_unipro_core_clk_src
  (git-fixes).
- clk: clk-flexgen: fix clock-critical handling (git-fixes).
- clk: bcm2835: Remove casting to bcm2835_clk_register
  (git-fixes).
- clk: bcm2835: Fix return type of bcm2835_register_gate
  (git-fixes).
- clk: sprd: return correct type of value for
  _sprd_pll_recalc_rate (git-fixes).
- clk: sunxi: Fix incorrect usage of round_down() (git-fixes).
- clk: samsung: Mark top ISP and CAM clocks on Exynos542x as
  critical (git-fixes).
- clk: meson: meson8b: Don't rely on u-boot to init all GP_PLL
  registers (git-fixes).
- clk: meson: meson8b: Fix the vclk_div{1, 2, 4, 6, 12}_en gate
  bits (git-fixes).
- clk: meson: meson8b: Fix the polarity of the RESET_N lines
  (git-fixes).
- power: supply: smb347-charger: IRQSTAT_D is volatile
  (git-fixes).
- power: supply: lp8788: Fix an error handling path in
  'lp8788_charger_probe()' (git-fixes).
- power: supply: core: fix memory leak in HWMON error path
  (git-fixes).
- power: supply: core: fix HWMON temperature labels (git-fixes).
- power: reset: qcom-pon: reg write mask depends on pon generation
  (git-fixes).
- power: supply: bq24257_charger: Replace depends on REGMAP_I2C
  with select (git-fixes).
- staging: rtl8712: Fix IEEE80211_ADDBA_PARAM_BUF_SIZE_MASK
  (git-fixes).
- USB: serial: option: add Telit LE910C1-EUX compositions
  (git-fixes).
- USB: serial: qcserial: add DW5816e QDL support (git-fixes).
- mmc: fix compilation of user API (git-fixes).
- spi: dt-bindings: spi-controller: Fix #address-cells for slave
  mode (git-fixes).
- spi: dw: use "smp_mb()" to avoid sending spi data error
  (git-fixes).
- commit f18fb8c
* Fri Jun 12 2020 tiwai@suse.de
- ASoC: rt5645: Add platform-data for Asus T101HA (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for Toshiba Encore WT10-A
  tablet (git-fixes).
- ASoC: meson: add missing free_irq() in error path (git-fixes).
- ALSA: hda/realtek - add a pintbl quirk for several Lenovo
  machines (git-fixes).
- ALSA: emu10k1: delete an unnecessary condition (git-fixes).
- commit 509b163
* Fri Jun 12 2020 tiwai@suse.de
- ALSA: pcm: disallow linking stream to itself (git-fixes).
- ALSA: usb-audio: Manage auto-pm of all bundled interfaces
  (git-fixes).
- ALSA: pcm: fix snd_pcm_link() lockdep splat (git-fixes).
- ALSA: usb-audio: Use the new macro for HP Dock rename quirks
  (git-fixes).
- ALSA: usb-audio: Add vendor, product and profile name for HP
  Thunderbolt Dock (git-fixes).
- ALSA: usb-audio: Fix inconsistent card PM state after resume
  (git-fixes).
- ALSA: usb-audio: Add Pioneer DJ DJM-900NXS2 support (git-fixes).
- pcm_native: result of put_user() needs to be checked
  (git-fixes).
- commit ef14fbe
* Thu Jun 11 2020 bp@suse.de
- x86/speculation: Avoid force-disabling IBPB based on STIBP
  and enhanced IBRS (bsc#1172782 CVE-2020-10767).
- commit 6c80e35
* Thu Jun 11 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-Offload-wakee-task-activation-if-it-the-wakee-is-descheduling.patch.
- Refresh
  patches.suse/sched-Optimize-ttwu-spinning-on-p-on_cpu.patch.
- Refresh
  patches.suse/sched-cpuacct-Use-__this_cpu_add-instead-of-this_cpu_ptr.patch.
- Refresh
  patches.suse/sched-fair-Fix-negative-imbalance-in-imbalance-calculation.patch.
- Refresh
  patches.suse/sched-fair-Use-__this_cpu_read-in-wake_wide.patch.
- commit 34c599d
* Thu Jun 11 2020 mbenes@suse.cz
- livepatch: Make klp_apply_object_relocs static (bsc#1071995).
- commit 293cfbf
* Thu Jun 11 2020 mbenes@suse.cz
- livepatch: Prevent module-specific KLP rela sections from
  referencing vmlinux symbols (bsc#1071995).
- Refresh
  patches.suse/livepatch-create-and-include-UAPI-headers.patch.
- commit 9ab151a
* Thu Jun 11 2020 mbenes@suse.cz
- livepatch: Remove .klp.arch (bsc#1071995).
- commit 0d36b79
* Thu Jun 11 2020 jack@suse.cz
- bfq: Fix check detecting whether waker queue should be selected
  (bsc#1168838).
- commit 570a2f2
* Thu Jun 11 2020 mbenes@suse.cz
- livepatch: Apply vmlinux-specific KLP relocations early
  (bsc#1071995).
- Refresh
  patches.suse/livepatch-create-and-include-UAPI-headers.patch.
- commit 28cfe0c
* Thu Jun 11 2020 mgorman@suse.de
- Refresh
  patches.suse/cpufreq-intel_pstate-Allow-unspecified-FADT-profile-to-probe-PPC.patch.
- Refresh
  patches.suse/pcc-cpufreq-Re-introduce-deadband-effect-to-reduce-number-of-frequency-changes.patch.
- Refresh patches.suse/readahead-request-tunables.patch.
- commit e092759
* Wed Jun 10 2020 msuchanek@suse.de
- scsi: ibmvscsi: Don't send host info in adapter info MAD after
  LPM (bsc#1172759 ltc#184814).
- commit 2cb7730
* Wed Jun 10 2020 mbenes@suse.cz
- livepatch: Disallow vmlinux.ko (bsc#1071995).
- commit a7813fd
* Wed Jun 10 2020 tiwai@suse.de
- ASoC: intel: cht_bsw_max98090_ti: Add all Chromebooks that
  need pmc_plt_clk_0 quirk (bsc#1171246).
- commit 912573f
* Wed Jun 10 2020 colyli@suse.de
- blacklist.conf: add Add 78f57ef9d50a75326da73d352d7c27828495229a
- commit 828a354
* Wed Jun 10 2020 ykaukab@suse.de
- config: arm64: enable CONFIG_IOMMU_DEFAULT_PASSTHROUGH
  References: bsc#1172739
- commit 3b77faf
* Wed Jun 10 2020 mgorman@suse.de
- fsnotify: Rearrange fast path to minimise overhead when there
  is no watcher (bsc#1158765).
- sched/fair: fix nohz next idle balance (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- commit 1b0cbfe
* Wed Jun 10 2020 tiwai@suse.de
- vt: keyboard: avoid signed integer overflow in k_ascii
  (CVE-2020-13974 bsc#1172775).
- commit 9b0650e
* Wed Jun 10 2020 tiwai@suse.de
- remoteproc: Fix and restore the parenting hierarchy for vdev
  (git-fixes).
- remoteproc: Fall back to using parent memory pool if no
  dedicated available (git-fixes).
- remoteproc: Add missing '\n' in log messages (git-fixes).
- remoteproc: Fix IDR initialisation in rproc_alloc() (git-fixes).
- drm/i915: Whitelist context-local timestamp in the gen9
  cmdparser (git-fixes).
- drm/i915/gem: Avoid iterating an empty list (git-fixes).
- Revert "drm/amd/display: disable dcn20 abm feature for bring up"
  (git-fixes).
- commit 8d68d47
* Wed Jun 10 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/fanotify-fix-ignore-mask-logic-for-events-on-child-a.patch
- commit bceb814
* Wed Jun 10 2020 mkoutny@suse.com
- Revert "fs/seq_file.c: seq_read(): add info message about buggy .next functions" (bsc#1172751)
  The message floods dmesg and its benefit is marginal in default kernel.
  Delete patches.suse/fs-seq_file.c-seq_read-add-info-message-about-buggy-.patch.
- commit 00aa3d5
* Wed Jun 10 2020 pvorel@suse.cz
- fanotify: fix ignore mask logic for events on child and on dir
  (bsc#1172719).
- commit ce60cdb
* Tue Jun  9 2020 jroedel@suse.de
- blacklist.conf: Add c4e0f3b24004 iommu/msm: Make msm_iommu_lock static
- commit fd75b72
* Tue Jun  9 2020 jroedel@suse.de
- KVM: x86/mmu: Set mmio_value to '0' if reserved #PF can't be
  generated (bsc#1171904).
- KVM: x86: only do L1TF workaround on affected processors
  (bsc#1171904).
- commit d33828d
* Tue Jun  9 2020 dwagner@suse.de
- blacklist: 55e8c8eb2c7b ("posix-cpu-timers: Store a reference to a pid not a task")
  This fixes a historical/theoretical bug which is not worth
  back porting. It depends on tglx's massive posix-cpu-timers
  refactoring. The risk to introduce subtle bugs do not outweigh the
  gain of fixing the bug.
- commit fc0a1e1
* Tue Jun  9 2020 dwagner@suse.de
- netfilter: not mark a spinlock as __read_mostly (git-fixes).
- netfilter: connlabels: prefer static lock initialiser
  (git-fixes).
- commit 2cf2f11
* Tue Jun  9 2020 oneukum@suse.com
- CDC-ACM: heed quirk also in error handling (git-fixes).
- commit a90fe00
* Mon Jun  8 2020 tzimmermann@suse.de
- drm/dp_mst: Increase ACT retry timeout to 3s (bsc#1152472)
  * context changes
- commit 07b82ee
* Mon Jun  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: force fbdev into vram'
- commit 0516e8a
* Mon Jun  8 2020 ailiop@suse.com
- xfs: fix duplicate verification from xfs_qm_dqflush()
  (git-fixes).
- commit 51ce4f9
* Mon Jun  8 2020 ailiop@suse.com
- xfs: clean up the error handling in xfs_swap_extents
  (git-fixes).
- commit 7e54c91
* Mon Jun  8 2020 nsaenzjulienne@suse.de
- PCI: brcmstb: Fix window register offset from 4 to 8
  (git-fixes).
- PCI: brcmstb: Assert fundamental reset on initialization
  (git-fixes).
- commit 70db1f0
* Mon Jun  8 2020 nsaenzjulienne@suse.de
- blacklist.conf: Blacklist 3ac395a5b3f3
- commit f86499e
* Mon Jun  8 2020 tiwai@suse.de
- ima: Remove __init annotation from ima_pcrread() (git-fixes).
- commit 438f005
* Mon Jun  8 2020 tiwai@suse.de
- ima: Directly free *entry in ima_alloc_init_template() if
  digests is NULL (bsc#1172223).
- commit 3741933
* Mon Jun  8 2020 tiwai@suse.de
- ima: Call ima_calc_boot_aggregate() in ima_eventdigest_init()
  (bsc#1172223).
- commit 25930ca
* Mon Jun  8 2020 tiwai@suse.de
- Move upstreamed IMA patches into sorted section
- commit 7e9708e
* Mon Jun  8 2020 tiwai@suse.de
- ima: Directly assign the ima_default_policy pointer to ima_rules (bsc#1172223)
  Delete obsoleted downstream fix, too:
  patches.suse/ima-Fix-Oops-at-boot-with-ima_template_fmt-d-boot-op.patch
- commit f1f48b1
* Mon Jun  8 2020 tiwai@suse.de
- evm: Fix a small race in init_desc() (git-fixes).
- commit 391f180
* Mon Jun  8 2020 tiwai@suse.de
- pinctrl: sprd: Fix the incorrect pull-up definition (git-fixes).
- pinctrl: freescale: imx: Use 'devm_of_iomap()' to avoid
  a resource leak in case of error in 'imx_pinctrl_probe()'
  (git-fixes).
- pinctrl: freescale: imx: Fix an error handling path in
  'imx_pinctrl_probe()' (git-fixes).
- pinctrl: imxl: Fix an error handling path in
  'imx1_pinctrl_core_probe()' (git-fixes).
- pinctrl: samsung: Save/restore eint_mask over suspend for
  EINT_TYPE GPIOs (git-fixes).
- pinctrl: samsung: Correct setting of eint wakeup mask on s5pv210
  (git-fixes).
- pinctrl: ocelot: Fix GPIO interrupt decoding on Jaguar2
  (git-fixes).
- pinctrl: rza1: Fix wrong array assignment of rza1l_swio_entries
  (git-fixes).
- pinctrl: stmfx: stmfx_pinconf_set doesn't require to get
  direction anymore (git-fixes).
- rtc: rv3028: Add missed check for devm_regmap_init_i2c()
  (git-fixes).
- rtc: mc13xxx: fix a double-unlock issue (git-fixes).
- extcon: adc-jack: Fix an error handling path in
  'adc_jack_probe()' (git-fixes).
- w1: omap-hdq: cleanup to add missing newline for some dev_dbg
  (git-fixes).
- fpga: dfl: afu: Corrected error handling levels (git-fixes).
- habanalabs: Align protection bits configuration of all TPCs
  (git-fixes).
- misc: fastrpc: fix potential fastrpc_invoke_ctx leak
  (git-fixes).
- slimbus: core: Fix mismatch in of_node_get/put (git-fixes).
- firmware: xilinx: Fix an error handling path in
  'zynqmp_firmware_probe()' (git-fixes).
- iio:chemical:pms7003: Fix timestamp alignment and prevent data
  leak (git-fixes).
- iio:chemical:sps30: Fix timestamp alignment (git-fixes).
- iio: vcnl4000: Fix i2c swapped word reading (git-fixes).
- staging: sm750fb: add missing case while setting FB_VISUAL
  (git-fixes).
- iio: pressure: bmp280: Tolerate IRQ before registering
  (git-fixes).
- iio: buffer: Don't allow buffers without any channels enabled
  to be activated (git-fixes).
- tty: n_gsm: Fix bogus i++ in gsm_data_kick (git-fixes).
- tty: n_gsm: Fix waking up upper tty layer when room available
  (git-fixes).
- tty: n_gsm: Fix SOF skipping (git-fixes).
- USB: serial: usb_wwan: do not resubmit rx urb on fatal errors
  (git-fixes).
- CDC-ACM: heed quirk also in error handling (git-fixes).
- usb: musb: Fix runtime PM imbalance on error (git-fixes).
- usb: musb: start session in resume for host port (git-fixes).
- usb: gadget: fix potential double-free in m66592_probe
  (git-fixes).
- usb: gadget: lpc32xx_udc: don't dereference ep pointer before
  null check (git-fixes).
- USB: gadget: udc: s3c2410_udc: Remove pointless NULL check in
  s3c2410_udc_nuke (git-fixes).
- usb: dwc2: gadget: move gadget resume after the core is in L0
  state (git-fixes).
- usb: dwc3: gadget: Properly handle failed kick_transfer
  (git-fixes).
- usb: dwc3: gadget: Properly handle ClearFeature(halt)
  (git-fixes).
- USB: host: ehci-mxc: Add error handling in ehci_mxc_drv_probe()
  (git-fixes).
- USB: ohci-sm501: fix error return code in
  ohci_hcd_sm501_drv_probe() (git-fixes).
- PCI: vmd: Filter resource type bits from shadow register
  (git-fixes).
- PCI: v3-semi: Fix a memory leak in v3_pci_probe() error handling
  paths (git-fixes).
- PCI: rcar: Fix incorrect programming of OB windows (git-fixes).
- PCI: amlogic: meson: Don't use FAST_LINK_MODE to set up link
  (git-fixes).
- PCI: brcmstb: Fix window register offset from 4 to 8
  (git-fixes).
- PCI: brcmstb: Assert fundamental reset on initialization
  (git-fixes).
- PCI: Allow pci_resize_resource() for devices on root bus
  (git-fixes).
- PCI/PM: Adjust pcie_wait_for_link_delay() for caller delay
  (git-fixes).
- PCI/PM: Call .bridge_d3() hook only if non-NULL (git-fixes).
- PCI/PTM: Inherit Switch Downstream Port PTM settings from
  Upstream Port (git-fixes).
- PCI: Program MPS for RCiEP devices (git-fixes).
- PCI: Fix pci_register_host_bridge() device_register() error
  handling (git-fixes).
- evm: Fix possible memory leak in evm_calc_hmac_or_hash()
  (git-fixes).
- gpio: dwapb: Call acpi_gpiochip_free_interrupts() on GPIO chip
  de-registration (git-fixes).
- gpiolib: Document that GPIO line names are not globally unique
  (git-fixes).
- gpio: dwapb: Append MODULE_ALIAS for platform driver
  (git-fixes).
- vfio/mdev: Fix reference count leak in add_mdev_supported_type
  (git-fixes).
- vfio/pci: fix memory leaks in alloc_perm_bits() (git-fixes).
- HID: i2c-hid: add Schneider SCL142ALM to descriptor override
  (git-fixes).
- mt76: mt76x02u: Add support for newer versions of the XBox
  One wifi adapter (git-fixes).
- p54usb: add AirVasT USB stick device-id (git-fixes).
- drm/edid: Add Oculus Rift S to non-desktop list (git-fixes).
- i2c: altera: Fix race between xfer_msg and isr thread
  (git-fixes).
- evm: Fix RCU list related warnings (git-fixes).
- evm: Check also if *tfm is an error pointer in init_desc()
  (git-fixes).
- drm/i915: fix port checks for MST support on gen >= 11
  (git-fixes).
- ASoC: intel - fix the card names (git-fixes).
- commit 993a2a7
* Mon Jun  8 2020 colyli@suse.de
- raid5: remove gfp flags from scribble_alloc() (bsc#1166985).
- commit d35a2bb
* Mon Jun  8 2020 tiwai@suse.de
- Add cherry-picked ID to the already applied pinctrl patch
- commit b7b9bd6
* Sun Jun  7 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/scsi-lpfc-Change-default-queue-allocation-for-reduce.patch
  patches.suse/scsi-lpfc-Fix-MDS-Diagnostic-Enablement-definition.patch
  patches.suse/scsi-lpfc-Fix-lpfc_nodelist-leak-when-processing-uns.patch
  patches.suse/scsi-lpfc-Fix-negation-of-else-clause-in-lpfc_prep_n.patch
  patches.suse/scsi-lpfc-Fix-noderef-and-address-space-warnings.patch
  patches.suse/scsi-lpfc-Maintain-atomic-consistency-of-queue_claim.patch
  patches.suse/scsi-lpfc-Remove-re-binding-of-nvme-rport-during-reg.patch
  patches.suse/scsi-lpfc-Remove-redundant-initialization-to-variabl.patch
  patches.suse/scsi-lpfc-Remove-unnecessary-lockdep_assert_held-cal.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.1.patch
  patches.suse/scsi-lpfc-remove-duplicate-unloading-checks.patch
  patches.suse/scsi-zfcp-Fence-adapter-status-propagation-for-commo.patch
  patches.suse/scsi-zfcp-Fence-early-sysfs-interfaces-for-accesses-.patch
  patches.suse/scsi-zfcp-Fence-fc_host-updates-during-link-down-han.patch
  patches.suse/scsi-zfcp-Move-allocation-of-the-shost-object-to-aft.patch
  patches.suse/scsi-zfcp-Move-fc_host-updates-during-xport-data-han.patch
  patches.suse/scsi-zfcp-Move-p-t-p-port-allocation-to-after-xport-.patch
  patches.suse/scsi-zfcp-Move-shost-modification-after-QDIO-re-open.patch
  patches.suse/scsi-zfcp-Move-shost-updates-during-xconfig-data-han.patch
- commit 9ccb987
* Sun Jun  7 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline and drop Git-repo:
  patches.suse/bpf-Fix-map-permissions-check.patch
  patches.suse/libbpf-Fix-perf_buffer__free-API-for-sparse-allocs.patch
  patches.suse/selftests-bpf-CONFIG_IPV6_SEG6_BPF-required-for-test.patch
  patches.suse/selftests-bpf-CONFIG_LIRC-required-for-test_lirc_mod.patch
  patches.suse/selftests-bpf-Fix-invalid-memory-reads-in-core_relo-.patch
  patches.suse/selftests-bpf-Fix-memory-leak-in-extract_build_id.patch
  patches.suse/selftests-bpf-flow_dissector-Close-TAP-device-FD-aft.patch
- commit fb39453
* Sun Jun  7 2020 colyli@suse.de
- xfrm: fix error in comment (git fixes (block drivers)).
- virtio-blk: handle block_device_operations callbacks after hot unplug (git fixes (block drivers)).
- dm verity fec: fix hash block number in verity_fec_decode (git fixes (block drivers)).
- dm writecache: fix data corruption when reloading the target (git fixes (block drivers)).
- commit b4c0830
* Sat Jun  6 2020 ailiop@suse.com
- xfs: force writes to delalloc regions to unwritten
  (bsc#1158242).
- commit 0735a16
* Sat Jun  6 2020 ailiop@suse.com
- xfs: measure all contiguous previous extents for prealloc size
  (bsc#1158242).
- commit 0724b42
* Sat Jun  6 2020 ailiop@suse.com
- xfs: don't fail unwritten extent conversion on writeback due
  to edquot (bsc#1158242).
- commit 8be9c37
* Fri Jun  5 2020 jeffm@suse.com
- mdraid: fix read/write bytes accounting (bsc#1172537).
- commit 52b03e4
* Fri Jun  5 2020 dwagner@suse.de
- lpfc: Fix return value in __lpfc_nvme_ls_abort (bsc#1171530).
- lpfc: fix axchg pointer reference after free and double frees
  (bsc#1171530).
- lpfc: Fix pointer checks and comments in LS receive refactoring
  (bsc#1171530).
- commit d3a7d02
* Fri Jun  5 2020 dwagner@suse.de
- series: update meta data
  The nmve/nvme-5.8 branch has been merged into mainline, that means no more
  rebases of these patches. Hence move them back to the sorted section.
- commit 4a0d7a9
* Fri Jun  5 2020 tiwai@suse.de
- firmware: imx: scu: Fix possible memory leak in imx_scu_probe()
  (git-fixes).
- firmware: qcom_scm: fix bogous abuse of dma-direct internals
  (git-fixes).
- i2c: fix missing pm_runtime_put_sync in i2c_device_probe
  (git-fixes).
- i2c: acpi: put device when verifying client fails (git-fixes).
- commit d4c4283
* Fri Jun  5 2020 bp@suse.de
- blacklist.conf: 88743470668e x86/dma: Fix max PFN arithmetic overflow on 32 bit systems
- commit efee432
* Fri Jun  5 2020 dwagner@suse.de
- lpfc_debugfs: get rid of pointless access_ok() (bsc#1171530).
- scsi: lpfc: Copyright updates for 12.6.0.4 patches
  (bsc#1171530).
- scsi: lpfc: Make lpfc_defer_acc_rsp static (bsc#1171530).
- scsi: lpfc: Fix incomplete NVME discovery when target
  (bsc#1171530).
- scsi: lpfc: fix spelling mistakes of asynchronous (bsc#1171530).
- scsi: lpfc: fix build failure with DEBUGFS disabled
  (bsc#1171530).
- scsi: lpfc: Fix memory leak on lpfc_bsg_write_ebuf_set func
  (bsc#1171530).
- commit 07d03b5
* Fri Jun  5 2020 hare@suse.de
- nvme: provide num dword helper (bsc#1159058).
- nvme: fix possible hang when ns scanning fails during error (bsc#1159058).
- nvme: prevent double free in nvme_alloc_ns() error handling (bsc#1159058).
- nvme-tcp: fix possible crash in write_zeroes processing
  (bsc#1159058).
- nvme: cleanup namespace identifier reporting in (bsc#1159058).
- nvme: rename __nvme_find_ns_head to nvme_find_ns_head
  (bsc#1159058).
- nvme: refactor nvme_identify_ns_descs error handling
  (bsc#1159058).
- nvme-tcp: Add warning on state change failure at (bsc#1159058).
- nvme-rdma: Add warning on state change failure at (bsc#1159058).
- nvme: Fix controller creation races with teardown flow
  (bsc#1159058).
- nvme: Make nvme_uninit_ctrl symmetric to nvme_init_ctrl
  (bsc#1159058).
- nvme: Fix ctrl use-after-free during sysfs deletion
  (bsc#1159058).
- nvme-pci: Re-order nvme_pci_free_ctrl (bsc#1159058).
- nvme: Remove unused return code from nvme_delete_ctrl_sync
  (bsc#1159058).
- nvme: release ida resources (bsc#1159058).
- nvme: expose hostid via sysfs for fabrics controllers
  (bsc#1159058).
- nvme: expose hostnqn via sysfs for fabrics controllers
  (bsc#1159058).
- commit 377781c
* Fri Jun  5 2020 tiwai@suse.de
- soc: qcom: rpmh: Dirt can only make you dirtier, not cleaner
  (git-fixes).
- commit 9e8f57f
* Fri Jun  5 2020 tiwai@suse.de
- drivers: soc: ti: knav_qmss_queue: Make knav_gp_range_ops static
  (git-fixes).
- soc/tegra: pmc: Select GENERIC_PINCONF (git-fixes).
- soc: qcom: rpmh-rsc: Allow using free WAKE TCS for active
  request (git-fixes).
- soc: qcom: rpmh-rsc: Clear active mode configuration for wake
  TCS (git-fixes).
- soc: qcom: rpmh: Invalidate SLEEP and WAKE TCSes before flushing
  new data (git-fixes).
- soc: qcom: rpmh: Update dirty flag only when data changes
  (git-fixes).
- HID: intel-ish-hid: avoid bogus uninitialized-variable warning
  (git-fixes).
- HID: sony: Fix for broken buttons on DS3 USB dongles
  (git-fixes).
- ASoC: fix incomplete error-handling in img_i2s_in_probe
  (git-fixes).
- ASoC: ux500: mop500: Fix some refcounted resources issues
  (git-fixes).
- ASoC: SOF: core: fix error return code in sof_probe_continue()
  (git-fixes).
- watchdog: imx_sc_wdt: Fix reboot on crash (git-fixes).
- mfd: stmfx: Fix stmfx_irq_init error path (git-fixes).
- mfd: stmfx: Reset chip on resume as supply was disabled
  (git-fixes).
- commit cdc4c92
* Fri Jun  5 2020 tiwai@suse.de
- Refresh and move the upstreamed relay security fix to sorted section
- commit b8d4113
* Fri Jun  5 2020 tiwai@suse.de
- kABI workaround for struct hdac_bus changes (git-fixes).
- commit d370486
* Fri Jun  5 2020 jkosina@suse.cz
- Refresh
  patches.suse/block-floppy-fix-contended-case-in-floppy_queue_rq.patch: update
  upstream reference.
- commit ec891fb
* Fri Jun  5 2020 tiwai@suse.de
- ALSA: es1688: Add the missed snd_card_free() (git-fixes).
- ALSA: hda: add sienna_cichlid audio asic id for sienna_cichlid
  up (git-fixes).
- ALSA: hda: Add ElkhartLake HDMI codec vid (git-fixes).
- ALSA: usb-audio: Fixing usage of plain int instead of NULL
  (git-fixes).
- ALSA: usb-audio: Clean up quirk entries with macros (git-fixes).
- ALSA: hda: Fix potential race in unsol event handler
  (git-fixes).
- ALSA: usb-audio: Add duplex sound support for USB devices
  using implicit feedback (git-fixes).
- ALSA: usb-audio: fixing upper volume limit for RME Babyface
  Pro routing crosspoints (git-fixes).
- ALSA: fireface: fix configuration error for nominal sampling
  transfer frequency (git-fixes).
- ALSA: firewire-lib: fix invalid assignment to union data for
  directional parameter (git-fixes).
- ALSA: hda/tegra: workaround playback failure on Tegra194
  (git-fixes).
- ALSA: hda: add member to store ratio for stripe control
  (git-fixes).
- ALSA: hda/tegra: correct number of SDO lines for Tegra194
  (git-fixes).
- ALSA: hda/realtek - Fix unused variable warning w/o
  CONFIG_LEDS_TRIGGER_AUDIO (git-fixes).
- ALSA: hda/realtek - Add LED class support for micmute LED
  (git-fixes).
- ALSA: hda/realtek - Enable micmute LED on and HP system
  (git-fixes).
- ALSA: hda/realtek - Introduce polarity for micmute LED GPIO
  (git-fixes).
- ALSA: usb-audio: Fix racy list management in output queue
  (git-fixes).
- ALSA: usb-audio: Remove async workaround for Scarlett 2nd gen
  (git-fixes).
- ALSA: usb-audio: Improve frames size computation (git-fixes).
- ALSA: usb-audio: Fix a limit check in
  proc_dump_substream_formats() (git-fixes).
- ALSA: usb-audio: Print more information in stream proc files
  (git-fixes).
- ALSA: usb-audio: RME Babyface Pro mixer patch (git-fixes).
- commit 4609c7f
* Fri Jun  5 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/nfs-add-minor-version-to-nfs_server_key-for-fscache.patch
- commit 5fe8ee1
* Fri Jun  5 2020 mkubecek@suse.cz
- Update upstream reference:
  patches.suse/mm-fix-mremap-not-considering-huge-pmd-devmap.patch
- commit a7fb6a0
* Fri Jun  5 2020 glin@suse.com
- selftests/bpf: CONFIG_LIRC required for test_lirc_mode2.sh
  (bsc#1155518).
- selftests/bpf: CONFIG_IPV6_SEG6_BPF required for
  test_seg6_loop.o (bsc#1155518).
- selftests/bpf: Fix invalid memory reads in core_relo selftest
  (bsc#1155518).
- commit 433235c
* Fri Jun  5 2020 glin@suse.com
- selftests/bpf, flow_dissector: Close TAP device FD after the
  test (bsc#1155518).
- bpf: Fix map permissions check (bsc#1155518).
- libbpf: Fix perf_buffer__free() API for sparse allocs
  (bsc#1155518).
- selftests/bpf: Fix memory leak in extract_build_id()
  (bsc#1155518).
- commit 1e6959e
* Fri Jun  5 2020 glin@suse.com
- Refresh patches.suse/selftests-bpf-Validate-frozen-map-contents-stays-fro.patch.
- commit a23c87d
* Thu Jun  4 2020 ailiop@suse.com
- xfs: preserve default grace interval during quotacheck
  (bsc#1172170).
- commit 6ac0d79
* Thu Jun  4 2020 ailiop@suse.com
- xfs: don't commit sunit/swidth updates to disk if that would
  cause repair failures (bsc#1172169).
- commit 428ff5a
* Thu Jun  4 2020 ailiop@suse.com
- xfs: split the sunit parameter update into two parts
  (bsc#1172169).
- commit ae3fe8d
* Thu Jun  4 2020 ailiop@suse.com
- xfs: refactor agfl length computation function (bsc#1172169).
- commit 59f4128
* Thu Jun  4 2020 jack@suse.cz
- bfq: Use only idle IO periods for think time calculations
  (bsc#1171513).
- bfq: Use 'ttime' local variable (bsc#1171513).
- commit e237c2f
* Thu Jun  4 2020 bp@suse.de
- x86: Fix early boot crash on gcc-10, third try (bsc#1152489).
- commit 4156a32
* Thu Jun  4 2020 tiwai@suse.de
- media: go7007: fix a miss of snd_card_free (CVE-2019-20810
  bsc#1172458).
- commit af15264
* Thu Jun  4 2020 bp@suse.de
- EDAC/amd64: Add PCI device IDs for family 17h, model 70h
  (bsc#1165975).
- Refresh
  patches.suse/edac-amd64-add-family-ops-for-family-19h-models-00h-0fh.patch.
- commit 7847579
* Thu Jun  4 2020 jack@suse.cz
- bfq: Avoid false bfq queue merging (bsc#1171513).
- commit 5742c15
* Thu Jun  4 2020 dwagner@suse.de
- nvme-fc: print proper nvme-fc devloss_tmo value (bsc#1172391).
- commit 3186404
* Thu Jun  4 2020 tiwai@suse.de
- media: staging: ipu3-imgu: Move alignment attribute to field
  (git-fixes).
- media: Revert "staging: imgu: Address a compiler warning on
  alignment" (git-fixes).
- media: staging: ipu3: Fix stale list entries on parameter
  queue failure (git-fixes).
- media: platform: fcp: Set appropriate DMA parameters
  (git-fixes).
- media: dvb: return -EREMOTEIO on i2c transfer failure
  (git-fixes).
- Bluetooth: btmtkuart: Improve exception handling in
  btmtuart_probe() (git-fixes).
- ath10k: Remove ath10k_qmi_register_service_notifier()
  declaration (git-fixes).
- wcn36xx: Fix error handling path in 'wcn36xx_probe()'
  (git-fixes).
- ath10k: Skip handling del_server during driver exit (git-fixes).
- mwifiex: Fix memory corruption in dump_station (git-fixes).
- rtlwifi: Fix a double free in _rtl_usb_tx_urb_setup()
  (git-fixes).
- iwlwifi: avoid debug max amsdu config overwriting itself
  (git-fixes).
- ath9k_htc: Silence undersized packet warnings (git-fixes).
- ath10k: remove the max_sched_scan_reqs value (git-fixes).
- libertas_tf: avoid a null dereference in pointer priv
  (git-fixes).
- mwifiex: avoid -Wstringop-overflow warning (git-fixes).
- rtw88: fix an issue about leak system resources (git-fixes).
- b43legacy: Fix case where channel status is corrupted
  (git-fixes).
- brcmfmac: fix wrong location to get firmware feature
  (git-fixes).
- Bluetooth: hci_bcm: fix freeing not-requested IRQ (git-fixes).
- clocksource: dw_apb_timer_of: Fix missing clockevent timers
  (git-fixes).
- spi: spi-fsl-dspi: Fix 16-bit word order in 32-bit XSPI mode
  (git-fixes).
- commit 4b38228
* Wed Jun  3 2020 neilb@suse.de
- nfs: add minor version to nfs_server_key for fscache
  (bsc#1172467).
- commit b589a40
* Wed Jun  3 2020 tiwai@suse.de
- Update patch reference of a net security fix (CVE-2019-20812 bsc#1172453)
- commit c181788
* Wed Jun  3 2020 mbenes@suse.cz
- objtool: Ignore empty alternatives (bsc#1169514).
- commit 117af93
* Wed Jun  3 2020 mbenes@suse.cz
- objtool: Clean instruction state before each function validation
  (bsc#1169514).
- commit 7737495
* Wed Jun  3 2020 mhocko@suse.com
- mm: Fix mremap not considering huge pmd devmap (bsc#1172317,
  CVE-2020-10757).
- commit 43819f6
* Wed Jun  3 2020 msuchanek@suse.de
- Delete patches.suse/seltests-powerpc-Add-a-selftest-for-memcpy_mcsafe.patch (bsc#1171699).
  This patch adds a symlink which cannot be handled by quilt.
- commit 6407cc2
* Wed Jun  3 2020 tiwai@suse.de
- relay: handle alloc_percpu returning NULL in relay_open
  (CVE-2019-19462 bsc#1158265).
- commit 47f5251
* Wed Jun  3 2020 dwagner@suse.de
- Drop a couple of block layer git-fixes (bsc#1170891 bsc#1173139)
  Upstream changed the partition usage counter check back and forth and
  ended up reverting all changes. Let's drop our the partial backport.
  (cherry picked from commit 70ad1b2fa5955d91e1a09a8027daf210e28fee30)
- Drop a couple of block layer git-fixes
  Upstream changed the partition usage counter check back and forth and
  ended up reverting all changes. Let's drop our the partial backport.
- commit e674b5a
* Wed Jun  3 2020 dwagner@suse.de
- series: Update meta data
  lfpc commits have been merged into the jejb tree.
- commit 557015d
* Wed Jun  3 2020 tiwai@suse.de
- platform/x86: intel-vbtn: Only blacklist SW_TABLET_MODE on
  the 9 / "Laptop" chasis-type (git-fixes).
- commit 19f981c
* Wed Jun  3 2020 tiwai@suse.de
- drm/mcde: dsi: Fix return value check in mcde_dsi_bind()
  (git-fixes).
- video: fbdev: w100fb: Fix a potential double free (git-fixes).
- drm/dp_mst: Reformat drm_dp_check_act_status() a bit
  (git-fixes).
- agp/intel: Reinforce the barrier after GTT updates (git-fixes).
- ACPI: CPPC: Fix reference count leak in
  acpi_cppc_processor_probe() (git-fixes).
- ACPI: sysfs: Fix reference count leak in
  acpi_sysfs_add_hotplug_profile() (git-fixes).
- PM: runtime: clk: Fix clk_pm_runtime_get() error path
  (git-fixes).
- platform/x86: dell-laptop: don't register micmute LED if there
  is no token (git-fixes).
- platform/x86: intel-vbtn: Also handle tablet-mode switch on
  "Detachable" and "Portable" chassis-types (git-fixes).
- platform/x86: intel-vbtn: Do not advertise switches to userspace
  if they are not there (git-fixes).
- platform/x86: intel-vbtn: Split keymap into buttons and switches
  parts (git-fixes).
- platform/x86: intel-vbtn: Use acpi_evaluate_integer()
  (git-fixes).
- mmc: sdhci-msm: Clear tuning done flag while hs400 tuning
  (git-fixes).
- mmc: sdhci-esdhc-imx: fix the mask for tuning start point
  (git-fixes).
- mmc: mmci_sdmmc: fix DMA API warning overlapping mappings
  (git-fixes).
- mmc: uniphier-sd: call devm_request_irq() after
  tmio_mmc_host_probe() (git-fixes).
- mmc: meson-mx-sdio: trigger a soft reset after a timeout or
  CRC error (git-fixes).
- mmc: sdio: Fix potential NULL pointer error in
  mmc_sdio_init_card() (git-fixes).
- mmc: core: Use DEFINE_DEBUGFS_ATTRIBUTE instead of
  DEFINE_SIMPLE_ATTRIBUTE (git-fixes).
- Input: synaptics-rmi4 - fix error return code in
  rmi_driver_probe() (git-fixes).
- Input: i8042 - add ThinkPad S230u to i8042 reset list
  (git-fixes).
- Input: xpad - add custom init packet for Xbox One S controllers
  (git-fixes).
- Input: evdev - call input_flush_device() on release(), not
  flush() (git-fixes).
- Input: usbtouchscreen - add support for BonXeon TP (git-fixes).
- clk: ti: am33xx: fix RTC clock parent (git-fixes).
- usb: gadget: legacy: fix redundant initialization warnings
  (git-fixes).
- usb: dwc3: pci: Enable extcon driver for Intel Merrifield
  (git-fixes).
- drm/amd/powerplay: perform PG ungate prior to CG ungate
  (git-fixes).
- gpio: tegra: mask GPIO IRQs during IRQ shutdown (git-fixes).
- commit 28d8ae3
* Wed Jun  3 2020 ykaukab@suse.de
- fdt: Update CRC check for rng-seed (jsc#SLE-12424).
- commit 4204d16
* Wed Jun  3 2020 wqu@suse.com
- btrfs: reloc: clear DEAD_RELOC_TREE bit for orphan roots  to
  prevent runaway balance (bsc#1171417 bsc#1160947 bsc#1172366).
- commit af6e7de
* Wed Jun  3 2020 wqu@suse.com
- btrfs: reloc: fix reloc root leak and NULL pointer  dereference
  (bsc#1171417 bsc#1160947 bsc#1172366).
- commit 96f60c2
* Wed Jun  3 2020 neilb@suse.de
- nfsd: always check return value of find_any_file (bsc#1172208).
- commit 2c210bd
* Tue Jun  2 2020 tiwai@suse.de
- fs/binfmt_elf.c: allocate initialized memory in
  fill_thread_core_info() (CVE-2020-10732 bsc#1171220).
- commit b52f45b
* Tue Jun  2 2020 tiwai@suse.de
- iwlwifi: pcie: handle QuZ configs with killer NICs as well
  (bsc#1172374).
- commit 21f33d7
* Tue Jun  2 2020 tiwai@suse.de
- crypto: stm32/crc32 - fix multi-instance (git-fixes).
- crypto: stm32/crc32 - fix run-time self test issue (git-fixes).
- crypto: stm32/crc32 - fix ext4 chksum BUG_ON() (git-fixes).
- crypto: drbg - fix error return code in drbg_alloc_state()
  (git-fixes).
- crypto: ccp -- don't "select" CONFIG_DMADEVICES (git-fixes).
- crypto: algapi - Avoid spurious modprobe on LOADED (git-fixes).
- spi: dw: Add SPI Rx-done wait method to DMA-based transfer
  (git-fixes).
- spi: dw: Add SPI Tx-done wait method to DMA-based transfer
  (git-fixes).
- spi: dw: Fix native CS being unset (git-fixes).
- spi: dw: Zero DMA Tx and Rx configurations on stack (git-fixes).
- spi: spi-mem: Fix Dual/Quad modes on Octal-capable devices
  (git-fixes).
- spi: pxa2xx: Fix runtime PM ref imbalance on probe error
  (git-fixes).
- spi: pxa2xx: Fix controller unregister order (git-fixes).
- spi: dw: Fix controller unregister order (git-fixes).
- spi: bcm2835aux: Fix controller unregister order (git-fixes).
- spi: bcm2835: Fix controller unregister order (git-fixes).
- spi: Fix controller unregister order (git-fixes).
- spi: bcm-qspi: when tx/rx buffer is NULL set to 0 (git-fixes).
- spi: Respect DataBitLength field of SpiSerialBusV2() ACPI
  resource (git-fixes).
- NFC: st21nfca: add missed kfree_skb() in an error path
  (git-fixes).
- crypto: chelsio/chtls: properly set tp->lsndtime (git-fixes).
- ieee80211: Fix incorrect mask for default PE duration
  (git-fixes).
- mac80211: mesh: fix discovery timer re-arming issue / crash
  (git-fixes).
- gpio: bcm-kona: Fix return value of bcm_kona_gpio_probe()
  (git-fixes).
- gpio: pxa: Fix return value of pxa_gpio_probe() (git-fixes).
- gpio: exar: Fix bad handling for ida_simple_get error path
  (git-fixes).
- commit c5d8ee8
* Tue Jun  2 2020 nsaenzjulienne@suse.de
- spi: spi-fsl-dspi: Replace interruptible wait queue with a
  simple completion (git-fixes).
- commit eb6dfdf
* Tue Jun  2 2020 ykaukab@suse.de
- kabi: ppc64le: prevent struct dma_map_ops to become defined (jsc#SLE-12424).
- commit ca74359
* Tue Jun  2 2020 jroedel@suse.de
- iommu: Fix reference count leak in iommu_group_alloc
  (bsc#1172394).
- iommu/amd: Fix legacy interrupt remapping for x2APIC-enabled
  system (bsc#1172393).
- commit 7cd78b9
* Tue Jun  2 2020 jslaby@suse.cz
- net: bcmgenet: correct per TX/RX ring statistics
  (networking-stable-20_04_27).
- net/x25: Fix x25_neigh refcnt leak when receiving frame
  (networking-stable-20_04_27).
- cxgb4: fix adapter crash due to wrong MC size
  (networking-stable-20_04_27).
- vxlan: use the correct nlattr array in NL_SET_ERR_MSG_ATTR
  (networking-stable-20_04_27).
- mlxsw: Fix some IS_ERR() vs NULL bugs
  (networking-stable-20_04_27).
- ipv4: Update fib_select_default to handle nexthop objects
  (networking-stable-20_04_27).
- vrf: Fix IPv6 with qdisc and xfrm (networking-stable-20_04_27).
- sched: etf: do not assume all sockets are full blown
  (networking-stable-20_04_27).
- net: dsa: b53: b53_arl_rw_op() needs to select IVL or SVL
  (networking-stable-20_04_27).
- net: dsa: b53: Rework ARL bin logic
  (networking-stable-20_04_27).
- net: dsa: b53: Fix ARL register definitions
  (networking-stable-20_04_27).
- net: dsa: b53: Lookup VID in ARL searches when VLAN is enabled
  (networking-stable-20_04_27).
- vrf: Check skb for XFRM_TRANSFORMED flag
  (networking-stable-20_04_27).
- xfrm: Always set XFRM_TRANSFORMED in xfrm{4,6}_output_finish
  (networking-stable-20_04_27).
- team: fix hang in team_mode_get() (networking-stable-20_04_27).
- cxgb4: fix large delays in PTP synchronization
  (networking-stable-20_04_27).
- net: openvswitch: ovs_ct_exit to be done under ovs_lock
  (networking-stable-20_04_27).
- tcp: cache line align MAX_TCP_HEADER
  (networking-stable-20_04_27).
- net/mlx4_en: avoid indirect call in TX completion
  (networking-stable-20_04_27).
- net: netrom: Fix potential nr_neigh refcnt leak in nr_add_node
  (networking-stable-20_04_27).
- commit 5938694
* Tue Jun  2 2020 nsaenzjulienne@suse.de
- spi: fsl: use platform_get_irq() instead of of_irq_to_resource()
  (git-fixes).
- commit bd042e3
* Tue Jun  2 2020 jslaby@suse.cz
- amd-xgbe: Use __napi_schedule() in BH context
  (networking-stable-20_04_17).
- net: dsa: mt7530: fix tagged frames pass-through in VLAN-unaware
  mode (networking-stable-20_04_17).
- net: tun: record RX queue in skb before do_xdp_generic()
  (networking-stable-20_04_17).
- net: ipv4: devinet: Fix crash when add/del multicast IP with
  autojoin (networking-stable-20_04_17).
- net: qrtr: send msgs from local of same id as broadcast
  (networking-stable-20_04_17).
- net/mlx5e: Fix pfnum in devlink port attribute
  (networking-stable-20_04_17).
- net/mlx5e: Add missing release firmware call
  (networking-stable-20_04_17).
- net/mlx5: Fix frequent ioread PCI access during recovery
  (networking-stable-20_04_17).
- l2tp: Allow management of tunnels and session in user namespace
  (networking-stable-20_04_17).
- hsr: check protocol version in hsr_newlink()
  (networking-stable-20_04_17).
- net: revert default NAPI poll timeout to 2 jiffies
  (networking-stable-20_04_17).
- net: ipv6: do not consider routes via gateways for anycast
  address check (networking-stable-20_04_17).
- commit 1727243
* Tue Jun  2 2020 tiwai@suse.de
- supported.conf: Mark two hwtracing helper modules as externally supported (bsc#1170879)
- commit 504def2
* Tue Jun  2 2020 tbogendoerfer@suse.de
- net: mvpp2: Enable autoneg bypass for 1000BaseX/2500BaseX ports
  (bsc#1162209).
- commit 7789c1f
* Tue Jun  2 2020 neilb@suse.de
- kabi fix for sunrpc-clean-up-properly-in-gss_mech_unregister
  (bsc#1171219, CVE-2020-12656).
- sunrpc: clean up properly in gss_mech_unregister() (bsc#1171219,
  CVE-2020-12656).
- sunrpc: svcauth_gss_register_pseudoflavor must reject duplicate
  registrations (bsc#1171219, CVE-2020-12656).
- commit 6de429c
* Mon Jun  1 2020 mkubecek@suse.cz
- selinux: properly handle multiple messages in
  selinux_netlink_send() (CVE-2020-10751 bsc#1171189).
- commit 7f84ce6
* Mon Jun  1 2020 nsaenzjulienne@suse.de
- spi: spi-fsl-dspi: Don't access reserved fields in SPI_MCR
  (git-fixes).
- pwm: sun4i: Move pwm_calculate() out of spin_lock() (git-fixes).
- spi: fsl: don't map irq during probe (git-fixes).
- spi: spi-fsl-dspi: Change usage pattern of SPI_MCR_* and
  SPI_CTAR_* macros (git-fixes).
- commit b10c30b
* Mon Jun  1 2020 nsaenzjulienne@suse.de
- blacklist.conf: Blacklist 671ffde1752f
- commit 5cf09f7
* Mon Jun  1 2020 mkubecek@suse.cz
- netlabel: cope with NULL catmap (CVE-2020-10711 bsc#1171191).
- commit 5e0d442
* Mon Jun  1 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/btrfs-fix-log-context-list-corruption-after-rename-w.patch
- commit e2decaa
* Mon Jun  1 2020 nsaenzjulienne@suse.de
- blacklist.conf: Blacklist 37b410018064
- commit e4b5a91
* Mon Jun  1 2020 nsaenzjulienne@suse.de
- blacklist.conf: Blacklist 34719de919af
- commit b0e5046
* Mon Jun  1 2020 fdmanana@suse.com
- btrfs: fix partial loss of prealloc extent past i_size after
  fsync (bsc#1172343).
- commit 54a1118
* Mon Jun  1 2020 fdmanana@suse.com
- btrfs: fix log context list corruption after rename whiteout
  error (bsc#1172342).
- commit 4fb9cbe
* Mon Jun  1 2020 msuchanek@suse.de
- drivers/net/ibmvnic: Update VNIC protocol version reporting
  (bsc#1065729).
- commit 141c495
* Mon Jun  1 2020 pmladek@suse.com
- powerpc/bpf: Enable bpf_probe_read{, str}() on powerpc again
  (bsc#1172344).
- Update config files.
- commit 4d25196
* Mon Jun  1 2020 pmladek@suse.com
- bpf: Restrict bpf_probe_read{, str}() only to archs where they
  work (bsc#1172344).
- Update config files.
- commit e0c0f64
* Sat May 30 2020 tiwai@suse.de
- soc: mediatek: cmdq: return send msg error code (git-fixes).
- mmc: block: Fix use-after-free issue for rpmb (git-fixes).
- gpu/drm: Ingenic: Fix opaque pointer casted to wrong type
  (git-fixes).
- drm/amd/display: drop cursor position check in atomic test
  (git-fixes).
- commit a495b53
* Sat May 30 2020 tiwai@suse.de
- Move an upstreamed sound patch into sorted section
- commit 423c7d0
* Sat May 30 2020 tiwai@suse.de
- ALSA: hda/realtek - Add new codec supported for ALC287
  (git-fixes).
- ALSA: usb-audio: Quirks for Gigabyte TRX40 Aorus Master onboard
  audio (git-fixes).
- ALSA: usb-audio: mixer: volume quirk for ESS Technology Asus
  USB DAC (git-fixes).
- ALSA: hwdep: fix a left shifting 1 by 31 UB bug (git-fixes).
- commit eb6c2db
* Fri May 29 2020 bp@suse.de
- x86/mm/cpa: Flush direct map alias during cpa (bsc#1152489).
- commit 9b8006c
* Fri May 29 2020 bp@suse.de
- blacklist.conf: Add arch/x86/um to the blacklist
- commit afdd481
* Fri May 29 2020 tiwai@suse.de
- ima: Fix Oops at boot with ima_template_fmt=d boot option
  (bsc#1172223).
- commit f5ff35f
* Fri May 29 2020 tiwai@suse.de
- Input: synaptics-rmi4 - really fix attn_data use-after-free
  (git-fixes).
- Input: dlink-dir685-touchkeys - fix a typo in driver name
  (git-fixes).
- commit 80c7b8b
* Thu May 28 2020 tiwai@suse.de
- misc: rtsx: Add short delay after exit from ASPM (git-fixes).
- mei: release me_cl object reference (git-fixes).
- iio: adc: stm32-dfsdm: fix device used to request dma
  (git-fixes).
- iio: adc: stm32-adc: fix device used to request dma (git-fixes).
- drm/etnaviv: fix perfmon domain interation (git-fixes).
- component: Silence bind error on -EPROBE_DEFER (git-fixes).
- USB: core: Fix misleading driver bug report (git-fixes).
- drm/amd/display: Prevent dpcd reads with passive dongles
  (git-fixes).
- platform/x86: asus-nb-wmi: Do not load on Asus T100TA and T200TA
  (git-fixes).
- HID: quirks: Add HID_QUIRK_NO_INIT_REPORTS quirk for Dell K12A
  keyboard-dock (git-fixes).
- HID: i2c-hid: reset Synaptics SYNA2393 on resume (git-fixes).
- HID: alps: ALPS_1657 is too specific; use U1_UNICORN_LEGACY
  instead (git-fixes).
- HID: alps: Add AUI1657 device ID (git-fixes).
- HID: multitouch: add eGalaxTouch P80H84 support (git-fixes).
- i2c: dev: Fix the race between the release of i2c_dev and cdev
  (git-fixes).
- iio: adc: stm32-adc: Use dma_request_chan() instead
  dma_request_slave_channel() (git-fixes).
- iio: adc: stm32-dfsdm: Use dma_request_chan() instead
  dma_request_slave_channel() (git-fixes).
- commit 44aca06
* Wed May 27 2020 bp@suse.de
- x86/speculation: Add SRBDS vulnerability and mitigation
  documentation (bsc#1154824 CVE-2020-0543).
- commit 6bcc04c
* Wed May 27 2020 ykaukab@suse.de
- Refresh
  patches.suse/cpufreq-tegra186-add-CPUFREQ_NEED_INITIAL_FREQ_CHECK.patch.
- commit 819998f
* Wed May 27 2020 bp@suse.de
- x86/speculation: Add Special Register Buffer Data Sampling
  (SRBDS) mitigation (bsc#1154824 CVE-2020-0543).
- commit a4ac28e
* Wed May 27 2020 ykaukab@suse.de
- PCI: mobiveil: ls_pcie_g4: fix SError when accessing config space (bsc#1161495).
- PCI: mobiveil: ls_pcie_g4: add Workaround for A-011451 (bsc#1161495).
- PCI: mobiveil: ls_pcie_g4: add Workaround for A-011577 (bsc#1161495).
- PCI: mobiveil: Fix unmet dependency warning for PCIE_MOBIVEIL_PLAT (bsc#1161495).
- PCI: mobiveil: Fix sparse different address space warnings (bsc#1161495).
- PCI: mobiveil: Add PCIe Gen4 RC driver for Layerscape SoCs (bsc#1161495).
- PCI: mobiveil: Add Header Type field check (bsc#1161495).
- PCI: mobiveil: Add 8-bit and 16-bit CSR register accessors (bsc#1161495).
- PCI: mobiveil: Allow mobiveil_host_init() to be used to re-init host (bsc#1161495).
- PCI: mobiveil: Add callback function for link up check (bsc#1161495).
- PCI: mobiveil: Add callback function for interrupt initialization (bsc#1161495).
- PCI: mobiveil: Modularize the Mobiveil PCIe Host Bridge IP driver (bsc#1161495).
- PCI: mobiveil: Collect the interrupt related operations into a function (bsc#1161495).
- PCI: mobiveil: Move the host initialization into a function (bsc#1161495).
- PCI: mobiveil: Introduce a new structure mobiveil_root_port (bsc#1161495).
- commit 84a8a95
* Wed May 27 2020 ykaukab@suse.de
- pcie: mobiveil: remove patchset v9
  Prepare to backport upstream version.
- commit 00b589d
* Wed May 27 2020 bp@suse.de
- x86/cpu: Add 'table' argument to cpu_matches() (bsc#1154824
  CVE-2020-0543).
- commit a0bbf3d
* Wed May 27 2020 dwagner@suse.de
- scsi: lpfc: Fix lpfc_nodelist leak when processing unsolicited
  event (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: remove duplicate unloading checks (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
  Remove hunk in patches.suse/lpfc-Refactor-Send-LS-Response-support.patch
  which is in patches.suse/scsi-lpfc-remove-duplicate-unloading-checks.patch
- scsi: lpfc: Remove redundant initialization to variable rc
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.8.0.1 (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix MDS Diagnostic Enablement definition
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix noderef and address space warnings (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Remove unnecessary lockdep_assert_held calls
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Change default queue allocation for reduced memory
  consumption (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix negation of else clause in
  lpfc_prep_node_fc4type (bsc#1164777 bsc#1164780 bsc#1165211
  jsc#SLE-8654).
- scsi: lpfc: Remove re-binding of nvme rport during registration
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Maintain atomic consistency of queue_claimed flag
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- commit 575ae7a
* Wed May 27 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/s390-kexec_file-fix-initrd-location-for-kdump-kernel.patch
- update upstream reference and move into sorted section:
  patches.suse/x86-microcode-amd-increase-microcode-patch_max_size.patch
- move into sorted section:
  patches.suse/signal-avoid-double-atomic-counter-increments-for-user-accounting.patch
  No effect on expanded tree.
- commit 571cf9a
* Wed May 27 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/cifs-add-SMB2_open-arg-to-return-POSIX-data.patch
  patches.suse/cifs-add-smb2-POSIX-info-level.patch
  patches.suse/cifs-call-wake_up-server-response_q-inside-of-cifs_r.patch
  patches.suse/cifs-do-d_move-in-rename.patch
  patches.suse/cifs-do-not-ignore-the-SYNC-flags-in-getattr.patch
  patches.suse/cifs-handle-prefix-paths-in-reconnect.patch
  patches.suse/cifs-make-use-of-cap_unix-ses-in-cifs_reconnect_tcon.patch
  patches.suse/cifs-plumb-smb2-POSIX-dir-enumeration.patch
  patches.suse/cifs-potential-unintitliazed-error-code-in-cifs_geta.patch
  patches.suse/cifs-rename-posix-create-rsp.patch
  patches.suse/cifs-use-mod_delayed_work-for-server-reconnect-if-al.patch
  patches.suse/smb3-fix-performance-regression-with-setting-mtime.patch
- update to mainline version, rename and move into sorted section:
  patches.suse/cifs-print-warning-once-if-mounting-with-vers-1.0.patch -> patches.suse/cifs-print-warning-mounting-with-vers-1-0.patch
  No relevant effect on expanded tree:
  diff -urN old/fs/cifs/connect.c new/fs/cifs/connect.c
  - -- old/fs/cifs/connect.c	2020-05-27 11:46:54.090968292 +0200
  +++ new/fs/cifs/connect.c	2020-05-27 11:46:54.990971522 +0200
  @@ -1466,8 +1466,8 @@
  cifs_dbg(VFS, "vers=1.0 (cifs) not permitted when mounting with smb3\n");
  return 1;
  }
  - printk_once(KERN_WARNING "Use of the less secure dialect "
  - "vers=1.0 is not recommended unless required for "
  +		cifs_dbg(VFS, "Use of the less secure dialect vers=1.0 "
  +			   "is not recommended unless required for "
  "access to very old servers\n");
  vol->ops = &smb1_operations;
  vol->vals = &smb1_values;
  diff -urN old/fs/cifs/smb2ops.c new/fs/cifs/smb2ops.c
  - -- old/fs/cifs/smb2ops.c	2020-05-27 11:46:54.074968234 +0200
  +++ new/fs/cifs/smb2ops.c	2020-05-27 11:46:54.974971463 +0200
  @@ -3020,7 +3020,7 @@
  oparms.fid = &fid;
  oparms.reconnect = false;
  - rc = SMB2_open(xid, &oparms, utf16_path, &oplock, NULL,NULL, NULL,
  +	rc = SMB2_open(xid, &oparms, utf16_path, &oplock, NULL, NULL, NULL,
  NULL);
  kfree(utf16_path);
  if (!rc) {
  - -
- commit f7dacbf
* Tue May 26 2020 jkosina@suse.cz
- Refresh
  patches.suse/block-floppy-fix-contended-case-in-floppy_queue_rq.patch:
  update upstream references (submitted -> applied).
- commit fce9354
* Tue May 26 2020 jkosina@suse.cz
- block/floppy: fix contended case in floppy_queue_rq()
  (bsc#1171426).
- commit 18ed9ad
* Tue May 26 2020 tiwai@suse.de
- tty: serial: add missing spin_lock_init for SiFive serial
  console (git-fixes).
- vfio/type1: Fix VA->PA translation for PFNMAP VMAs in
  vaddr_get_pfn() (git-fixes).
- vfio: avoid possible overflow in vfio_iommu_type1_pin_pages
  (git-fixes).
- vfio: Ignore -ENODEV when getting MSI cookie (git-fixes).
- commit 250c72c
* Tue May 26 2020 tiwai@suse.de
- Add a GIT commit ID of already cherry-picked x86/platform patch
- commit 6c1b791
* Tue May 26 2020 tiwai@suse.de
- ax25: fix setsockopt(SO_BINDTODEVICE) (git-fixes).
- dmaengine: tegra210-adma: Fix an error handling path in
  'tegra_adma_probe()' (git-fixes).
- dmaengine: dmatest: Restore default for channel (git-fixes).
- dmaengine: owl: Use correct lock in owl_dma_get_pchan()
  (git-fixes).
- mtd: Fix mtd not registered due to nvmem name collision
  (git-fixes).
- mtd: spinand: Propagate ECC information to the MTD structure
  (git-fixes).
- ARM: oxnas: make ox820_boot_secondary static (git-fixes).
- commit eaf4ceb
* Tue May 26 2020 tiwai@suse.de
- ACPICA: Fixes for acpiExec namespace init file (git-fixes).
- commit 36c0ce1
* Tue May 26 2020 msuchanek@suse.de
- powerpc/64s/kuap: Restore AMR in system reset exception
  (bsc#1156395).
- powerpc/kuap: PPC_KUAP_DEBUG should depend on PPC_KUAP
  (bsc#1156395).
- commit bba3032
* Tue May 26 2020 msuchanek@suse.de
- powerpc/setup_64: Set cache-line-size based on cache-block-size
  (bsc#1065729).
- commit 2697326
* Tue May 26 2020 msuchanek@suse.de
- blacklist.conf: Add 9d82973e032e gcc-10 warnings: fix low-hanging fruit
- commit d3df11a
* Tue May 26 2020 msuchanek@suse.de
- scripts/decodecode: fix trapping instruction formatting
  (bsc#1065729).
- commit b83c354
* Tue May 26 2020 msuchanek@suse.de
- tpm: ibmvtpm: retry on H_CLOSED in tpm_ibmvtpm_send()
  (bsc#1065729).
- commit a0d3d55
* Tue May 26 2020 msuchanek@suse.de
- rpm/kernel-source.spec.in: Add obsolete_rebuilds (boo#1172073).
- commit 6524463
* Tue May 26 2020 pmladek@suse.com
- printk: queue wake_up_klogd irq_work only if per-CPU areas
  are ready (bsc#1172095).
- commit 96ce1d2
* Tue May 26 2020 pmladek@suse.com
- vsprintf: don't obfuscate NULL and error pointers (bsc#1172086).
- commit f35dca1
* Tue May 26 2020 tiwai@suse.de
- ALSA: hda/realtek - Add a model for Thinkpad T570 without DAC
  workaround (bsc#1172017).
- commit c7e1c2b
* Tue May 26 2020 jroedel@suse.de
- kabi/severities: Ingnore get_dev_data()
  The function is internal to the AMD IOMMU driver and must
  not be called by any third party.
- commit b897173
* Mon May 25 2020 jroedel@suse.de
- iommu/amd: Fix over-read of ACPI UID from IVRS table
  (bsc#1172064).
- iommu/virtio: Reverse arguments to list_add (bsc#1172068).
- iommu/amd: Do not flush Device Table in iommu_map_page()
  (bsc#1172062).
- iommu/amd: Update Device Table in increase_address_space()
  (bsc#1172066).
- iommu/amd: Call domain_flush_complete() in update_domain()
  (bsc#1172061).
- iommu/amd: Do not loop forever when trying to increase address
  space (bsc#1172063).
- iommu/amd: Fix race in increase_address_space()/fetch_pte()
  (bsc#1172065).
- iommu/qcom: Fix local_base status check (bsc#1172067).
- KVM: Check validity of resolved slot when searching memslots
  (bsc#1172069).
- commit dd49af6
* Mon May 25 2020 mkoutny@suse.com
- mm: memcontrol: fix memory.low proportional distribution
  (bsc#1168230).
- commit 94666fc
* Mon May 25 2020 dwagner@suse.de
- scsi: qla2xxx: Do not log message when reading port speed via
  sysfs (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- scsi: qla2xxx: Delete all sessions before unregister local nvme
  port (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- scsi: qla2xxx: Fix hang when issuing nvme disconnect-all in NPIV
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- commit b6f8c1c
* Mon May 25 2020 dwagner@suse.de
- wireguard: noise: separate receive counter from send counter
  (bsc#1169021 jsc#SLE-12250).
- wireguard: queueing: preserve flow hash across packet scrubbing
  (bsc#1169021 jsc#SLE-12250).
- wireguard: noise: read preshared key while taking lock
  (bsc#1169021 jsc#SLE-12250).
- wireguard: selftests: use newer iproute2 for gcc-10 (bsc#1169021
  jsc#SLE-12250).
- commit 299cebb
* Mon May 25 2020 dwagner@suse.de
- rcu: Avoid data-race in rcu_gp_fqs_check_wake() (bsc#1171828).
- rcu: Use *_ONCE() to protect lockless ->expmask accesses
  (bsc#1171828).
- rcu: Make rcu_read_unlock_special() checks match
  raise_softirq_irqoff() (bsc#1172046).
  Refresh rcu-Use-READ_ONCE-for-expmask-in-rcu_read_unlock_spe.patch
- rcu: Simplify rcu_read_unlock_special() deferred wakeups
  (bsc#1172046).
- commit 14cfc7d
* Mon May 25 2020 mbenes@suse.cz
- x86/unwind/orc: Fix unwind_get_return_address_ptr() for inactive
  tasks (bsc#1058115).
  (cherry picked from commit 5d062fa0c4b96d9f6695e0393114da63299cd52e)
- x86/unwind/orc: Fix unwind_get_return_address_ptr() for inactive
  tasks (bsc#1058115).
- commit d9c0a48
* Mon May 25 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/s390-kexec_file-fix-initrd-location-for-kdump-kernel.patch
- commit 6765b4b
* Mon May 25 2020 tiwai@suse.de
- iio: sca3000: Remove an erroneous 'get_device()' (git-fixes).
- iio: adc: ti-ads8344: Fix channel selection (git-fixes).
- staging: iio: ad2s1210: Fix SPI reading (git-fixes).
- iio: dac: vf610: Fix an error handling path in
  'vf610_dac_probe()' (git-fixes).
- commit f20f881
* Mon May 25 2020 glin@suse.com
- bpf: Prevent mmap()'ing read-only maps as writable
  (bsc#1155518).
- commit db279bd
* Sun May 24 2020 mgorman@suse.de
- sched: Offload wakee task activation if it the wakee is
  descheduling (bnc#1158748, bnc#1159781).
- sched: Optimize ttwu() spinning on p->on_cpu (bnc#1158748,
  bnc#1159781).
- commit 6a690f9
* Fri May 22 2020 tiwai@suse.de
- ALSA: hda/realtek - Add more fixup entries for Clevo machines
  (git-fixes).
- ALSA: iec1712: Initialize STDSP24 properly when using the
  model=staudio option (git-fixes).
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus
  Xtreme (git-fixes).
- ALSA: pcm: fix incorrect hw_base increase (git-fixes).
- commit 1a75995
* Fri May 22 2020 tiwai@suse.de
- Update patch reference for SPI security fix (CVE-2020-12769 bsc#1171983)
- commit bdb2e59
* Fri May 22 2020 tiwai@suse.de
- Update patch reference for USB gadeget security fix (CVE-2020-13143 bsc#1171982)
- commit 2b875ef
* Fri May 22 2020 bp@suse.de
- x86/resctrl: Preserve CDP enable over CPU hotplug (bsc#1152489).
- commit f6b2bde
* Fri May 22 2020 bp@suse.de
- x86/resctrl: Fix invalid attempt at removing the default
  resource group (bsc#1152489).
- commit 960b1f0
* Fri May 22 2020 bp@suse.de
- EDAC/synopsys: Do not dump uninitialized pinf->col
  (bsc#1152489).
- commit 349fab2
* Fri May 22 2020 bp@suse.de
- blacklist.conf: 870b4333a62e x86/ioremap: Fix CONFIG_EFI=n build
- commit c645d02
* Fri May 22 2020 pvorel@suse.cz
- nfs: fix NULL deference in nfs4_get_valid_delegation.
- commit ee8a543
* Fri May 22 2020 tonyj@suse.de
- blacklist.conf:
- commit 1787033
* Wed May 20 2020 mkubecek@suse.cz
- Update kabi files.
- update to "RC3" submission (commit de1e6fb20e9d)
- commit 8f25cbe
* Wed May 20 2020 tiwai@suse.de
- USB: gadget: fix illegal array access in binding with UDC
  (git-fixes).
- USB: usbfs: fix mmap dma mismatch (git-fixes).
- dwc3: Remove check for HWO flag in
  dwc3_gadget_ep_reclaim_trb_sg() (git-fixes).
- drm/amd/display: add basic atomic check for cursor plane
  (git-fixes).
- Make the "Reducing compressed framebufer size" message be
  DRM_INFO_ONCE() (git-fixes).
- usb: usbfs: correct kernel->user page attribute mismatch
  (git-fixes).
- dmaengine: mmp_tdma: Reset channel error on release (git-fixes).
- dmaengine: mmp_tdma: Do not ignore slave config validation
  errors (git-fixes).
- dmaengine: pch_dma.c: Avoid data race between probe and irq
  handler (git-fixes).
- drm/amdgpu: invalidate L2 before SDMA IBs (v2) (git-fixes).
- drm/amd/powerplay: avoid using pm_en before it is initialized
  revised (git-fixes).
- drm/qxl: lost qxl_bo_kunmap_atomic_page in
  qxl_image_init_helper() (git-fixes).
- pnp: Use list_for_each_entry() instead of open coding
  (git-fixes).
- drm/amdgpu: simplify padding calculations (v2) (git-fixes).
- commit eb4042e
* Wed May 20 2020 tiwai@suse.de
- blacklist.conf: Add an entry for non-supported arch/hexagon
- commit 4f664be
* Wed May 20 2020 tiwai@suse.de
- workqueue: Remove the warning in wq_worker_sleeping()
  (git-fixes).
- workqueue: don't use wq_select_unbound_cpu() for bound works
  (git-fixes).
- commit 4686860
* Wed May 20 2020 tiwai@suse.de
- vt: vt_ioctl: fix VT_DISALLOCATE freeing in-use virtual console
  (git-fixes).
- vt: vt_ioctl: remove unnecessary console allocation checks
  (git-fixes).
- commit 3c82977
* Wed May 20 2020 tiwai@suse.de
- usb: core: hub: limit HUB_QUIRK_DISABLE_AUTOSUSPEND to USB5534B
  (git-fixes).
- usb: gadget: udc: atmel: Make some symbols static (git-fixes).
- usb: host: xhci-plat: keep runtime active when removing host
  (git-fixes).
- usb: gadget: legacy: fix error return code in gncm_bind()
  (git-fixes).
- usb: gadget: legacy: fix error return code in cdc_bind()
  (git-fixes).
- usb: gadget: net2272: Fix a memory leak in an error handling
  path in 'net2272_plat_probe()' (git-fixes).
- usb: gadget: audio: Fix a missing error return value in
  audio_bind() (git-fixes).
- commit 8d23cb6
* Wed May 20 2020 tiwai@suse.de
- i2c: mux: demux-pinctrl: Fix an error handling path in
  'i2c_demux_pinctrl_probe()' (git-fixes).
- gpio: pca953x: Fix pca953x_gpio_set_config (git-fixes).
- iwlwifi: mvm: limit maximum queue appropriately (git-fixes).
- mfd: intel-lpss: Use devm_ioremap_uc for MMIO (git-fixes).
- lib: devres: add a helper function for ioremap_uc (git-fixes).
- commit db78707
* Wed May 20 2020 tiwai@suse.de
- drm/i915/gvt: Fix kernel oops for 3-level ppgtt guest
  (git-fixes).
- drm/i915/gvt: Init DPLL/DDI vreg for virtual display instead
  of inheritance (git-fixes).
- drm/i915: Propagate error from completed fences (git-fixes).
- drm/i915: Don't enable WaIncreaseLatencyIPCEnabled when IPC
  is disabled (git-fixes).
- coredump: fix crash when umh is disabled (git-fixes).
- dmaengine: dmatest: Fix process hang when reading 'wait'
  parameter (git-fixes).
- drm/i915: HDCP: fix Ri prime check done during link check
  (git-fixes).
- coredump: fix null pointer dereference on coredump (git-fixes).
- dma-debug: fix displaying of dma allocation type (git-fixes).
- dma-direct: fix data truncation in
  dma_direct_get_required_mask() (git-fixes).
- dma-coherent: fix integer overflow in the reserved-memory dma
  allocation (git-fixes).
- drm/etnaviv: rework perfmon query infrastructure (git-fixes).
- commit 79467c5
* Wed May 20 2020 tonyj@suse.de
- perf/core: fix parent pid/tid in task exit events (git-fixes).
- perf/core: Fix endless multiplex timer (git-fixes).
- commit 9e85c92
* Wed May 20 2020 mkubecek@suse.cz
- netfilter: ctnetlink: netns exit must wait for callbacks
  (bsc#1169795).
- commit 1367464
* Wed May 20 2020 ggherdovich@suse.cz
- Update upstream reference and move to sorted section:
  patches.suse/x86-sched-Don-t-enable-static-key-when-starting-seco.patch.
- commit 286ea13
* Wed May 20 2020 ggherdovich@suse.cz
- Update upstream reference and move to sorted section:
  patches.suse/x86-sched-Account-for-CPUs-with-less-than-4-cores-in.patch.
- commit 806c75b
* Wed May 20 2020 ggherdovich@suse.cz
- Update upstream reference and move to sorted section:
  patches.suse/x86-sched-Bail-out-of-frequency-invariance-if-.patch.
- commit debf0d3
* Wed May 20 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/NFSv3-fix-rpc-receive-buffer-size-for-MOUNT-call.patch
- commit c8d32f9
* Wed May 20 2020 tzimmermann@suse.de
- drm/i915/gvt: Fix kernel oops for 3-level ppgtt guest (bsc#1152489)
- commit 9d0ce16
* Wed May 20 2020 tzimmermann@suse.de
- drm/i915/gvt: Init DPLL/DDI vreg for virtual display instead of (bsc#1152489)
- commit addefe4
* Wed May 20 2020 tzimmermann@suse.de
- drm/amdgpu: force fbdev into vram (bsc#1152472)
  * context changes
- commit 84af19b
* Wed May 20 2020 tzimmermann@suse.de
- drm/i915: Don't enable WaIncreaseLatencyIPCEnabled when IPC is (bsc#1152489)
- commit 2c2843b
* Wed May 20 2020 tzimmermann@suse.de
- sun6i: dsi: fix gcc-4.8 (bsc#1152489)
- commit 7678d54
* Wed May 20 2020 tzimmermann@suse.de
- drm/i915: HDCP: fix Ri prime check done during link check (bsc#1152489)
  * context changes
- commit a3e33d0
* Wed May 20 2020 tzimmermann@suse.de
- drm/i915: Extend WaDisableDARBFClkGating to icl,ehl,tgl (bsc#1152489)
- commit 99f05b3
* Wed May 20 2020 neilb@suse.de
- NFSv3: fix rpc receive buffer size for MOUNT call (bsc#1171849).
- commit 4832c5f
* Tue May 19 2020 lduncan@suse.com
- scsi: mptfusion: Fix double fetch bug in ioctl (bsc#1171218
  CVE-2020-12652).
- commit d61daf3
* Tue May 19 2020 tiwai@suse.de
- Update patch reference for ipv6 security fix (CVE-2020-1749 bsc#1165629)
- commit b65b793
* Tue May 19 2020 jroedel@suse.de
- KVM: SVM: Fix potential memory leak in svm_cpu_init() (bsc#1171736).
- commit 010dbdc
* Tue May 19 2020 dmueller@suse.com
- scripts/dtc: Remove redundant YYLOC global declaration
  (bsc#1160388).
- commit 40e5eca
* Tue May 19 2020 jack@suse.cz
- bdi: Fix up kabi for dev_name addition (bsc#1171844).
- commit 4d83bb4
* Tue May 19 2020 mbenes@suse.cz
- x86/unwind/orc: Fix error handling in __unwind_start()
  (bsc#1058115).
- commit ad0fbff
* Tue May 19 2020 tiwai@suse.de
- platform/x86: ISST: Fix wrong unregister type (bsc#1171810).
- platform/x86: ISST: Allow additional core-power mailbox commands
  (bsc#1171810).
- platform/x86: ISST: Use dev_get_drvdata (bsc#1171810).
- commit 6bfd9ca
* Tue May 19 2020 tiwai@suse.de
- Move two upstreamed IMA patches into sorted section
- commit caf8825
* Tue May 19 2020 glin@suse.com
- bpf: Fix error return code in map_lookup_and_delete_elem()
  (bsc#1155518).
- bpf: Fix sk_psock refcnt leak when receiving message
  (bsc#1155518).
- commit d621e20
* Mon May 18 2020 tonyj@suse.de
- perf/x86/intel/uncore: Add Ice Lake server uncore support
  (jsc#SLE-8898).
- perf/x86/intel/uncore: Factor out __snr_uncore_mmio_init_box
  (jsc#SLE-8898).
- perf/x86/intel/uncore: Add box_offsets for free-running counters
  (jsc#SLE-8898).
- commit 093dafa
* Mon May 18 2020 oneukum@suse.com
- vt: fix unicode console freeing with a common interface
  (git-fixes).
- commit 4d7b8d6
* Mon May 18 2020 msuchanek@suse.de
- s390/kexec_file: fix initrd location for kdump kernel
  (bsc#1166340 ltc#184171).
- commit d2b5550
* Mon May 18 2020 jack@suse.cz
- block: Fix writeback throttling W=1 compiler warnings
  (bsc#1171844).
- blacklist.conf: Remove the commit
- commit 2a895f4
* Mon May 18 2020 jack@suse.cz
- bdi: add a ->dev_name field to struct backing_dev_info
  (bsc#1171844).
- commit 1e675b2
* Mon May 18 2020 jack@suse.cz
- bdi: move bdi_dev_name out of line (bsc#1171844).
- commit 8c98f9b
* Mon May 18 2020 jack@suse.cz
- bdi: use bdi_dev_name() to get device name (bsc#1171844).
- commit 2f2a729
* Mon May 18 2020 jack@suse.cz
- propagate_one(): mnt_set_mountpoint() needs mount_lock
  (bsc#1171843).
- commit d12939e
* Mon May 18 2020 oneukum@suse.com
- vt: don't hardcode the mem allocation upper bound (git-fixes).
- commit cef46bf
* Mon May 18 2020 oneukum@suse.com
- vt: don't use kmalloc() for the unicode screen buffer
  (git-fixes).
- commit 4fd1f99
* Mon May 18 2020 dwagner@suse.de
- rcu: Add *_ONCE() for grace-period progress indicators
  (bsc#1171828).
- rcu: Add READ_ONCE() to rcu_segcblist ->tails (bsc#1171828).
- rcu: Add WRITE_ONCE() to rcu_node ->qsmaskinitnext
  (bsc#1171828).
- rcu: Add WRITE_ONCE() to rcu_state ->gp_req_activity
  (bsc#1171828).
- rcu: Add WRITE_ONCE to rcu_node ->exp_seq_rq store
  (bsc#1171828).
- rcu: Add WRITE_ONCE() to rcu_node ->qsmask update (bsc#1171828).
- rcu: Provide debug symbols and line numbers in KCSAN runs
  (bsc#1171828).
- rcu: Fix exp_funnel_lock()/rcu_exp_wait_wake() datarace
  (bsc#1171828).
- rcu: Use READ_ONCE() for ->expmask in rcu_read_unlock_special()
  (bsc#1171828).
- srcu: Apply *_ONCE() to ->srcu_last_gp_end (bsc#1171828).
- commit a409a59
* Mon May 18 2020 jack@suse.cz
- blacklist.conf: Blacklist c4b4c2a78a9f
- commit 7d1f234
* Mon May 18 2020 jack@suse.cz
- ext4: use non-movable memory for superblock readahead
  (bsc#1171842).
- commit cc13e88
* Mon May 18 2020 jack@suse.cz
- ocfs2: no need try to truncate file beyond i_size (bsc#1171841).
- commit 4ea0462
* Mon May 18 2020 oneukum@suse.com
- USB: uas: add quirk for LaCie 2Big Quadra (git-fixes).
- commit 827d447
* Mon May 18 2020 jack@suse.cz
- io_uring: remove bogus RLIMIT_NOFILE check in file registration
  (bsc#1171840).
- commit 2d64873
* Mon May 18 2020 jack@suse.cz
- io_uring: honor original task RLIMIT_FSIZE (bsc#1171839).
- commit c77337d
* Mon May 18 2020 oneukum@suse.com
- USB: serial: qcserial: Add DW5816e support (git-fixes).
- commit aa6d686
* Mon May 18 2020 rgoldwyn@suse.com
- mm/swapfile.c: move inode_lock out of claim_swapfile (git-fixes, bsc#1171730).
- commit e2fed77
* Mon May 18 2020 oneukum@suse.com
- usb: xhci: Fix NULL pointer dereference when enqueuing trbs
  from urb sg list (git-fixes).
- commit 25bbbc6
* Mon May 18 2020 jack@suse.cz
- blacklist.conf: Blacklist ce623f89872d
- commit 1a198c3
* Mon May 18 2020 jack@suse.cz
- blacklist.conf: Blacklist 02f03c4206c1
- commit 2d8e6ba
* Mon May 18 2020 jack@suse.cz
- ext4: fix a data race at inode->i_blocks (bsc#1171835).
- commit 3a01d10
* Mon May 18 2020 jack@suse.cz
- block, bfq: invoke flush_idle_tree after reparent_active_queues
  in pd_offline (bsc#1171834).
- commit 2f6d8ec
* Mon May 18 2020 jack@suse.cz
- block, bfq: make reparent_leaf_entity actually work only on
  leaf entities (bsc#1171833).
- commit d07ba45
* Mon May 18 2020 jack@suse.cz
- block, bfq: turn put_queue into release_process_ref in
  __bfq_bic_change_cgroup (bsc#1171832).
- commit 8dc34a5
* Mon May 18 2020 msuchanek@suse.de
- libnvdimm/dax: Pick the right alignment default when creating dax
  devices (bsc#1171759).
- powerpc/book3s64: Export has_transparent_hugepage() related
  functions (bsc#1171759).
- Refresh patches.suse/powerpc-hash64-devmap-Use-H_PAGE_THP_HUGE-when-setti.patch.
- commit 01ee8de
* Mon May 18 2020 dwagner@suse.de
- rcu: Remove rcu_swap_protected() (bsc#1171827).
- wireless/mediatek: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1171827).
- fs/afs: Replace rcu_swap_protected() with rcu_replace_pointer()
  (bsc#1171827).
- drivers/scsi: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1171827).
- drm/i915: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1171827).
- x86/kvm/pmu: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1171827).
- mt76: drop rcu read lock in mt76_rx_aggr_stop (bsc#1171827).
- commit a6fb099
* Mon May 18 2020 nsaenzjulienne@suse.de
- blacklist.conf: Append "ARM: dts: bcm283x: Disable dsi0 node"
  It's a device tree change, we don't maintain device trees.
- commit 2f253e6
* Mon May 18 2020 ailiop@suse.com
- blacklist.conf: add 5a57c05b56b6e
- commit a97a544
* Mon May 18 2020 ailiop@suse.com
- blacklist.conf: add 71912e08e06b7
- commit e4cf882
* Mon May 18 2020 nsaenzjulienne@suse.de
- net: broadcom: Select BROADCOM_PHY for BCMGENET (git-fixes).
- commit 45f06fc
* Mon May 18 2020 tbogendoerfer@suse.de
- bpf: Enforce returning 0 for fentry/fexit progs (bsc#1154353).
- bpf: Fix bug in mmap() implementation for BPF array map
  (bsc#1154353).
- ionic: call ionic_port_init after fw-upgrade (bsc#1167773).
- ionic: leave netdev mac alone after fw-upgrade (bsc#1167773).
- RDMA/uverbs: Move IB_EVENT_DEVICE_FATAL to destroy_uobj
  (jsc#SLE-8449).
- RDMA/uverbs: Do not discard the IB_EVENT_DEVICE_FATAL event
  (jsc#SLE-8449).
- ipv6: fix restrict IPV6_ADDRFORM operation (bsc#1171662).
- selftests/bpf: Validate frozen map contents stays frozen
  (bsc#1154353).
- ipv6: restrict IPV6_ADDRFORM operation (bsc#1171662).
- commit b0eba11
* Mon May 18 2020 dwagner@suse.de
- wireguard: send/receive: cond_resched() when processing worker
  ringbuffers (bsc#1169021 jsc#SLE-12250).
- wireguard: socket: remove errant restriction on looping to self
  (bsc#1169021 jsc#SLE-12250).
- wireguard: receive: use tunnel helpers for decapsulating ECN
  markings (bsc#1169021 jsc#SLE-12250).
- wireguard: queueing: cleanup ptr_ring in error path of
  packet_queue_init (bsc#1169021 jsc#SLE-12250).
- commit 3b1c8e3
* Mon May 18 2020 tiwai@suse.de
- clk: rockchip: fix incorrect configuration of rk3228 aclk_gpu*
  clocks (git-fixes).
- clk: Unlink clock if failed to prepare or enable (git-fixes).
- commit 1326aea
* Mon May 18 2020 jslaby@suse.cz
- net: ipv4: really enforce backoff for redirects (git-fixes).
- commit 439f9a6
* Mon May 18 2020 mkubecek@suse.cz
- series.conf: cleanup
- move kabi workaround to the right section:
  patches.kabi/snd-rawmidi-buffer_ref-kABI-workaround.patch
- commit 6394f10
* Mon May 18 2020 tiwai@suse.de
- ima: Set again build_ima_appraise variable (bsc#1171709).
- ima: Remove redundant policy rule set in add_rules()
  (bsc#1171709).
- ima: Fix ima digest hash table key calculation (bsc#1171709).
- ima: Fix return value of ima_write_policy() (bsc#1171709).
- ima: Set file->f_mode instead of file->f_flags in
  ima_calc_file_hash() (bsc#1171709).
- commit 9bfa29c
* Mon May 18 2020 mkubecek@suse.cz
- series.conf: cleanup
  Drop unneeded comment.
- commit c7bd9f9
* Sun May 17 2020 dbueso@suse.de
- ipc/util.c: sysvipc_find_ipc() incorrectly updates position
  index (bsc#1171236).
- kernel/gcov/fs.c: gcov_seq_next() should increase position index
  (bsc#1171236).
- fs/seq_file.c: seq_read(): add info message about buggy .next
  functions (bsc#1171236).
- selinux: sel_avc_get_stat_idx should increase position index
  (bsc#1171236).
- mm/swapfile.c: swap_next should increase position index
  (bsc#1171236).
- commit 02aa5d8
* Sun May 17 2020 tiwai@suse.de
- pinctrl: cherryview: Add missing spinlock usage in
  chv_gpio_irq_handler (git-fixes).
- pinctrl: baytrail: Enable pin configuration setting for GPIO
  chip (git-fixes).
- pinctrl: sunrisepoint: Fix PAD lock register offset for SPT-H
  (git-fixes).
- pinctrl: qcom: fix wrong write in update_dual_edge (git-fixes).
- pinctrl: actions: fix function group name for i2c0_group
  (git-fixes).
- commit 47ce68c
* Sat May 16 2020 lduncan@suse.com
- scsi: sg: add sg_remove_request in sg_common_write
  (bsc#1171790).
- commit 6f665e2
* Sat May 16 2020 lduncan@suse.com
- Blacklist git-fix that uses kABI not present yet in SLE.
  This uses get_unaligned_be24(), which isn't in our kernel yet,
  to clean up debug code, but it does not fix anything.
- commit 0389ede
* Sat May 16 2020 lduncan@suse.com
- scsi: mpt3sas: Fix kernel panic observed on soft HBA unplug
  (bsc#1171783).
- scsi: ufs: Clean up ufshcd_scale_clks() and clock scaling
  error out path (bsc#1171792).
- scsi: aha1740: Fix an errro handling path in aha1740_probe()
  (bsc#1171774).
- scsi: ufs: Fix ufshcd_hold() caused scheduling while atomic
  (bsc#1171795).
- scsi: ufs: fix Auto-Hibern8 error detection (bsc#1171794).
- block/drbd: delete invalid function drbd_md_mark_dirty_
  (bsc#1171773).
- scsi: sd: Fix optimal I/O size for devices that change reported
  values (bsc#1171789).
- scsi: ufs: Fix ufshcd_probe_hba() reture value in case
  ufshcd_scsi_add_wlus() fails (bsc#1171796).
- scsi: csiostor: Adjust indentation in csio_device_reset
  (bsc#1171777).
- scsi: qla4xxx: Adjust indentation in qla4xxx_mem_free
  (bsc#1171784).
- scsi: ufs: Recheck bkops level if bkops is disabled
  (bsc#1171798).
- scsi: fnic: fix invalid stack access (bsc#1171780).
- scsi: sd: Clear sdkp->protection_type if disk is reformatted
  without PI (bsc#1171787).
- scsi: iscsi: Fix a potential deadlock in the timeout handler
  (bsc#1171781).
- scsi: ufs: Disable autohibern8 feature in Cadence UFS
  (bsc#1171793).
- scsi: iscsi: qla4xxx: fix double free in probe (bsc#1171782).
- scsi: ufs: Give an unique ID to each ufs-bsg (bsc#1171797).
- scsi: scsi_transport_sas: Fix memory leak when removing devices
  (bsc#1171786).
- scsi: bnx2i: fix potential use after free (bsc#1171775).
- scsi: qla4xxx: fix double free bug (bsc#1171785).
- scsi: zorro_esp: Limit DMA transfers to 65536 bytes (except
  on Fastlane) (bsc#1171799).
- scsi: tracing: Fix handling of TRANSFER LENGTH == 0 for READ(6)
  and WRITE(6) (bsc#1171791).
- scsi: core: scsi_trace: Use get_unaligned_be*() (bsc#1171776).
- scsi: esas2r: unlock on error in esas2r_nvram_read_direct()
  (bsc#1171779).
- scsi: csiostor: Don't enable IRQs too early (bsc#1171778).
- scsi: sd: enable compat ioctls for sed-opal (bsc#1171788).
- commit f218358
* Sat May 16 2020 tiwai@suse.de
- umh: fix memory leak on execve failure (git-fixes).
- r8169: re-establish support for RTL8401 chip version
  (git-fixes).
- hwmon: (da9052) Synchronize access with mfd (git-fixes).
- commit c93a77b
* Sat May 16 2020 tiwai@suse.de
- kABI workaround for snd_rawmidi buffer_ref field addition
  (git-fixes).
- commit a26b757
* Sat May 16 2020 tiwai@suse.de
- ALSA: hda/realtek - Limit int mic boost for Thinkpad T530
  (git-fixes bsc#1171293).
- ALSA: hda/realtek - Add COEF workaround for ASUS ZenBook UX431DA
  (git-fixes).
- ALSA: hda/realtek: Enable headset mic of ASUS UX581LV with
  ALC295 (git-fixes).
- ALSA: hda/realtek - Enable headset mic of ASUS UX550GE with
  ALC295 (git-fixes).
- ALSA: hda/realtek - Enable headset mic of ASUS GL503VM with
  ALC295 (git-fixes).
- ALSA: hda/realtek: Add quirk for Samsung Notebook (git-fixes).
- ALSA: rawmidi: Fix racy buffer resize under concurrent accesses
  (git-fixes).
- ALSA: usb-audio: add mapping for ASRock TRX40 Creator
  (git-fixes).
- ALSA: hda/realtek - Fix S3 pop noise on Dell Wyse (git-fixes).
- Revert "ALSA: hda/realtek: Fix pop noise on ALC225" (git-fixes).
- ALSA: firewire-lib: fix 'function sizeof not defined' error
  of tracepoints format (git-fixes).
- ALSA: usb-audio: Add control message quirk delay for Kingston
  HyperX headset (git-fixes).
- commit 1c282f0
* Fri May 15 2020 ptesarik@suse.cz
- s390/qeth: refactor buffer pool code (git-fixes).
- s390/qeth: use page pointers to manage RX buffer pool
  (git-fixes).
- commit 78b8e17
* Fri May 15 2020 ptesarik@suse.cz
- s390/qdio: fill SBALEs with absolute addresses (git-fixes).
- commit 3a84ac3
* Fri May 15 2020 ptesarik@suse.cz
- blacklist.conf: Add unimportant S390 fixes.
- commit da76ba0
* Fri May 15 2020 ptesarik@suse.cz
- s390: Keep kABI after adding fields to struct lowcore
  (git-fixes).
- s390: prevent leaking kernel address in BEAR (git-fixes).
- commit 2432c42
* Fri May 15 2020 ptesarik@suse.cz
- Update upstream references and move to sorted section:
  patches.suse/s390-mm-fix-page-table-upgrade-vs-2ndary-address-mode
- commit 5b70b1c
* Fri May 15 2020 ptesarik@suse.cz
- s390/protvirt: fix compilation issue (git-fixes).
- s390/pci: do not set affinity for floating irqs (git-fixes).
- KVM: s390: Fix PV check in deliverable_irqs() (git-fixes).
- s390/cio: generate delayed uevent for vfio-ccw subchannels
  (git-fixes).
- s390/cio: avoid duplicated 'ADD' uevents (git-fixes).
- KVM: s390: vsie: Fix possible race when shadowing region 3
  tables (git-fixes).
- KVM: s390: vsie: Fix region 1 ASCE sanity shadow address checks
  (git-fixes).
- s390/diag: fix display of diagnose call statistics (git-fixes).
- s390/cpuinfo: fix wrong output when CPU0 is offline (git-fixes).
- scsi: zfcp: fix missing erp_lock in port recovery trigger for
  point-to-point (git-fixes).
- s390/gmap: return proper error code on ksm unsharing
  (git-fixes).
- s390/qeth: support net namespaces for L3 devices (git-fixes).
- s390/qeth: implement smarter resizing of the RX buffer pool
  (git-fixes).
- s390/qeth: cancel RX reclaim work earlier (git-fixes).
- s390/qeth: handle error when backing RX buffer (git-fixes).
- s390/qeth: don't reset default_out_queue (git-fixes).
- s390/qeth: fix off-by-one in RX copybreak check (git-fixes).
- s390/qeth: don't warn for napi with 0 budget (git-fixes).
- s390/qeth: vnicc Fix EOPNOTSUPP precedence (git-fixes).
- commit f4042da
* Fri May 15 2020 ptesarik@suse.cz
- s390/uv: Fix handling of length extensions (git-fixes).
- Refresh
  patches.suse/0008-s390-protvirt-introduce-host-side-setup.
- commit b147e1a
* Fri May 15 2020 ptesarik@suse.cz
- s390/qeth: consolidate QDIO queue setup (git-fixes).
- s390/startup: round down "mem" option to page boundary
  (git-fixes).
- commit 1751aa6
* Fri May 15 2020 ptesarik@suse.cz
- s390/cpum_cf: Add new extended counters for IBM z15 (bsc#1169763
  LTC#185290).
- commit 7b5f7a7
* Fri May 15 2020 ptesarik@suse.cz
- s390/ftrace: fix potential crashes when switching tracers
  (bsc#1171242 LTC#185786).
- commit 4872847
* Fri May 15 2020 hare@suse.de
- fnic: to not call 'scsi_done()' for unhandled commands
  (bsc#1168468, bsc#1171675).
- commit ab83c6a
* Fri May 15 2020 tiwai@suse.de
- ima: Use ima_hash_algo for collision detection in the
  measurement list (bsc#1171709).
- ima: Calculate and extend PCR with digests in ima_template_entry
  (bsc#1171709).
- ima: Allocate and initialize tfm for each PCR bank
  (bsc#1171709).
- ima: Switch to dynamically allocated buffer for template digests
  (bsc#1171709).
- ima: Store template digest directly in ima_template_entry
  (bsc#1171709).
- ima: Evaluate error in init_ima() (bsc#1171709).
- ima: Switch to ima_hash_algo for boot aggregate (bsc#1171709).
- commit b14498d
* Fri May 15 2020 tiwai@suse.de
- mmc: sdhci-acpi: Add SDHCI_QUIRK2_BROKEN_64_BIT_DMA for AMDI0040
  (git-fixes).
- mmc: block: Fix request completion in the CQE timeout path
  (git-fixes).
- mmc: core: Fix recursive locking issue in CQE recovery path
  (git-fixes).
- mmc: core: Check request type before completing the request
  (git-fixes).
- mmc: sdhci-pci-gli: Fix can not access GL9750 after reboot
  from Windows 10 (git-fixes).
- mmc: alcor: Fix a resource leak in the error path for ->probe()
  (git-fixes).
- mmc: sdhci-pci-gli: Fix no irq handler from suspend (git-fixes).
- HID: wacom: Report 2nd-gen Intuos Pro S center button status
  over BT (git-fixes).
- commit c8b265a
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Move allocation of the shost object to after xconf-
  and xport-data (bsc#1158050).
- commit 21f0bbc
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Fence early sysfs interfaces for accesses of shost
  objects (bsc#1158050).
- commit 14fe477
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Fence adapter status propagation for common statuses
  (bsc#1158050).
- commit 2239fe3
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Move p-t-p port allocation to after xport data
  (bsc#1158050).
- commit 6523a4a
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Fence fc_host updates during link-down handling
  (bsc#1158050).
- commit e19869e
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Move fc_host updates during xport data handling
  into fenced function (bsc#1158050).
- commit ed1083e
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Move shost updates during xconfig data handling
  into fenced function (bsc#1158050).
- commit 2b1bff7
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Move shost modification after QDIO (re-)open into
  fenced function (bsc#1158050).
- commit 125f4c2
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: log FC Endpoint Security errors (bsc#1158050).
- commit 917028c
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: enhance handling of FC Endpoint Security errors
  (bsc#1158050).
- commit 36c135f
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: trace FC Endpoint Security of FCP devices and
  connections (bsc#1158050).
- commit 7e76f52
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: log FC Endpoint Security of connections
  (bsc#1158050).
- commit c39b6cd
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: report FC Endpoint Security in sysfs (bsc#1158050).
- commit f23d4ba
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: auto variables for dereferenced structs in open
  port handler (bsc#1158050).
- commit 59d992b
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: fix fc_host attributes that should be unknown on
  local link down (bsc#1158050).
- commit eeef336
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: wire previously driver-specific sysfs attributes
  also to fc_host (bsc#1158050).
- commit 6bad869
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: expose fabric name as common fc_host sysfs attribute
  (bsc#1158050).
- commit ea0cf94
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: fix wrong data and display format of SFP+
  temperature (bsc#1158050).
- commit 90e31fe
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: proper indentation to reduce confusion in
  zfcp_erp_required_act (bsc#1158050).
- commit 4e35fda
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: move maximum age of diagnostic buffers into a
  per-adapter variable (bsc#1158050).
- commit be264de
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: implicitly refresh config-data diagnostics when
  reading sysfs (bsc#1158050).
- commit 20412aa
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: introduce sysfs interface to read the local
  B2B-Credit (bsc#1158050).
- commit 843431c
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: implicitly refresh port-data diagnostics when
  reading sysfs (bsc#1158050).
- commit 161aea6
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: introduce sysfs interface for diagnostics of local
  SFP transceiver (bsc#1158050).
- commit a779192
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: support retrieval of SFP Data via Exchange Port Data
  (bsc#1158050).
- commit 5dc40b1
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: add diagnostics buffer for exchange config data
  (bsc#1158050).
- commit 57cb8ce
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: diagnostics buffer caching and use for exchange
  port data (bsc#1158050).
- commit dd2087b
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: signal incomplete or error for sync exchange
  config/port data (bsc#1158050).
- commit c1722d3
* Thu May 14 2020 jack@suse.cz
- ext4: do not zeroout extents beyond i_disksize (bsc#1167851).
- commit af137fd
* Thu May 14 2020 bp@suse.de
- x86/smpboot: Remove the last ICPU() macro (bsc#1171644).
- commit 363d04a
* Thu May 14 2020 lhenriques@suse.com
- ceph: demote quotarealm lookup warning to a debug message
  (jsc#SES-1134).
- ceph: fix double unlock in handle_cap_export() (jsc#SES-1134).
- ceph: fix special error code in ceph_try_get_caps()
  (jsc#SES-1134).
- ceph: fix endianness bug when handling MDS session feature bits
  (jsc#SES-1134).
- commit f1fae63
* Thu May 14 2020 bp@suse.de
- ACPI: Convert to new X86 CPU match macros (bsc#1171644).
- ASoC: Intel: Convert to new X86 CPU match macros (bsc#1171644).
- cpufreq: Convert to new X86 CPU match macros (bsc#1171644).
- cpufreq/intel_pstate: Fix wrong macro conversion (bsc#1171644).
- crypto: Convert to new CPU match macros (bsc#1171644).
- EDAC: Convert to new X86 CPU match macros (bsc#1171644).
- extcon: axp288: Convert to new X86 CPU match macros
  (bsc#1171644).
- hwmon: Convert to new X86 CPU match macros (bsc#1171644).
- hwrng: via_rng: Convert to new X86 CPU match macros
  (bsc#1171644).
- intel_idle: Convert to new X86 CPU match macros (bsc#1171644).
- mmc: sdhci-acpi: Convert to new X86 CPU match macros
  (bsc#1171644).
- PCI: intel-mid: Convert to new X86 CPU match macros
  (bsc#1171644).
- platform/x86: Convert to new CPU match macros (bsc#1171644).
- powercap/intel_rapl: Convert to new X86 CPU match macros
  (bsc#1171644).
- thermal: Convert to new X86 CPU match macros (bsc#1171644).
- x86/cpu/bugs: Convert to new matching macros (bsc#1171644).
- x86/cpu: Cleanup the now unused CPU match macros (bsc#1171644).
- x86/intel: Aggregate big core client naming (bsc#1171644).
- x86/intel: Aggregate big core graphics naming (bsc#1171644).
- x86/intel: Aggregate big core mobile naming (bsc#1171644).
- x86/intel: Aggregate microserver naming (bsc#1171644).
- x86/kernel: Convert to new CPU match macros (bsc#1171644).
- x86/kvm: Convert to new CPU match macros (bsc#1171644).
- x86/perf/events: Convert to new CPU match macros (bsc#1171644).
- x86/platform: Convert to new CPU match macros (bsc#1171644).
- Refresh
  patches.suse/edac-i10nm-update-driver-to-support-different-bus-number-config-register-offsets.patch.
- Refresh
  patches.suse/edac-skx-i10nm-make-some-configurations-cpu-model-specific.patch.
- Refresh
  patches.suse/perf-x86-cstate-add-comet-lake-cpu-support.patch.
- Refresh
  patches.suse/perf-x86-cstate-update-c-state-counters-for-ice-lake.patch.
- Refresh
  patches.suse/perf-x86-intel-add-comet-lake-cpu-support.patch.
- Refresh
  patches.suse/perf-x86-msr-add-comet-lake-cpu-support.patch.
- Refresh
  patches.suse/platform-x86-intel_pmc_core-Add-Comet-Lake-CML-platf.patch.
- Refresh
  patches.suse/platform-x86-intel_pmc_core-update-Comet-Lake-platfo.patch.
- Refresh
  patches.suse/powercap-intel_rapl-add-support-for-CometLake-Mobile.
- Refresh
  patches.suse/powercap-intel_rapl-add-support-for-Cometlake-desktop.
- Refresh
  patches.suse/powercap-intel_rapl-add-support-for-TigerLake-Mobile.patch.
- Refresh
  patches.suse/x86-bugs-Add-ITLB_MULTIHIT-bug-infrastructure.patch.
- Refresh
  patches.suse/x86-cpu-Add-Tiger-Lake-to-Intel-family.patch.
- Refresh
  patches.suse/x86-cpu-Add-Tremont-to-the-cpu-vulnerability-whiteli.patch.
- Refresh
  patches.suse/x86-cpu-add-a-steppings-field-to-struct-x86_cpu_id.patch.
- Refresh
  patches.suse/x86-sched-Add-support-for-frequency-invariance.patch.
- commit 424d9a3
* Thu May 14 2020 jroedel@suse.de
- Update
  patches.suse/pci-aer-add-pci_aer_raw_clear_status-to-unconditionally-clear-error-status
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update
  patches.suse/pci-aer-rationalize-error-status-register-clearing
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update
  patches.suse/pci-dpc-add-error-disconnect-recover-edr-support
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update
  patches.suse/pci-dpc-cache-dpc-capabilities-in-pci_init_capabilities
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update
  patches.suse/pci-dpc-expose-dpc_process_error-dpc_reset_link-for-use-by-edr
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update patches.suse/pci-dpc-move-dpc-data-into-struct-pci_dev
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update
  patches.suse/pci-err-remove-service-dependency-in-pcie_do_recovery
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update patches.suse/pci-err-return-status-of-pcie_do_recovery
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- commit dbc15d0
* Thu May 14 2020 ykaukab@suse.de
- efi: READ_ONCE rng seed size before munmap (jsc#SLE-12424).
- efi/random: Treat EFI_RNG_PROTOCOL output as bootloader randomness (jsc#SLE-12424).
- char/random: Add a newline at the end of the file (jsc#SLE-12424).
- fdt: add support for rng-seed (jsc#SLE-12424).
- arm64: map FDT as RW for early_init_dt_scan() (jsc#SLE-12424).
- commit 14ee05c
* Thu May 14 2020 msuchanek@suse.de
- rpm/check-for-config-changes: Ignore CONFIG_CC_VERSION_TEXT
- commit 8e6b05f
* Wed May 13 2020 mkubecek@suse.cz
- Update kabi files.
- update to "Snapshot 16" submission (commit 2c1dc3e59ade)
- commit 5277b75
* Wed May 13 2020 jack@suse.cz
- fanotify: merge duplicate events on parent and child
  (bsc#1171285).
- commit 31ead62
* Wed May 13 2020 mbenes@suse.cz
- blacklist.conf: 81b67439d147 ("x86/unwind/orc: Fix premature unwind stoppage due to IRET frames")
  Breaks kABI. SLE15-SP3 is the target.
- commit 9871f13
* Wed May 13 2020 mkubecek@suse.cz
- series.conf: whitespace cleanup
  No functional change.
- commit 2c1dc3e
* Wed May 13 2020 mbenes@suse.cz
- x86/unwind/orc: Fix error path for bad ORC entry type
  (bsc#1058115).
- commit 031383f
* Wed May 13 2020 mbenes@suse.cz
- x86/unwind/orc: Prevent unwinding before ORC initialization
  (bsc#1058115).
- commit d558feb
* Wed May 13 2020 mbenes@suse.cz
- x86/unwind/orc: Don't skip the first frame for inactive tasks
  (bsc#1058115).
- commit aa72d5b
* Wed May 13 2020 mbenes@suse.cz
- x86/unwind: Prevent false warnings for non-current tasks
  (bsc#1058115).
- commit 00ea671
* Wed May 13 2020 tbogendoerfer@suse.de
- Dropped jsc#PM and jsc#ECO references.
- Update
  patches.suse/Doc-networking-device_drivers-pensando-fix-ionic.rst.patch
  (bsc#1167773).
- Update
  patches.suse/Documentation-networking-device-drivers-Remove-stray.patch
  (bsc#1167773).
- Update
  patches.suse/dynamic_debug-provide-dynamic_hex_dump-stub.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-RSS-support.patch (bsc#1167773).
- Update
  patches.suse/ionic-Add-Rx-filter-and-rx_mode-ndo-support.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-Tx-and-Rx-handling.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-adminq-action.patch (bsc#1167773).
- Update
  patches.suse/ionic-Add-async-link-status-check-and-basic-stats.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-basic-adminq-support.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-Add-basic-framework-for-IONIC-Network-device-d.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-basic-lif-support.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-coalesce-and-other-features.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-driver-stats.patch (bsc#1167773).
- Update
  patches.suse/ionic-Add-hardware-init-and-device-commands.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-initial-ethtool-support.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-interrupts-and-doorbells.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-management-of-rx-filters.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-netdev-event-handling.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-notifyq-support.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-port-management-commands.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-Add-the-basic-NDO-callbacks-for-netdev-support.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-Fix-an-error-code-in-ionic_lif_alloc.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-Remove-set-but-not-used-variable-sg_desc.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-Remove-unnecessary-ternary-operator-in-ionic_d.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-Remove-unused-including-linux-version.h.patch
  (bsc#1167773).
- Update patches.suse/ionic-add-Rx-dropped-packet-counter.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-add-a-watchdog-timer-to-monitor-heartbeat.patch
  (bsc#1167773).
- Update patches.suse/ionic-add-decode-for-IONIC_RC_ENOSUPP.patch
  (bsc#1167773).
- Update patches.suse/ionic-add-dynamic_debug-header.patch
  (bsc#1167773).
- Update patches.suse/ionic-add-heartbeat-check.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-add-lif_quiesce-to-wait-for-queue-activity-to-.patch
  (bsc#1167773).
- Update patches.suse/ionic-add-support-for-device-id-0x1004.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-add-timeout-error-checking-for-queue-disable.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-check-for-NULL-structs-on-teardown.patch
  (bsc#1167773).
- Update patches.suse/ionic-check-for-linkup-in-watchdog.patch
  (bsc#1167773).
- Update patches.suse/ionic-check-for-queues-before-deleting.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-clean-irq-affinity-on-queue-deinit.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-clean-tx-queue-of-unfinished-requests.patch
  (bsc#1167773).
- Update patches.suse/ionic-clean-up-bitflag-usage.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-clear-compiler-warning-on-hb-use-before-set.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-decouple-link-message-from-netdev-state.patch
  (bsc#1167773).
- Update patches.suse/ionic-deinit-rss-only-if-selected.patch
  (bsc#1167773).
- Update patches.suse/ionic-disable-the-queues-on-link-down.patch
  (bsc#1167773).
- Update patches.suse/ionic-drop-use-of-subdevice-tags.patch
  (bsc#1167773).
- Update patches.suse/ionic-fix-fw_status-read.patch
  (bsc#1167773).
- Update patches.suse/ionic-fix-rxq-comp-packet-type-mask.patch
  (bsc#1167773).
- Update patches.suse/ionic-fix-stats-memory-dereference.patch
  (bsc#1167773).
- Update patches.suse/ionic-fix-unused-assignment.patch
  (bsc#1167773).
- Update patches.suse/ionic-fix-up-struct-name-comments.patch
  (bsc#1167773).
- Update patches.suse/ionic-fix-vf-op-lock-usage.patch
  (bsc#1167773).
- Update patches.suse/ionic-ignore-eexist-on-rx-filter-add.patch
  (bsc#1167773).
- Update patches.suse/ionic-implement-ethtool-set-fec.patch
  (bsc#1167773).
- Update patches.suse/ionic-implement-support-for-rx-sgl.patch
  (bsc#1167773).
- Update patches.suse/ionic-improve-irq-numa-locality.patch
  (bsc#1167773).
- Update patches.suse/ionic-ionic_if-bits-for-sr-iov-support.patch
  (bsc#1167773).
- Update patches.suse/ionic-keep-ionic-dev-on-lif-init-fail.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-keep-users-rss-hash-across-lif-reset.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-leave-dev-cmd-request-contents-alone-on-FW-tim.patch
  (bsc#1167773).
- Update patches.suse/ionic-make-spdxcheck.py-happy.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-move-debugfs-add-delete-to-match-alloc-free.patch
  (bsc#1167773).
- Update patches.suse/ionic-move-irq-request-to-qcq-alloc.patch
  (bsc#1167773).
- Update patches.suse/ionic-only-save-good-lif-dentry.patch
  (bsc#1167773).
- Update patches.suse/ionic-print-data-for-unknown-xcvr-type.patch
  (bsc#1167773).
- Update patches.suse/ionic-print-pci-bus-lane-info.patch
  (bsc#1167773).
- Update patches.suse/ionic-remove-adminq-napi-instance.patch
  (bsc#1167773).
- Update patches.suse/ionic-remove-lifs-on-fw-reset.patch
  (bsc#1167773).
- Update patches.suse/ionic-remove-pragma-packed.patch
  (bsc#1167773).
- Update patches.suse/ionic-replay-filters-after-fw-upgrade.patch
  (bsc#1167773).
- Update patches.suse/ionic-report-users-coalesce-request.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-restrict-received-packets-to-mtu-size.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-reverse-an-interrupt-coalesce-calculation.patch
  (bsc#1167773).
- Update patches.suse/ionic-select-CONFIG_NET_DEVLINK.patch
  (bsc#1167773).
- Update patches.suse/ionic-set-station-addr-only-if-needed.patch
  (bsc#1167773).
- Update patches.suse/ionic-simplify-returns-in-devlink-info.patch
  (bsc#1167773).
- Update patches.suse/ionic-stop-devlink-warn-on-mgmt-device.patch
  (bsc#1167773).
- Update patches.suse/ionic-support-ethtool-rxhash-disable.patch
  (bsc#1167773).
- Update patches.suse/ionic-support-sr-iov-operations.patch
  (bsc#1167773).
- Update patches.suse/ionic-update-driver-version.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-use-wait_on_bit_lock-rather-than-open-code.patch
  (bsc#1167773).
- Update
  patches.suse/net-ionic-Use-scnprintf-for-avoiding-potential-buffe.patch
  (bsc#1167773).
- commit cd1780f
* Wed May 13 2020 mkubecek@suse.cz
- update metadata of nvme patches and move them out from sorted section
  The nvme-5.8 branch in nvme repository got rebased fourth time in three
  weeks. Update Git-commit tags again and move the patches out of sorted
  section as keeping them there makes more harm than good.
- update upstream reference and move to "almost mainline" section:
  patches.suse/lpfc-Commonize-lpfc_async_xchg_ctx-state-and-flag-de.patch
  patches.suse/lpfc-Refactor-NVME-LS-receive-handling.patch
  patches.suse/lpfc-Refactor-Send-LS-Abort-support.patch
  patches.suse/lpfc-Refactor-Send-LS-Request-support.patch
  patches.suse/lpfc-Refactor-Send-LS-Response-support.patch
  patches.suse/lpfc-Refactor-lpfc-nvme-headers.patch
  patches.suse/lpfc-Refactor-nvmet_rcv_ctx-to-create-lpfc_async_xch.patch
  patches.suse/lpfc-nvme-Add-Receive-LS-Request-and-Send-LS-Respons.patch
  patches.suse/lpfc-nvmet-Add-Send-LS-Request-and-Abort-LS-Request-.patch
  patches.suse/lpfc-nvmet-Add-support-for-NVME-LS-request-hosthandl.patch
  patches.suse/nvme-fc-Add-Disconnect-Association-Rcv-support.patch
  patches.suse/nvme-fc-Ensure-private-pointers-are-NULL-if-no-data.patch
  patches.suse/nvme-fc-Sync-header-to-FC-NVME-2-rev-1.08.patch
  patches.suse/nvme-fc-Update-header-and-host-for-common-definition.patch
  patches.suse/nvme-fc-and-nvmet-fc-revise-LLDD-api-for-LS-receptio.patch
  patches.suse/nvme-fc-convert-assoc_active-flag-to-bit-op.patch
  patches.suse/nvme-fc-nvmet-fc-refactor-for-common-LS-definitions.patch
  patches.suse/nvme-fcloop-add-target-to-host-LS-request-support.patch
  patches.suse/nvme-fcloop-refactor-to-enable-target-to-host-LS.patch
  patches.suse/nvmet-fc-Add-Disconnect-Association-Xmt-support.patch
  patches.suse/nvmet-fc-Better-size-LS-buffers.patch
  patches.suse/nvmet-fc-Update-target-for-common-definitions-for-LS.patch
  patches.suse/nvmet-fc-add-LS-failure-messages.patch
  patches.suse/nvmet-fc-perform-small-cleanups-on-unneeded-checks.patch
  patches.suse/nvmet-fc-rename-ls_list-to-ls_rcv_list.patch
  patches.suse/nvmet-fc-track-hostport-handle-for-associations.patch
- commit 63b19d5
* Tue May 12 2020 ohering@suse.de
- Fix hv_alloc_hyperv_zeroed_page to actually return something (bsc#1171507)
  Refresh patches.suse/suse-hv-kabi.patch.
- commit 2870dc6
* Tue May 12 2020 oneukum@suse.com
- iwlwifi: mvm: fix non-ACPI function (git-fixes).
- commit 676dedd
* Tue May 12 2020 mkoutny@suse.com
- mm: don't prepare anon_vma if vma has VM_WIPEONFORK
  (bsc#1169681).
- Delete
  patches.suse/0002-mm-set-vm_next-and-vm_prev-to-NULL-in-vm_area_dup.patch.
  The added patch is a proactive git-fix, the removed patch is unnecessary
  member of the same series (bsc#1169681).
- commit a316e23
* Tue May 12 2020 mbenes@suse.cz
- x86/entry/64: Fix unwind hints in rewind_stack_do_exit()
  (bsc#1058115).
- commit 3901d59
* Tue May 12 2020 oneukum@suse.com
- pinctrl: denverton: Update pin names according to v1.08
  (bsc#1171514).
- commit 2f0f43d
* Tue May 12 2020 oneukum@suse.com
- pinctrl: denverton: Provide Interrupt Status register offset
  (bsc#1171514).
- commit 60af7d7
* Tue May 12 2020 mbenes@suse.cz
- x86/entry/64: Fix unwind hints in __switch_to_asm()
  (bsc#1058115).
- commit 9d0fdcf
* Tue May 12 2020 mbenes@suse.cz
- x86/entry/64: Fix unwind hints in kernel exit path
  (bsc#1058115).
- commit 5322f7b
* Tue May 12 2020 mbenes@suse.cz
- x86/entry/64: Fix unwind hints in register clearing code
  (bsc#1058115).
- commit 74bcafb
* Tue May 12 2020 mbenes@suse.cz
- objtool: Fix stack offset tracking for indirect CFAs
  (bsc#1169514).
- commit bcaa294
* Tue May 12 2020 jslaby@suse.cz
- blacklist.conf: add one net entry
- commit 8a6918a
* Tue May 12 2020 jslaby@suse.cz
- net: macb: Fix runtime PM refcounting (git-fixes).
- selftests: Fix suppress test in fib_tests.sh (git-fixes).
- commit b936936
* Tue May 12 2020 tbogendoerfer@suse.de
- Refresh
  patches.suse/net-mlx5-Remove-redundant-NULL-initializations.patch.
  Folded in merge commit 95e6ba5133163f8241c9ea2439369cec0452fec6 from Linus:
  [ Did an evil merge to silence a warning introduced by this pull - Linus ]
- commit 6693a9f
* Tue May 12 2020 tbogendoerfer@suse.de
- cxgb4: fix EOTID leak when disabling TC-MQPRIO offload
  (jsc#SLE-8389).
- ionic: refresh devinfo after fw-upgrade (bsc#1167773).
- ionic: no link check until after probe (bsc#1167773).
- net/mlx5e: Fix q counters on uplink representors (jsc#SLE-8464).
- net/mlx5: DR, On creation set CQ's arm_db member to right value
  (jsc#SLE-8464).
- net/mlx5: Expose port speed when possible (bsc#1171117).
- net/mlx5: Expose link speed directly (bsc#1171117).
- commit 0b73846
* Tue May 12 2020 mbenes@suse.cz
- tracing/kprobes: Fix a double initialization typo (git-fixes).
- commit 84310a8
* Tue May 12 2020 mbenes@suse.cz
- tracing: Add a vmalloc_sync_mappings() for safe measure
  (git-fixes).
- commit 2019d7b
* Tue May 12 2020 ohering@suse.de
- clocksource/drivers/hyper-v: Set TSC clocksource as default w/
  InvariantTSC (bsc#1170621).
- x86/hyperv: Allow guests to enable InvariantTSC (bsc#1170621).
- commit 16f337f
* Mon May 11 2020 dbueso@suse.de
- ipc/mqueue.c: change __do_notify() to bypass
  check_kill_permission() (bsc#1159886).
- vdso/datapage: Use correct clock mode name in comment
  (bsc#1164648,jsc#SLE-11493).
- time/namespace: Fix time_for_children symlink
  (bsc#1164648,jsc#SLE-11493).
- ipc/util.c: sysvipc_find_ipc() should increase position index
  (bsc#1171236).
- ipc/shm.c: make compat_ksys_shmctl() static (bsc#1159886).
- ipc/mqueue.c: fix a brace coding style issue (bsc#1159886).
- epoll: fix possible lost wakeup on epoll_ctl() path.
- commit dbaec66
* Mon May 11 2020 tiwai@suse.de
- usb: dwc3: gadget: Properly set maxpacket limit (git-fixes).
- wimax/i2400m: Fix potential urb refcnt leak (git-fixes).
- drm/amdgpu: Correctly initialize thermal controller for GPUs
  with Powerplay table v0 (e.g Hawaii) (git-fixes).
- remoteproc: qcom_q6v5_mss: fix a bug in q6v5_probe()
  (git-fixes).
- drm/amdgpu: Fix oops when pp_funcs is unset in ACPI event
  (git-fixes).
- mac80211: add ieee80211_is_any_nullfunc() (git-fixes).
- platform/x86: GPD pocket fan: Fix error message when temp-limits
  are out of range (git-fixes).
- PM / devfreq: Add missing locking while setting suspend_freq
  (git-fixes).
- remoteproc: Fix wrong rvring index computation (git-fixes).
- commit 4da097b
* Mon May 11 2020 jroedel@suse.de
- PCI/DPC: Add Error Disconnect Recover (EDR) support
  (bsc#1169263).
- Update config files.
- Refresh patches.suse/0001-kABI-more-hooks-for-PCI-changes.patch.
- commit dc2f3a4
* Mon May 11 2020 mfleming@suse.de
- x86/asm/64: Align start of __clear_user() loop to 16-bytes
  (bsc#1168461)
- commit 1bafa6b
* Mon May 11 2020 jroedel@suse.de
- kABI: Fix kABI after EDR backport (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- commit 3c954c1
* Mon May 11 2020 oneukum@suse.com
- xhci: Fix handling halted endpoint even if endpoint ring
  appears empty (git-fixes).
- Refresh
  patches.suse/xhci-Don-t-clear-hub-TT-buffer-on-ep0-protocol-stall.patch.
- commit 6ca613f
* Mon May 11 2020 jslaby@suse.cz
- net: dsa: bcm_sf2: Ensure correct sub-node is parsed
  (networking-stable-20_04_09).
- mlxsw: spectrum_flower: Do not stop at FLOW_ACTION_VLAN_MANGLE
  (networking-stable-20_04_09).
- net: dsa: bcm_sf2: Do not register slave MDIO bus with OF
  (networking-stable-20_04_09).
- net_sched: fix a missing refcnt in tcindex_init()
  (networking-stable-20_04_09).
- net: stmmac: dwmac1000: fix out-of-bounds mac address reg
  setting (networking-stable-20_04_09).
- cxgb4: fix MPS index overwrite when setting MAC address
  (networking-stable-20_04_09).
- ipv6: don't auto-add link-local address to lag ports
  (networking-stable-20_04_09).
- net_sched: add a temporary refcnt for struct tcindex_data
  (networking-stable-20_04_09).
- commit 964e915
* Mon May 11 2020 ykaukab@suse.de
- clk: qoriq: add cpufreq platform device (bsc#1165455).
- cpufreq: qoriq: convert to a platform driver (bsc#1165455).
- commit e0e9680
* Mon May 11 2020 msuchanek@suse.de
- asm-generic/tlb: add missing CONFIG symbol (bsc#1156395).
- commit ee4dbba
* Mon May 11 2020 mkubecek@suse.cz
- supported.conf: cleanup
- fix path of wireguard module
- fix sort order
- commit 5ca7d5d
* Mon May 11 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/scsi-ibmvfc-Don-t-send-implicit-logouts-prior-to-NPI.patch
  patches.suse/scsi-ibmvscsi-Fix-WARN_ON-during-event-pool-release.patch
- commit 7f02596
* Mon May 11 2020 mkubecek@suse.cz
- update metadata of nvme patches
  The nvme-5.8 branch in nvme repository got rebased again, update Git-commit
  tags:
  patches.suse/lpfc-Commonize-lpfc_async_xchg_ctx-state-and-flag-de.patch
  patches.suse/lpfc-Refactor-NVME-LS-receive-handling.patch
  patches.suse/lpfc-Refactor-Send-LS-Abort-support.patch
  patches.suse/lpfc-Refactor-Send-LS-Request-support.patch
  patches.suse/lpfc-Refactor-Send-LS-Response-support.patch
  patches.suse/lpfc-Refactor-lpfc-nvme-headers.patch
  patches.suse/lpfc-Refactor-nvmet_rcv_ctx-to-create-lpfc_async_xch.patch
  patches.suse/lpfc-nvme-Add-Receive-LS-Request-and-Send-LS-Respons.patch
  patches.suse/lpfc-nvmet-Add-Send-LS-Request-and-Abort-LS-Request-.patch
  patches.suse/lpfc-nvmet-Add-support-for-NVME-LS-request-hosthandl.patch
  patches.suse/nvme-fc-Add-Disconnect-Association-Rcv-support.patch
  patches.suse/nvme-fc-Ensure-private-pointers-are-NULL-if-no-data.patch
  patches.suse/nvme-fc-Sync-header-to-FC-NVME-2-rev-1.08.patch
  patches.suse/nvme-fc-Update-header-and-host-for-common-definition.patch
  patches.suse/nvme-fc-and-nvmet-fc-revise-LLDD-api-for-LS-receptio.patch
  patches.suse/nvme-fc-convert-assoc_active-flag-to-bit-op.patch
  patches.suse/nvme-fc-nvmet-fc-refactor-for-common-LS-definitions.patch
  patches.suse/nvme-fcloop-add-target-to-host-LS-request-support.patch
  patches.suse/nvme-fcloop-refactor-to-enable-target-to-host-LS.patch
  patches.suse/nvmet-fc-Add-Disconnect-Association-Xmt-support.patch
  patches.suse/nvmet-fc-Better-size-LS-buffers.patch
  patches.suse/nvmet-fc-Update-target-for-common-definitions-for-LS.patch
  patches.suse/nvmet-fc-add-LS-failure-messages.patch
  patches.suse/nvmet-fc-perform-small-cleanups-on-unneeded-checks.patch
  patches.suse/nvmet-fc-rename-ls_list-to-ls_rcv_list.patch
  patches.suse/nvmet-fc-track-hostport-handle-for-associations.patch
- commit 0113fce
* Mon May 11 2020 wqu@suse.com
- btrfs: relocation: Work around dead relocation stage loop
  (bsc#1171417).
- commit f418462
* Mon May 11 2020 wqu@suse.com
- btrfs: relocation: Check cancel request after each extent  found
  (bsc#1171417).
- commit 9d1084e
* Mon May 11 2020 wqu@suse.com
- btrfs: relocation: Check cancel request after each data  page
  read (bsc#1171417).
- commit 6e7cf97
* Mon May 11 2020 wqu@suse.com
- btrfs: relocation: add error injection points for  cancelling
  balance (bsc#1171417).
- commit ef70462
* Sat May  9 2020 tiwai@suse.de
- staging: gasket: Check the return value of
  gasket_get_bar_index() (git-fixes).
- Revert "tty: serial: bcm63xx: fix missing clk_put() in
  bcm63xx_uart" (git-fixes).
- USB: serial: garmin_gps: add sanity checking for data length
  (git-fixes).
- drm: ingenic-drm: add MODULE_DEVICE_TABLE (git-fixes).
- commit e8b3583
* Fri May  8 2020 ykaukab@suse.de
- build tegra186 as a module (bsc#1171156)
- export MODULE_DEVICE_TABLE to allow building as module:
  add patches.suse/gpio-tegra186-export-MODULE_DEVICE_TABLE.patch
- update arm64 configs (GPIO_TEGRA186 y->m)
- add gpio-tegra186 entry to supported.conf
- soc/tegra: pmc: Enable PMIC wake event on Tegra186.
- commit 70ad6b5
* Fri May  8 2020 ykaukab@suse.de
- Update
  patches.suse/net-dsa-felix-Use-PHY_INTERFACE_MODE_INTERNAL-instea.patch
  upstream reference and move to sorted section.
- commit c046bd4
* Fri May  8 2020 ykaukab@suse.de
- Update patches.suse/net-mscc-fix-in-frame-extraction.patch upstream reference and move to sorted section.
- commit 28974d3
* Thu May  7 2020 jzerebecki@suse.com
- kernel-docs: Change Requires on python-Sphinx to earlier than version 3
  References: bsc#1166965
  From 3 on the internal API that the build system uses was rewritten in
  an incompatible way.
  See https://github.com/sphinx-doc/sphinx/issues/7421 and
  https://bugzilla.suse.com/show_bug.cgi?id=1166965#c16 for some details.
- commit cf60b5c
* Thu May  7 2020 msuchanek@suse.de
- libnvdimm: cover up nd_region changes (bsc#1162400).
- commit 528df6d
* Thu May  7 2020 msuchanek@suse.de
- libnvdimm: cover up struct nvdimm changes (bsc#1171742).
- commit 78df47c
* Thu May  7 2020 lhenriques@suse.com
- ceph: fix potential bad pointer deref in async dirops cb's
  (bsc#1171390).
- rbd: don't mess with a page vector in rbd_notify_op_lock()
  (bsc#1171391).
- rbd: don't test rbd_dev->opts in rbd_dev_image_release()
  (bsc#1171392).
- commit 11ed7ef
* Thu May  7 2020 msuchanek@suse.de
- libnvdimm: cover up nvdimm_security_ops changes (bsc#1171742).
- commit 37c125e
* Thu May  7 2020 msuchanek@suse.de
- libnvdimm: cover up nd_pfn_sb changes (bsc#1171759).
- commit 59fc719
* Thu May  7 2020 nsaenzjulienne@suse.de
- Update config files: Build w1 bus on arm64 (jsc#SLE-12203)
- supported.conf: support w1 core and thermometer support
- commit 73998d2
* Thu May  7 2020 tiwai@suse.de
- sched/psi: Fix OOB write when writing 0 bytes to PSI files
  (CVE-2020-0110 bsc#1171374).
- commit 0044c49
* Thu May  7 2020 tiwai@suse.de
- dp83640: reverse arguments to list_add_tail (git-fixes).
- batman-adv: Fix refcnt leak in batadv_v_ogm_process (git-fixes).
- batman-adv: Fix refcnt leak in batadv_store_throughput_override
  (git-fixes).
- batman-adv: Fix refcnt leak in batadv_show_throughput_override
  (git-fixes).
- batman-adv: fix batadv_nc_random_weight_tq (git-fixes).
- crypto: arch/nhpoly1305 - process in explicit 4k chunks
  (git-fixes).
- crypto: arch/lib - limit simd usage to 4k chunks (git-fixes).
- commit fbff5a5
* Thu May  7 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/bnxt_en-Fix-VF-anti-spoof-filter-setup.patch
  patches.suse/bnxt_en-Fix-VLAN-acceleration-handling-in-bnxt_fix_f.patch
  patches.suse/bnxt_en-Improve-AER-slot-reset.patch
  patches.suse/bnxt_en-Reduce-BNXT_MSIX_VEC_MAX-value-to-supported-.patch
  patches.suse/bnxt_en-Return-error-when-allocating-zero-size-conte.patch
  patches.suse/ibmvnic-Skip-fatal-error-reset-after-passive-init.patch
- commit 7b08e5b
* Wed May  6 2020 mkubecek@suse.cz
- add kabi reference files
- import from Public RC2 submission (commit b8c70f8e938e)
- enable kabi checking for -default and -preempt flavors
- commit 297cfce
* Wed May  6 2020 mbrugger@suse.com
- supported.conf: mark cuse as supported (bsc#1171279)
- commit 57d34e1
* Wed May  6 2020 bp@suse.de
- x86/cpu: Add a steppings field to struct x86_cpu_id
  (bsc#1152489).
- commit 0e87eea
* Wed May  6 2020 tiwai@suse.de
- PM: hibernate: Freeze kernel threads in software_resume()
  (git-fixes).
- PM: ACPI: Output correct message on target power state
  (git-fixes).
- dmaengine: dmatest: Fix iteration non-stop logic (git-fixes).
- drm/amd/display: Fix green screen issue after suspend
  (git-fixes).
- drm/edid: Fix off-by-one in DispID DTD pixel clock (git-fixes).
- mmc: sdhci-msm: Enable host capabilities pertains to R1b
  response (git-fixes).
- commit 2128020
* Wed May  6 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/powerplay: using the FCLK DPM table to set the MCLK'
- commit 8f1a5e9
* Wed May  6 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gt: Close race between cacheline_retire and free'
- commit 8f35802
* Wed May  6 2020 tzimmermann@suse.de
- drm/i915/gt: Stage the transfer of the virtual breadcrumb (bsc#1152489)
  * context changes
- commit dd7c1b9
* Wed May  6 2020 tzimmermann@suse.de
- drm/i915: Apply Wa_1406680159:icl,ehl as an engine workaround (bsc#1152489)
  * context changes
- commit 1b9f5c3
* Wed May  6 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gt: Avoid resetting ring->head outside of its timeline mutex'
- commit ce5eb60
* Wed May  6 2020 mbrugger@suse.com
- arm64: blacklist.conf: ignore commit that got reveted later
- commit ea9a578
* Wed May  6 2020 mbrugger@suse.com
- arm64: Update config files. (bsc#1170680)
  Enable CONFIG_KEXEC_SIG and CONFIG_KEXEC_IMAGE_VERIFY_SIG
- commit 83dffa3
* Wed May  6 2020 mbrugger@suse.com
- arm64: kexec_file: Fixed code style (bsc#1170680).
- arm64: kexec_file: add crash dump support (bsc#1170680).
- libfdt: include fdt_addresses.c (bsc#1170680).
- arm64: kexec: remove unnecessary debug prints (bsc#1170680).
- libfdt: define INT32_MAX and UINT32_MAX in libfdt_env.h
  (bsc#1170680).
- commit 3e603a5
* Wed May  6 2020 mbrugger@suse.com
- arm64: Use pr_warn instead of pr_warning (bsc#1170680).
- Refresh
  patches.suse/arm64-smp-fix-smp_send_stop-behaviour.patch.
- commit deabe43
* Wed May  6 2020 mbrugger@suse.com
- arm64: smp: Treat unknown boot failures as being 'stuck in
  kernel' (bsc#1170680).
- arm64: kexec_file: add rng-seed support (bsc#1170680).
- arm64/kexec: Use consistent convention of initializing
  'kxec_buf.mem' with KEXEC_BUF_MEM_UNKNOWN (bsc#1170680).
- commit b8854a2
* Wed May  6 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline tags:
  patches.suse/NFS-Directory-page-cache-pages-need-to-be-locked-whe.patch
  patches.suse/NFS-Fix-a-page-leak-in-nfs_destroy_unlinked_subreque.patch
  patches.suse/NFS-Fix-fix-of-show_nfs_errors.patch
  patches.suse/NFS-Fix-memory-leaks-and-corruption-in-readdir.patch
  patches.suse/NFS-Fix-races-nfs_page_group_destroy-vs-nfs_destroy_.patch
  patches.suse/NFS-Fix-use-after-free-issues-in-nfs_pageio_add_requ.patch
  patches.suse/NFS-Revalidate-the-file-mapping-on-all-fatal-writeba.patch
  patches.suse/NFS-Revalidate-the-file-size-on-a-fatal-write-error.patch
  patches.suse/NFS-alloc_nfs_open_context-must-use-the-file-cred-wh.patch
  patches.suse/NFS-pnfs-Fix-pnfs_generic_prepare_to_resend_writes.patch
  patches.suse/NFSD-fixing-possible-null-pointer-derefering-in-copy.patch
  patches.suse/NFSv2-Fix-a-typo-in-encode_sattr.patch
  patches.suse/NFSv4-pnfs-Return-valid-stateids-in-nfs_layout_find_.patch
  patches.suse/NFSv4-pnfs_roc-must-use-cred_fscmp-to-compare-creds.patch
  patches.suse/NFSv4-try-lease-recovery-on-NFS4ERR_EXPIRED.patch
  patches.suse/NFSv4.0-nfs4_do_fsinfo-should-not-do-implicit-lease-.patch
  patches.suse/NFSv4.1-fix-handling-of-backchannel-binding-in-BIND_.patch
  patches.suse/NFSv4.1-make-cachethis-no-for-writes.patch
  patches.suse/NFSv4.x-Drop-the-slot-if-nfs4_delegreturn_prepare-wa.patch
  patches.suse/NFSv4.x-Handle-bad-dead-sessions-correctly-in-nfs41_.patch
  patches.suse/SUNRPC-Fix-a-potential-buffer-overflow-in-svc_print_.patch
  patches.suse/SUNRPC-Fix-backchannel-RPC-soft-lockups.patch
  patches.suse/SUNRPC-Remove-unreachable-error-condition.patch
  patches.suse/nfs-Fix-potential-posix_acl-refcnt-leak-in-nfs3_set_.patch
  patches.suse/nfsd-Don-t-add-locks-to-closed-or-closing-open-state.patch
  patches.suse/nfsd-Fix-NFSv4-READ-on-RDMA-when-using-readv.patch
  patches.suse/nfsd-Return-the-correct-number-of-bytes-written-to-t.patch
  patches.suse/nfsd-depend-on-CRYPTO_MD5-for-legacy-client-tracking.patch
  patches.suse/nfsd-fix-delay-timer-on-32-bit-architectures.patch
  patches.suse/nfsd-fix-jiffies-time_t-mixup-in-LRU-list.patch
  patches.suse/nfsd-fsnotify-on-rmdir-under-nfsd-clients.patch
  patches.suse/nfsd-memory-corruption-in-nfsd4_lock.patch
  patches.suse/nfsd-remove-nfs4_reset_lease-declarations.patch
  patches.suse/nfsd4-fix-up-replay_matches_cache.patch
  patches.suse/sunrpc-expiry_time-should-be-seconds-not-timeval.patch
  patches.suse/svcrdma-Fix-double-svc_rdma_send_ctxt_put-in-an-erro.patch
  patches.suse/svcrdma-Fix-leak-of-transport-addresses.patch
- commit 913c3fc
* Tue May  5 2020 bp@suse.de
- x86/cpu: Add consistent CPU match macros (bsc#1152489).
- commit a70979e
* Tue May  5 2020 bp@suse.de
- x86/devicetable: Move x86 specific macro out of generic code
  (bsc#1152489).
- commit 9581d95
* Tue May  5 2020 msuchanek@suse.de
- nvdimm: Avoid race between probe and reading device attributes
  (bsc#1170442).
- commit daea9d3
* Tue May  5 2020 ailiop@suse.com
- xfs: add agf freeblocks verify in xfs_agf_verify (bsc#1171217
  CVE-2020-12655).
- commit 08016b2
* Tue May  5 2020 tiwai@suse.de
- xsk: Add missing check on user supplied headroom size
  (CVE-2020-12659 bsc#1171214).
- commit 57877bb
* Tue May  5 2020 tiwai@suse.de
- Update patch reference tags for mwifiex security fixes (CVE-2020-12653 bsc#1171195 CVE-2020-12654 bsc#1171202)
- commit 8da2e42
* Tue May  5 2020 tiwai@suse.de
- Update patch reference tag for a bfq security fix (CVE-2020-12657 bsc#1171205)
- commit a3037e6
* Tue May  5 2020 jslaby@suse.cz
- net: dsa: ksz: Select KSZ protocol tag
  (networking-stable-20_04_02).
- net, ip_tunnel: fix interface lookup with no key
  (networking-stable-20_04_02).
- sctp: fix possibly using a bad saddr with a given dst
  (networking-stable-20_04_02).
- sctp: fix refcount bug in sctp_wfree
  (networking-stable-20_04_02).
- ipv4: fix a RCU-list lock in fib_triestat_seq_show
  (networking-stable-20_04_02).
- commit 841d154
* Tue May  5 2020 tbogendoerfer@suse.de
- bnxt_en: Fix VLAN acceleration handling in bnxt_fix_features()
  (bsc#1171150).
- bnxt_en: Return error when allocating zero size context memory
  (bsc#1171150).
- bnxt_en: Improve AER slot reset (bsc#1171150).
- bnxt_en: Reduce BNXT_MSIX_VEC_MAX value to supported CQs per PF
  (bsc#1171150).
- bnxt_en: Fix VF anti-spoof filter setup (bsc#1171150).
- bnxt_en: Reset rings if ring reservation fails during open()
  (bsc#1171150).
- bnxt_en: Free context memory after disabling PCI in probe
  error path (bsc#1171150).
- bnxt_en: Return error if bnxt_alloc_ctx_mem() fails
  (bsc#1171150).
- bnxt_en: fix memory leaks in bnxt_dcbnl_ieee_getets()
  (bsc#1171150).
- bnxt_en: Fix Priority Bytes and Packets counters in ethtool -S
  (bsc#1171150).
- commit 0a89267
* Tue May  5 2020 mbenes@suse.cz
- xprtrdma: Fix trace point use-after-free race (git-fixes).
- commit 52af41b
* Tue May  5 2020 jslaby@suse.cz
- mlxsw: spectrum_mr: Fix list iteration in error path
  (networking-stable-20_03_28).
- net: dsa: tag_8021q: replace dsa_8021q_remove_header with
  __skb_vlan_pop (networking-stable-20_03_28).
- net: cbs: Fix software cbs to consider packet sending time
  (networking-stable-20_03_28).
- net: dsa: Fix duplicate frames flooded by learning
  (networking-stable-20_03_28).
- bnxt_en: Reset rings if ring reservation fails during open()
  (networking-stable-20_03_28).
- bnxt_en: Free context memory after disabling PCI in probe
  error path (networking-stable-20_03_28).
- bnxt_en: Return error if bnxt_alloc_ctx_mem() fails
  (networking-stable-20_03_28).
- bnxt_en: fix memory leaks in bnxt_dcbnl_ieee_getets()
  (networking-stable-20_03_28).
- bnxt_en: Fix Priority Bytes and Packets counters in ethtool -S
  (networking-stable-20_03_28).
- macsec: restrict to ethernet devices
  (networking-stable-20_03_28).
- ipv4: fix a RCU-list lock in inet_dump_fib()
  (networking-stable-20_03_28).
- tcp: repair: fix TCP_QUEUE_SEQ implementation
  (networking-stable-20_03_28).
- net: phy: dp83867: w/a for fld detect threshold bootstrapping
  issue (networking-stable-20_03_28).
- net: stmmac: dwmac-rk: fix error path in rk_gmac_probe
  (networking-stable-20_03_28).
- hsr: fix general protection fault in hsr_addr_is_self()
  (networking-stable-20_03_28).
- cxgb4: fix Txq restart check during backpressure
  (networking-stable-20_03_28).
- net/sched: act_ct: Fix leak of ct zone template on replace
  (networking-stable-20_03_28).
- net: ip_gre: Accept IFLA_INFO_DATA-less configuration
  (networking-stable-20_03_28).
- net: mvneta: Fix the case where the last poll did not process
  all rx (networking-stable-20_03_28).
- net_sched: cls_route: remove the right filter from hashtable
  (networking-stable-20_03_28).
- hsr: set .netnsok flag (networking-stable-20_03_28).
- hsr: add restart routine into hsr_get_node_list()
  (networking-stable-20_03_28).
- hsr: use rcu_read_lock() in hsr_get_node_{list/status}()
  (networking-stable-20_03_28).
- net/packet: tpacket_rcv: avoid a producer race condition
  (networking-stable-20_03_28).
- net: ip_gre: Separate ERSPAN newlink / changelink callbacks
  (networking-stable-20_03_28).
- net_sched: hold rtnl lock in tcindex_partial_destroy_work()
  (networking-stable-20_03_28).
- commit b6b5945
* Tue May  5 2020 mbenes@suse.cz
- svcrdma: Fix trace point use-after-free race (git-fixes).
- commit 44461e4
* Tue May  5 2020 tiwai@suse.de
- Revert "HID: wacom: generic: read the number of expected
  touches on a per collection basis" (git-fixes).
- HID: wacom: Read HID_DG_CONTACTMAX directly for non-generic
  devices (git-fixes).
- commit 16cdbdb
* Tue May  5 2020 neilb@suse.de
- NFSv4.1: fix handling of backchannel binding in
  BIND_CONN_TO_SESSION (bsc#1170630).
- commit a75f6f6
* Tue May  5 2020 neilb@suse.de
- SUNRPC: Remove unreachable error condition (git-fixes).
- nfs: Fix potential posix_acl refcnt leak in nfs3_set_acl
  (git-fixes).
- SUNRPC: Fix backchannel RPC soft lockups (git-fixes).
- nfsd: memory corruption in nfsd4_lock() (git-fixes).
- NFS: Fix use-after-free issues in nfs_pageio_add_request()
  (git-fixes).
- NFS: Fix races nfs_page_group_destroy() vs
  nfs_destroy_unlinked_subrequests() (git-fixes).
- NFS: Fix a page leak in nfs_destroy_unlinked_subrequests()
  (git-fixes).
- NFSv4/pnfs: Return valid stateids in
  nfs_layout_find_inode_by_stateid() (git-fixes).
- NFS: alloc_nfs_open_context() must use the file cred when
  available (git-fixes).
- svcrdma: Fix leak of transport addresses (git-fixes).
- SUNRPC: Fix a potential buffer overflow in 'svc_print_xprts()'
  (git-fixes).
- nfsd: fsnotify on rmdir under nfsd/clients/ (git-fixes).
- nfsd: Don't add locks to closed or closing open stateids
  (git-fixes).
- svcrdma: Fix double svc_rdma_send_ctxt_put() in an error path
  (git-fixes).
- nfsd: Fix NFSv4 READ on RDMA when using readv (git-fixes).
- NFSv4.1 make cachethis=no for writes (git-fixes).
- sunrpc: expiry_time should be seconds not timeval (git-fixes).
- nfsd: remove nfs4_reset_lease() declarations (git-fixes).
- nfsd: fix jiffies/time_t mixup in LRU list (git-fixes).
- nfsd: fix delay timer on 32-bit architectures (git-fixes).
- nfsd: Return the correct number of bytes written to the file
  (git-fixes).
- NFSv4.0: nfs4_do_fsinfo() should not do implicit lease renewals
  (git-fixes).
- NFSv4: try lease recovery on NFS4ERR_EXPIRED (git-fixes).
- NFS: Directory page cache pages need to be locked when read
  (git-fixes).
- NFS: Fix memory leaks and corruption in readdir (git-fixes).
- NFSv4: pnfs_roc() must use cred_fscmp() to compare creds
  (git-fixes).
- NFS: Fix fix of show_nfs_errors (git-fixes).
- NFS/pnfs: Fix pnfs_generic_prepare_to_resend_writes()
  (git-fixes).
- NFS: Revalidate the file mapping on all fatal writeback errors
  (git-fixes).
- NFS: Revalidate the file size on a fatal write error
  (git-fixes).
- nfsd: depend on CRYPTO_MD5 for legacy client tracking
  (git-fixes).
- NFSD fixing possible null pointer derefering in copy offload
  (git-fixes).
- nfsd4: fix up replay_matches_cache() (git-fixes).
- NFSv4.x: Drop the slot if nfs4_delegreturn_prepare waits for
  layoutreturn (git-fixes).
- NFSv4.x: Handle bad/dead sessions correctly in
  nfs41_sequence_process() (git-fixes).
- NFSv2: Fix a typo in encode_sattr() (git-fixes).
- commit d9c3108
* Mon May  4 2020 ailiop@suse.com
- xfs: acquire superblock freeze protection on eofblocks scans
  (git-fixes).
- commit ae8b96a
* Mon May  4 2020 ailiop@suse.com
- xfs: clear PF_MEMALLOC before exiting xfsaild thread
  (git-fixes).
- commit a472c36
* Mon May  4 2020 tbogendoerfer@suse.de
- RDMA/core: Fix overwriting of uobj in case of error
  (jsc#SLE-8449).
- RDMA/uverbs: Fix a race with disassociate and exit_mmap()
  (jsc#SLE-8449).
- commit fcb09af
* Mon May  4 2020 msuchanek@suse.de
- ibmvnic: Skip fatal error reset after passive init (bsc#1171078
  ltc#184239).
- commit b0e0859
* Mon May  4 2020 mbrugger@suse.com
- arm64: dts: allwinner: a64: Fix display clock register range
  (bsc#1171081).
- arm64: bcm2835: Drop select of nonexistent HAVE_ARM_ARCH_TIMER
  (bsc#1171079).
- ARM: bcm2835-rpi-zero-w: Add missing pinctrl name (bsc#1171075).
- arm64: alternative: fix build with clang integrated assembler
  (bsc#1171076).
- arm64: compat: Fix syscall number of compat_clock_getres
  (bsc#1171080).
- arm64: smp: fix crash_smp_send_stop() behaviour (bsc#1171082).
- arm64: smp: fix smp_send_stop() behaviour (bsc#1171083).
- compat: ARM64: always include asm-generic/compat.h
  (bsc#1171084).
- commit 559d336
* Mon May  4 2020 nsaenzjulienne@suse.de
- Update patches.suse/firmware-raspberrypi-introduce-vl805-init-routine.patch.
- commit 984c0bd
* Mon May  4 2020 jslaby@suse.cz
- blacklist.conf: add aer_inject entry
  It requires the new irq injection infrastructure.
- commit a8523ff
* Mon May  4 2020 jslaby@suse.cz
- Revert "serial: uartps: Fix uartps_major handling" (git-fixes).
- net: stmmac: dwmac-meson8b: Add missing boundary to RGMII TX
  clock array (git-fixes).
- commit 7b95e1e
* Mon May  4 2020 jslaby@suse.cz
- random: always use batched entropy for get_random_u{32,64}
  (git-fixes).
- commit 6e4b6dc
* Sun May  3 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/ALSA-pcm-oss-Place-the-plugin-buffer-overflow-checks.patch
  patches.suse/scsi-qla2xxx-check-UNLOADING-before-posting-async-wo.patch
  patches.suse/scsi-qla2xxx-set-UNLOADING-before-waiting-for-sessio.patch
- commit ed4ef69
* Sun May  3 2020 mkubecek@suse.cz
- update metadata of nvme patches
  The nvme-5.8 branch in nvme repository got rebased again, update Git-commit
  tags:
  patches.suse/lpfc-Commonize-lpfc_async_xchg_ctx-state-and-flag-de.patch
  patches.suse/lpfc-Refactor-NVME-LS-receive-handling.patch
  patches.suse/lpfc-Refactor-Send-LS-Abort-support.patch
  patches.suse/lpfc-Refactor-Send-LS-Request-support.patch
  patches.suse/lpfc-Refactor-Send-LS-Response-support.patch
  patches.suse/lpfc-Refactor-lpfc-nvme-headers.patch
  patches.suse/lpfc-Refactor-nvmet_rcv_ctx-to-create-lpfc_async_xch.patch
  patches.suse/lpfc-nvme-Add-Receive-LS-Request-and-Send-LS-Respons.patch
  patches.suse/lpfc-nvmet-Add-Send-LS-Request-and-Abort-LS-Request-.patch
  patches.suse/lpfc-nvmet-Add-support-for-NVME-LS-request-hosthandl.patch
  patches.suse/nvme-fc-Add-Disconnect-Association-Rcv-support.patch
  patches.suse/nvme-fc-Ensure-private-pointers-are-NULL-if-no-data.patch
  patches.suse/nvme-fc-Sync-header-to-FC-NVME-2-rev-1.08.patch
  patches.suse/nvme-fc-Update-header-and-host-for-common-definition.patch
  patches.suse/nvme-fc-and-nvmet-fc-revise-LLDD-api-for-LS-receptio.patch
  patches.suse/nvme-fc-convert-assoc_active-flag-to-bit-op.patch
  patches.suse/nvme-fc-nvmet-fc-refactor-for-common-LS-definitions.patch
  patches.suse/nvme-fcloop-add-target-to-host-LS-request-support.patch
  patches.suse/nvme-fcloop-refactor-to-enable-target-to-host-LS.patch
  patches.suse/nvmet-fc-Add-Disconnect-Association-Xmt-support.patch
  patches.suse/nvmet-fc-Better-size-LS-buffers.patch
  patches.suse/nvmet-fc-Update-target-for-common-definitions-for-LS.patch
  patches.suse/nvmet-fc-add-LS-failure-messages.patch
  patches.suse/nvmet-fc-perform-small-cleanups-on-unneeded-checks.patch
  patches.suse/nvmet-fc-rename-ls_list-to-ls_rcv_list.patch
  patches.suse/nvmet-fc-track-hostport-handle-for-associations.patch
- commit a859813
* Sat May  2 2020 tiwai@suse.de
- PCI: Add ACS quirk for iProc PAXB (git-fixes).
- Refresh
  patches.suse/PCI-Add-ACS-quirk-for-Amazon-Annapurna-Labs-root-por.patch.
- commit aef108e
* Sat May  2 2020 tiwai@suse.de
- i2c: aspeed: Avoid i2c interrupt status clear race condition
  (git-fixes).
- i2c: amd-mp2-pci: Fix Oops in amd_mp2_pci_init() error handling
  (git-fixes).
- i2c: iproc: generate stop event for slave writes (git-fixes).
- drm/qxl: qxl_release use after free (git-fixes).
- drm/qxl: qxl_release leak in qxl_hw_surface_alloc() (git-fixes).
- drm/qxl: qxl_release leak in qxl_draw_dirty_fb() (git-fixes).
- mmc: sdhci-pci: Fix eMMC driver strength for BYT-based
  controllers (git-fixes).
- mmc: sdhci-xenon: fix annoying 1.8V regulator warning
  (git-fixes).
- mmc: cqhci: Avoid false "cqhci: CQE stuck on" by not open-coding
  timeout loop (git-fixes).
- mmc: meson-mx-sdio: remove the broken ->card_busy() op
  (git-fixes).
- mmc: meson-mx-sdio: Set MMC_CAP_WAIT_WHILE_BUSY (git-fixes).
- PCI: Move Apex Edge TPU class quirk to fix BAR assignment
  (git-fixes).
- hwmon: (jc42) Fix name to have no illegal characters
  (git-fixes).
- mac80211: fix channel switch trigger from unknown mesh peer
  (git-fixes).
- PCI: Add ACS quirk for Zhaoxin Root/Downstream Ports
  (git-fixes).
- PCI: Add ACS quirk for Zhaoxin multi-function devices
  (git-fixes).
- PCI: Add Zhaoxin Vendor ID (git-fixes).
- PCI: Avoid ASMedia XHCI USB PME# from D0 defect (git-fixes).
- PCI: Unify ACS quirk desired vs provided checking (git-fixes).
- PCI: Make ACS quirk implementations more uniform (git-fixes).
- commit 21a860f
* Sat May  2 2020 tiwai@suse.de
- ALSA: usb-audio: Correct a typo of NuPrime DAC-10 USB ID
  (git-fixes).
- ALSA: opti9xx: shut up gcc-10 range warning (git-fixes).
- ALSA: hda/hdmi: fix without unlocked before return (git-fixes).
- ALSA: hda/hdmi: fix race in monitor detection during probe
  (git-fixes).
- ALSA: hda/realtek - Two front mics on a Lenovo ThinkCenter
  (git-fixes).
- ALSA: line6: Fix POD HD500 audio playback (git-fixes).
- ALSA: hda: Match both PCI ID and SSID for driver blacklist
  (git-fixes).
- commit f537abd
* Sat May  2 2020 tiwai@suse.de
- Move the upstreamed sound and scsi patches to the mainline section
- commit f5d1d6a
* Sat May  2 2020 colyli@suse.de
- libnvdimm/region: Fix build error (bsc#1162400).
- libnvdimm/region: Introduce an 'align' attribute (bsc#1162400).
- commit cdf6722
* Sat May  2 2020 colyli@suse.de
- libnvdimm/region: Introduce NDD_LABELING (bsc#1162400).
- libnvdimm/namespace: Enforce memremap_compat_align()
  (bsc#1162400).
- libnvdimm/pfn: Prevent raw mode fallback if pfn-infoblock valid
  (bsc#1171743).
- commit f5c3d9e
* Sat May  2 2020 colyli@suse.de
- mm/memremap_pages: Introduce memremap_compat_align() (bsc#1162400).
- Update configs for the above change.
- Refresh patches.suse/powerpc-bpf-Enable-bpf_probe_read-str-on-powerpc-aga.patch.
- mm/memremap_pages: Kill unused __devm_memremap_pages()
  (bsc#1162400).
- libnvdimm/btt: fix variable 'rc' set but not used
  (bsc#1162400).
- libnvdimm/namsepace: Don't set claim_class on error
  (bsc#1162400).
- commit 312e489
* Sat May  2 2020 colyli@suse.de
- lib: Uplevel the pmem "region" ida to a global allocator
  (bc#1162400).
- Update configs for the above change.
- libnvdimm: Use PAGE_SIZE instead of SZ_4K for align check
  (bsc#1171759).
- libnvdimm/label: Remove the dpa align check (bsc#1171759).
- libnvdimm/pfn_dev: Add page size and struct page size to pfn
  superblock (bsc#1171759).
- commit c578923
* Sat May  2 2020 colyli@suse.de
- libnvdimm/pmem: Advance namespace seed for specific probe errors
  (bsc#1171743).
- libnvdimm/pfn_dev: Add a build check to make sure we notice when
  struct page size change (bsc#1171743).
- Refresh for the above changes,
  patches.suse/libnvdimm-namespace-Differentiate-between-probe-mapp.patch.
- commit 9e70235
* Fri May  1 2020 colyli@suse.de
- libnvdimm/region: Rewrite _probe_success() to _advance_seeds()
  (bsc#1171743).
- commit dd1569b
* Fri May  1 2020 colyli@suse.de
- libnvdimm/security: Introduce a 'frozen' attribute (bsc#1171742).
- Refresh for the above change,
  patches.suse/libnvdimm-prevent-nvdimm-from-requesting-key-when-security.patch.
- commit 307a9c7
* Fri May  1 2020 colyli@suse.de
- libnvdimm/of_pmem: Provide a unique name for bus provider
  (bsc#1171739).
- commit 3aff0cd
* Fri May  1 2020 rgoldwyn@suse.com
- fanotify: fix merging marks masks with FAN_ONDIR  (bsc#1170799).
- commit 5edf4ab
* Fri May  1 2020 tiwai@suse.de
- Revert an ASoC meson backport that is known to to break
  Delete patches.suse/ASoC-meson-axg-card-fix-codec-to-codec-link-setup.patch
  Add the commit to blacklist.conf, too
- commit d6f33c1
* Thu Apr 30 2020 msuchanek@suse.de
- libnvdimm: Out of bounds read in __nd_ioctl() (bsc#1065729).
- mm/memremap: drop unused SECTION_SIZE and SECTION_MASK
  (bsc#1162400 bsc#1170895 ltc#184375 ltc#185686).
- commit ceaa507
* Thu Apr 30 2020 tiwai@suse.de
- Update patch reference for a USB core fix (CVE-2020-12464 bsc#1170901)
- commit c3ba43e
* Thu Apr 30 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline, drop Git-repo and Git-commit:
  patches.suse/net-phy-realtek-fix-handling-of-RTL8105e-integrated-.patch
- commit d71cae8
* Thu Apr 30 2020 oneukum@suse.com
- Update
  patches.suse/mt76-fix-array-overflow-on-receiving-too-many-fragme.patch
  (bsc#1170828 CVE-2020-12465).
  Added bsc and CVE number
- commit 62c98d8
* Thu Apr 30 2020 tiwai@suse.de
- drm/i915: properly sanity check batch_start_offset (git-fixes).
- commit 6a1493c
* Thu Apr 30 2020 tiwai@suse.de
- tty: hvc: fix buffer overflow during hvc_alloc() (git-fixes).
- watchdog: reset last_hw_keepalive time at start (git-fixes).
- Revert "software node: Simplify software_node_release()
  function" (git-fixes).
- intel_th: msu: Fix window switching without windows (git-fixes).
- commit f284d1e
* Thu Apr 30 2020 tiwai@suse.de
- crypto: caam - fix the address of the last entry of S/G
  (git-fixes).
- USB: sisusbvga: Change port variable from signed to unsigned
  (git-fixes).
- usb-storage: Add unusual_devs entry for JMicron JMS566
  (git-fixes).
- xhci: prevent bus suspend if a roothub port detected a
  over-current condition (git-fixes).
- USB: Add USB_QUIRK_DELAY_CTRL_MSG and USB_QUIRK_DELAY_INIT
  for Corsair K70 RGB RAPIDFIRE (git-fixes).
- usb: typec: tcpm: Ignore CC and vbus changes in PORT_RESET
  change (git-fixes).
- cdc-acm: introduce a cool down (git-fixes).
- cdc-acm: close race betrween suspend() and acm_softint
  (git-fixes).
- USB: core: Fix free-while-in-use bug in the USB S-Glibrary
  (git-fixes).
- serial: sh-sci: Make sure status register SCxSR is read in
  correct sequence (git-fixes).
- staging: comedi: dt2815: fix writing hi byte of analog output
  (git-fixes).
- iwlwifi: mvm: fix inactive TID removal return value usage
  (git-fixes).
- iwlwifi: mvm: Do not declare support for ACK Enabled Aggregation
  (git-fixes).
- iwlwifi: mvm: beacon statistics shouldn't go backwards
  (git-fixes).
- drm/amd/display: Calculate scaling ratios on every medium/full
  update (git-fixes).
- drm/amd/display: Update stream adjust in
  dc_stream_adjust_vmin_vmax (git-fixes).
- drm/amd/display: Not doing optimize bandwidth if flip pending
  (git-fixes).
- xhci: Finetune host initiated USB3 rootport link suspend and
  resume (git-fixes).
- xhci: Wait until link state trainsits to U0 after setting
  USB_SS_PORT_LS_U0 (git-fixes).
- xhci: Ensure link state is U3 after setting USB_SS_PORT_LS_U3
  (git-fixes).
- PCI/PM: Add pcie_wait_for_link_delay() (git-fixes).
- PCI/ASPM: Allow re-enabling Clock PM (git-fixes).
- commit 69b68ab
* Thu Apr 30 2020 glin@suse.com
- bpf: Fix handling of XADD on BTF memory (bsc#1155518).
- bpf: Forbid XADD on spilled pointers for unprivileged users
  (bsc#1155518).
- commit 60505c2
* Wed Apr 29 2020 tiwai@suse.de
- net: phy: realtek: fix handling of RTL8105e-integrated PHY
  (git-fixes).
- commit 630c337
* Wed Apr 29 2020 tiwai@suse.de
- USB: hub: Fix handling of connect changes during sleep
  (git-fixes).
- usb: typec: altmode: Fix typec_altmode_get_partner sometimes
  returning an invalid pointer (git-fixes).
- usb: gadget: udc: atmel: Fix vbus disconnect handling
  (git-fixes).
- usb: gadget: udc: bdc: Remove unnecessary NULL checks in
  bdc_req_complete (git-fixes).
- geneve: use the correct nlattr array in NL_SET_ERR_MSG_ATTR
  (git-fixes).
- drivers: soc: xilinx: fix firmware driver Kconfig dependency
  (git-fixes).
- soc: imx: gpc: fix power up sequencing (git-fixes).
- hibernate: Allow uswsusp to write to swap (git-fixes).
- phy: uniphier-usb3ss: Add Pro5 support (git-fixes).
- padata: update documentation file path in MAINTAINERS
  (git-fixes).
- commit b521dd8
* Wed Apr 29 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/0001-btrfs-don-t-pass-system_chunk-into-can_overcommit.patch
  patches.suse/0001-btrfs-fix-force-usage-in-inc_block_group_ro.patch
  patches.suse/0002-btrfs-kill-min_allocable_bytes-in-inc_block_group_ro.patch
  patches.suse/0002-btrfs-take-overcommit-into-account-in-inc_block_grou.patch
  patches.suse/btrfs-check-rw_devices-not-num_devices-for-balance.patch
  patches.suse/btrfs-scrub-Don-t-check-free-space-before-marking-a-.patch
- commit 0c4ef8d
* Wed Apr 29 2020 msuchanek@suse.de
- scsi: ibmvscsi: Fix WARN_ON during event pool release
  (bsc#1170791 ltc#185128).
- commit 235b7cd
* Wed Apr 29 2020 wqu@suse.com
- btrfs: take overcommit into account in inc_block_group_ro
  (bsc#1156898).
- commit b4b780e
* Wed Apr 29 2020 wqu@suse.com
- btrfs: fix force usage in inc_block_group_ro (bsc#1156898).
- commit 9de9dbb
* Wed Apr 29 2020 wqu@suse.com
- btrfs: scrub: Don't check free space before marking a block
  group RO (bsc#1156898).
- Refresh
  patches.suse/0001-btrfs-scrub-Require-mandatory-block-group-RO-for-dev.patch.
- Refresh
  patches.suse/Btrfs-fix-block-group-remaining-RO-forever-after-err.patch.
- commit 0af353d
* Wed Apr 29 2020 wqu@suse.com
- btrfs: kill min_allocable_bytes in inc_block_group_ro
  (bsc#1156898).
- commit d02303e
* Wed Apr 29 2020 wqu@suse.com
- btrfs: don't pass system_chunk into can_overcommit
  (bsc#1156898).
- commit c373e8e
* Wed Apr 29 2020 wqu@suse.com
- btrfs: check rw_devices, not num_devices for balance
  (bsc#1156898).
- commit 1228d44
* Wed Apr 29 2020 tbogendoerfer@suse.de
- RDMA/bnxt_re: make bnxt_re_ib_init static (bsc#1170774).
- RDMA/bnxt_re: Wait for all the CQ events before freeing CQ
  data structures (bsc#1170774).
- RDMA/bnxt_re: Remove unnecessary sched count (bsc#1170774).
- RDMA/bnxt_re: Fix lifetimes in bnxt_re_task (bsc#1170774).
- RDMA/bnxt_re: Use ib_device_try_get() (bsc#1170774).
- RDMA/bnxt_re: Remove a redundant 'memset' (bsc#1170774).
- RDMA/bnxt_re: Remove set but not used variables 'pg' and 'idx'
  (bsc#1170774).
- RDMA/bnxt_re: Remove set but not used variable 'dev_attr'
  (bsc#1170774).
- RDMA/bnxt_re: Remove set but not used variable 'pg_size'
  (bsc#1170774).
- RDMA/bnxt_re: Use driver_unregister and unregistration API
  (bsc#1170774).
- RDMA/bnxt_re: Refactor device add/remove functionalities
  (bsc#1170774).
- RDMA/bnxt_re: Using vmalloc requires including vmalloc.h
  (bsc#1170774).
- RDMA/bnxt_re: use ibdev based message printing functions
  (bsc#1170774).
- RDMA/bnxt_re: Refactor doorbell management functions
  (bsc#1170774).
- RDMA/bnxt_re: Refactor notification queue management code
  (bsc#1170774).
- RDMA/bnxt_re: Refactor command queue management code
  (bsc#1170774).
- RDMA/bnxt_re: Refactor net ring allocation function
  (bsc#1170774).
- RDMA/bnxt_re: Refactor hardware queue memory allocation
  (bsc#1170774).
- RDMA/bnxt_re: Replace chip context structure with pointer
  (bsc#1170774).
- RDMA/bnxt_re: Refactor queue pair creation code (bsc#1170774).
- RDMA/bnxt_re: Use rdma_read_gid_hw_context to retrieve HW gid
  index (bsc#1170774).
- RDMA/core: Add helper function to retrieve driver gid context
  from gid attr (bsc#1170774).
- commit 63c9b07
* Tue Apr 28 2020 ptesarik@suse.cz
- s390/mm: fix page table upgrade vs 2ndary address mode accesses
  (bsc#1170030 CVE-2020-11884).
- commit 0b0d8cd
* Tue Apr 28 2020 bp@suse.de
- EDAC/i10nm: Update driver to support different bus number
  config register offsets (bsc#1159522).
- commit 796bb54
* Tue Apr 28 2020 mhocko@suse.com
- Update patches.suse/x86-mm-split-vmalloc_sync_all.patch
  (bsc#1165741, bsc#1166969).
- commit dc341e6
* Tue Apr 28 2020 bp@suse.de
- EDAC, {skx,i10nm}: Make some configurations CPU model specific
  (bsc#1159522).
- commit 7936538
* Tue Apr 28 2020 msuchanek@suse.de
- Update patches.suse/ibmvfc-don-t-send-implicit-logouts-prior-to-NPIV-log.patch
  to upstream version and rename to patches.suse/scsi-ibmvfc-Don-t-send-implicit-logouts-prior-to-NPI.patch
- commit d04a4dc
* Tue Apr 28 2020 dwagner@suse.de
- wireguard: Kconfig: select parent dependency for crypto
  (bsc#1169021 jsc#SLE-12250).
- commit 41bcd62
* Mon Apr 27 2020 lyan@suse.com
- KVM: s390: Return last valid slot if approx index is
  out-of-bounds (bsc#1133021).
- commit a035552
* Mon Apr 27 2020 dbueso@suse.de
- proc, time/namespace: Show clock symbolic names in
  /proc/pid/timens_offsets (bsc#1164648,jsc#SLE-11493).
- futex: Remove {get,drop}_futex_key_refs() (bsc#1149032).
- futex: Remove pointless mmgrap() + mmdrop() (bsc#1149032).
- locking/rtmutex: rcu: Add WRITE_ONCE() to rt_mutex ->owner
  (bsc#1149032).
- futex: Unbreak futex hashing (bsc#1149032).
- futex: Fix inode life-time issue (bsc#1149032).
- commit 7790db5
* Mon Apr 27 2020 ohering@suse.de
- x86: hyperv: report value of misc_features (git fixes).
- commit e231452
* Mon Apr 27 2020 ohering@suse.de
- x86/Hyper-V: Report crash data in die() when panic_on_oops is
  set (git fixes).
  Refresh patches.suse/suse-hv-kabi.patch
- commit 5afa1b8
* Mon Apr 27 2020 ohering@suse.de
- x86/Hyper-V: Report crash register data when
  sysctl_record_panic_msg is not set (git fixes).
- commit f165c68
* Mon Apr 27 2020 ohering@suse.de
- x86/Hyper-V: Report crash register data or kmsg before running
  crash kernel (git fixes).
- commit b120cb7
* Mon Apr 27 2020 ohering@suse.de
- x86/Hyper-V: Trigger crash enlightenment only once during
  system crash (git fixes).
- commit 1644d6f
* Mon Apr 27 2020 ohering@suse.de
- x86/Hyper-V: Free hv_panic_page when fail to register kmsg dump
  (git fixes).
- commit 918a3d5
* Mon Apr 27 2020 ohering@suse.de
- x86/Hyper-V: Unload vmbus channel in hv panic callback
  (git fixes).
  Refresh patches.suse/suse-hv-kabi.patch
- commit f66b321
* Mon Apr 27 2020 tiwai@suse.de
- drm/exynos: Fix cleanup of IOMMU related objects (git-fixes).
- commit 7669fb1
* Mon Apr 27 2020 tiwai@suse.de
- staging: comedi: Fix comedi_device refcnt leak in comedi_open
  (git-fixes).
- macsec: avoid to set wrong mtu (git-fixes).
- iwlwifi: pcie: actually release queue memory in TVQM
  (git-fixes).
- macvlan: fix null dereference in macvlan_device_event()
  (git-fixes).
- PM: sleep: core: Switch back to async_schedule_dev()
  (git-fixes).
- drm/meson: Delete an error message in meson_dw_hdmi_bind()
  (git-fixes).
- audit: check the length of userspace generated audit records
  (git-fixes).
- tpm/tpm_tis: Free IRQ if probing fails (git-fixes).
- tpm: fix wrong return value in tpm_pcr_extend (git-fixes).
- drm/amdkfd: kfree the wrong pointer (git-fixes).
- drm/nouveau/gr/gp107,gp108: implement workaround for HW hanging
  during init (git-fixes).
- drm/nouveau: workaround runpm fail by disabling PCI power
  management on certain intel bridges (git-fixes).
- drm/nouveau/svm: check for SVM initialized before migrating
  (git-fixes).
- drm/nouveau/svm: fix vma range check for migration (git-fixes).
- fbcon: fix null-ptr-deref in fbcon_switch (git-fixes).
- power: supply: bq27xxx_battery: Silence deferred-probe error
  (git-fixes).
- power: supply: axp288_charger: Add special handling for HP
  Pavilion x2 10 (git-fixes).
- power: supply: axp288_fuel_gauge: Broaden vendor check for
  Intel Compute Sticks (git-fixes).
- clk: tegra: Fix Tegra PMC clock out parents (git-fixes).
- clk: at91: usb: continue if clk_hw_round_rate() return zero
  (git-fixes).
- rtc: 88pm860x: fix possible race condition (git-fixes).
- NTB: ntb_transport: Use scnprintf() for avoiding potential
  buffer overflow (git-fixes).
- ntb_hw_switchtec: Fix ntb_mw_clear_trans error if size == 0
  (git-fixes).
- ntb_tool: Fix printk format (git-fixes).
- NTB: ntb_perf: Fix address err in perf_copy_chunk (git-fixes).
- NTB: Fix an error in get link status (git-fixes).
- cpufreq: imx6q: fix error handling (git-fixes).
- cpufreq: imx6q: Fixes unwanted cpu overclocking on i.MX6ULL
  (git-fixes).
- iio: industrialio-core: Fix debugfs read (git-fixes).
- libfs: fix infoleak in simple_attr_read() (git-fixes).
- drm/amdgpu: fix memory leak during TDR test(v2) (git-fixes).
- Fix built-in early-load Intel microcode alignment (git-fixes).
- cpufreq: s3c64xx: Remove pointless NULL check in
  s3c64xx_cpufreq_driver_init (git-fixes).
- commit d13e57f
* Mon Apr 27 2020 ohering@suse.de
- Drivers: hv: vmbus: Fix crash handler reset of Hyper-V synic
  (git fixes).
  Refresh patches.suse/suse-hv-kabi.patch
- commit 73a1fdb
* Mon Apr 27 2020 ohering@suse.de
- Drivers: hv: vmbus: Remove dependencies on guest page size
  (git fixes).
- commit 0eb9623
* Mon Apr 27 2020 oneukum@suse.com
- UAS: fix deadlock in error handling and PM flushing work
  (git-fixes).
- commit f10ebae
* Mon Apr 27 2020 oneukum@suse.com
- UAS: no use logging any details in case of ENODEV (git-fixes).
- commit 12e8b6e
* Mon Apr 27 2020 oneukum@suse.com
- USB: hub: Revert commit bd0e6c9614b9 ("usb: hub: try old
  enumeration scheme first for high speed devices") (git-fixes).
- commit 63272b5
* Mon Apr 27 2020 oneukum@suse.com
- xhci: Don't clear hub TT buffer on ep0 protocol stall
  (git-fixes).
- commit d0e1439
* Mon Apr 27 2020 oneukum@suse.com
- usb: dwc3: gadget: Fix request completion check (git-fixes).
- commit eb78203
* Mon Apr 27 2020 tzimmermann@suse.de
- drm/sun4i: sun6i_mipi_dsi: Add VCC-DSI regulator support (bsc#1152489)
  * manual patch refresh
- commit 66ebcc7
* Mon Apr 27 2020 oneukum@suse.com
- usb: dwc3: gadget: Do link recovery for SS and SSP (git-fixes).
- commit 87d561b
* Mon Apr 27 2020 oneukum@suse.com
- usb: dwc3: Fix GTXFIFOSIZ.TXFDEP macro name (git-fixes).
- commit 7eb2c31
* Mon Apr 27 2020 oneukum@suse.com
- usb: f_fs: Clear OS Extended descriptor counts to zero in
  ffs_data_reset() (git-fixes).
- commit 1fb0c5f
* Mon Apr 27 2020 oneukum@suse.com
- USB: early: Handle AMD's spec-compliant identifiers, too
  (git-fixes).
- commit 26634ce
* Mon Apr 27 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/cpuidle-menu-Allow-tick-to-be-stopped-if-PM-QoS-is-used.patch
  patches.suse/mm-vmscan.c-clean-code-by-removing-unnecessary-assignment.patch
  patches.suse/rcu-Allow-only-one-expedited-GP-to-run-concurrently-with-wakeups.patch
  patches.suse/rcu-Fix-missed-wakeup-of-exp_wq-waiters.patch
  patches.suse/sched-fair-Align-rq-avg_idle-and-rq-avg_scan_cost.patch
- commit f15a73a
* Mon Apr 27 2020 mgorman@suse.de
- sched/nohz: Avoid disabling the tick for very short durations
  (bnc#754690, bsc#1158748).
- Delete patches.suse/sched-throttle-nohz.patch.
- commit 0628907
* Mon Apr 27 2020 mgorman@suse.de
- sched/cpuacct: Use __this_cpu_add() instead of this_cpu_ptr()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit 04cc379
* Mon Apr 27 2020 mgorman@suse.de
- sched/fair: Use __this_cpu_read() in wake_wide() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Align rq->avg_idle and rq->avg_scan_cost
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- mm/vmscan.c: clean code by removing unnecessary assignment
  (git fixes (mm/vmscan)).
- rcu: Allow only one expedited GP to run concurrently with
  wakeups (git fixes (rcu)).
- rcu: Fix missed wakeup of exp_wq waiters (git fixes (rcu)).
- cpuidle: menu: Allow tick to be stopped if PM QoS is used
  (bnc#1158748 (network regression)).
- commit cb72208
* Mon Apr 27 2020 tiwai@suse.de
- tty: rocket, avoid OOB access (git-fixes).
- tty: serial: bcm63xx: fix missing clk_put() in bcm63xx_uart
  (git-fixes).
- tty: serial: owl: add "much needed" clk_prepare_enable()
  (git-fixes).
- staging: vt6656: Fix calling conditions of vnt_set_bss_mode
  (git-fixes).
- staging: vt6656: Fix pairwise key entry save (git-fixes).
- staging: vt6656: Fix drivers TBTT timing counter (git-fixes).
- staging: vt6656: Don't set RCR_MULTICAST or RCR_BROADCAST by
  default (git-fixes).
- iio: core: remove extra semi-colon from
  devm_iio_device_register() macro (git-fixes).
- iio: adc: ti-ads8344: properly byte swap value (git-fixes).
- iio: st_sensors: rely on odr mask to know if odr can be set
  (git-fixes).
- iio: xilinx-xadc: Make sure not exceed maximum samplerate
  (git-fixes).
- iio: xilinx-xadc: Fix sequencer configuration for aux channels
  in simultaneous mode (git-fixes).
- iio: xilinx-xadc: Fix clearing interrupt when enabling trigger
  (git-fixes).
- iio: xilinx-xadc: Fix ADC-B powerdown (git-fixes).
- iio: adc: stm32-adc: fix sleep in atomic context (git-fixes).
- iio:ad7797: Use correct attribute_group (git-fixes).
- staging: gasket: Fix incongruency in handling of sysfs entries
  creation (git-fixes).
- commit 4fa06ba
* Mon Apr 27 2020 lyan@suse.com
- KVM: s390: vsie: Fix delivery of addressing exceptions
  (bsc#1133021).
- commit 2daae50
* Sun Apr 26 2020 tiwai@suse.de
- ALSA: pcm: oss: Place the plugin buffer overflow checks
  correctly (for 5.7) (bsc#1170522).
- commit b4d1953
* Sat Apr 25 2020 tiwai@suse.de
- ALSA: hda: Always use jackpoll helper for jack update after
  resume (git-fixes).
- ALSA: hda/realtek - Add new codec supported for ALC245
  (git-fixes).
- ALSA: usb-audio: Fix usb audio refcnt leak when getting spdif
  (git-fixes).
- ALSA: usb-audio: Add connector notifier delegation (git-fixes).
- ASoC: wm8960: Fix wrong clock after suspend & resume
  (git-fixes).
- ASoC: rsnd: Fix "status check failed" spam for multi-SSI
  (git-fixes).
- ASoC: rsnd: Don't treat master SSI in multi SSI setup as parent
  (git-fixes).
- ASoC: meson: axg-card: fix codec-to-codec link setup
  (git-fixes).
- ASoC: dapm: fixup dapm kcontrol widget (git-fixes).
- ASoC: SOF: Intel: add min/max channels for SSP on
  Baytrail/Broadwell (git-fixes).
- ASoC: rsnd: Fix HDMI channel mapping for multi-SSI mode
  (git-fixes).
- ASoC: rsnd: Fix parent SSI start/stop in multi-SSI mode
  (git-fixes).
- ASoC: codecs: hdac_hdmi: Fix incorrect use of
  list_for_each_entry (git-fixes).
- ASoC: topology: Fix endianness issue (git-fixes).
- ASoC: q6dsp6: q6afe-dai: add missing channels to MI2S DAIs
  (git-fixes).
- ASoC: sgtl5000: Fix VAG power-on handling (git-fixes).
- ASoC: madera: Remove a couple of stray blank lines (git-fixes).
- ASoC: qcom: common: Silence duplicate parse error messages
  (git-fixes).
- soc/stm/stm32_sub_sai: Add missing '\n' in log messages
  (git-fixes).
- ASoC: tas571x: disable regulators on failed probe (git-fixes).
- ASoC: topology: Check return value of soc_tplg_dai_config
  (git-fixes).
- ASoC: topology: Check return value of pcm_new_ver (git-fixes).
- ASoC: topology: Check soc_tplg_add_route return value
  (git-fixes).
- ASoC: topology: Check return value of soc_tplg_*_create
  (git-fixes).
- ASoC: topology: Check return value of soc_tplg_create_tlv
  (git-fixes).
- ALSA: usb-audio: Apply async workaround for Scarlett 2i4 2nd
  gen (git-fixes).
- ALSA: usx2y: Fix potential NULL dereference (git-fixes).
- ALSA: usb-audio: Add quirk for Focusrite Scarlett 2i2
  (git-fixes).
- ALSA: usb-audio: Add static mapping table for ALC1220-VB-based
  mobos (git-fixes).
- ALSA: hda: Remove ASUS ROG Zenith from the blacklist
  (git-fixes).
- ALSA: hda/realtek - Fix unexpected init_amp override
  (git-fixes).
- ALSA: usb-audio: Filter out unsupported sample rates on
  Focusrite devices (git-fixes).
- ALSA: hda/hdmi: Add module option to disable audio component
  binding (git-fixes).
- commit 9aa515f
* Fri Apr 24 2020 msuchanek@suse.de
- Update
  patches.suse/powerpc-pseries-ddw-Extend-upper-limit-for-huge-DMA-.patch
  (FATE#327775 bsc#1142685 bsc#1167867 ltc#179509 ltc#184616).
- commit 54d9eaa
* Thu Apr 23 2020 dwagner@suse.de
- scsi: qla2xxx: check UNLOADING before posting async work
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- scsi: qla2xxx: set UNLOADING before waiting for session deletion
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- scsi: qla2xxx: Fix regression warnings (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- scsi: qla2xxx: Remove non functional code (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- scsi: qla2xxx: add ring buffer for tracing debug logs
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- commit 0ed2831
* Thu Apr 23 2020 dwagner@suse.de
- Fix meta data for FC-NVME-2 patches
  The branch of the maintainer got rebased. Update the commit id accordingly.
- commit e17d7e2
* Thu Apr 23 2020 tzimmermann@suse.de
- Revert "drm/panel: simple: Add support for Sharp LQ150X1LG11 panels" (bsc#1152472)
- commit 5a48ac0
* Thu Apr 23 2020 tzimmermann@suse.de
- drm/sun4i: dsi: Remove incorrect use of runtime PM (bsc#1152472)
  * manual patch refresh
- commit 1f5ded0
* Thu Apr 23 2020 tzimmermann@suse.de
- fbcon: fix null-ptr-deref in fbcon_switch (bsc#1152472)
- commit a5735e6
* Thu Apr 23 2020 shung-hsi.yu@suse.com
- net: fec_ptp: Use platform_get_irq_xxx_optional() to avoid
  error message (bsc#1161695).
- net: fec_main: Use platform_get_irq_byname_optional() to avoid
  error message (bsc#1161695).
- commit 7080d97
* Wed Apr 22 2020 tiwai@suse.de
- irqchip/mbigen: Free msi_desc on device teardown (git-fixes).
- i2c: altera: use proper variable to hold errno (git-fixes).
- i2c: designware: platdrv: Remove DPM_FLAG_SMART_SUSPEND flag
  on BYT and CHT (git-fixes).
- drm/amd/powerplay: force the trim of the mclk dpm_levels if
  OD is enabled (git-fixes).
- watchdog: sp805: fix restart handler (git-fixes).
- mac80211: fix race in ieee80211_register_hw() (git-fixes).
- mac80211_hwsim: Use kstrndup() in place of kasprintf()
  (git-fixes).
- commit 158e556
* Wed Apr 22 2020 tiwai@suse.de
- Revert ACPI EC patch that was reverted in stable tree
  Delete:
  patches.suse/ACPI-EC-Do-not-clear-boot_ec_is_ecdt-in-acpi_ec_add.patch.
- commit 4ca2cd1
* Wed Apr 22 2020 mbenes@suse.cz
- objtool: Make BP scratch register warning more robust
  (bsc#1169514).
- commit 21d4b08
* Wed Apr 22 2020 mbenes@suse.cz
- objtool: Fix switch table detection in .text.unlikely
  (bsc#1169514).
- commit c2b49a3
* Wed Apr 22 2020 tbogendoerfer@suse.de
- ionic: fix unused assignment (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: add dynamic_debug header (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- commit 61e55e9
* Wed Apr 22 2020 tbogendoerfer@suse.de
- net/mlx5e: Fix nest_level for vlan pop action (bsc#1154353).
- ionic: set station addr only if needed (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: replay filters after fw upgrade (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- net: icmp6: do not select saddr from iif when route has prefsrc
  set (bsc#1154353).
- commit da058f0
* Tue Apr 21 2020 oneukum@suse.com
- PCI: endpoint: Fix for concurrent memory allocation in OB
  address region (git-fixes).
- commit efb90c5
* Tue Apr 21 2020 oneukum@suse.com
- mmc: sdhci-of-at91: fix memleak on clk_get failure (git-fixes).
- commit df10885
* Tue Apr 21 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/ext4-Avoid-freeing-inodes-on-dirty-list.patch
  patches.suse/fs-Avoid-leaving-freed-inode-on-dirty-list.patch
  patches.suse/writeback-Export-inode_io_list_del.patch
- commit 9d7a667
* Tue Apr 21 2020 nstange@suse.de
- icmp: allow icmpv6_ndo_send to work with CONFIG_IPV6=n
  (bsc#1169021 jsc#SLE-12250).
- commit 8129fee
* Tue Apr 21 2020 nstange@suse.de
- crypto: arm64/poly1305 - ignore build files (bsc#1169021
  jsc#SLE-12250).
- commit 5860f7d
* Tue Apr 21 2020 tiwai@suse.de
- Update references for ptp security fixes (CVE-2020-10690, bsc#1170056)
- commit 0efc222
* Tue Apr 21 2020 oneukum@suse.com
- padata: always acquire cpu_hotplug_lock before pinst->lock
  (git-fixes).
- commit d5448e4
* Tue Apr 21 2020 oneukum@suse.com
- padata: validate cpumask without removed CPU during offline
  (git-fixes).
- commit e4437ab
* Tue Apr 21 2020 jack@suse.cz
- ext4: Avoid freeing inodes on dirty list (bsc#1168423).
- writeback: Export inode_io_list_del() (bsc#1168423).
- fs: Avoid leaving freed inode on dirty list (bsc#1168423).
- commit 86af897
* Tue Apr 21 2020 jslaby@suse.cz
- PCI: endpoint: Fix for concurrent memory allocation in OB
  address region (git-fixes).
- PCI: endpoint: Cast the page number to phys_addr_t (git-fixes).
- commit 3e58a3a
* Tue Apr 21 2020 mhocko@suse.com
- mm: set vm_next and vm_prev to NULL in vm_area_dup()
  (bnc#1169681).
- Revert "mm/rmap.c: reuse mergeable anon_vma as parent when fork"
  (bnc#1169681).
- commit f7b4d10
* Tue Apr 21 2020 glin@suse.com
- bpf: Prevent re-mmap()'ing BPF map as writable for initially
  r/o mapping (bsc#1155518).
- xsk: Fix out of boundary write in __xsk_rcv_memcpy
  (bsc#1155518).
- kbuild, btf: Fix dependencies for DEBUG_INFO_BTF (bsc#1155518).
- commit ac4792a
* Mon Apr 20 2020 nstange@suse.de
- wireguard: noise: error out precomputed DH during handshake
  rather than config (bsc#1169021 jsc#SLE-12250).
- commit e14e578
* Mon Apr 20 2020 nstange@suse.de
- wireguard: receive: remove dead code from default packet type
  case (bsc#1169021 jsc#SLE-12250).
- commit c43a23b
* Mon Apr 20 2020 nstange@suse.de
- wireguard: queueing: account for skb->protocol==0 (bsc#1169021
  jsc#SLE-12250).
- commit 9e6b83e
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: test using new 64-bit time_t (bsc#1169021
  jsc#SLE-12250).
- commit 60756ac
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: remove duplicated include <sys/types.h>
  (bsc#1169021 jsc#SLE-12250).
- commit b51ae0c
* Mon Apr 20 2020 nstange@suse.de
- wireguard: socket: remove extra call to synchronize_net
  (bsc#1169021 jsc#SLE-12250).
- commit 182535b
* Mon Apr 20 2020 nstange@suse.de
- wireguard: send: account for mtu=0 devices (bsc#1169021
  jsc#SLE-12250).
- commit 2f73731
* Mon Apr 20 2020 nstange@suse.de
- wireguard: receive: reset last_under_load to zero (bsc#1169021
  jsc#SLE-12250).
- commit 5207bec
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: reduce complexity and fix make races
  (bsc#1169021 jsc#SLE-12250).
- commit 9718224
* Mon Apr 20 2020 nstange@suse.de
- wireguard: device: use icmp_ndo_send helper (bsc#1169021
  jsc#SLE-12250).
- commit 76ba369
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: tie socket waiting to target pid
  (bsc#1169021 jsc#SLE-12250).
- commit bf1d7e5
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: cleanup CONFIG_ENABLE_WARN_DEPRECATED
  (bsc#1169021 jsc#SLE-12250).
- commit fe77b94
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: ensure non-addition of peers with failed
  precomputation (bsc#1169021 jsc#SLE-12250).
- commit ad7678e
* Mon Apr 20 2020 nstange@suse.de
- wireguard: noise: reject peers with low order public keys
  (bsc#1169021 jsc#SLE-12250).
- commit 8542988
* Mon Apr 20 2020 nstange@suse.de
- wireguard: allowedips: fix use-after-free in
  root_remove_peer_lists (bsc#1169021 jsc#SLE-12250).
- commit 2be5b62
* Mon Apr 20 2020 nstange@suse.de
- net: introduce skb_list_walk_safe for skb segment walking
  (bsc#1169021 jsc#SLE-12250).
- commit 1ec4578
* Mon Apr 20 2020 nstange@suse.de
- wireguard: socket: mark skbs as not on list when receiving
  via gro (bsc#1169021 jsc#SLE-12250).
- commit a45554a
* Mon Apr 20 2020 nstange@suse.de
- wireguard: queueing: do not account for pfmemalloc when clearing
  skb header (bsc#1169021 jsc#SLE-12250).
- commit dd22191
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: remove ancient kernel compatibility code
  (bsc#1169021 jsc#SLE-12250).
- commit e478c39
* Mon Apr 20 2020 nstange@suse.de
- wireguard: allowedips: use kfree_rcu() instead of call_rcu()
  (bsc#1169021 jsc#SLE-12250).
- commit 8c0e1e0
* Mon Apr 20 2020 nstange@suse.de
- wireguard: main: remove unused include <linux/version.h>
  (bsc#1169021 jsc#SLE-12250).
- commit 3a111bf
* Mon Apr 20 2020 nstange@suse.de
- wireguard: global: fix spelling mistakes in comments
  (bsc#1169021 jsc#SLE-12250).
- commit 79a082d
* Mon Apr 20 2020 mkubecek@suse.cz
- Update
  patches.suse/tcp-dccp-fix-possible-race-__inet_lookup_established.patch
  references (add bsc#1151794).
- commit 0f4b072
* Mon Apr 20 2020 colyli@suse.de
- block: Fix partition support for host aware zoned block devices
  (git fixes (block layer)).
- commit 2826707
* Mon Apr 20 2020 msuchanek@suse.de
- powerpc/sstep: Fix DS operand in ld encoding to appropriate
  value (bsc#1065729).
- commit ffe7728
* Mon Apr 20 2020 colyli@suse.de
- block: fix busy device checking in blk_drop_partitions again
  (git fixes (block layer)).
- scsi: sd_sbc: Fix sd_zbc_report_zones() (git fixes (block
  layer)).
- block: allow partitions on host aware zone devices (git fixes
  (block layer)).
- block: refactor rescan_partitions (bsc#1169493).
- null_blk: Fix zoned command return code (git fixes (block
  layer)).
- commit 2eec3ac
* Mon Apr 20 2020 tabraham@suse.com
- EDAC: skx_common: downgrade message importance on missing PCI
  device (bsc#1165581).
- commit 33acab9
* Mon Apr 20 2020 colyli@suse.de
- rbd: call rbd_dev_unprobe() after unwatching and flushing
  notifies (git fixes (block layer)).
- commit b8a8f93
* Mon Apr 20 2020 colyli@suse.de
- rbd: avoid a deadlock on header_rwsem when flushing notifies
  (git fixes (block layer)).
- commit 39eb136
* Mon Apr 20 2020 colyli@suse.de
- block: fix busy device checking in blk_drop_partitions (git
  fixes (block layer)).
- commit a502c37
* Mon Apr 20 2020 mbenes@suse.cz
- tracing: Fix the race between registering 'snapshot' event
  trigger and triggering 'snapshot' operation (git-fixes).
- commit e9b7241
* Mon Apr 20 2020 colyli@suse.de
- dm writecache: add cond_resched to avoid CPU hangs (git fixes
  (block layer)).
- dm integrity: fix a crash with unusually large tag size (git
  fixes (block layer)).
- dm zoned: remove duplicate nr_rnd_zones increase in
  dmz_init_zone() (git fixes (block layer)).
- commit bae04d0
* Mon Apr 20 2020 colyli@suse.de
- Revert "bcache: ignore pending signals when creating gc and
  allocator thread" (git fixes (block layer)).
- commit 389cb15
* Mon Apr 20 2020 colyli@suse.de
- block: rework zone reporting (git fixes (block layer)).
- Refresh for the above change,
  patches.suse/dm-zoned-reduce-overhead-of-backing-device-checks.patch.
- commit e2e1ac1
* Mon Apr 20 2020 mbenes@suse.cz
- tracing: Disable trace_printk() on post poned tests (git-fixes).
- commit a1f20fd
* Mon Apr 20 2020 colyli@suse.de
- null_blk: clean up report zones (git fixes (block layer)).
- null_blk: clean up the block device operations (git fixes
  (block layer)).
- block: Remove partition support for zoned block devices (git
  fixes (block layer)).
- commit 47f4ca0
* Mon Apr 20 2020 colyli@suse.de
- block: Simplify report zones execution (git fixes (block
  layer)).
- block: cleanup the !zoned case in blk_revalidate_disk_zones
  (git fixes (block layer)).
- block: Enhance blk_revalidate_disk_zones() (git fixes (block
  layer)).
- block: add zone open, close and finish operations (git fixes
  (block layer)).
- commit c73ea39
* Mon Apr 20 2020 colyli@suse.de
- block: Simplify REQ_OP_ZONE_RESET_ALL handling (git fixes
  (block layer)).
- block: Remove REQ_OP_ZONE_RESET plugging (git fixes (block
  layer)).
- commit 1d004e0
* Mon Apr 20 2020 colyli@suse.de
- dm: make dm_table_find_target return NULL (git fixes (block
  layer)).
- null_blk: fix inline misuse (git fixes (block layer)).
- null_blk: create a helper for zoned devices (git fixes
  (block layer)).
- null_blk: move duplicate code to callers (git fixes (block
  layer)).
- commit 9efd841
* Mon Apr 20 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/ibmvfc-don-t-send-implicit-logouts-prior-to-NPIV-log.patch
- commit cb5e73f
* Mon Apr 20 2020 neilb@suse.de
- fs/filesystems.c: downgrade user-reachable WARN_ONCE() to
  pr_warn_once() (bsc#1163463).
- commit 399801b
* Fri Apr 17 2020 tiwai@suse.de
- ALSA: hda: call runtime_allow() for all hda controllers
  (git-fixes).
- ALSA: hda: Explicitly permit using autosuspend if runtime PM
  is supported (git-fixes).
- ALSA: hda: Skip controller resume if not needed (git-fixes).
- ALSA: hda: Keep the controller initialization even if no codecs
  found (git-fixes).
- ALSA: hda: Release resources at error in delayed probe
  (git-fixes).
- ALSA: hda: Honor PM disablement in PM freeze and thaw_noirq ops
  (git-fixes).
- ALSA: hda: Don't release card at firmware loading error
  (git-fixes).
- ALSA: usb-audio: Check mapping at creating connector controls,
  too (git-fixes).
- ALSA: usb-audio: Don't create jack controls for PCM terminals
  (git-fixes).
- ALSA: usb-audio: Don't override ignore_ctl_error value from
  the map (git-fixes).
- ALSA: usb-audio: Filter error from connector kctl ops, too
  (git-fixes).
- ALSA: hda/realtek - Enable the headset mic on Asus FX505DT
  (git-fixes).
- commit 8a08089
* Fri Apr 17 2020 tiwai@suse.de
- arm, bpf: Fix offset overflow for BPF_MEM BPF_DW (git-fixes).
- nl80211: fix NL80211_ATTR_FTM_RESPONDER policy (git-fixes).
- net: phy: micrel: use genphy_read_status for KSZ9131
  (git-fixes).
- arm, bpf: Fix bugs with ALU64 {RSH, ARSH} BPF_K shift by 0
  (git-fixes).
- keys: Fix proc_keys_next to increase position index (git-fixes).
- drm/amdgpu: unify fw_write_wait for new gfx9 asics (git-fixes).
- libata: Return correct status in sata_pmp_eh_recover_pm()
  when ATA_DFLAG_DETACH is set (git-fixes).
- Input: i8042 - add Acer Aspire 5738z to nomux list (git-fixes).
- net: phy: micrel: kszphy_resume(): add delay after
  genphy_resume() before accessing PHY registers (git-fixes).
- vfio: platform: Switch to platform_get_irq_optional()
  (git-fixes).
- PCI: Add boot interrupt quirk mechanism for Xeon chipsets
  (git-fixes).
- ALSA: doc: Document PC Beep Hidden Register on Realtek ALC256
  (git-fixes).
- drm/scheduler: fix rare NULL ptr race (git-fixes).
- drm/dp_mst: Fix clearing payload state on topology disable
  (git-fixes).
- crypto: ccree - dec auth tag size from cryptlen map (git-fixes).
- crypto: ccree - only try to map auth tag if needed (git-fixes).
- crypto: ccree - protect against empty or NULL scatterlists
  (git-fixes).
- irqchip/gic-v4: Provide irq_retrigger to avoid circular locking
  dependency (git-fixes).
- ACPI: EC: Do not clear boot_ec_is_ecdt in acpi_ec_add()
  (git-fixes).
- acpi/x86: ignore unspecified bit positions in the ACPI global
  lock field (git-fixes).
- firmware: fix a double abort case with fw_load_sysfs_fallback
  (git-fixes).
- usb: dwc3: core: add support for disabling SS instances in
  park mode (git-fixes).
- xhci: bail out early if driver can't accress host in resume
  (git-fixes).
- media: venus: firmware: Ignore secure call error on first resume
  (git-fixes).
- media: allegro: fix type of gop_length in channel_create message
  (git-fixes).
- media: i2c: ov5695: Fix power on and off sequences (git-fixes).
- media: ti-vpe: cal: fix disable_irqs to only the intended target
  (git-fixes).
- media: venus: hfi_parser: Ignore HEVC encoding for V1
  (git-fixes).
- pstore/platform: fix potential mem leak if pstore_init_fs failed
  (git-fixes).
- tpm: Don't make log failures fatal (git-fixes).
- i2c: pca-platform: Use platform_irq_get_optional (git-fixes).
- i2c: st: fix missing struct parameter description (git-fixes).
- bus: sunxi-rsb: Return correct data when mixing 16-bit and
  8-bit reads (git-fixes).
- soc: fsl: dpio: register dpio irq handlers after dpio create
  (git-fixes).
- Input: tm2-touchkey - add support for Coreriver TC360 variant
  (git-fixes).
- i2c: jz4780: silence log flood on txabrt (git-fixes).
- mmc: sdhci-of-esdhc: fix esdhc_reset() for different controller
  versions (git-fixes).
- cpufreq: Cancel policy update work scheduled before freeing
  (git-fixes).
- commit e5ee52f
* Fri Apr 17 2020 ailiop@suse.com
- xfs: reflink should force the log out if mounted with wsync
  (git-fixes).
- commit 2e7b82b
* Fri Apr 17 2020 ailiop@suse.com
- xfs: factor out a new xfs_log_force_inode helper (git-fixes).
- commit 9fd128e
* Fri Apr 17 2020 ailiop@suse.com
- xfs: don't write a corrupt unmount record to force summary
  counter recalc (git-fixes).
- commit 6add31e
* Fri Apr 17 2020 ailiop@suse.com
- xfs: don't allow log IO to be throttled (git-fixes).
- commit 925e53f
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove some stale comments from the log code (git-fixes).
- commit b869987
* Fri Apr 17 2020 ailiop@suse.com
- xfs: refactor unmount record writing (git-fixes).
- commit 60c7c2f
* Fri Apr 17 2020 ailiop@suse.com
- xfs: merge xlog_commit_record with xlog_write_done (git-fixes).
- commit 6169e00
* Fri Apr 17 2020 ailiop@suse.com
- xfs: split xlog_ticket_done (git-fixes).
- commit 3540978
* Fri Apr 17 2020 ailiop@suse.com
- xfs: kill XLOG_TIC_INITED (git-fixes).
- commit 1c52baf
* Fri Apr 17 2020 ailiop@suse.com
- xfs: refactor and split xfs_log_done() (git-fixes).
- commit 27f5afa
* Fri Apr 17 2020 ailiop@suse.com
- xfs: re-order initial space accounting checks in xlog_write
  (git-fixes).
- commit d2e492c
* Fri Apr 17 2020 ailiop@suse.com
- xfs: don't try to write a start record into every iclog
  (git-fixes).
- commit 62148c3
* Fri Apr 17 2020 ailiop@suse.com
- xfs: shutdown on failure to add page to log bio (git-fixes).
- commit cb7737c
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove xlog_state_want_sync (git-fixes).
- commit 99f092d
* Fri Apr 17 2020 ailiop@suse.com
- xfs: move the ioerror check out of xlog_state_clean_iclog
  (git-fixes).
- commit f23116d
* Fri Apr 17 2020 ailiop@suse.com
- xfs: refactor xlog_state_clean_iclog (git-fixes).
- commit e43b3ed
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove the aborted parameter to xlog_state_done_syncing
  (git-fixes).
- commit eaff4cc
* Fri Apr 17 2020 ailiop@suse.com
- xfs: simplify log shutdown checking in xfs_log_release_iclog
  (git-fixes).
- commit d486a9f
* Fri Apr 17 2020 ailiop@suse.com
- xfs: simplify the xfs_log_release_iclog calling convention
  (git-fixes).
- commit 5b62921
* Fri Apr 17 2020 ailiop@suse.com
- xfs: factor out a xlog_wait_on_iclog helper (git-fixes).
- commit 371f1e3
* Fri Apr 17 2020 ailiop@suse.com
- xfs: merge xlog_cil_push into xlog_cil_push_work (git-fixes).
- commit 22531f1
* Fri Apr 17 2020 ailiop@suse.com
- xfs: cleanup xfs_log_unmount_write (git-fixes).
- commit 47964dc
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove dead code from xfs_log_unmount_write (git-fixes).
- commit 15d084c
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove the unused return value from xfs_log_unmount_write
  (git-fixes).
- commit 7daf110
* Fri Apr 17 2020 ailiop@suse.com
- xfs: don't ever return a stale pointer from __xfs_dir3_free_read
  (git-fixes).
- commit e98d8e7
* Fri Apr 17 2020 ailiop@suse.com
- xfs: fix buffer corruption reporting when
  xfs_dir3_free_header_check fails (git-fixes).
- commit 0d51de1
* Fri Apr 17 2020 ailiop@suse.com
- xfs: add a function to deal with corrupt buffers post-verifiers
  (git-fixes).
- commit cdad8b5
* Fri Apr 17 2020 ailiop@suse.com
- xfs: fix iclog release error check race with shutdown
  (git-fixes).
- commit 2814941
* Fri Apr 17 2020 ailiop@suse.com
- xfs: don't check for AG deadlock for realtime files in bunmapi
  (git-fixes).
- commit fc993c5
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove the XLOG_STATE_DO_CALLBACK state (git-fixes).
- commit c72277f
* Fri Apr 17 2020 ailiop@suse.com
- xfs: turn ic_state into an enum (git-fixes).
- commit 1f9b2d3
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove the unused XLOG_STATE_ALL and XLOG_STATE_UNUSED
  flags (git-fixes).
- commit 22ec56e
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove dead ifdef XFSERRORDEBUG code (git-fixes).
- commit f73533e
* Fri Apr 17 2020 ailiop@suse.com
- xfs: call xlog_state_release_iclog with l_icloglock held
  (git-fixes).
- commit e2ae7c9
* Fri Apr 17 2020 ailiop@suse.com
- xfs: move the locking from xlog_state_finish_copy to the callers
  (git-fixes).
- commit 4fc8e18
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove the unused ic_io_size field from xlog_in_core
  (git-fixes).
- commit cc60ace
* Fri Apr 17 2020 ailiop@suse.com
- xfs: pass the correct flag to xlog_write_iclog (git-fixes).
- commit d0ba340
* Thu Apr 16 2020 mbenes@suse.cz
- x86/xen: fix booting 32-bit pv guest (bsc#1071995).
- commit de745ab
* Thu Apr 16 2020 mbenes@suse.cz
- x86/xen: Make the secondary CPU idle tasks reliable
  (bsc#1071995).
- commit b937a33
* Thu Apr 16 2020 mbenes@suse.cz
- x86/xen: Make the boot CPU idle task reliable (bsc#1071995).
- commit 7555345
* Thu Apr 16 2020 oneukum@suse.com
- Update
  patches.suse/media-stv06xx-add-missing-descriptor-sanity-checks.patch
  (bsc#1168854). Pending CVE request, adding bsc so that it is not lost
- commit 3e4aa5f
* Thu Apr 16 2020 oneukum@suse.com
- Update
  patches.suse/media-xirlink_cit-add-missing-descriptor-sanity-chec.patch
  (bsc#1168952). Pending CVE request, adding bsc so this is not lost.
- commit 98ac2ff
* Thu Apr 16 2020 msuchanek@suse.de
- tools/test/nvdimm: Fix out of tree build (bsc#1156395).
- commit bec0a07
* Thu Apr 16 2020 msuchanek@suse.de
- Refresh patches.suse/tools-testing-nvdimm-Fix-compilation-failure-without.patch.
- commit 48bddf2
* Thu Apr 16 2020 msuchanek@suse.de
- ibmvfc: don't send implicit logouts prior to NPIV login
  (bsc#1169625 ltc#184611).
- commit 1026f14
* Thu Apr 16 2020 jslaby@suse.cz
- net: systemport: fix index check to avoid an array out of
  bounds access (networking-stable-20_03_14).
- taprio: Fix sending packets without dequeueing them
  (networking-stable-20_03_14).
- net: memcg: fix lockdep splat in inet_csk_accept()
  (networking-stable-20_03_14).
- net: dsa: Don't instantiate phylink for CPU/DSA ports unless
  needed (networking-stable-20_03_14).
- net/packet: tpacket_rcv: do not increment ring index on drop
  (networking-stable-20_03_14).
- net: fec: validate the new settings in fec_enet_set_coalesce()
  (networking-stable-20_03_14).
- net: macsec: update SCI upon MAC address change
  (networking-stable-20_03_14).
- ipv6/addrconf: call ipv6_mc_up() for non-Ethernet interface
  (networking-stable-20_03_14).
- net: memcg: late association of sock to memcg
  (networking-stable-20_03_14).
- ipvlan: do not use cond_resched_rcu() in
  ipvlan_process_multicast() (networking-stable-20_03_14).
- cgroup, netclassid: periodically release file_lock on classid
  updating (networking-stable-20_03_14).
- ipvlan: add cond_resched_rcu() while processing muticast backlog
  (networking-stable-20_03_14).
- ipvlan: don't deref eth hdr before checking it's set
  (networking-stable-20_03_14).
- sfc: detach from cb_page in efx_copy_channel()
  (networking-stable-20_03_14).
- inet_diag: return classid for all socket types
  (networking-stable-20_03_14).
- net: stmmac: dwmac1000: Disable ACS if enhanced descs are not
  used (networking-stable-20_03_14).
- gre: fix uninit-value in __iptunnel_pull_header
  (networking-stable-20_03_14).
- bonding/alb: make sure arp header is pulled before accessing it
  (networking-stable-20_03_14).
- net: nfc: fix bounds checking bugs on "pipe"
  (networking-stable-20_03_14).
- net: hns3: fix a not link up issue when fibre port supports
  autoneg (networking-stable-20_03_14).
- slip: make slhc_compress() more robust against malicious packets
  (networking-stable-20_03_14).
- net: dsa: fix phylink_start()/phylink_stop() calls
  (networking-stable-20_03_14).
- selftests/net/fib_tests: update addr_metric_test for peer
  route testing (networking-stable-20_03_14).
- net/ipv6: remove the old peer route if change it to a new one
  (networking-stable-20_03_14).
- net/ipv6: need update peer route when modify metric
  (networking-stable-20_03_14).
- net: taprio: add missing attribute validation for txtime delay
  (networking-stable-20_03_14).
- net: fq: add missing attribute validation for orphan mask
  (networking-stable-20_03_14).
- fib: add missing attribute validation for tun_id
  (networking-stable-20_03_14).
- devlink: validate length of region addr/len
  (networking-stable-20_03_14).
- devlink: validate length of param values
  (networking-stable-20_03_14).
- net/ipv6: use configured metric when add peer route
  (networking-stable-20_03_14).
- net: dsa: mv88e6xxx: fix lockup on warm boot
  (networking-stable-20_03_14).
- netlink: Use netlink header as base to calculate bad attribute
  offset (networking-stable-20_03_14).
- r8152: check disconnect status after long sleep
  (networking-stable-20_03_14).
- commit 4f8bc32
* Wed Apr 15 2020 ddiss@suse.de
- patches.suse/0005-scsi-target-use-the-stack-for-XCOPY-passthrough-cmds.patch:
  (bsc#1164514).
- patches.suse/0004-scsi-target-increase-XCOPY-I-O-size.patch:
  (bsc#1164514).
- patches.suse/0003-scsi-target-avoid-per-loop-XCOPY-buffer-allocations.patch:
  (bsc#1164514).
- patches.suse/0002-scsi-target-drop-xcopy-DISK-BLOCK-LENGTH-debug.patch:
  (bsc#1164514).
- patches.suse/0001-scsi-target-use-define-for-xcopy-descriptor-len.patch:
  (bsc#1164514).
- commit 35bd511
* Wed Apr 15 2020 jroedel@suse.de
- PCI/AER: Rationalize error status register clearing
  (bsc#1169263).
- PCI/DPC: Expose dpc_process_error(), dpc_reset_link() for use
  by EDR (bsc#1169263).
- PCI/AER: Add pci_aer_raw_clear_status() to unconditionally
  clear Error Status (bsc#1169263).
- PCI/DPC: Cache DPC capabilities in pci_init_capabilities()
  (bsc#1169263).
- PCI/ERR: Return status of pcie_do_recovery() (bsc#1169263).
- PCI/ERR: Remove service dependency in pcie_do_recovery()
  (bsc#1169263).
- PCI/DPC: Move DPC data into struct pci_dev (bsc#1169263).
- commit 01b5293
* Wed Apr 15 2020 bp@suse.de
- x86/microcode/AMD: Increase microcode PATCH_MAX_SIZE
  (bsc#1169005).
- commit 92271b2
* Wed Apr 15 2020 aaptel@suse.com
- Refresh
  patches.suse/cifs-ignore-cached-share-root-handle-closing-errors.patch.
- commit c6f232e
* Wed Apr 15 2020 ptesarik@suse.cz
- s390/zcrypt: use kvmalloc instead of kmalloc for 256k alloc
  (bsc#1169003 LTC#185029).
- commit efd0cc2
* Wed Apr 15 2020 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix H_CEDE return code for nested guests
  (bsc#1156395).
- commit 30499af
* Wed Apr 15 2020 mkubecek@suse.cz
- update patches metadata
- update upstream references and resort:
  patches.suse/nvme-fc-Revert-add-module-to-ops-template-to-allow-m.patch
  patches.suse/nvme-fcloop-fix-deallocation-of-working-context.patch
  patches.suse/nvme-fix-deadlock-caused-by-ANA-update-wrong-locking.patch
  patches.suse/nvme-inherit-stable-pages-constraint-in-the-mpath-st.patch
  patches.suse/nvme-rdma-Replace-comma-with-a-semicolon.patch
  patches.suse/nvmet-fc-fix-typo-in-comment.patch
  patches.suse/nvmet-fix-NULL-dereference-when-removing-a-referral.patch
  patches.suse/nvmet-rdma-fix-bonding-failover-possible-NULL-deref.patch
- fix Patch-mainline:
  patches.suse/nvme-Check-for-readiness-more-quickly-to-speed-up-bo.patch
  patches.suse/nvme-code-cleanup-nvme_identify_ns_desc.patch
  patches.suse/nvme-fabrics-Use-scnprintf-for-avoiding-potential-bu.patch
  patches.suse/nvme-log-additional-message-for-controller-status.patch
  patches.suse/nvme-multipath-do-not-reset-on-unknown-status.patch
  patches.suse/nvme-remove-unused-return-code-from-nvme_alloc_ns.patch
  patches.suse/nvme-tcp-Set-SO_PRIORITY-for-all-host-sockets.patch
  patches.suse/nvmet-check-sscanf-value-for-subsys-serial-attr.patch
  patches.suse/nvmet-configfs-code-cleanup.patch
  patches.suse/nvmet-make-ctrl-id-configurable.patch
  patches.suse/nvmet-make-ctrl-model-configurable.patch
  patches.suse/nvmet-tcp-set-SO_PRIORITY-for-accepted-sockets.patch
- commit 66e0350
* Wed Apr 15 2020 yousaf.kaukab@suse.com
- Revert "cpufreq: arm64: prevent module unload (bsc#1168476)."
  This reverts commit 59dc6e32df1940481a3955a2caf2e64f735a0831.
- commit c363644
* Wed Apr 15 2020 msuchanek@suse.de
- rpm/check-for-config-changes: Ignore CONFIG_LD_VERSION
- commit e60242e
* Wed Apr 15 2020 jslaby@suse.cz
- udp: rehash on disconnect (networking-stable-20_03_01).
- net/tls: Fix to avoid gettig invalid tls record
  (networking-stable-20_03_01).
- Revert "net: dev: introduce support for sch BYPASS for lockless
  qdisc" (networking-stable-20_03_01).
- qede: Fix race between rdma destroy workqueue and link change
  event (networking-stable-20_03_01).
- sctp: move the format error check out of __sctp_sf_do_9_1_abort
  (networking-stable-20_03_01).
- net: sched: correct flower port blocking
  (networking-stable-20_03_01).
- net: dsa: b53: Ensure the default VID is untagged
  (networking-stable-20_03_01).
- net: macb: ensure interface is not suspended on at91rm9200
  (networking-stable-20_03_01).
- net: fib_rules: Correctly set table field when table number
  exceeds 8 bits (networking-stable-20_03_01).
- ipv6: Fix nlmsg_flags when splitting a multipath route
  (networking-stable-20_03_01).
- ipv6: Fix route replacement with dev-only route
  (networking-stable-20_03_01).
- commit 7f4f9c7
* Wed Apr 15 2020 ggherdovich@suse.cz
- x86, sched: Don't enable static key when starting secondary CPUs
  (bsc#1169518).
- commit 7e982dc
* Wed Apr 15 2020 yousaf.kaukab@suse.com
- thermal/drivers/cpufreq_cooling: Fix return of
  cpufreq_set_cur_state (bsc#1168476).
- commit 1bb91ae
* Wed Apr 15 2020 bp@suse.de
- EDAC/mce_amd: Make fam_ops static global (jsc#SLE-11833).
- commit a2a7430
* Wed Apr 15 2020 mkoutny@suse.com
- cgroup: cgroup_procs_next should increase position index
  (bsc#1169524).
- commit e8538bb
* Wed Apr 15 2020 mbenes@suse.cz
- btrfs: separate definition of assertion failure handlers
  (bsc#1169514).
- commit 47cc410
* Wed Apr 15 2020 mbenes@suse.cz
- objtool: Add relocation check for alternative sections
  (bsc#1169514).
- commit ddcfb2d
* Wed Apr 15 2020 ggherdovich@suse.cz
- Refresh
  patches.suse/x86-sched-Account-for-CPUs-with-less-than-4-cores-in.patch.
- commit fe74002
* Wed Apr 15 2020 mbenes@suse.cz
- objtool: Add is_static_jump() helper (bsc#1169514).
- commit d3f8210
* Wed Apr 15 2020 jslaby@suse.cz
- selftests/powerpc: Turn off timeout setting for benchmarks,
  dscr, signal, tm (git-fixes).
- selftests/powerpc: Add tlbie_test in .gitignore (git-fixes).
- tools: gpio: Fix out-of-tree build regression (git-fixes).
- commit 32ce8b5
* Wed Apr 15 2020 bp@suse.de
- EDAC/amd64: Drop some family checks for newer systems
  (jsc#SLE-11833).
- commit c3845bc
* Wed Apr 15 2020 yousaf.kaukab@suse.com
- ahci: Add support for Amazon's Annapurna Labs SATA controller
  (bsc#1169013).
- commit 4296517
* Wed Apr 15 2020 jslaby@suse.cz
- blacklist.conf: add three cleanups
- commit cf5b455
* Wed Apr 15 2020 bp@suse.de
- EDAC/amd64: Add family ops for Family 19h Models 00h-0Fh
  (jsc#SLE-11833).
- commit 6188ac8
* Wed Apr 15 2020 jslaby@suse.cz
- PCI: dwc: Fix dw_pcie_ep_raise_msix_irq() to get correct MSI-X
  table address (git-fixes).
- PCI: endpoint: Fix ->set_msix() to take BIR and offset as
  arguments (git-fixes).
- commit c6334e6
* Wed Apr 15 2020 tzimmermann@suse.de
- fbmem: Adjust indentation in fb_prepare_logo and fb_blank (bsc#1152489)
- commit bcb3d94
* Wed Apr 15 2020 mkubecek@suse.cz
- config: refresh
  No functional change, only menu structure comments and one line move.
- commit cbac380
* Wed Apr 15 2020 tbogendoerfer@suse.de
- cxgb4: free MQPRIO resources in shutdown path (jsc#SLE-8389).
- RDMA/hns: Fix a wrong judgment of return value (jsc#SLE-8449).
- RDMA/hns: Fix wrong judgments of udata->outlen (jsc#SLE-8449).
- RDMA/core: Remove the duplicate header file (jsc#SLE-8449).
- IB/mlx5: Optimize u64 division on 32-bit arches (jsc#SLE-8446).
- RDMA/mlx5: Prevent UMR usage with RO only when we have RO caps
  (jsc#SLE-8446).
- net: hns3: fix for fraglist SKB headlen not handling correctly
  (bsc#1154353).
- net: hns3: drop the WQ_MEM_RECLAIM flag when allocating WQ
  (bsc#1154353).
- selftests/bpf: Fix test_progs's parsing of test numbers
  (bsc#1154353).
- bnxt_en: Fix "fw.mgmt" and "fw.nsci" info via devlink info_get
  cb (jsc#SLE-8371 bsc#1153274).
- taprio: do not use BIT() in TCA_TAPRIO_ATTR_FLAG_* definitions
  (bsc#1154353).
- sfc: fix XDP-redirect in this driver (jsc#SLE-8314).
- libbpf: Ignore incompatible types with matching name during
  CO-RE relocation (bsc#1154353).
- sfc: remove unused variable 'efx_default_channel_type'
  (jsc#SLE-8314).
- commit 655c6cc
* Wed Apr 15 2020 tzimmermann@suse.de
- OMAP: DSS2: remove non-zero check on variable r (bsc#1152489)
- commit 82ee31e
* Wed Apr 15 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline ("Queued" is for patches going to get into mainline):
  patches.suse/drm-i915-Fix-ref-mutex-deadlock-in-i915_active_wait.patch
- commit f1086d5
* Wed Apr 15 2020 mkubecek@suse.cz
- supported.conf: cleanup
  Make the comment consistent with the rest of the file.
- commit c905a51
* Wed Apr 15 2020 bp@suse.de
- EDAC/mce_amd: Always load on SMCA systems (jsc#SLE-11833).
- commit f330d60
* Wed Apr 15 2020 mkubecek@suse.cz
- improve patch metadata
- make Patch-mainline more explicit:
  patches.suse/bfq-tune-slice-idle.patch
- commit 6fb07af
* Wed Apr 15 2020 jslaby@suse.cz
- Refresh
  patches.suse/0001-efi-fix-a-race-and-a-buffer-overflow-while-reading-e.patch.
  One more update on an upstreamed patch.
- commit 0bed50c
* Wed Apr 15 2020 jslaby@suse.cz
- Refresh
  patches.suse/KEYS-reaching-the-keys-quotas-correctly.patch.
- Refresh
  patches.suse/PCI-pciehp-Add-DMI-table-for-in-band-presence-detect.patch.
- Refresh
  patches.suse/PCI-pciehp-Disable-in-band-presence-detect-when-poss.patch.
- Refresh
  patches.suse/PCI-pciehp-Wait-for-PDS-if-in-band-presence-is-disab.patch.
- Refresh
  patches.suse/edac-mc-carve-out-error-increment-into-a-separate-function.patch.
- Refresh
  patches.suse/edac-mc-change-mci-device-removal-to-use-put_device.patch.
- Refresh
  patches.suse/edac-mc-determine-mci-pointer-from-the-error-descriptor.patch.
- Refresh
  patches.suse/edac-mc-pass-the-error-descriptor-to-error-reporting-functions.patch.
- Refresh
  patches.suse/edac-mc-remove-detail-string-and-cleanup-error-string-generation.patch.
- Refresh
  patches.suse/edac-mc-remove-enable_per_layer_report-function-argument.patch.
- Refresh patches.suse/edac-mc-remove-per-layer-counters.patch.
- Refresh
  patches.suse/edac-mc-reorder-functions-edac_mc_alloc.patch.
- Refresh
  patches.suse/edac-mc-report-unknown-memory-on-too-many-dimm-labels-found.patch.
- Refresh
  patches.suse/edac-mc-split-edac_mc_alloc-into-smaller-functions.patch.
- Refresh
  patches.suse/edac-store-error-type-in-struct-edac_raw_error_desc.patch.
- Refresh
  patches.suse/efi-x86-add-tpm-related-efi-tables-to-unencrypted-mapping-checks.patch.
- Refresh
  patches.suse/x86-amd_nb-char-amd64-agp-use-amd_nb_num-accessor.patch.
- Refresh
  patches.suse/x86-intel_pstate-Handle-runtime-turbo-disablement-en.patch.
- Refresh
  patches.suse/x86-sched-Add-support-for-frequency-invariance-on-ATOM.patch.
- Refresh
  patches.suse/x86-sched-Add-support-for-frequency-invariance-on-ATOM_GOLDMONT.patch.
- Refresh
  patches.suse/x86-sched-Add-support-for-frequency-invariance-on-SK.patch.
- Refresh
  patches.suse/x86-sched-Add-support-for-frequency-invariance-on-XE.patch.
- Refresh
  patches.suse/x86-sched-Add-support-for-frequency-invariance.patch.
  Update upstream status and sort them all.
- commit 6e97756
* Tue Apr 14 2020 bp@suse.de
- x86/amd_nb: Add Family 19h PCI IDs (jsc#SLE-11833).
- Refresh
  patches.suse/x86-amd_nb-char-amd64-agp-use-amd_nb_num-accessor.patch.
- commit ffdd1b6
* Tue Apr 14 2020 rgoldwyn@suse.com
- exfat: add Kconfig and Makefile (JSC#SLE-9489).
  Also changes config files and supported.conf to incorporate exfat
- exfat: add nls operations (JSC#SLE-9489).
- exfat: add misc operations (JSC#SLE-9489).
- exfat: add exfat cache (JSC#SLE-9489).
- exfat: add bitmap operations (JSC#SLE-9489).
- exfat: add fat entry operations (JSC#SLE-9489).
- exfat: add file operations (JSC#SLE-9489).
- exfat: add directory operations (JSC#SLE-9489).
- exfat: add inode operations (JSC#SLE-9489).
- exfat: add super block operations (JSC#SLE-9489).
- exfat: add in-memory and on-disk structures and headers
  (JSC#SLE-9489).
- vfs: Create fs_context-aware mount_bdev() replacement
  (JSC#SLE-9489).
- commit 3b40335
* Tue Apr 14 2020 lhenriques@suse.com
- ceph: fix snapshot directory timestamps (jsc#SES-1134).
- ceph: wait for async creating inode before requesting new max
  size (jsc#SES-1134).
- ceph: don't skip updating wanted caps when cap is stale
  (jsc#SES-1134).
- ceph: request new max size only when there is auth cap
  (jsc#SES-1134).
- ceph: cleanup return error of try_get_cap_refs() (jsc#SES-1134).
- ceph: return ceph_mdsc_do_request() errors from __get_parent()
  (jsc#SES-1134).
- ceph: check all mds' caps after page writeback (jsc#SES-1134).
- ceph: update i_requested_max_size only when sending cap msg
  to auth mds (jsc#SES-1134).
- ceph: simplify calling of ceph_get_fmode() (jsc#SES-1134).
- ceph: remove delay check logic from ceph_check_caps()
  (jsc#SES-1134).
- ceph: consider inode's last read/write when calculating wanted
  caps (jsc#SES-1134).
- ceph: always renew caps if mds_wanted is insufficient
  (jsc#SES-1134).
- ceph: update dentry lease for async create (jsc#SES-1134).
- ceph: attempt to do async create when possible (jsc#SES-1134).
- ceph: cache layout in parent dir on first sync create
  (jsc#SES-1134).
- ceph: add new MDS req field to hold delegated inode number
  (jsc#SES-1134).
- ceph: decode interval_sets for delegated inos (jsc#SES-1134).
- ceph: make ceph_fill_inode non-static (jsc#SES-1134).
- ceph: perform asynchronous unlink if we have sufficient caps
  (jsc#SES-1134).
- ceph: don't take refs to want mask unless we have all bits
  (jsc#SES-1134).
- ceph: cap tracking for async directory operations
  (jsc#SES-1134).
- ceph: make __take_cap_refs non-static (jsc#SES-1134).
- ceph: add infrastructure for waiting for async create to
  complete (jsc#SES-1134).
- ceph: track primary dentry link (jsc#SES-1134).
- ceph: add flag to designate that a request is asynchronous
  (jsc#SES-1134).
- ceph: more caps.c lockdep assertions (jsc#SES-1134).
- ceph: clean up kick_flushing_inode_caps() (jsc#SES-1134).
- libceph: directly skip to the end of redirect reply
  (jsc#SES-1134).
- libceph: simplify ceph_monc_handle_map() (jsc#SES-1134).
- ceph: return ETIMEDOUT errno to userland when request timed out
  (jsc#SES-1134).
- ceph: re-org copy_file_range and fix some error paths
  (jsc#SES-1134).
- ceph: move to a dedicated slabcache for mds requests
  (jsc#SES-1134).
- ceph: reorganize fields in ceph_mds_request (jsc#SES-1134).
- ceph: replace zero-length array with flexible-array member
  (jsc#SES-1134).
- ceph: check if file lock exists before sending unlock request
  (jsc#SES-1134).
- ceph: move ceph_osdc_{read,write}pages to ceph.ko
  (jsc#SES-1134).
- ceph: don't ClearPageChecked in ceph_invalidatepage()
  (jsc#SES-1134).
- libceph: drop CEPH_DEFINE_SHOW_FUNC (jsc#SES-1134).
- ceph: check inode type for
  CEPH_CAP_FILE_{CACHE,RD,REXTEND,LAZYIO} (jsc#SES-1134).
- ceph: add refcounting for Fx caps (jsc#SES-1134).
- ceph: register MDS request with dir inode from the start
  (jsc#SES-1134).
- commit 5555f78
* Tue Apr 14 2020 jack@suse.cz
- bfq: Tune slice_idle (bsc#1168838).
- commit cd1f013
* Tue Apr 14 2020 oneukum@suse.com
- mt76: mt76x02: fix coverage_class type (git-fixes).
- commit 17e4f02
* Tue Apr 14 2020 oneukum@suse.com
- blacklist.conf: cosmetic change only
- commit c7bf43b
* Tue Apr 14 2020 oneukum@suse.com
- padata: fix uninitialized return value in padata_replace()
  (git-fixes).
- commit 3620d06
* Tue Apr 14 2020 msuchanek@suse.de
- Revert "powerpc/64: irq_work avoid interrupt when called with
  hardware irqs enabled" (bsc#1156395).
- commit 6d41ca5
* Tue Apr 14 2020 tiwai@suse.de
- drm/i915: Fix ref->mutex deadlock in i915_active_wait()
  (stable-5.4.y).
- commit 35b215a
* Tue Apr 14 2020 tiwai@suse.de
- drm/sun4i: dsi: Avoid hotplug race with DRM driver bind
  (git-fixes).
- commit 725ce8a
* Tue Apr 14 2020 tiwai@suse.de
- pwm: pca9685: Fix PWM/GPIO inter-operation (git-fixes).
- pwm: renesas-tpu: Fix late Runtime PM enablement (git-fixes).
- pwm: rcar: Fix late Runtime PM enablement (git-fixes).
- pwm: meson: Fix confusing indentation (git-fixes).
- pwm: bcm2835: Dynamically allocate base (git-fixes).
- ipmi: fix hung processes in __get_guid() (git-fixes).
- drm/i915/gem: Flush all the reloc_gpu batch (git-fixes).
- platform/chrome: cros_ec_rpmsg: Fix race with host event
  (git-fixes).
- acpi/nfit: improve bounds checking for 'func' (git-fixes).
- drm/sun4i: dsi: Allow binding the host without a panel
  (git-fixes).
- drm/sun4i: dsi: Use NULL to signify "no panel" (git-fixes).
- drm/sun4i: dsi: Remove unused drv from driver context
  (git-fixes).
- Bluetooth: RFCOMM: fix ODEBUG bug in rfcomm_dev_ioctl
  (git-fixes).
- commit 3034d25
* Tue Apr 14 2020 kbuild@suse.de
- Delete patches.kabi/* workarounds
- commit 70f1868
* Tue Apr 14 2020 mkubecek@suse.cz
- supported.conf: fix order of entries (sort)
- commit ead7ceb
* Tue Apr 14 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/scsi-lpfc-Change-default-SCSI-LUN-QD-to-64.patch
  patches.suse/scsi-lpfc-Fix-crash-after-handling-a-pci-error.patch
  patches.suse/scsi-lpfc-Fix-crash-in-target-side-cable-pulls-hitti.patch
  patches.suse/scsi-lpfc-Fix-erroneous-cpu-limit-of-128-on-I-O-stat.patch
  patches.suse/scsi-lpfc-Fix-kasan-slab-out-of-bounds-error-in-lpfc.patch
  patches.suse/scsi-lpfc-Fix-lockdep-error-register-non-static-key.patch
  patches.suse/scsi-lpfc-Fix-lpfc-overwrite-of-sg_cnt-field-in-nvme.patch
  patches.suse/scsi-lpfc-Fix-scsi-host-template-for-SLI3-vports.patch
  patches.suse/scsi-lpfc-Fix-update-of-wq-consumer-index-in-lpfc_sl.patch
  patches.suse/scsi-lpfc-Make-debugfs-ktime-stats-generic-for-NVME-.patch
  patches.suse/scsi-lpfc-Remove-prototype-FIPS-DSS-options-from-SLI.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.0.patch
- commit 8c32594
* Tue Apr 14 2020 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section:
  patches.suse/cifs-ignore-cached-share-root-handle-closing-errors.patch
- commit d749c1b
* Tue Apr 14 2020 jgross@suse.com
- xen/blkfront: fix memory allocation flags in
  blkfront_setup_indirect() (bsc#1168486).
- commit 97066fb
* Mon Apr 13 2020 dbueso@suse.de
- time/namespace: Add max_time_namespaces ucount (bsc#1164648,jsc#SLE-11493).
- commit 15be678
* Mon Apr 13 2020 colyli@suse.de
- blacklist.conf: add following commits, disable them temporarily,
  a4a8d286586d4b28c8517a51db8d86954aadc74b
  3918e0667bbac99400b44fa5aef3f8be2eeada4a
  When add them back when dm back port done.
- commit 23511fe
* Mon Apr 13 2020 colyli@suse.de
- lib/raid6/test: fix build on distros whose /bin/sh is not bash
  (git fixes (block layer)).
- Revert "dm: always call blk_queue_split() in dm_process_bio()"
  (git fixes (block layer)).
- coresight: do not use the BIT() macro in the UAPI header
  (git fixes (block layer)).
- pid: Improve the comment about waiting in zap_pid_ns_processes
  (git fixes (block layer)).
- dm verity fec: fix memory leak in verity_fec_dtr (git fixes
  (block layer)).
- null_blk: Fix the null_add_dev() error path (git fixes
  (block layer)).
- blk-mq: Keep set->nr_hw_queues and set->map[].nr_queues in sync
  (git fixes (block layer)).
- dm: fix congested_fn for request-based device (git fixes
  (block layer)).
- dm zoned: Fix reference counter initial value of chunk works
  (git fixes (block layer)).
- dm writecache: verify watermark during resume (git fixes
  (block layer)).
- dm: report suspended device during destroy (git fixes (block
  layer)).
- dm cache: fix a crash due to incorrect work item cancelling
  (git fixes (block layer)).
- dm integrity: fix invalid table returned due to argument count
  mismatch (git fixes (block layer)).
- dm integrity: fix a deadlock due to offloading to an incorrect
  workqueue (git fixes (block layer)).
- dm integrity: fix recalculation when moving from journal mode
  to bitmap mode (git fixes (block layer)).
- lib/stackdepot.c: fix global out-of-bounds in stack_slabs
  (git fixes (block layer)).
- drivers/block/zram/zram_drv.c: fix error return codes not
  being returned in writeback_store (git fixes (block layer)).
- dm: fix potential for q->make_request_fn NULL pointer (git fixes
  (block layer)).
- dm thin metadata: use pool locking at end of
  dm_pool_metadata_close (git fixes (block layer)).
- dm writecache: fix incorrect flush sequence when doing SSD
  mode commit (git fixes (block layer)).
- dm crypt: fix benbi IV constructor crash if used in
  authenticated mode (git fixes (block layer)).
- dm space map common: fix to ensure new block isn't already in
  use (git fixes (block layer)).
- dm zoned: support zone sizes smaller than 128MiB (git fixes
  (block layer)).
- padata: update documentation (git fixes (block layer)).
- block: fix an integer overflow in logical block size (git fixes
  (block layer)).
- compat_ioctl: block: handle Persistent Reservations (git fixes
  (block layer)).
- dm thin: Flush data device before committing metadata (git fixes
  (block layer)).
- dm thin metadata: Add support for a pre-commit callback (git
  fixes (block layer)).
- dm btree: increase rebalance threshold in __rebalance2()
  (git fixes (block layer)).
- dm mpath: remove harmful bio-based optimization (git fixes
  (block layer)).
- block: fix memleak of bio integrity data (git fixes (block
  layer)).
- block: sed-opal: fix sparse warning: convert __be64 data
  (git fixes (block layer)).
- block: sed-opal: fix sparse warning: obsolete array init
  (git fixes (block layer)).
- commit 7a0b356
* Sun Apr 12 2020 mkubecek@suse.cz
- constrants: fix malformed XML
  Closing tag of an element is "</foo>", not "<foo/>".
  Fixes: 8b37de2eb835 ("rpm/constraints.in: Increase memory for kernel-docs")
- commit 4a8ca28
* Sun Apr 12 2020 tiwai@suse.de
- Refresh patches.suse/ALSA-pcm-oss-Fix-regression-by-buffer-overflow-fix-a.patch
  Mark the upstream commit id to be ignored; the chery-picked patch supercedes it
- commit 5705a3a
* Sat Apr 11 2020 tiwai@suse.de
- ASoC: cs4270: pull reset GPIO low then high (git-fixes).
- ASoC: rt5645: Add platform-data for Medion E1239T (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for MPMAN MPWIN895CL tablet
  (git-fixes).
- ASoC: Intel: atom: Fix uninitialized variable compiler warning
  (git-fixes).
- ASoC: Intel: atom: Check drv->lock is locked in
  sst_fill_and_send_cmd_unlocked (git-fixes).
- ASoC: Intel: atom: Take the drv->lock mutex before calling
  sst_send_slot_map() (git-fixes).
- ASoC: topology: use name_prefix for new kcontrol (git-fixes).
- ASoC: rt5682: Fix build error without CONFIG_I2C (git-fixes).
- ASoC: dpcm: allow start or stop during pause for backend
  (git-fixes).
- ASoC: dapm: connect virtual mux with default value (git-fixes).
- ASoC: Intel: bdw-rt5677: Remove ignore_suspend flag from SSP0
  dai link (git-fixes).
- ASoC: Intel: haswell: Remove ignore_suspend flag from SSP0
  dai link (git-fixes).
- ASoC: Intel: broadwell: Remove ignore_suspend flag from SSP0
  dai link (git-fixes).
- ASoC: fix regwmask (git-fixes).
- ALSA: hda: Add driver blacklist (git-fixes).
- ALSA: usb-audio: Add mixer workaround for TRX40 and co
  (git-fixes).
- ALSA: hda/realtek - Add quirk for MSI GL63 (git-fixes).
- ALSA: ice1724: Fix invalid access for enumerated ctl items
  (git-fixes).
- ALSA: hda: Fix potential access overflow in beep helper
  (git-fixes).
- ALSA: hda/realtek - Add HP new mute led supported for ALC236
  (git-fixes).
- ALSA: hda/realtek - Add supported new mute Led for HP
  (git-fixes).
- ALSA: usb-audio: Add registration quirk for Kingston HyperX
  Cloud Alpha S (git-fixes).
- ALSA: usb-audio: Add Pioneer DJ DJM-250MK2 quirk (git-fixes).
- ALSA: pcm: oss: Fix regression by buffer overflow fix (again)
  (git-fixes).
- ALSA: hda/realtek - Add quirk for Lenovo Carbon X1 8th gen
  (git-fixes).
- commit fa71152
* Thu Apr  9 2020 dwagner@suse.de
- crypto: arm/poly1305 - add artifact to .gitignore files
  (bsc#1169021 jsc#SLE-12250).
- crypto: x86/curve25519 - leave r12 as spare register
  (bsc#1169021 jsc#SLE-12250).
- crypto: x86/curve25519 - replace with formally verified
  implementation (bsc#1169021 jsc#SLE-12250).
- crypto: arm64/chacha - correctly walk through blocks
  (bsc#1169021 jsc#SLE-12250).
- crypto: x86/curve25519 - support assemblers with no adx support
  (bsc#1169021 jsc#SLE-12250).
- crypto: chacha20poly1305 - prevent integer overflow on large
  input (bsc#1169021 jsc#SLE-12250).
- icmp: introduce helper for nat'd source address in network
  device context (bsc#1169021 jsc#SLE-12250).
- crypto: Kconfig - allow tests to be disabled when manager is
  disabled (bsc#1169021 jsc#SLE-12250).
- wireguard: selftests: import harness makefile for test suite
  (bsc#1169021 jsc#SLE-12250).
- net: WireGuard secure network tunnel (bsc#1169021
  jsc#SLE-12250).
- Update config files: enable WIREGUARD on all archs.
- Update supported.conf: mark new drivers/net/wireguard as unsupported.
- crypto: arm/chacha - fix build failured when kernel mode NEON
  is disabled (bsc#1169021 jsc#SLE-12250).
- crypto: x86/poly1305 - emit does base conversion itself
  (bsc#1169021 jsc#SLE-12250).
- crypto: chacha20poly1305 - add back missing test vectors and
  test chunking (bsc#1169021 jsc#SLE-12250).
- crypto: x86/poly1305 - fix .gitignore typo (bsc#1169021
  jsc#SLE-12250).
- crypto: curve25519 - Fix selftest build error (bsc#1169021
  jsc#SLE-12250).
- Update supported.conf: mark new lib/crypto/libcurve25519-generic as
  unsupported.
- crypto: {arm,arm64,mips}/poly1305 - remove redundant
  non-reduction from emit (bsc#1169021 jsc#SLE-12250).
- crypto: x86/poly1305 - wire up faster implementations for kernel
  (bsc#1169021 jsc#SLE-12250).
- Update config files: a value of 11 is now required for
  CRYPTO_LIB_POLY1305_RSIZE on x86_64.
- crypto: x86/poly1305 - import unmodified cryptogams
  implementation (bsc#1169021 jsc#SLE-12250).
- crypto: poly1305 - add new 32 and 64-bit generic versions
  (bsc#1169021 jsc#SLE-12250).
- crypto: lib/curve25519 - re-add selftests (bsc#1169021
  jsc#SLE-12250).
- crypto: chacha - fix warning message in header file (bsc#1169021
  jsc#SLE-12250).
- crypto: arm/curve25519 - add arch-specific key generation
  function (bsc#1169021 jsc#SLE-12250).
- crypto: arch - conditionalize crypto api in arch glue for lib
  code (bsc#1169021 jsc#SLE-12250).
- crypto: lib/chacha20poly1305 - use chacha20_crypt() (bsc#1169021
  jsc#SLE-12250).
- crypto: x86/chacha - only unregister algorithms if registered
  (bsc#1169021 jsc#SLE-12250).
- crypto: chacha_generic - remove unnecessary setkey() functions
  (bsc#1169021 jsc#SLE-12250).
- crypto: lib/chacha20poly1305 - reimplement crypt_from_sg()
  routine (bsc#1169021 jsc#SLE-12250).
- crypto: chacha20poly1305 - import construction and selftest
  from Zinc (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_LIB_CHACHA20POLY1305 on all archs.
- Update supported.conf: mark new lib/crypto/libchacha20poly1305 as
  unsupported.
- crypto: arm/curve25519 - wire up NEON implementation
  (bsc#1169021 jsc#SLE-12250).
- crypto: arm/curve25519 - import Bernstein and Schwabe's
  Curve25519 ARM implementation (bsc#1169021 jsc#SLE-12250).
- crypto: curve25519 - x86_64 library and KPP implementations
  (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_CURVE25519_X86 on x86_64, which in
  turn implies CRYPTO_ARCH_HAVE_LIB_CURVE25519.
- Update supported.conf: mark new arch/x86/crypto/curve25519-x86_64 as
  unsupported.
- crypto: lib/curve25519 - work around Clang stack spilling issue
  (bsc#1169021 jsc#SLE-12250).
- crypto: curve25519 - implement generic KPP driver (bsc#1169021
  jsc#SLE-12250).
- Update config files: enable CRYPTO_CURVE25519 on all archs.
- Update supported.conf: mark new crypto/curve25519-generic as unsupported.
- crypto: curve25519 - add kpp selftest (bsc#1169021
  jsc#SLE-12250).
- crypto: curve25519 - generic C library implementations
  (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_LIB_CURVE25519 on all archs, which in
  turn implies CRYPTO_LIB_CURVE25519_GENERIC.
- Update supported.conf: mark new lib/crypto/libcurve25519 as unsupported.
- crypto: blake2s - x86_64 SIMD implementation (bsc#1169021
  jsc#SLE-12250).
- Update config files: enable CRYPTO_BLAKE2S_X86 on x86_64, which in turn
  implies CRYPTO_ARCH_HAVE_LIB_BLAKE2S.
- Update supported.conf: mark new arch/x86/crypto/blake2s-x86_64 as
  unsupported.
- crypto: blake2s - implement generic shash driver (bsc#1169021
  jsc#SLE-12250).
- Update config files: enable CRYPTO_BLAKE2S on all archs.
- Update supported.conf: mark new crypto/blake2s_generic as unsupported.
- crypto: testmgr - add test cases for Blake2s (bsc#1169021
  jsc#SLE-12250).
- crypto: blake2s - generic C library implementation and selftest
  (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_LIB_BLAKE2S on all archs, which in
  turn implies CRYPTO_LIB_BLAKE2S_GENERIC.
- Update supported.conf: mark new lib/crypto/libblake2s and
  lib/crypto/libblake2s-generic as unsupported.
- crypto: mips/poly1305 - incorporate OpenSSL/CRYPTOGAMS optimized
  implementation (bsc#1169021 jsc#SLE-12250).
- crypto: arm/poly1305 - incorporate OpenSSL/CRYPTOGAMS NEON
  implementation (bsc#1169021 jsc#SLE-12250).
- crypto: arm64/poly1305 - incorporate OpenSSL/CRYPTOGAMS NEON
  implementation (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_POLY1305_NEON on arm64, which in turn
  implies CRYPTO_ARCH_HAVE_LIB_POLY1305;
  a value of 9 is required for the internal CRYPTO_LIB_POLY1305_RSIZE on
  arm64.
- Update supported.conf: mark new arch/arm64/crypto/poly1305-neon as
  unsupported.
- crypto: x86/poly1305 - expose existing driver as poly1305
  library (bsc#1169021 jsc#SLE-12250).
- Update config files: CRYPTO_POLY1305_X86_64 implies
  CRYPTO_ARCH_HAVE_LIB_POLY1305 on x86_64 now;
  a value of 4 is required for the internal CRYPTO_LIB_POLY1305_RSIZE on
  x86_64.
- crypto: x86/poly1305 - depend on generic library not generic
  shash (bsc#1169021 jsc#SLE-12250).
- crypto: poly1305 - expose init/update/final library interface
  (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_LIB_POLY1305 on all archs and set the
  internal CRYPTO_LIB_POLY1305_RSIZE to 1 (the common default value among
  all archs for now).
- crypto: x86/poly1305 - unify Poly1305 state struct with generic
  code (bsc#1169021 jsc#SLE-12250).
- crypto: poly1305 - move core routines into a separate library
  (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_LIB_POLY1305_GENERIC on all archs.
- Update supported.conf: mark new lib/crypto/libpoly1305 as supported.
- crypto: chacha - unexport chacha_generic routines (bsc#1169021
  jsc#SLE-12250).
- crypto: mips/chacha - wire up accelerated 32r2 code from Zinc
  (bsc#1169021 jsc#SLE-12250).
- crypto: mips/chacha - import 32r2 ChaCha code from Zinc
  (bsc#1169021 jsc#SLE-12250).
- crypto: arm/chacha - expose ARM ChaCha routine as library
  function (bsc#1169021 jsc#SLE-12250).
- crypto: arm/chacha - remove dependency on generic ChaCha driver
  (bsc#1169021 jsc#SLE-12250).
- crypto: arm/chacha - import Eric Biggers's scalar accelerated
  ChaCha code (bsc#1169021 jsc#SLE-12250).
- crypto: arm64/chacha - expose arm64 ChaCha routine as library
  function (bsc#1169021 jsc#SLE-12250).
- Update config files: CRYPTO_CHACHA20_NEON implies
  CRYPTO_ARCH_HAVE_LIB_CHACHA on arm64 now.
- crypto: arm64/chacha - depend on generic chacha library instead
  of crypto driver (bsc#1169021 jsc#SLE-12250).
- crypto: x86/chacha - expose SIMD ChaCha routine as library
  function (bsc#1169021 jsc#SLE-12250).
- Update config files: CRYPTO_CHACHA20_X86_64 implies
  CRYPTO_ARCH_HAVE_LIB_CHACHA on x86_64 now.
- crypto: x86/chacha - depend on generic chacha library instead
  of crypto driver (bsc#1169021 jsc#SLE-12250).
- crypto: chacha - move existing library code into lib/crypto
  (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_LIB_CHACHA_GENERIC and
  CRYPTO_LIB_CHACHA on all archs.
- Update supported.conf: mark new lib/crypto/libchacha as unsupported.
- crypto: lib - tidy up lib/crypto Kconfig and Makefile
  (bsc#1169021 jsc#SLE-12250).
- commit 121a35e
* Thu Apr  9 2020 mgorman@suse.de
- cgroup, rstat: Revert "cgroup: Add memory barriers to plug
  cgroup_rstat_updated() race window" (bsc#1158748).
- commit f88fb2e
* Thu Apr  9 2020 oneukum@suse.com
- Refresh patches.suse/0001-kABI-more-hooks-for-PCI-changes.patch.
  (bsc#1168999)
  For some unknown reason (likely a macro), changing
  struct pci_fixup breaks things left and right.
  Removing the padding
- commit bbd0eda
* Thu Apr  9 2020 jwiesner@suse.com
- ipvlan: do not add hardware address of master to its unicast
  filter list (bsc#1137325).
- commit 51a58f4
* Thu Apr  9 2020 aaptel@suse.com
- cifs: ignore cached share root handle closing errors
  (bsc#1166780).
- commit 1f63b4d
* Thu Apr  9 2020 mgorman@suse.de
- Update config files to disable CONFIG_TRACE_IRQFLAGS (bsc#1169078).
- commit 35b5c01
* Thu Apr  9 2020 mkubecek@suse.cz
- kabi: drop kabi reference files (stop checking kabi)
  After the SLE15 SP2 release schedule update, it's too early to enforce
  kabi and there are some upcoming requests which either cannot be
  implemented without kabi change or would require too complicated hacks.
  Drop kabi reference files so that kabi won't be checked until they are
  added back again.
- commit 16aa8e7
* Thu Apr  9 2020 hare@suse.de
- lpfc: nvmet: Add Send LS Request and Abort LS Request support (bsc#1169045).
- lpfc: nvmet: Add support for NVME LS request hosthandle (bsc#1169045).
- lpfc: nvme: Add Receive LS Request and Send LS Response (bsc#1169045).
- lpfc: Refactor Send LS Response support (bsc#1169045).
- lpfc: Refactor Send LS Abort support (bsc#1169045).
- lpfc: Refactor Send LS Request support (bsc#1169045).
- lpfc: Refactor NVME LS receive handling (bsc#1169045).
- lpfc: Commonize lpfc_async_xchg_ctx state and flag (bsc#1169045).
- lpfc: Refactor nvmet_rcv_ctx to create lpfc_async_xchg_ctx (bsc#1169045).
- lpfc: Refactor lpfc nvme headers (bsc#1169045).
- nvme-fcloop: add target to host LS request support (bsc#1169045).
- nvme-fcloop: refactor to enable target to host LS (bsc#1169045).
- nvmet-fc: Add Disconnect Association Xmt support (bsc#1169045).
- nvmet-fc: rename ls_list to ls_rcv_list (bsc#1169045).
- nvmet-fc: track hostport handle for associations (bsc#1169045).
- nvmet-fc: perform small cleanups on unneeded checks (bsc#1169045).
- nvmet-fc: add LS failure messages (bsc#1169045).
- nvme-fc: Add Disconnect Association Rcv support (bsc#1169045).
- nvmet-fc: Update target for common definitions for LS (bsc#1169045).
- nvme-fc: Update header and host for common definitions for LS (bsc#1169045).
- nvme-fc: convert assoc_active flag to bit op (bsc#1169045).
- nvme-fc: Ensure private pointers are NULL if no data (bsc#1169045).
- nvmet-fc: Better size LS buffers (bsc#1169045).
- nvme-fc nvmet-fc: refactor for common LS definitions (bsc#1169045).
- nvme-fc and nvmet-fc: revise LLDD api for LS reception and LS (bsc#1169045).
- nvme-fc: Sync header to FC-NVME-2 rev 1.08 (bsc#1169045).
- nvme-fc: Revert "add module to ops template to allow module (bsc#1169045).
- nvme: fix deadlock caused by ANA update wrong locking (bsc#1169045).
- nvmet-rdma: fix bonding failover possible NULL deref (bsc#1169045).
- nvmet: fix NULL dereference when removing a referral (bsc#1169045).
- nvme: inherit stable pages constraint in the mpath stack (bsc#1169045).
- nvmet-fc: fix typo in comment (bsc#1169045).
- nvme-rdma: Replace comma with a semicolon (bsc#1169045).
- nvme-fcloop: fix deallocation of working context (bsc#1169045).
- commit afa84e7
* Thu Apr  9 2020 hare@suse.de
- scripts/git_sort/git_sort.py: Update nvme repositories
- commit 45cef90
* Thu Apr  9 2020 hare@suse.de
- nvme-fabrics: Use scnprintf() for avoiding potential buffer overflow (bsc#1161930).
- nvme-multipath: do not reset on unknown status (bsc#1161930).
- nvme: Check for readiness more quickly, to speed up boot time (bsc#1161930).
- nvme: log additional message for controller status (bsc#1161930).
- nvme: code cleanup nvme_identify_ns_desc() (bsc#1161930).
- nvmet-tcp: set MSG_MORE only if we actually have more to send (bsc#1161930).
- commit 0215ed6
* Thu Apr  9 2020 msuchanek@suse.de
- rpm/constraints.in: Increase memory for kernel-docs
  References: https://build.opensuse.org/request/show/792664
- commit 8b37de2
* Thu Apr  9 2020 hare@suse.de
- nvmet-tcp: set SO_PRIORITY for accepted sockets (bsc#1169045).
- nvme-tcp: Set SO_PRIORITY for all host sockets (bsc#1169045).
- nvmet: check sscanf value for subsys serial attr (bsc#1169045).
- nvmet: make ctrl model configurable (bsc#1169045).
- nvmet: make ctrl-id configurable (bsc#1169045).
- nvmet: configfs code cleanup (bsc#1169045).
- nvme: remove unused return code from nvme_alloc_ns (bsc#1169045).
- nvme-rdma: Avoid double freeing of async event data (bsc#1169045).
- nvme-pci: Hold cq_poll_lock while completing CQEs (bsc#1169045).
- nvme-multipath: Fix memory leak with ana_log_buf (bsc#1169045).
- nvme: Fix uninitialized-variable warning (bsc#1169045).
- nvme-pci: Use single IRQ vector for old Apple models (bsc#1169045).
- nvme/pci: Add sleep quirk for Samsung and Toshiba drives (bsc#1169045).
- nvme/pci: move cqe check after device shutdown (bsc#1169045).
- nvme: prevent warning triggered by nvme_stop_keep_alive (bsc#1169045).
- nvme/tcp: fix bug on double requeue when send fails (bsc#1169045).
- nvmet: update AEN list and array at one place (bsc#1169045).
- nvmet: Fix controller use after free (bsc#1169045).
- nvmet: Fix error print message at nvmet_install_queue (bsc#1169045).
- nvme-pci: remove nvmeq->tags (bsc#1169045).
- nvmet: fix dsm failure when payload does not match sgl (bsc#1169045).
- nvmet: fix per feat data len for get_feature (bsc#1169045).
- nvme/pci: Fix read queue count (bsc#1169045).
- nvme/pci Limit write queue sizes to possible cpus (bsc#1169045).
- nvme/pci: Fix write and poll queue types (bsc#1169045).
- nvme/pci: Remove last_cq_head (bsc#1169045).
- nvme: Namepace identification descriptor list is optional (bsc#1169045).
- commit 583ef0e
* Thu Apr  9 2020 jroedel@suse.de
- PCI: pciehp: Fix MSI interrupt race (bsc#1159037).
- commit 41635b6
* Thu Apr  9 2020 tiwai@suse.de
- Fix mmc CMD6 timeout spams (bsc#1169056)
  The patch
  patches.suse/mmc-core-Default-to-generic_cmd6_time-as-timeout-in-.patch.
  triggers spamming wrt MMC CMD6 timeout default.  This has been already
  reverted in stable queue, too, so let's kill it.
  This also requires the refresh of
  patches.suse/mmc-core-Allow-host-controllers-to-require-R1B-for-C.patch.
- commit d264c89
* Thu Apr  9 2020 hare@suse.de
- nvme-fc: fix double-free scenarios on hw queues (bsc#1169045).
- nvme: else following return is not needed (bsc#1169045).
- nvme: add error message on mismatching controller ids (bsc#1169045).
- nvme_fc: add module to ops template to allow module (bsc#1169045).
- nvme-fc: Avoid preallocating big SGL for data (bsc#1169045).
- nvme-rdma: Avoid preallocating big SGL for data (bsc#1169045).
- nvme: hwmon: add quirk to avoid changing temperature (bsc#1169045).
- nvme: hwmon: provide temperature min and max values for each (bsc#1169045).
- nvme: Discard workaround for non-conformant devices (bsc#1169045).
- commit ad5c1b6
* Thu Apr  9 2020 hare@suse.de
- nvme: Add hardware monitoring support (bsc#1169045).
- Update config files.
- commit 7065393
* Thu Apr  9 2020 hare@suse.de
- nvmet: Introduce common execute function for get_log_page and identify (bsc#1169045).
- commit 9f41df0
* Thu Apr  9 2020 jroedel@suse.de
- iommu/virtio: Fix freeing of incomplete domains (bsc#1169049).
- iommu/vt-d: Fix mm reference leak (bsc#1169050).
- iommu/amd: Fix the configuration of GCR3 table root pointer
  (bsc#1169048).
- iommu/vt-d: Fix page request descriptor size (bsc#1169051).
- KVM: x86: Fix CPUID range checks for Hypervisor and Centaur
  classes (bsc#1169052).
- KVM: x86: Trace the original requested CPUID function in
  kvm_cpuid() (bsc#1169053).
- commit 02f2b47
* Thu Apr  9 2020 hare@suse.de
- nvmet: stop using bio_set_op_attrs (bsc#1169045).
- nvmet: add plugging for read/write when ns is bdev (bsc#1169045).
- nvmet: clean up command parsing a bit (bsc#1169045).
- nvmet: fill discovery controller sn, fr and mn correctly (bsc#1169045).
- nvmet: Open code nvmet_req_execute() (bsc#1169045).
- nvmet: Remove the data_len field from the nvmet_req struct (bsc#1169045).
- nvmet: Introduce nvmet_dsm_len() helper (bsc#1169045).
- nvmet: Cleanup discovery execute handlers (bsc#1169045).
- nvmet-tcp: Don't set the request's data_len (bsc#1169045).
- nvmet-tcp: Don't check data_len in nvmet_tcp_map_data() (bsc#1169045).
- nvme: Introduce nvme_lba_to_sect() (bsc#1169045).
- nvme: Cleanup and rename nvme_block_nr() (bsc#1169045).
- nvme: move common call to nvme_cleanup_cmd to core layer (bsc#1169045).
- nvme: introduce "Command Aborted By host" status code (bsc#1169045).
- nvmet-rdma: add unlikely check at nvmet_rdma_map_sgl_keyed (bsc#1169045).
- nvmet: add unlikely check at nvmet_req_alloc_sgl (bsc#1169045).
- nvmet: use bio_io_error instead of duplicating it (bsc#1169045).
- nvme: introduce nvme_is_aen_req function (bsc#1169045).
- nvme-fc: ensure association_id is cleared regardless of a Disconnet LS (bsc#1169045).
- nvme-fc: clarify error messages (bsc#1169045).
- nvme-fc: Set new cmd set indicator in nvme-fc cmnd iu (bsc#1169045).
- nvme-fc and nvmet-fc: sync with FC-NVME-2 header changes (bsc#1169045).
- nvme-fc: Sync nvme-fc header to FC-NVME-2 (bsc#1169045).
- commit 2d3a577
* Thu Apr  9 2020 hare@suse.de
- nvme-multipath: remove unused groups_only mode in ana log (bsc#1169045).
- nvme: Wait for reset state when required (bsc#1169045).
- nvme: Prevent resets during paused controller state (bsc#1169045).
- nvme: Restart request timers in resetting state (bsc#1169045).
- nvme: Remove ADMIN_ONLY state (bsc#1169045).
- nvme-pci: Free tagset if no IO queues (bsc#1169045).
- nvme: retain split access workaround for capability reads (bsc#1169045).
- nvme: fix possible deadlock when nvme_update_formats fails (bsc#1169045).
- commit a98e6f9
* Thu Apr  9 2020 dwagner@suse.de
- scsi: core: avoid repetitive logging of device offline messages
  (bsc#1145929).
- commit 4217986
* Thu Apr  9 2020 wqu@suse.com
- btrfs: qgroup: Mark qgroup inconsistent if we're inherting
  snapshot to a new qgroup (bsc#1165823).
- commit f82cb6e
* Thu Apr  9 2020 neilb@suse.de
- SUNRPC: fix krb5p mount to provide large enough buffer in
  rq_rcvsize (bsc#1168236).
- commit 973a971
* Wed Apr  8 2020 mkubecek@suse.cz
- config: refresh
- commit 60a481d
* Wed Apr  8 2020 yousaf.kaukab@suse.com
- cpufreq: arm64: prevent module unload (bsc#1168476).
- commit 59dc6e3
* Wed Apr  8 2020 tiwai@suse.de
- misc: pci_endpoint_test: Fix to support > 10 pci-endpoint-test
  devices (git-fixes).
- pinctrl: sprd: Use the correct pin output configuration
  (git-fixes).
- pxa168fb: fix release function mismatch in probe failure
  (git-fixes).
- mt76: remove variable 'val' set but not used (git-fixes).
- irqchip/bcm2835: Quiesce IRQs left enabled by bootloader
  (git-fixes).
- iio: potentiostat: lmp9100: fix
  iio_triggered_buffer_{predisable,postenable} positions
  (git-fixes).
- iio: si1133: read 24-bit signed integer for measurement
  (git-fixes).
- staging: kpc2000: prevent underflow in cpld_reconfigure()
  (git-fixes).
- pstore: pstore_ftrace_seq_next should increase position index
  (git-fixes).
- libata: Remove extra scsi_host_put() in ata_scsi_add_hosts()
  (git-fixes).
- r8169: fix PHY driver check on platforms w/o module softdeps
  (git-fixes).
- i2c: nvidia-gpu: Handle timeout correctly in
  gpu_i2c_check_status() (git-fixes).
- geneve: move debug check after netdev unregister (git-fixes).
- lib/test_kasan.c: fix memory leak in kmalloc_oob_krealloc_more()
  (git-fixes).
- lib/ubsan: don't serialize UBSAN report (git-fixes).
- commit a79673f
* Wed Apr  8 2020 tiwai@suse.de
- drm/vc4: Fix HDMI mode validation (git-fixes).
- drm: amd/acp: fix broken menu structure (git-fixes).
- drm/v3d: Replace wait_for macros to remove use of msleep
  (git-fixes).
- drm/amd/display: Fix wrongly passed static prefix (git-fixes).
- drm: Remove PageReserved manipulation from drm_pci_alloc
  (git-fixes).
- drm/crc: Actually allow to change the crc source (git-fixes).
- drm/drm_dp_mst:remove set but not used variable 'origlen'
  (git-fixes).
- drm/amdgpu: fix typo for vcn1 idle check (git-fixes).
- drm/amd/display: Add link_rate quirk for Apple 15" MBP 2017
  (git-fixes).
- drm/bochs: downgrade pci_request_region failure from error to
  warning (git-fixes).
- drm/amdgpu: correct ROM_INDEX/DATA offset for VEGA20
  (git-fixes).
- commit 3d01994
* Wed Apr  8 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/slcan-Don-t-transmit-uninitialized-stack-data-in-pad.patch
- commit 26aaf48
* Wed Apr  8 2020 tiwai@suse.de
- thermal: devfreq_cooling: inline all stubs for
  CONFIG_DEVFREQ_THERMAL=n (git-fixes).
- thermal: qoriq: Fix a compiling issue (git-fixes).
- mfd: dln2: Fix sanity checking for endpoints (git-fixes).
- tun: Don't put_page() for all negative return values from XDP
  program (git-fixes).
- PCI/ERR: Update error status after reset_link() (git-fixes).
- PCI/ERR: Combine pci_channel_io_frozen cases (git-fixes).
- mei: me: add cedar fork device ids (git-fixes).
- extcon: axp288: Add wakeup support (git-fixes).
- fbdev: potential information leak in do_fb_ioctl() (git-fixes).
- watchdog: iTCO_wdt: Make ICH_RES_IO_SMI optional (git-fixes).
- watchdog: iTCO_wdt: Export vendorsupport (git-fixes).
- fat: fix uninit-memory access for partial initialized inode
  (git-fixes).
- commit 58be4d2
* Wed Apr  8 2020 ggherdovich@suse.cz
- x86, sched: Account for CPUs with less than 4 cores in
  freq. invariance (boo#1166664).
- commit 949f5c1
* Wed Apr  8 2020 ggherdovich@suse.cz
- x86, sched: Bail out of frequency invariance if base frequency
  is unknown (bsc#1167878).
- commit f094f17
* Tue Apr  7 2020 msuchanek@suse.de
- Refresh patches.suse/powerpc-pseries-Fix-MCE-handling-on-pseries.patch.
- commit 901c022
* Tue Apr  7 2020 msuchanek@suse.de
- s390x: zfcpdump: disable CONFIG_RELOCATABLE (bsc#1168847).
- commit 77366c6
* Tue Apr  7 2020 mkubecek@suse.cz
- series.conf: cleanup
- move into sorted section:
  patches.suse/slcan-Don-t-transmit-uninitialized-stack-data-in-pad.patch
- commit 6de7fc6
* Tue Apr  7 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/btrfs-qgroup-ensure-qgroup_rescan_running-is-only-se.patch
- commit 5232dd1
* Tue Apr  7 2020 mgorman@suse.de
- Update config files to disable CONFIG_UCLAMP_TASK (bsc#1168888).
- commit 00c1c4e
* Tue Apr  7 2020 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patches out of sorted section
- commit 362f0b0
* Tue Apr  7 2020 oneukum@suse.com
- Update
  patches.suse/media-ov519-add-missing-endpoint-sanity-checks.patch
  (CVE-2020-11608 bsc#1168829). Added cve number
- commit a2db40e
* Tue Apr  7 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/Documentation-ABI-Add-ABI-documentation-for-sys-kern.patch
  patches.suse/Documentation-ABI-Mark-sys-kernel-fadump_-sysfs-file.patch
  patches.suse/cpufreq-powernv-Fix-unsafe-notifiers.patch
  patches.suse/cpufreq-powernv-Fix-use-after-free.patch
  patches.suse/powerpc-64-Prevent-stack-protection-in-early-boot.patch
  patches.suse/powerpc-64-Setup-a-paca-before-parsing-device-tree-e.patch
  patches.suse/powerpc-64-tm-Don-t-let-userspace-set-regs-trap-via-.patch
  patches.suse/powerpc-64s-Fix-section-mismatch-warnings-from-boot-.patch
  patches.suse/powerpc-book3s64-Fix-error-handling-in-mm_iommu_do_a.patch
  patches.suse/powerpc-drmem-avoid-NULL-pointer-dereference-when-dr.patch
  patches.suse/powerpc-fadump-Reorganize-sys-kernel-fadump_-sysfs-f.patch
  patches.suse/powerpc-fadump-sysfs-for-fadump-memory-reservation.patch
  patches.suse/powerpc-powernv-Move-core-and-fadump_release_opalcor.patch
  patches.suse/powerpc-pseries-Fix-of_read_drc_info_cell-to-point-a.patch
  patches.suse/powerpc-pseries-Handle-UE-event-for-memcpy_mcsafe.patch
  patches.suse/powerpc-smp-Use-nid-as-fallback-for-package_id.patch
  patches.suse/powerpc-vmlinux.lds-Explicitly-retain-.gnu.hash.patch
  patches.suse/powerpc-xive-Use-XIVE_BAD_IRQ-instead-of-zero-to-cat.patch
  patches.suse/sysfs-Wrap-__compat_only_sysfs_link_entry_to_kobj-fu.patch
- commit 895f36d
* Tue Apr  7 2020 pjakobsson@suse.de
- supported.conf: Mark mali-dp as supported
  References: bsc#1168596
  Used on NXP LS1028A devices.
- commit 3682c9a
* Tue Apr  7 2020 glin@suse.com
- bpf: Verifier, do_refine_retval_range may clamp umin to 0
  incorrectly (bsc#1155518).
- bpf: Explicitly memset some bpf info structures declared on
  the stack (bsc#1155518).
- bpf: Explicitly memset the bpf_attr structure (bsc#1155518).
- commit b866c91
* Tue Apr  7 2020 neilb@suse.de
- MM: replace PF_LESS_THROTTLE with PF_LOCAL_THROTTLE
  (bsc#1163403).
- Deprecate NR_UNSTABLE_NFS, use NR_WRITEBACK (bsc#1163403).
- commit 73cedab
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc/irq: Use current_stack_pointer in do_IRQ()
  (bsc#1156395).
- powerpc/irq: Use current_stack_pointer in check_stack_overflow()
  (bsc#1156395).
- powerpc: Add current_stack_pointer as a register global
  (bsc#1156395).
- powerpc: Rename current_stack_pointer() to current_stack_frame()
  (bsc#1156395).
- commit dfb328d
* Mon Apr  6 2020 jack@suse.cz
- blacklist.conf: Blacklist 1ac994525b9d
- commit 536164b
* Mon Apr  6 2020 jack@suse.cz
- mm/filemap.c: don't bother dropping mmap_sem for zero size
  readahead (bsc#1168768).
- commit 73bb347
* Mon Apr  6 2020 jack@suse.cz
- blacklist.conf: Blacklist 780f66e59231
- commit f5700fa
* Mon Apr  6 2020 jack@suse.cz
- ext4: fix incorrect group count in ext4_fill_super error message
  (bsc#1168765).
- commit fe1e977
* Mon Apr  6 2020 jack@suse.cz
- ext4: fix incorrect inodes per group in error message
  (bsc#1168764).
- commit 30375fd
* Mon Apr  6 2020 jack@suse.cz
- Move merged patches to sorted section.
- commit cd90775
* Mon Apr  6 2020 jack@suse.cz
  patches.suse/ext4-Avoid-ENOSPC-when-avoiding-to-reuse-recently-de.patch,
  patches.suse/ext4-Unregister-sysfs-path-before-destroying-jbd2-journal.patch,
  patches.suse/ext4-do-not-commit-super-on-read-only-bdev.patch: Update
  tags
- commit 9574818
* Mon Apr  6 2020 jack@suse.cz
- patches.suse/ext4-Check-for-non-zero-journal-inum-in-ext4_calculate_overhead.patches:
  Update patch tags
- commit 2c9a584
* Mon Apr  6 2020 jack@suse.cz
- partitions/efi: Fix partition name parsing in GUID partition
  entry (bsc#1168763).
- commit 0cdb51e
* Mon Apr  6 2020 jack@suse.cz
- block: keep bdi->io_pages in sync with max_sectors_kb for
  stacked devices (bsc#1168762).
- commit bab38c6
* Mon Apr  6 2020 jack@suse.cz
- blacklist.conf: Blacklist f01b411f41f9
- commit a9128f0
* Mon Apr  6 2020 jack@suse.cz
- block/diskstats: more accurate approximation of io_ticks for
  slow disks (bsc#1168761).
- commit fbbe9dc
* Mon Apr  6 2020 jack@suse.cz
- block, bfq: fix use-after-free in bfq_idle_slice_timer_body
  (bsc#1168760).
- commit 1b05c31
* Mon Apr  6 2020 tiwai@suse.de
- ASoC: jz4740-i2s: Fix divider written at incorrect offset in
  register (git-fixes).
- commit 8642419
* Mon Apr  6 2020 tiwai@suse.de
- xarray: Fix early termination of xas_for_each_marked
  (git-fixes).
- XArray: Fix xas_pause for large multi-index entries (git-fixes).
- XArray: Fix xa_find_next for large multi-index entries
  (git-fixes).
- commit b6feec2
* Mon Apr  6 2020 tiwai@suse.de
- media: imx: Propagate quantization and encoding in CSI
  (git-fixes).
- blacklist.conf:
- commit 43a1dba
* Mon Apr  6 2020 tiwai@suse.de
- tty: evh_bytechan: Fix out of bounds accesses (git-fixes).
- rtc: imx-sc: Align imx sc msg structs to 4 (git-fixes).
- rtc: cmos: Use spin_lock_irqsave() in cmos_interrupt()
  (git-fixes).
- rtc: zynqmp: Clear alarm interrupt status before interrupt
  enable (git-fixes).
- gpio: siox: use raw spinlock for irq related locking
  (git-fixes).
- soc: mediatek: knows_txdone needs to be set in Mediatek CMDQ
  helper (git-fixes).
- PCI: qcom: Fix the fixup of PCI_VENDOR_ID_QCOM (git-fixes).
- PCI: endpoint: Fix clearing start entry in configfs (git-fixes).
- PCI: pciehp: Fix indefinite wait on sysfs requests (git-fixes).
- PCI/ASPM: Clear the correct bits when enabling L1 substates
  (git-fixes).
- misc: rtsx: set correct pcr_ops for rts522A (git-fixes).
- PCI/switchtec: Fix init_completion race condition with
  poll_wait() (git-fixes).
- PM / Domains: Allow no domain-idle-states DT property in genpd
  when parsing (git-fixes).
- PM: sleep: wakeup: Skip wakeup_source_sysfs_remove() if device
  is not there (git-fixes).
- phy: ti: gmii-sel: do not fail in case of gmii (git-fixes).
- phy: ti: gmii-sel: fix set of copy-paste errors (git-fixes).
- commit b2ac503
* Mon Apr  6 2020 tiwai@suse.de
- clk: imx: clk-gate2: Pass the device to the register function
  (git-fixes).
- clk: imx8mm: Fix the CLKO1 source select list (git-fixes).
- clk: qcom: clk-rpmh: Wait for completion when enabling clocks
  (git-fixes).
- clk: sprd: fix to get a correct ibias of pll (git-fixes).
- clk: at91: usb: use proper usbs_mask (git-fixes).
- clk: at91: sam9x60: fix usb clock parents (git-fixes).
- clk: at91: sam9x60: Don't use audio PLL (git-fixes).
- clk: ingenic/jz4770: Exit with error if CGU init failed
  (git-fixes).
- clk: sunxi-ng: sun8i-de2: Add rotation core clocks and reset
  for A83T (git-fixes).
- clk: sunxi-ng: sun8i-de2: H6 doesn't have rotate core
  (git-fixes).
- clk: sunxi-ng: sun8i-de2: Add rotation core clocks and reset
  for A64 (git-fixes).
- clk: sunxi-ng: sun8i-de2: Split out H5 definitions (git-fixes).
- clk: ti: Fix dm814x clkctrl for ethernet (git-fixes).
- clk: imx: Align imx sc clock parent msg structs to 4
  (git-fixes).
- clk: imx: Align imx sc clock msg structs to 4 (git-fixes).
- clk: ti: am43xx: Fix clock parent for RTC clock (git-fixes).
- commit 2f7671e
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc: define helpers to get L1 icache sizes (bsc#1156395).
- commit 780726d
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc/hash64/devmap: Use H_PAGE_THP_HUGE when setting up
  huge devmap PTE entries (bsc#1156395).
- commit 86ebd4a
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc/kprobes: Ignore traps that happened in real mode
  (bsc#1065729).
- commit fc55c00
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc/mm: Fix missing KUAP disable in flush_coherent_icache()
  (bsc#1156395).
- powerpc: Convert flush_icache_range & friends to C
  (bsc#1156395).
- powerpc/32: don't use CPU_FTR_COHERENT_ICACHE (bsc#1156395).
- commit 9ea5bb3
* Mon Apr  6 2020 mbenes@suse.cz
- ftrace/kprobe: Show the maxactive number on kprobe_events
  (git-fixes).
- commit 090d00e
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc: Make setjmp/longjmp signature standard (bsc#1156395).
- powerpc: Add attributes for setjmp/longjmp (bsc#1156395).
- commit 918fd5d
* Mon Apr  6 2020 ykaukab@suse.de
- PM / QoS: Redefine FREQ_QOS_MAX_DEFAULT_VALUE to S32_MAX
  (bsc#1168476).
- ACPI: processor: Add QoS requests for all CPUs (bsc#1168476).
- commit d3f0646
* Mon Apr  6 2020 ykaukab@suse.de
- cpufreq: Fix policy initialization for internal governor drivers
  (bsc#1168476).
- cpufreq: Avoid creating excessively large stack frames
  (bsc#1168476).
- cpufreq: Avoid leaving stale IRQ work items during CPU offline
  (bsc#1168476).
- cpufreq: Register drivers only after CPU devices have been
  registered (bsc#1168476).
- cpufreq: Clarify the comment in cpufreq_set_policy()
  (bsc#1168476).
- PM: QoS: Invalidate frequency QoS requests after removal
  (bsc#1168476).
- PM: QoS: Drop frequency QoS types from device PM QoS
  (bsc#1168476).
- cpufreq: Use per-policy frequency QoS (bsc#1168476).
- PM: QoS: Introduce frequency QoS (bsc#1168476).
- ACPI: processor: Avoid NULL pointer dereferences at init time
  (bsc#1168476).
- Documentation: cpufreq: Update policy notifier documentation
  (bsc#1168476).
- cpufreq: Remove CPUFREQ_ADJUST and CPUFREQ_NOTIFY policy
  notifier events (bsc#1168476).
- ACPI: cpufreq: Switch to QoS requests instead of cpufreq
  notifier (bsc#1168476).
- video: pxafb: Remove cpufreq policy notifier (bsc#1168476).
- video: sa1100fb: Remove cpufreq policy notifier (bsc#1168476).
- arch_topology: Use CPUFREQ_CREATE_POLICY instead of
  CPUFREQ_NOTIFY (bsc#1168476).
- cpufreq: powerpc_cbe: Switch to QoS requests for freq limits
  (bsc#1168476).
- cpufreq: powerpc: macintosh: Switch to QoS requests for freq
  limits (bsc#1168476).
- thermal: cpu_cooling: Switch to QoS requests for freq limits
  (bsc#1168476).
- cpufreq: Add policy create/remove notifiers back (bsc#1168476).
- cpufreq: intel_pstate: Implement QoS supported freq constraints
  (bsc#1168476).
- commit 9298b0f
* Mon Apr  6 2020 ptesarik@suse.cz
- s390/pci: Fix unexpected write combine on resource (bsc#1168553
  LTC#184760).
- commit 0e9a5c8
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc/pseries/ddw: Extend upper limit for huge DMA window
  for persistent memory (FATE#327775 bsc#1142685 ltc#179509).
- commit 0b3bfc8
* Mon Apr  6 2020 dwagner@suse.de
- scsi: qla2xxx: Fix I/Os being passed down when FC device is
  being deleted (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- commit a560046
* Mon Apr  6 2020 oneukum@suse.com
- blacklist.conf: already done in 045706bff837ee89c13f1ace173db71922c1c40b
- commit 255a9d4
* Mon Apr  6 2020 oneukum@suse.com
- blacklist.conf: already done in b32196e35bd7bbc8038db1aba1fbf022dc469b6a
- commit c52adb6
* Mon Apr  6 2020 ptesarik@suse.cz
- s390/mm: fix panic in gup_fast on large pud (bsc#1167197
  LTC#184507).
- commit a8ed0dc
* Mon Apr  6 2020 oneukum@suse.com
- blacklist.conf: fixes only logged messages
- commit 8266fdf
* Mon Apr  6 2020 wqu@suse.com
- btrfs: qgroup: ensure qgroup_rescan_running is only set when
  the worker is at least queued (bsc#1168670).
- Delete
  patches.suse/btrfs-qgroups-fix-rescan-worker-running-races.patch.
- commit acca6e8
* Mon Apr  6 2020 pvorel@suse.cz
- nfsd: remove read permission bit for ctl sysctl (git-fixes).
- commit 6b806f6
* Sun Apr  5 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-kvm-s390-disallow-invalid-bits-in-kvm_valid_regs-and-kvm_dirty_regs
  patches.suse/0002-kvm-s390-mark-_insn32_query-as-_always_inline
  patches.suse/0003-kvm-s390-cleanup-kvm_arch_init-error-path
  patches.suse/0004-kvm-s390-cleanup-initial-cpu-reset
  patches.suse/0005-kvm-s390-add-new-reset-vcpu-api
- commit e3cd9b7
* Sun Apr  5 2020 mkubecek@suse.cz
- Update kabi files.
- commit 038f102
* Sat Apr  4 2020 ailiop@suse.com
- xfs: fix use-after-free when aborting corrupt attr inactivation
  (git-fixes).
- commit bef8807
* Fri Apr  3 2020 ptesarik@suse.cz
- KVM: s390: protvirt: Add initial vm and cpu lifecycle handling
  (jsc#SLE-7512 bsc#1165545).
- Update kabi files.
- commit f7edc36
* Fri Apr  3 2020 ptesarik@suse.cz
- KVM: s390: protvirt: Implement interrupt injection (jsc#SLE-7512
  bsc#1165545).
- Update kabi files.
- commit 992821a
* Fri Apr  3 2020 ptesarik@suse.cz
- KVM: s390: protvirt: Instruction emulation (jsc#SLE-7512
  bsc#1165545).
- commit 19e482f
* Fri Apr  3 2020 ptesarik@suse.cz
- mm/gup/writeback: add callbacks for inaccessible pages
  (jsc#SLE-7512 bsc#1165545).
- commit 2700b97
* Fri Apr  3 2020 msuchanek@suse.de
- scsi: ibmvfc: Fix NULL return compiler warning (bsc#1161951
  ltc#183551).
- commit 8a47623
* Fri Apr  3 2020 msuchanek@suse.de
- powerpc/pseries: Fix MCE handling on pseries (bsc#1168575
  ltc#183501).
- commit ef26231
* Fri Apr  3 2020 msuchanek@suse.de
- scsi: lpfc: Change default SCSI LUN QD to 64 (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
  Patch split off
  patches.suse/scsi-lpfc-Fix-erroneous-cpu-limit-of-128-on-I-O-stat.patch
  in upstream repository.
- Refresh patches.suse/scsi-lpfc-Fix-erroneous-cpu-limit-of-128-on-I-O-stat.patch.
- Refresh patches.suse/scsi-lpfc-Make-debugfs-ktime-stats-generic-for-NVME-.patch.
- Refresh patches.suse/scsi-lpfc-Remove-prototype-FIPS-DSS-options-from-SLI.patch.
- Refresh patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.0.patch.
- commit a4a3d20
* Fri Apr  3 2020 yousaf.kaukab@suse.com
- config: arm64: enable cpufreq driver for Jetson Nano and TX1
  References: jsc#SLE-9391
- commit 57d2fdd
* Fri Apr  3 2020 mkubecek@suse.cz
- Update kabi files.
  Update to Snapshot 10 submission (commit c4804773a3be).
- commit 46da16d
* Fri Apr  3 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/pinctrl-bcm2835-add-support-for-all-gpios-on-bcm2711.patch
  patches.suse/pinctrl-bcm2835-drop-unused-define.patch
  patches.suse/pinctrl-bcm2835-refactor-platform-data.patch
  patches.suse/scsi-fc-Update-Descriptor-definition-and-add-RDF-and.patch
  patches.suse/scsi-ibmvfc-Avoid-loss-of-all-paths-during-SVC-node-.patch
  patches.suse/scsi-lpfc-Clean-up-hba-max_lun_queue_depth-checks.patch
  patches.suse/scsi-lpfc-Fix-RQ-buffer-leakage-when-no-IOCBs-availa.patch
  patches.suse/scsi-lpfc-Fix-broken-Credit-Recovery-after-driver-lo.patch
  patches.suse/scsi-lpfc-Fix-compiler-warning-on-frame-size.patch
  patches.suse/scsi-lpfc-Fix-coverity-errors-in-fmdi-attribute-hand.patch
  patches.suse/scsi-lpfc-Fix-lpfc_io_buf-resource-leak-in-lpfc_get_.patch
  patches.suse/scsi-lpfc-Fix-registration-of-ELS-type-support-in-fd.patch
  patches.suse/scsi-lpfc-Fix-release-of-hwq-to-clear-the-eq-relatio.patch
  patches.suse/scsi-lpfc-Remove-handler-for-obsolete-ELS-Read-Port-.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.6.0.4.patch
  patches.suse/scsi-lpfc-add-RDF-registration-and-Link-Integrity-FP.patch
  patches.suse/scsi-lpfc-fix-spelling-mistake-Notication-Notificati.patch
  patches.suse/scsi-qla2xxx-Add-16.0GT-for-PCI-String.patch
  patches.suse/scsi-qla2xxx-Add-beacon-LED-config-sysfs-interface.patch
  patches.suse/scsi-qla2xxx-Add-changes-in-preparation-for-vendor-e.patch
  patches.suse/scsi-qla2xxx-Add-deferred-queue-for-processing-ABTS-.patch
  patches.suse/scsi-qla2xxx-Add-endianizer-macro-calls-to-fc-host-s.patch
  patches.suse/scsi-qla2xxx-Add-fixes-for-mailbox-command.patch
  patches.suse/scsi-qla2xxx-Add-ql2xrdpenable-module-parameter-for-.patch
  patches.suse/scsi-qla2xxx-Add-sysfs-node-for-D-Port-Diagnostics-A.patch
  patches.suse/scsi-qla2xxx-Add-vendor-extended-FDMI-commands.patch
  patches.suse/scsi-qla2xxx-Add-vendor-extended-RDP-additions-and-a.patch
  patches.suse/scsi-qla2xxx-Avoid-setting-firmware-options-twice-in.patch
  patches.suse/scsi-qla2xxx-Check-locking-assumptions-at-runtime-in.patch
  patches.suse/scsi-qla2xxx-Cleanup-ELS-PUREX-iocb-fields.patch
  patches.suse/scsi-qla2xxx-Convert-MAKE_HANDLE-from-a-define-into-.patch
  patches.suse/scsi-qla2xxx-Correction-to-selection-of-loopback-ech.patch
  patches.suse/scsi-qla2xxx-Display-message-for-FCE-enabled.patch
  patches.suse/scsi-qla2xxx-Fix-FCP-SCSI-FC4-flag-passing-error.patch
  patches.suse/scsi-qla2xxx-Fix-NPIV-instantiation-after-FW-dump.patch
  patches.suse/scsi-qla2xxx-Fix-RDP-respond-data-format.patch
  patches.suse/scsi-qla2xxx-Fix-RDP-response-size.patch
  patches.suse/scsi-qla2xxx-Fix-control-flags-for-login-logout-IOCB.patch
  patches.suse/scsi-qla2xxx-Fix-qla2x00_echo_test-based-on-ISP-type.patch
  patches.suse/scsi-qla2xxx-Fix-sparse-warning-reported-by-kbuild-b.patch
  patches.suse/scsi-qla2xxx-Fix-sparse-warnings-triggered-by-the-PC.patch
  patches.suse/scsi-qla2xxx-Force-semaphore-on-flash-validation-fai.patch
  patches.suse/scsi-qla2xxx-Handle-NVME-status-iocb-correctly.patch
  patches.suse/scsi-qla2xxx-Handle-cases-for-limiting-RDP-response-.patch
  patches.suse/scsi-qla2xxx-Improved-secure-flash-support-messages.patch
  patches.suse/scsi-qla2xxx-Move-free-of-fcport-out-of-interrupt-co.patch
  patches.suse/scsi-qla2xxx-Print-portname-for-logging-in-qla24xx_l.patch
  patches.suse/scsi-qla2xxx-Remove-restriction-of-FC-T10-PI-and-FC-.patch
  patches.suse/scsi-qla2xxx-Return-appropriate-failure-through-BSG-.patch
  patches.suse/scsi-qla2xxx-Save-rscn_gen-for-new-fcport.patch
  patches.suse/scsi-qla2xxx-Serialize-fc_port-alloc-in-N2N.patch
  patches.suse/scsi-qla2xxx-Set-Nport-ID-for-N2N.patch
  patches.suse/scsi-qla2xxx-Show-correct-port-speed-capabilities-fo.patch
  patches.suse/scsi-qla2xxx-Simplify-the-code-for-aborting-SCSI-com.patch
  patches.suse/scsi-qla2xxx-Suppress-endianness-complaints-in-qla2x.patch
  patches.suse/scsi-qla2xxx-Update-BPM-enablement-semantics.patch
  patches.suse/scsi-qla2xxx-Update-driver-version-to-10.01.00.24-k.patch
  patches.suse/scsi-qla2xxx-Update-driver-version-to-10.01.00.25-k.patch
  patches.suse/scsi-qla2xxx-Use-FC-generic-update-firmware-options-.patch
  patches.suse/scsi-qla2xxx-Use-QLA_FW_STOPPED-macro-to-propagate-f.patch
  patches.suse/scsi-qla2xxx-Use-a-dedicated-interrupt-handler-for-h.patch
  patches.suse/scsi-qla2xxx-Use-correct-ISP28xx-active-FW-region.patch
  patches.suse/scsi-qla2xxx-Use-endian-macros-to-assign-static-fiel.patch
  patches.suse/scsi-qla2xxx-add-more-FW-debug-information.patch
  patches.suse/scsi-qla2xxx-fix-FW-resource-count-values.patch
  patches.suse/scsi-target-convert-boolean-se_dev_attrib-types-to-b.patch
  patches.suse/scsi-target-fix-unmap_zeroes_data-boolean-initialisa.patch
  patches.suse/scsi-target-use-an-enum-to-track-emulate_ua_intlck_c.patch
  patches.suse/scsi-tcm_qla2xxx-Make-qlt_alloc_qfull_cmd-set-cmd-se.patch
- commit e921d75
* Fri Apr  3 2020 tiwai@suse.de
- mtd: spinand: Do not erase the block before writing a bad
  block marker (git-fixes).
- mtd: spinand: Explicitly use MTD_OPS_RAW to write the bad
  block marker to OOB (git-fixes).
- mtd: spinand: Stop using spinand->oobbuf for buffering bad
  block markers (git-fixes).
- mtd: rawnand: free the nand_device object (git-fixes).
- mtd: phram: fix a double free issue in error path (git-fixes).
- mtd: lpddr: Fix a double free in probe() (git-fixes).
- i2c: smbus: remove outdated references to irq level triggers
  (git-fixes).
- ASoC: Intel: mrfld: fix incorrect check on p->sink (git-fixes).
- ASoC: sun8i-codec: Remove unused dev from codec struct
  (git-fixes).
- ASoC: Intel: mrfld: return error codes when an error occurs
  (git-fixes).
- ASoC: stm32: spdifrx: fix regmap status check (git-fixes).
- pinctrl: actions: Fix functions groups names for S700 SoC
  (git-fixes).
- remoteproc: Fix NULL pointer dereference in rproc_virtio_notify
  (git-fixes).
- remoteproc: qcom_q6v5_mss: Reload the mba region on coredump
  (git-fixes).
- remoteproc: qcom_q6v5_mss: Don't reassign mpss region on
  shutdown (git-fixes).
- include/bitmap.h: add missing parameter in docs (git-fixes).
- mac80211: fix authentication with iwlwifi/mvm (git-fixes).
- mac80211: Check port authorization in the ieee80211_tx_dequeue()
  case (git-fixes).
- nl80211: fix NL80211_ATTR_CHANNEL_WIDTH attribute type
  (git-fixes).
- slcan: not call free_netdev before rtnl_unlock in slcan_open
  (git-fixes).
- commit 784cfac
* Fri Apr  3 2020 tiwai@suse.de
- ALSA: pcm.h: add for_each_pcm_streams() (git-fixes).
- commit 03a4da5
* Fri Apr  3 2020 tiwai@suse.de
- ALSA: usb-audio: Fix case when USB MIDI interface has more
  than one extra endpoint descriptor (git-fixes).
- ALSA: hda/realtek - Remove now-unnecessary XPS 13 headphone
  noise fixups (git-fixes).
- ALSA: hda/realtek - Set principled PC Beep configuration for
  ALC256 (git-fixes).
- ALSA: usx2y: use for_each_pcm_streams() macro (git-fixes).
- ALSA: hda: default enable CA0132 DSP support (git-fixes).
- ALSA: usb-audio: Inform devices that need delayed registration
  (git-fixes).
- ALSA: usb-audio: Add delayed_register option (git-fixes).
- ALSA: usb-audio: Rewrite registration quirk handling
  (git-fixes).
- ALSA: core: Add snd_device_get_state() helper (git-fixes).
- ALSA: usb-audio: Create a registration quirk for Kingston
  HyperX Amp (0951:16d8) (git-fixes).
- ALSA: usb-audio: Fix mixer controls' USB interface for Kingston
  HyperX Amp (0951:16d8) (git-fixes).
- ALSA: hda: Use scnprintf() for string truncation (git-fixes).
- ALSA: pcm: Fix superfluous snprintf() usage (git-fixes).
- ALSA: pcm: oss: Simplify plugin frame size calculations
  (git-fixes).
- ALSA: usb-audio: Fix missing braces in some struct inits
  (git-fixes).
- ALSA: usb-audio: Add support for MOTU MicroBook IIc (git-fixes).
- ALSA: korg1212: fix if-statement empty body warnings
  (git-fixes).
- ALSA: usb-audio: Parse source ID of UAC2 effect unit
  (git-fixes).
- usb: audio-v2: Add uac2_effect_unit_descriptor definition
  (git-fixes).
- ALSA: usb-audio: Add support for Presonus Studio 1810c
  (git-fixes).
- ALSA: pcm: oss: Unlock mutex temporarily for sleeping at
  read/write (git-fixes).
- ALSA: usb-audio: Don't create a mixer element with bogus volume
  range (git-fixes).
- ALSA: hda_codec: Replace zero-length array with flexible-array
  member (git-fixes).
- ALSA: hda/ca0132 - Replace zero-length array with flexible-array
  member (git-fixes).
- ALSA: usb-midi: Replace zero-length array with flexible-array
  member (git-fixes).
- ALSA: core: Replace zero-length array with flexible-array member
  (git-fixes).
- ALSA: info: remove redundant assignment to variable c
  (git-fixes).
- ALSA: ali5451: remove redundant variable capture_flag
  (git-fixes).
- ALSA: hda: remove redundant assignment to variable timeout
  (git-fixes).
- ALSA: hdsp: remove redundant assignment to variable err
  (git-fixes).
- ALSA: pcm: Use a macro for parameter masks to reduce the needed
  cast (git-fixes).
- ALSA: pcm: Use standard macros for fixing PCM format cast
  (git-fixes).
- ALSA: usb-audio: Use pcm_for_each_format() macro for PCM format
  iterations (git-fixes).
- ALSA: pcm: More helper macros for reducing snd_pcm_format_t cast
  (git-fixes).
- ALSA: emu10k1: Fix endianness annotations (git-fixes).
- ALSA: via82xx: Fix endianness annotations (git-fixes).
- ALSA: hda/hdmi: Move ELD parse and jack reporting into
  update_eld() (git-fixes).
- ALSA: hda/hdmi: Move runtime PM resume into
  hdmi_present_sense_via_verbs() (git-fixes).
- ALSA: hda/hdmi: Don't use standard hda_jack for generic HDMI
  jacks (git-fixes).
- ALSA: hda/hdmi: Reduce hda_jack_tbl lookup at unsol event
  handling (git-fixes).
- ALSA: hda/realtek - a fake key event is triggered by running
  shutup (git-fixes).
- ALSA: hda/realtek: Enable mute LED on an HP system (git-fixes).
- ALSA: hda/ca0132 - Add Recon3Di quirk to handle integrated
  sound on EVGA X99 Classified motherboard (git-fixes).
- commit f898dc5
* Fri Apr  3 2020 tiwai@suse.de
- slcan: Don't transmit uninitialized stack data in padding
  (CVE-2020-11494 bsc#1168424).
- commit 246f367
* Fri Apr  3 2020 wqu@suse.com
- btrfs: do not zero f_bavail if we have available space
  (bsc#1168081).
- commit 77d5937
* Thu Apr  2 2020 tiwai@suse.de
- USB: cdc-acm: fix close_delay and closing_wait units in
  TIOCSSERIAL (git-fixes).
- Refresh
  patches.suse/USB-cdc-acm-fix-rounding-error-in-TIOCSSERIAL.patch.
- commit 8731e73
* Thu Apr  2 2020 tiwai@suse.de
- USB: cdc-acm: restore capability check order (git-fixes).
- usb: gadget: f_fs: Fix use after free issue as part of queue
  failure (git-fixes).
- USB: serial: io_edgeport: fix slab-out-of-bounds read in
  edge_interrupt_callback (git-fixes).
- USB: serial: option: add Wistron Neweb D19Q1 (git-fixes).
- USB: serial: option: add BroadMobi BM806U (git-fixes).
- USB: serial: option: add support for ASKEY WWHC050 (git-fixes).
- usb: musb: fix crash with highmen PIO and usbmon (git-fixes).
- usb: gadget: composite: Inform controller driver of self-powered
  (git-fixes).
- usb: dwc3: gadget: Wrap around when skip TRBs (git-fixes).
- usb: dwc3: gadget: Don't clear flags before transfer ended
  (git-fixes).
- seccomp: Add missing compat_ioctl for notify (git-fixes).
- tpm: ibmvtpm: Wait for buffer to be set before proceeding
  (git-fixes).
- tpm: tpm2_bios_measurements_next should increase position index
  (git-fixes).
- tpm: tpm1_bios_measurements_next should increase position index
  (git-fixes).
- vti6: Fix memory leak of skb if input policy check fails
  (git-fixes).
- USB: serial: pl2303: add device-id for HP LD381 (git-fixes).
- USB: serial: option: add ME910G1 ECM composition 0x110b
  (git-fixes).
- usb: quirks: add NO_LPM quirk for RTL8153 based ethernet
  adapters (git-fixes).
- usb: host: xhci-plat: add a shutdown (git-fixes).
- USB: Disable LPM on WD19's Realtek Hub (git-fixes).
- usb: xhci: apply XHCI_SUSPEND_DELAY to AMD XHCI controller
  1022:145c (git-fixes).
- tty: fix compat TIOCGSERIAL checking wrong function ptr
  (git-fixes).
- tty: fix compat TIOCGSERIAL leaking uninitialized memory
  (git-fixes).
- seccomp: Check that seccomp_notif is zeroed out by the user
  (git-fixes).
- commit 6e62c53
* Thu Apr  2 2020 tiwai@suse.de
- mmc: core: Respect MMC_CAP_NEED_RSP_BUSY for eMMC sleep command
  (git-fixes).
- mmc: sdhci-tegra: Fix busy detection by enabling
  MMC_CAP_NEED_RSP_BUSY (git-fixes).
- mmc: sdhci-omap: Fix busy detection by enabling
  MMC_CAP_NEED_RSP_BUSY (git-fixes).
- mmc: core: Respect MMC_CAP_NEED_RSP_BUSY for erase/trim/discard
  (git-fixes).
- mmc: core: Allow host controllers to require R1B for CMD6
  (git-fixes).
- mmc: core: Default to generic_cmd6_time as timeout in
  __mmc_switch() (git-fixes).
- commit a7a7a34
* Thu Apr  2 2020 tiwai@suse.de
- media: i2c: video-i2c: fix build errors due to 'imply hwmon'
  (git-fixes).
- media: vivid: fix incorrect PA assignment to HDMI outputs
  (git-fixes).
- media: imx: imx7-media-csi: Fix video field handling
  (git-fixes).
- media: imx: imx7-media-csi: Remove unneeded register read
  (git-fixes).
- media: imx: imx7_mipi_csis: Power off the source when stopping
  streaming (git-fixes).
- media: xirlink_cit: add missing descriptor sanity checks
  (git-fixes).
- media: stv06xx: add missing descriptor sanity checks
  (git-fixes).
- media: ov519: add missing endpoint sanity checks (git-fixes).
- media: v4l2-fwnode: fix v4l2_fwnode_parse_link handling
  (git-fixes).
- media: ti-vpe: cal: fix a kernel oops when unloading module
  (git-fixes).
- media: tda10071: fix unsigned sign extension overflow
  (git-fixes).
- media: v4l2-core: fix entity initialization in
  device_register_subdev (git-fixes).
- media: v4l2-core: fix a use-after-free bug of sd->devnode
  (git-fixes).
- media: vsp1: tidyup VI6_HGT_LBn_H() macro (git-fixes).
- media: staging/imx: Missing assignment in
  imx_media_capture_device_register() (git-fixes).
- media: hantro: Read be32 words starting at every fourth byte
  (git-fixes).
- media: dib0700: fix rc endpoint lookup (git-fixes).
- media: flexcop-usb: fix endpoint sanity check (git-fixes).
- media: usbtv: fix control-message timeouts (git-fixes).
- commit 80da5af
* Thu Apr  2 2020 tbogendoerfer@suse.de
- ionic: print data for unknown xcvr type (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- commit e353704
* Thu Apr  2 2020 tbogendoerfer@suse.de
- ionic: remove lifs on fw reset (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: disable the queues on link down (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: check for queues before deleting (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: clean tx queue of unfinished requests (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: move irq request to qcq alloc (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: move debugfs add/delete to match alloc/free (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: check for linkup in watchdog (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: decouple link message from netdev state (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: check for NULL structs on teardown (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: clean irq affinity on queue deinit (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: ignore eexist on rx filter add (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: only save good lif dentry (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: leave dev cmd request contents alone on FW timeout
  (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: add timeout error checking for queue disable (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: add decode for IONIC_RC_ENOSUPP (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: remove adminq napi instance (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: deinit rss only if selected (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: stop devlink warn on mgmt device (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: add support for device id 0x1004 (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: print pci bus lane info (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: support ethtool rxhash disable (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: clean up bitflag usage (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: improve irq numa locality (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: remove pragma packed (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: keep ionic dev on lif init fail (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ice: add additional E810 device id (jsc#SLE-7966 bsc#1157177).
- ionic: make spdxcheck.py happy (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- net: ionic: Use scnprintf() for avoiding potential buffer
  overflow (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- commit dca9c4d
* Thu Apr  2 2020 oneukum@suse.com
- USB: serial: pl2303: add device-id for HP LD381 (git-fixes).
- commit f358c73
* Thu Apr  2 2020 ptesarik@suse.cz
- KVM: S390: protvirt: Introduce instruction data area bounce
  buffer (jsc#SLE-7512 bsc#1165545).
- Update kabi files.
- commit fb23a46
* Thu Apr  2 2020 oneukum@suse.com
- USB: serial: option: add ME910G1 ECM composition 0x110b
  (git-fixes).
- commit d394d40
* Thu Apr  2 2020 oneukum@suse.com
- usb: quirks: add NO_LPM quirk for RTL8153 based ethernet
  adapters (git-fixes).
- commit 4366db0
* Thu Apr  2 2020 oneukum@suse.com
- usb: host: xhci-plat: add a shutdown (git-fixes).
- commit d6ce28e
* Thu Apr  2 2020 tiwai@suse.de
- staging: wlan-ng: fix use-after-free Read in
  hfa384x_usbin_callback (git-fixes).
- staging: wlan-ng: fix ODEBUG bug in prism2sta_disconnect_usb
  (git-fixes).
- staging: rtl8188eu: Add ASUS USB-N10 Nano B1 to device table
  (git-fixes).
- net: qmi_wwan: add support for ASKEY WWHC050 (git-fixes).
- commit cae14b2
* Thu Apr  2 2020 oneukum@suse.com
- USB: Disable LPM on WD19's Realtek Hub (git-fixes).
- commit 545e2ba
* Thu Apr  2 2020 tiwai@suse.de
- maillbox: bcm-flexrm-mailbox: handle cmpl_pool dma allocation
  failure (git-fixes).
- HID: fix Kconfig word ordering (git-fixes).
- hwrng: imx-rngc - fix an error path (git-fixes).
- mac80211: set IEEE80211_TX_CTRL_PORT_CTRL_PROTO for nl80211 TX
  (git-fixes).
- mac80211: mark station unauthorized before key removal
  (git-fixes).
- mac80211: drop data frames without key on encrypted links
  (git-fixes).
- i2c: hix5hd2: add missed clk_disable_unprepare in remove
  (git-fixes).
- Input: synaptics - enable RMI on HP Envy 13-ad105ng (git-fixes).
- mac80211: Do not send mesh HWMP PREQ if HWMP is disabled
  (git-fixes).
- commit 1a471a8
* Thu Apr  2 2020 oneukum@suse.com
- usb: xhci: apply XHCI_SUSPEND_DELAY to AMD XHCI controller
  1022:145c (git-fixes).
- commit 84b09ec
* Thu Apr  2 2020 tiwai@suse.de
- crypto: caam - update xts sector size for large input length
  (git-fixes).
- crypto: caam/qi2 - fix chacha20 data size error (git-fixes).
- crypto: mxs-dcp - fix scatterlist linearization for hash
  (git-fixes).
- crypto: arm64/sha-ce - implement export/import (git-fixes).
- crypto: tcrypt - fix printed skcipher [a]sync mode (git-fixes).
- crypto: rng - Fix a refcounting bug in crypto_rng_reset()
  (git-fixes).
- ahci: Add Intel Comet Lake H RAID PCI ID (git-fixes).
- commit c24e76c
* Thu Apr  2 2020 oneukum@suse.com
- xhci: Do not open code __print_symbolic() in xhci trace events
  (git-fixes).
- commit fed4fc3
* Thu Apr  2 2020 ptesarik@suse.cz
- KVM: s390: protvirt: Add SCLP interrupt handling (jsc#SLE-7512
  bsc#1165545).
- Update kabi files.
- commit 4f3b7b8
* Thu Apr  2 2020 ptesarik@suse.cz
- s390/mm: provide memory management functions for protected
  KVM guests (jsc#SLE-7512 bsc#1165545).
- Update kabi files.
- commit 9c9391b
* Thu Apr  2 2020 oneukum@suse.com
- blacklist.conf: code cleanup that breaks kABI
- commit 0354bc9
* Thu Apr  2 2020 ptesarik@suse.cz
- KVM: s390: protvirt: Add KVM api documentation (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: introduce and enable KVM_CAP_S390_PROTECTED
  (jsc#SLE-7512 bsc#1165545).
- DOCUMENTATION: Protected virtual machine introduction and IPL
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Add UV cpu reset calls (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: do not inject interrupts after start
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Mask PSW interrupt bits for interception
  104 and 112 (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Support cmd 5 operation state (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: Report CPU state to Ultravisor
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: UV calls in support of diag308 0, 1
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Add program exception injection
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Only sync fmt4 registers (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: Do only reset registers that are accessible
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: disallow one_reg (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: STSI handling (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Write sthyi data to instruction data area
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390/mm: handle guest unpin events (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: handle secure guest prefix pages
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Add new gprs location handling
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Handle spec exception loops (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: Handle SE notification interceptions
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390/mm: Make pages accessible before destroying the guest
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Secure memory is not mergeable
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: add new variants of UV CALL (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: Add UV debug trace (jsc#SLE-7512
  bsc#1165545).
- KVM: s390/interrupt: do not pin adapter interrupt pages
  (jsc#SLE-7512 bsc#1165545).
- s390/protvirt: Add sysfs firmware interface for Ultravisor
  information (jsc#SLE-7512 bsc#1165545).
- s390/mm: add (non)secure page access exceptions handlers
  (jsc#SLE-7512 bsc#1165545).
- s390/protvirt: add ultravisor initialization (jsc#SLE-7512
  bsc#1165545).
- s390/protvirt: introduce host side setup (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: Also reset registers in sync regs for initial cpu
  reset (jsc#SLE-7512 bsc#1165545).
- KVM: s390: Add new reset vcpu API (jsc#SLE-7512 bsc#1165545).
- KVM: s390: Cleanup initial cpu reset (jsc#SLE-7512 bsc#1165545).
- KVM: s390: Cleanup kvm_arch_init error path (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: mark __insn32_query() as __always_inline
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: Disallow invalid bits in kvm_valid_regs and
  kvm_dirty_regs (jsc#SLE-7512 bsc#1165545).
- commit 8e1956a
* Thu Apr  2 2020 jslaby@suse.cz
- char/random: silence a lockdep splat with printk() (git-fixes).
- commit dce5b06
* Wed Apr  1 2020 msuchanek@suse.de
- powerpc/vmlinux.lds: Explicitly retain .gnu.hash (bsc#1148868).
- commit 0843abc
* Wed Apr  1 2020 msuchanek@suse.de
- powerpc/64/tm: Don't let userspace set regs->trap via sigreturn
  (bsc#1118338 ltc#173734).
- commit 3d1d975
* Wed Apr  1 2020 msuchanek@suse.de
- powerpc/pseries: Handle UE event for memcpy_mcsafe (jsc#SLE-7730
  jsc#SLE-8330).
- commit 823260c
* Wed Apr  1 2020 msuchanek@suse.de
- powerpc/xive: Use XIVE_BAD_IRQ instead of zero to catch non
  configured IPIs (bsc#1085030).
- commit e5b59c4
* Wed Apr  1 2020 mgorman@suse.de
- Update config files to disable CONFIG_KERNEL_HEADER_TEST (bsc#1168354).
- commit bc323e4
* Wed Apr  1 2020 msuchanek@suse.de
- powerpc/64: Prevent stack protection in early boot
  (bsc#1156395).
- powerpc/64: Setup a paca before parsing device tree etc
  (bsc#1156395).
- commit 196aec2
* Wed Apr  1 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/sched-core-Don-t-skip-remote-tick-for-idle-CPUs.patch
  patches.suse/timers-nohz-Update-NOHZ-load-in-remote-tick.patch
- commit 41bab0e
* Wed Apr  1 2020 mkubecek@suse.cz
- update patch metadata
- update upstream reference:
  patches.suse/net-bpfilter-remove-superfluous-testing-message.patch
- commit 9f9b3f8
* Wed Apr  1 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/media-go7007-Fix-URB-type-for-interrupt-handling.patch
  patches.suse/mmc-sdhci-introduce-sdhci_set_power_and_bus_voltage.patch
  patches.suse/mmc-sdhci-iproc-add-custom-set_power-callback-for-bcm2711.patch
- commit 69e3868
* Wed Apr  1 2020 jack@suse.cz
- ext4: Avoid ENOSPC when avoiding to reuse recently deleted
  inodes (bsc#1165019).
- commit ac99ab8
* Wed Apr  1 2020 tiwai@suse.de
- Delete patches.suse/i2c-i801-Do-not-add-ICH_RES_IO_SMI-for-the-iTCO_wdt-.patch (bsc#1168297)
  The patch caused a regression on DNV board.
- commit e88f35c
* Wed Apr  1 2020 lhenriques@suse.com
- ceph: fix memory leak in ceph_cleanup_snapid_map()
  (jsc#SES-1134).
- libceph: fix alloc_msg_with_page_vector() memory leaks
  (jsc#SES-1134).
- ceph: check POOL_FLAG_FULL/NEARFULL in addition to
  OSDMAP_FULL/NEARFULL (jsc#SES-1134).
- commit c22ae0e
* Wed Apr  1 2020 glin@suse.com
- net/bpfilter: remove superfluous testing message (bsc#1155518).
- commit 8cf8e50
* Wed Apr  1 2020 tbogendoerfer@suse.de
- vti: fix packet tx through bpf_redirect() in XinY cases
  (bsc#1154353).
- RDMA/core: Ensure security pkey modify is not lost
  (jsc#SLE-8449).
- net/mlx5e: Do not recover from a non-fatal syndrome
  (jsc#SLE-8464).
- net/mlx5e: Fix ICOSQ recovery flow with Striding RQ
  (jsc#SLE-8464).
- net/mlx5e: Fix missing reset of SW metadata in Striding RQ reset
  (jsc#SLE-8464).
- net/mlx5e: Enhance ICOSQ WQE info fields (jsc#SLE-8464).
- net/mlx5e: kTLS, Fix TCP seq off-by-1 issue in TX resync flow
  (jsc#SLE-8464).
- net/mlx5: DR, Fix postsend actions write length (jsc#SLE-8464).
- cxgb4: fix throughput drop during Tx backpressure (jsc#SLE-8389
  bnc#1151927 5.3.10).
- mlxsw: pci: Only issue reset when system is ready (bsc#1154488).
- net: ena: fix incorrect setting of the number of msix vectors
  (bsc#1154492).
- cxgb4: fix delete filter entry fail in unload path
  (jsc#SLE-8389).
- net_sched: keep alloc_hash updated after hash allocation
  (bsc#1154353).
- bpf/btf: Fix BTF verification of enum members in struct/union
  (bsc#1154353).
- bpf: Initialize storage pointers to NULL to prevent freeing
  garbage pointer (bsc#1154353).
- commit f057e20
* Wed Apr  1 2020 glin@suse.com
- bpf: Simplify reg_set_min_max_inv handling (bsc#1167722,
  CVE-2020-8835).
- bpf: Fix tnum constraints for 32-bit comparisons (bsc#1167722,
  CVE-2020-8835).
- bpf: Reliably preserve btf_trace_xxx types (bsc#1155518).
- commit 0eb8897
* Wed Apr  1 2020 tiwai@suse.de
- Crypto: chelsio - Fixes a deadlock between rtnl_lock and
  uld_mutex (git-fixes).
- Crypto: chelsio - Fixes a hang issue during driver registration
  (git-fixes).
- ath9k: Handle txpower changes even when TPC is disabled
  (git-fixes).
- mwifiex: set needed_headroom, not hard_header_len (git-fixes).
- brcmfmac: abort and release host after error (git-fixes).
- platform/x86: asus_wmi: Fix return value of fan_boost_mode_store
  (git-fixes).
- platform/x86: pmc_atom: Add Lex 2I385SW to critclk_systems
  DMI table (git-fixes).
- serial: sprd: Fix a dereference warning (git-fixes).
- firmware: arm_sdei: fix possible double-lock on hibernate
  error path (git-fixes).
- firmware: arm_sdei: fix double-lock on hibernate with shared
  events (git-fixes).
- fbdev/g364fb: Fix build failure (git-fixes).
- commit 342cd4b
* Wed Apr  1 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/modpost-move-the-namespace-field-in-Module.symvers-last.patch
- commit af8306c
* Wed Apr  1 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/ethtool-Factored-out-similar-ethtool-link-settings-f.patch
  patches.suse/modpost-return-error-if-module-is-missing-ns-imports.patch
  patches.suse/net-ethtool-Introduce-link_ksettings-API-for-virtual.patch
- commit 177866a
* Tue Mar 31 2020 mgorman@suse.de
- kthread: Do not preempt current task if it is going to
  call schedule() (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/fair: Improve spreading of utilization (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched: Avoid scale real weight down to zero (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/core: Distribute tasks within affinity masks (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Fix enqueue_task_fair warning (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/core: Remove duplicate assignment in sched_tick_remote()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- timers/nohz: Update NOHZ load in remote tick (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/core: Don't skip remote tick for idle CPUs (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit 1264b2f
* Tue Mar 31 2020 mgorman@suse.de
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/sched-fair-Fix-kernel-build-warning-in-test_idle_cores-for-SMT-NUMA.patch.
  patches.suse/sched-fair-Fix-reordering-of-enqueue-dequeue_task_fair.patch.
  patches.suse/sched-fair-Fix-runnable_avg-for-throttled-cfs.patch.
  patches.suse/sched-fair-Optimize-select_idle_core.patch.
  patches.suse/sched-fair-Take-into-account-runnable_avg-to-classify-group.patch.
  patches.suse/sched-fair-fix-condition-of-avg_load-calculation.patch.
  patches.suse/sched-fair-fix-statistics-for-find_idlest_group.patch.
  patches.suse/sched-fair-reorder-enqueue-dequeue_task_fair-path.patch.
  patches.suse/sched-numa-Acquire-RCU-lock-for-checking-idle-cores-during-NUMA-balancing.patch.
  patches.suse/sched-numa-Bias-swapping-tasks-based-on-their-preferred-node.patch.
  patches.suse/sched-numa-Distinguish-between-the-different-task_numa_migrate-failure-cases.patch.
  patches.suse/sched-numa-Find-an-alternative-idle-CPU-if-the-CPU-is-part-of-an-active-NUMA-balance.patch.
  patches.suse/sched-numa-Prefer-using-an-idle-cpu-as-a-migration-target-instead-of-comparing-tasks.patch.
  patches.suse/sched-numa-Stop-an-exhastive-search-if-a-reasonable-swap-candidate-or-idle-CPU-is-found.patch.
  patches.suse/sched-numa-Trace-when-no-candidate-CPU-was-found-on-the-preferred-node.patch.
  patches.suse/sched-numa-Use-similar-logic-to-the-load-balancer-for-moving-between-domains-with-spare-capacity.patch.
  patches.suse/sched-numa-replace-runnable_load_avg-by-load_avg.patch.
  patches.suse/sched-pelt-Add-a-new-runnable-average-signal.patch.
  patches.suse/sched-pelt-Remove-unused-runnable-load-average.patch.
  patches.suse/sched-topology-Don-t-enable-EAS-on-SMT-systems.patch.
- commit ecd3b4e
* Tue Mar 31 2020 ohering@suse.de
- clocksource/drivers/hyper-v: Make sched clock return nanoseconds
  correctly (git-fixes).
- commit 5751e50
* Tue Mar 31 2020 tiwai@suse.de
- thermal: Add a sanity check for invalid state at stats update
  (bsc#1166535).
- commit c368806
* Tue Mar 31 2020 glin@suse.com
- bpf: Undo incorrect __reg_bound_offset32 handling (bsc#1167722, CVE-2020-8835).
- commit ef6c245
* Mon Mar 30 2020 nmoreychaisemartin@suse.com
- net/mlx5_core: Set IB capability mask1 to fix ib_srpt connection failure (bsc#1167903)
- commit b92b72c
* Mon Mar 30 2020 ptesarik@suse.cz
- kabi/severities: Exempt IBM z/Architecture internal symbols.
- commit 61f446e
* Mon Mar 30 2020 nstange@suse.de
- kABI: shield fsnotify.h #include in libfs.c from kABI checker
  (bsc#1159198).
- commit c381542
* Mon Mar 30 2020 ptesarik@suse.cz
- s390/dasd: fix data corruption for thin provisioned devices
  (bsc#1167201 LTC#184504).
- Delete
  patches.suse/s390-dasd-disable-ese-support-due-to-possible-data-c.patch.
- commit 5c48dc0
* Mon Mar 30 2020 jeyu@suse.de
- Update patches.suse/modpost-move-the-namespace-field-in-Module.symvers-last.patch.
- update patch metadata/upstream references and move into the sorted section.
- commit 678cbc3
* Mon Mar 30 2020 ykaukab@suse.de
- usb: host: xhci-tegra: Implement basic ELPG support
  (bsc#1167765).
- usb: host: xhci-tegra: Add XUSB controller context
  (bsc#1167765).
- usb: host: xhci-tegra: Add support for XUSB context save/restore
  (bsc#1167765).
- usb: host: xhci-tegra: Enable runtime PM as late as possible
  (bsc#1167765).
- usb: host: xhci-tegra: Reuse stored register base address
  (bsc#1167765).
- usb: host: xhci-tegra: Extract firmware enable helper
  (bsc#1167765).
- usb: host: xhci-tegra: Use CNR as firmware ready indicator
  (bsc#1167765).
- usb: host: xhci-tegra: Avoid a fixed duration sleep
  (bsc#1167765).
- usb: host: xhci-tegra: Separate firmware request and load
  (bsc#1167765).
- usb: host: xhci-tegra: Fix "tega" -> "tegra" typo (bsc#1167765).
- commit da4b20d
* Mon Mar 30 2020 glin@suse.com
- net/bpfilter: fix dprintf usage for /dev/kmsg (bsc#1155518).
- bpf/btf: Fix BTF verification of enum members in struct/union
  (bsc#1155518).
- bpf: Fix cgroup ref leak in cgroup_bpf_inherit on out-of-memory
  (bsc#1155518).
- bpf: Initialize storage pointers to NULL to prevent freeing
  garbage pointer (bsc#1155518).
- commit 0e26614
* Sun Mar 29 2020 msuchanek@suse.de
- Disable hibernation on s390x (bsc#1167650).
- [mkubecek] update s390x kabi reference files (incompatible):
  CONFIG_HIBERNATION y->n, CONFIG_PM y->n
- commit f392251
* Sun Mar 29 2020 mkubecek@suse.cz
- series.conf: whitespace cleanup
- commit 963e602
* Sat Mar 28 2020 tonyj@suse.de
- blacklist.conf: add git-fixes that are in perf userspace package
- commit 4dabd66
* Sat Mar 28 2020 tonyj@suse.de
- perf/x86/amd: Add missing L2 misses event spec to AMD Family
  17h's event map (git-fixes).
- perf/x86/amd: Constrain Large Increment per Cycle events
  (git-fixes).
- perf/x86/intel/uncore: Fix missing marker for
  snr_uncore_imc_freerunning_events (git-fixes).
- perf/x86/intel: Fix PT PMI handling (git-fixes).
- perf/x86/intel/bts: Fix the use of page_private() (git-fixes).
- perf/x86/cstate: Update C-state counters for Ice Lake
  (git-fixes).
- commit c1a8c50
* Fri Mar 27 2020 bp@suse.de
- vhost: Check docket sk_family instead of call getname
  (bsc#1167629 CVE-2020-10942).
- commit b04a498
* Fri Mar 27 2020 msuchanek@suse.de
- powerpc/64s: Fix section mismatch warnings from boot code
  (bsc#1148868).
- commit 74f4898
* Fri Mar 27 2020 jbohac@suse.cz
- net: ena: Add PCI shutdown handler to allow safe kexec
  (bsc#1167421, bsc#1167423).
- commit 9ba04ea
* Fri Mar 27 2020 dwagner@suse.de
- lpfc kABI fixes for 12.8.0.0 (bsc#1164777 bsc#1164780
  bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.8.0.0 (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Remove prototype FIPS/DSS options from SLI-3
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Make debugfs ktime stats generic for NVME and SCSI
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix erroneous cpu limit of 128 on I/O statistics
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix crash in target side cable pulls hitting
  WAIT_FOR_UNREG (bsc#1164777 bsc#1164780 bsc#1165211
  jsc#SLE-8654).
- scsi: lpfc: Fix update of wq consumer index in
  lpfc_sli4_wq_release (bsc#1164777 bsc#1164780 bsc#1165211
  jsc#SLE-8654).
- scsi: lpfc: Fix crash after handling a pci error (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix scsi host template for SLI3 vports (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix lpfc overwrite of sg_cnt field in
  nvmefc_tgt_fcp_req (bsc#1164777 bsc#1164780 bsc#1165211
  jsc#SLE-8654).
- scsi: lpfc: Fix lockdep error - register non-static key
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix kasan slab-out-of-bounds error in
  lpfc_unreg_login (bsc#1164777 bsc#1164780 bsc#1165211
  jsc#SLE-8654).
- scsi: lpfc: fix spelling mistake "Notication" -> "Notification"
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: add RDF registration and Link Integrity FPIN logging
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: fc: Update Descriptor definition and add RDF and
  Link Integrity FPINs (bsc#1164777 bsc#1164780 bsc#1165211
  jsc#SLE-8654).
- commit 8ee63af
* Fri Mar 27 2020 dwagner@suse.de
- Refresh series.conf
- patches.suse/scsi-target-convert-boolean-se_dev_attrib-types-to-b.patch
- patches.suse/scsi-target-fix-unmap_zeroes_data-boolean-initialisa.patch
- patches.suse/scsi-target-use-an-enum-to-track-emulate_ua_intlck_c.patch
- commit ee2196b
* Fri Mar 27 2020 tiwai@suse.de
- Input: avoid BIT() macro usage in the serio.h UAPI header
  (git-fixes).
- Input: raydium_i2c_ts - fix error codes in
  raydium_i2c_boot_trigger() (git-fixes).
- commit 6acc495
* Fri Mar 27 2020 dwagner@suse.de
- net/mlx5: Add stub for mlx5_eswitch_mode (jsc#SLE-8464).
- commit 154e4ec
* Fri Mar 27 2020 mgorman@suse.de
- sched/fair: Fix negative imbalance in imbalance calculation
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit 4f5edea
* Thu Mar 26 2020 bp@suse.de
- perf/x86/amd: Add support for Large Increment per Cycle Events
  (jsc#SLE-11831).
- commit 43457d3
* Thu Mar 26 2020 ptesarik@suse.cz
- s390/setup: Fix secure ipl message (bsc#1163524 LTC#183960).
- commit dea2aed
* Thu Mar 26 2020 tbogendoerfer@suse.de
- blacklist.conf: bdd68860a044 is a dup of 17df5ae1b3e1
- commit d81f030
* Thu Mar 26 2020 tbogendoerfer@suse.de
- Documentation: networking: device drivers: Remove stray
  asterisks (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- Doc: networking/device_drivers/pensando: fix ionic.rst warnings
  (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: select CONFIG_NET_DEVLINK (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- commit 4199ffe
* Thu Mar 26 2020 tbogendoerfer@suse.de
- ionic: fix vf op lock usage (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: fix fw_status read (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: fix rxq comp packet type mask (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: clear compiler warning on hb use before set (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: restrict received packets to mtu size (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: add Rx dropped packet counter (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: drop use of subdevice tags (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: support sr-iov operations (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: ionic_if bits for sr-iov support (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: keep users rss hash across lif reset (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: Remove set but not used variable 'sg_desc' (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: update driver version (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: implement support for rx sgl (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: add a watchdog timer to monitor heartbeat (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: add heartbeat check (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: reverse an interrupt coalesce calculation (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: fix up struct name comments (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: add lif_quiesce to wait for queue activity to stop
  (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: implement ethtool set-fec (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: report users coalesce request (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: use wait_on_bit_lock() rather than open code (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: simplify returns in devlink info (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- dynamic_debug: provide dynamic_hex_dump stub (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: fix stats memory dereference (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Fix an error code in ionic_lif_alloc() (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: Remove unnecessary ternary operator in
  ionic_debugfs_add_ident (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: Remove unused including <linux/version.h> (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: Add coalesce and other features (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add RSS support (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: Add driver stats (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: Add netdev-event handling (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add Tx and Rx handling (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add initial ethtool support (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add async link status check and basic stats (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: Add Rx filter and rx_mode ndo support (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: Add management of rx filters (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add the basic NDO callbacks for netdev support
  (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: Add notifyq support (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add adminq action (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: Add basic adminq support (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add interrupts and doorbells (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add basic lif support (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add port management commands (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add hardware init and device commands (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: Add basic framework for IONIC Network device driver
  (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- Update config files.
- supported.conf: mark ionic supported (bsc#1167773 jsc#PM-1588 jsc#ECO-1386)
- commit 7927437
* Thu Mar 26 2020 msuchanek@suse.de
- update patch metadata and move it into sorted section
  Rename patches.suse/powerpc-pseries-fix-of_read_drc_info_cell-to-point-at-next-record.patch
  to patches.suse/powerpc-pseries-Fix-of_read_drc_info_cell-to-point-a.patch,
  update to upstream version, update upstream references and move into sorted section.
- commit 58f6e72
* Thu Mar 26 2020 mbrugger@suse.com
- Revert "net: bcmgenet: use RGMII loopback for MAC reset"
  (bsc#1167769).
- commit b9b9649
* Thu Mar 26 2020 jack@suse.cz
- ext4: Check for non-zero journal inum in ext4_calculate_overhead
  (bsc#1167288).
- commit 4a32d11
* Thu Mar 26 2020 tiwai@suse.de
- r8169: re-enable MSI on RTL8168c (git-fixes).
- net: phy: mdio-bcm-unimac: Fix clock handling (git-fixes).
- NFC: fdp: Fix a signedness bug in fdp_nci_send_patch()
  (git-fixes).
- vxlan: check return value of gro_cells_init() (git-fixes).
- net: phy: mdio-mux-bcm-iproc: check clk_prepare_enable()
  return value (git-fixes).
- iwlwifi: yoyo: don't add TLV offset when reading FIFOs
  (git-fixes).
- iwlwifi: consider HE capability when setting LDPC (git-fixes).
- gpiolib: acpi: Add quirk to ignore EC wakeups on HP x2 10 CHT +
  AXP288 model (git-fixes).
- gpiolib: acpi: Add quirk to ignore EC wakeups on HP x2 10 BYT +
  AXP288 model (git-fixes).
- gpiolib: acpi: Rework honor_wakeup option into an ignore_wake
  option (git-fixes).
- gpiolib: acpi: Correct comment for HP x2 10 honor_wakeup quirk
  (git-fixes).
- gpiolib: Fix irq_disable() semantics (git-fixes).
- intel_th: pci: Add Elkhart Lake CPU support (git-fixes).
- staging: rtl8188eu: Add device id for MERCUSYS MW150US v2
  (git-fixes).
- staging/speakup: fix get_word non-space look-ahead (git-fixes).
- drm/amd/amdgpu: Fix GPR read from debugfs (v2) (git-fixes).
- drm/lease: fix WARNING in idr_destroy (git-fixes).
- mmc: rtsx_pci: Fix support for speed-modes that relies on tuning
  (git-fixes).
- mmc: sdhci-cadence: set SDHCI_QUIRK2_PRESET_VALUE_BROKEN for
  UniPhier (git-fixes).
- altera-stapl: altera_get_note: prevent write beyond end of 'key'
  (git-fixes).
- spi: spi_register_controller(): free bus id on error paths
  (git-fixes).
- spi/zynqmp: remove entry that causes a cs glitch (git-fixes).
- spi: pxa2xx: Add CS control clock quirk (git-fixes).
- spi: qup: call spi_qup_pm_resume_runtime before suspending
  (git-fixes).
- spi: spi-omap2-mcspi: Support probe deferral for DMA channels
  (git-fixes).
- drm/amd/display: fix dcc swath size calculations on dcn1
  (git-fixes).
- drm/amd/display: Clear link settings on MST disable connector
  (git-fixes).
- drm/amdgpu: clean wptr on wb when gpu recovery (git-fixes).
- drm/mediatek: Find the cursor plane instead of hard coding it
  (git-fixes).
- drm/exynos: hdmi: don't leak enable HDMI_EN regulator if probe
  fails (git-fixes).
- drm/exynos: dsi: fix workaround for the legacy clock name
  (git-fixes).
- drm/exynos: dsi: propagate error value and silence meaningless
  warning (git-fixes).
- mmc: sdhci-cadence: use struct_size() helper (git-fixes).
- commit 963c6b7
* Thu Mar 26 2020 mhocko@suse.com
- selftests: vm: drop dependencies on page flags from mlock2 tests
  (bnc#1167384).
- commit 93ec8db
* Thu Mar 26 2020 mkubecek@suse.cz
- Update kabi files.
  Update from RC2 kernel submission (commit 2cc5c6f40e3f).
- commit bc36e97
* Wed Mar 25 2020 jack@suse.cz
- ext4: do not commit super on read-only bdev (bsc#1167288
  bsc#1167338).
- commit 3e272f3
* Wed Mar 25 2020 jack@suse.cz
- ext4: Unregister sysfs path before destroying jbd2 journal
  (bsc#1167338 bsc#1167288).
- commit 536d85c
* Wed Mar 25 2020 tiwai@suse.de
- struct phy_device kABI compatibility workaround (git-fixes).
- commit feeaa43
* Wed Mar 25 2020 tiwai@suse.de
- net: phy: fix MDIO bus PM PHY resuming (git-fixes).
- commit d42c758
* Wed Mar 25 2020 tiwai@suse.de
- net: phy: Avoid multiple suspends (git-fixes).
- commit c95182b
* Wed Mar 25 2020 tiwai@suse.de
- drm/bridge: dw-hdmi: fix AVI frame colorimetry (git-fixes).
- alarmtimer: Make alarmtimer platform device child of RTC device
  (git-fixes).
- commit ba8679d
* Wed Mar 25 2020 tiwai@suse.de
- virtio-blk: improve virtqueue error to BLK_STS (bsc#1167649).
- commit 0db14dd
* Wed Mar 25 2020 vbabka@suse.cz
- mm, slub: prevent kmalloc_node crashes and memory leaks
  (bsc#1167657, VM functionality).
- commit 4697f85
* Wed Mar 25 2020 vbabka@suse.cz
- mm: slub: be more careful about the double cmpxchg of freelist
  (bsc#1167657, VM functionality).
- commit e8bce3b
* Wed Mar 25 2020 vbabka@suse.cz
- mm: slub: add missing TID bump in kmem_cache_alloc_bulk()
  (bsc#1167657, VM functionality).
- commit 0108e02
* Wed Mar 25 2020 mkubecek@suse.cz
- fix patch metadata
- fix wrong Patch-mainline:
  patches.suse/0001-Revert-serial-uartlite-Add-runtime-support.patch
  patches.suse/0001-Revert-serial-uartlite-Do-not-use-static-struct-uart.patch
  patches.suse/0001-Revert-serial-uartlite-Move-the-uart-register.patch
  patches.suse/0001-pinctrl-baytrail-Really-serialize-all-register-acces.patch
- commit a449950
* Wed Mar 25 2020 oneukum@suse.com
- pinctrl: baytrail: Really serialize all register accesses
  (git-fixes).
- Refresh
  patches.suse/pinctrl-baytrail-Do-not-clear-IRQ-flags-on-direct-ir.patch.
- commit 3060b4c
* Wed Mar 25 2020 oneukum@suse.com
- Revert "serial-uartlite: Move the uart register" (git-fixes).
- commit 7d98e39
* Wed Mar 25 2020 oneukum@suse.com
- Revert "serial-uartlite: Do not use static struct uart_driver
  out of probe()" (git-fixes).
- commit 053f110
* Wed Mar 25 2020 oneukum@suse.com
- Revert "serial-uartlite: Add runtime support" (git-fixes).
- commit 869ee8e
* Tue Mar 24 2020 mkubecek@suse.cz
- update patch metadata
- improve Patch-mainline tag:
  patches.suse/rcuwait-Let-rcuwait_wake_up-return-whether-or-not-a-.patch
- commit f21d25e
* Tue Mar 24 2020 dbueso@suse.de
- rcuwait: Let rcuwait_wake_up() return whether or not a task was awoken (bsc#1167594).
- commit e399edf
* Tue Mar 24 2020 ptesarik@suse.cz
- Update config files: Increase NR_CPUS to 768 on arm64 to support the
  extra cores on a Marvell ThunderX3 SoC (jsc#SLE-9971).
- [mkubecek] update kabi reference files (incompatible):
  NR_CPUS raised from 480 to 768 on aarch64
- commit d52fc74
* Tue Mar 24 2020 bp@suse.de
- x86/MCE/AMD, EDAC/mce_amd: Add new Load Store unit McaType
  (jsc#SLE-11833).
- commit a9c59e2
* Tue Mar 24 2020 colyli@suse.de
- md: rename wb stuffs (bsc#1166003).
- Update with kabi fix for the above change,
  patches.kabi/md-backport-kabi.patch.
- Refresh for the above change,
  patches.suse/md-display-timeout-error.patch.
- commit eabced8
* Tue Mar 24 2020 colyli@suse.de
- raid5: remove worker_cnt_per_group argument from
  alloc_thread_groups (bsc#1166003).
- commit ffebcdb
* Tue Mar 24 2020 tiwai@suse.de
- KEYS: reaching the keys quotas correctly (bsc#1167517).
- commit 39a6103
* Tue Mar 24 2020 oneukum@suse.com
- kABI: more hooks for PCI changes (bsc#1141558).
- [mkubecek] update kabi reference files (incompatible):
  SUSE kabi padding added to some PCI related structures
- commit 29f5545
* Tue Mar 24 2020 tbogendoerfer@suse.de
- net: hns3: fix RMW issue for VLAN filter switch (bsc#1154353).
- netfilter: nf_tables: fix infinite loop when expr is not
  available (bsc#1154353).
- bnxt_en: fix error handling when flashing from file (sc#SLE-8371
  bsc#1153274 bsc#1163419).
- bnxt_en: reinitialize IRQs when MTU is modified (sc#SLE-8371
  bsc#1153274 bsc#1163419).
- bnxt_en: add newline to netdev_*() format strings (sc#SLE-8371
  bsc#1153274 bsc#1163419).
- bnxt_en: Issue PCIe FLR in kdump kernel to cleanup pending DMAs
  (sc#SLE-8371 bsc#1153274 bsc#1163419).
- bnxt_en: Improve device shutdown method (sc#SLE-8371 bsc#1153274
  bsc#1163419).
- commit 6ec4eab
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: add enospc debug messages for ticket failure   (bsc#1141456).
- Refresh
  patches.suse/btrfs-dump_space_info-when-encountering-total_bytes_pinned-0-at-umount.patch.
- commit b0b4b45
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: do not account global reserve in can_overcommit (bsc#1141456).
- commit cbebbcb
* Tue Mar 24 2020 mbrugger@suse.com
- supported.conf: mark synopsys_edac as supported.
  Used in Xilinx ZynqMP devices.
- commit 8d84988
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: use btrfs_try_granting_tickets in update_global_rsv (bsc#1141456).
- commit 2c7e1da
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: always reserve our entire size for the global reserve (bsc#1141456).
- commit 0ded727
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: change the minimum global reserve size (bsc#1141456).
- commit 20a34ab
* Tue Mar 24 2020 mbenes@suse.cz
- tracing: Add 'hist:' to hist trigger error log error string
  (bsc#1164917).
- commit c0e7e4a
* Tue Mar 24 2020 mbenes@suse.cz
- tracing: Add hist trigger error messages for sort specification
  (bsc#1164917).
- commit 9b80622
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: unexport the temporary exported functions (bsc#1162831).
- commit 795367d
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group cleanup code (bsc#1162831).
- Refresh
  patches.suse/0001-btrfs-qgroup-Always-free-PREALLOC-META-reserve-in-bt.patch.
- Refresh
  patches.suse/btrfs-dump_space_info-when-encountering-total_bytes_pinned-0-at-umount.patch.
- commit b3b0455
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the alloc_profile helpers (bsc#1162831).
- commit d4eb35f
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the chunk allocation code (bsc#1162831).
- commit 2694f31
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group space accounting helpers (bsc#1162831).
- commit cfbc882
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: export block group accounting helpers (bsc#1162831).
- commit 1701266
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the dirty bg writeout code (bsc#1162831).
- commit e9dcb00
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate inc/dec_block_group_ro code (bsc#1162831).
- Refresh
  patches.suse/0001-btrfs-qgroup-Always-free-PREALLOC-META-reserve-in-bt.patch.
- commit abe1d44
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: temporarily export btrfs_get_restripe_target (bsc#1162831).
- commit dcd4303
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group read/creation code (bsc#1162831).
- Refresh
  patches.suse/0001-btrfs-block-group-Fix-a-memory-leak-due-to-missing-b.patch.
- commit 4cffeef
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group removal code (bsc#1162831).
- commit 313711e
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: temporarily export inc_block_group_ro (bsc#1162831).
- commit 9260ebc
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group caching code (bsc#1162831).
- commit 610d6da
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: make caching_thread use btrfs_find_next_key (bsc#1162831).
- commit 32ee695
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: temporarily export fragment_free_space (bsc#1162831).
- commit b52844f
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: export the caching control helpers (bsc#1162831).
- commit 96ba87a
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: export the excluded extents helpers (bsc#1162831).
- commit 0c5df27
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: export the block group caching helpers (bsc#1162831).
- commit 01de231
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate nocow and reservation helpers (bsc#1162831).
- commit e4a70ac
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group ref counting stuff (bsc#1162831).
- commit 81d13e7
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group lookup code (bsc#1162831).
- commit fe38e12
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: move basic block_group definitions to their own header (bsc#1162831).
- commit a828471
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: move btrfs_add_free_space out of a header file (bsc#1162831).
- commit c5144d6
* Mon Mar 23 2020 tiwai@suse.de
- USB: cdc-acm: fix rounding error in TIOCSSERIAL (git-fixes).
- usb: typec: ucsi: displayport: Fix a potential race during
  registration (git-fixes).
- usb: typec: ucsi: displayport: Fix NULL pointer dereference
  (git-fixes).
- commit 864c13e
* Mon Mar 23 2020 tiwai@suse.de
- rtc: max8907: add missing select REGMAP_IRQ (git-fixes).
- serial: 8250_exar: add support for ACCES cards (git-fixes).
- serial: ar933x_uart: set UART_CS_{RX,TX}_READY_ORIDE
  (git-fixes).
- commit ae8a796
* Mon Mar 23 2020 tiwai@suse.de
- net: phy: bcm63xx: fix OOPS due to missing driver name
  (git-fixes).
- net: phy: avoid clearing PHY interrupts twice in irq handler
  (git-fixes).
- net: phy: mscc: fix firmware paths (git-fixes).
- net: phy: restore mdio regs in the iproc mdio driver
  (git-fixes).
- net: phy: fixed_phy: fix use-after-free when checking link GPIO
  (git-fixes).
- commit 9488907
* Mon Mar 23 2020 tiwai@suse.de
- intel_th: Fix user-visible error codes (git-fixes).
- iio: chemical: sps30: fix missing triggered buffer dependency
  (git-fixes).
- iio: st_sensors: remap SMO8840 to LIS2DH12 (git-fixes).
- iio: light: vcnl4000: update sampling periods for vcnl4040
  (git-fixes).
- iio: light: vcnl4000: update sampling periods for vcnl4200
  (git-fixes).
- iio: accel: adxl372: Set iio_chan BE (git-fixes).
- iio: magnetometer: ak8974: Fix negative raw values in sysfs
  (git-fixes).
- iio: trigger: stm32-timer: disable master mode when stopping
  (git-fixes).
- iio: adc: stm32-dfsdm: fix sleep in atomic context (git-fixes).
- iio: adc: at91-sama5d2_adc: fix differential channels in
  triggered mode (git-fixes).
- mmc: sdhci-of-at91: fix cd-gpios for SAMA5D2 (git-fixes).
- mac80211: rx: avoid RCU list traversal under mutex (git-fixes).
- commit 9bd80d9
* Mon Mar 23 2020 tiwai@suse.de
- HID: add ALWAYS_POLL quirk to lenovo pixart mouse (git-fixes).
- HID: google: add moonball USB id (git-fixes).
- HID: hid-bigbenff: fix race condition for scheduled work during
  removal (git-fixes).
- HID: hid-bigbenff: call hid_hw_stop() in case of error
  (git-fixes).
- HID: hid-bigbenff: fix general protection fault caused by
  double kfree (git-fixes).
- HID: i2c-hid: add Trekstor Surfbook E11B to descriptor override
  (git-fixes).
- HID: apple: Add support for recent firmware on Magic Keyboards
  (git-fixes).
- commit 5f6c3d6
* Mon Mar 23 2020 nborisov@suse.com
- Fix patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch
  Fix earlier refresh.
- commit 479cae8
* Mon Mar 23 2020 lyan@suse.com
- Revert sgi_iodev for kabi break (bsc#1166547).
- commit 1393f42
* Mon Mar 23 2020 ykaukab@suse.de
- apei/ghes: Do not delay GHES polling (bsc#1166982).
- commit b9901b6
* Mon Mar 23 2020 jslaby@suse.cz
- net: dsa: tag_qca: Make sure there is headroom for tag
  (networking-stable-20_02_19).
- net/sched: flower: add missing validation of TCA_FLOWER_FLAGS
  (networking-stable-20_02_19).
- net/sched: matchall: add missing validation of
  TCA_MATCHALL_FLAGS (networking-stable-20_02_19).
- net/smc: fix leak of kernel memory to user space
  (networking-stable-20_02_19).
- core: Don't skip generic XDP program execution for cloned SKBs
  (networking-stable-20_02_19).
- commit f564699
* Mon Mar 23 2020 jroedel@suse.de
- Refresh patches.suse/x86-mm-split-vmalloc_sync_all.patch.
- commit 52f4443
* Mon Mar 23 2020 jroedel@suse.de
- blacklist.conf: Add 02d715b4a818 iommu/vt-d: Fix RCU list debugging warnings
- commit edb9131
* Mon Mar 23 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/signal-avoid-double-atomic-counter-increments-for-user-accounting.patch
- commit 4c51946
* Mon Mar 23 2020 mgorman@suse.de
- sched/fair: Clear SMT siblings after determining the core is
  not idle (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit fafc10a
* Mon Mar 23 2020 mgorman@suse.de
- sched/fair: fix condition of avg_load calculation (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit db78afd
* Mon Mar 23 2020 mgorman@suse.de
- signal: avoid double atomic counter increments for user
  accounting (bnc#1167415 (Kernel core performance backports)).
- commit 6ff4a7e
* Mon Mar 23 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/cgroup-iterate-tasks-that-did-not-finish-do_exit.patch
- commit 5b30728
* Mon Mar 23 2020 bp@suse.de
- EDAC/synopsys: Do not print an error with back-to-back
  snprintf() calls (bsc#1152489).
- commit 3d8b07b
* Mon Mar 23 2020 bp@suse.de
- perf/amd/uncore: Replace manual sampling check with
  CAP_NO_INTERRUPT flag (bsc#1152489).
- commit 509a4ff
* Mon Mar 23 2020 bp@suse.de
- x86/mce: Fix logic and comments around MSR_PPIN_CTL
  (bsc#1152489).
- commit c2e64b7
* Mon Mar 23 2020 bp@suse.de
- x86/pkeys: Manually set X86_FEATURE_OSPKE to preserve existing
  changes (bsc#1152489).
- commit 062e80e
* Mon Mar 23 2020 lyan@suse.com
- KVM: arm/arm64: vgic: Use a single IO device per redistributor
  (bsc#1166547).
- commit 0aaedec
* Sun Mar 22 2020 bp@suse.de
- efi/x86: Add TPM related EFI tables to unencrypted mapping
  checks (bsc#1159816).
- commit 0d7e2e6
* Sat Mar 21 2020 tiwai@suse.de
- ALSA: hda/realtek - Enable the headset of Acer N50-600 with
  ALC662 (git-fixes).
- ALSA: hda/realtek - Enable headset mic of Acer X2660G with
  ALC662 (git-fixes).
- ALSA: seq: oss: Fix running status after receiving sysex
  (git-fixes).
- ALSA: seq: virmidi: Fix running status after receiving sysex
  (git-fixes).
- ALSA: pcm: oss: Remove WARNING from snd_pcm_plug_alloc() checks
  (git-fixes).
- ALSA: hda/realtek: Fix pop noise on ALC225 (git-fixes).
- ALSA: line6: Fix endless MIDI read loop (git-fixes).
- ALSA: pcm: oss: Avoid plugin buffer overflow (git-fixes).
- commit ed262e3
* Fri Mar 20 2020 ptesarik@suse.cz
- s390/pci: Fix possible deadlock in recover_store() (bsc#1165187
  LTC#184105).
- commit 121df27
* Fri Mar 20 2020 ptesarik@suse.cz
- s390/pci: Recover handle in clp_set_pci_fn() (bsc#1165187
  LTC#184105).
- commit 5d2c6ee
* Fri Mar 20 2020 ptesarik@suse.cz
- s390/pkey: fix missing length of protected key on return
  (git-fixes).
- s390/zcrypt: Fix CCA cipher key gen with clear key value
  function (git-fixes).
- commit 6bb7487
* Fri Mar 20 2020 ptesarik@suse.cz
- s390/mm: fix dynamic pagetable upgrade for hugetlbfs
  (bsc#1165181 LTC#184104).
- commit 5c2c836
* Fri Mar 20 2020 jeyu@suse.de
- module: avoid setting info->name early in case we can fall back to
  info->mod->name (git-fixes).
- commit eebf8d1
* Fri Mar 20 2020 jeyu@suse.de
- blacklist.conf: blacklist f6d061d61712
- commit 72a83b2
* Fri Mar 20 2020 mkoutny@suse.com
- cgroup: memcg: net: do not associate sock with unrelated cgroup
  (bsc#1167241).
- commit 844ea7f
* Fri Mar 20 2020 colyli@suse.de
- md: fix a typo s/creat/create (bsc#1166003).
- commit 5717a6b
* Fri Mar 20 2020 colyli@suse.de
- md/raid6: fix algorithm choice under larger PAGE_SIZE
  (bsc#1166003).
- raid6/test: fix a compilation warning (bsc#1166003).
- raid6/test: fix a compilation error (bsc#1166003).
- commit b4c3abd
* Fri Mar 20 2020 colyli@suse.de
- md-bitmap: small cleanups (bsc#1166003).
- md: make sure desc_nr less than MD_SB_DISKS (bsc#1166003).
- md: raid1: check rdev before reference in raid1_sync_request
  func (bsc#1166003).
- drivers/md/raid5.c: use the new spelling of
  RWH_WRITE_LIFE_NOT_SET (bsc#1166003).
- md: avoid invalid memory access for array sb->dev_roles
  (bsc#1166003).
- md/raid1: avoid soft lockup under high load (bsc#1166003).
- commit f5e32ec
* Fri Mar 20 2020 colyli@suse.de
- md: no longer compare spare disk superblock events in super_load
  (bsc#1166003).
- commit ac7ff9d
* Fri Mar 20 2020 colyli@suse.de
- md/bitmap: avoid race window between md_bitmap_resize and
  bitmap_file_clear_bit (bsc#1166003).
- commit 1195535
* Thu Mar 19 2020 mkoutny@suse.com
- cgroup: Iterate tasks that did not finish do_exit()
  (bsc#1167151).
- commit 16348dc
* Thu Mar 19 2020 yousaf.kaukab@suse.com
- arm64: fix config and supported.conf for MTD devices on NXP boards
  References: bsc#1167137
  Get rid of CONFIG_MTD_PHYSMAP_COMPAT and enable CONFIG_MTD_PHYSMAP_OF.
  Compat maps of zero length (CONFIG_MTD_PHYSMAP_LEN=0x0) doesn't make
  sense and driver initialization is bound to fail.
  Update supported.conf to include required modules.
- commit c23c1f0
* Thu Mar 19 2020 jeyu@suse.de
- modpost: return error if module is missing ns imports and
  MODULE_ALLOW_MISSING_NAMESPACE_IMPORTS=n (jsc#SLE-10158).
- Refresh patches.suse/supported-flag.
- Refresh patches.suse/supported-flag-modverdir.
- commit 686d15e
* Thu Mar 19 2020 msuchanek@suse.de
- cpufreq: powernv: Fix unsafe notifiers (bsc#1065729).
- cpufreq: powernv: Fix use-after-free (bsc#1065729).
- powerpc: fix hardware PMU exception bug on PowerVM compatibility
  mode systems (bsc#1056686).
- commit c0f95eb
* Wed Mar 18 2020 nborisov@suse.com
- Btrfs: fix race leading to metadata space leak after task
  received  signal (bsc#1141456).
- Refresh
  patches.suse/btrfs-run-btrfs_try_granting_tickets-if-a-priority-ticket-fails.patch.
- commit 0d2889a
* Wed Mar 18 2020 colyli@suse.de
- raid5: use bio_end_sector in r5_next_bio (bsc#1166003).
- raid5: remove STRIPE_OPS_REQ_PENDING (bsc#1166003).
- md: add feature flag MD_FEATURE_RAID0_LAYOUT (bsc#1166003).
- md/raid5: use bio_end_sector to calculate last_sector (bsc#1166003).
- commit 7e33890
* Wed Mar 18 2020 colyli@suse.de
- md raid0/linear: Mark array as 'broken' and fail BIOs if a member is
  gone (bsc#1166003).
- Refresh for the above change,
  patches.suse/md-raid0-avoid-RAID0-data-corruption-due-to-layout-c.patch.
- commit a563707
* Wed Mar 18 2020 colyli@suse.de
- raid5 improve too many read errors msg by adding limits (bsc#1166003).
- raid1: factor out a common routine to handle the
  completion of sync write (bsc#1166003).
- md: allow last device to be forcibly removed from RAID1/RAID10 (bsc#1166003).
- Update with kabi fix for the above change,
  patches.kabi/md-backport-kabi.patch
- md: Convert to use int_pow() (bsc#1166003).
- commit aa334d3
* Wed Mar 18 2020 hare@suse.de
- nvme: Translate more status codes to blk_status_t (bsc#1156510).
- nvme: Fix parsing of ANA log page (bsc#1166658).
- nvme: resync include/linux/nvme.h with nvmecli (bsc#1156510).
- commit 672f1cb
* Wed Mar 18 2020 colyli@suse.de
- md/raid10: end bio when the device faulty (bsc#1166003).
- Refresh for the above change,
  patches.suse/md-display-timeout-error.patch.
- commit 760aa49
* Wed Mar 18 2020 colyli@suse.de
- raid1: use an int as the return value of raise_barrier() (bsc#1166003).
- commit 5ac4a79
* Wed Mar 18 2020 jack@suse.cz
- ext4: potential crash on allocation error in
  ext4_alloc_flex_bg_array() (bsc#1166940).
- commit a1c176a
* Wed Mar 18 2020 tiwai@suse.de
- ARM: 8961/2: Fix Kbuild issue caused by per-task stack protector
  GCC plugin (git-fixes).
- ARM: 8958/1: rename missed uaccess .fixup section (git-fixes).
- ARM: 8957/1: VDSO: Match ARMv8 timer in cntvct_functional()
  (git-fixes).
- efi: Add a sanity check to efivar_store_raw() (git-fixes).
- drm/i915: be more solid in checking the alignment (git-fixes).
- mt76: fix array overflow on receiving too many fragments for
  a packet (git-fixes).
- ARM: imx: build v7_cpu_resume() unconditionally (git-fixes).
- drm/amd/display: remove duplicated assignment to grph_obj_type
  (git-fixes).
- commit 7fe5a8f
* Wed Mar 18 2020 tiwai@suse.de
- blacklist.conf: Add a reverted amdgpu entry
- commit 916aa15
* Tue Mar 17 2020 jack@suse.cz
- blktrace: fix dereference after null check (bsc#1159285).
- commit df5056f
* Tue Mar 17 2020 jack@suse.cz
- blacklist.conf: Blacklist d87683620489
- commit 87e4a94
* Tue Mar 17 2020 jack@suse.cz
- jbd2: fix ocfs2 corrupt when clearing block group bits
  (bsc#1166878).
- commit 4ccf692
* Tue Mar 17 2020 jack@suse.cz
- io_uring: fix __io_iopoll_check deadlock in io_sq_thread
  (bsc#1166876).
- commit 47c1bb0
* Tue Mar 17 2020 jack@suse.cz
- io_uring: prevent sq_thread from spinning when it should stop
  (bsc#1166875).
- commit 59a5904
* Tue Mar 17 2020 jack@suse.cz
- ecryptfs: replace BUG_ON with error handling code (bsc#1166874).
- commit 7eb7c45
* Tue Mar 17 2020 jack@suse.cz
- ecryptfs: fix a memory leak bug in ecryptfs_init_messaging()
  (bsc#1166872).
- commit 58a8bc1
* Tue Mar 17 2020 jack@suse.cz
- ecryptfs: fix a memory leak bug in parse_tag_1_packet()
  (bsc#1166871).
- commit c7ebfb4
* Tue Mar 17 2020 jack@suse.cz
- ext4: fix race between writepages and enabling EXT4_EXTENTS_FL
  (bsc#1166870).
- commit d4cc10a
* Tue Mar 17 2020 jack@suse.cz
- ext4: rename s_journal_flag_rwsem to s_writepages_rwsem
  (bsc#1166868).
- commit 3fea683
* Tue Mar 17 2020 jack@suse.cz
- ext4: fix potential race between s_flex_groups online resizing
  and access (bsc#1166867).
- commit 8b31558
* Tue Mar 17 2020 jack@suse.cz
- ext4: fix potential race between s_group_info online resizing
  and access (bsc#1166866).
- commit 8fec0cb
* Tue Mar 17 2020 jack@suse.cz
- ext4: fix potential race between online resizing and write
  operations (bsc#1166864).
- commit 8ac7c77
* Tue Mar 17 2020 jack@suse.cz
- ext4: add cond_resched() to __ext4_find_entry() (bsc#1166862).
- commit 098ad12
* Tue Mar 17 2020 jack@suse.cz
- ext4: fix a data race in EXT4_I(inode)->i_disksize
  (bsc#1166861).
- commit ff7b112
* Tue Mar 17 2020 jack@suse.cz
- ext4: don't assume that mmp_nodename/bdevname have NUL
  (bsc#1166860).
- commit 26f5b12
* Tue Mar 17 2020 jack@suse.cz
- block, bfq: get a ref to a group when adding it to a service
  tree (bsc#1166859).
- commit 0cc750a
* Tue Mar 17 2020 jack@suse.cz
- blacklist.conf: Blacklist 4d8340d0d4d9
- commit a9eb92c
* Tue Mar 17 2020 tiwai@suse.de
- i2c: gpio: suppress error on probe defer (git-fixes).
- i2c: i801: Do not add ICH_RES_IO_SMI for the iTCO_wdt device
  (git-fixes).
- iwlwifi: mvm: Do not require PHY_SKU NVM section for 3168
  devices (bsc#1166632).
- crypto: pcrypt - Fix user-after-free on module unload
  (git-fixes).
- iwlwifi: mvm: fix NVM check for 3168 devices (git-fixes).
- ASoC: pcm: update FE/BE trigger order based on the command
  (git-fixes).
- commit 0ca34dd
* Tue Mar 17 2020 bp@suse.de
- x86/amd_nb, char/amd64-agp: Use amd_nb_num() accessor
  (bsc#1152489).
- [mkubecek] update kabi files (incompatible):
  - drop amd_nb_misc_ids symbol (no longer exported so that we can add more
    device ids later)
- commit bb3cbed
* Mon Mar 16 2020 dbueso@suse.de
- sys/sysinfo: Respect boottime inside time namespace
  (bsc#1164648,jsc#SLE-11493).
- commit 695315f
* Mon Mar 16 2020 nborisov@suse.com
- btrfs: run btrfs_try_granting_tickets if a priority ticket fails
  (bsc#1141456).
- btrfs: only check priority tickets for priority flushing
  (bsc#1141456).
- btrfs: Account for trans_block_rsv in may_commit_transaction
  (bsc#1141456).
- btrfs: allow us to use up to 90%% of the global rsv for unlink
  (bsc#1141456).
- btrfs: Improve global reserve stealing logic (bsc#1141456).
- btrfs: force chunk allocation if our global rsv is larger than
  metadata (bsc#1141456).
- commit 0e267e6
* Mon Mar 16 2020 tzimmermann@suse.de
- drm/virtio: module_param_named() requires linux/moduleparam.h (bsc#1152489)
- commit bbc436c
* Mon Mar 16 2020 jroedel@suse.de
- iommu/vt-d: Fix debugfs register reads (bsc#1166769).
- commit acf3bd7
* Mon Mar 16 2020 nborisov@suse.com
- Refresh patches.suse/btrfs-dump_space_info-when-encountering-total_bytes_pinned-0-at-umount.patch.
- commit 867843d
* Mon Mar 16 2020 tzimmermann@suse.de
- drm/i915/gt: Close race between cacheline_retire and free (bsc#1152489)
  Additional changes:
  * Added i915_active_acquire_if_busy() to
  drivers/gpu/drm/i915/i915_active.{c,h}. See upstream
  commit b1e3177bd1d8f
- commit 0111275
* Mon Mar 16 2020 tzimmermann@suse.de
- drm/virtio: make resource id workaround runtime switchable. (bsc#1152489)
- commit 370ca9c
* Mon Mar 16 2020 jroedel@suse.de
- x86/ioremap: Map EFI runtime services data as encrypted for SEV
  (bsc#1160508).
- commit 27cbc80
* Mon Mar 16 2020 mkubecek@suse.cz
- Add kabi reference files - import from KotD (commit 49476dcf3399)
  Enable kabi checking for -default and -preempt flavors.
- commit fe7e9d8
* Mon Mar 16 2020 jroedel@suse.de
- iommu/vt-d: Populate debugfs if IOMMUs are detected
  (bsc#1166728).
- iommu/vt-d: Ignore devices with out-of-spec domain number
  (bsc#1166727).
- iommu/vt-d: Fix the wrong printing in RHSA parsing
  (bsc#1166726).
- iommu/vt-d: quirk_ioat_snb_local_iommu: replace WARN_TAINT
  with pr_warn + add_taint (bsc#1166729).
- iommu/vt-d: dmar: replace WARN_TAINT with pr_warn + add_taint
  (bsc#1166723).
- iommu/vt-d: Fix RCU-list bugs in intel_iommu_init()
  (bsc#1166725).
- iommu/dma: Fix MSI reservation allocation (bsc#1166722).
- iommu/vt-d: Fix a bug in intel_iommu_iova_to_phys() for huge
  page (bsc#1166724).
- commit eb2e9ee
* Sun Mar 15 2020 ailiopoulos@suse.com
- xfs: report corruption only as a regular error (bsc#1166687).
- commit abd2d39
* Sun Mar 15 2020 ailiopoulos@suse.com
- xfs: add a XFS_IS_CORRUPT macro (bsc#1166686).
- commit 877ee95
* Sun Mar 15 2020 ailiopoulos@suse.com
- xfs: make the assertion message functions take a mount parameter
  (bsc#1166685).
- commit 7bd7696
* Fri Mar 13 2020 ailiopoulos@suse.com
- xfs: check attribute leaf block structure (bsc#1166153).
- commit 1008e2c
* Fri Mar 13 2020 jslaby@suse.cz
- net: dsa: microchip: enable module autoprobe
  (networking-stable-20_02_09).
- net: dsa: b53: Always use dev->vlan_enabled in
  b53_configure_vlan() (networking-stable-20_02_09).
- net: stmmac: fix a possible endless loop
  (networking-stable-20_02_09).
- net: systemport: Avoid RBUF stuck in Wake-on-LAN mode
  (networking-stable-20_02_09).
- net: mvneta: move rx_dropped and rx_errors in per-cpu stats
  (networking-stable-20_02_09).
- qed: Fix timestamping issue for L2 unicast ptp packets
  (networking-stable-20_02_09).
- net: macb: Limit maximum GEM TX length in TSO
  (networking-stable-20_02_09).
- net: macb: Remove unnecessary alignment check for TSO
  (networking-stable-20_02_09).
- bonding/alb: properly access headers in bond_alb_xmit()
  (networking-stable-20_02_09).
- devlink: report 0 after hitting end in region read
  (networking-stable-20_02_09).
- net_sched: fix a resource leak in tcindex_set_parms()
  (networking-stable-20_02_09).
- commit c82701f
* Fri Mar 13 2020 nsaenzjulienne@suse.de
- mmc: sdhci: iproc: Add custom set_power() callback for bcm2711
  (bsc#1165954).
- mmc: sdhci: Introduce sdhci_set_power_and_bus_voltage()
  (bsc#1165954).
- commit a751850
* Fri Mar 13 2020 ailiopoulos@suse.com
- fs: add generic UNRESVSP and ZERO_RANGE ioctl handlers
  (bsc#1165806, bsc#1165807).
- commit 59a3783
* Fri Mar 13 2020 ailiopoulos@suse.com
- xfs: don't implement XFS_IOC_RESVSP / XFS_IOC_RESVSP64
  (bsc#1165806, bsc#1165807).
- commit 17753e3
* Fri Mar 13 2020 duwe@suse.de
- crypto: arm{,64} neon: memzero_explicit aes-cbc key
  (bsc#1165167, FIPS).
- commit cb788e3
* Fri Mar 13 2020 ptesarik@suse.cz
- Refresh
  patches.suse/scsi-ibmvfc-Avoid-loss-of-all-paths-during-SVC-node-.patch.
- commit bb81764
* Fri Mar 13 2020 tiwai@suse.de
- drm/i915: Defer semaphore priority bumping to a workqueue
  (git-fixes).
- drm/i915/gvt: Fix dma-buf display blur issue on CFL (git-fixes).
- drm/i915/gvt: Fix unnecessary schedule timer when no vGPU exits
  (git-fixes).
- nl80211: add missing attribute validation for channel switch
  (git-fixes).
- nl80211: add missing attribute validation for beacon report
  scanning (git-fixes).
- nl80211: add missing attribute validation for critical protocol
  indication (git-fixes).
- batman-adv: Don't schedule OGM for disabled interface
  (git-fixes).
- macvlan: add cond_resched() during multicast processing
  (git-fixes).
- nfc: add missing attribute validation for vendor subcommand
  (git-fixes).
- nfc: add missing attribute validation for deactivate target
  (git-fixes).
- nfc: add missing attribute validation for SE API (git-fixes).
- tipc: add missing attribute validation for MTU property
  (git-fixes).
- team: add missing attribute validation for array index
  (git-fixes).
- team: add missing attribute validation for port ifindex
  (git-fixes).
- macsec: add missing attribute validation for port (git-fixes).
- can: add missing attribute validation for termination
  (git-fixes).
- nl802154: add missing attribute validation for dev_type
  (git-fixes).
- nl802154: add missing attribute validation (git-fixes).
- firmware: imx: Align imx_sc_msg_req_cpu_start to 4 (git-fixes).
- firmware: imx: scu-pd: Align imx sc msg structs to 4
  (git-fixes).
- firmware: imx: misc: Align imx sc msg structs to 4 (git-fixes).
- firmware: imx: scu: Ensure sequential TX (git-fixes).
- tty:serial:mvebu-uart:fix a wrong return (git-fixes).
- usb: dwc3: gadget: Update chain bit correctly when using sg list
  (git-fixes).
- usb: storage: Add quirk for Samsung Fit flash (git-fixes).
- usb: quirks: add NO_LPM quirk for Logitech Screen Share
  (git-fixes).
- media: hantro: Fix broken media controller links (git-fixes).
- media: mc-entity.c: use & to check pad flags, not ==
  (git-fixes).
- media: v4l2-mem2mem.c: fix broken links (git-fixes).
- dmaengine: tegra-apb: Prevent race conditions of tasklet vs
  free list (git-fixes).
- dmaengine: tegra-apb: Fix use-after-free (git-fixes).
- audit: always check the netlink payload length in
  audit_receive_msg() (git-fixes).
- audit: fix error handling in audit_data_to_entry() (git-fixes).
- watchdog: da9062: do not ping the hw during stop() (git-fixes).
- habanalabs: patched cb equals user cb in device memset
  (git-fixes).
- habanalabs: do not halt CoreSight during hard reset (git-fixes).
- habanalabs: halt the engines before hard-reset (git-fixes).
- usb: gadget: serial: fix Tx stall after buffer overflow
  (git-fixes).
- usb: gadget: ffs: ffs_aio_cancel(): Save/restore IRQ flags
  (git-fixes).
- usb: gadget: composite: Support more than 500mA MaxPower
  (git-fixes).
- drm/modes: Allow DRM_MODE_ROTATE_0 when applying video mode
  parameters (git-fixes).
- drm/modes: Make sure to parse valid rotation value from cmdline
  (git-fixes).
- drm/msm/dsi/pll: call vco set rate explicitly (git-fixes).
- drm/msm/dsi: save pll state before dsi host is powered off
  (git-fixes).
- drm: msm: Fix return type of dsi_mgr_connector_mode_valid for
  kCFI (git-fixes).
- drm/msm/mdp5: rate limit pp done timeout warnings (git-fixes).
- ALSA: hda: do not override bus codec_mask in link_get()
  (git-fixes).
- vfio-ccw: Use the correct style for SPDX License Identifier
  (git-fixes).
- commit d192c28
* Fri Mar 13 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-padata-initialize-pd-cpu-with-effective-cpumask.patch
  patches.suse/0001-padata-pcrypt-take-CPU-hotplug-lock-internally-in-pa.patch
  patches.suse/0001-padata-unbind-parallel-jobs-from-specific-CPUs.patch
  patches.suse/0001-padata-use-separate-workqueues-for-parallel-and-seri.patch
  patches.suse/0001-workqueue-unconfine-alloc-apply-free_workqueue_attrs.patch
- commit c637d96
* Fri Mar 13 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/ibmvnic-Do-not-process-device-remove-during-device-r.patch
- commit aed6449
* Thu Mar 12 2020 tiwai@suse.de
- Move the upstreamed ipmi_si patch into sorted section
- commit ca4ab45
* Thu Mar 12 2020 dbueso@suse.de
- pid: Fix error return value in some cases
  (bsc#1164648,jsc#SLE-11493).
- commit 2c02126
* Thu Mar 12 2020 msuchanek@suse.de
- blacklist.conf: expand wildcards.
- commit 7232917
* Thu Mar 12 2020 tiwai@suse.de
- arm64: dts: qcom: Add Lenovo Yoga C630 (jsc#SLE-9418).
- commit 5c6966e
* Thu Mar 12 2020 tiwai@suse.de
- x86/intel: Disable HPET on Intel Ice Lake platforms (git-fixes).
- x86/intel: Disable HPET on Intel Coffee Lake H platforms
  (git-fixes).
- commit df3778b
* Thu Mar 12 2020 tiwai@suse.de
- pinctrl: core: Remove extra kref_get which blocks hogs being
  freed (git-fixes).
- pinctrl: imx: scu: Align imx sc msg structs to 4 (git-fixes).
- pinctrl: meson-gxl: fix GPIOX sdio pins (git-fixes).
- virtio_balloon: Adjust label in virtballoon_probe (git-fixes).
- virtio_ring: Fix mem leak with vring_new_virtqueue()
  (git-fixes).
- Revert "PM / devfreq: Modify the device name as devfreq(X)
  for sysfs" (git-fixes).
- nfc: pn544: Fix occasional HW initialization failure
  (git-fixes).
- NFC: pn544: Fix a typo in a debug message (git-fixes).
- gpio: xilinx: Fix bug where the wrong GPIO register is written
  to (git-fixes).
- irqchip/gic-v3: Only provision redistributors that are enabled
  in ACPI (git-fixes).
- virtio_balloon: prevent pfn array overflow (git-fixes).
- clk: Use parent node pointer during registration if necessary
  (git-fixes).
- gpu/drm: ingenic: Avoid null pointer deference in plane atomic
  update (git-fixes).
- gpio: gpio-grgpio: fix possible sleep-in-atomic-context bugs
  in grgpio_irq_map/unmap() (git-fixes).
- fore200e: Fix incorrect checks of NULL pointer dereference
  (git-fixes).
- NFC: port100: Convert cpu_to_le16(le16_to_cpu(E1) + E2) to
  use le16_add_cpu() (git-fixes).
- irqchip/mbigen: Set driver .suppress_bind_attrs to avoid remove
  problems (git-fixes).
- ACPICA: Disassembler: create buffer fields in
  ACPI_PARSE_LOAD_PASS1 (git-fixes).
- gpio: add gpiod_toggle_active_low() (git-fixes).
- XArray: Fix xas_find returning too many entries (git-fixes).
- XArray: Fix xa_find_after with multi-index entries (git-fixes).
- XArray: Fix infinite loop with entry at ULONG_MAX (git-fixes).
- XArray: Fix xas_pause at ULONG_MAX (git-fixes).
- commit aac43c5
* Thu Mar 12 2020 yousaf.kaukab@suse.com
- Revert "tick/common: Make tick_periodic() check for missing ticks"
  This reverts commit 4d65090f1171433dc9438813b674f86d4925eb9c.
  Patch causes hard lockup. See [1] for details. Issue is fixed with
  Marvell frimware v7.4.1
  [1]: https://lkml.org/lkml/2020/3/6/1245
- commit be5e348
* Thu Mar 12 2020 ptesarik@suse.cz
- Enable CONFIG_KEXEC_SIG on s390x (jsc#SLE-8923).
- commit 3dbf242
* Wed Mar 11 2020 tiwai@suse.de
- Update patch reference for console security fix (CVE-2020-8647 bsc#1162929 CVE-2020-8649 bsc#1162931)
- commit 3e9c1d2
* Wed Mar 11 2020 oneukum@suse.com
- padata, pcrypt: take CPU hotplug lock internally in
  padata_alloc_possible (git-fixes).
- commit aad348d
* Wed Mar 11 2020 mhocko@suse.com
- x86/mm: Split vmalloc_sync_all() (bsc#1165741).
- commit 6f59f79
* Wed Mar 11 2020 oneukum@suse.com
- workqueue: unconfine alloc/apply/free_workqueue_attrs()
  (git-fixes).
- commit 00cf9ef
* Wed Mar 11 2020 oneukum@suse.com
- crypto: pcrypt - Avoid deadlock by using per-instance padata
  queues (git-fixes).
- commit 2487df7
* Wed Mar 11 2020 oneukum@suse.com
- padata: unbind parallel jobs from specific CPUs (git-fixes).
- Refresh
  patches.suse/0001-padata-Remove-broken-queue-flushing.patch.
- commit f5446c1
* Wed Mar 11 2020 mkubecek@suse.cz
- patch metadata cleanup
- drop duplicate References line:
  patches.suse/sched-fair-fix-statistics-for-find_idlest_group.patch
- commit d4e3168
* Wed Mar 11 2020 mkubecek@suse.cz
- series.conf: tidy up
- "inherited SP1 patches for review" section is emtpy, drop the header
- drop a pointless comment
- commit d5cfa09
* Wed Mar 11 2020 oneukum@suse.com
- padata: use separate workqueues for parallel and serial work
  (git-fixes).
- commit 93a8f87
* Wed Mar 11 2020 nborisov@suse.com
- refresh and enable: patches.suse/btrfs-dump_space_info-when-encountering-total_bytes_pinned-0-at-umount.patch
- commit 0883fb3
* Wed Mar 11 2020 nborisov@suse.com
- refresh and enable: patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch
- commit e7ac692
* Wed Mar 11 2020 mgorman@suse.de
- sched/fair: Fix reordering of enqueue/dequeue_task_fair()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Fix runnable_avg for throttled cfs (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/topology: Don't enable EAS on SMT systems (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/numa: Acquire RCU lock for checking idle cores during
  NUMA balancing (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/fair: Fix kernel build warning in test_idle_cores()
  for !SMT NUMA (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- commit 54c1e7e
* Wed Mar 11 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-fix-statistics-for-find_idlest_group.patch.
- commit 19f7ff2
* Wed Mar 11 2020 jslaby@suse.cz
- vt: selection, push sel_lock up (bnc#1162928 CVE-2020-8648).
- vt: selection, push console lock down (bnc#1162928
  CVE-2020-8648).
- commit 826e708
* Wed Mar 11 2020 mkubecek@suse.cz
- supported.conf: cleanup
  Remove entries for modules which are only built into vmlinuz image and no
  longer as a module on any supported architecture.
- commit 442ceef
* Wed Mar 11 2020 tbogendoerfer@suse.de
- net: export netdev_next_lower_dev_rcu() (bsc#1154353).
- commit 50e6fb7
* Wed Mar 11 2020 mkubecek@suse.cz
- supported.conf: proper sort
  While having all modules belonging to internal KMPs (i.e. marked with
  "+foo-kmp" style guards) on top of supported.conf might seem intentional,
  it was in fact only a side effect of a bug in supported-conf-fixup which
  did not expect guards with a dash ('-').
  Sort the file properly now to avoid potential mistakes resulting from wrong
  order of entries.
- commit 26973fc
* Wed Mar 11 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-crypto-pcrypt-remove-padata-cpumask-notifier.patch
  patches.suse/0001-padata-Replace-delayed-timer-with-immediate-workqueu.patch
  patches.suse/0001-padata-allocate-workqueue-internally.patch
  patches.suse/0001-padata-initialize-pd-cpu-with-effective-cpumask.patch
  patches.suse/0001-padata-make-padata_do_parallel-find-alternate-callba.patch
  patches.suse/0001-padata-purge-get_cpu-and-reorder_via_wq-from-padata_.patch
  patches.suse/0001-virtio-blk-fix-hw_queue-stopped-on-arbitrary-error.patch
- commit bc937a8
* Wed Mar 11 2020 msuchanek@suse.de
- ibmvnic: Do not process device remove during device reset
  (bsc#1065729).
- commit cc9dad3
* Tue Mar 10 2020 msuchanek@suse.de
- ibmvnic: Warn unknown speed message only when carrier is present
  (bsc#1065729).
- commit e9a3130
* Tue Mar 10 2020 dbueso@suse.de
- arm64/spinlock: fix a -Wunused-function warning (bsc#1149032).
- locking/rwsem: Fix kernel crash when spinning on
  RWSEM_OWNER_UNKNOWN (bsc#1149032).
- futex: Fix kernel-doc notation warning (bsc#1149032).
- commit 4912275
* Tue Mar 10 2020 dbueso@suse.de
- Revert "ipc,sem: remove uneeded sem_undo_list lock usage in
  exit_sem()" (bsc#1159886).
- powerpc/spinlocks: Fix oops in __spin_yield() on bare metal
  (bsc#1149032).
- powerpc/spinlocks: Rename SPLPAR-only spinlocks (bsc#1149032).
- commit 4b45f4c
* Tue Mar 10 2020 oneukum@suse.com
- padata: initialize pd->cpu with effective cpumask (git-fixes).
- Refresh
  patches.suse/0001-padata-Remove-broken-queue-flushing.patch.
- commit c8738d9
* Tue Mar 10 2020 oneukum@suse.com
- padata: purge get_cpu and reorder_via_wq from padata_do_serial
  (git-fixes).
- commit 32854ac
* Tue Mar 10 2020 oneukum@suse.com
- padata: Replace delayed timer with immediate workqueue in
  padata_reorder (git-fixes).
- Refresh
  patches.suse/0001-padata-Remove-broken-queue-flushing.patch.
- commit ab62460
* Tue Mar 10 2020 oneukum@suse.com
- padata: Remove broken queue flushing (git-fixes).
- commit feb9def
* Tue Mar 10 2020 oneukum@suse.com
- crypto: pcrypt - remove padata cpumask notifier (git-fixes).
- commit 61ed2ae
* Tue Mar 10 2020 oneukum@suse.com
- padata: make padata_do_parallel find alternate callback CPU
  (git-fixes).
- commit 1bf4612
* Tue Mar 10 2020 oneukum@suse.com
- padata: allocate workqueue internally (git-fixes).
- commit c16372d
* Tue Mar 10 2020 tbogendoerfer@suse.de
- RDMA/odp: Ensure the mm is still alive before creating an
  implicit child (jsc#SLE-8449).
- IB/mlx5: Fix implicit ODP race (jsc#SLE-8446).
- RDMA/core: Fix pkey and port assignment in get_new_pps
  (jsc#SLE-8449).
- RDMA/rw: Fix error flow during RDMA context initialization
  (jsc#SLE-8449).
- RDMA/core: Fix use of logical OR in get_new_pps (jsc#SLE-8449).
- commit 76634af
* Tue Mar 10 2020 oneukum@suse.com
- virtio-blk: fix hw_queue stopped on arbitrary error (git-fixes).
- commit 1b95f96
* Tue Mar 10 2020 dwagner@suse.de
- i2c: exynos5: Remove IRQF_ONESHOT (bsc#1162702).
- i2c: hix5hd2: Remove IRQF_ONESHOT (bsc#1162702).
- commit b6d534c
* Tue Mar 10 2020 ailiopoulos@suse.com
- xfs: constify the buffer pointer arguments to error functions
  (bsc#1166226).
- commit a8f2d26
* Tue Mar 10 2020 jlee@suse.com
- Delete
  patches.suse/0057-acpi-Disable-APEI-error-injection-if-the-kernel-is-l.patch.
  Removed this patch because it was not sent to kernel mainline with other
  kernel lockdown patches. Maintainers didn't reponse for why this patch
  not be sent. So, I removed this patch to align mainline kernel.
- commit cfa2dff
* Tue Mar 10 2020 nsaenzjulienne@suse.de
- mmc: sdhci-pci-gli: Enable MSI interrupt for GL975x (git-fixes).
- commit b05ab91
* Tue Mar 10 2020 tzimmermann@suse.de
- drm/sun4i: Add separate DE3 VI layer formats (bsc#1152472)
- commit 9c87cd6
* Tue Mar 10 2020 tzimmermann@suse.de
- drm/virtio: fix resource id creation race (bsc#1152489)
- commit 875669e
* Tue Mar 10 2020 tzimmermann@suse.de
- drm/radeon: Inline drm_get_pci_dev (bsc#1152472)
- commit 27b152d
* Tue Mar 10 2020 tzimmermann@suse.de
- drm/i915: Update drm/i915 bug filing URL (bsc#1152489)
- commit e0978de
* Tue Mar 10 2020 nsaenzjulienne@suse.de
- Refresh: patches.suse/firmware-raspberrypi-introduce-vl805-init-routine.patch
  There is a missing inline in a function declaration. As this is a bug in
  the upstream submission, a subsequent series will be sent.
- commit 24cdb0d
* Tue Mar 10 2020 jlee@suse.com
- efi: fix a race and a buffer overflow while reading efivars
  via sysfs (bsc#1164893).
- commit 57ac0e8
* Tue Mar 10 2020 tzimmermann@suse.de
- drm/nouveau/kms/gv100-: Re-set LUT after clearing for modesets (bsc#1152472)
- commit 6746148
* Tue Mar 10 2020 tzimmermann@suse.de
- drm/vgem: Close use-after-free race in vgem_gem_create (bsc#1152472)
- commit 65490f2
* Tue Mar 10 2020 tzimmermann@suse.de
- Revert "drm/amd/display: Don't skip link training for empty dongle" (bsc#1152489)
- commit 62bee52
* Tue Mar 10 2020 tzimmermann@suse.de
- vgacon: Fix a UAF in vgacon_invert_region (bsc#1152472)
- commit b9949b5
* Tue Mar 10 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/usercopy-Avoid-soft-lockups-in-test_check_nonzero_us.patch
- commit 1ec8a33
* Tue Mar 10 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-iwlwifi-mvm-remove-d0i3_ap_sta_id.patch
  patches.suse/0001-iwlwifi-mvm-remove-last-leftovers-of-d0i3.patch
  patches.suse/0001-iwlwifi-mvm-remove-the-d0i3-entry-exit-flow.patch
  patches.suse/0001-iwlwifi-mvm-remove-the-tx-defer-for-d0i3.patch
  patches.suse/0001-iwlwifi-mvm-start-to-remove-the-code-for-d0i3.patch
  patches.suse/0001-iwlwifi-remove-all-the-d0i3-references.patch
- commit c0e601f
* Tue Mar 10 2020 mkubecek@suse.cz
- series.conf: cleanup
- move into sorted section
  patches.suse/scsi-target-fix-unmap_zeroes_data-boolean-initialisa.patch
  patches.suse/scsi-target-convert-boolean-se_dev_attrib-types-to-b.patch
  patches.suse/scsi-target-use-an-enum-to-track-emulate_ua_intlck_c.patch
- commit 2ee4b82
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: fix attr leaf header freemap.size underflow (bsc#1166164).
- commit 33188db
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: fix some memory leaks in log recovery (bsc#1166162).
- commit 0fc66f0
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: attach dquots before performing xfs_swap_extents
  (bsc#1166161).
- commit 1da5af8
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: range check ri_cnt when recovering log items (bsc#1166160).
- commit 90b681f
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: always log corruption errors (bsc#1166158).
- commit 4ceca97
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: replace -EIO with -EFSCORRUPTED for corrupt metadata
  (bsc#1166156).
- commit 8aae262
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: namecheck directory entry names before listing them
  (bsc#1166155).
- commit bd61b8e
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: namecheck attribute names before listing them
  (bsc#1166154).
- commit eddc1b8
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: cap longest free extent to maximum allocatable
  (bsc#1166152).
- commit 9db4cae
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: Fix deadlock between AGI and AGF when target_ip exists
  in xfs_rename() (bsc#1166149).
- commit 2f06de6
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: check log iovec size to make sure it's plausibly a buffer
  log format (bsc#1166147).
- commit 266b31b
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: convert EIO to EFSCORRUPTED when log contents are invalid
  (bsc#1166145).
- commit 343511d
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: also call xfs_file_iomap_end_delalloc for zeroing
  operations (bsc#1166144).
- commit 5e9fd03
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: fix inode fork extent count overflow (bsc#1166143).
- commit 016eaf4
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: log proper length of superblock (bsc#1166140).
- commit 3caa90e
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: convert inode to extent format after extent merge due to
  shift (bsc#1166136).
- commit d852ad3
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: Use WARN_ON_ONCE for bailout mount-operation (bsc#1166133).
- commit cc00b41
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: fix maxicount division by zero error (bsc#1166132).
- commit d8d261a
* Mon Mar  9 2020 jeyu@suse.de
- rpm/kabi.pl: account for namespace field being moved last
  Upstream is moving the namespace field in Module.symvers last in order to
  preserve backwards compatibility with kmod tools (depmod, etc). Fix the kabi.pl
  script to expect the namespace field last. Since split() ignores trailing empty
  fields and delimeters, switch to using tr to count how many fields/tabs are in
  a line. Also, in load_symvers(), pass LIMIT of -1 to split() so it does not
  strip trailing empty fields, as namespace is an optional field.
- commit a3bb253
* Mon Mar  9 2020 dbueso@suse.de
- lib/vdso: Only read hrtimer_res when needed in
  __cvdso_clock_getres() (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Check for right timens offsets after fork
  and exec (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Add a simple perf test for clock_gettime()
  (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Add timer offsets test
  (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Add procfs selftest
  (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Add a test for clock_nanosleep()
  (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Add a test for timerfd
  (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Add Time Namespace test for supported clocks
  (bsc#1164648,jsc#SLE-11493).
- fs/proc: Introduce /proc/pid/timens_offsets
  (bsc#1164648,jsc#SLE-11493).
- x86/vdso: Zap vvar pages when switching to a time namespace
  (bsc#1164648,jsc#SLE-11493).
- x86/vdso: On timens page fault prefault also VVAR page
  (bsc#1164648,jsc#SLE-11493).
- x86/vdso: Handle faults on timens page
  (bsc#1164648,jsc#SLE-11493).
- time: Allocate per-timens vvar page (bsc#1164648,jsc#SLE-11493).
- x86/vdso: Add time napespace page (bsc#1164648,jsc#SLE-11493).
- update x86_64 configs: GENERIC_VDSO_TIME_NS=y, TIME_NS=y
- x86/vdso: Provide vdso_data offset on vvar_page
  (bsc#1164648,jsc#SLE-11493).
- lib/vdso: Prepare for time namespace support
  (bsc#1164648,jsc#SLE-11493).
- refresh config files (drop TIME_NS - no longer available)
- x86/vdso: Restrict splitting VVAR VMA
  (bsc#1164648,jsc#SLE-11493).
- fs/proc: Respect boottime inside time namespace for /proc/uptime
  (bsc#1164648,jsc#SLE-11493).
- posix-timers: Make clock_nanosleep() time namespace aware
  (bsc#1164648,jsc#SLE-11493).
- hrtimers: Prepare hrtimer_nanosleep() for time namespaces
  (bsc#1164648,jsc#SLE-11493).
- alarmtimer: Make nanosleep() time namespace aware
  (bsc#1164648,jsc#SLE-11493).
- posix-timers: Make timer_settime() time namespace aware
  (bsc#1164648,jsc#SLE-11493).
- timerfd: Make timerfd_settime() time namespace aware
  (bsc#1164648,jsc#SLE-11493).
- time: Add do_timens_ktime_to_host() helper
  (bsc#1164648,jsc#SLE-11493).
- posix-clocks: Wire up clock_gettime() with timens offsets
  (bsc#1164648,jsc#SLE-11493).
- posix-timers: Use clock_get_ktime() in common_timer_get()
  (bsc#1164648,jsc#SLE-11493).
- posix-clocks: Introduce clock_get_ktime() callback
  (bsc#1164648,jsc#SLE-11493).
- alarmtimer: Provide get_timespec() callback
  (bsc#1164648,jsc#SLE-11493).
- alarmtimer: Rename gettime() callback to get_ktime()
  (bsc#1164648,jsc#SLE-11493).
- posix-clocks: Rename .clock_get_timespec() callbacks accordingly
  (bsc#1164648,jsc#SLE-11493).
- posix-clocks: Rename the clock_get() callback to
  clock_get_timespec() (bsc#1164648,jsc#SLE-11493).
- time: Add timens_offsets to be used for tasks in time namespace
  (bsc#1164648,jsc#SLE-11493).
- ns: Introduce Time Namespace (bsc#1164648,jsc#SLE-11493).
- update config files: TIME_NS=y (=n in s390x/zfcpdump)
- lib/vdso: Mark do_hres() and do_coarse() as __always_inline
  (bsc#1164648,jsc#SLE-11493).
- lib/vdso: Add unlikely() hint into vdso_read_begin()
  (bsc#1164648,jsc#SLE-11493).
- lib/vdso: Avoid duplication in __cvdso_clock_getres()
  (bsc#1164648,jsc#SLE-11493).
- lib/vdso: Let do_coarse() return 0 to simplify the callsite
  (bsc#1164648,jsc#SLE-11493).
- lib/vdso: Make __cvdso_clock_getres() static
  (bsc#1164648,jsc#SLE-11493).
- clone3: ensure copy_thread_tls is implemented
  (bsc#1163988,bsc#1164648,jsc#SLE-11493).
- ubsan, x86: Annotate and allow
  __ubsan_handle_shift_out_of_bounds() in uaccess regions
  (bsc#1164648,jsc#SLE-11493).
- fork: extend clone3() to support setting a PID
  (bsc#1164648,jsc#SLE-11493).
- clone3: add CLONE_CLEAR_SIGHAND (bsc#1164648,jsc#SLE-11493).
- tools headers UAPI: Sync sched.h with the kernel
  (bsc#1164648,jsc#SLE-11493).
- usercopy: Avoid soft lockups in test_check_nonzero_user()
  (bsc#1164648,jsc#SLE-11493).
- lib: test_user_copy: style cleanup (bsc#1164648,jsc#SLE-11493).
- usercopy: Add parentheses around assignment in
  test_copy_struct_from_user (bsc#1164648,jsc#SLE-11493).
- clone3: switch to copy_struct_from_user()
  (bsc#1164648,jsc#SLE-11493).
- lib: introduce copy_struct_from_user() helper
  (bsc#1164648,jsc#SLE-11493).
- sched: add kernel-doc for struct clone_args
  (bsc#1164648,jsc#SLE-11493).
- commit 992f679
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- kprobes: Fix optimize_kprobe()/unoptimize_kprobe() cancellation
  logic (git-fixes).
- commit d42d5d9
* Mon Mar  9 2020 dbueso@suse.de
- Delete
  patches.suse/clone3-ensure-copy_thread_tls-is-implemented.patch.
- commit 5c13d46
* Mon Mar  9 2020 oneukum@suse.com
- usb: core: port: do error out if usb_autopm_get_interface()
  fails (git-fixes).
- usb: core: hub: do error out if usb_autopm_get_interface()
  fails (git-fixes).
- commit 011bc72
* Mon Mar  9 2020 tiwai@suse.de
- Revert "drm/fbdev: Fallback to non tiled mode if all tiles
  not present" (bsc#1051510).
- commit 07e015b
* Mon Mar  9 2020 jeyu@suse.de
- modpost: move the namespace field in Module.symvers last
  (jsc#SLE-10158).
- Refresh patches.suse/supported-flag.
- commit d026ef9
* Mon Mar  9 2020 oneukum@suse.com
- USB: misc: iowarrior: add support for 2 OEMed devices
  (git-fixes).
- commit e40d2a1
* Mon Mar  9 2020 oneukum@suse.com
- USB: Fix novation SourceControl XL after suspend (git-fixes).
- commit 25b0137
* Mon Mar  9 2020 jroedel@suse.de
- KVM: VMX: check descriptor table exits on instruction emulation
  (bsc#1166091).
- commit bf59879
* Mon Mar  9 2020 tiwai@suse.de
- drm/i915/selftests: Fix return in assert_mmap_offset()
  (git-fixes).
- drm/i915: Program MBUS with rmw during initialization
  (git-fixes).
- drm/sun4i: Fix DE2 VI layer format support (git-fixes).
- drm/sun4i: de2/de3: Remove unsupported VI layer formats
  (git-fixes).
- drm/i915/gvt: Fix orphan vgpu dmabuf_objs' lifetime (git-fixes).
- drm/i915/gvt: Separate display reset from ALL_ENGINES reset
  (git-fixes).
- drm/amdgpu: Drop DRIVER_USE_AGP (git-fixes).
- drm/i915: Wean off drm_pci_alloc/drm_pci_free (git-fixes).
- drm/i915/gt: Protect defer_request() from new waiters
  (git-fixes).
- drm/msm/dpu: fix BGR565 vs RGB565 confusion (git-fixes).
- drm/amdgpu/gfx10: disable gfxoff when reading rlc clock
  (git-fixes).
- drm/amdgpu/gfx9: disable gfxoff when reading rlc clock
  (git-fixes).
- drm/amdgpu/soc15: fix xclk for raven (git-fixes).
- drm/amd/display: Check engine is not NULL before acquiring
  (git-fixes).
- drm/amd/display: Do not set optimized_require to false after
  plane disable (git-fixes).
- drm/msm: Set dma maximum segment size for mdss (git-fixes).
- drm/amdgpu/smu10: fix smu10_get_clock_by_type_with_voltage
  (git-fixes).
- drm/amdgpu/smu10: fix smu10_get_clock_by_type_with_latency
  (git-fixes).
- drm/amdgpu/display: handle multiple numbers of fclks in
  dcn_calcs.c (v2) (git-fixes).
- drm/amdkfd: Fix a bug in SDMA RLC queue counting under HWS mode
  (git-fixes).
- drm/amd/display: do not allocate display_mode_lib unnecessarily
  (git-fixes).
- drm/nouveau/disp/nv50-: prevent oops when no channel method
  map provided (git-fixes).
- drm/nouveau/mmu: fix comptag memory leak (git-fixes).
- drm/amd/display: fixup DML dependencies (git-fixes).
- drm/amd/display: Clear state after exiting fixed active VRR
  state (git-fixes).
- drm/nouveau/fault/gv100-: fix memory leak on module unload
  (git-fixes).
- drm/nouveau/drm/ttm: Remove set but not used variable 'mem'
  (git-fixes).
- drm/nouveau/gr/gk20a,gm200-: add terminators to method lists
  read from fw (git-fixes).
- drm/mediatek: handle events when enabling/disabling crtc
  (git-fixes).
- drm/amdkfd: Fix permissions of hang_hws (git-fixes).
- drm/amdgpu: fix KIQ ring test fail in TDR of SRIOV (git-fixes).
- drm: remove the newline for CRC source name (git-fixes).
- drm/amdgpu: Ensure ret is always initialized when using
  SOC15_WAIT_ON_RREG (git-fixes).
- drm/gma500: Fixup fbdev stolen size usage evaluation
  (git-fixes).
- drm/fbdev: Fallback to non tiled mode if all tiles not present
  (git-fixes).
- commit c42f713
* Mon Mar  9 2020 tiwai@suse.de
- dma-buf: free dmabuf->name in dma_buf_release() (git-fixes).
- dmaengine: imx-sdma: Fix the event id check to include RX
  event for UART6 (git-fixes).
- dmaengine: imx-sdma: fix context cache (git-fixes).
- dmaengine: coh901318: Fix a double lock bug in dma_tc_handle()
  (git-fixes).
- clocksource: davinci: only enable clockevents once tim34 is
  initialized (git-fixes).
- cmd64x: potential buffer overflow in cmd64x_program_timings()
  (git-fixes).
- dmaengine: Store module owner in dma_device struct (git-fixes).
- dmaengine: change alignment of mux_configure32 and
  fsl_edma_chan_mux (git-fixes).
- commit b143f5d
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- net: bcmgenet: Clear ID_MODE_DIS in EXT_RGMII_OOB_CTRL when
  not needed (git-fixes).
- dma-direct: relax addressability checks in dma_direct_supported
  (git-fixes).
- kprobes: Set unoptimized flag after unoptimizing code
  (git-fixes).
- dma-direct: don't check swiotlb=force in dma_direct_map_resource
  (git-fixes).
- Refresh: patches.suse/dma-direct-exclude-dma_direct_map_resource-from-the-min_low_pfn-check.patch
- dma/direct: turn ARCH_ZONE_DMA_BITS into a variable (git-fixes).
- Refresh: patches.suse/dma-direct-avoid-a-forward-declaration-for-phys_to_dma.patch
- Refresh: patches.suse/dma-mapping-treat-dev-bus_dma_mask-as-a-dma-limit.patch
- Refresh: patches.suse/dma-mapping-treat-dev-bus_dma_mask-as-a-dma-limit.patch
- commit ee87f08
* Mon Mar  9 2020 tiwai@suse.de
- blacklist.conf: Add dma/imx-sdma entries that have been reverted
- commit f53a68f
* Mon Mar  9 2020 tiwai@suse.de
- usb: core: hub: fix unhandled return by employing a void
  function (git-fixes).
- commit 9ef677e
* Mon Mar  9 2020 tiwai@suse.de
- usb: core: port: do error out if usb_autopm_get_interface()
  fails (git-fixes).
- usb: core: hub: do error out if usb_autopm_get_interface()
  fails (git-fixes).
- staging: vt6656: fix sign of rx_dbm to bb_pre_ed_rssi
  (git-fixes).
- vt: vt_ioctl: fix race in VT_RESIZEX (git-fixes).
- vt: fix scrollback flushing on background consoles (git-fixes).
- USB: misc: iowarrior: add support for the 100 device
  (git-fixes).
- usb: dwc2: Fix SET/CLEAR_FEATURE and GET_STATUS flows
  (git-fixes).
- usb: dwc2: Fix in ISOC request length checking (git-fixes).
- usb: gadget: composite: Fix bMaxPower for SuperSpeedPlus
  (git-fixes).
- usb: dwc3: gadget: Check for IOC/LST bit in TRB->ctrl fields
  (git-fixes).
- usb: gadget: udc-xilinx: Fix xudc_stop() kernel-doc format
  (git-fixes).
- USB: misc: iowarrior: add support for the 28 and 28L devices
  (git-fixes).
- USB: misc: iowarrior: add support for 2 OEMed devices
  (git-fixes).
- USB: Fix novation SourceControl XL after suspend (git-fixes).
- xhci: Fix memory leak when caching protocol extended capability
  PSI tables - take 2 (git-fixes).
- USB: quirks: blacklist duplicate ep on Sound Devices USBPre2
  (git-fixes).
- USB: core: add endpoint-blacklist quirk (git-fixes).
- usb: dwc3: debug: fix string position formatting mixup with
  ret and len (git-fixes).
- USB: hub: Don't record a connect-change event during
  reset-resume (git-fixes).
- usb: charger: assign specific number for enum value (git-fixes).
- usb: uas: fix a plug & unplug racing (git-fixes).
- USB: hub: Fix the broken detection of USB3 device in SMSC hub
  (git-fixes).
- xhci: apply XHCI_PME_STUCK_QUIRK to Intel Comet Lake platforms
  (git-fixes).
- xhci: fix runtime pm enabling for quirky Intel hosts
  (git-fixes).
- xhci: Force Maximum Packet size for Full-speed bulk devices
  to valid range (git-fixes).
- xprtrdma: Fix DMA scatter-gather list mapping imbalance
  (git-fixes).
- uio: fix a sleep-in-atomic-context bug in
  uio_dmem_genirq_irqcontrol() (git-fixes).
- usb: musb: omap2430: Get rid of musb .set_vbus for omap2430 glue
  (git-fixes).
- usb: gadget: udc: fix possible sleep-in-atomic-context bugs
  in gr_probe() (git-fixes).
- usb: dwc2: Fix IN FIFO allocation (git-fixes).
- usbip: Fix unsafe unaligned pointer usage (git-fixes).
- wan/hdlc_x25: fix skb handling (git-fixes).
- wan: ixp4xx_hss: fix compile-testing on 64-bit (git-fixes).
- watchdog/softlockup: Enforce that timestamp is valid on boot
  (git-fixes).
- usb: dwc3: use proper initializers for property entries
  (git-fixes).
- commit 7d830dc
* Mon Mar  9 2020 tiwai@suse.de
- tty: serial: fsl_lpuart: free IDs allocated by IDA (git-fixes).
- spi: bcm63xx-hsspi: Really keep pll clk enabled (git-fixes).
- spi: atmel-quadspi: fix possible MMIO window size overrun
  (git-fixes).
- spi: spidev: Fix CS polarity if GPIO descriptors are used
  (git-fixes).
- tty: serial: qcom_geni_serial: Fix RX cancel command failure
  (git-fixes).
- tty: serial: imx: setup the correct sg entry for tx dma
  (git-fixes).
- tty/serial: atmel: manage shutdown in case of RS485 or ISO7816
  mode (git-fixes).
- thunderbolt: Prevent crash if non-active NVMem file is read
  (git-fixes).
- tpm: Initialize crypto_id of allocated_banks to HASH_ALGO__LAST
  (git-fixes).
- soc/tegra: fuse: Fix build with Tegra194 configuration
  (git-fixes).
- tty: synclink_gt: Adjust indentation in several functions
  (git-fixes).
- tty: synclinkmp: Adjust indentation in several functions
  (git-fixes).
- commit f7b10ec
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- USB: pci-quirks: Add Raspberry Pi 4 quirk (bsc#1163560).
- soc: bcm2835: Sync xHCI reset firmware property with downstream
  (bsc#1163560).
- PCI: brcmstb: Wait for Raspberry Pi's firmware when present
  (bsc#1163560).
- firmware: raspberrypi: Introduce vl805 init routine
  (bsc#1163560).
- commit e30de5f
* Mon Mar  9 2020 tiwai@suse.de
- regulator: stm32-vrefbuf: fix a possible overshoot when
  re-enabling (git-fixes).
- staging: rtl8723bs: Fix potential overuse of kernel memory
  (git-fixes).
- staging: rtl8188eu: Fix potential overuse of kernel memory
  (git-fixes).
- staging: rtl8723bs: Fix potential security hole (git-fixes).
- staging: rtl8188eu: Fix potential security hole (git-fixes).
- staging: rtl8723bs: fix copy of overlapping memory (git-fixes).
- serial: 8250: Check UPF_IRQ_SHARED in advance (git-fixes).
- serdev: ttyport: restore client ops on deregistration
  (git-fixes).
- reset: uniphier: Add SCSSI reset control for each channel
  (git-fixes).
- remoteproc: Initialize rproc_class before use (git-fixes).
- staging: rtl8188: avoid excessive stack usage (git-fixes).
- rtw88: fix rate mask for 1SS chip (git-fixes).
- rtlwifi: rtl_pci: Fix -Wcast-function-type (git-fixes).
- commit b3aad35
* Mon Mar  9 2020 tiwai@suse.de
- phy: mapphone-mdm6600: Fix timeouts by adding wake-up handling
  (git-fixes).
- phy: mapphone-mdm6600: Fix write timeouts with shorter GPIO
  toggle interval (git-fixes).
- qmi_wwan: unconditionally reject 2 ep interfaces (git-fixes).
- radeon: insert 10ms sleep in dce5_crtc_load_lut (git-fixes).
- pinctrl: baytrail: Do not clear IRQ flags on direct-irq enabled
  pins (git-fixes).
- pinctrl: sh-pfc: sh7269: Fix CAN function GPIOs (git-fixes).
- pinctrl: sh-pfc: sh7264: Fix CAN function GPIOs (git-fixes).
- r8169: check that Realtek PHY driver module is loaded
  (git-fixes).
- commit 1f5e949
* Mon Mar  9 2020 tiwai@suse.de
- PCI: Fix pci_add_dma_alias() bitmask size (git-fixes).
- PCI: Increase D3 delay for AMD Ryzen5/7 XHCI controllers
  (git-fixes).
- PCI: Add generic quirk for increasing D3hot delay (git-fixes).
- PCI: iproc: Apply quirk_paxc_bridge() for module as well as
  built-in (git-fixes).
- commit 124e17e
* Mon Mar  9 2020 tiwai@suse.de
- mac80211: Remove a redundant mutex unlock (git-fixes).
- ipmi:ssif: Handle a possible NULL pointer reference (git-fixes).
- mac80211: fix wrong 160/80+80 MHz setting (git-fixes).
- mac80211: consider more elements in parsing CRC (git-fixes).
- iwlwifi: mvm: Check the sta is not NULL in iwl_mvm_cfg_he_sta()
  (git-fixes).
- iwlwifi: mvm: Fix thermal zone registration (git-fixes).
- media: uvcvideo: Add a quirk to force GEO GC6500 Camera
  bits-per-pixel value (git-fixes).
- media: sti: bdisp: fix a possible sleep-in-atomic-context bug
  in bdisp_device_run() (git-fixes).
- media: i2c: mt9v032: fix enum mbus codes and frame sizes
  (git-fixes).
- media: v4l2-device.h: Explicitly compare grp{id,mask} to zero
  in v4l2_device macros (git-fixes).
- media: cx23885: Add support for AVerMedia CE310B (git-fixes).
- orinoco: avoid assertion in case of NULL pointer (git-fixes).
- iwlegacy: Fix -Wcast-function-type (git-fixes).
- ipw2x00: Fix -Wcast-function-type (git-fixes).
- commit 57f0620
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- PCI: brcmstb: Fix build on 32bit ARM platforms with older
  compilers (jsc#SLE-7772).
- commit ca7a98f
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- delete: patches.suse/linux-log2-h-add-roundup-rounddown_pow_two64-family-of-functions.patch
  Not needed anymore
- commit c7ab3e3
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- update and move into sorted section: patches.suse/pci-brcmstb-add-msi-support.patch
- commit 71e1948
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- refresh and move into sorted section:
  patches.suse/pci-brcmstb-add-broadcom-stb-pcie-host-controller-driver.patch
- commit b774a70
* Mon Mar  9 2020 martin.wilck@suse.com
- drm/i915/execlists: Always force a context reload when rewinding
  RING_TAIL (bsc#1161207).
- commit 8af101c
* Mon Mar  9 2020 vbabka@suse.cz
- Refresh
  patches.suse/mm-hotplug-fix-page-online-with-debug_pagealloc-compiled-but-not-enabled.patch.
- commit went mainline from a non-git maintainer repository, add proper metadata
- commit e59a6b6
* Mon Mar  9 2020 tiwai@suse.de
- blacklist.conf: Add input/rmi4 revert patch that was already blacklisted
- commit 730af68
* Mon Mar  9 2020 tiwai@suse.de
- i2c: altera: Fix potential integer overflow (git-fixes).
- Input: synaptics - remove the LEN0049 dmi id from topbuttonpad
  list (git-fixes).
- Input: synaptics - enable SMBus on ThinkPad L470 (git-fixes).
- Input: synaptics - switch T470s to RMI4 by default (git-fixes).
- Input: edt-ft5x06 - work around first register access error
  (git-fixes).
- ide: serverworks: potential overflow in svwks_set_pio_mode()
  (git-fixes).
- commit 99877db
* Mon Mar  9 2020 tiwai@suse.de
- hwmon: (adt7462) Fix an error return in ADT7462_REG_VOLT()
  (git-fixes).
- HID: alps: Fix an error handling path in
  'alps_input_configured()' (git-fixes).
- HID: hiddev: Fix race in in hiddev_disconnect() (git-fixes).
- HID: core: increase HID report buffer size to 8KiB (git-fixes).
- HID: core: fix off-by-one memset in hid_report_raw_event()
  (git-fixes).
- HID: ite: Only bind to keyboard USB interface on Acer SW5-012
  keyboard dock (git-fixes).
- commit 3cf2320
* Mon Mar  9 2020 tiwai@suse.de
- floppy: check FDC index for errors before assigning it
  (CVE-2020-9383 bsc#1165111).
- commit 47c6d94
* Mon Mar  9 2020 tiwai@suse.de
- crypto: rename sm3-256 to sm3 in hash_algo_name (git-fixes).
- driver core: platform: fix u32 greater or equal to zero
  comparison (git-fixes).
- driver core: Print device when resources present in
  really_probe() (git-fixes).
- driver core: platform: Prevent resouce overflow from causing
  infinite loops (git-fixes).
- crypto: chtls - Fixed memory leak (git-fixes).
- commit 934bfba
* Mon Mar  9 2020 tiwai@suse.de
- bus: ti-sysc: Fix 1-wire reset quirk (git-fixes).
- cfg80211: add missing policy for NL80211_ATTR_STATUS_CODE
  (git-fixes).
- cfg80211: check wiphy driver existence for drvinfo report
  (git-fixes).
- commit 518082f
* Mon Mar  9 2020 tiwai@suse.de
- ACPI: watchdog: Fix gas->access_width usage (git-fixes).
- ACPICA: Introduce ACPI_ACCESS_BYTE_WIDTH() macro (git-fixes).
- b43legacy: Fix -Wcast-function-type (git-fixes).
- ACPI: button: Add DMI quirk for Razer Blade Stealth 13 late
  2019 lid switch (git-fixes).
- commit d4fdd22
* Mon Mar  9 2020 tiwai@suse.de
- amdgpu/gmc_v9: save/restore sdpif regs during S3 (git-fixes).
- ASoC: Intel: sof_rt5682: Ignore the speaker amp when there
  isn't one (git-fixes).
- ASoC: soc-topology: fix endianness issues (git-fixes).
- ASoC: SOF: Intel: hda: Add iDisp4 DAI (git-fixes).
- ASoC: intel: sof_rt5682: Add support for tgl-max98357a-rt5682
  (git-fixes).
- ASoC: intel: sof_rt5682: Add quirk for number of HDMI DAI's
  (git-fixes).
- ASoC: SOF: Intel: hda: Fix SKL dai count (git-fixes).
- commit b3e9ee6
* Mon Mar  9 2020 tiwai@suse.de
- ALSA: ctl: allow TLV read operation for callback type of
  element in locked case (git-fixes).
- ALSA: usx2y: Adjust indentation in snd_usX2Y_hwdep_dsp_status
  (git-fixes).
- commit d5a4d9f
* Mon Mar  9 2020 tiwai@suse.de
- ASoC: wm8741: Fix typo in Kconfig prompt (git-fixes).
- ASoC: SOF: Fix snd_sof_ipc_stream_posn() (git-fixes).
- ASoC: dapm: Correct DAPM handling of active widgets during
  shutdown (git-fixes).
- ASoC: Intel: Skylake: Fix available clock counter incrementation
  (git-fixes).
- ASoC: meson: g12a: add tohdmitx reset (git-fixes).
- ASoC: pcm512x: Fix unbalanced regulator enable call in probe
  error path (git-fixes).
- ASoC: soc-core: fix for_rtd_codec_dai_rollback() macro
  (git-fixes).
- ASoC: topology: Fix memleak in soc_tplg_manifest_load()
  (git-fixes).
- ASoC: topology: Fix memleak in soc_tplg_link_elems_load()
  (git-fixes).
- ASoC: pcm: Fix possible buffer overflow in dpcm state sysfs
  output (git-fixes).
- ASoC: intel: skl: Fix possible buffer overflow in debug outputs
  (git-fixes).
- ASoC: intel: skl: Fix pin debug prints (git-fixes).
- ALSA: hda/realtek - Enable the headset of ASUS B9450FA with
  ALC294 (git-fixes).
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus
  Master (git-fixes).
- ALSA: hda/realtek - Add Headset Button supported for ThinkPad X1
  (git-fixes).
- ALSA: hda/realtek - Add Headset Mic supported (git-fixes).
- ALSA: hda/realtek - Fix a regression for mute led on Lenovo
  Carbon X1 (git-fixes).
- commit 533eaf3
* Sat Mar  7 2020 msuchanek@suse.de
- powerpc/pseries: fix of_read_drc_info_cell() to point at next
  record (bsc#1165980 ltc#183834).
- commit 1ae6694
* Sat Mar  7 2020 msuchanek@suse.de
- libnvdimm/pfn_dev: Don't clear device memmap area during
  generic namespace probe (bsc#1165929 bsc#1165950 bsc#1166323).
- commit dd773b9
* Fri Mar  6 2020 ailiopoulos@suse.com
- xfs: also remove cached ACLs when removing the underlying attr
  (bsc#1165873).
- commit 8ec3453
* Fri Mar  6 2020 ddiss@suse.de
- patches.suse/scsi-target-use-an-enum-to-track-emulate_ua_intlck_c.patch:
  (bsc#1163617).
- patches.suse/scsi-target-convert-boolean-se_dev_attrib-types-to-b.patch:
  (bsc#1163617).
- patches.suse/scsi-target-fix-unmap_zeroes_data-boolean-initialisa.patch:
  (bsc#1163617).
- commit 182fa83
* Fri Mar  6 2020 dwagner@suse.de
- sched/rt, workqueue: Use PREEMPTION (bsc#1162702).
- sched/core: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, locking: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, mm: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, btrfs: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, fs: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, xen: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, net: Use CONFIG_PREEMPTION.patch (bsc#1162702).
- sched/rt, xtensa: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, sparc: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, sh: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, s390: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, riscv: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, parisc: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, nios2: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, nds32: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, MIPS: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, microblaze: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, ia64: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, hexagon: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, h8300: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, csky: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, c6x: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, ARC: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, powerpc: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, arm64: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, ARM: Use CONFIG_PREEMPTION (bsc#1162702).
- rcu: Use CONFIG_PREEMPTION where appropriate (bsc#1162702).
- m68k/coldfire: Use CONFIG_PREEMPTION (bsc#1162702).
- backlight: Kconfig: jornada720: Use CONFIG_PREEMPTION
  (bsc#1162702).
- drm/i810: Refer to `PREEMPTION' in comment (bsc#1162702).
- media: cec-gpio: Use CONFIG_PREEMPTION (bsc#1162702).
- commit d311e76
* Fri Mar  6 2020 dwagner@suse.de
- x86/kvm: Use CONFIG_PREEMPTION (bsc#1162702).
- x86/dumpstack: Indicate PREEMPT_RT in dumps (bsc#1162702).
- x86: Use CONFIG_PREEMPTION (bsc#1162702).
  Refresh patches.suse/x86-xen-32-Make-xen_iret_crit_fixup-independent-of-f.patch
- kprobes: Use CONFIG_PREEMPTION (bsc#1162702).
- tracing: Use CONFIG_PREEMPTION (bsc#1162702).
- locking/spinlocks: Use CONFIG_PREEMPTION (bsc#1162702).
- rcu: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/preempt: Use CONFIG_PREEMPTION where appropriate
  (bsc#1162702).
  Refresh patches.suse/sched-fair-Rework-load_balance.patch
- commit 6a43532
* Fri Mar  6 2020 jslaby@suse.cz
- selftests: Install settings files to fix TIMEOUT failures
  (git-fixes).
- commit b511dec
* Fri Mar  6 2020 msuchanek@suse.de
- powerpc/smp: Use nid as fallback for package_id (bsc#1165813
  ltc#184091).
- commit 6ff58c9
* Fri Mar  6 2020 msuchanek@suse.de
- update powerpc fadump patches
- update to version in maintainer repository and move into sorted section:
  Refresh patches.suse/powerpc-fadump-sysfs-for-fadump-memory-reservation.patch.
  patches.suse/powerpc-fadump-sysfs-for-fadump-memory-reservation.patch
  patches.suse/Documentation-ABI-add-ABI-documentation-for-sys-kern.patch -> patches.suse/Documentation-ABI-Add-ABI-documentation-for-sys-kern.patch
  patches.suse/Documentation-ABI-mark-sys-kernel-fadump_-sysfs-file.patch -> patches.suse/Documentation-ABI-Mark-sys-kernel-fadump_-sysfs-file.patch
  patches.suse/powerpc-fadump-reorganize-sys-kernel-fadump_-sysfs-f.patch -> patches.suse/powerpc-fadump-Reorganize-sys-kernel-fadump_-sysfs-f.patch
  patches.suse/powerpc-powernv-move-core-and-fadump_release_opalcor.patch -> patches.suse/powerpc-powernv-Move-core-and-fadump_release_opalcor.patch
  patches.suse/sysfs-wrap-__compat_only_sysfs_link_entry_to_kobj-fu.patch -> patches.suse/sysfs-Wrap-__compat_only_sysfs_link_entry_to_kobj-fu.patch
- commit 3b382c0
* Fri Mar  6 2020 msuchanek@suse.de
- treewide: remove redundant IS_ERR() before error code check (bsc#1156395).
- Refresh patches.suse/sysfs-wrap-__compat_only_sysfs_link_entry_to_kobj-fu.patch.
- commit 4eaa7b9
* Fri Mar  6 2020 msuchanek@suse.de
- powerpc/book3s64: Fix error handling in mm_iommu_do_alloc()
  (bsc#1156395).
- commit aca1a7b
* Fri Mar  6 2020 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patches out of sorted section
  No effect on expanded tree.
- commit 6151f14
* Fri Mar  6 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/cifs-Use-define-in-cifs_dbg.patch
  patches.suse/cifs-add-missing-mount-option-to-proc-mounts.patch
  patches.suse/cifs-don-t-leak-EAGAIN-for-stat-during-reconnect.patch
  patches.suse/cifs-fix-potential-mismatch-of-UNC-paths.patch
  patches.suse/cifs-fix-rename-by-ensuring-source-handle-opened-wit.patch
  patches.suse/fs-cifs-Initialize-filesystem-timestamp-ranges.patch
- commit ec2b8cb
* Fri Mar  6 2020 msuchanek@suse.de
- update patches.suse/powerpc-drmem-avoid-NULL-pointer-dereference-when-dr.patch
- update to version from maintainer repository and move into sorted section
- commit 9c11a0c
* Fri Mar  6 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-mac80211-pass-the-vif-to-cancel_remain_on_channel.patch
- commit a0c00c0
* Fri Mar  6 2020 jdelvare@suse.de
- scsi: fnic: do not queue commands during fwreset (bsc#1146539).
- commit c38dde7
* Thu Mar  5 2020 msuchanek@suse.de
- Delete patches which cause regression (bsc#1165527 ltc#184149).
- Delete patches.suse/powerpc-avoid-adjusting-memory_limit-for-capture-ker.patch.
- Delete patches.suse/powerpc-reserve-memory-for-capture-kernel-after-huge.patch.
- commit f7abbd0
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: mvm: fix potential SKB leak on TXQ TX (git-fixes).
- commit 1ac0a4b
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: mvm: remove last leftovers of d0i3 (git-fixes).
- commit dde7e54
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: mvm: remove d0i3_ap_sta_id (git-fixes).
- commit fd2b562
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: mvm: remove the d0i3 entry/exit flow (git-fixes).
- commit 84ff808
* Thu Mar  5 2020 yousaf.kaukab@suse.com
- tick/common: Make tick_periodic() check for missing ticks
  (bsc#1164534).
- commit 4d65090
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: mvm: remove the tx defer for d0i3 (git-fixes).
- commit ec16006
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: remove all the d0i3 references (git-fixes).
- commit beb11dd
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: mvm: start to remove the code for d0i3 (git-fixes).
- commit 4ff93db
* Thu Mar  5 2020 oneukum@suse.com
- mac80211: pass the vif to cancel_remain_on_channel (git-fixes).
- commit f9393f5
* Thu Mar  5 2020 jslaby@suse.cz
- rxrpc: Fix service call disconnection (git-fixes).
- commit 4266941
* Thu Mar  5 2020 jack@suse.cz
- blktrace: Protect q->blk_trace with RCU (bsc#1159285
  CVE-2019-19768).
- commit c44e53f
* Thu Mar  5 2020 jslaby@suse.cz
- gtp: use __GFP_NOWARN to avoid memalloc warning
  (networking-stable-20_02_05).
- l2tp: Allow duplicate session creation with UDP
  (networking-stable-20_02_05).
- net: hsr: fix possible NULL deref in hsr_handle_frame()
  (networking-stable-20_02_05).
- net: stmmac: Delete txtimer in suspend()
  (networking-stable-20_02_05).
- rxrpc: Fix NULL pointer deref due to call->conn being cleared
  on disconnect (networking-stable-20_02_05).
- rxrpc: Fix missing active use pinning of rxrpc_local object
  (networking-stable-20_02_05).
- rxrpc: Fix insufficient receive notification generation
  (networking-stable-20_02_05).
- rxrpc: Fix use-after-free in rxrpc_put_local()
  (networking-stable-20_02_05).
- tcp: clear tp->segs_{in|out} in tcp_disconnect()
  (networking-stable-20_02_05).
- tcp: clear tp->data_segs{in|out} in tcp_disconnect()
  (networking-stable-20_02_05).
- tcp: clear tp->delivered in tcp_disconnect()
  (networking-stable-20_02_05).
- tcp: clear tp->total_retrans in tcp_disconnect()
  (networking-stable-20_02_05).
- commit 3758fff
* Thu Mar  5 2020 jslaby@suse.cz
- net: dsa: bcm_sf2: Forcibly configure IMP port for 1Gb/sec
  (git-fixes).
- net: dsa: bcm_sf2: Only 7278 supports 2Gb/sec IMP port
  (git-fixes).
- commit 7361c96
* Thu Mar  5 2020 jslaby@suse.cz
- udp: segment looped gso packets correctly
  (networking-stable-20_01_30).
- rxrpc: Fix use-after-free in rxrpc_receive_data()
  (networking-stable-20_01_30).
- net_sched: ematch: reject invalid TCF_EM_SIMPLE
  (networking-stable-20_01_30).
- net: include struct nhmsg size in nh nlmsg size
  (networking-stable-20_01_30).
- net_sched: walk through all child classes in tc_bind_tclass()
  (networking-stable-20_01_30).
- net_sched: fix ops->bind_class() implementations
  (networking-stable-20_01_30).
- commit a2d67cb
* Wed Mar  4 2020 palcantara@suse.de
- smb3: Fix regression in time handling (bsc#1164565).
- commit 76489e8
* Wed Mar  4 2020 palcantara@suse.de
- fs: cifs: Initialize filesystem timestamp ranges (bsc#1164565).
- commit 4bd8d12
* Wed Mar  4 2020 palcantara@suse.de
- fs: cifs: Fix atime update check vs mtime (bsc#1164565).
- commit 0137273
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/mediatek: disable all the planes in atomic_disable (bsc#1152489)
- commit beb3e57
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/mcde: Some fixes to handling video mode (bsc#1152472)
- commit 29f754d
* Wed Mar  4 2020 tzimmermann@suse.de
- drm: rcar-du: Recognize "renesas,vsps" in addition to "vsps" (bsc#1152489)
- commit 56e3aa3
* Wed Mar  4 2020 jslaby@suse.cz
- net: bcmgenet: Use netif_tx_napi_add() for TX NAPI
  (networking-stable-20_01_27).
- commit 9e56daf
* Wed Mar  4 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/radeon: fix bad DMA from INTERRUPT_CNTL2'
- commit b3a8eb6
* Wed Mar  4 2020 jslaby@suse.cz
- net: systemport: Fixed queue mapping in internal ring map
  (networking-stable-20_01_20).
- net: dsa: bcm_sf2: Configure IMP port for 2Gb/sec
  (networking-stable-20_01_20).
- net: dsa: sja1105: Don't error out on disabled ports with no
  phy-mode (networking-stable-20_01_20).
- net: dsa: tag_qca: fix doubled Tx statistics
  (networking-stable-20_01_20).
- net: dsa: tag_gswip: fix typo in tagger name
  (networking-stable-20_01_20).
- net: ethernet: ave: Avoid lockdep warning
  (networking-stable-20_01_20).
- net/wan/fsl_ucc_hdlc: fix out of bounds write on array utdm_info
  (networking-stable-20_01_20).
- hv_netvsc: Fix memory leak when removing rndis device
  (networking-stable-20_01_20).
- commit 7f37dbf
* Wed Mar  4 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix license on Kconfig and Makefiles'
- commit 5173cd9
* Wed Mar  4 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: add default clocks if not able to fetch them'
- commit 666a2d4
* Wed Mar  4 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix bad DMA from INTERRUPT_CNTL2'
- commit 1874918
* Wed Mar  4 2020 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/amdgpu: Set no-retry as default."'
- commit b4576bc
* Wed Mar  4 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/smu: add metrics table lock for arcturus (v2)'
- commit f64b7b2
* Wed Mar  4 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-crypto-atmel-Fix-build-error-of-CRYPTO_AUTHENC.patch
  patches.suse/0001-tools-lib-traceevent-Remove-unneeded-qsort-and-uses-.patch
  patches.suse/0001-usb-host-xhci-update-event-ring-dequeue-pointer-on-p.patch
- commit d776890
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: remove redundant variable r and redundant return (bsc#1152489)
- commit 9635a45
* Wed Mar  4 2020 tbogendoerfer@suse.de
- supported.conf: mark hinic driver supported (bsc#1165618)
- commit d183caf
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: remove ras_reserve_vram in ras injection (bsc#1152489)
- commit e39df99
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu/discovery: reserve discovery data at the top of VRAM (bsc#1152489)
- commit 87c3ae9
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: add invalidate semaphore limit for SRIOV and picasso in (bsc#1152472)
- commit 8bb0283
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: avoid using invalidate semaphore for picasso (bsc#1152472)
- commit 7a93979
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: invalidate mmhub semaphore workaround in gmc9/gmc10 (bsc#1152472)
- commit f513a95
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: initialize vm_inv_eng0_sem for gfxhub and mmhub (bsc#1152472)
- commit cc4b76c
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: re-init clear state buffer after gpu reset (bsc#1152472)
- commit 8c64b3d
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: cleanup creating BOs at fixed location (v2) (bsc#1152489)
- commit 633a2a8
* Wed Mar  4 2020 glin@suse.com
- samples/bpf: Don't try to remove user's homedir on clean
  (bsc#1155518).
- samples/bpf: Xdp_redirect_cpu fix missing tracepoint attach
  (bsc#1155518).
- commit 11d150a
* Wed Mar  4 2020 jslaby@suse.cz
- PCI: pciehp: Add DMI table for in-band presence detection
  disabled (bnc#1162576 jsc#SLE-11112).
- PCI: pciehp: Wait for PDS if in-band presence is disabled
  (bnc#1162576 jsc#SLE-11112).
- PCI: pciehp: Disable in-band presence detect when possible
  (bnc#1162576 jsc#SLE-11112).
- commit 6963c35
* Wed Mar  4 2020 glin@suse.com
- bpf, offload: Replace bitwise AND by logical AND in
  bpf_prog_offload_info_fill (bsc#1155518).
- samples: bpf: Drop doubled variable declaration in xdpsock
  (bsc#1155518).
- samples/bpf: xdpsock: Add option to specify transmit fill
  pattern (bsc#1155518).
- samples/bpf: xdpsock: Add option to specify tx packet size
  (bsc#1155518).
- samples/bpf: xdpsock: Add option to specify number of packets
  to send (bsc#1155518).
- samples/bpf: xdpsock: Add option to specify batch size
  (bsc#1155518).
- samples/bpf: xdpsock: Use common code to handle signal and
  main exit (bsc#1155518).
- samples/bpf: xdpsock: Add duration option to specify how long
  to run (bsc#1155518).
- riscv, bpf: Fix broken BPF tail calls (bsc#1155518).
- samples/bpf: Attach XDP programs in driver mode by default
  (bsc#1155518).
- libbpf: Don't attach perf_buffer to offline/missing CPUs
  (bsc#1155518).
- libbpf: Extract and generalize CPU mask parsing logic
  (bsc#1155518).
- samples/bpf: Add missing option to xdpsock usage (bsc#1155518).
- samples/bpf: Remove duplicate option from xdpsock (bsc#1155518).
- samples/bpf: Use Rx-only and Tx-only sockets in xdpsock
  (bsc#1155518).
- samples/bpf: Add XDP_SHARED_UMEM support to xdpsock
  (bsc#1155518).
- samples: bpf: update map definition to new syntax BTF-defined
  map (bsc#1155518).
- samples/bpf: Trivial - fix spelling mistake in usage
  (bsc#1155518).
- samples/bpf: fix xdpsock l2fwd tx for unaligned mode
  (bsc#1155518).
- samples/bpf: use hugepages in xdpsock app (bsc#1155518).
- samples/bpf: add buffer recycling for unaligned chunks to
  xdpsock (bsc#1155518).
- samples/bpf: add unaligned chunks mode support to xdpsock
  (bsc#1155518).
- samples/bpf: add use of need_wakeup flag in xdpsock
  (bsc#1155518).
- samples/bpf: make xdp_fwd more practically usable via devmap
  lookup (bsc#1155518).
- samples/bpf: xdp_fwd rename devmap name to be xdp_tx_ports
  (bsc#1155518).
- commit ebecd6a
* Tue Mar  3 2020 mkubecek@suse.cz
- supported.conf: fix broken dependencies
  Recently added modules mscc_felix and tag_ocelot are marked as supported
  but depend on unsupported modules dsa_core and mscc_ocelot_common which
  breaks dependencies in aarch64 kernel-default package and therefore also
  aarch64/default and aarch/preempt build.
  Mark dsa_core and mscc_ocelot_common as supported as well.
- commit 102e871
* Tue Mar  3 2020 palcantara@suse.de
- cifs: do d_move in rename (bsc#1164565).
- commit 500b81b
* Tue Mar  3 2020 palcantara@suse.de
- cifs: add SMB2_open() arg to return POSIX data (bsc#1164565).
- commit ee82400
* Tue Mar  3 2020 palcantara@suse.de
- cifs: plumb smb2 POSIX dir enumeration (bsc#1164565).
- commit 3127734
* Tue Mar  3 2020 palcantara@suse.de
- cifs: add smb2 POSIX info level (bsc#1164565).
- commit 0cbf023
* Tue Mar  3 2020 palcantara@suse.de
- cifs: rename posix create rsp (bsc#1164565).
- commit 4b07bca
* Tue Mar  3 2020 palcantara@suse.de
- cifs: print warning once if mounting with vers=1.0
  (bsc#1164565).
- commit a59d8f7
* Tue Mar  3 2020 palcantara@suse.de
- smb3: fix performance regression with setting mtime
  (bsc#1164565).
- commit 4e529a9
* Tue Mar  3 2020 palcantara@suse.de
- cifs: make use of cap_unix(ses) in cifs_reconnect_tcon()
  (bsc#1164565).
- commit 5e21989
* Tue Mar  3 2020 palcantara@suse.de
- cifs: use mod_delayed_work() for &server->reconnect if already
  queued (bsc#1164565).
- commit b9b1327
* Tue Mar  3 2020 palcantara@suse.de
- cifs: call wake_up(&server->response_q) inside of
  cifs_reconnect() (bsc#1164565).
- commit 7684617
* Tue Mar  3 2020 palcantara@suse.de
- cifs: handle prefix paths in reconnect (bsc#1164565).
- commit 62ccc7c
* Tue Mar  3 2020 palcantara@suse.de
- cifs: potential unintitliazed error code in cifs_getattr()
  (bsc#1164565).
- commit a4ddb9f
* Tue Mar  3 2020 palcantara@suse.de
- cifs: do not ignore the SYNC flags in getattr (bsc#1164565).
- commit fc2ab55
* Tue Mar  3 2020 palcantara@suse.de
- cifs: Use #define in cifs_dbg (bsc#1164565).
- commit 12c009d
* Tue Mar  3 2020 palcantara@suse.de
- cifs: fix rename() by ensuring source handle opened with DELETE
  bit (bsc#1164565).
- commit 270fcbb
* Tue Mar  3 2020 palcantara@suse.de
- cifs: add missing mount option to /proc/mounts (bsc#1164565).
- commit 3115514
* Tue Mar  3 2020 dwagner@suse.de
- Drop patches.suse/qla2xxx-Enable-T10-DIF-with-FC-NVMe-enabled.patch
  The driver update to 10.01.00.25-k replaces the dropped patch.
- commit d25382d
* Tue Mar  3 2020 dwagner@suse.de
- scsi: qla2xxx: Update driver version to 10.01.00.25-k
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Set Nport ID for N2N (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Handle NVME status iocb correctly (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove restriction of FC T10-PI and FC-NVMe
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Serialize fc_port alloc in N2N (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix NPIV instantiation after FW dump
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix RDP respond data format (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Force semaphore on flash validation failure
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: add more FW debug information (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Update BPM enablement semantics (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: fix FW resource count values (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use a dedicated interrupt handler for
  'handshake-required' ISPs (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Return appropriate failure through BSG Interface
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Improved secure flash support messages
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix FCP-SCSI FC4 flag passing error (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use FC generic update firmware options routine
  for ISP27xx (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Avoid setting firmware options twice
  in 24xx_update_fw_options (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Add 16.0GT for PCI String (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Convert MAKE_HANDLE() from a define into an
  inline function (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix sparse warnings triggered by the PCI state
  checking code (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Suppress endianness complaints in
  qla2x00_configure_local_loop() (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Simplify the code for aborting SCSI commands
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix sparse warning reported by kbuild bot
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- commit 54d9078
* Tue Mar  3 2020 dwagner@suse.de
- Refresh patches.suse/scsi-ibmvfc-Avoid-loss-of-all-paths-during-SVC-node-.patch.
- commit f3b4108
* Tue Mar  3 2020 palcantara@suse.de
- cifs: fix potential mismatch of UNC paths (bsc#1164565).
- commit 47e9729
* Tue Mar  3 2020 palcantara@suse.de
- cifs: don't leak -EAGAIN for stat() during reconnect
  (bsc#1164565).
- commit 8f37e30
* Tue Mar  3 2020 jack@suse.cz
- tools/testing/nvdimm: Fix compilation failure without
  CONFIG_DEV_DAX_PMEM_COMPAT (bsc#1159523).
- commit 08c88c8
* Tue Mar  3 2020 tbogendoerfer@suse.de
- mlxsw: pci: Wait longer before accessing the device after reset
  (bsc#1154488).
- sched: act: count in the size of action flags bitfield
  (bsc#1154353).
- net: genetlink: return the error code when attribute parsing
  fails (bsc#1154353).
- commit 28120f1
* Tue Mar  3 2020 trenn@suse.com
- powercap/intel_rapl: add support for TigerLake Mobile
  (bsc#1164993, bsc#1165102).
- commit aa3d1d3
* Tue Mar  3 2020 oneukum@suse.com
- usb: host: xhci: update event ring dequeue pointer on purpose
  (git-fixes).
- commit fbca080
* Tue Mar  3 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/acpi-watchdog-allow-disabling-wdat-at-boot.patch
  patches.suse/acpi-watchdog-set-default-timeout-in-probe.patch
- commit b455329
* Mon Mar  2 2020 lyan@suse.com
- KVM: arm64: pmu: Reset sample period on overflow handling
  (bsc#1133021).
- KVM: arm64: pmu: Set the CHAINED attribute before creating
  the in-kernel event (bsc#1133021).
- arm64: KVM: Handle PMCR_EL0.LC as RES1 on pure AArch64 systems
  (bsc#1133021).
- KVM: arm64: pmu: Fix cycle counter truncation (bsc#1133021).
- commit d9abd96
* Mon Mar  2 2020 msuchanek@suse.de
- powerpc/pseries: update device tree before ejecting hotplug
  uevents (bsc#1165404 ltc#183498).
- powerpc/pseries: group lmb operation and memblock's (bsc#1165404
  ltc#183498).
- commit 6d4f5d6
* Mon Mar  2 2020 msuchanek@suse.de
- ibmvfc: Fix NULL return compiler warning (bsc#1161951
  ltc#183551).
- commit 7015eca
* Mon Mar  2 2020 palcantara@suse.de
- cifs: make sure we do not overflow the max EA buffer size
  (bsc#1164565).
- commit 187fa15
* Mon Mar  2 2020 palcantara@suse.de
- cifs: enable change notification for SMB2.1 dialect
  (bsc#1164565).
- commit 18efac6
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix mode output in debugging statements (bsc#1164565).
- commit 921b85b
* Mon Mar  2 2020 palcantara@suse.de
- smb3: Add defines for new information level, FileIdInformation
  (bsc#1164565).
- commit 6421d32
* Mon Mar  2 2020 palcantara@suse.de
-  smb3: print warning once if posix context returned on open
  (bsc#1164565).
- commit 1c772a2
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add one more dynamic tracepoint missing from strict
  fsync path (bsc#1164565).
- commit 756599a
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix mode bits from dir listing when mounted with
  modefromsid (bsc#1164565).
- commit 577afbb
* Mon Mar  2 2020 palcantara@suse.de
- cifs: add SMB3 change notification support (bsc#1164565).
- commit fd3741d
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix soft mounts hanging in the reconnect code
  (bsc#1164565).
- commit bd3733d
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Add tracepoints for errors on flush or fsync
  (bsc#1164565).
- commit c47bf63
* Mon Mar  2 2020 palcantara@suse.de
- cifs: log warning message (once) if out of disk space
  (bsc#1164565).
- commit 0a33490
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fail i/o on soft mounts if sessionsetup errors out
  (bsc#1164565).
- commit 79eff03
* Mon Mar  2 2020 palcantara@suse.de
- smb3: fix problem with null cifs super block with previous patch
  (bsc#1164565).
- commit 4f17f73
* Mon Mar  2 2020 palcantara@suse.de
- SMB3: Backup intent flag missing from some more ops
  (bsc#1164565).
- commit cea0ba2
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix soft mounts hanging in the reconnect code
  (bsc#1164565).
- commit 53d1815
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Fix task struct use-after-free on reconnect (bsc#1164565).
- commit d8da619
* Mon Mar  2 2020 palcantara@suse.de
- cifs: use PTR_ERR_OR_ZERO() to simplify code (bsc#1164565).
- commit ae626b0
* Mon Mar  2 2020 palcantara@suse.de
- cifs: add support for fallocate mode 0 for non-sparse files
  (bsc#1164565).
- commit 0bd12eb
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix NULL dereference in match_prepath (bsc#1164565).
- commit 0dec827
* Mon Mar  2 2020 palcantara@suse.de
- smb3: fix default permissions on new files when mounting with
  modefromsid (bsc#1164565).
- commit 5854994
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Add support for setting owner info, dos attributes,
  and create time (bsc#1164565).
- commit fc7a4ec
* Mon Mar  2 2020 palcantara@suse.de
- cifs: remove set but not used variable 'server' (bsc#1164565).
- commit d7bd290
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix memory allocation in __smb2_handle_cancelled_cmd()
  (bsc#1164565).
- commit 2e77717
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix mount options set in automount (bsc#1164565).
- commit 23cc00f
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix unitialized variable poential problem with network
  I/O cache lock patch (bsc#1164565).
- commit 683e390
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix return value in __update_cache_entry (bsc#1164565).
- commit 0d6d00e
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Avoid doing network I/O while holding cache lock
  (bsc#1164565).
- commit 21b1bb8
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix potential deadlock when updating vol in
  cifs_reconnect() (bsc#1164565).
- commit 7f4c5eb
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Merge is_path_valid() into get_normalized_path()
  (bsc#1164565).
- commit 90e6c2e
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Introduce helpers for finding TCP connection
  (bsc#1164565).
- commit 278b9d9
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Get rid of kstrdup_const()'d paths (bsc#1164565).
- commit 136ec9a
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Clean up DFS referral cache (bsc#1164565).
- commit b1680d8
* Mon Mar  2 2020 palcantara@suse.de
- cifs: set correct max-buffer-size for smb2_ioctl_init()
  (bsc#1164565).
- commit 4203783
* Mon Mar  2 2020 palcantara@suse.de
- cifs: use compounding for open and first query-dir for readdir()
  (bsc#1164565).
- commit e47a329
* Mon Mar  2 2020 palcantara@suse.de
- cifs: create a helper function to parse the query-directory
  response buffer (bsc#1164565).
- commit 0960f35
* Mon Mar  2 2020 palcantara@suse.de
- cifs: prepare SMB2_query_directory to be used with compounding
  (bsc#1164565).
- commit f065422
* Mon Mar  2 2020 palcantara@suse.de
- fs/cifs/cifssmb.c: use true,false for bool variable
  (bsc#1164565).
- commit dd0ed6f
* Mon Mar  2 2020 palcantara@suse.de
- fs/cifs/smb2ops.c: use true,false for bool variable
  (bsc#1164565).
- commit 21e8ec0
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Optimize readdir on reparse points (bsc#1164565).
- commit 1966fae
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Adjust indentation in smb2_open_file (bsc#1164565).
- commit 331c9ed
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Close cached root handle only if it has a lease
  (bsc#1164565).
- commit 47dfff5
* Mon Mar  2 2020 palcantara@suse.de
- SMB3: Fix crash in SMB2_open_init due to uninitialized field
  in compounding path (bsc#1164565).
- commit 4b50b8c
* Mon Mar  2 2020 palcantara@suse.de
- smb3: fix refcount underflow warning on unmount when no
  directory leases (bsc#1164565).
- commit 39393bb
* Mon Mar  2 2020 palcantara@suse.de
- smb3: improve check for when we send the security descriptor
  context on create (bsc#1164565).
- commit 4083b73
* Mon Mar  2 2020 palcantara@suse.de
- smb3: fix mode passed in on create for modetosid mount option
  (bsc#1164565).
- commit c05fc9d
* Mon Mar  2 2020 palcantara@suse.de
- smb3: query attributes on file close (bsc#1164565).
- commit 6280b64
* Mon Mar  2 2020 palcantara@suse.de
- smb3: remove unused flag passed into close functions
  (bsc#1164565).
- commit 1cc8c7f
* Mon Mar  2 2020 palcantara@suse.de
- cifs: remove redundant assignment to pointer pneg_ctxt
  (bsc#1164565).
- commit e68dc80
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: fix a white space issue in cifs_get_inode_info()
  (bsc#1164565).
- commit 10fc15b
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix retrieval of DFS referrals in cifs_mount()
  (bsc#1164565).
- commit 22772da
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix potential softlockups while refreshing DFS cache
  (bsc#1164565).
- commit 694eb6e
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix lookup of root ses in DFS referral cache
  (bsc#1164565).
- commit 2cf9686
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix use-after-free bug in cifs_reconnect() (bsc#1164565).
- commit d57d122
* Mon Mar  2 2020 palcantara@suse.de
- smb3: dump in_send and num_waiters stats counters by default
  (bsc#1164565).
- commit e81c291
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Properly process SMB3 lease breaks (bsc#1164565).
- commit 579b98d
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: refactor cifs_get_inode_info() (bsc#1164565).
- commit 0b80dd7
* Mon Mar  2 2020 palcantara@suse.de
- cifs: don't use 'pre:' for MODULE_SOFTDEP (bsc#1164565).
- commit 44b1acc
* Mon Mar  2 2020 palcantara@suse.de
- cifs: smbd: Return -EAGAIN when transport is reconnecting
  (bsc#1164565).
- commit 44743f5
* Mon Mar  2 2020 palcantara@suse.de
- cifs: smbd: Only queue work for error recovery on memory
  registration (bsc#1164565).
- commit 4c66f23
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add debug messages for closing unmatched open
  (bsc#1164565).
- commit 47f85b3
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Do not miss cancelled OPEN responses (bsc#1164565).
- commit 6d9d8e6
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Fix NULL pointer dereference in mid callback
  (bsc#1164565).
- commit 220efe8
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Close open handle after interrupted close (bsc#1164565).
- commit a0e0f78
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Respect O_SYNC and O_DIRECT flags during reconnect
  (bsc#1164565).
- commit 5d00439
* Mon Mar  2 2020 palcantara@suse.de
- smb3: remove confusing dmesg when mounting with encryption
  ("seal") (bsc#1164565).
- commit 26d3f50
* Mon Mar  2 2020 palcantara@suse.de
- cifs: close the shared root handle on tree disconnect
  (bsc#1164565).
- commit 5fba990
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Return directly after a failed build_path_from_dentry()
  in cifs_do_create() (bsc#1164565).
- commit 5bdda87
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Use common error handling code in smb2_ioctl_query_info()
  (bsc#1164565).
- commit 7c9d0d2
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Use memdup_user() rather than duplicating its
  implementation (bsc#1164565).
- commit ac9ac99
* Mon Mar  2 2020 palcantara@suse.de
- cifs: smbd: Return -ECONNABORTED when trasnport is not in
  connected state (bsc#1164565).
- commit 1d4896f
* Mon Mar  2 2020 palcantara@suse.de
- cifs: smbd: Add messages on RDMA session destroy and
  reconnection (bsc#1164565).
- commit c884cac
* Mon Mar  2 2020 palcantara@suse.de
- cifs: smbd: Return -EINVAL when the number of iovs exceeds
  SMBDIRECT_MAX_SGE (bsc#1164565).
- commit 342a436
* Mon Mar  2 2020 palcantara@suse.de
- cifs: smbd: Invalidate and deregister memory registration on
  re-send for direct I/O (bsc#1164565).
- commit 95bdb07
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Don't display RDMA transport on reconnect (bsc#1164565).
- commit 901256b
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: remove set but not used variables 'cinode' and 'netfid'
  (bsc#1164565).
- commit da66a8f
* Mon Mar  2 2020 palcantara@suse.de
- cifs: add support for flock (bsc#1164565).
- commit 61dc219
* Mon Mar  2 2020 palcantara@suse.de
- cifs: remove unused variable 'sid_user' (bsc#1164565).
- commit 5c64672
* Mon Mar  2 2020 palcantara@suse.de
- cifs: rename a variable in SendReceive() (bsc#1164565).
- commit 054c459
* Mon Mar  2 2020 palcantara@suse.de
- fix memory leak in large read decrypt offload (bsc#1164565).
- commit 7880d1c
* Mon Mar  2 2020 msuchanek@suse.de
- Revert "Revert "sign also s390x kernel images (bsc#1163524)""
  This reverts commit 6326fe1a81221fb3ce28ff84532bd48a182f7731.
  pesign should now be able to sign s390 kernels.
- commit e9175e5
* Mon Mar  2 2020 msuchanek@suse.de
- blacklist.conf: Blacklist unsupported ppc platforms.
- commit b290d11
* Mon Mar  2 2020 msuchanek@suse.de
- net/ethtool: Introduce link_ksettings API for virtual network
  devices (bsc#1136157 ltc#177197).
  Delete patches.suse/ibmveth-Update-ethtool-settings-to-reflect-virtual-p.patch.
- ethtool: Factored out similar ethtool link settings for virtual
  devices to core (bsc#1136157 ltc#177197).
- commit 4638559
* Mon Mar  2 2020 jdelvare@suse.de
- Refresh
  patches.suse/acpi-watchdog-allow-disabling-wdat-at-boot.patch.
- Refresh
  patches.suse/acpi-watchdog-set-default-timeout-in-probe.patch.
  Add upstream commit IDs and move to the sorted section.
- commit 678d8e6
* Mon Mar  2 2020 ohering@suse.de
- hv_netvsc: Fix unwanted wakeup in netvsc_attach() (git-fixes).
- commit c3cdac3
* Mon Mar  2 2020 palcantara@suse.de
- smb3: remove noisy debug message and minor cleanup
  (bsc#1164565).
- commit f116adb
* Mon Mar  2 2020 palcantara@suse.de
- smb3: cleanup some recent endian errors spotted by updated
  sparse (bsc#1164565).
- commit b63cc8a
* Mon Mar  2 2020 palcantara@suse.de
- smb3: missing ACL related flags (bsc#1164565).
- commit ddcd4e7
* Mon Mar  2 2020 palcantara@suse.de
- smb3: pass mode bits into create calls (bsc#1164565).
- commit 9e90af4
* Mon Mar  2 2020 palcantara@suse.de
- smb3: Add missing reparse tags (bsc#1164565).
- commit 631f1b0
* Mon Mar  2 2020 palcantara@suse.de
- fs/cifs/sess.c: Remove set but not used variable 'capabilities'
  (bsc#1164565).
- commit e4f316a
* Mon Mar  2 2020 palcantara@suse.de
- fs/cifs/smb2pdu.c: Make SMB2_notify_init static (bsc#1164565).
- commit 1781460
* Mon Mar  2 2020 palcantara@suse.de
- smb3: allow decryption keys to be dumped by admin for debugging
  (bsc#1164565).
- commit 449f80c
* Mon Mar  2 2020 palcantara@suse.de
- cifs: modefromsid: write mode ACE first (bsc#1164565).
- commit 6f29db0
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add missing worker function for SMB3 change notify
  (bsc#1164565).
- commit c88cd2a
* Mon Mar  2 2020 palcantara@suse.de
- cifs: modefromsid: make room for 4 ACE (bsc#1164565).
- commit 41e2c7e
* Mon Mar  2 2020 palcantara@suse.de
- smb3: fix potential null dereference in decrypt offload
  (bsc#1164565).
- commit cc2bebe
* Mon Mar  2 2020 palcantara@suse.de
- smb3: display max smb3 requests in flight at any one time
  (bsc#1164565).
- commit 2b340ea
* Mon Mar  2 2020 palcantara@suse.de
- smb3: only offload decryption of read responses if multiple
  requests (bsc#1164565).
- Refresh
  patches.suse/cifs-move-cifsFileInfo_put-logic-into-a-work-queue.patch.
- commit 8d8b9e0
* Mon Mar  2 2020 palcantara@suse.de
- smb3: enable offload of decryption of large reads via mount
  option (bsc#1164565).
- commit c0c0dd0
* Mon Mar  2 2020 palcantara@suse.de
- smb3: allow parallelizing decryption of reads (bsc#1164565).
- Refresh
  patches.suse/cifs-move-cifsFileInfo_put-logic-into-a-work-queue.patch.
- commit dbfeff1
* Mon Mar  2 2020 palcantara@suse.de
- cifs: add a debug macro that prints \\server\share for errors
  (bsc#1164565).
- commit fd241c6
* Mon Mar  2 2020 palcantara@suse.de
- smb3: allow skipping signature verification for perf sensitive
  configurations (bsc#1164565).
- commit dd9ca23
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add dynamic tracepoints for flush and close (bsc#1164565).
- commit b3d48ee
* Mon Mar  2 2020 palcantara@suse.de
- smb3: log warning if CSC policy conflicts with cache mount
  option (bsc#1164565).
- commit 633ceea
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add mount option to allow RW caching of share accessed
  by only 1 client (bsc#1164565).
- commit 79b4f8c
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add some more descriptive messages about share when
  mounting cache=ro (bsc#1164565).
- commit fc6a23b
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add mount option to allow forced caching of read only
  share (bsc#1164565).
- commit 30b7183
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix dereference on ses before it is null checked
  (bsc#1164565).
- commit 30243d5
* Mon Mar  2 2020 palcantara@suse.de
- cifs: add new debugging macro cifs_server_dbg (bsc#1164565).
- Refresh
  patches.suse/CIFS-Fix-retry-mid-list-corruption-on-reconnects.patch.
- commit 894b13c
* Mon Mar  2 2020 palcantara@suse.de
- cifs: remove set but not used variables (bsc#1164565).
- commit 147b525
* Mon Mar  2 2020 palcantara@suse.de
- cifs: remove unused variable (bsc#1164565).
- commit b38b168
* Mon Mar  2 2020 palcantara@suse.de
- cifs: remove redundant assignment to variable rc (bsc#1164565).
- commit a3fa732
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add missing flag definitions (bsc#1164565).
- commit 344e8bd
* Mon Mar  2 2020 palcantara@suse.de
- cifs: add passthrough for smb2 setinfo (bsc#1164565).
- commit 046be6b
* Mon Mar  2 2020 palcantara@suse.de
- cifs: allow chmod to set mode bits using special sid
  (bsc#1164565).
- commit fc541ed
* Mon Mar  2 2020 palcantara@suse.de
- cifs: get mode bits from special sid on stat (bsc#1164565).
- commit 5c3507b
* Mon Mar  2 2020 palcantara@suse.de
- fs: cifs: cifsssmb: remove redundant assignment to variable ret
  (bsc#1164565).
- commit 79247fd
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix a comment for the timeouts when sending echos
  (bsc#1164565).
- commit d69504d
* Sat Feb 29 2020 msuchanek@suse.de
- scsi: ibmvfc: Avoid loss of all paths during SVC node reboot
  (bsc#1161951 ltc#183551).
- commit fd62623
* Fri Feb 28 2020 nsaenzjulienne@suse.de
- pinctrl: bcm2835: Add support for all GPIOs on BCM2711
  (bsc#1164722).
- commit ac59893
* Fri Feb 28 2020 nsaenzjulienne@suse.de
- pinctrl: bcm2835: Refactor platform data (bsc#1164722).
- pinctrl: bcm2835: Drop unused define (bsc#1164722).
- commit 1089640
* Fri Feb 28 2020 nsaenzjulienne@suse.de
- Refresh: patches.suse/thermal-add-bcm2711-thermal-driver.patch
- commit 15ec939
* Fri Feb 28 2020 mkubecek@suse.cz
- supported.conf: sort
  Fix order of entries.
- commit b92122c
* Fri Feb 28 2020 tbogendoerfer@suse.de
- supported.conf: mark GVE supported (jsc#SLE10540, bsc#1165245)
- commit 87b5d1a
* Fri Feb 28 2020 yousaf.kaukab@suse.com
- dmaengine: make mux_configure32 static (jsc#SLE-9263).
- commit b01a9f4
* Fri Feb 28 2020 yousaf.kaukab@suse.com
- net: dsa: felix: use dsa_switch_alloc() (jsc#SLE-9263).
- commit 1190849
* Thu Feb 27 2020 bp@suse.de
- x86/mce/amd: Fix kobject lifetime (bsc#1152489).
- x86/mce/amd: Publish the bank pointer only after setup has
  succeeded (bsc#1152489).
- commit 218de4e
* Thu Feb 27 2020 bp@suse.de
- x86/cpu/amd: Enable the fixed Instructions Retired counter
  IRPERF (bsc#1152489).
- commit a161705
* Thu Feb 27 2020 dwagner@suse.de
- scsi: qla2xxx: Update driver version to 10.01.00.24-k
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use QLA_FW_STOPPED macro to propagate flag
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add fixes for mailbox command (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix control flags for login/logout IOCB
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Save rscn_gen for new fcport (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use correct ISP28xx active FW region
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Print portname for logging in
  qla24xx_logio_entry() (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Fix qla2x00_echo_test() based on ISP type
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Correction to selection of loopback/echo test
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use endian macros to assign static fields in
  fwdump header (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix RDP response size (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Handle cases for limiting RDP response payload
  length (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add deferred queue for processing ABTS and RDP
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Cleanup ELS/PUREX iocb fields (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Show correct port speed capabilities for RDP
  command (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Display message for FCE enabled (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add vendor extended FDMI commands (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add ql2xrdpenable module parameter for RDP
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add vendor extended RDP additions and amendments
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add changes in preparation for vendor extended
  FDMI/RDP (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add endianizer macro calls to fc host stats
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add sysfs node for D-Port Diagnostics AEN data
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Move free of fcport out of interrupt context
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add beacon LED config sysfs interface
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Check locking assumptions at runtime in
  qla2x00_abort_srb() (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- commit d0cdedd
* Thu Feb 27 2020 dwagner@suse.de
- Refresh series.conf
- commit b45c83a
* Thu Feb 27 2020 yousaf.kaukab@suse.com
- gpio: mpc8xxx: ls1088a/ls1028a edge detection mode bug fixs
  (jsc#SLE-9263).
- dmaengine: fsl-edma: Add eDMA support for QorIQ LS1028A platform
  (jsc#SLE-9263).
- dmaengine: fsl-edma: add i.mx7ulp edma2 version support
  (jsc#SLE-9263).
- commit 2aac33b
* Thu Feb 27 2020 jslaby@suse.cz
- net: stmmac: Fixed link does not need MDIO Bus (git-fixes).
- commit c15f5f6
* Thu Feb 27 2020 yousaf.kaukab@suse.com
- clk: ls1028a: fix a dereference of pointer 'parent' before a
  null check (jsc#SLE-9263).
- clk: ls1028a: Fix warning on clamp() usage (jsc#SLE-9263).
- clk: ls1028a: Add clock driver for Display output interface
  (jsc#SLE-9263).
- commit b49745f
* Thu Feb 27 2020 jslaby@suse.cz
- net: stmmac: dwmac-sun8i: Allow all RGMII modes
  (networking-stable-20_01_11).
- net: stmmac: dwmac-sunxi: Allow all RGMII modes
  (networking-stable-20_01_11).
- net: dsa: mv88e6xxx: Preserve priority when setting CPU port
  (networking-stable-20_01_11).
- net: freescale: fec: Fix ethtool -d runtime PM
  (networking-stable-20_01_11).
- commit 292d79c
* Thu Feb 27 2020 mhocko@suse.com
- Update config files.
  turn {arm64,x86_64}/preempt to diff config against default flavor.
- commit 79606c0
* Thu Feb 27 2020 yousaf.kaukab@suse.com
- net: dsa: felix: Use PHY_INTERFACE_MODE_INTERNAL instead of GMII
  (jsc#SLE-9263).
- commit 6cfa413
* Thu Feb 27 2020 jslaby@suse.cz
- net: dsa: sja1105: Reconcile the meaning of TPID and TPID2
  for E/T and P/Q/R/S (networking-stable-20_01_01).
- net: stmmac: dwmac-meson8b: Fix the RGMII TX delay on
  Meson8b/8m2 SoCs (networking-stable-20_01_01).
- net/dst: do not confirm neighbor for vxlan and geneve pmtu
  update (networking-stable-20_01_01).
- sit: do not confirm neighbor when do pmtu update
  (networking-stable-20_01_01).
- vti: do not confirm neighbor when do pmtu update
  (networking-stable-20_01_01).
- tunnel: do not confirm neighbor when do pmtu update
  (networking-stable-20_01_01).
- net/dst: add new function skb_dst_update_pmtu_no_confirm
  (networking-stable-20_01_01).
- gtp: do not confirm neighbor when do pmtu update
  (networking-stable-20_01_01).
- ip6_gre: do not confirm neighbor when do pmtu update
  (networking-stable-20_01_01).
- net: add bool confirm_neigh parameter for dst_ops.update_pmtu
  (networking-stable-20_01_01).
- net: dsa: bcm_sf2: Fix IP fragment location and behavior
  (networking-stable-20_01_01).
- gtp: avoid zero size hashtable (networking-stable-20_01_01).
- gtp: fix an use-after-free in ipv4_pdp_find()
  (networking-stable-20_01_01).
- gtp: fix wrong condition in gtp_genl_dump_pdp()
  (networking-stable-20_01_01).
- gtp: do not allow adding duplicate tid and ms_addr pdp context
  (networking-stable-20_01_01).
- vhost/vsock: accept only packets with the right dst_cid
  (networking-stable-20_01_01).
- commit f17afc0
* Thu Feb 27 2020 jslaby@suse.cz
- net: stmmac: platform: Fix MDIO init for platforms without PHY
  (networking-stable-19_12_28).
- selftests: forwarding: Delete IPv6 address at the end
  (networking-stable-19_12_28).
- sctp: fully initialize v4 addr in some functions
  (networking-stable-19_12_28).
- commit 6abcdbd
* Wed Feb 26 2020 yousaf.kaukab@suse.com
- net: dsa: felix: fix link error (jsc#SLE-9263).
- enetc: Fix inconsistent IS_ERR and PTR_ERR (jsc#SLE-9263).
- commit 77d3fbd
* Wed Feb 26 2020 duwe@suse.de
- enable CRYPTO_TEST on arm64, as it is on all other architectures.
  (bsc#1164254)
- commit a8c6955
* Wed Feb 26 2020 msuchanek@suse.de
- rpm/package-descriptions: garbege collection
  remove old ARM and Xen flavors.
- commit bda0360
* Wed Feb 26 2020 mkubecek@suse.cz
- Revert "sign also s390x kernel images (bsc#1163524)"
  This reverts commit b38b61155f0a2c3ebca06d4bb0c2e11a19a87f1f.
  As further discussion revealed, this change depends on changes in
  pesign-obs-integration package which are not ready yet so that it breaks
  s390x binary builds at the moment.
- commit 6326fe1
* Wed Feb 26 2020 mhocko@suse.com
- Created new preempt kernel flavor (jsc#SLE-11309)
  Configs are cloned from the respective $arch/default configs. All
  changed configs appart from CONFIG_PREEMPT->y are a result of
  dependencies, namely many lock/unlock primitives are no longer
  inlined in the preempt kernel. TREE_RCU has been also changed to
  PREEMPT_RCU which is the default implementation for PREEMPT kernel.
- commit f994874
* Wed Feb 26 2020 bp@suse.de
- EDAC/mc: Fix use-after-free and memleaks during device removal
  (jsc#SLE-9482).
- EDAC/sysfs: Remove csrow objects on errors (jsc#SLE-9482).
- commit 9698f66
* Tue Feb 25 2020 tbogendoerfer@suse.de
- net/mlx5: DR, Handle reformat capability over sw-steering tables
  (jsc#SLE-8464).
- net/mlx5e: Don't clear the whole vf config when switching modes
  (jsc#SLE-8464).
- net/mlx5: DR, Fix matching on vport gvmi (jsc#SLE-8464).
- net/mlx5e: Fix crash in recovery flow without devlink reporter
  (jsc#SLE-8464).
- net/mlx5e: Reset RQ doorbell counter before moving RQ state
  from RST to RDY (jsc#SLE-8464 bsc#1163335).
- bonding: fix lockdep warning in bond_get_stats() (bsc#1154353
  bnc#1151927).
- bonding: add missing netdev_update_lockdep_key() (bsc#1154353).
- net: add strict checks in netdev_name_node_alt_destroy()
  (bsc#1154353).
- net: rtnetlink: fix bugs in rtnl_alt_ifname() (bsc#1154353).
- commit 1a3940e
* Tue Feb 25 2020 yousaf.kaukab@suse.com
- net: mscc: fix in frame extraction (jsc#SLE-9263).
- net: dsa: felix: Allow PHY to AN 10/100/1000 with 2500 serdes link (jsc#SLE-9263).
- net: dsa: felix: Handle PAUSE RX regardless of AN result (jsc#SLE-9263).
- net: dsa: felix: Don't error out on disabled ports with no phy-mode (jsc#SLE-9263).
- net: dsa: felix: Don't restart PCS SGMII AN if not needed (jsc#SLE-9263).
- net: dsa: felix: Set USXGMII link based on BMSR, not LPA (jsc#SLE-9263).
- net: dsa: felix: Add PCS operations for PHYLINK (jsc#SLE-9263).
- net: mscc: ocelot: export ANA, DEV and QSYS registers to include/soc/mscc (jsc#SLE-9263).
- net: mscc: ocelot: make phy_mode a member of the common struct ocelot_port (jsc#SLE-9263).
- enetc: Set MDIO_CFG_HOLD to the recommended value of 2 (jsc#SLE-9263).
- enetc: Make MDIO accessors more generic and export to include/linux/fsl (jsc#SLE-9263).
- net: dsa: Pass pcs_poll flag from driver to PHYLINK (jsc#SLE-9263).
- net: phylink: add support for polling MAC PCS (jsc#SLE-9263).
- net: phylink: make QSGMII a valid PHY mode for in-band AN (jsc#SLE-9263).
- mii: Add helpers for parsing SGMII auto-negotiation (jsc#SLE-9263).
- net: dsa: ocelot: add NET_VENDOR_MICROSEMI dependency (jsc#SLE-9263).
- net: mscc: ocelot: unregister the PTP clock on deinit (jsc#SLE-9263).
- net: mscc: ocelot: use skb queue instead of skbs list (jsc#SLE-9263).
- net: mscc: ocelot: avoid incorrect consuming in skbs list (jsc#SLE-9263).
- net: dsa: ocelot: fix "should it be static?" warnings (jsc#SLE-9263).
- net: dsa: ocelot: add hardware timestamping support for Felix (jsc#SLE-9263).
- net: dsa: ocelot: define PTP registers for felix_vsc9959 (jsc#SLE-9263).
- net: mscc: ocelot: convert to use ocelot_port_add_txtstamp_skb() (jsc#SLE-9263).
- net: mscc: ocelot: convert to use ocelot_get_txtstamp() (jsc#SLE-9263).
- net: mscc: ocelot: export ocelot_hwstamp_get/set functions (jsc#SLE-9263).
- net: dsa: felix: Fix CPU port assignment when not last port (jsc#SLE-9263).
- net: dsa: ocelot: add driver for Felix switch family (jsc#SLE-9263).
- net: dsa: ocelot: add tagger for Ocelot/Felix switches (jsc#SLE-9263).
- net: mscc: ocelot: publish ocelot_sys.h to include/soc/mscc (jsc#SLE-9263).
- net: mscc: ocelot: publish structure definitions to include/soc/mscc/ocelot.h (jsc#SLE-9263).
- net: mscc: ocelot: separate the implementation of switch reset (jsc#SLE-9263).
- net: mscc: ocelot: adjust MTU on the CPU port in NPI mode (jsc#SLE-9263).
- net: mscc: ocelot: export a constant for the tag length in bytes (jsc#SLE-9263).
- net: mscc: ocelot: create a helper for changing the port MTU (jsc#SLE-9263).
- net: mscc: ocelot: move invariant configs out of adjust_link (jsc#SLE-9263).
- net: mscc: ocelot: filter out ocelot SoC specific PCS config from common path (jsc#SLE-9263).
- net: mscc: ocelot: move resource ioremap and regmap init to common code (jsc#SLE-9263).
- net: mscc: ocelot: don't hardcode the number of the CPU port (jsc#SLE-9263).
- net: mscc: ocelot: split assignment of the cpu port into a separate function (jsc#SLE-9263).
- net: mscc: ocelot: refactor adjust_link into a netdev-independent function (jsc#SLE-9263).
- net: mscc: ocelot: initialize list of multicast addresses in common code (jsc#SLE-9263).
- net: mscc: ocelot: separate the common implementation of ndo_open and ndo_stop (jsc#SLE-9263).
- net: mscc: ocelot: move port initialization into separate function (jsc#SLE-9263).
- net: mscc: ocelot: limit vlan ingress filtering to actual number of ports (jsc#SLE-9263).
- net: mscc: ocelot: refactor ethtool callbacks (jsc#SLE-9263).
- net: mscc: ocelot: separate net_device related items out of ocelot_port (jsc#SLE-9263).
- net: mscc: ocelot: refactor struct ocelot_port out of function prototypes (jsc#SLE-9263).
- net: mscc: ocelot: change prototypes of switchdev port attribute handlers (jsc#SLE-9263).
- net: mscc: ocelot: change prototypes of hwtstamping ioctls (jsc#SLE-9263).
- net: mscc: ocelot: break out fdb operations into abstract implementations (jsc#SLE-9263).
- net: mscc: ocelot: break apart vlan operations into ocelot_vlan_{add, del} (jsc#SLE-9263).
- net: mscc: ocelot: break apart ocelot_vlan_port_apply (jsc#SLE-9263).
- net: mscc: PTP Hardware Clock (PHC) support (jsc#SLE-9263).
- net: mscc: remove the frame_info cpuq member (jsc#SLE-9263).
- net: mscc: improve the frame header parsing readability (jsc#SLE-9263).
- net: mscc: describe the PTP register range (jsc#SLE-9263).
- commit 79f7160
* Tue Feb 25 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-Take-into-account-runnable_avg-to-classify-group.patch.
- Refresh
  patches.suse/sched-fair-reorder-enqueue-dequeue_task_fair-path.patch.
- Refresh
  patches.suse/sched-numa-Bias-swapping-tasks-based-on-their-preferred-node.patch.
- Refresh
  patches.suse/sched-numa-Distinguish-between-the-different-task_numa_migrate-failure-cases.patch.
- Refresh
  patches.suse/sched-numa-Find-an-alternative-idle-CPU-if-the-CPU-is-part-of-an-active-NUMA-balance.patch.
- sched/numa: Prefer using an idle CPU as a migration target
  instead of comparing tasks (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- Refresh
  patches.suse/sched-numa-Stop-an-exhastive-search-if-a-reasonable-swap-candidate-or-idle-CPU-is-found.patch.
- Refresh
  patches.suse/sched-numa-Trace-when-no-candidate-CPU-was-found-on-the-preferred-node.patch.
- Refresh
  patches.suse/sched-numa-Use-similar-logic-to-the-load-balancer-for-moving-between-domains-with-spare-capacity.patch.
- Refresh
  patches.suse/sched-numa-replace-runnable_load_avg-by-load_avg.patch.
- Refresh
  patches.suse/sched-pelt-Add-a-new-runnable-average-signal.patch.
- Refresh
  patches.suse/sched-pelt-Remove-unused-runnable-load-average.patch.
- commit de86223
* Tue Feb 25 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-reorder-enqueue-dequeue_task_fair-path.patch.
- commit a0aa0f8
* Tue Feb 25 2020 mgorman@suse.de
- sched/numa: Distinguish between the different
  task_numa_migrate() failure cases (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- commit 408baa5
* Tue Feb 25 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-numa-Trace-when-no-candidate-CPU-was-found-on-the-preferred-node.patch.
- commit 7d03e16
* Tue Feb 25 2020 mgorman@suse.de
- sched/fair: Optimize select_idle_core() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- commit f749d53
* Tue Feb 25 2020 mgorman@suse.de
- sched/fair: Allow a per-CPU kthread waking a task to stack on
  the same CPU, to fix XFS performance regression (bsc#1154329).
- sched/fair: Allow a small load imbalance between low utilisation
  SD_NUMA domains (bnc#1160896).
- commit 2ab2039
* Tue Feb 25 2020 meissner@suse.de
- sign also s390x kernel images (bsc#1163524)
- commit b38b611
* Tue Feb 25 2020 vbabka@suse.cz
- mm, hotplug: fix page online with DEBUG_PAGEALLOC compiled
  but not enabled (VM Functionality, bsc#1164436).
- commit 05a4d19
* Tue Feb 25 2020 jslaby@suse.cz
- blacklist.conf: add CONFIG_PROC_FS=n entry
- commit cc29a90
* Tue Feb 25 2020 jslaby@suse.cz
- nbd: add a flush_workqueue in nbd_start_device (git-fixes).
- perf c2c: Fix return type for histogram sorting comparision
  functions (git-fixes).
- x86/cpu: Update cached HLE state on write to
  TSX_CTRL_CPUID_CLEAR (git-fixes).
- commit 6880922
* Tue Feb 25 2020 jroedel@suse.de
- KVM: nVMX: Check IO instruction VM-exit conditions
  (CVE-2020-2732 bsc#1163971).
- KVM: nVMX: Refactor IO bitmap checks into helper function
  (CVE-2020-2732 bsc#1163971).
- KVM: nVMX: Don't emulate instructions in guest mode
  (CVE-2020-2732 bsc#1163971).
- commit f91f45f
* Tue Feb 25 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/vt-selection-close-sel_buffer-race.patch
  patches.suse/vt-selection-handle-pending-signals-in-paste_selecti.patch
- commit 0c9df1b
* Tue Feb 25 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/powerpc-tm-Fix-clearing-MSR-TS-in-current-when-recla.patch
- commit 220f81e
* Mon Feb 24 2020 bp@suse.de
- x86/boot: Handle malformed SRAT tables during early ACPI parsing
  (bsc#1152489).
- commit ce68bc1
* Mon Feb 24 2020 jroedel@suse.de
- iommu/vt-d: Unnecessary to handle default identity domain
  (bsc#1162414).
- iommu/vt-d: Allow devices with RMRRs to use identity domain
  (bsc#1162414).
- commit 048a6f9
* Mon Feb 24 2020 nborisov@suse.com
- btrfs: rename btrfs_space_info_add_old_bytes (bsc#1141456).
- btrfs: remove orig_bytes from reserve_ticket (bsc#1141456).
- btrfs: fix may_commit_transaction to deal with no partial
  filling (bsc#1141456).
- btrfs: rework wake_all_tickets (bsc#1141456).
- btrfs: refactor the ticket wakeup code (bsc#1141456).
- btrfs: stop partially refilling tickets when releasing space
  (bsc#1141456).
- btrfs: add space reservation tracepoint for reserved bytes
  (bsc#1141456).
- btrfs: roll tracepoint into btrfs_space_info_update helper
  (bsc#1141456).
- btrfs: do not allow reservations if we have pending tickets
  (bsc#1141456).
- commit 18cd200
* Mon Feb 24 2020 yousaf.kaukab@suse.com
- Refresh patches.suse/mmc-sdhci-fix-up-CMD12-sending.patch.
- commit b36db25
* Mon Feb 24 2020 oneukum@suse.com
- tools lib traceevent: Remove unneeded qsort and uses memmove
  instead (git-fixes).
- commit 37953f8
* Mon Feb 24 2020 yousaf.kaukab@suse.com
- rtc: fsl-ftm-alarm: move patch to sorted section
- commit 80b90f8
* Mon Feb 24 2020 oneukum@suse.com
- kvm: Reintroduce nopvspin kernel parameter (bsc#1056427).
- commit dcec1fa
* Mon Feb 24 2020 yousaf.kaukab@suse.com
- thermal: qoriq: refresh patches
- Refresh patches.suse/thermal-qoriq-Add-hwmon-support.patch.
- Refresh
  patches.suse/thermal-qoriq-Add-local-struct-device-pointer.patch.
- Refresh
  patches.suse/thermal-qoriq-Add-local-struct-qoriq_sensor-pointer.patch.
- Refresh
  patches.suse/thermal-qoriq-Convert-driver-to-use-regmap-API.patch.
- Refresh
  patches.suse/thermal-qoriq-Do-not-report-invalid-temperature-read.patch.
- Refresh
  patches.suse/thermal-qoriq-Don-t-store-struct-thermal_zone_device.patch.
- Refresh
  patches.suse/thermal-qoriq-Drop-unnecessary-drvdata-cleanup.patch.
- Refresh
  patches.suse/thermal-qoriq-Embed-per-sensor-data-into-struct-qori.patch.
- Refresh
  patches.suse/thermal-qoriq-Enable-all-sensors-before-registering-.patch.
- Refresh
  patches.suse/thermal-qoriq-Pass-data-to-qoriq_tmu_calibration-dir.patch.
- Refresh
  patches.suse/thermal-qoriq-Pass-data-to-qoriq_tmu_register_tmu_zo.patch.
- Refresh
  patches.suse/thermal_hwmon-Add-devres-wrapper-for-thermal_add_hwm.patch.
- commit bd644db
* Mon Feb 24 2020 jslaby@suse.cz
- ttyprintk: fix a potential deadlock in interrupt context issue
  (git-fixes).
- commit dc7ade5
* Mon Feb 24 2020 pmladek@suse.com
- blacklist.conf: bug: cosmetic change; related to a larger code clean up
- commit 43ce447
* Mon Feb 24 2020 ykaukab@suse.de
- dpaa_eth: support all modes with rate adapting PHYs
  (bsc#1159662).
- commit a5b2d56
* Mon Feb 24 2020 pmladek@suse.com
- printk: fix exclusive_console replaying (bsc#1164711).
- commit 466e4dc
* Mon Feb 24 2020 msuchanek@suse.de
- sr_vendor: support Beurer GL50 evo CD-on-a-chip devices
  (boo#1164632).
- commit a186914
* Mon Feb 24 2020 msuchanek@suse.de
- Enable CONFIG_BLK_DEV_SR_VENDOR (boo#1164632).
- commit 1c8f90b
* Mon Feb 24 2020 jack@suse.cz
- patches.suse/ext4-Fix-mount-failure-with-quota-configured-as-modu.patch:
  Update tags.
- commit 713f734
* Mon Feb 24 2020 oneukum@suse.com
- Delete
  patches.suse/0001-kvm-Introduce-nopvspin-kernel-parameter.patch.
  Remove guarded patch as it has been rendered unnecessary by
  9043442b43b1fddf202591b84702863286700c1a
  ("locking/paravirt: Use new static key for controlling call of
  virt_spin_lock()")
  and b2798ba0b876 ("KVM: X86: Choose qspinlock when dedicated physical
  CPUs are available")
- commit 583da5e
* Mon Feb 24 2020 jgross@suse.com
- xen: Enable interrupts when calling _cond_resched()
  (bsc#1065600).
- commit 4f2ecad
* Mon Feb 24 2020 lyan@suse.com
- KVM: arm64: Treat emulated TVAL TimerValue as a signed 32-bit
  integer (bsc#1133021).
- KVM: arm64: pmu: Fix chained SW_INCR counters (bsc#1133021).
- KVM: arm64: pmu: Don't increment SW_INCR if PMCR.E is unset
  (bsc#1133021).
- KVM: arm: Make inject_abt32() inject an external abort instead
  (bsc#1133021).
- KVM: arm: Fix DFSR setting for non-LPAE aarch32 guests
  (bsc#1133021).
- KVM: arm/arm64: Fix young bit from mmu notifier (bsc#1133021).
- KVM: arm/arm64: vgic-its: Fix restoration of unmapped
  collections (bsc#1133021).
- KVM: Clean up __kvm_gfn_to_hva_cache_init() and its callers
  (bsc#1133021).
- KVM: Check for a bad hva before dropping into the ghc slow path
  (bsc#1133021).
- KVM: arm/arm64: Properly handle faulting of device mappings
  (bsc#1133021).
- KVM: arm64: Ensure 'params' is initialised when looking up
  sys register (bsc#1133021).
- KVM: arm/arm64: Get rid of unused arg in cpu_init_hyp_mode()
  (bsc#1133021).
- KVM: fix placement of refcount initialization (bsc#1133021).
- KVM: Fix NULL-ptr deref after kvm_create_vm fails (bsc#1133021).
- kvm: call kvm_arch_destroy_vm if vm creation fails
  (bsc#1133021).
- commit 51a3eef
* Mon Feb 24 2020 lyan@suse.com
- kvm: Allocate memslots and buses before calling kvm_arch_init_vm
  (bsc#1133021).
- Refresh
  patches.suse/kvm-x86-mmu-Recovery-of-shattered-NX-large-pages.patch.
- commit fc34308
* Mon Feb 24 2020 nborisov@suse.com
- btrfs: only reserve metadata_size for inodes (bsc#1141456).
- btrfs: rename the btrfs_calc_*_metadata_size helpers
  (bsc#1141456).
- commit d6be9ae
* Mon Feb 24 2020 nborisov@suse.com
- btrfs: introduce an evict flushing state (bsc#1141456).
- btrfs: refactor priority_reclaim_metadata_space (bsc#1141456).
- btrfs: factor out the ticket flush handling (bsc#1141456).
- btrfs: unify error handling for ticket flushing (bsc#1141456).
- btrfs: add a flush step for delayed iputs (bsc#1141456).
- commit 21300d0
* Sun Feb 23 2020 colyli@suse.de
- md/raid0: Fix buffer overflow at debug print (bsc#1164051).
- commit c36de2b
* Fri Feb 21 2020 mkubecek@suse.cz
- series.conf: cleanup
  Reorganize the "Storage" section a bit.
  No effect on expanded tree.
- commit 0a80524
* Fri Feb 21 2020 duwe@suse.de
- crypto: allow self-test for ansi_cprng (bsc#1164254).
- commit e75c9ce
* Fri Feb 21 2020 mkubecek@suse.cz
- series.conf: cleanup
  Keep the number of top level sections reasonable.
- commit ff097d4
* Fri Feb 21 2020 duwe@suse.de
- s390 crypto: explicitly memzero stack key material in aes_s390.c
  (bsc#1163459).
- random: move FIPS continuous test to output functions
  (bsc#1163458).
- commit b896cb7
* Fri Feb 21 2020 nstange@suse.de
- kABI: restore debugfs_remove_recursive() (bsc#1159198).
- commit 102712e
* Fri Feb 21 2020 mkubecek@suse.cz
- hwmon: (k10temp) Display up to eight sets of CCD temperatures
  (bsc#1163206).
- hwmon: (k10temp) Don't show temperature limits on Ryzen (Zen)
  CPUs (bsc#1163206).
- hwmon: (k10temp) Show core and SoC current and voltages on
  Ryzen CPUs (bsc#1163206).
- hwmon: (k10temp) Report temperatures per CPU die (bsc#1163206).
- hmon: (k10temp) Convert to use
  devm_hwmon_device_register_with_info (bsc#1163206).
- hwmon: (k10temp) Use bitops (bsc#1163206).
- commit 82bbfc1
* Fri Feb 21 2020 dwagner@suse.de
- arm64: KVM: Invoke compute_layout() before alternatives are
  applied (bsc#1162702).
- percpu-refcount: Use normal instead of RCU-sched" (bsc#1162702).
- drm/i915: Don't disable interrupts independently of the lock
  (bsc#1162702).
- x86/ioapic: Rename misnamed functions (bsc#1162702).
- block: Don't disable interrupts in trigger_softirq()
  (bsc#1162702).
- commit 227d21b
* Fri Feb 21 2020 ailiopoulos@suse.com
- xfs: Fix deadlock between AGI and AGF with RENAME_WHITEOUT
  (bsc#1164482).
- commit 96d108c
* Fri Feb 21 2020 jack@suse.cz
- ext4: Fix mount failure with quota configured as module
  (bsc#1164471).
  Refresh patches.suse/ext4-unsupported-features.patch
- commit 4ccdd26
* Fri Feb 21 2020 hare@suse.de
- Refresh
  patches.suse/sd-always-retry-READ-CAPACITY-for-ALUA-state-transit.patch.
- commit 6221d57
* Fri Feb 21 2020 hare@suse.de
- Delete
  patches.suse/sd-always-scan-VPD-pages-if-thin-provisioning-is-ena.patch.
- commit 7919fbe
* Fri Feb 21 2020 hare@suse.de
- Delete patches.suse/scsi-disable-VPD-page-check-on-error.patch.
- commit e6dd2e4
* Fri Feb 21 2020 hare@suse.de
- ch: review and re-enable refcounting patches
- ch: remove ch_mutex() (bsc#1124235).
- ch: synchronize ch_probe() and ch_open() (bsc#1124235).
- Refresh
  patches.suse/ch-fixup-refcounting-imbalance-for-SCSI-devices.patch.
- Delete
  patches.suse/ch-add-missing-mutex_lock-mutex_unlock-in-ch_release.patch.
- commit 9a39484
* Fri Feb 21 2020 hare@suse.de
- scsi: mpt3sas: Update drive version to 33.100.00.00
  (jsc#SLE-10717).
- scsi: mpt3sas: Remove usage of device_busy counter
  (jsc#SLE-10717).
- scsi: mpt3sas: Print function name in which cmd timed out
  (jsc#SLE-10717).
- scsi: mpt3sas: Optimize mpt3sas driver logging (jsc#SLE-10717).
- scsi: mpt3sas: print in which path firmware fault occurred
  (jsc#SLE-10717).
- scsi: mpt3sas: Handle CoreDump state from watchdog thread
  (jsc#SLE-10717).
- scsi: mpt3sas: Add support IOCs new state named COREDUMP
  (jsc#SLE-10717).
- scsi: mpt3sas: renamed _base_after_reset_handler function
  (jsc#SLE-10717).
- scsi: mpt3sas: Add support for NVMe shutdown (jsc#SLE-10717).
- scsi: mpt3sas: Update MPI Headers to v02.00.57 (jsc#SLE-10717).
- scsi: mpt3sas: Fix double free in attach error handling
  (jsc#SLE-10717).
- scsi: mpt3sas: change allocation option (jsc#SLE-10717).
- scsi: mpt3sas: Clean up some indenting (jsc#SLE-10717).
- commit 916674e
* Fri Feb 21 2020 hare@suse.de
- megaraid_sas-fixup-MSIx-interrupt-setup-during-resume.patch: replace with upstream version
- commit 56ba2a9
* Fri Feb 21 2020 hare@suse.de
- scsi: megaraid_sas: Update driver version to 07.713.01.00-rc1
  (jsc#SLE-10720).
- scsi: megaraid_sas: Use Block layer API to check SCSI device
  in-flight IO requests (jsc#SLE-10720).
- scsi: megaraid_sas: Limit the number of retries for the IOCTLs
  causing firmware fault (jsc#SLE-10720).
- scsi: megaraid_sas: Do not initiate OCR if controller is not
  in ready state (jsc#SLE-10720).
- scsi: megaraid_sas: Re-Define enum DCMD_RETURN_STATUS
  (jsc#SLE-10720).
- scsi: megaraid_sas: Do not set HBA Operational if FW is not
  in operational state (jsc#SLE-10720).
- scsi: megaraid_sas: Do not kill HBA if JBOD Seqence map or
  RAID map is disabled (jsc#SLE-10720).
- scsi: megaraid_sas: Do not kill host bus adapter, if adapter
  is already dead (jsc#SLE-10720).
- scsi: megaraid_sas: Update optimal queue depth for SAS and
  NVMe devices (jsc#SLE-10720).
- scsi: megaraid_sas: Set no_write_same only for Virtual Disk
  (jsc#SLE-10720).
- scsi: megaraid_sas: Reset adapter if FW is not in READY state
  after device resume (jsc#SLE-10720).
- commit 65e16b2
* Fri Feb 21 2020 hare@suse.de
- Disable 'megaraid_sas-fixup-MSIx-interrupt-setup-during-resume'
- commit e492554
* Fri Feb 21 2020 mkubecek@suse.cz
- series.conf: cleanup
  Move patches.suse/suse-hv-kabi.patch into kABI padding section.
- commit fc6dc14
* Fri Feb 21 2020 rgoldwyn@suse.com
- fix up iter on short count in fuse_direct_io() (git-fixes).
- ovl: fix lseek overflow on 32bit (git-fixes).
- ovl: fix wrong WARN_ON() in ovl_cache_update_ino() (git-fixes).
- commit 508fa98
* Fri Feb 21 2020 rgoldwyn@suse.com
- Refresh patches.suse/new-helper-lookup_positive_unlocked.patch.
  Remove compiler warnings because of unused goto label.
- commit 71e012e
* Thu Feb 20 2020 ohering@suse.de
- hyper-v: Untangle stimers and timesync from clocksources (jsc#SLE-8133).
- commit a1b2308
* Thu Feb 20 2020 ohering@suse.de
- hv: kabi placeholders (jsc#SLE-8133).
- commit c3e96e8
* Thu Feb 20 2020 jroedel@suse.de
- KVM: x86/mmu: Add explicit access mask for MMIO SPTEs
  (bsc#1164354).
- Refresh patches.suse/kvm-mmu-ITLB_MULTIHIT-mitigation.patch.
- Refresh
  patches.suse/kvm-svm-override-default-mmio-mask-if-memory-encryption-is-enabled.
- commit 8a15fbd
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: push the grant head when the log head moves forward
  (bsc#1164095).
- commit d1770d3
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: push iclog state cleaning into xlog_state_clean_log
  (bsc#1164095).
- commit d1535a4
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: factor iclog state processing out of
  xlog_state_do_callback() (bsc#1164095).
- commit 3094c67
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: factor callbacks out of xlog_state_do_callback()
  (bsc#1164095).
- commit 901e51d
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: factor debug code out of xlog_state_do_callback()
  (bsc#1164095).
- commit 860c5ae
* Thu Feb 20 2020 jroedel@suse.de
- KVM: x86/mmu: Revert "KVM: x86/mmu: Remove is_obsolete() call"
  (bsc#1164357).
- Refresh
  patches.suse/kvm-x86-mmu-Recovery-of-shattered-NX-large-pages.patch.
- commit c9e37dc
* Thu Feb 20 2020 jroedel@suse.de
- KVM: x86/mmu: Revert "Revert "KVM: MMU: reclaim the
  zapped-obsolete page first"" (bsc#1164361).
- Refresh
  patches.suse/kvm-x86-mmu-Recovery-of-shattered-NX-large-pages.patch.
- commit 3193cde
* Thu Feb 20 2020 jroedel@suse.de
- KVM: x86: Unconditionally call x86 ops that are always
  implemented (bsc#1164382).
- Refresh
  patches.suse/kvm-x86-mmu-Recovery-of-shattered-NX-large-pages.patch.
- commit 3095ae2
* Thu Feb 20 2020 mbrugger@suse.com
- ARM: dts: stm32: add missing vdda-supply to adc on
  stm32429i-eval (bsc#1164461).
- commit da5a397
* Thu Feb 20 2020 mbrugger@suse.com
- blacklist.conf: add duplicated commit ID
- commit a626162
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: prevent CIL push holdoff in log recovery (bsc#1164095).
- commit d2cfffa
* Thu Feb 20 2020 mbrugger@suse.com
- blacklist.conf: ignore fix for not supported arch
- commit ca8ddc1
* Thu Feb 20 2020 jroedel@suse.de
- iommu/qcom: Fix bogus detach logic (bsc#1164445).
- iommu/vt-d: Simplify check in identity_mapping() (bsc#1159594).
- iommu/vt-d: Remove deferred_attach_domain() (bsc#1159594).
- iommu/vt-d: Do deferred attachment in iommu_need_mapping()
  (bsc#1159594).
- iommu/vt-d: Move deferred device attachment into helper function
  (bsc#1159594).
- iommu/vt-d: Add attach_deferred() helper (bsc#1159594).
- iommu/vt-d: Fix compile warning from intel-svm.h (bsc#1164446).
- KVM: x86/mmu: Fix struct guest_walker arrays for 5-level paging
  (bsc#1164356).
- KVM: nVMX: Use correct root level for nested EPT shadow page
  tables (bsc#1164330).
- KVM: x86: Mask off reserved bit from #DB exception payload
  (bsc#1164353).
- KVM: Use vcpu-specific gva->hva translation when querying host
  page size (bsc#1164337).
- KVM: x86: Revert "KVM: X86: Fix fpu state crash in kvm guest"
  (bsc#1164381).
- KVM: x86: Ensure guest's FPU state is loaded when accessing
  for emulation (bsc#1164344).
- KVM: x86: Handle TIF_NEED_FPU_LOAD in kvm_{load,put}_guest_fpu()
  (bsc#1164349).
- KVM: x86: Protect pmu_intel.c from Spectre-v1/L1TF attacks
  (bsc#1164374).
- KVM: x86: Protect DR-based index computations from
  Spectre-v1/L1TF attacks (bsc#1164365).
- KVM: x86: Protect exit_reason from being used in Spectre-v1/L1TF
  attacks (bsc#1164366).
- KVM: x86: Protect MSR-based index computations from
  Spectre-v1/L1TF attacks in x86.c (bsc#1164371).
- KVM: x86: Protect MSR-based index computations in pmu.h from
  Spectre-v1/L1TF attacks (bsc#1164373).
- KVM: x86: Protect MSR-based index computations in
  fixed_msr_to_seg_unit() from Spectre-v1/L1TF attacks
  (bsc#1164372).
- KVM: x86: Protect kvm_lapic_reg_write() from Spectre-v1/L1TF
  attacks (bsc#1164370).
- KVM: x86: Protect ioapic_write_indirect() from Spectre-v1/L1TF
  attacks (bsc#1164368).
- KVM: x86: Protect ioapic_read_indirect() from Spectre-v1/L1TF
  attacks (bsc#1164367).
- KVM: x86: Refactor picdev_write() to prevent Spectre-v1/L1TF
  attacks (bsc#1164376).
- KVM: x86: Protect kvm_hv_msr_[get|set]_crash_data() from
  Spectre-v1/L1TF attacks (bsc#1164369).
- KVM: x86: Protect x86_decode_insn from Spectre-v1/L1TF attacks
  (bsc#1164375).
- kvm/svm: PKU not currently supported (bsc#1164335).
- KVM: x86: Remove spurious clearing of async #PF MSR
  (bsc#1164378).
- KVM: x86: Remove spurious kvm_mmu_unload() from vcpu destruction
  path (bsc#1164379).
- KVM: x86: Free wbinvd_dirty_mask if vCPU creation fails
  (bsc#1164348).
- KVM: x86/mmu: Apply max PA check for MMIO sptes to 32-bit KVM
  (bsc#1164355).
- KVM: x86: Fix potential put_fpu() w/o load_fpu() on MPX platform
  (bsc#1164346).
- kvm: nVMX: VMWRITE checks unsupported field before read-only
  field (bsc#1164331).
- kvm: nVMX: VMWRITE checks VMCS-link pointer before VMCS field
  (bsc#1164332).
- kvm: nVMX: Relax guest IA32_FEATURE_CONTROL constraints
  (bsc#1164329).
- KVM: retpolines: x86: eliminate retpoline from vmx.c exit
  handlers (bsc#1164333).
- KVM: VMX: Fix conditions for guest IA32_XSS support
  (bsc#1164340).
- KVM: x86: Introduce vcpu->arch.xsaves_enabled (bsc#1164351).
- KVM: SVM: Guard against DEACTIVATE when performing
  WBINVD/DF_FLUSH (bsc#1164334).
- KVM: SVM: Serialize access to the SEV ASID bitmap (bsc#1164336).
- KVM: VMX: Do not change PID.NDST when loading a blocked vCPU
  (bsc#1164339).
- KVM: VMX: Consider PID.PIR to determine if vCPU has pending
  interrupts (bsc#1164338).
- KVM: nVMX: Don't leak L1 MMIO regions to L2 (bsc#1164328).
- kvm: vmx: Limit guest PMCs to those supported on the host
  (bsc#1164342).
- kvm: x86: Use AMD CPUID semantics for AMD vCPUs (bsc#1164383).
- kvm: x86: Improve emulation of CPUID leaves 0BH and 1FH
  (bsc#1164350).
- kvm: x86: Fix a spurious -E2BIG in __do_cpuid_func
  (bsc#1164345).
- KVM: x86/mmu: Revert "Revert "KVM: MMU: collapse TLB flushes
  when zap all pages"" (bsc#1164360).
- KVM: x86/mmu: Revert "Revert "KVM: MMU: zap pages in batch""
  (bsc#1164363).
- KVM: x86/mmu: Revert "Revert "KVM: MMU: add tracepoint for
  kvm_mmu_invalidate_all_pages"" (bsc#1164359).
- KVM: x86/mmu: Revert "Revert "KVM: MMU: show mmu_valid_gen in
  shadow page related tracepoints"" (bsc#1164362).
- KVM: x86/mmu: Treat invalid shadow pages as obsolete
  (bsc#1164364).
- KVM: x86: Manually flush collapsible SPTEs only when toggling
  flags (bsc#1164352).
- KVM: x86: Return to userspace with internal error on unexpected
  exit reason (bsc#1164380).
- KVM: x86: Add kvm_emulate_{rd,wr}msr() to consolidate VXM/SVM
  code (bsc#1164343).
- KVM: x86: Refactor up kvm_{g,s}et_msr() to simplify callers
  (bsc#1164377).
- KVM: x86: Fix x86_decode_insn() return when fetching insn
  bytes fails (bsc#1164347).
- commit d065de5
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: push the AIL in xlog_grant_head_wake (bsc#1164095).
- commit 1bce18c
* Thu Feb 20 2020 mkubecek@suse.cz
- enable patches.suse/lan78xx-Enable-LEDs-and-auto-negotiation.patch
  This is one of inherited SLE15-SP1 non-upstream patches. It doesn't really
  match the bug it references and there has not been any apparent attempt to
  get it into mainline since it was added to SLE15. To avoid regressions,
  keep it in SLE15-SP2 for now but drop with SLE16 unless it gets upstreamed
  or there is at least some serious attempt to upstream it.
  Rename patches.suse/bsc1084332-0003-lan78xx-Enable-LEDs-and-auto-negotiation.patch
  to patches.suse/lan78xx-Enable-LEDs-and-auto-negotiation.patch, refresh it,
  enable and move into NIC driver section.
- commit 627e945
* Thu Feb 20 2020 ohering@suse.de
- hv_balloon: Balloon up according to request page number
  (git-fixes).
- scsi: storvsc: Correctly set number of hardware queues for
  IDE disk (git-fixes).
- hv_netvsc: Fix unwanted rx_table reset (git-fixes).
- hv_netvsc: Fix tx_table init in rndis_set_subchannel()
  (git-fixes).
- Drivers: hv: balloon: Remove dependencies on guest page size
  (git-fixes).
- hv_netvsc: flag software created hash value (git-fixes).
- hv_netvsc: Fix send_table offset in case of a host bug
  (git-fixes).
- hv_netvsc: Fix offset usage in netvsc_send_table() (git-fixes).
- commit 9bdb4de
* Wed Feb 19 2020 msuchanek@suse.de
- powerpc/tm: Fix clearing MSR[TS] in current when reclaiming
  on signal delivery (bsc#1118338 ltc#173734).
- commit 2e0d5f0
* Wed Feb 19 2020 tiwai@suse.de
- ASoC: sun8i-codec: Fix setting DAI data format (git-fixes).
- ASoC: fsl_sai: Fix exiting path on probing failure (git-fixes).
- ALSA: hda: Use scnprintf() for printing texts for sysfs/procfs
  (git-fixes).
- ALSA: hda/realtek - Apply quirk for yet another MSI laptop
  (git-fixes).
- ALSA: hda/realtek - Apply quirk for MSI GP63, too (git-fixes).
- ALSA: rawmidi: Avoid bit fields for state flags (git-fixes).
- ALSA: seq: Fix concurrent access to queue current tick/time
  (git-fixes).
- ALSA: seq: Avoid concurrent access to queue flags (git-fixes).
- commit a23ff90
* Wed Feb 19 2020 mbrugger@suse.com
- ata: ahci: Add shutdown to freeze hardware resources of ahci
  (bsc#1164388).
- commit ce5f6e5
* Wed Feb 19 2020 jroedel@suse.de
- iommu/arm-smmu-v3: Populate VMID field for CMDQ_OP_TLBI_NH_VA (bsc#1164308).
- commit d6eceea
* Wed Feb 19 2020 jroedel@suse.de
- blacklist.conf: Add b06c076ea962 Revert "iommu/arm-smmu: Make arm-smmu explicitly non-modular"
- commit 08f1fd5
* Wed Feb 19 2020 jroedel@suse.de
- blacklist.conf: Add 6e8fa7404c13 Revert "iommu/arm-smmu: Make arm-smmu-v3 explicitly non-modular"
- commit 4c1b45c
* Wed Feb 19 2020 jroedel@suse.de
- perf/x86/intel: Fix inaccurate period in context switch for
  auto-reload (bsc#1164307).
- iommu/vt-d: Avoid sending invalid page response (bsc#1164304).
- iommu/vt-d: Fix off-by-one in PASID allocation (bsc#1164305).
- iommu/vt-d: Match CPU and IOMMU paging mode (bsc#1164306).
- iommu/amd: Only support x2APIC with IVHD type 11h/40h
  (bsc#1164303).
- iommu/amd: Check feature support bit before accessing MSI
  capability registers (bsc#1164302).
- commit ead9f32
* Wed Feb 19 2020 mbenes@suse.cz
- tracing: Fix now invalid var_ref_vals assumption in trace action
  (git-fixes).
- commit 9385a9b
* Wed Feb 19 2020 jack@suse.cz
- block: fix get_max_segment_size() overflow on 32bit arch
  (bsc#1164285).
- commit 88517df
* Wed Feb 19 2020 jack@suse.cz
- ext4: fix support for inode sizes > 1024 bytes (bsc#1164284).
- commit 05b8b1c
* Wed Feb 19 2020 jack@suse.cz
- memcg: fix a crash in wb_workfn when a device disappears
  (bsc#1164276).
- commit b25cbaa
* Wed Feb 19 2020 mbrugger@suse.com
- arm64: dts: agilex/stratix10: fix pmu interrupt numbers
  (bsc#1164272).
- commit 0c677d5
* Wed Feb 19 2020 mbrugger@suse.com
- arm64: KVM: Device mappings should be execute-never
  (bsc#1164268).
- Refresh
  patches.suse/arm64-Ensure-VM_WRITE-VM_SHARED-ptes-are-clean-by-de.patch.
- commit b79bc51
* Wed Feb 19 2020 mkubecek@suse.cz
- fix upstream references
- fix Patch-mainline:
  patches.suse/fix-autofs-regression-caused-by-follow_managed-changes.patch
  patches.suse/fix-dget_parent-fastpath-race.patch
  patches.suse/fsnamei.c-fix-missing-barriers-when-checking-positivity.patch
  patches.suse/fsnamei.c-pull-positivity-check-into-follow_managed.patch
  patches.suse/new-helper-lookup_positive_unlocked.patch
- commit d37656d
* Wed Feb 19 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/dma-contiguous-cma-give-precedence-to-cmdline.patch
- commit 1b96e18
* Wed Feb 19 2020 lyan@suse.com
- Replace
  Replace patches.suse/kvm-aarch64-avoid-guest-access-host-pmu-register.patch
  with patches.suse/KVM-arm64-Write-arch.mdcr_el2-changes-since-last-vcp.patch
  upstream id is 4942dec6638b0 (bsc#1161692).
- commit 6264601
* Tue Feb 18 2020 tbogendoerfer@suse.de
- netdevsim: fix ptr_ret.cocci warnings (bsc#1154353).
- commit acfaee7
* Tue Feb 18 2020 rgoldwyn@suse.com
- fix autofs regression caused by follow_managed() changes
  (git-fixes, bsc#1159271).
- commit a954cfa
* Tue Feb 18 2020 rgoldwyn@suse.com
- fs/namei.c: fix missing barriers when checking positivity
  (bsc#1159271).
- fix dget_parent() fastpath race  (bsc#1159271).
- new helper: lookup_positive_unlocked()  (bsc#1159271).
- fs/namei.c: pull positivity check into follow_managed()
  (bsc#1159271).
- commit 15f64cd
* Tue Feb 18 2020 mgorman@suse.de
- sched/fair: fix statistics for find_idlest_group() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit 2db86c8
* Tue Feb 18 2020 mgorman@suse.de
- sched/fair: Fix kernel-doc warning in attach_entity_load_avg()
  (git fixes (sched)).
- commit 366accc
* Tue Feb 18 2020 msuchanek@suse.de
- powerpc/kexec: Move kexec files into a dedicated subdir
  (bsc#1140025 ltc#176086).
  Refresh
  patches.suse/powerpc-Avoid-clang-warnings-around-setjmp-and-longj.patch.
- powerpc/32: Split kexec low level code out of misc_32.S
  (bsc#1140025 ltc#176086).
- commit ea45911
* Tue Feb 18 2020 mbrugger@suse.com
- arm64: dts: fast models: Fix FVP PCI interrupt-map property
  (bsc#1164201).
- arm64: ssbs: Fix context-switch when SSBS is present on all CPUs
  (bsc#1164221).
- arm64: dts: marvell: clearfog-gt-8k: fix switch cpu port node
  (bsc#1164211).
- arm64: acpi: fix DAIF manipulation with pNMI (bsc#1164197).
- arm64: nofpsmid: Handle TIF_FOREIGN_FPSTATE flag cleanly
  (bsc#1164219).
- arm64: ptrace: nofpsimd: Fail FP/SIMD regset operations
  (bsc#1164220).
- arm64: cpufeature: Set the FP/SIMD compat HWCAP bits properly
  (bsc#1164199).
- arm64: cpufeature: Fix the type of no FP/SIMD capability
  (bsc#1164198).
- arm64: kbuild: remove compressed images on 'make ARCH=arm64
  (dist)clean' (bsc#1164218).
- arm64: dts: allwinner: a64: olinuxino: Fix SDIO supply regulator
  (bsc#1164200).
- arm64: dts: imx8mq-librem5-devkit: use correct interrupt for
  the magnetometer (bsc#1164205).
- arm64: dts: imx8mm: Change SDMA1 ahb clock for imx8mm
  (bsc#1164202).
- arm64: dts: ls1028a: fix endian setting for dcfg (bsc#1164208).
- arm64: Implement copy_thread_tls (bsc#1164195).
- update arm64 config files (add HAVE_COPY_THREAD_TLS=y)
- arm64: Move __ARCH_WANT_SYS_CLONE3 definition to uapi headers
  (bsc#1164196).
- arm64: dts: ls1028a: fix reboot node (bsc#1164209).
- Revert "arm64: dts: juno: add dma-ranges property"
  (bsc#1164194).
- arm64: dts: juno: Fix UART frequency (bsc#1164206).
- arm64: dts: meson-gxm-khadas-vim2: fix uart_A bluetooth node
  (bsc#1164216).
- arm64: dts: meson-gxl-s905x-khadas-vim: fix uart_A bluetooth
  node (bsc#1164215).
- arm64: dts: meson-gxl-s905x-khadas-vim: fix gpio-keys-polled
  node (bsc#1164214).
- arm64: dts: meson: odroid-c2: Disable usb_otg bus to avoid
  power failed warning (bsc#1164217).
- arm64: dts: meson: axg: fix audio fifo reg size (bsc#1164212).
- arm64: dts: marvell: Fix CP110 NAND controller node multi-line
  comment alignment (bsc#1164210).
- arm64: dts: imx8mm: Correct OPP table according to latest
  datasheet (bsc#1164203).
- commit 8ffc54a
* Tue Feb 18 2020 msuchanek@suse.de
- powerpc: avoid adjusting memory_limit for capture kernel memory
  reservation (bsc#1140025).
- powerpc: reserve memory for capture kernel after hugepages init
  (bsc#1140025).
- commit 3e6df66
* Tue Feb 18 2020 dwagner@suse.de
- nvme: fix the parameter order for nvme_get_log in
  nvme_get_fw_slot_info (bsc#1163774).
- commit f4930bf
* Tue Feb 18 2020 mbrugger@suse.com
- ARM: npcm: Bring back GPIOLIB support (bsc#1164185).
- commit 3c9a346
* Tue Feb 18 2020 mbrugger@suse.com
- blacklist.conf: blacklist commits with wrong fixes ID
- commit b51d31a
* Tue Feb 18 2020 mbrugger@suse.com
- ARM: dts: am43xx: add support for clkout1 clock (bsc#1164150).
- ARM: dts: meson8b: use the actual frequency for the GPU's
  364MHz OPP (bsc#1164174).
- ARM: dts: meson8: use the actual frequency for the GPU's
  182.1MHz OPP (bsc#1164172).
- ARM: dts: meson8b: fix the clock controller compatible string
  (bsc#1164173).
- ARM: dts: at91: sama5d3: define clock rate range for tcb1
  (bsc#1164156).
- ARM: dts: at91: sama5d3: fix maximum peripheral clock rates
  (bsc#1164157).
- ARM: dts: at91: Reenable UART TX pull-ups (bsc#1164155).
- ARM: dts: stm32: Add power-supply for DSI panel on
  stm32f469-disco (bsc#1164177).
- ARM: dts: imx7: Fix Toradex Colibri iMX7S 256MB NAND flash
  support (bsc#1164167).
- ARM: dts: imx6sll-evk: Remove incorrect power supply assignment
  (bsc#1164164).
- ARM: dts: imx6sl-evk: Remove incorrect power supply assignment
  (bsc#1164163).
- ARM: dts: imx6sx-sdb: Remove incorrect power supply assignment
  (bsc#1164165).
- ARM: dts: imx6qdl-sabresd: Remove incorrect power supply
  assignment (bsc#1164162).
- ARM: dts: imx6q-icore-mipi: Use 1.5 version of i.Core MX6DL
  (bsc#1164161).
- ARM: dts: imx6q-dhcom: Fix SGTL5000 VDDIO regulator connection
  (bsc#1164159).
- ARM: dts: imx7ulp: fix reg of cpu node (bsc#1164168).
- ARM: dts: imx6q-dhcom: fix rtc compatible (bsc#1164160).
- ARM: dts: meson8: fix the size of the PMU registers
  (bsc#1164171).
- ARM: dts: am571x-idk: Fix gpios property to have the correct
  gpio number (bsc#1164151).
- ARM: OMAP2+: Fix ti_sysc_find_one_clockdomain to check for
  to_clk_hw_omap (bsc#1164146).
- ARM: dts: imx6ul: imx6ul-14x14-evk.dtsi: Fix SPI NOR probing
  (bsc#1164166).
- ARM: dts: bcm283x: Fix critical trip point (bsc#1164158).
- ARM: dts: Cygnus: Fix MDIO node address/size cells
  (bsc#1164148).
- ARM: dts: BCM5301X: Fix MDIO node address/size cells
  (bsc#1164147).
- ARM: dts: Fix sgx sysconfig register for omap4 (bsc#1164149).
- ARM: dts: logicpd-torpedo-37xx-devkit-28: Reference new DRM
  panel (bsc#1164170).
- ARM: dts: s3c64xx: Fix init order of clock providers
  (bsc#1164176).
- ARM: dts: stm32: relax qspi pins slew-rate for stm32mp157
  (bsc#1164182).
- ARM: dts: sunxi: Revert phy-names removal for ECHI and OHCI
  (bsc#1164184).
- ARM: omap2plus_defconfig: Enable DRM_TI_TFP410 (bsc#1164186).
- ARM: dts: logicpd-som-lv: Fix i2c2 and i2c3 Pin mux
  (bsc#1164169).
- ARM: dts: aspeed-g5: Fixe gpio-ranges upper limit (bsc#1164152).
- ARM: dts: aspeed: swift: Change power supplies to version 2
  (bsc#1164153).
- ARM: dts: aspeed: swift: Fix FSI GPIOs (bsc#1164154).
- ARM: dts: r8a7779: Use SYSC "always-on" PM Domain for HSCIF
  (bsc#1164175).
- ARM: dts: stm32: add pwm cells to stm32f746 (bsc#1164180).
- ARM: dts: stm32: add pwm cells to stm32f429 (bsc#1164179).
- ARM: dts: stm32: add pwm cells to stm32mp157c (bsc#1164181).
- ARM: dts: stm32: add missing vdda-supply to adc on
  stm32h743i-eval (bsc#1164178).
- ARM: dts: stm32: remove fixed regulator unit address on
  stm32429i-eval (bsc#1164183).
- commit 303d59d
* Tue Feb 18 2020 msuchanek@suse.de
- asm-generic/tlb: avoid potential double flush (bsc#1163776
  ltc#183929).
- commit 3b90a7e
* Tue Feb 18 2020 mbrugger@suse.com
- lib/vdso: Make __arch_update_vdso_data() logic understandable
  (bsc#1164141).
- commit 0a18ce1
* Tue Feb 18 2020 lhenriques@suse.com
- ceph: noacl mount option is effectively ignored (jsc#SES-1134).
- ceph: canonicalize server path in place (jsc#SES-1134).
- ceph: do not execute direct write in parallel if O_APPEND is
  specified (jsc#SES-1134).
- rbd: set the 'device' link in sysfs (jsc#SES-1134).
- ceph: move net/ceph/ceph_fs.c to fs/ceph/util.c (jsc#SES-1134).
- ceph: print name of xattr in __ceph_{get,set}xattr() douts
  (jsc#SES-1134).
- ceph: print r_direct_hash in hex in __choose_mds() dout
  (jsc#SES-1134).
- ceph: use copy-from2 op in copy_file_range (jsc#SES-1134).
- ceph: close holes in structs ceph_mds_session and
  ceph_mds_request (jsc#SES-1134).
- ceph: allocate the correct amount of extra bytes for the
  session features (jsc#SES-1134).
- ceph: rename get_session and switch to use ceph_get_mds_session
  (jsc#SES-1134).
- ceph: remove the extra slashes in the server path
  (jsc#SES-1134).
- ceph: add possible_max_rank and make the code more readable
  (jsc#SES-1134).
- ceph: print dentry offset in hex and fix xattr_version type
  (jsc#SES-1134).
- ceph: only touch the caps which have the subset mask requested
  (jsc#SES-1134).
- ceph: don't clear I_NEW until inode metadata is fully populated
  (jsc#SES-1134).
- ceph: retry the same mds later after the new session is opened
  (jsc#SES-1134).
- ceph: check availability of mds cluster on mount after wait
  timeout (jsc#SES-1134).
- ceph: keep the session state until it is released
  (jsc#SES-1134).
- ceph: add __send_request helper (jsc#SES-1134).
- ceph: ensure we have a new cap before continuing in fill_inode
  (jsc#SES-1134).
- ceph: drop unused ttl_from parameter from fill_inode
  (jsc#SES-1134).
- ceph: fix possible long time wait during umount (jsc#SES-1134).
- ceph: only choose one MDS who is in up:active state without
  laggy (jsc#SES-1134).
- ceph: fix mdsmap cluster available check based on laggy number
  (jsc#SES-1134).
- ceph: remove unnecessary assignment in ceph_pre_init_acls()
  (jsc#SES-1134).
- ceph: delete redundant douts in con_get/put() (jsc#SES-1134).
- commit 7a69ca8
* Tue Feb 18 2020 tbogendoerfer@suse.de
- IB/mlx5: Use div64_u64 for num_var_hw_entries calculation
  (jsc#SLE-8446).
- RDMA/core: Fix protection fault in get_pkey_idx_qp_list
  (jsc#SLE-8449).
- RDMA/rxe: Fix soft lockup problem due to using tasklets in
  softirq (jsc#SLE-8449).
- RDMA/mlx5: Prevent overflow in mmap offset calculations
  (jsc#SLE-8446).
- IB/umad: Fix kernel crash while unloading ib_umad
  (jsc#SLE-8449).
- RDMA/mlx5: Fix async events cleanup flows (jsc#SLE-8446).
- RDMA/core: Add missing list deletion on freeing event queue
  (jsc#SLE-8449).
- RDMA/siw: Remove unwanted WARN_ON in siw_cm_llp_data_ready()
  (jsc#SLE-8381).
- RDMA/iw_cxgb4: initiate CLOSE when entering TERM (jsc#SLE-8392).
- IB/mlx5: Return failure when rts2rts_qp_counters_set_id is
  not supported (jsc#SLE-8446).
- RDMA/core: Fix invalid memory access in spec_filter_size
  (jsc#SLE-8449).
- IB/rdmavt: Reset all QPs when the device is shut down
  (jsc#SLE-8449).
- IB/hfi1: Close window for pq and request coliding
  (jsc#SLE-8449).
- IB/hfi1: Acquire lock to release TID entries when user file
  is closed (jsc#SLE-8449).
- RDMA/hfi1: Fix memory leak in _dev_comp_vect_mappings_create
  (jsc#SLE-8449).
- net: hns3: fix a copying IPv6 address error in
  hclge_fd_get_flow_tuples() (bsc#1154353).
- net: hns3: fix VF bandwidth does not take effect in some case
  (bsc#1154353).
- net: hns3: add management table after IMP reset (bsc#1154353).
- page_pool: refill page when alloc.count of pool is zero
  (bsc#1154353).
- ice: Trivial fixes (jsc#SLE-7926).
- ice: Use correct netif error function (jsc#SLE-7926).
- ice: Cleanup ice_vsi_alloc_q_vectors (jsc#SLE-7926).
- ice: Make print statements more compact (jsc#SLE-7926).
- ice: Use ice_pf_to_dev (jsc#SLE-7926).
- ice: Remove possible null dereference (jsc#SLE-7926).
- ice: update Unit Load Status bitmask to check after reset
  (jsc#SLE-7926).
- ice: fix and consolidate logging of NVM/firmware version
  information (jsc#SLE-7926).
- ice: Modify link message logging (jsc#SLE-7926).
- ice: Remove CONFIG_PCI_IOV wrap in ice_set_pf_caps
  (jsc#SLE-7926).
- ice: Remove ice_dev_onetime_setup() (jsc#SLE-7926).
- ice: Don't allow same value for Rx tail to be written twice
  (jsc#SLE-7926).
- ice: display supported and advertised link modes (jsc#SLE-7926).
- ice: Fix switch between FW and SW LLDP (jsc#SLE-7926).
- ice: Fix DCB rebuild after reset (jsc#SLE-7926).
- net: ena: ena-com.c: prevent NULL pointer dereference
  (bsc#1154492).
- net: ena: ethtool: use correct value for crc32 hash
  (bsc#1154492).
- net: ena: make ena rxfh support ETH_RSS_HASH_NO_CHANGE
  (bsc#1154492).
- net: ena: fix corruption of dev_idx_to_host_tbl (bsc#1154492).
- net: ena: fix incorrectly saving queue numbers when setting
  RSS indirection table (bsc#1154492).
- net: ena: rss: store hash function as values and not bits
  (bsc#1154492).
- net: ena: rss: fix failure to get indirection table
  (bsc#1154492).
- net: ena: rss: do not allocate key when not supported
  (bsc#1154492).
- net: ena: fix incorrect default RSS key (bsc#1154492).
- net: ena: add missing ethtool TX timestamping indication
  (bsc#1154492).
- net: ena: fix uses of round_jiffies() (bsc#1154492).
- net: ena: fix potential crash when rxfh key is NULL
  (bsc#1154492).
- i40e: Fix the conditional for i40e_vc_validate_vqs_bitmaps
  (bsc#1163036).
- bpf: Improve bucket_log calculation logic (bsc#1154353).
- i40e: Relax i40e_xsk_wakeup's return value when PF is busy
  (jsc#SLE-8025).
- mlxsw: spectrum_dpipe: Add missing error path (bsc#1154488).
- mlxsw: core: Add validation of hardware device types for MGPIR
  register (bsc#1154488).
- ipv6/addrconf: fix potential NULL deref in inet6_set_link_af()
  (bsc#1154353).
- taprio: Fix dropping packets when using taprio + ETF offloading
  (bsc#1154353).
- taprio: Use taprio_reset_tc() to reset Traffic Classes
  configuration (bsc#1154353).
- taprio: Add missing policy validation for flags (bsc#1154353).
- taprio: Fix still allowing changing the flags during runtime
  (bsc#1154353).
- taprio: Fix enabling offload with wrong number of traffic
  classes (bsc#1154353).
- net/mlx5: Deprecate usage of generic TLS HW capability bit
  (jsc#SLE-8464).
- net/mlx5e: TX, Error completion is for last WQE in batch
  (jsc#SLE-8464).
- net/mlx5: IPsec, fix memory leak at
  mlx5_fpga_ipsec_delete_sa_ctx (jsc#SLE-8464).
- net/mlx5: IPsec, Fix esp modify function attribute
  (jsc#SLE-8464).
- net/mlx5: Fix deadlock in fs_core (jsc#SLE-8464).
- skbuff: fix a data race in skb_queue_len() (bsc#1154353).
- cxgb4: Added tls stats prints (jsc#SLE-8389).
- net_sched: fix an OOB access in cls_tcindex (bsc#1154353).
- netdevsim: remove unused sdev code (bsc#1154353).
- netdevsim: use __GFP_NOWARN to avoid memalloc warning
  (bsc#1154353).
- netdevsim: use IS_ERR instead of IS_ERR_OR_NULL for debugfs
  (bsc#1154353).
- netdevsim: fix stack-out-of-bounds in nsim_dev_debugfs_init()
  (bsc#1154353).
- netdevsim: fix panic in nsim_dev_take_snapshot_write()
  (bsc#1154353).
- netdevsim: disable devlink reload when resources are being used
  (bsc#1154353).
- netdevsim: fix using uninitialized resources (bsc#1154353).
- bnxt_en: Fix TC queue mapping (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix logic that disables Bus Master during firmware
  reset (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix RDMA driver failure with SRIOV after firmware reset
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor logic to re-enable SRIOV after firmware
  reset detected (jsc#SLE-8371 bsc#1153274).
- cls_rsvp: fix rsvp_policy (bsc#1154353).
- RDMA/core: Make the entire API tree static (jsc#SLE-8449).
- RDMA/efa: Mask access flags with the correct optional range
  (jsc#SLE-5640).
- RDMA/cma: Fix unbalanced cm_id reference count during address
  resolve (jsc#SLE-8449).
- RDMA/umem: Fix ib_umem_find_best_pgsz() (jsc#SLE-8449).
- IB/mlx4: Fix leak in id_map_find_del (jsc#SLE-8461).
- IB/opa_vnic: Spelling correction of 'erorr' to 'error'
  (jsc#SLE-8449).
- IB/hfi1: Fix logical condition in msix_request_irq
  (jsc#SLE-8449).
- RDMA/cm: Use IBA functions for complex structure members
  (jsc#SLE-8449).
- RDMA/cm: Use IBA functions for simple structure members
  (jsc#SLE-8449).
- RDMA/cm: Use IBA functions for swapping get/set acessors
  (jsc#SLE-8449).
- RDMA/cm: Use IBA functions for simple get/set acessors
  (jsc#SLE-8449).
- RDMA/cm: Add SET/GET implementations to hide IBA wire format
  (jsc#SLE-8449).
- RDMA/cm: Add accessors for CM_REQ transport_type (jsc#SLE-8449).
- IB/mlx5: Return the administrative GUID if exists
  (jsc#SLE-8446).
- RDMA/core: Ensure that rdma_user_mmap_entry_remove() is a fence
  (jsc#SLE-8449).
- IB/mlx4: Fix memory leak in add_gid error flow (jsc#SLE-8461).
- IB/mlx5: Expose RoCE accelerator counters (jsc#SLE-8446).
- RDMA/mlx5: Set relaxed ordering when requested (jsc#SLE-8446).
- RDMA/uverbs: Add new relaxed ordering memory region access flag
  (jsc#SLE-8446).
- RDMA/efa: Allow passing of optional access flags for MR
  registration (jsc#SLE-5640).
- RDMA/core: Add optional access flags range (jsc#SLE-8449).
- RDMA/uverbs: Verify MR access flags (jsc#SLE-8449).
- RDMA/uverbs: Add ioctl command to get a device context
  (jsc#SLE-8449).
- RDMA/core: Remove ucontext_lock from the
  uverbs_destry_ufile_hw() path (jsc#SLE-8449).
- RDMA/core: Add UVERBS_METHOD_ASYNC_EVENT_ALLOC (jsc#SLE-8449).
- net/mlx5: Expose relaxed ordering bits (jsc#SLE-8464).
- net/mlx5: Add RoCE accelerator counters (jsc#SLE-8464).
- IB/srp: Never use immediate data if it is disabled by a user
  (jsc#SLE-8449).
- RDMA/rxe: Compute the maximum sges and inline size based on
  the WQE size (jsc#SLE-8449).
- Introduce maximum WQE size to check limits (jsc#SLE-8449).
- RDMA/efa: Remove unused ucontext parameter from
  efa_qp_user_mmap_entries_remove (jsc#SLE-5640).
- RDMA/efa: Remove {} brackets from single statement if
  (jsc#SLE-5640).
- RDMA/efa: Device definitions documentation updates
  (jsc#SLE-5640).
- RDMA/hns: Add support for extended atomic in userspace
  (jsc#SLE-8449).
- RDMA/hns: Get pf capabilities from firmware (jsc#SLE-8449).
- RDMA/hns: Add interfaces to get pf capabilities from firmware
  (jsc#SLE-8449).
- RDMA/hns: Remove some redundant variables related to
  capabilities (jsc#SLE-8449).
- RDMA/core: Use READ_ONCE for ib_ufile.async_file (jsc#SLE-8449).
- RDMA/core: Make ib_uverbs_async_event_file into a uobject
  (jsc#SLE-8449).
- RDMA/core: Remove the ufile arg from rdma_alloc_begin_uobject
  (jsc#SLE-8449).
- RDMA/core: Simplify type usage for ib_uverbs_async_handler()
  (jsc#SLE-8449).
- RDMA/core: Do not erase the type of ib_wq.uobject
  (jsc#SLE-8449).
- RDMA/core: Do not erase the type of ib_srq.uobject
  (jsc#SLE-8449).
- RDMA/core: Do not erase the type of ib_qp.uobject
  (jsc#SLE-8449).
- RDMA/core: Do not erase the type of ib_cq.uobject
  (jsc#SLE-8449).
- RDMA/core: Make ib_ucq_object use ib_uevent_object
  (jsc#SLE-8449).
- RDMA/core: Do not allow alloc_commit to fail (jsc#SLE-8449).
- RDMA/mlx5: Simplify devx async commands (jsc#SLE-8446).
- RDMA/core: Simplify destruction of FD uobjects (jsc#SLE-8449).
- RDMA/mlx5: Use RCU and direct refcounts to keep memory alive
  (jsc#SLE-8446).
- RDMA/uverbs: Remove needs_kfree_rcu from uverbs_obj_type_class
  (jsc#SLE-8449).
- IB/mlx5: Add mmap support for VAR (jsc#SLE-8446).
- IB/mlx5: Introduce VAR object and its alloc/destroy methods
  (jsc#SLE-8446).
- IB/mlx5: Extend caps stage to handle VAR capabilities
  (jsc#SLE-8446).
- RDMA/core: Remove err in iw_query_port (jsc#SLE-8449).
- RDMA/hns: Add support for reporting wc as software mode
  (jsc#SLE-8449).
- RDMA/hns: Bugfix for posting a wqe with sge (jsc#SLE-8449).
- IB/hfi1: Add RcvShortLengthErrCnt to hfi1stats (jsc#SLE-8449).
- IB/hfi1: Add software counter for ctxt0 seq drop (jsc#SLE-8449).
- IB/hfi1: Return void in packet receiving functions
  (jsc#SLE-8449).
- IB/hfi1: Decouple IRQ name from type (jsc#SLE-8449).
- IB/hfi1: Create API for auto activate (jsc#SLE-8449).
- IB/hfi1: IB/hfi1: Add an API to handle special case drop
  (jsc#SLE-8449).
- IB/hfi1: Move common receive IRQ code to function
  (jsc#SLE-8449).
- IB/hfi1: Add fast and slow handlers for receive context
  (jsc#SLE-8449).
- IB/hfi1: Move chip specific functions to chip.c (jsc#SLE-8449).
- RDMA/core: Fix locking in ib_uverbs_event_read (jsc#SLE-8449).
- IB/core: Fix build failure without hugepages (jsc#SLE-8449).
- IB/core: Rename event_handler_lock to qp_open_list_lock
  (jsc#SLE-8449).
- IB/core: Cut down single member ib_cache structure
  (jsc#SLE-8449).
- IB/core: Let IB core distribute cache update events
  (jsc#SLE-8449).
- IB/mlx5: Do reverse sequence during device removal
  (jsc#SLE-8446).
- RDMA/hns: Fix coding style issues (jsc#SLE-8449).
- RDMA/hns: Replace custom macros HNS_ROCE_ALIGN_UP
  (jsc#SLE-8449).
- RDMA/hns: Remove redundant print information (jsc#SLE-8449).
- RDMA/hns: Delete unnessary parameters in hns_roce_v2_qp_modify()
  (jsc#SLE-8449).
- RDMA/hns: Update the value of qp type (jsc#SLE-8449).
- RDMA/hns: Remove unused function hns_roce_init_eq_table()
  (jsc#SLE-8449).
- RDMA/hns: Avoid printing address of mtt page (jsc#SLE-8449).
- RDMA/core: Add trace points to follow MR allocation
  (jsc#SLE-8449).
- RDMA/core: Trace points for diagnosing completion queue issues
  (jsc#SLE-8449).
- RDMA/cma: Add trace points in RDMA Connection Manager
  (jsc#SLE-8449).
- RDMA/cm: Delete unused CM ARP functions (jsc#SLE-8449).
- RDMA/cm: Delete unused CM LAP functions (jsc#SLE-8449).
- RDMA/i40iw: fix a potential NULL pointer dereference
  (jsc#SLE-8449).
- RDMA/rxe: Fix error type of mmap_offset (jsc#SLE-8449).
- RDMA/mlx5: use true,false for bool variable (jsc#SLE-8446).
- RDMA/mlx4: use true,false for bool variable (jsc#SLE-8461).
- IB/iser: use true,false for bool variable (jsc#SLE-8449).
- IB/hfi1: use true,false for bool variable (jsc#SLE-8449).
- RDMA/siw: use true,false for bool variable (jsc#SLE-8381).
- IB/core: Fix ODP with IB_ACCESS_HUGETLB handling (jsc#SLE-8449).
- IB/core: Fix ODP get user pages flow (jsc#SLE-8449).
- IB/mlx5: Unify ODP MR code paths to allow extra flexibility
  (jsc#SLE-8446).
- IB/rdmavt: Correct comments in rdmavt_qp.h header
  (jsc#SLE-8449).
- IB/hfi1: List all receive contexts from debugfs (jsc#SLE-8449).
- IB/hfi1: Add accessor API routines to access context members
  (jsc#SLE-8449).
- RDMA/mlx4: Redo TX checksum offload in line with docs
  (jsc#SLE-8461).
- RDMA/cm: Use RCU synchronization mechanism to protect
  cm_id_private xa_load() (jsc#SLE-8449).
- RDMA/srpt: Remove unnecessary assertion in srpt_queue_response
  (jsc#SLE-8449).
- RDMA/netlink: Do not always generate an ACK for some netlink
  operations (jsc#SLE-8449).
- IB/mlx5: Fix outstanding_pi index for GSI qps (jsc#SLE-8446).
- RDMA/siw: Simplify QP representation (jsc#SLE-8381).
- RDMA/hns: Simplify the calculation and usage of wqe idx for
  post verbs (jsc#SLE-8449).
- RDMA/bnxt_re: Report more number of completion vectors
  (jsc#SLE-8372 bsc#1153275).
- RDMA/qedr: Add kernel capability flags for dpm enabled mode
  (jsc#SLE-8215).
- net/core: Do not clear VF index for node/port GUIDs query
  (bsc#1154353).
- flow_dissector: Fix to use new variables for port ranges in
  bpf hook (bsc#1154353).
- libbpf: Fix realloc usage in bpf_core_find_cands (bsc#1154353).
- sfc: move mcdi filtering code (jsc#SLE-8314).
- sfc: create header for mcdi filtering code (jsc#SLE-8314).
- sfc: rename mcdi filtering functions/structs (jsc#SLE-8314).
- bnxt_en: Add support for devlink info command (jsc#SLE-8371
  bsc#1153274).
- devlink: add macro for "fw.roce" (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Rename switch_id to dsn (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add support to update progress of flash update
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Move devlink_register before registering netdev
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Register devlink irrespective of firmware spec version
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor bnxt_dl_register() (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Disable workaround for lost interrupts on 575XX B0
  and newer chips (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Periodically check and remove aged-out ntuple filters
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Do not accept fragments for aRFS flow steering
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Support UDP RSS hashing on 575XX chips (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Remove the setting of dev_port (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Improve bnxt_probe_phy() (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Improve link up detection (jsc#SLE-8371 bsc#1153274).
- mlxsw: minimal: Fix an error handling path in
  'mlxsw_m_port_create()' (bsc#1154488).
- ice: Bump version (jsc#SLE-7926).
- ice: Implement ethtool get/set rx-flow-hash (jsc#SLE-7926).
- ice: Initilialize VF RSS tables (jsc#SLE-7926).
- ice: Optimize table usage (jsc#SLE-7926).
- ice: Enable writing filtering tables (jsc#SLE-7926).
- ice: Populate TCAM filter software structures (jsc#SLE-7926).
- ice: Allocate flow profile (jsc#SLE-7926).
- ice: Enable writing hardware filtering tables (jsc#SLE-7926).
- net: sched: sch_tbf: Don't overwrite backlog before dumping
  (bsc#1154353).
- devlink: Add health recover notifications on devlink flows
  (bsc#1154353).
- net/mlx5e: Enable all available stats for uplink reps
  (jsc#SLE-8464).
- net/mlx5e: Create q counters on uplink representors
  (jsc#SLE-8464).
- net/mlx5e: Convert rep stats to mlx5e_stats_grp-based infra
  (jsc#SLE-8464).
- net/mlx5e: IPoIB, use separate stats groups (jsc#SLE-8464).
- net/mlx5e: Convert stats groups array to array of group pointers
  (jsc#SLE-8464).
- net/mlx5e: Declare stats groups via macro (jsc#SLE-8464).
- net/mlx5e: Profile specific stats groups (jsc#SLE-8464).
- net/mlx5e: Move uplink rep init/cleanup code into own functions
  (jsc#SLE-8464).
- net/mlx5: DR, Allow connecting flow table to a lower/same
  level table (jsc#SLE-8464).
- net/mlx5: DR, Modify header copy support (jsc#SLE-8464).
- net/mlx5: DR, Modify set action limitation extension
  (jsc#SLE-8464).
- net/mlx5e: Add mlx5e_flower_parse_meta support (jsc#SLE-8464).
- net/mlx5e: allow TSO on VXLAN over VLAN topologies
  (jsc#SLE-8464).
- net/mlx5e: Fix printk format warning (jsc#SLE-8464).
- bpf: Fix trampoline usage in preempt (bsc#1154353).
- net: hns3: cleanup some coding style issue (bsc#1154353).
- net: hns3: remove redundant print on ENOMEM (bsc#1154353).
- net: hns3: delete unnecessary blank line and space for cleanup
  (bsc#1154353).
- net: hns3: rewrite a log in hclge_put_vector() (bsc#1154353).
- net: hns3: refine the input parameter 'size' for snprintf()
  (bsc#1154353).
- net: hns3: move duplicated macro definition into header
  (bsc#1154353).
- net: hns3: set VF's default reset_type to HNAE3_NONE_RESET
  (bsc#1154353).
- net: hns3: do not reuse pfmemalloc pages (bsc#1154353).
- net: hns3: limit the error logging in the hns3_clean_tx_ring()
  (bsc#1154353).
- net: hns3: replace snprintf with scnprintf in
  hns3_update_strings (bsc#1154353).
- net: hns3: replace snprintf with scnprintf in hns3_dbg_cmd_read
  (bsc#1154353).
- RDMA/mlx5: Fix handling of IOVA != user_va in ODP paths
  (jsc#SLE-8446).
- IB/mlx5: Mask out unsupported ODP capabilities for kernel QPs
  (jsc#SLE-8446).
- RDMA/mlx5: Don't fake udata for kernel path (jsc#SLE-8446).
- IB/mlx5: Add ODP WQE handlers for kernel QPs (jsc#SLE-8446).
- IB/core: Add interface to advise_mr for kernel users
  (jsc#SLE-8449).
- IB/core: Introduce ib_reg_user_mr (jsc#SLE-8449).
- net/mlx5: Allow creating autogroups with reserved entries
  (jsc#SLE-8464).
- net/mlx5: Add ignore level support fwd to table rules
  (jsc#SLE-8464).
- net/mlx5: fs_core: Introduce unmanaged flow tables
  (jsc#SLE-8464).
- net/mlx5: Refactor mlx5_create_auto_grouped_flow_table
  (jsc#SLE-8464).
- net/mlx5e: Add discard counters per priority (jsc#SLE-8464).
- net/mlx5e: Expose FEC feilds and related capability bit
  (jsc#SLE-8464).
- net/mlx5: Add mlx5_ifc definitions for connection tracking
  support (jsc#SLE-8464).
- net/mlx5: Add copy header action struct layout (jsc#SLE-8464).
- net/mlx5: Expose resource dump register mapping (jsc#SLE-8464).
- net/mlx5: Add structures and defines for MIRC register
  (jsc#SLE-8464).
- net/mlx5: Read MCAM register groups 1 and 2 (jsc#SLE-8464).
- net/mlx5: Add structures layout for new MCAM access reg groups
  (jsc#SLE-8464).
- net/mlx5: Expose vDPA emulation device capabilities
  (jsc#SLE-8464).
- net/mlx5: Add Virtio Emulation related device capabilities
  (jsc#SLE-8464).
- sfc: remove duplicated include from efx.c (jsc#SLE-8314).
- sfc/ethtool_common: Make some function to static (jsc#SLE-8314).
- net: hns3: refactor the notification scheme of PF reset
  (bsc#1154353).
- net: hns3: modify hclge_func_reset_sync_vf()'s return type to
  void (bsc#1154353).
- net: hns3: enlarge HCLGE_RESET_WAIT_CNT (bsc#1154353).
- net: hns3: refactor the procedure of VF FLR (bsc#1154353).
- net: hns3: refactor the precedure of PF FLR (bsc#1154353).
- net: hns3: split hclgevf_reset() into preparing and rebuilding
  part (bsc#1154353).
- net: hns3: split hclge_reset() into preparing and rebuilding
  part (bsc#1154353).
- sfc: remove set but not used variable 'nic_data' (jsc#SLE-8314).
- sfc: remove duplicated include from ef10.c (jsc#SLE-8314).
- bnxt: Detach page from page pool before sending up the stack
  (jsc#SLE-8371 bsc#1153274).
- devlink: add macro for "fw.psid" (bsc#1154353).
- sfc: move RPS code (jsc#SLE-8314).
- sfc: move yet more functions (jsc#SLE-8314).
- sfc: move RSS code (jsc#SLE-8314).
- sfc: move a couple more functions (jsc#SLE-8314).
- sfc: move some ethtool code (jsc#SLE-8314).
- sfc: move various functions (jsc#SLE-8314).
- sfc: move more rx code (jsc#SLE-8314).
- sfc: move more tx code (jsc#SLE-8314).
- sfc: refactor selftest work init code (jsc#SLE-8314).
- sfc: move MCDI logging device attribute (jsc#SLE-8314).
- sfc: conditioned some functionality (jsc#SLE-8314).
- sfc: move MCDI receive queue management code (jsc#SLE-8314).
- sfc: move MCDI transmit queue management code (jsc#SLE-8314).
- sfc: move MCDI event queue management code (jsc#SLE-8314).
- sfc: move MCDI VI alloc/free code (jsc#SLE-8314).
- sfc: move more MCDI port code (jsc#SLE-8314).
- sfc: move some MCDI port utility functions (jsc#SLE-8314).
- sfc: move some port link state/caps code (jsc#SLE-8314).
- vmxnet3: Remove always false conditional statement
  (bsc#1154353).
- bnxt_en: Call recovery done after reset is successfully done
  (jsc#SLE-8371 bsc#1153274).
- devlink: add devink notification when reporter update health
  state (bsc#1154353).
- devlink: add support for reporter recovery completion
  (bsc#1154353).
- sfc: move common tx code (jsc#SLE-8314).
- sfc: move common rx code (jsc#SLE-8314).
- sfc: move event queue management code (jsc#SLE-8314).
- sfc: move channel interrupt management code (jsc#SLE-8314).
- sfc: move channel alloc/removal code (jsc#SLE-8314).
- sfc: move channel start/stop code (jsc#SLE-8314).
- sfc: move some channel-related code (jsc#SLE-8314).
- sfc: move struct init and fini code (jsc#SLE-8314).
- sfc: move some device reset code (jsc#SLE-8314).
- sfc: move datapath management code (jsc#SLE-8314).
- sfc: move mac configuration and status functions (jsc#SLE-8314).
- sfc: move reset workqueue code (jsc#SLE-8314).
- sfc: further preparation for code split (jsc#SLE-8314).
- sfc: add new headers in preparation for code split
  (jsc#SLE-8314).
- net/mlx5: DR, Create multiple destination action from
  dr_create_fte (jsc#SLE-8464).
- net/mlx5: DR, Add support for multiple destination table action
  (jsc#SLE-8464).
- net/mlx5: DR, Align dest FT action creation to API
  (jsc#SLE-8464).
- net/mlx5: DR, Pass table flags at creation to lower layer
  (jsc#SLE-8464).
- net/mlx5: DR, Create multi-destination table for SW-steering
  use (jsc#SLE-8464).
- net/mlx5: DR, Create FTE entry in the FW from SW-steering
  (jsc#SLE-8464).
- net/mlx5: DR, Use attributes struct for FW flow table creation
  (jsc#SLE-8464).
- net/mlx5: Use async EQ setup cleanup helpers for multiple EQs
  (jsc#SLE-8464).
- net/mlx5: Reduce No CQ found log level from warn to debug
  (jsc#SLE-8464).
- net/mlx5: Increase the max number of channels to 128
  (jsc#SLE-8464).
- net/mlx5e: Support accept action on nic table (jsc#SLE-8464).
- mlx5: work around high stack usage with gcc (jsc#SLE-8464).
- net/mlx5: limit the function in local scope (jsc#SLE-8464).
- mlxsw: spectrum: Disable DIP_LINK_LOCAL check in hardware
  pipeline (bsc#1154488).
- mlxsw: spectrum: Disable SIP_DIP check in hardware pipeline
  (bsc#1154488).
- mlxsw: spectrum: Disable MC_DMAC check in hardware pipeline
  (bsc#1154488).
- mlxsw: spectrum: Disable SIP_CLASS_E check in hardware pipeline
  (bsc#1154488).
- net: hns3: modify an unsuitable reset level for hardware error
  (bsc#1154353).
- net: hns3: replace an unsuitable variable type in
  hclge_inform_reset_assert_to_vf() (bsc#1154353).
- net: hns3: add protection when get SFP speed as 0 (bsc#1154353).
- net: hns3: modify the IRQ name of misc vectors (bsc#1154353).
- net: hns3: modify an unsuitable log in
  hclge_map_ring_to_vector() (bsc#1154353).
- net: hns3: modify the IRQ name of TQP vector (bsc#1154353).
- net: hns3: re-organize vector handle (bsc#1154353).
- net: hns3: add trace event support for HNS3 driver
  (bsc#1154353).
- ice: Suppress Coverity warnings for xdp_rxq_info_reg
  (jsc#SLE-7926).
- ice: Add a boundary check in ice_xsk_umem() (jsc#SLE-7926).
- ice: add extra check for null Rx descriptor (jsc#SLE-7926).
- ice: suppress checked_return error (jsc#SLE-7926).
- ice: Demote MTU change print to debug (jsc#SLE-7926).
- ice: Enable ip link show on the PF to display VF unicast MAC(s)
  (jsc#SLE-7926).
- ice: Fix VF link state when it's IFLA_VF_LINK_STATE_AUTO
  (jsc#SLE-7926).
- ice: Remove Rx flex descriptor programming (jsc#SLE-7926).
- ice: Return error on not supported ethtool -C parameters
  (jsc#SLE-7926).
- ice: Restore interrupt throttle settings after VSI rebuild
  (jsc#SLE-7926).
- ice: Set default value for ITR in alloc function (jsc#SLE-7926).
- ice: Add ice_for_each_vf() macro (jsc#SLE-7926).
- ice: Add code to keep track of current dflt_vsi (jsc#SLE-7926).
- ice: Fix VF spoofchk (jsc#SLE-7926).
- ice: Support UDP segmentation offload (jsc#SLE-7926).
- sfc: Remove unnecessary dependencies on I2C (jsc#SLE-8314).
- mlxsw: spectrum_dcb: Allow setting default port priority
  (bsc#1154488).
- mlxsw: reg: Add QoS Port DSCP to Priority Mapping Register
  (bsc#1154488).
- page_pool: help compiler remove code in case CONFIG_NUMA=n
  (bsc#1154353).
- page_pool: handle page recycle for NUMA_NO_NODE condition
  (bsc#1154353).
- e1000e: Use netdev_info instead of pr_info for link messages
  (jsc#SLE-8100).
- igb: dont drop packets if rx flow control is enabled
  (jsc#SLE-7967 jsc#SLE-8010).
- sfc: avoid duplicate error handling code in
  'efx_ef10_sriov_set_vf_mac()' (jsc#SLE-8314).
- net: ena: remove set but not used variable 'rx_ring'
  (bsc#1154492).
- mlxsw: spectrum_router: Make route creation and destruction
  symmetric (bsc#1154488).
- mlxsw: spectrum_router: Eliminate dead code (bsc#1154488).
- mlxsw: spectrum_router: Remove unnecessary checks (bsc#1154488).
- net: hns3: only print misc interrupt status when handling fails
  (bsc#1154353).
- net: hns3: add a log for getting chain failure in
  hns3_nic_uninit_vector_data() (bsc#1154353).
- net: hns3: add some VF VLAN information for command "ip link
  show" (bsc#1154353).
- net: hns3: implement ndo_features_check ops for hns3 driver
  (bsc#1154353).
- net: hns3: get FD rules location before dump in debugfs
  (bsc#1154353).
- net: hns3: optimization for CMDQ uninitialization (bsc#1154353).
- net: hns3: remove useless mutex vport_cfg_mutex in the struct
  hclge_dev (bsc#1154353).
- net: hns3: check FE bit before calling hns3_add_frag()
  (bsc#1154353).
- mlxsw: spectrum: Rename MLXSW_REG_QEEC_HIERARCY_* enumerators
  (bsc#1154488).
- mlxsw: spectrum_qdisc: Clarify a comment (bsc#1154488).
- net: pkt_cls: Clarify a comment (bsc#1154353).
- sch_cake: drop unused variable tin_quantum_prio (bsc#1154353).
- cxgb4/chtls: fix ULD connection failures due to wrong TID base
  (jsc#SLE-8389).
- cxgb4: fix missed high priority region calculation
  (jsc#SLE-8389).
- net: hns3: do not schedule the periodic task when reset fail
  (bsc#1154353).
- net: hns3: allocate WQ with WQ_MEM_RECLAIM flag (bsc#1154353).
- net: hns3: remove unnecessary work in hclgevf_main
  (bsc#1154353).
- net: hns3: remove mailbox and reset work in hclge_main
  (bsc#1154353).
- net: hns3: schedule hclgevf_service by using delayed workqueue
  (bsc#1154353).
- tcp: Set rcv zerocopy hint correctly if skb last frag is <
  PAGE_SIZE (bsc#1154353).
- Revert "nfp: abm: fix memory leak in nfp_abm_u32_knode_replace"
  (bsc#1154353).
- net: ena: Add first_interrupt field to napi struct
  (bsc#1154492).
- net: ena: Implement XDP_TX action (bsc#1154492).
- net: ena: implement XDP drop support (bsc#1154492).
- rtnetlink: provide permanent hardware address in RTM_NEWLINK
  (bsc#1154353).
- cxgb4: add support for high priority filters (jsc#SLE-8389).
- nfp: add support for TLV device stats (bsc#1154353).
- tcp: Cleanup duplicate initialization of sk->sk_state
  (bsc#1154353).
- qed: remove redundant assignments to rc (jsc#SLE-8401).
- Documentation: nfp: add nfp driver specific notes (bsc#1154353).
- commit 00df886
* Tue Feb 18 2020 mbenes@suse.cz
- ftrace: Protect ftrace_graph_hash with ftrace_sync (git-fixes).
- commit 18b606e
* Tue Feb 18 2020 mbenes@suse.cz
- ftrace: Add comment to why rcu_dereference_sched() is open coded
  (git-fixes).
- commit 3920d17
* Tue Feb 18 2020 mbenes@suse.cz
- tracing: Annotate ftrace_graph_notrace_hash pointer with __rcu
  (git-fixes).
- commit dca30ea
* Tue Feb 18 2020 mbenes@suse.cz
- tracing: Annotate ftrace_graph_hash pointer with __rcu
  (git-fixes).
- commit 0478306
* Tue Feb 18 2020 jgross@suse.com
- xen/balloon: Support xend-based toolstack take two
  (bsc#1065600).
- commit 97502bd
* Tue Feb 18 2020 mbenes@suse.cz
- tracing: Fix sched switch start/stop refcount racy updates
  (git-fixes).
- commit cccfa7b
* Tue Feb 18 2020 mbenes@suse.cz
- tracing: Simplify assignment parsing for hist triggers
  (git-fixes).
- commit 4ec91e7
* Tue Feb 18 2020 mbenes@suse.cz
- tracing: Fix tracing_stat return values in error handling paths
  (git-fixes).
- commit f3d8551
* Tue Feb 18 2020 mbenes@suse.cz
- tracing: Fix very unlikely race of registering two stat tracers
  (git-fixes).
- commit f65b168
* Tue Feb 18 2020 mbrugger@suse.com
- serial: 8250_dw: Avoid double error messaging when IRQ absent
  (bsc#1164118).
- commit f336e59
* Tue Feb 18 2020 mbrugger@suse.com
- blacklist.conf: ignore duplicated commit ID
- commit 720d999
* Tue Feb 18 2020 mkoutny@suse.com
- powerpc: convert to copy_thread_tls (bsc#1163988).
- Update config files: Add CONFIG_HAVE_COPY_THREAD_TLS=y
- commit f351204
* Tue Feb 18 2020 petr.pavlu@suse.com
- cifs: fix mount option display for sec=krb5i (bsc#1161907).
- commit c56405f
* Tue Feb 18 2020 msuchanek@suse.de
- Delete patches.rpmify/powerpc-boot-Fix-missing-crc32poly.h-when-building-w.patch.
- commit 18a7f4d
* Tue Feb 18 2020 mbrugger@suse.com
- arm64: Revert support for execute-only user mappings
  (bsc#1160218).
- commit 373929f
* Tue Feb 18 2020 mkoutny@suse.com
- memcg: account security cred as well to kmemcg (bsc#1164094).
- commit 28f2006
* Tue Feb 18 2020 jack@suse.cz
- ext4: add cond_resched() to ext4_protect_reserved_inode
  (bsc#1164069 CVE-2020-8992).
- commit e44be93
* Tue Feb 18 2020 nborisov@suse.com
- btrfs: Fix split-brain handling when changing FSID to metadata
  uuid (git-fixes).
- btrfs: Handle another split brain scenario with metadata uuid
  feature (git-fixes).
- btrfs: Factor out metadata_uuid code from find_fsid (git-fixes).
- btrfs: Call find_fsid from find_fsid_inprogress (git-fixes).
- commit d6dd57b
* Tue Feb 18 2020 nborisov@suse.com
- btrfs: Correctly handle empty trees in find_first_clear_extent_bit (git-fixes).
- commit 35b5ead
* Tue Feb 18 2020 colyli@suse.de
- bcache: remove macro nr_to_fifo_front() (bsc#1163762).
- bcache: Revert "bcache: shrink btree node cache after
  bch_btree_check()" (bsc#1163762, bsc#1112504).
- bcache: ignore pending signals when creating gc and allocator
  thread (bsc#1163762, bsc#1112504).
- bcache: check return value of prio_read() (bsc#1163762).
- bcache: fix incorrect data type usage in btree_flush_write()
  (bsc#1163762).
- bcache: add readahead cache policy options via sysfs interface
  (bsc#1163762).
- bcache: explicity type cast in bset_bkey_last() (bsc#1163762).
- bcache: fix memory corruption in bch_cache_accounting_clear()
  (bsc#1163762).
- bcache: reap from tail of c->btree_cache in bch_mca_scan()
  (bsc#1163762).
- bcache: reap c->btree_cache_freeable from the tail in
  bch_mca_scan() (bsc#1163762).
- bcache: remove member accessed from struct btree (bsc#1163762).
- bcache: print written and keys in trace_bcache_btree_write
  (bsc#1163762).
- bcache: avoid unnecessary btree nodes flushing in
  btree_flush_write() (bsc#1163762).
- bcache: add code comments for state->pool in __btree_sort()
  (bsc#1163762).
- lib: crc64: include <linux/crc64.h> for 'crc64_be'
  (bsc#1163762).
- bcache: don't export symbols (bsc#1163762).
- bcache: remove the extra cflags for request.o (bsc#1163762).
- bcache: at least try to shrink 1 node in bch_mca_scan()
  (bsc#1163762).
- bcache: add idle_max_writeback_rate sysfs interface
  (bsc#1163762).
- bcache: add code comments in bch_btree_leaf_dirty()
  (bsc#1163762).
- bcache: fix deadlock in bcache_allocator (bsc#1163762).
- bcache: add code comment bch_keylist_pop() and
  bch_keylist_pop_front() (bsc#1163762).
- bcache: deleted code comments for dead code in
  bch_data_insert_keys() (bsc#1163762).
- bcache: add more accurate error messages in read_super()
  (bsc#1163762).
- bcache: fix static checker warning in bcache_device_free()
  (bsc#1163762).
- bcache: fix a lost wake-up problem caused by
  mca_cannibalize_lock (bsc#1163762).
- bcache: Fix an error code in bch_dump_read() (bsc#1163762).
- bcache: add cond_resched() in __bch_cache_cmp() (bsc#1163762).
- commit fdeab1e
* Mon Feb 17 2020 mkoutny@suse.com
- clone3: ensure copy_thread_tls is implemented (bsc#1163988).
- commit 480a977
* Mon Feb 17 2020 mkoutny@suse.com
- cgroup: Prevent double killing of css when enabling threaded
  cgroup (bsc#1153013).
- commit c46884c
* Mon Feb 17 2020 jack@suse.cz
- ext4: fix kernel oops caused by spurious casefold flag
  (bsc#1163984).
- commit 91a9b4c
* Mon Feb 17 2020 jack@suse.cz
- blacklist.conf: Blacklist 44d282796f81
- commit 13cd15a
* Mon Feb 17 2020 jack@suse.cz
- blacklist.conf: Blacklist 311ae9e159d8
- commit 72fb7d5
* Mon Feb 17 2020 msuchanek@suse.de
- Update
  patches.suse/powerpc-pseries-vio-Fix-iommu_table-use-after-free-r.patch
  (bsc#1065729 bsc#1163838 ltc#183850).
- commit 7b4b6e2
* Mon Feb 17 2020 lyan@suse.com
- KVM: s390: do not clobber registers during guest reset/store
  status (bsc#1133021).
- KVM: s390: ENOTSUPP -> EOPNOTSUPP fixups (bsc#1133021).
- commit 25937f8
* Mon Feb 17 2020 jack@suse.cz
- bdev: Refresh bdev size for disks without partitioning
  (bsc#1163921).
- commit 6da307d
* Mon Feb 17 2020 jack@suse.cz
- bdev: Factor out bdev revalidation into a common helper
  (bsc#1163920).
- commit 7d363e5
* Mon Feb 17 2020 jack@suse.cz
- udf: Allow writing to 'Rewritable' partitions (bsc#1163919).
- commit ae441d0
* Mon Feb 17 2020 jack@suse.cz
- blacklist.conf: Blacklist d9e9866803f7
- commit 53fef3b
* Mon Feb 17 2020 jack@suse.cz
- reiserfs: Fix memory leak of journal device string
  (bsc#1163867).
- commit 56254a8
* Mon Feb 17 2020 jack@suse.cz
- reiserfs: Fix spurious unlock in reiserfs_fill_super() error
  handling (bsc#1163869).
- commit f560b4f
* Mon Feb 17 2020 jack@suse.cz
- aio: prevent potential eventfd recursion on poll (bsc#1163918).
- commit d377261
* Mon Feb 17 2020 jack@suse.cz
- eventfd: track eventfd_signal() recursion depth (bsc#1163917).
- commit 29a8cc7
* Mon Feb 17 2020 jack@suse.cz
- ubifs: Fix memory leak from c->sup_node (bsc#1163916).
- commit fe0e8a1
* Mon Feb 17 2020 jack@suse.cz
- ubifs: Fix ino_t format warnings in orphan_delete()
  (bsc#1163915).
- commit 9d44fec
* Mon Feb 17 2020 jack@suse.cz
- ubifs: Fix deadlock in concurrent bulk-read and writepage
  (bsc#1163856).
- commit d4691a3
* Mon Feb 17 2020 jack@suse.cz
- ubifs: Fix wrong memory allocation (bsc#1163913).
- commit 08cc8d9
* Mon Feb 17 2020 jack@suse.cz
- ubifs: Fix FS_IOC_SETFLAGS unexpectedly clearing encrypt flag
  (bsc#1163855).
- commit 3341be7
* Mon Feb 17 2020 jack@suse.cz
- jbd2: make sure ESHUTDOWN to be recorded in the journal
  superblock (bsc#1163912).
- commit d51c1c8
* Mon Feb 17 2020 jack@suse.cz
- ext4, jbd2: ensure panic when aborting with zero errno
  (bsc#1163853).
- commit f604866
* Mon Feb 17 2020 jack@suse.cz
- jbd2: switch to use jbd2_journal_abort() when failed to submit
  the commit record (bsc#1163852).
- commit c3599a5
* Mon Feb 17 2020 jack@suse.cz
- jbd2_seq_info_next should increase position index (bsc#1163911).
- commit d64397e
* Mon Feb 17 2020 jack@suse.cz
- jbd2: clear JBD2_ABORT flag before journal_reset to update
  log tail info when load journal (bsc#1163910).
- commit 78b7063
* Mon Feb 17 2020 jack@suse.cz
- erofs: fix out-of-bound read for shifted uncompressed block
  (bsc#1163909).
- commit a97e621
* Mon Feb 17 2020 jack@suse.cz
- ubifs: don't trigger assertion on invalid no-key filename
  (bsc#1163850).
- commit 64c82f1
* Mon Feb 17 2020 jack@suse.cz
- readdir: be more conservative with directory entry names
  (bsc#1163907).
- commit 879663d
* Mon Feb 17 2020 jack@suse.cz
- locks: print unsigned ino in /proc/locks (bsc#1163905).
- blacklist.conf: blacklist e39e773ad100
- commit 611e661
* Mon Feb 17 2020 jack@suse.cz
- iomap: fix sub-page uptodate handling (bsc#1163904).
- commit f83b374
* Mon Feb 17 2020 jack@suse.cz
- ubifs: do_kill_orphans: Fix a memory leak bug (bsc#1163902).
- commit 37ace01
* Mon Feb 17 2020 jack@suse.cz
- ubifs: Fixed missed le64_to_cpu() in journal (bsc#1163901).
- commit cc34990
* Mon Feb 17 2020 jack@suse.cz
- fcntl: fix typo in RWH_WRITE_LIFE_NOT_SET r/w hint name
  (bsc#1163843).
- commit bc0e099
* Mon Feb 17 2020 jack@suse.cz
- ext4: improve explanation of a mount failure caused by a
  misconfigured kernel (bsc#1163843).
- commit 900aad6
* Mon Feb 17 2020 jack@suse.cz
- ext4: fix race conditions in ->d_compare() and ->d_hash()
  (bsc#1163899).
- commit cfc289b
* Mon Feb 17 2020 jack@suse.cz
- ext4: fix deadlock allocating crypto bounce page from mempool
  (bsc#1163898).
- commit 21b72aa
* Mon Feb 17 2020 jack@suse.cz
- ext4: validate the debug_want_extra_isize mount option at
  parse time (bsc#1163897).
- commit b0ee42b
* Mon Feb 17 2020 jack@suse.cz
- ext4: unlock on error in ext4_expand_extra_isize()
  (bsc#1163896).
- commit cd7a6d4
* Mon Feb 17 2020 jack@suse.cz
- block, bfq: do not plug I/O for bfq_queues with no proc refs
  (bsc#1163894).
- commit 3c9b27c
* Mon Feb 17 2020 jack@suse.cz
- block: fix splitting segments on boundary masks (bsc#1163893).
- commit 8b3de45
* Mon Feb 17 2020 jack@suse.cz
- compat_ioctl: block: handle BLKGETZONESZ/BLKGETNRZONES
  (bsc#1163892).
- commit c3d2ac2
* Mon Feb 17 2020 jack@suse.cz
- compat_ioctl: block: handle BLKREPORTZONE/BLKRESETZONE
  (bsc#1163891).
- commit bbed8ba
* Mon Feb 17 2020 jack@suse.cz
- jbd2: do not clear the BH_Mapped flag when forgetting a metadata
  buffer (bsc#1163836).
- commit 17af302
* Mon Feb 17 2020 jack@suse.cz
- jbd2: move the clearing of b_modified flag to the
  journal_unmap_buffer() (bsc#1163880).
- commit 2f2419e
* Mon Feb 17 2020 jack@suse.cz
- ext4: fix checksum errors with indexed dirs (bsc#1160979).
- commit b490dab
* Mon Feb 17 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/0001-crypto-sun4i-ss-fix-big-endian-issues.patch
  patches.suse/0001-perf-imx_ddr-Add-MODULE_DEVICE_TABLE.patch
- commit 9d8931e
* Mon Feb 17 2020 mkubecek@suse.cz
- blaklist.conf: improve comments
- "already gone in" is rather cryptic, change the d51224b73d18 entry to
  "duplicate of ac479b51f3f4"
- change the 1340cc631bd0 entry to "duplicate of d79749f7716d"
- commit 580e740
* Mon Feb 17 2020 msuchanek@suse.de
- powerpc/mmu_gather: enable RCU_TABLE_FREE even for !SMP case
  (bsc#1163776 ltc#183929).
- Refresh
  patches.suse/mm-mmu_gather-invalidate-TLB-correctly-on-batch-allo.patch.
- commit b99c448
* Mon Feb 17 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/fmc-remove-left-over-ipmi-fru.h-after-fmc-deletion.patch
  patches.suse/mm-thp-don-t-need-care-deferred-split-queue-in-memcg-charge-move-path.patch
  patches.suse/mm-vmscan-protect-shrinker-idr-replace-with-CONFIG_MEMCG.patch
  patches.suse/ptr_ring-add-include-of-linux-mm.h.patch
  patches.suse/taskstats-fix-data-race.patch
- commit b311938
* Mon Feb 17 2020 oneukum@suse.com
- crypto: atmel - Fix build error of CRYPTO_AUTHENC (git-fixes).
- commit 96a9a36
* Mon Feb 17 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/scsi-lpfc-Fix-Fabric-hostname-registration-if-system.patch
  patches.suse/scsi-lpfc-Fix-MDS-Latency-Diagnostics-Err-drop-rates.patch
  patches.suse/scsi-lpfc-Fix-Rework-setting-of-fdmi-symbolic-node-n.patch
  patches.suse/scsi-lpfc-Fix-disablement-of-FC-AL-on-lpe35000-model.patch
  patches.suse/scsi-lpfc-Fix-improper-flag-check-for-IO-type.patch
  patches.suse/scsi-lpfc-Fix-missing-check-for-CSF-in-Write-Object-.patch
  patches.suse/scsi-lpfc-Fix-ras_log-via-debugfs.patch
  patches.suse/scsi-lpfc-Fix-unmap-of-dpp-bars-affecting-next-drive.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.6.0.3.patch
  No effect on expanded tree.
- commit b74bc8d
* Mon Feb 17 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/panfrost: Handle resetting on timeout better'
- commit c1cf6b0
* Mon Feb 17 2020 tzimmermann@suse.de
- drm/mipi_dbi: Fix off-by-one bugs in mipi_dbi_blank() (bsc#1152489)
- commit 5f73109
* Mon Feb 17 2020 mkubecek@suse.cz
- series.conf: cleanup
  Keep ACPI patches in one place.
  No effect on expanded tree.
- commit daba698
* Mon Feb 17 2020 tzimmermann@suse.de
- drm/etnaviv: fix dumping of iommuv2 (bsc#1152472)
- commit f714fd7
* Mon Feb 17 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/ehl: Define EHL powerwells independently of ICL'
- commit 2edb74e
* Mon Feb 17 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Copy across scheduler behaviour flags across submit fences'
- commit fe75061
* Mon Feb 17 2020 tiwai@suse.de
- hwmon: (pmbus/ltc2978) Fix PMBus polling of MFR_COMMON
  definitions (git-fixes).
- commit f1c1df9
* Mon Feb 17 2020 tiwai@suse.de
- drivers: ipmi: fix off-by-one bounds check that leads to a
  out-of-bounds write (git-fixes).
- commit 901290b
* Mon Feb 17 2020 jslaby@suse.cz
- vt: selection, close sel_buffer race (bnc#1162928
  CVE-2020-8648).
- vt: selection, handle pending signals in paste_selection
  (bnc#1162928 CVE-2020-8648).
- commit c7af915
* Mon Feb 17 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/drivers-ipmi-Modify-max-length-of-IPMB-packet.patch
  patches.suse/drivers-ipmi-Support-raw-i2c-packet-in-IPMB.patch
  No effect on expanded tree.
- commit cb3f6eb
* Mon Feb 17 2020 glin@suse.com
- bpf, sockmap: Don't sleep while holding RCU lock on tear-down
  (bsc#1155518).
- bpftool: Don't crash on missing xlated program instructions
  (bsc#1155518).
- samples: bpf: Allow for -ENETDOWN in xdpsock (bsc#1155518).
- bpf: Fix modifier skipping logic (bsc#1155518).
- commit c617a95
* Mon Feb 17 2020 firo.yang@suse.com
- enic: prevent waking up stopped tx queues over watchdog reset
  (bsc#1133147).
- commit b9b83d8
* Sat Feb 15 2020 mgorman@suse.de
- sched/fair: Take into account runnable_avg to classify group
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit 60b875c
* Sat Feb 15 2020 mgorman@suse.de
- sched/pelt: Add a new runnable average signal (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit eb2bc08
* Sat Feb 15 2020 mgorman@suse.de
- sched/pelt: Remove unused runnable load average (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit 99634f9
* Sat Feb 15 2020 tiwai@suse.de
- mwifiex: Fix possible buffer overflows in
  mwifiex_cmd_append_vsie_tlv() (git-fixes).
- mwifiex: Fix possible buffer overflows in
  mwifiex_ret_wmm_get_status() (git-fixes).
- commit 0a55d21
* Sat Feb 15 2020 tiwai@suse.de
- mac80211: fix quiet mode activation in action frames
  (git-fixes).
- qmi_wwan: re-add DW5821e pre-production variant (git-fixes).
- drm/i915/gvt: more locking for ppgtt mm LRU list (git-fixes).
- Revert "drm/sun4i: drv: Allow framebuffer modifiers in mode
  config" (git-fixes).
- commit 8c7a45f
* Sat Feb 15 2020 tiwai@suse.de
- ALSA: usb-audio: Apply sample rate quirk for Audioengine D1
  (git-fixes).
- ALSA: usb-audio: Apply 48kHz fixed rate playback for Jabra
  Evolve 65 headset (git-fixes).
- commit 36550e5
* Sat Feb 15 2020 tiwai@suse.de
- ALSA: pcm: Fix double hw_free calls (git-fixes).
- ALSA: usb-audio: Add clock validity quirk for Denon
  MC7000/MCX8000 (git-fixes).
- ALSA: hda/realtek - Fix silent output on MSI-GL73 (git-fixes).
- ALSA: hda/realtek - Add more codec supported Headset Button
  (git-fixes).
- ALSA: usb-audio: Fix UAC2/3 effect unit parsing (git-fixes).
- ALSA: usb-audio: add quirks for Line6 Helix devices fw>=2.82
  (git-fixes).
- ALSA: usb-audio: add implicit fb quirk for MOTU M Series
  (git-fixes).
- ALSA: usb-audio: unlock on error in probe (git-fixes).
- ALSA: usb-audio: Add boot quirk for MOTU M Series (git-fixes).
- ALSA: usb-audio: Use lower hex numbers for IDs (git-fixes).
- commit 70d0fd1
* Fri Feb 14 2020 mgorman@suse.de
- sched/numa: Stop an exhastive search if a reasonable swap
  candidate or idle CPU is found (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- commit a207d84
* Fri Feb 14 2020 tiwai@suse.de
- Move ipmi_si fix to subsystem sorted section (bsc#1161943)
- commit 53fab48
* Fri Feb 14 2020 mgorman@suse.de
- sched/numa: Bias swapping tasks based on their preferred
  node (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/numa: Find an alternative idle CPU if the CPU is part of
  an active NUMA balance (bnc#1155798 (CPU scheduler functional
  and performance backports)).
- sched/numa: Prefer using an idle cpu as a migration target
  instead of comparing tasks (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched/numa: Use similar logic to the load balancer for moving
  between domains with spare capacity (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched/numa: replace runnable_load_avg by load_avg (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: reorder enqueue/dequeue_task_fair path (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/numa: Distinguish between the different task_numa_migrate
  failure cases (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/numa: Trace when no candidate CPU was found on the
  preferred node (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- mm: thp: don't need care deferred split queue in memcg charge
  move path (git fixes (mm/memcg)).
- fmc: remove left-over ipmi-fru.h after fmc deletion (git fixes
  (FRU removal)).
- ptr_ring: add include of linux/mm.h (git fixes (mm/includes)).
- taskstats: fix data-race (git fixes (taskstats)).
- mm: vmscan: protect shrinker idr replace with CONFIG_MEMCG
  (git fixes (mm/vmscan)).
- commit a00a8d0
* Fri Feb 14 2020 mgorman@suse.de
- Refresh patches.suse/sched-fair-Optimize-select_idle_core.patch.
- commit 59efedb
* Thu Feb 13 2020 tiwai@suse.de
- Update config files: enable CONFIG_FW_CFG_SYSFS for arm64 (bsc#1163521)
- commit 3795961
* Thu Feb 13 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-Allow-a-small-load-imbalance-between-low-utilisation-SD_NUMA-domains.patch.
- commit d461156
* Wed Feb 12 2020 jdelvare@suse.de
- ACPI / watchdog: Set default timeout in probe (bsc#1162557).
- ACPI: watchdog: Allow disabling WDAT at boot (bsc#1162557).
- commit 54f65f7
* Wed Feb 12 2020 mcgrof@suse.com
- patches.suse/simple_recursive_removal-kernel-side-rm-rf-for-ramfs.patch: (bsc#1159198,CVE-2019-19770).
- commit ae16628
* Wed Feb 12 2020 trenn@suse.com
- cpuidle: use first valid target residency as poll time
  (jsc#SLE-11312).
- commit 4e4e473
* Wed Feb 12 2020 trenn@suse.com
- cpuidle: haltpoll: Take 'idle=' override into account
  (jsc#SLE-11312).
- commit b7ea903
* Wed Feb 12 2020 trenn@suse.com
- cpuidle-haltpoll: Enable kvm guest polling when dedicated
  physical CPUs are available (jsc#SLE-11312).
- commit c957ec1
* Wed Feb 12 2020 trenn@suse.com
- cpuidle-haltpoll: do not set an owner to allow modunload
  (jsc#SLE-11312).
- commit dc19dcc
* Wed Feb 12 2020 trenn@suse.com
- cpuidle-haltpoll: return -ENODEV on modinit failure
  (jsc#SLE-11312).
- commit 5f4abc5
* Wed Feb 12 2020 trenn@suse.com
- cpuidle-haltpoll: set haltpoll as preferred governor
  (jsc#SLE-11312).
- commit f056412
* Wed Feb 12 2020 trenn@suse.com
- cpuidle: allow governor switch on cpuidle_register_driver()
  (jsc#SLE-11312).
- commit a8f3113
* Wed Feb 12 2020 hare@suse.de
- scsi: lpfc: Update lpfc version to 12.6.0.4
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Clean up hba max_lun_queue_depth checks
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Remove handler for obsolete ELS - Read Port
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix coverity errors in fmdi attribute handling
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix compiler warning on frame size
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix release of hwq to clear the eq relationship
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix registration of ELS type support in fdmi
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix broken Credit Recovery after driver load
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix lpfc_io_buf resource leak in
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix RQ buffer leakage when no IOCBs available
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.6.0.3
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix improper flag check for IO type
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix MDS Latency Diagnostics Err-drop rates
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix unmap of dpp bars affecting next driver load
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix disablement of FC-AL on lpe35000 models
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix ras_log via debugfs (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix Fabric hostname registration if system
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix missing check for CSF in Write Object Mbox
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix: Rework setting of fdmi symbolic node name
  registration (bsc#1156632,jsc#SLE-8654).
- commit ad7b473
* Wed Feb 12 2020 tiwai@suse.de
- tools/kvm_stat: Fix kvm_exit filter name (git-fixes).
- tools lib: Fix builds when glibc contains strlcpy() (git-fixes).
- tools/power/acpi: fix compilation error (git-fixes).
- sh_eth: check sh_eth_cpu_data::dual_port when dumping registers
  (git-fixes).
- commit a1660a4
* Wed Feb 12 2020 tiwai@suse.de
- enetc: Don't print from enetc_sched_speed_set when link goes
  down (git-fixes).
- PM / devfreq: Add new name attribute for sysfs (git-fixes).
- PM / devfreq: Don't fail devfreq_dev_release if not in list
  (git-fixes).
- PM / devfreq: Set scaling_max_freq to max on OPP notifier error
  (git-fixes).
- PM / devfreq: Fix devfreq_notifier_call returning errno
  (git-fixes).
- commit 280c62f
* Wed Feb 12 2020 trenn@suse.com
- cpuidle-haltpoll: vcpu hotplug support (jsc#SLE-11312).
- commit be83569
* Wed Feb 12 2020 trenn@suse.com
- cpuidle: header file stubs must be "static inline"
  (jsc#SLE-11312).
- commit 72c5ab4
* Wed Feb 12 2020 tiwai@suse.de
- blacklist.conf: Add already cherry-picked i915 commits
- commit e79e886
* Wed Feb 12 2020 trenn@suse.com
- cpuidle-haltpoll: disable host side polling when kvm virtualized
  (jsc#SLE-11312).
- Update config files.
- commit 7a92459
* Wed Feb 12 2020 tiwai@suse.de
- alarmtimer: Unregister wakeup source when module get fails
  (git-fixes).
- afs: Fix characters allowed into cell names (git-fixes).
- afs: Fix afs_lookup() to not clobber the version on a new dentry
  (git-fixes).
- afs: Fix use-after-loss-of-ref (git-fixes).
- atm: eni: fix uninitialized variable warning (git-fixes).
- staging: axis-fifo: add unspecified HAS_IOMEM dependency
  (git-fixes).
- afs: Fix missing cell comparison in afs_test_super()
  (git-fixes).
- afs: Fix creation calls in the dynamic root to fail with
  EOPNOTSUPP (git-fixes).
- afs: Fix mountpoint parsing (git-fixes).
- afs: Fix SELinux setting security label on /afs (git-fixes).
- afs: Fix afs_find_server lookups for ipv4 peers (git-fixes).
- afs: Remove set but not used variables 'before', 'after'
  (git-fixes).
- affs: fix a memory leak in affs_remount (git-fixes).
- afs: Fix large file support (git-fixes).
- afs: Fix possible assert with callbacks from yfs servers
  (git-fixes).
- afs: Fix missing timeout reset (git-fixes).
- commit 70f7941
* Wed Feb 12 2020 fdmanana@suse.com
- Btrfs: make deduplication with range including the last block
  work (bsc#1163496).
- commit 177be09
* Wed Feb 12 2020 trenn@suse.com
- cpuidle: add haltpoll governor (jsc#SLE-11312).
- Update config files.
- commit 3395a31
* Wed Feb 12 2020 fdmanana@suse.com
- fs: allow deduplication of eof block into the end of the
  destination file (bsc#1163496).
- commit a6f621e
* Wed Feb 12 2020 fdmanana@suse.com
- Btrfs: send, fix emission of invalid clone operations within
  the same file (bsc#1163493).
- commit e5b1bf0
* Wed Feb 12 2020 trenn@suse.com
- governors: unify last_state_idx (jsc#SLE-11312).
- Refresh
  patches.suse/cpuidle-teo-Allow-tick-to-be-stopped-if-PM-QoS-is-us.patch.
- Refresh
  patches.suse/cpuidle-teo-Avoid-using-early-hits-incorrectly.patch.
- commit 5219109
* Wed Feb 12 2020 trenn@suse.com
- cpuidle: add poll_limit_ns to cpuidle_device structure
  (jsc#SLE-11312).
- commit 39e79ea
* Wed Feb 12 2020 fdmanana@suse.com
- Btrfs: fix race between adding and putting tree mod seq elements
  and nodes (bsc#1163384).
- commit 20ba722
* Wed Feb 12 2020 fdmanana@suse.com
- Btrfs: fix infinite loop during fsync after rename operations
  (bsc#1163383).
- commit d4b4993
* Wed Feb 12 2020 fdmanana@suse.com
- Btrfs: fix missing hole after hole punching and fsync when
  using NO_HOLES (bsc#1158749).
- commit 1e49dd1
* Wed Feb 12 2020 trenn@suse.com
- add cpuidle-haltpoll driver (jsc#SLE-11312).
- Update config files.
- supported.conf: add cpuidle-haltpoll as supported
  supported.conf:
  Add newly introduced cpuidle-haltpoll driver
- commit ba1edb5
* Wed Feb 12 2020 mkubecek@suse.cz
- drop obsolete btrfs patches inherited from SLE15-SP1
- drop
  patches.suse/btrfs-prevent-ioctls-from-interfering-with-a-swap-file.patch
    (mainline commit eede2bf34f4f, v5.0-rc1)
  patches.suse/btrfs-rename-and-export-get_chunk_map.patch
    (mainline commit 60ca842e3457, v5.0-rc1)
  patches.suse/btrfs-support-swap-files.patch
    (mainline commit ed46ff3d4237, v5.0-rc1)
- commit 7f19d4b
* Wed Feb 12 2020 tiwai@suse.de
- ASoC: sgtl5000: Fix VDDA and VDDIO comparison (git-fixes).
- commit 75f282a
* Wed Feb 12 2020 tiwai@suse.de
- crypto: ccree - fix pm wrongful error reporting (git-fixes).
- Refresh patches.suse/crypto-ccree-fix-PM-race-condition.patch.
- commit dbcb926
* Wed Feb 12 2020 tiwai@suse.de
- iwlwifi: don't throw error when trying to remove IGTK
  (git-fixes).
- ARM: tegra: Enable PLLP bypass during Tegra124 LP1 (git-fixes).
- drm/amd/dm/mst: Ignore payload update failures (git-fixes).
- clk: tegra: Mark fuse clock as critical (git-fixes).
- mfd: dln2: More sanity checking for endpoints (git-fixes).
- media: rc: ensure lirc is initialized before registering input
  device (git-fixes).
- media: v4l2-core: compat: ignore native command codes
  (git-fixes).
- PM: core: Fix handling of devices deleted during system-wide
  resume (git-fixes).
- media/v4l2-core: set pages dirty upon releasing DMA buffers
  (git-fixes).
- power: supply: ltc2941-battery-gauge: fix use-after-free
  (git-fixes).
- usb: gadget: legacy: set max_speed to super-speed (git-fixes).
- crypto: ccree - fix FDE descriptor sequence (git-fixes).
- crypto: ccree - fix backlog memory leak (git-fixes).
- ACPI: video: Do not export a non working backlight interface
  on MSI MS-7721 boards (git-fixes).
- regulator fix for "regulator: core: Add regulator_is_equal()
  helper" (git-fixes).
- regulator: core: Add regulator_is_equal() helper (git-fixes).
- platform/x86: intel_scu_ipc: Fix interrupt support (git-fixes).
- mmc: spi: Toggle SPI polarity, do not hardcode it (git-fixes).
- mmc: sdhci-pci: Make function amd_sdhci_reset static
  (git-fixes).
- commit 798d10c
* Wed Feb 12 2020 mkubecek@suse.cz
- fix mainline references
- fix Patch-mainline:
  patches.suse/apparmor-Switch-to-GFP_KERNEL-where-possible.patch
  patches.suse/apparmor-Use-a-memory-pool-instead-per-CPU-caches.patch
  patches.suse/apparmor-fix-aa_xattrs_match-may-sleep-while-holding-a-RCU-lock.patch
  patches.suse/apparmor-fix-bind-mounts-aborting-with-ENOMEM.patch
  patches.suse/apparmor-fix-wrong-buffer-allocation-in-aa_new_mount.patch
  patches.suse/apparmor-increase-left-match-history-buffer-size.patch
  patches.suse/apparmor-make-it-so-work-buffers-can-be-allocated-from-atomic-context.patch
  patches.suse/apparmor-only-get-a-label-reference-if-the-fast-path-check-fails.patch
  patches.suse/apparmor-reduce-rcu_read_lock-scope-for-aa_file_perm-mediation.patch
- commit 04ce0c4
* Wed Feb 12 2020 mkubecek@suse.cz
- update patch metadata
- update Git-commit after (likely) maintainer tree rebase:
  patches.suse/scsi-tcm_qla2xxx-Make-qlt_alloc_qfull_cmd-set-cmd-se.patch
- commit 1747315
* Tue Feb 11 2020 dbueso@suse.de
- ipc/msg.c: consolidate all xxxctl_down() functions
  (bsc#1159886).
- ipc/sem.c: document and update memory barriers (bsc#1159886).
- ipc/msg.c: update and document memory barriers (bsc#1159886).
- ipc/mqueue.c: update/document memory barriers (bsc#1159886).
- ipc/mqueue.c: remove duplicated code (bsc#1159886).
- locking/osq: Use optimized spinning loop for arm64
  (bsc#1149032).
- cgroup: Optimize single thread migration (bsc#1163388).
- cgroup/cpuset: Convert cpuset_mutex to percpu_rwsem
  (bsc#1163388).
- commit 95157e6
* Tue Feb 11 2020 tiwai@suse.de
- vfio/spapr/nvlink2: Skip unpinning pages on error exit
  (git-fixes).
- commit 97b7cca
* Tue Feb 11 2020 tiwai@suse.de
- smp_mb__{before,after}_atomic(): update Documentation
  (git-fixes).
- tomoyo: Use atomic_t for statistics counter (git-fixes).
- irqdomain: Fix a memory leak in irq_domain_push_irq()
  (git-fixes).
- commit ab7e36c
* Tue Feb 11 2020 tiwai@suse.de
- irqchip/gic-v3-its: Reference to its_invall_cmd descriptor
  when building INVALL (git-fixes).
- hrtimer: Annotate lockless access to timer->state (git-fixes).
- commit 18567f5
* Tue Feb 11 2020 tiwai@suse.de
- dma-mapping: fix handling of dma-ranges for reserved memory
  (again) (git-fixes).
- commit 854b530
* Tue Feb 11 2020 tiwai@suse.de
- kconfig: fix broken dependency in randconfig-generated .config
  (git-fixes).
- clocksource: Prevent double add_timer_on() for watchdog_timer
  (git-fixes).
- iwlwifi: mvm: avoid use after free for pmsr request (git-fixes).
- drop_monitor: Do not cancel uninitialized work item (git-fixes).
- soc: qcom: rpmhpd: Set 'active_only' for active only power
  domains (git-fixes).
- soc/tegra: fuse: Correct straps' address for older Tegra124
  device trees (git-fixes).
- bus: tegra-aconnect: Remove PM_CLK dependency (git-fixes).
- ARM: at91: pm: use of_device_id array to find the proper shdwc
  node (git-fixes).
- ARM: at91: pm: use SAM9X60 PMC's compatible (git-fixes).
- ARM: dma-api: fix max_pfn off-by-one error in __dma_supported()
  (git-fixes).
- commit 80930f7
* Mon Feb 10 2020 msuchanek@suse.de
- powerpc/kuap: Fix set direction in allow/prevent_user_access()
  (bsc#1156395).
- powerpc/32s: Fix bad_kuap_fault() (bsc#1156395).
- commit ecc6175
* Mon Feb 10 2020 tiwai@suse.de
- ipmi_si: Avoid spurious errors for optional IRQs (bsc#1161943).
- commit 807bbff
* Mon Feb 10 2020 tiwai@suse.de
- media: go7007: Fix URB type for interrupt handling
  (bsc#1162583).
- commit 658c146
* Mon Feb 10 2020 msuchanek@suse.de
- powerpc/futex: Fix incorrect user access blocking (bsc#1156395).
- powerpc/ptdump: Only enable PPC_CHECK_WX with STRICT_KERNEL_RWX
  (bsc#1156395).
- powerpc/ptdump: Fix W+X verification (bsc#1156395).
- powerpc: Define arch_is_kernel_initmem_freed() for lockdep
  (bsc#1156395).
- powerpc/ptdump: get out of note_prot_wx() when
  CONFIG_PPC_DEBUG_WX is not selected (bsc#1156395).
- commit f8eff5c
* Mon Feb 10 2020 mhocko@suse.com
- mm/sparse.c: reset section's mem_map when fully deactivated
  (bnc#1162503).
- commit f068a8c
* Mon Feb 10 2020 msuchanek@suse.de
- powerpc/papr_scm: Fix leaking 'bus_desc.provider_name' in some
  paths (FATE#327775 bsc#1142685 ltc#179509).
- commit 1c49eb1
* Mon Feb 10 2020 mgorman@suse.de
- apparmor: fix aa_xattrs_match() may sleep while holding a RCU
  lock (bnc#1158765).
- apparmor: only get a label reference if the fast path check
  fails (bnc#1158765).
- apparmor: fix bind mounts aborting with -ENOMEM (bnc#1158765).
- apparmor: make it so work buffers can be allocated from atomic
  context (bnc#1158765).
- apparmor: reduce rcu_read_lock scope for aa_file_perm mediation
  (bnc#1158765).
- apparmor: fix wrong buffer allocation in aa_new_mount
  (bnc#1158765).
- apparmor: increase left match history buffer size (bnc#1158765).
- apparmor: Switch to GFP_KERNEL where possible (bnc#1158765).
- apparmor: Use a memory pool instead per-CPU caches
  (bnc#1158765).
- commit db8094b
* Mon Feb 10 2020 tiwai@suse.de
- Move upstreamed wireless fixes into sorted section
  Refreshed:
  patches.suse/libertas-dont-exit-from-lbs_ibss_join_existing-with.patch
  patches.suse/libertas-make-lbs_ibss_join_existing-return-error.patch
  patches.suse/mwifiex-fix-unbalanced-locking-in-mwifiex_process_co.patch
- commit 8dbbd1d
* Mon Feb 10 2020 msuchanek@suse.de
- powerpc/pseries/vio: Fix iommu_table use-after-free refcount
  warning (bsc#1065729).
- powerpc/pseries: Advance pfn if section is not present in
  lmb_is_removable() (bsc#1065729).
- powerpc/pseries: Allow not having ibm,
  hypertas-functions::hcall-multi-tce for DDW (bsc#1065729).
- powerpc/pseries/hotplug-memory: Change rc variable to bool
  (bsc#1065729).
- commit fe5c033
* Mon Feb 10 2020 mkubecek@suse.cz
- tomoyo: Don't use nifty names on sockets (git-fixes).
  Bring the patch again as bsc#1162590 turned out to be bogus.
- commit e6918af
* Mon Feb 10 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/scsi-qla2xxx-Fix-unbound-NVME-response-length.patch
- commit f9847d8
* Sat Feb  8 2020 tiwai@suse.de
- drm/amd/display: Retrain dongles when SINK_COUNT becomes
  non-zero (git-fixes).
- clk: qcom: rcg2: Don't crash if our parent can't be found;
  return an error (git-fixes).
- clk: qcom: Don't overwrite 'cfg' in clk_rcg2_dfs_populate_freq()
  (git-fixes).
- watchdog: fix UAF in reboot notifier handling in watchdog core
  code (git-fixes).
- drivers: watchdog: stm32_iwdg: set WDOG_HW_RUNNING at probe
  (git-fixes).
- virtio_balloon: Fix memory leaks on errors in
  virtballoon_probe() (git-fixes).
- virtio-balloon: Fix memory leak when unloading while hinting
  is in progress (git-fixes).
- virtio-pci: check name when counting MSI-X vectors (git-fixes).
- virtio-balloon: initialize all vq callbacks (git-fixes).
- commit 56decc0
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic/x2apic: Implement IPI shorthands support (bsc#1162702).
- commit af57cfd
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic/flat64: Remove the IPI shorthand decision logic (bsc#1162702).
- commit 309c2e1
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Share common IPI helpers (bsc#1162702).
- commit e29e384
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Remove the shorthand decision logic (bsc#1162702).
- commit b931a9c
* Fri Feb  7 2020 dwagner@suse.de
- x86/smp: Enhance native_send_call_func_ipi() (bsc#1162702).
- commit f0857f7
* Fri Feb  7 2020 dwagner@suse.de
- x86/smp: Move smp_function_call implementations into IPI code (bsc#1162702).
- commit 10bcbc5
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Provide and use helper for send_IPI_allbutself() (bsc#1162702).
- commit ee9e660
* Fri Feb  7 2020 mbenes@suse.cz
- livepatch/samples/selftest: Use klp_shadow_alloc() API correctly
  (bsc#1071995).
- commit 00eed06
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Add static key to Control IPI shorthands (bsc#1162702).
- commit 6d35b8a
* Fri Feb  7 2020 mbenes@suse.cz
- livepatch/selftest: Clean up shadow variable names and type
  (bsc#1071995).
- commit e95b82b
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Move no_ipi_broadcast() out of 32bit (bsc#1162702).
- commit 9c72d3f
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Add NMI_VECTOR wait to IPI shorthand (bsc#1162702).
- commit 11f617e
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Remove dest argument from __default_send_IPI_shortcut() (bsc#1162702).
- commit 6e1b483
* Fri Feb  7 2020 dwagner@suse.de
- x86/hotplug: Silence APIC and NMI when CPU is dead (bsc#1162702).
- commit c8f6f01
* Fri Feb  7 2020 dwagner@suse.de
- x86/cpu: Move arch_smt_update() to a neutral place (bsc#1162702).
- Refresh patches.suse/x86-speculation-taa-Add-mitigation-for-TSX-Async-Abo.patch.
- Refresh patches.suse/x86-speculation-taa-Fix-printing-of-TAA_MSG_SMT-on-I.patch.
- commit 1c4fec9
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic/uv: Make x2apic_extra_bits static (bsc#1162702).
- Refresh patches.suse/x86-platform-uv-Add-UV-Hubbed-Hubless-Proc-FS-Files.patch.
- Refresh patches.suse/x86-platform-uv-Return-UV-Hubless-System-Type.patch.
- commit c91a792
* Fri Feb  7 2020 nborisov@suse.com
- btrfs: drop log root for dropped roots (bsc#1166772).
- btrfs: do not delete mismatched root refs (bsc#1166772).
- btrfs: fix invalid removal of root ref (bsc#1166772).
- btrfs: rework arguments of btrfs_unlink_subvol (bsc#1166772).
- btrfs: do not leak reloc root if we fail to read the fs root (bsc#1166772).
- commit 9f44227
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Consolidate the apic local headers (bsc#1162702).
- commit c920fec
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Move apic_flat_64 header into apic directory (bsc#1162702).
- commit 73a08d5
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Move ipi header into apic directory (bsc#1162702).
- commit 06589f2
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Cleanup the include maze (bsc#1162702).
- Refresh patches.suse/x86-platform-uv-Check-EFI-Boot-to-set-reboot-type.patch.
- Refresh patches.suse/x86-platform-uv-Return-UV-Hubless-System-Type.patch.
- Refresh patches.suse/x86-platform-uv-Save-OEM_ID-from-ACPI-MADT-probe.patch.
- commit 327f5f6
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Move IPI inlines into ipi.c (bsc#1162702).
- commit 81a4d6d
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Invoke perf_events_lapic_init() after enabling APIC (bsc#1162702).
- Refresh patches.suse/x86-apic-32-Avoid-bogus-LDR-warnings.patch.
- commit b5224ec
* Fri Feb  7 2020 tiwai@suse.de
- uaccess: disallow > INT_MAX copy sizes (git-fixes).
- commit 59e5f9a
* Fri Feb  7 2020 tiwai@suse.de
- thermal: brcmstb_thermal: Do not use DT coefficients
  (git-fixes).
- soc: ti: wkup_m3_ipc: Fix race condition with rproc_boot
  (git-fixes).
- serdev: Don't claim unsupported ACPI serial devices (git-fixes).
- commit ea25f56
* Fri Feb  7 2020 tiwai@suse.de
- rtc: cmos: Stop using shared IRQ (git-fixes).
- rtc: hym8563: Return -EINVAL if the time is known to be invalid
  (git-fixes).
- commit 15ca52d
* Fri Feb  7 2020 tiwai@suse.de
- pxa168fb: Fix the function used to release some memory in an
  error handling path (git-fixes).
- qmi_wwan: Add support for Quectel RM500Q (git-fixes).
- commit b92716e
* Fri Feb  7 2020 tiwai@suse.de
- power: supply: core: Update sysfs-class-power ABI document
  (git-fixes).
- power: supply: sbs-battery: Fix a signedness bug in
  sbs_get_battery_capacity() (git-fixes).
- power: supply: axp20x_ac_power: Fix reporting online status
  (git-fixes).
- power/supply: ingenic-battery: Don't change scale if there's
  only one (git-fixes).
- commit cfd3f61
* Fri Feb  7 2020 tiwai@suse.de
- blacklist.conf: Add already cherry-picked platform drivers
- commit 57ff8bd
* Fri Feb  7 2020 tiwai@suse.de
- mtd: sharpslpart: Fix unsigned comparison to zero (git-fixes).
- mtd: onenand_base: Adjust indentation in onenand_read_ops_nolock
  (git-fixes).
- net: phy: dp83867: Set FORCE_LINK_GOOD to default after reset
  (git-fixes).
- commit 9763e59
* Fri Feb  7 2020 tiwai@suse.de
- mfd: rn5t618: Mark ADC control register volatile (git-fixes).
- mfd: da9062: Fix watchdog compatible string (git-fixes).
- mfd: max77650: Select REGMAP_IRQ in Kconfig (git-fixes).
- mfd: axp20x: Mark AXP20X_VBUS_IPSOUT_MGMT as volatile
  (git-fixes).
- mfd: bd70528: Fix hour register mask (git-fixes).
- leds: pca963x: Fix open-drain initialization (git-fixes).
- lib/scatterlist.c: adjust indentation in __sg_alloc_table
  (git-fixes).
- ide: remove set but not used variable 'hwif' (git-fixes).
- ima: ima/lsm policy rule loading logic bug fixes (git-fixes).
- hwmon: (pmbus/ibm-cffps) Fix LED blink behavior (git-fixes).
- commit e4dc7c5
* Fri Feb  7 2020 tiwai@suse.de
- fbdev: fix numbering of fbcon options (git-fixes).
- habanalabs: remove variable 'val' set but not used (git-fixes).
- habanalabs: rate limit error msg on waiting for CS (git-fixes).
- habanalabs: skip VA block list update in reset flow (git-fixes).
- commit afb5fba
* Fri Feb  7 2020 tiwai@suse.de
- clk: qcom: Add missing msm8998 gcc_bimc_gfx_clk (git-fixes).
- clk: qcom: smd: Add missing bimc clock (git-fixes).
- clk: ti: dra7: fix parent for gmac_clkctrl (git-fixes).
- clk: sunxi-ng: add mux and pll notifiers for A64 CPU clock
  (git-fixes).
- clk: meson: meson8b: make the CCF use the glitch-free mali mux
  (git-fixes).
- clk: meson: pll: Fix by 0 division in __pll_params_to_rate()
  (git-fixes).
- clk: meson: g12a: fix missing uart2 in regmap table (git-fixes).
- clk: renesas: rcar-gen3: Allow changing the RPC[D2] clocks
  (git-fixes).
- clk: imx: imx8mq: fix sys3_pll_out_sels (git-fixes).
- commit edbbc8e
* Fri Feb  7 2020 tiwai@suse.de
- Bluetooth: hci_bcm: Drive RTS only for BCM43438 (git-fixes).
- Bluetooth: hci_bcm: Add device-tree compatible for BCM4329
  (git-fixes).
- Bluetooth: hci_bcm: Disallow set_baudrate for BCM4354
  (git-fixes).
- Bluetooth: btbcm: Add entry for BCM4335A0 UART bluetooth
  (git-fixes).
- Bluetooth: hci_bcm: Add compatible string for BCM43540
  (git-fixes).
- commit f42c6a9
* Fri Feb  7 2020 dwagner@suse.de
- cpumask: Implement cpumask_or_equal() (bsc#1162702).
- commit a130302
* Fri Feb  7 2020 jeyu@suse.de
- Refresh and re-enable
  patches.suse/0005-modsign-print-module-name-along-with-error-message.patch.
- commit e9c76fb
* Fri Feb  7 2020 tiwai@suse.de
- clk: at91: sam9x60: fix programmable clock prescaler
  (git-fixes).
- clk: uniphier: Add SCSSI clock gate for each channel
  (git-fixes).
- clk: actually call the clock init before any other callback
  of the clock (git-fixes).
- media: vp7045: do not read uninitialized values if usb transfer
  fails (git-fixes).
- media: af9005: uninitialized variable printked (git-fixes).
- media: digitv: don't continue if remote control state can't
  be read (git-fixes).
- media: dvb-usb/dvb-usb-urb.c: initialize actlen to 0
  (git-fixes).
- media: gspca: zero usb_buf (git-fixes).
- Bluetooth: Fix race condition in hci_release_sock() (git-fixes).
- r8152: disable DelayPhyPwrChg (git-fixes).
- r8152: avoid the MCU to clear the lanwake (git-fixes).
- r8152: disable test IO for RTL8153B (git-fixes).
- r8152: get default setting of WOL before initializing
  (git-fixes).
- Input: max77650-onkey - add of_match table (git-fixes).
- Input: evdev - convert kzalloc()/vzalloc() to kvzalloc()
  (git-fixes).
- led: max77650: add of_match table (git-fixes).
- wireless: wext: avoid gcc -O3 warning (git-fixes).
- mac80211: Fix TKIP replay protection immediately after key setup
  (git-fixes).
- cfg80211: Fix radar event during another phy CAC (git-fixes).
- wireless: fix enabling channel 12 for custom regulatory domain
  (git-fixes).
- mac80211: mesh: restrict airtime metric to peered established
  plinks (git-fixes).
- clk: mmp2: Fix the order of timer mux parents (git-fixes).
- clk: sunxi-ng: h6-r: Fix AR100/R_APB2 parent order (git-fixes).
- clk: sunxi-ng: sun8i-r: Fix divider on APB0 clock (git-fixes).
- platform/x86: intel_pmc_core: update Comet Lake platform driver
  (git-fixes).
- platform/x86: GPD pocket fan: Allow somewhat lower/higher
  temperature limits (git-fixes).
- commit eff0f28
* Thu Feb  6 2020 tiwai@suse.de
- ALSA: hda: Clear RIRB status before reading WP (git-fixes).
- ALSA: hda/realtek - Fixed one of HP ALC671 platform Headset
  Mic supported (git-fixes).
- ASoC: SOF: trace: fix unconditional free in trace release
  (git-fixes).
- ALSA: hda - Fix DP-MST support for NVIDIA codecs (git-fixes).
- ALSA: dummy: Fix PCM format loop in proc output (git-fixes).
- ALSA: usb-audio: Annotate endianess in Scarlett gen2 quirk
  (git-fixes).
- ALSA: usb-audio: Fix endianess in descriptor validation
  (git-fixes).
- ALSA: hda: Add JasperLake PCI ID and codec vid (git-fixes).
- ALSA: pcm: Fix memory leak at closing a stream without hw_free
  (git-fixes).
- ALSA: hda: Reset stream if DMA RUN bit not cleared (git-fixes).
- ASoC: Intel: Skylake: Explicitly include linux/io.h for
  virt_to_phys() (git-fixes).
- commit 90e1eab
* Thu Feb  6 2020 chrubis@suse.cz
- rpm/kernel-binary.spec.in: Replace Novell with SUSE
- commit 8719d69
* Thu Feb  6 2020 ykaukab@suse.de
- kabi: arm64: reserve space in cpu_hwcaps and cpu_hwcap_keys
  arrays (bsc#1089086).
  Enable and refresh cpu_hwcaps kabi reservation patch.
- commit a2cfe97
* Thu Feb  6 2020 nborisov@suse.com
- btrfs: don't double lock the subvol_sem for rename exchange (bsc#1162943).
- commit 6492de6
* Thu Feb  6 2020 oneukum@suse.com
- blacklist.conf: different IDs in stable and mainline
- commit a8a637a
* Thu Feb  6 2020 wqu@suse.com
- Update
  patches.suse/btrfs-qgroups-fix-rescan-worker-running-races.patch
  (bsc#1091101, bsc#1156919).
  Since the problem is still here and not solved, re-enable it and rebase
  the code.
- commit 5647b0a
* Wed Feb  5 2020 tiwai@suse.de
- pwm: Remove set but not set variable 'pwm' (git-fixes).
- pwm: omap-dmtimer: put_device() after of_find_device_by_node()
  (git-fixes).
- pwm: omap-dmtimer: Simplify error handling (git-fixes).
- pwm: omap-dmtimer: Remove PWM chip in .remove before making
  it unfunctional (git-fixes).
- commit f1507d7
* Wed Feb  5 2020 msuchanek@suse.de
- Refresh patches.suse/powerpc-drmem-avoid-NULL-pointer-dereference-when-dr.patch.
- commit 3c1c79f
* Wed Feb  5 2020 tiwai@suse.de
- PCI: Add DMA alias quirk for Intel VCA NTB (git-fixes).
- Refresh
  patches.suse/0001-PCI-Vulcan-AHCI-PCI-bar-fix-for-Broadcom-Vulcan-earl.patch.
- commit 55d6c4b
* Wed Feb  5 2020 tiwai@suse.de
- mei: me: add comet point (lake) H device ids (git-fixes).
- mei: hdcp: bind only with i915 on the same PCH (git-fixes).
- staging: most: net: fix buffer overflow (git-fixes).
- staging: vt6656: Fix false Tx excessive retries reporting
  (git-fixes).
- staging: vt6656: use NULLFUCTION stack on mac80211 (git-fixes).
- staging: vt6656: correct packet types for CTS protect, mode
  (git-fixes).
- serial: imx: fix a race condition in receive path (git-fixes).
- usb: dwc3: pci: add ID for the Intel Comet Lake -V variant
  (git-fixes).
- ARM: 8955/1: virt: Relax arch timer version check during early
  boot (git-fixes).
- phy: cpcap-usb: Prevent USB line glitches from waking up modem
  (git-fixes).
- phy: qcom-qmp: Increase PHY ready timeout (git-fixes).
- usb: musb: jz4740: Silence error if code is -EPROBE_DEFER
  (git-fixes).
- drm/amd/display: Reduce HDMI pixel encoding if max clock is
  exceeded (git-fixes).
- gpio: max77620: Add missing dependency on GPIOLIB_IRQCHIP
  (git-fixes).
- HID: steam: Fix input device disappearing (git-fixes).
- HID: intel-ish-hid: ipc: Add Tiger Lake PCI device ID
  (git-fixes).
- drivers/hid/hid-multitouch.c: fix a possible null pointer access
  (git-fixes).
- HID: wacom: Recognize new MobileStudio Pro PID (git-fixes).
- HID: intel-ish-hid: ipc: add CMP device id (git-fixes).
- HID: Add quirk for incorrect input length on Lenovo Y720
  (git-fixes).
- HID: asus: Ignore Asus vendor-page usage-code 0xff events
  (git-fixes).
- HID: ite: Add USB id match for Acer SW5-012 keyboard dock
  (git-fixes).
- HID: Add quirk for Xin-Mo Dual Controller (git-fixes).
- HID: multitouch: Add LG MELF0410 I2C touchscreen support
  (git-fixes).
- watchdog: rn5t618_wdt: fix module aliases (git-fixes).
- watchdog: max77620_wdt: fix potential build errors (git-fixes).
- spi: spi-dw: Add lock protect dw_spi rx/tx to prevent concurrent
  calls (git-fixes).
- platform/x86: dell-laptop: disable kbd backlight on Inspiron
  10xx (git-fixes).
- staging: mt7621-pci: add quirks for 'E2' revision using
  'soc_device_attribute' (git-fixes).
- extcon-intel-cht-wc: Don't reset USB data connection at probe
  (git-fixes).
- usb-storage: Disable UAS on JMicron SATA enclosure (git-fixes).
- mmc: sdhci-pci: Add support for Intel JSL (git-fixes).
- mmc: sdhci-pci: Quirk for AMD SDHC Device 0x7906 (git-fixes).
- ASoC: Intel: cht_bsw_rt5645: Add quirk for boards using
  pmc_plt_clk_0 (git-fixes).
- ARM: OMAP2+: SmartReflex: add omap_sr_pdata definition
  (git-fixes).
- Bluetooth: btbcm: Use the BDADDR_PROPERTY quirk (git-fixes).
- Bluetooth: Allow combination of BDADDR_PROPERTY and
  INVALID_BDADDR quirks (git-fixes).
- HID: wacom: add new MobileStudio Pro 13 support (git-fixes).
- commit 2f59d11
* Wed Feb  5 2020 lhenriques@suse.com
- ceph: fix compat_ioctl for ceph_dir_operations (jsc#SES-1134).
- compat_ioctl: add compat_ptr_ioctl() (jsc#SES-1134).
- commit e540507
* Wed Feb  5 2020 oneukum@suse.com
- crypto: sun4i-ss - fix big endian issues (git-fixes).
- commit 0bfb337
* Wed Feb  5 2020 oneukum@suse.com
- blacklist.conf: not needed in our config
- commit a23b2d7
* Wed Feb  5 2020 oneukum@suse.com
- blacklist.conf: upstream has a wrong Fixes
- commit 3b66050
* Wed Feb  5 2020 oneukum@suse.com
- perf/imx_ddr: Add MODULE_DEVICE_TABLE (git-fixes).
- commit f0f1d6b
* Wed Feb  5 2020 dwagner@suse.de
- bitmap.h: fix kernel-doc warning and typo (bsc#1162702).
- commit be235a4
* Wed Feb  5 2020 oneukum@suse.com
- blacklist.conf: duplication
- commit 0224176
* Wed Feb  5 2020 oneukum@suse.com
- iwlwifi: fw: make pos static in iwl_sar_get_ewrd_table() loop
  (git-fixes).
- commit fa51eb6
* Wed Feb  5 2020 oneukum@suse.com
- iwlwifi: mvm: don't send the IWL_MVM_RXQ_NSSN_SYNC notif to
  Rx queues (git-fixes).
- commit 861212e
* Wed Feb  5 2020 jroedel@suse.de
- iommu/vt-d: Refactor find_domain() helper (bsc#1159594).
- commit e9b12d5
* Wed Feb  5 2020 oneukum@suse.com
- blacklist.conf: only cosmetics
- commit 1870278
* Wed Feb  5 2020 oneukum@suse.com
- blacklist.conf: patch is wrong, later reverted
- commit ed8aa8a
* Wed Feb  5 2020 bp@suse.de
- x86/resctrl: Fix a deadlock due to inaccurate reference
  (bsc#1152489).
- x86/resctrl: Fix use-after-free due to inaccurate refcount of
  rdtgroup (bsc#1152489).
- x86/resctrl: Fix use-after-free when deleting resource groups
  (bsc#1152489).
- commit 1107939
* Wed Feb  5 2020 ykaukab@suse.de
- coresight: etm4x: Fix unused function warning (jsc#SLE-9326).
- coresight: replicator: Fix missing spin_lock_init()
  (jsc#SLE-9326).
- coresight: funnel: Fix missing spin_lock_init() (jsc#SLE-9326).
- coresight: etm4x: Fix BMVAL misuse (jsc#SLE-9326).
- coresight: Add explicit architecture dependency (jsc#SLE-9326).
- coresight: etm4x: Add missing single-shot control API to sysfs
  (jsc#SLE-9326).
- coresight: etm4x: Add view comparator settings API to sysfs
  (jsc#SLE-9326).
- coresight: etm4x: Improve usability of sysfs - CID and VMID
  masks (jsc#SLE-9326).
- coresight: etm4x: Improve usability of sysfs - include/exclude
  addr (jsc#SLE-9326).
- coresight: etm4x: Fix issues with start-stop logic
  (jsc#SLE-9326).
- coresight: etm4x: Add missing API to set EL match on address
  filters (jsc#SLE-9326).
- coresight: etm4x: Fixes for ETM v4.4 architecture updates
  (jsc#SLE-9326).
- coresight: etm4x: Add support for ThunderX2 (jsc#SLE-9326).
- coresight: etm4x: Save/restore state across CPU low power states
  (jsc#SLE-9326).
- coresight: tmc-etr: Add barrier packets when moving offset
  forward (jsc#SLE-9326).
- coresight: tmc-etr: Decouple buffer sync and barrier packet
  insertion (jsc#SLE-9326).
- coresight: tmc: Make memory width mask computation into a
  function (jsc#SLE-9326).
- coresight: tmc-etr: Fix updating buffer in not-snapshot mode
  (jsc#SLE-9326).
- coresight: etm4x: improve clarity of etm4_os_unlock comment
  (jsc#SLE-9326).
- coresight: etm4x: use module_param instead of module_param_named
  (jsc#SLE-9326).
- coresight: etm4x: Remove superfluous setting of os_unlock
  (jsc#SLE-9326).
- coresight: acpi: Static funnel support (jsc#SLE-9326).
- coresight: Convert pr_warn to dev_warn for obsolete bindings
  (jsc#SLE-9326).
- coresight: tmc-etr: Check if non-secure access is enabled
  (jsc#SLE-9326).
- coresight: tmc-etr: Handle memory errors (jsc#SLE-9326).
- coresight: etr_buf: Consolidate refcount initialization
  (jsc#SLE-9326).
- coresight: cpu-debug: Add support for Qualcomm Kryo
  (jsc#SLE-9326).
- coresight: etm4x: Add ETM PIDs for SDM845 and MSM8996
  (jsc#SLE-9326).
- coresight: etm4x: Two function calls less (jsc#SLE-9326).
- commit 42abd9d
* Wed Feb  5 2020 mkubecek@suse.cz
- config: refresh
- drop no longer available option
- commit df9bfb1
* Wed Feb  5 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/mm-mmu_gather-invalidate-TLB-correctly-on-batch-allo.patch
- commit 11779f3
* Wed Feb  5 2020 mkubecek@suse.cz
- update patch metadata
- update Git-commit (maintainer repository rebased?):
  patches.suse/scsi-qla2xxx-Fix-unbound-NVME-response-length.patch
- commit 6a6f7db
* Wed Feb  5 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/powerpc-mm-Remove-kvm-radix-prefetch-workaround-for-.patch
  patches.suse/powerpc-papr_scm-Don-t-enable-direct-map-for-a-regio.patch
  patches.suse/powerpc-pseries-lparcfg-Fix-display-of-Maximum-Memor.patch
  patches.suse/powerpc-xmon-don-t-access-ASDR-in-VMs.patch
- commit b278cb1
* Wed Feb  5 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/vfs-fix-do_last-regression.patch
- commit d2a495c
* Wed Feb  5 2020 glin@suse.com
- libbpf: Add missing newline in opts validation macro
  (bsc#1155518).
- libbpf: Fix printf compilation warnings on ppc64le arch
  (bsc#1155518).
- commit 413fb24
* Tue Feb  4 2020 msuchanek@suse.de
- powerpc: Do not consider weak unresolved symbol relocations
  as bad (bsc#1148868).
- powerpc: Provide initial documentation for PAPR hcalls
  (bsc#1156395).
- gen_initramfs_list.sh: fix 'bad variable name' error
  (bsc#1148868).
- mkcompile_h: use printf for LINUX_COMPILE_BY (bsc#1148868).
- mkcompile_h: git rid of UTS_TRUNCATE from
  LINUX_COMPILE_{BY,HOST} (bsc#1148868).
- scripts/setlocalversion: clear local variable to make it work
  for sh (bsc#1148868).
- kbuild: add $(BASH) to run scripts with bash-extension
  (bsc#1148868).
- commit 200c822
* Tue Feb  4 2020 dwagner@suse.de
- jbd2: Free journal head outside of locked region (bsc#1162702).
- jbd2: Make state lock a spinlock (bsc#1162702).
- jbd2: Don't call __bforget() unnecessarily (bsc#1162702).
- jbd2: Drop unnecessary branch from jbd2_journal_forget()
  (bsc#1162702).
- jbd2: Move dropping of jh reference out of un/re-filing
  functions (bsc#1162702).
- jbd2: Remove jbd_trylock_bh_state() (bsc#1162702).
- jbd2: Simplify journal_unmap_buffer() (bsc#1162702).
- commit 64d9c8c
* Tue Feb  4 2020 jroedel@suse.de
- KVM: SVM: Override default MMIO mask if memory encryption is
  enabled (bsc#1162684).
- commit 6f8451a
* Tue Feb  4 2020 bp@suse.de
- x86/fpu: Deactivate FPU state after failure during state load
  (bsc#1152489).
- commit fb7702a
* Tue Feb  4 2020 bp@suse.de
- x86/resctrl: Check monitoring static key in the MBM overflow
  handler (bsc#1152489).
- commit 8f4ba2c
* Tue Feb  4 2020 tiwai@suse.de
- Delete patches.suse/tomoyo-Don-t-use-nifty-names-on-sockets.patch (bsc#1162590)
  We've hit mysterious regression and the git bisection points this one.
  As this is no serious fix backport, let's try to revert it at first.
- commit 0ecd623
* Tue Feb  4 2020 ghe@suse.com
- ocfs2: fix oops when writing cloned file (bsc#1160831).
- commit dd0a42c
* Tue Feb  4 2020 nsaenzjulienne@suse.de
- dma-contiguous: CMA: give precedence to cmdline (bsc#1160609).
- commit d7a3b9d
* Tue Feb  4 2020 msuchanek@suse.de
- mm/mmu_gather: invalidate TLB correctly on batch allocation
  failure and flush (bsc#1055186).
- commit c9dade1
* Tue Feb  4 2020 duwe@suse.de
- rpm/modules.fips: add keywrap (bsc#1160561)
- commit 68cc4b8
* Tue Feb  4 2020 lhenriques@suse.com
- ceph: hold extra reference to r_parent over life of request
  (jsc#SES-1134).
- ceph: add more debug info when decoding mdsmap (jsc#SES-1134).
- ceph: switch to global cap helper (jsc#SES-1134).
- ceph: trigger the reclaim work once there has enough pending
  caps (jsc#SES-1134).
- ceph: show tasks waiting on caps in debugfs caps file
  (jsc#SES-1134).
- ceph: convert int fields in ceph_mount_options to unsigned int
  (jsc#SES-1134).
- commit 5bcfbba
* Tue Feb  4 2020 bp@suse.de
- blacklist.conf: 6cd18453b689 EDAC/sifive: Fix return value check in ecc_register()
- commit 267e9ae
* Tue Feb  4 2020 lhenriques@suse.com
- libceph, rbd, ceph: convert to use the new mount API
  (jsc#SES-1134).
- Refresh
  patches.suse/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- commit dd179b3
* Tue Feb  4 2020 lhenriques@suse.com
- rbd: ask for a weaker incompat mask for read-only mappings
  (jsc#SES-1134).
- commit 1660de5
* Tue Feb  4 2020 lhenriques@suse.com
- rbd: don't query snapshot features (jsc#SES-1134).
- Refresh
  patches.suse/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- commit 578ddcb
* Tue Feb  4 2020 lhenriques@suse.com
- rbd: remove snapshot existence validation code (jsc#SES-1134).
- Refresh
  patches.suse/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- commit 15f7151
* Tue Feb  4 2020 lhenriques@suse.com
- rbd: don't establish watch for read-only mappings
  (jsc#SES-1134).
- rbd: don't acquire exclusive lock for read-only mappings
  (jsc#SES-1134).
- rbd: disallow read-write partitions on images mapped read-only
  (jsc#SES-1134).
- rbd: treat images mapped read-only seriously (jsc#SES-1134).
- commit 3b44169
* Tue Feb  4 2020 lhenriques@suse.com
- rbd: introduce RBD_DEV_FLAG_READONLY (jsc#SES-1134).
- Refresh
  patches.suse/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- commit 8848484
* Tue Feb  4 2020 lhenriques@suse.com
- rbd: introduce rbd_is_snap() (jsc#SES-1134).
- ceph: don't leave ino field in ceph_mds_request_head
  uninitialized (jsc#SES-1134).
- ceph: tone down loglevel on ceph_mdsc_build_path warning
  (jsc#SES-1134).
- ceph: fix geting random mds from mdsmap (jsc#SES-1134).
- rbd: fix spelling mistake "requeueing" -> "requeuing"
  (jsc#SES-1134).
- ceph: make several helper accessors take const pointers
  (jsc#SES-1134).
- libceph: drop unnecessary check from dispatch() in mon_client.c
  (jsc#SES-1134).
- commit ea0e3ab
* Tue Feb  4 2020 ggherdovich@suse.cz
- x86/intel_pstate: Handle runtime turbo disablement/enablement
  in frequency invariance (bsc#1155798).
- commit d2ecce1
* Tue Feb  4 2020 ggherdovich@suse.cz
- x86, sched: Add support for frequency invariance on ATOM
  (bsc#1155798).
- commit 5a622ef
* Tue Feb  4 2020 lpechacek@suse.cz
- net: aquantia: add an error handling in
  aq_nic_set_multicast_list (jsc#SLE-10218).
- commit d467792
* Tue Feb  4 2020 ggherdovich@suse.cz
- x86, sched: Add support for frequency invariance on
  ATOM_GOLDMONT* (bsc#1155798).
- commit 6550e7c
* Tue Feb  4 2020 ggherdovich@suse.cz
- x86, sched: Add support for frequency invariance on
  XEON_PHI_KNL/KNM (bsc#1155798).
- commit 708e8cb
* Tue Feb  4 2020 ggherdovich@suse.cz
- x86, sched: Add support for frequency invariance on SKYLAKE_X
  (bsc#1155798).
- commit 0ae5deb
* Tue Feb  4 2020 ggherdovich@suse.cz
- x86, sched: Add support for frequency invariance (bsc#1155798).
- commit 54365d2
* Mon Feb  3 2020 dwagner@suse.de
- scsi: qla2xxx: Fix unbound NVME response length (bsc#1157966
  bsc#1158013 bsc#1157424).
- scsi: tcm_qla2xxx: Make qlt_alloc_qfull_cmd() set
  cmd->se_cmd.map_tag (bsc#1157966 bsc#1158013 bsc#1157424).
- scsi: qla2xxx: Fix a NULL pointer dereference in an error path
  (bsc#1157966 bsc#1158013 bsc#1157424).
- commit 586fcc6
* Mon Feb  3 2020 rgoldwyn@suse.com
- vfs: fix do_last() regression  (bsc#1162109,CVE-2020-8428).
- Update
  patches.suse/do_last-fetch-directory--i_mode-and--i_uid-before-its-too-late.patch
  (bsc#1162109,CVE-2020-8428).
- commit 7adeb03
* Mon Feb  3 2020 msuchanek@suse.de
- KVM: PPC: Book3S PR: Fix -Werror=return-type build failure
  (bsc#1061840).
- KVM: PPC: Book3S PR: Free shared page if mmu initialization
  fails (bsc#1061840).
- KVM: PPC: Book3S HV: Uninit vCPU if vcore creation fails
  (bsc#1061840).
- commit 45012b1
* Mon Feb  3 2020 tzimmermann@suse.de
- Update "drm/amdkfd: fix a potential NULL pointer dereference (v2)"
  We have a bug report and a CVE for this patch. Point references tag there.
- commit db7a4f2
* Mon Feb  3 2020 mbenes@suse.cz
- tracing/kprobes: Have uname use __get_str() in print_fmt
  (git-fixes).
- commit 1cc7e66
* Mon Feb  3 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/0001-x86-kvm-Be-careful-not-to-clear-KVM_VCPU_FLUSH_TLB-b.patch
  patches.suse/0002-x86-kvm-Introduce-kvm_-un-map_gfn.patch
  patches.suse/0003-x86-kvm-Cache-gfn-to-pfn-translation.patch
  patches.suse/0004-x86-KVM-Make-sure-KVM_VCPU_FLUSH_TLB-flag-is-not-mis.patch
  patches.suse/0005-x86-KVM-Clean-up-host-s-steal-time-structure.patch
- commit 488b94c
* Mon Feb  3 2020 mkubecek@suse.cz
- patch whitespace cleanup
- delete whitespace on line separating rfc2822 header and body:
  patches.suse/ocfs2-make-local-header-paths-relative-to-C-files.patch
- commit bbd1cb9
* Sun Feb  2 2020 ghe@suse.com
- ocfs2: make local header paths relative to C files
  (bsc#1159889).
- commit fafd040
* Sat Feb  1 2020 tiwai@suse.de
- PCI: tegra: Fix afi_pex2_ctrl reg offset for Tegra30
  (git-fixes).
- PCI: tegra: Fix return value check of pm_runtime_get_sync()
  (git-fixes).
- PCI: keystone: Fix error handling when "num-viewport" DT
  property is not populated (git-fixes).
- PCI: keystone: Fix outbound region mapping (git-fixes).
- PCI: keystone: Fix link training retries initiation (git-fixes).
- PCI/IOV: Fix memory leak in pci_iov_add_virtfn() (git-fixes).
- PCI/switchtec: Fix vep_vector_number ioread width (git-fixes).
- PCI/switchtec: Use dma_set_mask_and_coherent() (git-fixes).
- PCI: Don't disable bridge BARs when assigning bus resources
  (git-fixes).
- PCI/AER: Initialize aer_fifo (git-fixes).
- media: uvcvideo: Avoid cyclic entity chains due to malformed
  USB descriptors (git-fixes).
- media: iguanair: fix endpoint sanity check (git-fixes).
- media: v4l2-rect.h: fix v4l2_rect_map_inside() top/left
  adjustments (git-fixes).
- media: ov5640: Fix check for PLL1 exceeding max allowed rate
  (git-fixes).
- media: imx7-mipi-csis: remove subdev_notifier (git-fixes).
- media: meson: add missing allocation failure check on new_buf
  (git-fixes).
- media: i2c: adv748x: Fix unsafe macros (git-fixes).
- commit 0778c54
* Fri Jan 31 2020 mbrugger@suse.com
- EDAC/mc: Fix use-after-free and memleaks during device removal
  (jsc#SLE-9482).
- Refresh
  patches.suse/EDAC-mc-Reorder-functions-edac_mc_alloc.patch.
- commit 7999d28
* Fri Jan 31 2020 duwe@suse.de
- Refresh and reenable patches.suse/prepare-arm64-kgraft.
- Delete patches.suse/pstore-backend-autoaction.
  (see commit 62c0377bb94742def)
- commit 2e37144
* Fri Jan 31 2020 hare@suse.de
- s390/dasd: disable ese support due to possible data corruption
  (bsc#1161428).
- commit daa742e
* Fri Jan 31 2020 jroedel@suse.de
- iommu/amd: Fix IOMMU perf counter clobbering during init
  (bsc#1162393).
- iommu/vt-d: Call __dmar_remove_one_dev_info with valid pointer
  (bsc#1159594).
- commit 3146a75
* Fri Jan 31 2020 tiwai@suse.de
- airo: Add missing CAP_NET_ADMIN check in
  AIROOLDIOCTL/SIOCDEVPRIVATE (git-fixes).
- airo: Fix possible info leak in AIROOLDIOCTL/SIOCDEVPRIVATE
  (git-fixes).
- commit 21afd27
* Fri Jan 31 2020 tiwai@suse.de
- crypto: vmx - Avoid weird build failures (git-fixes).
- commit 5668910
* Fri Jan 31 2020 tiwai@suse.de
- drm/vmwgfx: prevent memory leak in vmw_cmdbuf_res_add
  (git-fixes).
- drm: msm: mdp4: Adjust indentation in mdp4_dsi_encoder_enable
  (git-fixes).
- drm/msm/adreno: fix zap vs no-zap handling (git-fixes).
- drm/nouveau: Fix copy-paste error in
  nouveau_fence_wait_uevent_handler (git-fixes).
- drm/nouveau/secboot/gm20b: initialize pointer in
  gm20b_secboot_new() (git-fixes).
- drm/mediatek: Add gamma property according to hardware
  capability (git-fixes).
- drm: atmel-hlcdc: prefer a lower pixel-clock than requested
  (git-fixes).
- drm: atmel-hlcdc: enable clock before configuring timing engine
  (git-fixes).
- drm: atmel-hlcdc: use double rate for pixel clock only if
  supported (git-fixes).
- drm: bridge: dw-hdmi: constify copied structure (git-fixes).
- drm/rockchip: lvds: Fix indentation of a #define (git-fixes).
- drm/amdkfd: remove set but not used variable 'top_dev'
  (git-fixes).
- drm/amd/powerplay: remove set but not used variable 'us_mvdd'
  (git-fixes).
- drm/amdgpu: remove set but not used variable 'invalid'
  (git-fixes).
- drm/amdgpu: remove set but not used variable 'count'
  (git-fixes).
- drm/amdgpu: remove set but not used variable 'amdgpu_connector'
  (git-fixes).
- drm/amdgpu: remove set but not used variable 'mc_shared_chmap'
  from 'gfx_v6_0.c' and 'gfx_v7_0.c' (git-fixes).
- drm/amdgpu: remove set but not used variable 'mc_shared_chmap'
  (git-fixes).
- drm/amdgpu: remove always false comparison in
  'amdgpu_atombios_i2c_process_i2c_ch' (git-fixes).
- drm/amdgpu: remove set but not used variable 'dig' (git-fixes).
- drm/amdgpu: remove set but not used variable 'dig_connector'
  (git-fixes).
- drm/amdgpu: add function parameter description in
  'amdgpu_gart_bind' (git-fixes).
- drm/amdgpu: add function parameter description in
  'amdgpu_device_set_cg_state' (git-fixes).
- drm/amdgpu: remove 4 set but not used variable in
  amdgpu_atombios_get_connector_info_from_object_table
  (git-fixes).
- drm/panel: simple: Add Logic PD Type 28 display support
  (git-fixes).
- drm/qxl: Complete exception handling in qxl_device_init()
  (git-fixes).
- drm/rect: update kerneldoc for drm_rect_clip_scaled()
  (git-fixes).
- drm/rect: Avoid division by zero (git-fixes).
- drm/fourcc: Fill out all block sizes for P210 (git-fixes).
- drm/fourcc: Fill out all block sizes for P10/12/16 (git-fixes).
- drm/ttm: ttm_tt_init_fields() can be static (git-fixes).
- commit 93987eb
* Fri Jan 31 2020 tiwai@suse.de
- PM: hibernate: fix crashes with init_on_free=1 (git-fixes).
- commit 748603f
* Fri Jan 31 2020 tiwai@suse.de
- Add the already cherry-picked id to pinctrl fix patch
- commit fdc0f64
* Fri Jan 31 2020 jroedel@suse.de
- x86/KVM: Clean up host's steal time structure (bsc#1161154,
  CVE-2019-3016).
- x86/KVM: Make sure KVM_VCPU_FLUSH_TLB flag is not missed
  (bsc#1161154, CVE-2019-3016).
- x86/kvm: Cache gfn to pfn translation (bsc#1161154,
  CVE-2019-3016).
- x86/kvm: Introduce kvm_(un)map_gfn() (bsc#1161154,
  CVE-2019-3016).
- x86/kvm: Be careful not to clear KVM_VCPU_FLUSH_TLB bit
  (bsc#1161154, CVE-2019-3016).
- commit b5111ca
* Fri Jan 31 2020 mkubecek@suse.cz
- supported.conf: mark ufshcd_core and ufshcd_pltfrm as supported (bsc#1158776)
  kernel-source commit ba2a8909aec7 marked modules ufs_hisi, ufs_medatek and
  ufs_qcom as supported (with reference to comment 14 here); these depend on
  ufshcd_core and ufshcd_pltfrm which are unsupported so that IBS build
  (aarch64/default) now fails one of the late checks.
  Mark ufshcd_core and ufshcd_pltfrm as supported to avoid unfulfilled
  dependencies in arm64 kernel-default.
- commit e66a364
* Fri Jan 31 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/scsi-qla2xxx-Add-D-Port-Diagnostic-reason-explanatio.patch
  patches.suse/scsi-qla2xxx-Add-a-shadow-variable-to-hold-disc_stat.patch
  patches.suse/scsi-qla2xxx-Cleanup-unused-async_logout_done.patch
  patches.suse/scsi-qla2xxx-Consolidate-fabric-scan.patch
  patches.suse/scsi-qla2xxx-Correct-fcport-flags-handling.patch
  patches.suse/scsi-qla2xxx-Fix-RIDA-Format-2.patch
  patches.suse/scsi-qla2xxx-Fix-fabric-scan-hang.patch
  patches.suse/scsi-qla2xxx-Fix-mtcp-dump-collection-failure.patch
  patches.suse/scsi-qla2xxx-Fix-stuck-login-session-using-prli_pend.patch
  patches.suse/scsi-qla2xxx-Fix-stuck-session-in-GNL.patch
  patches.suse/scsi-qla2xxx-Fix-the-endianness-of-the-qla82xx_get_f.patch
  patches.suse/scsi-qla2xxx-Fix-update_fcport-for-current_topology.patch
  patches.suse/scsi-qla2xxx-Improve-readability-of-the-code-that-ha.patch
  patches.suse/scsi-qla2xxx-Remove-defer-flag-to-indicate-immeadiat.patch
  patches.suse/scsi-qla2xxx-Update-driver-version-to-10.01.00.22-k.patch
  patches.suse/scsi-qla2xxx-Use-common-routine-to-free-fcport-struc.patch
  patches.suse/scsi-qla2xxx-Use-get_unaligned_-instead-of-open-codi.patch
  No effect on expanded tree.
- commit 35cf494
* Thu Jan 30 2020 mbenes@suse.cz
- s390/ftrace: generate traced function stack frame
  (jsc#SLE-11050).
- commit 8abd203
* Thu Jan 30 2020 tiwai@suse.de
- scripts/find-unused-docs: Fix massive false positives
  (git-fixes).
- selftests: settings: tests can be in subsubdirs (git-fixes).
- visorbus: fix uninitialized variable access (git-fixes).
- debugfs: Return -EPERM when locked down (git-fixes).
- driver core: Fix test_async_driver_probe if NUMA is disabled
  (git-fixes).
- component: do not dereference opaque pointer in debugfs
  (git-fixes).
- iio: adc: stm32-dfsdm: fix single conversion (git-fixes).
- iio: st_gyro: Correct data for LSM9DS0 gyro (git-fixes).
- staging: wlan-ng: ensure error return is actually returned
  (git-fixes).
- serial: 8250_bcm2835aux: Fix line mismatch on driver unbind
  (git-fixes).
- USB: serial: ir-usb: fix IrLAP framing (git-fixes).
- USB: serial: ir-usb: fix link-speed handling (git-fixes).
- USB: serial: ir-usb: add missing endpoint sanity check
  (git-fixes).
- usb: typec: wcove: fix "op-sink-microwatt" default that was
  in mW (git-fixes).
- usb: typec: tcpci: mask event interrupts when remove driver
  (git-fixes).
- usb: host: xhci-tegra: set MODULE_FIRMWARE for tegra186
  (git-fixes).
- phy: qualcomm: Adjust indentation in read_poll_timeout
  (git-fixes).
- usb: gadget: f_ecm: Use atomic_t to track in-flight request
  (git-fixes).
- usb: gadget: f_ncm: Use atomic_t to track in-flight request
  (git-fixes).
- usb: dwc3: gadget: Delay starting transfer (git-fixes).
- usb: dwc3: gadget: Check END_TRANSFER completion (git-fixes).
- usb: dwc3: turn off VBUS when leaving host mode (git-fixes).
- usb: gadget: f_fs: set req->num_sgs as 0 for non-sg transfer
  (git-fixes).
- pinctrl: sh-pfc: r8a7778: Fix duplicate SDSELF_B and SD1_CLK_B
  (git-fixes).
- pinctrl: sh-pfc: r8a77965: Fix DU_DOTCLKIN3 drive/bias control
  (git-fixes).
- gpiolib: Set lockdep class for hierarchical irq domains
  (git-fixes).
- commit 28a738b
* Wed Jan 29 2020 rgoldwyn@suse.com
- do_last(): fetch directory ->i_mode and ->i_uid before it's
  too late  (bsc#1152109,CVE-2020-8428).
- commit 6a0a735
* Wed Jan 29 2020 bp@suse.de
- crypto: ccp - Verify access to device registers before
  initializing (bsc#1161073).
- crypto: ccp - Change a message to reflect status instead of
  failure (bsc#1161073).
- commit 9d00d4d
* Wed Jan 29 2020 tiwai@suse.de
- firestream: fix memory leaks (git-fixes).
- net: usb: lan78xx: Add .ndo_features_check (git-fixes).
- PCI: Mark AMD Navi14 GPU rev 0xc5 ATS as broken (git-fixes).
- hwmon: (adt7475) Make volt2reg return same reg as reg2volt input
  (git-fixes).
- media: v4l2-ioctl.c: zero reserved fields for S/TRY_FMT
  (git-fixes).
- commit 0f48df8
* Wed Jan 29 2020 mbrugger@suse.com
- EDAC/mc: Remove per layer counters (jsc#SLE-9482).
- EDAC/mc: Remove detail[] string and cleanup error string
  generation (jsc#SLE-9482).
- EDAC/mc: Pass the error descriptor to error reporting functions
  (jsc#SLE-9482).
- EDAC/mc: Remove enable_per_layer_report function arguments
  (jsc#SLE-9482).
- EDAC/mc: Report "unknown memory" on too many DIMM labels found
  (jsc#SLE-9482).
- EDAC/mc: Create new function edac_inc_csrow() (jsc#SLE-9482).
- EDAC/mc: Determine mci pointer from the error descriptor
  (jsc#SLE-9482).
- EDAC: Store error type in struct edac_raw_error_desc
  (jsc#SLE-9482).
- EDAC/mc: Reorder functions edac_mc_alloc*() (jsc#SLE-9482).
- EDAC/mc: Split edac_mc_alloc() into smaller functions
  (jsc#SLE-9482).
- commit d500698
* Wed Jan 29 2020 vbabka@suse.cz
- mm/hmm: hmm_range_fault() infinite loop (HMM Functionality,
  jsc#SLE-8176).
- commit f666122
* Wed Jan 29 2020 vbabka@suse.cz
- mm/hmm: hmm_range_fault() NULL pointer bug (HMM Functionality,
  jsc#SLE-8176).
- commit 27fd79f
* Wed Jan 29 2020 tiwai@suse.de
- Fix applying via rapidquilt again
  Refresh
  patches.suse/sched-topology-Assert-non-NUMA-topology-masks-don-t-partially-overlap.patch.
  A patch in a patch description is confusing.
- commit 82f83e9
* Wed Jan 29 2020 mkubecek@suse.cz
- update upstream references
- update Patch-mainline:
  patches.suse/sched-Use-fair-prio_changed-instead-of-ad-hoc-implementation.patch
  patches.suse/sched-core-Remove-unused-variable-from-set_user_nice.patch
  patches.suse/sched-fair-Define-sched_idle_cpu-only-for-SMP-configurations.patch
  patches.suse/sched-fair-Fix-sgc-min-max-_capacity-calculation-for-SD_OVERLAP.patch
  patches.suse/sched-topology-Assert-non-NUMA-topology-masks-don-t-partially-overlap.patch
  patches.suse/sched-wait-fix-___wait_var_event-exclusive.patch
  patches.suse/schied-fair-Skip-calculating-contrib-without-load.patch
- commit 1c0fc31
* Wed Jan 29 2020 ptesarik@suse.cz
- config: enable CONFIG_DRM_ETNAVIV on arm64 (jsc#SLE-9263).
- supported.conf: mark etnaviv as supported (jsc#SLE-9263).
- commit ff1abc4
* Wed Jan 29 2020 ptesarik@suse.cz
- supported.conf: Support lima and panfrost (jsc#SLE-8203).
- commit aa64aa2
* Wed Jan 29 2020 msuchanek@suse.de
- powerpc/mm: Remove kvm radix prefetch workaround for Power9
  DD2.2 (bsc#1061840).
- commit 8d2d7a2
* Wed Jan 29 2020 nsaenzjulienne@suse.de
- mmc: host: sdhci-pci: Add Genesys Logic GL975x support
  (bsc#1144168).
- Update config files
- mmc: sdhci: Export sdhci_abort_tuning function symbol
  (bsc#1144168).
- PCI: Add Genesys Logic, Inc. Vendor ID (bsc#1144168).
- mmc: sdhci: Add PLL Enable support to internal clock setup
  (bsc#1144168).
- commit 418d5df
* Wed Jan 29 2020 msuchanek@suse.de
- powerpc/xmon: don't access ASDR in VMs (bsc#1065729).
- commit cc778b6
* Wed Jan 29 2020 msuchanek@suse.de
- powerpc/papr_scm: Don't enable direct map for a region by
  default (bsc#1129551).
- commit 5d46d16
* Wed Jan 29 2020 tiwai@suse.de
- Add already cherry-picked id for mdio_bus fix
- commit e3cd812
* Wed Jan 29 2020 tiwai@suse.de
- opp: Free static OPPs on errors while adding them (git-fixes).
- ptp: free ptp device pin descriptors properly (git-fixes).
- clk: samsung: exynos5420: Keep top G3D clocks enabled
  (git-fixes).
- commit 003f497
* Wed Jan 29 2020 mgorman@suse.de
- sched/fair: Define sched_idle_cpu() only for SMP configurations
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit c8faafc
* Wed Jan 29 2020 mgorman@suse.de
- sched/topology: Assert non-NUMA topology masks don't (partially)
  overlap (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit ffd4102
* Wed Jan 29 2020 mgorman@suse.de
- sched/fair: Fix sgc->{min,max}_capacity calculation for
  SD_OVERLAP (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- commit d5c0168
* Wed Jan 29 2020 mgorman@suse.de
- sched/core: Remove unused variable from set_user_nice()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit d56a5d4
* Wed Jan 29 2020 mgorman@suse.de
- schied/fair: Skip calculating @contrib without load (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit e039f48
* Wed Jan 29 2020 mgorman@suse.de
- sched/wait: fix ___wait_var_event(exclusive) (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit a75fdb5
* Wed Jan 29 2020 mgorman@suse.de
- sched: Use fair:prio_changed() instead of ad-hoc implementation
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit d945568
* Wed Jan 29 2020 mkubecek@suse.cz
- supported.conf: cleanup
  Drop entries which no longer match any module built.
- commit c5f35cc
* Wed Jan 29 2020 tzimmermann@suse.de
- drm/mgag200: Flag all G200 SE A machines as broken wrt <startadd> (bsc#1152489)
- commit 9c74a8c
* Wed Jan 29 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/ASoC-fsl_sai-add-IRQF_SHARED.patch
  patches.suse/USB-Fix-Don-t-skip-endpoint-descriptors-with-maxpack.patch
  patches.suse/enetc-add-software-timestamping.patch
  patches.suse/enetc-remove-variable-tc_max_sized_frame-set-but-not.patch
  patches.suse/gpio-mpc8xxx-Add-platform-device-to-gpiochip-parent.patch
  patches.suse/libertas-Fix-two-buffer-overflows-at-parsing-bss-des.patch
  patches.suse/sched-Spare-resched-IPI-when-prio-changes-on-a-single-fair-task.patch
  patches.suse/sched-clock-Use-static_branch_likely-with-sched_clock_running.patch
  patches.suse/sched-fair-Improve-update_sd_pick_busiest-for-spare-capacity-case.patch
  patches.suse/sched-fair-Load-balance-aggressively-for-SCHED_IDLE-CPUs.patch
  patches.suse/sched-fair-Make-sched-idle-CPU-selection-consistent-throughout.patch
  patches.suse/sched-fair-Optimize-select_idle_cpu.patch
  patches.suse/sched-fair-Remove-redundant-call-to-cpufreq_update_util.patch
  patches.suse/sched-fair-calculate-delta-runnable-load-only-when-it-s-needed.patch
  No effect on expanded tree.
- commit 06db07c
* Wed Jan 29 2020 tzimmermann@suse.de
- drm/mgag200: Add workaround for HW that does not support 'startadd' (bsc#1152489)
- commit 8ad9863
* Wed Jan 29 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references (mainline now) and resort:
  patches.suse/hwrng-iproc-rng200-add-support-for-bcm2711.patch
  patches.suse/ice-Add-device-ids-for-E822-devices.patch
  patches.suse/igc-Add-64-bit-DMA-access-support.patch
  patches.suse/igc-Add-PHY-power-management-control.patch
  patches.suse/igc-Add-SKU-for-i225-device.patch
  patches.suse/igc-Add-basic-skeleton-for-PTP.patch
  patches.suse/igc-Add-legacy-power-management-support.patch
  patches.suse/igc-Add-scatter-gather-support.patch
  patches.suse/igc-Add-support-for-RX-timestamping.patch
  patches.suse/igc-Add-support-for-TSO.patch
  patches.suse/igc-Add-support-for-TX-timestamping.patch
  patches.suse/igc-Add-support-for-ethtool-GET_TS_INFO-command.patch
  patches.suse/igc-Fix-parameter-descriptions-for-a-several-functio.patch
  patches.suse/igc-Fix-the-parameter-description-for-igc_alloc_rx_b.patch
  patches.suse/igc-Fix-typo-in-a-comment.patch
  patches.suse/igc-Improve-the-DMA-mapping-flow.patch
  patches.suse/igc-Prefer-to-use-the-pci_release_mem_regions-method.patch
  patches.suse/igc-Remove-excess-parameter-description-from-igc_is_.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_alloc_mapp.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_assign_vec.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_clean_tx_r.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_configure.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_configure_.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_free_q_vec-f7bcca5d.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_free_q_vec.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_irq_disabl.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_irq_enable.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_power_down.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_set_defaul.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_set_interr.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_set_rx_mod.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_sw_init.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_write_itr.patch
  patches.suse/igc-Remove-serdes-comments-from-a-description-of-met.patch
  patches.suse/igc-Remove-unused-definition.patch
  patches.suse/igc-Use-Start-of-Packet-signal-from-PHY-for-timestam.patch
- commit a2cb839
* Wed Jan 29 2020 tiwai@suse.de
- crypto: ccree - fix PM race condition (git-fixes).
- crypto: caam/qi2 - fix typo in algorithm's driver name
  (git-fixes).
- crypto: atmel-sha - fix error handling when setting hmac key
  (git-fixes).
- crypto: artpec6 - return correct error code for failed setkey()
  (git-fixes).
- crypto: chelsio - fix writing tfm flags to wrong place
  (git-fixes).
- crypto: api - fix unexpectedly getting generic implementation
  (git-fixes).
- crypto: picoxcell - adjust the position of tasklet_init and
  fix missed tasklet_kill (git-fixes).
- crypto: api - Fix race condition in crypto_spawn_alg
  (git-fixes).
- crypto: api - Check spawn->alg under lock in crypto_drop_spawn
  (git-fixes).
- crypto: af_alg - Use bh_lock_sock in sk_destruct (git-fixes).
- crypto: testmgr - don't try to decrypt uninitialized buffers
  (git-fixes).
- crypto: pcrypt - Do not clear MAY_SLEEP flag in original request
  (git-fixes).
- crypto: arm64/ghash-neon - bump priority to 150 (git-fixes).
- crypto: ccp - set max RSA modulus size for v3 platform devices
  as well (git-fixes).
- commit 57ecf54
* Wed Jan 29 2020 tiwai@suse.de
- ASoC: topology: fix soc_tplg_fe_link_create() - link->dobj
  initialization order (git-fixes).
- ASoC: Intel: skl_hda_dsp_common: Fix global-out-of-bounds bug
  (git-fixes).
- ALSA: hda: Add Clevo W65_67SB the power_save blacklist
  (git-fixes).
- ALSA: hda - Add docking station support for Lenovo Thinkpad
  T420s (git-fixes).
- ALSA: hda/hdmi - add retry logic to parse_intel_hdmi()
  (git-fixes).
- ALSA: hda/realtek - Add Headset Mic supported for HP cPC
  (git-fixes).
- ALSA: hda/analog - Minor optimization for SPDIF mux connections
  (git-fixes).
- ALSA: hda: patch_hdmi: remove warnings with empty body
  (git-fixes).
- ALSA: hda: correct kernel-doc parameter descriptions
  (git-fixes).
- ALSA: hda: Manage concurrent reg access more properly
  (git-fixes).
- ALSA: hda: patch_realtek: fix empty macro usage in if block
  (git-fixes).
- ALSA: hda: Fix a typo in comments (git-fixes).
- ALSA: sh: Fix compile warning wrt const (git-fixes).
- ALSA: hda: More constifications (git-fixes).
- ALSA: hda/realtek - More constifications (git-fixes).
- ALSA: hda/realtek - Apply mic mute LED quirk for Dell E7xx
  laptops, too (git-fixes).
- ALSA: sh: Fix unused variable warnings (git-fixes).
- ALSA: hda - constify and cleanup static NodeID tables
  (git-fixes).
- ALSA: hda: Constify snd_pci_quirk tables (git-fixes).
- ALSA: hda: Constify snd_kcontrol_new items (git-fixes).
- ALSA: hda: constify copied structure (git-fixes).
- ALSA: hda: Comment about snd_hdac_bus_update_rirb() and spinlock
  (git-fixes).
- ALSA: control: remove useless assignment in .info callback of
  PCM chmap element (git-fixes).
- ALSA: hda: Unify get_response handling (git-fixes).
- ALSA: hda: Use waitqueue for RIRB in HDA-core helper, too
  (git-fixes).
- ALSA: hda: Use standard waitqueue for RIRB wakeup (git-fixes).
- ath10k: Correct the DMA direction for management tx buffers
  (git-fixes).
- Revert "ath10k: fix DMA related firmware crashes on multiple
  devices" (git-fixes).
- ath10k: pci: Fix comment on ath10k_pci_dump_memory_sram
  (git-fixes).
- ath10k: pci: Only dump ATH10K_MEM_REGION_TYPE_IOREG when safe
  (git-fixes).
- iwlegacy: ensure loop counter addr does not wrap and cause an
  infinite loop (git-fixes).
- rtw88: fix potential NULL skb access in TX ISR (git-fixes).
- brcmfmac: sdio: Fix OOB interrupt initialization on brcm43362
  (git-fixes).
- mwifiex: drop most magic numbers from
  mwifiex_process_tdls_action_frame() (git-fixes).
- net: socionext: fix xdp_result initialization in
  netsec_process_rx (git-fixes).
- net: socionext: fix possible user-after-free in
  netsec_process_rx (git-fixes).
- ath9k: fix storage endpoint lookup (git-fixes).
- brcmfmac: Fix memory leak in brcmf_usbdev_qinit (git-fixes).
- zd1211rw: fix storage endpoint lookup (git-fixes).
- rsi_91x_usb: fix interface sanity check (git-fixes).
- rtl8xxxu: fix interface sanity check (git-fixes).
- orinoco_usb: fix interface sanity check (git-fixes).
- brcmfmac: fix interface sanity check (git-fixes).
- mwifiex: delete unused mwifiex_get_intf_num() (git-fixes).
- brcmfmac: Fix use after free in brcmf_sdio_readframes()
  (git-fixes).
- rsi: fix non-atomic allocation in completion handler
  (git-fixes).
- rsi: fix memory leak on failed URB submission (git-fixes).
- rsi: fix use-after-free on probe errors (git-fixes).
- rsi: fix use-after-free on failed probe and unbind (git-fixes).
- bcma: remove set but not used variable 'sizel' (git-fixes).
- brcmfmac: Fix memory leak in brcmf_p2p_create_p2pdev()
  (git-fixes).
- wil6210: fix break that is never reached because of zero'ing
  of a retry counter (git-fixes).
- ath10k: Fix qmi init error handling (git-fixes).
- ath10k: correct the tlv len of
  ath10k_wmi_tlv_op_gen_config_pno_start (git-fixes).
- NFC: pn544: Adjust indentation in pn544_hci_check_presence
  (git-fixes).
- ppp: Adjust indentation into ppp_async_input (git-fixes).
- Bluetooth: btusb: fix memory leak on fw (git-fixes).
- Bluetooth: btusb: fix non-atomic allocation in completion
  handler (git-fixes).
- commit b16c1ef
* Wed Jan 29 2020 tiwai@suse.de
- regulator: core: Fix exported symbols to the exported GPL
  version (git-fixes).
- commit b623820
* Wed Jan 29 2020 wqu@suse.com
- btrfs: dev-replace: remove warning for unknown return codes
  when finished (dependency for bsc#1162067).
- commit c6cf4b1
* Wed Jan 29 2020 wqu@suse.com
- btrfs: scrub: Require mandatory block group RO for  dev-replace
  (bsc#1162067).
- commit 1eeede9
* Wed Jan 29 2020 jlee@suse.com
- Update config files. (bsc#1160067)
  The 8379bb84be be backported by Takashi from v5.5-rc7 to SLE15-SP2
  kernel. This patch fixed bsc#1160067. After long run testing, we
  confirmed that the issue be fixed on SLE15-SP2 and also v5.5 mainline
  kernel. So I enable CONFIG_KEYS_REQUEST_CACHE again.
  commit 8379bb84be757d5df2d818509faec5d66adb861d
  Author: David Howells <dhowells@redhat.com>
  Date:   Tue Jan 14 16:06:14 2020 +0000
    keys: Fix request_key() cache
- commit 8e290bd
* Wed Jan 29 2020 mgorman@suse.de
- sched, fair: Allow a per-cpu kthread waking a task to stack
  on the same CPU (bsc#1154329).
- commit 8765a0f
* Tue Jan 28 2020 ptesarik@suse.cz
- config: enable arm-specific UFS modules (bsc#1158776 comment 14).
- supported.conf: mark arm-specific UFS modules as supported.
- commit ba2a890
* Tue Jan 28 2020 ptesarik@suse.cz
- config: enable CONFIG_SCSI_SNIC_DEBUG_FS (bsc#1158776 comment 19).
- commit 1120a0c
* Tue Jan 28 2020 lyan@suse.com
- kvm: aarch64: Avoid guest access host debug/PMU registers
  (bnc#1161692).
- commit 392760e
* Tue Jan 28 2020 ptesarik@suse.cz
- config: enable CONFIG_NVM_PBLK on arm64 (bsc#1158776 comment 18).
- commit 1f58f3e
* Tue Jan 28 2020 ptesarik@suse.cz
- config: disable CONFIG_VIRTIO_BLK_SCSI (bsc#1158776 comment 17).
- commit a547bc2
* Tue Jan 28 2020 msuchanek@suse.de
- powerpc/pseries/lparcfg: Fix display of Maximum Memory
  (bsc#1162028 ltc#181740).
- commit c2573b2
* Tue Jan 28 2020 ptesarik@suse.cz
- config: enable BLK_SED_OPAL on arm64 (bsc#1158776 comment 16).
- commit 5c8c73b
* Tue Jan 28 2020 ptesarik@suse.cz
- config: disable CONFIG_RD_LZ4 in arm64/default and s390x/zfcpdump
  (bsc#1158776 comment 15).
- commit 6466f6e
* Tue Jan 28 2020 ptesarik@suse.cz
- config: adjust block device options on arm64 to match x86_64
  (bsc#1158776 comment 14).
- commit 6b66509
* Tue Jan 28 2020 ptesarik@suse.cz
- config: disable MANDATORY_FILE_LOCKING on arm64. To the best of my
  knowledge this is dead code that no one cares about. (bsc#1158776
  comment 12).
- commit 6b4bc5e
* Tue Jan 28 2020 ptesarik@suse.cz
- config: Disable 842 compression on arm64 (bsc#1158776 comment 11).
- commit 998bea1
* Tue Jan 28 2020 ptesarik@suse.cz
- config: file system options on arm64 (bsc#1158776 comment 10).
- commit b603b82
* Tue Jan 28 2020 ptesarik@suse.cz
- config: USB options on arm64 (bsc#1158776 comment 9).
- commit f06de5d
* Tue Jan 28 2020 ptesarik@suse.cz
- config: update non-x86_64 header (gcc 7.5.0)
- commit a033e88
* Tue Jan 28 2020 mbenes@suse.cz
- blacklist.conf: aeed8aa3874d ("tracing: trigger: Replace unneeded RCU-list traversals")
  Needs 28875945ba98 ("rcu: Add support for consolidated-RCU reader
  checking"), which seems to be too invasive for the potential gain.
- commit d3073ab
* Tue Jan 28 2020 ohering@suse.de
- Update patches.suse/target-add-lio-rbd-to-makefile-Kconfig.patch.
  TCM_RBD depends on BLK_DEV_RBD (rbd_img_request_put)
- commit 804b592
* Tue Jan 28 2020 mkubecek@suse.cz
- config: refresh
- update x86_64/default header (gcc 7.5.0)
- clean up x86_64/kvmsmall
- commit 88fb509
* Tue Jan 28 2020 mkubecek@suse.cz
- patch metadata cleanup
- fix Patch-mainline:
  patches.suse/sched-cfs-fix-spurious-active-migration.patch
  patches.suse/sched-fair-Fix-find_idlest_group-to-handle-CPU-affinity.patch
  patches.suse/sched-fair-Optimize-select_idle_core.patch
- commit 2dd79f3
* Tue Jan 28 2020 ptesarik@suse.cz
- Consistent network-related options (bsc#1158776 comment 7).
- commit 8954e4c
* Tue Jan 28 2020 tiwai@suse.de
- clocksource/drivers/bcm2835_timer: Fix memory leak of timer
  (git-fixes).
- ACPI / battery: Deal better with neither design nor full
  capacity not being reported (git-fixes).
- ACPI / battery: Use design-cap for capacity calculations if
  full-cap is not available (git-fixes).
- ACPI / battery: Deal with design or full capacity being reported
  as -1 (git-fixes).
- regulator: rk808: Lower log level on optional GPIOs being not
  available (git-fixes).
- regulator: vctrl-regulator: Avoid deadlock getting and setting
  the voltage (git-fixes).
- spi: fsl-lpspi: fix only one cs-gpio working (git-fixes).
- spi: spi-fsl-qspi: Ensure width is respected in spi-mem
  operations (git-fixes).
- regmap: fix writes to non incrementing registers (git-fixes).
- dmaengine: fsl-qdma: fix duplicated argument to && (git-fixes).
- dmaengine: axi-dmac: add a check for devm_regmap_init_mmio
  (git-fixes).
- platform/x86: intel_mid_powerbtn: Take a copy of ddata
  (git-fixes).
- commit 9a9e8fa
* Mon Jan 27 2020 fdmanana@suse.com
- Btrfs: always copy scrub arguments back to user space
  (bsc#1161948).
- commit 08b80dc
* Mon Jan 27 2020 fdmanana@suse.com
- btrfs: skip log replay on orphaned roots (bsc#1161935).
- commit eeeba1a
* Mon Jan 27 2020 fdmanana@suse.com
- btrfs: handle ENOENT in btrfs_uuid_tree_iterate (bsc#1161937).
- commit 2acecda
* Mon Jan 27 2020 fdmanana@suse.com
- btrfs: abort transaction after failed inode updates in
  create_subvol (bsc#1161936).
- commit 78f55a1
* Mon Jan 27 2020 fdmanana@suse.com
- btrfs: do not call synchronize_srcu() in inode_tree_del
  (bsc#1161934).
- commit 433b7cb
* Mon Jan 27 2020 fdmanana@suse.com
- Btrfs: make tree checker detect checksum items with overlapping
  ranges (bsc#1161931).
- commit 1bcc04b
* Mon Jan 27 2020 fdmanana@suse.com
- Btrfs: fix missing data checksums after replaying a log tree
  (bsc#1161931).
- commit fe9925a
* Mon Jan 27 2020 mbenes@suse.cz
- tracing: Fix histogram code when expression has same var as
  value (git-fixes).
- commit 70a4335
* Mon Jan 27 2020 mbenes@suse.cz
- tracing: xen: Ordered comparison of function pointers
  (git-fixes).
- commit 1c35b4a
* Mon Jan 27 2020 tiwai@suse.de
- mwifiex: fix unbalanced locking in mwifiex_process_country_ie()
  (CVE-2019-14895 bsc#1157158).
- commit b2eb35f
* Mon Jan 27 2020 tiwai@suse.de
- iwlwifi: mvm: fix SKB leak on invalid queue (git-fixes).
- can, slip: Protect tty->disc_data in write_wakeup and close
  with RCU (git-fixes).
- Input: pm8xxx-vib - fix handling of separate enable register
  (git-fixes).
- Input: keyspan-remote - fix control-message timeouts
  (git-fixes).
- Input: sur40 - fix interface sanity checks (git-fixes).
- Input: gtco - fix endpoint sanity check (git-fixes).
- Input: aiptek - fix endpoint sanity check (git-fixes).
- Input: pegasus_notetaker - fix endpoint sanity check
  (git-fixes).
- Input: sun4i-ts - add a check for
  devm_thermal_zone_of_sensor_register (git-fixes).
- drm/i915: Align engine->uabi_class/instance with i915_drm.h
  (git-fixes).
- drm/i915/userptr: fix size calculation (git-fixes).
- mmc: sdhci: fix minimum clock rate for v3 controller
  (git-fixes).
- mmc: tegra: fix SDR50 tuning override (git-fixes).
- mmc: sdhci_am654: Reset Command and Data line after tuning
  (git-fixes).
- mmc: sdhci_am654: Remove Inverted Write Protect flag
  (git-fixes).
- hwmon: (core) Do not use device managed functions for memory
  allocations (git-fixes).
- hwmon: (nct7802) Fix non-working alarm on voltages (git-fixes).
- hwmon: (nct7802) Fix voltage limits to wrong registers
  (git-fixes).
- batman-adv: Fix DAT candidate selection on little endian systems
  (git-fixes).
- cfg80211: check for set_wiphy_params (git-fixes).
- iio: adc: ad7124: Fix DT channel configuration (git-fixes).
- USB: serial: option: add support for Quectel RM500Q in QDL mode
  (git-fixes).
- USB: serial: option: Add support for Quectel RM500Q (git-fixes).
- USB: serial: simple: Add Motorola Solutions TETRA MTP3xxx and
  MTP85xx (git-fixes).
- usb: core: hub: Improved device recognition on remote wakeup
  (git-fixes).
- macb: Don't unregister clks unconditionally (git-fixes).
- drm/arm/mali: make malidp_mw_connector_helper_funcs static
  (git-fixes).
- tomoyo: Don't use nifty names on sockets (git-fixes).
- drm/i915/gvt: set guest display buffer as readonly (git-fixes).
- rtc: bd70528: fix module alias to autoload module (git-fixes).
- drm/amdgpu: allow direct upload save restore list for raven2
  (git-fixes).
- mt76: fix possible out-of-bound access in
  mt7615_fill_txs/mt7603_fill_txs (git-fixes).
- commit daca0f5
* Mon Jan 27 2020 tbogendoerfer@suse.de
- Update patches.suse/ipv6-fix-a-typo-in-fib6_rule_lookup.patch
  (bnc#1151927 5.3.4 CVE-2019-20422).
  Added CVE reference.
- commit afdb381
* Mon Jan 27 2020 tbogendoerfer@suse.de
- net: Fix skb->csum update in inet_proto_csum_replace16()
  (bsc#1154353).
- netfilter: nf_tables: autoload modules from the abort path
  (bsc#1154353).
- netfilter: nf_tables: add __nft_chain_type_get() (bsc#1154353).
- netfilter: conntrack: sctp: use distinct states for new SCTP
  connections (bsc#1154353).
- netfilter: ipset: use bitmap infrastructure completely
  (bsc#1154353).
- netfilter: nft_osf: add missing check for DREG attribute
  (bsc#1154353).
- net/mlx5e: kTLS, Do not send decrypted-marked SKBs via non-accel
  path (jsc#SLE-8464).
- net/mlx5e: kTLS, Remove redundant posts in TX resync flow
  (jsc#SLE-8464).
- net/mlx5e: kTLS, Fix corner-case checks in TX resync flow
  (jsc#SLE-8464).
- net/mlx5e: Clear VF config when switching modes (jsc#SLE-8464).
- net/mlx5: DR, use non preemptible call to get the current cpu
  number (jsc#SLE-8464).
- net/mlx5: E-Switch, Prevent ingress rate configuration of
  uplink rep (jsc#SLE-8464).
- net/mlx5: DR, Enable counter on non-fwd-dest objects
  (jsc#SLE-8464).
- net/mlx5: Update the list of the PCI supported devices
  (jsc#SLE-8464).
- net/mlx5: Fix lowest FDB pool size (jsc#SLE-8464).
- net: cxgb3_main: Add CAP_NET_ADMIN check to CHELSIO_GET_MEM
  (bsc#1154353).
- ipv6_route_seq_next should increase position index
  (bsc#1154353).
- rt_cpu_seq_next should increase position index (bsc#1154353).
- neigh_stat_seq_next() should increase position index
  (bsc#1154353).
- vcc_seq_next should increase position index (bsc#1154353).
- l2t_seq_next should increase position index (bsc#1154353).
- seq_tab_next() should increase position index (bsc#1154353).
- tcp: do not leave dangling pointers in tp->highest_sack
  (bsc#1154353).
- net/rose: fix spelling mistake "to" -> "too" (bsc#1154353).
- caif_usb: fix spelling mistake "to" -> "too" (bsc#1154353).
- ipvs: fix spelling mistake "to" -> "too" (bsc#1154353).
- i40e: fix spelling mistake "to" -> "too" (jsc#SLE-8025).
- net_sched: fix datalen for ematch (bsc#1154353).
- qlcnic: Fix CPU soft lockup while collecting firmware dump
  (bsc#1154353).
- fou: Fix IPv6 netlink policy (bsc#1154353).
- tun: add mutex_unlock() call and napi.skb clearing in
  tun_get_user() (bsc#1154353).
- mlxsw: spectrum_acl: Fix use-after-free during reload
  (bsc#1154488).
- gtp: make sure only SOCK_DGRAM UDP sockets are accepted
  (bsc#1154353).
- net: rtnetlink: validate IFLA_MTU attribute in
  rtnl_create_link() (bsc#1154353).
- net, ip6_tunnel: fix namespaces move (bsc#1154353).
- net_sched: use validated TCA_KIND attribute in tc_new_tfilter()
  (bsc#1154353).
- Revert "udp: do rmem bulk free even if the rx sk queue is empty"
  (bsc#1154353).
- net: Fix packet reordering caused by GRO and listified RX
  cooperation (bsc#1154353).
- net, sk_msg: Don't check if sock is locked when tearing down
  psock (bsc#1154353).
- net, ip_tunnel: fix namespaces move (bsc#1154353).
- tcp: remove redundant assigment to snd_cwnd (bsc#1154353).
- tcp_bbr: improve arithmetic division in bbr_update_bw()
  (bsc#1154353).
- net-sysfs: Fix reference count leak (bsc#1154353).
- ipv6: sr: remove SKB_GSO_IPXIP6 on End.D* actions (bsc#1154353).
- xfrm: support output_mark for offload ESP packets (bsc#1154353).
- xfrm interface: fix packet tx through bpf_redirect()
  (bsc#1154353).
- vti: fix packet tx through bpf_redirect() (bsc#1154353).
- net: ip6_gre: fix moving ip6gre between namespaces
  (bsc#1154353).
- commit 3508aa7
* Mon Jan 27 2020 bp@suse.de
- x86/MCE/AMD: Do not use rdmsr_safe_on_cpu() in smca_configure()
  (bsc#1152489).
- Refresh
  patches.suse/x86-mce-amd-allow-reserved-types-to-be-overwritten-in-smca_banks.patch.
- commit 0c7e16a
* Mon Jan 27 2020 jslaby@suse.cz
- Input: rmi_f54 - read from FIFO in 32 byte blocks (git-fixes).
- Input: synaptics-rmi4 - simplify data read in rmi_f54_work
  (git-fixes).
- Delete
  patches.suse/Input-synaptics-rmi4-don-t-increment-rmiaddr-for-SMB.patch.
  a284e11c371e was reverted in 8ff771f8c8d5. c15f8ba6dc1f is a proper fix.
- commit 396ae25
* Mon Jan 27 2020 jslaby@suse.cz
- net_sched: use validated TCA_KIND attribute in tc_new_tfilter()
  (git-fixes).
- readdir: make user_access_begin() use the real access range
  (git-fixes).
- commit 4c11de1
* Mon Jan 27 2020 tiwai@suse.de
- Fix off-by-one error in the previous i915 fix (bsc#1161720 bsc#1161785)
- commit 079d24f
* Mon Jan 27 2020 jeyu@suse.de
- rpm/kabi.pl: support new (>=5.4) Module.symvers format (new symbol namespace field)
- commit eecbd97
* Mon Jan 27 2020 msuchanek@suse.de
- powerpc/mm/hash: Fix sharing context ids between kernel &
  userspace (bsc#1156395).
- commit c178acd
* Mon Jan 27 2020 msuchanek@suse.de
- powerpc/xive: Discard ESB load value when interrupt is invalid
  (fate#322438 bsc#1085030).
- commit ee23543
* Mon Jan 27 2020 msuchanek@suse.de
- Update
  patches.suse/powerpc-xive-Implement-get_irqchip_state-method-for-.patch
  (fate#322438 bsc#1085030).
- commit 9781d7d
* Mon Jan 27 2020 jack@suse.cz
- libnvdimm/namespace: Differentiate between probe mapping and
  runtime mapping (bsc#1153535).
- commit 515c670
* Fri Jan 24 2020 tiwai@suse.de
- drm/i915/gt: Detect if we miss WaIdleLiteRestore (bsc#1161720).
  Remove the corresponding blacklist entry, too
- commit 480b94e
* Fri Jan 24 2020 mgorman@suse.de
- sched/fair: Load balance aggressively for SCHED_IDLE CPUs
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Make sched-idle CPU selection consistent throughout
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/clock: Use static_branch_likely() with sched_clock_running
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Remove redundant call to cpufreq_update_util()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: calculate delta runnable load only when it's
  needed (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair : Improve update_sd_pick_busiest for spare capacity
  case (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched: Spare resched IPI when prio changes on a single fair
  task (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Optimize select_idle_core (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/fair: Optimize select_idle_cpu (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched/fair: Fix find_idlest_group() to handle CPU affinity
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit aa673a4
* Fri Jan 24 2020 bp@suse.de
- x86/CPU/AMD: Ensure clearing of SME/SEV features is maintained
  (bsc#1161731).
- commit 4ba75bd
* Fri Jan 24 2020 ptesarik@suse.cz
- net/smc: unregister ib devices in reboot_event (jsc#SLE-7395).
- net/smc: remove unused constant (jsc#SLE-7395).
- net/smc: use rcu_barrier() on module unload (jsc#SLE-7395).
- net/smc: guarantee removal of link groups in reboot
  (jsc#SLE-7395).
- net/smc: introduce bookkeeping of SMCR link groups
  (jsc#SLE-7395).
- net/smc: immediate termination for SMCR link groups
  (jsc#SLE-7395).
- net/smc: wait for tx completions before link freeing
  (jsc#SLE-7395).
- net/smc: abnormal termination without orderly flag
  (jsc#SLE-7395).
- net/smc: no WR buffer wait for terminating link group
  (jsc#SLE-7395).
- net/smc: introduce bookkeeping of SMCD link groups
  (jsc#SLE-7395).
- net/smc: abnormal termination of SMCD link groups
  (jsc#SLE-7395).
- net/smc: immediate termination for SMCD link groups
  (jsc#SLE-7395).
- net/smc: fix final cleanup sequence for SMCD devices
  (jsc#SLE-7395).
- net/smc: remove close abort worker (jsc#SLE-7395).
- net/smc: introduce link group termination worker (jsc#SLE-7395).
- net/smc: improve abnormal termination of link groups
  (jsc#SLE-7395).
- net/smc: tell peers about abnormal link group termination
  (jsc#SLE-7395).
- net/smc: improve link group freeing (jsc#SLE-7395).
- net/smc: improve abnormal termination locking (jsc#SLE-7395).
- net/smc: terminate link group without holding lgr lock
  (jsc#SLE-7395).
- net/smc: cancel send and receive for terminated socket
  (jsc#SLE-7395).
- net/smc: improve close of terminated socket (jsc#SLE-7395).
- net/smc: no new connections on disappearing devices
  (jsc#SLE-7395).
- net/smc: increase device refcount for added link group
  (jsc#SLE-7395).
- net/smc: separate locks for SMCD and SMCR link group lists
  (jsc#SLE-7395).
- net/smc: separate SMCD and SMCR link group lists (jsc#SLE-7395).
- commit 57bf8aa
* Thu Jan 23 2020 mbrugger@suse.com
- EDAC: Remove misleading comment in struct edac_raw_error_desc
  (jsc#SLE-9482).
- commit f2fb341
* Thu Jan 23 2020 ailiopoulos@suse.com
- xfs: fix mount failure crash on invalid iclog memory access
  (bsc#1161726).
- commit fbaeaa1
* Thu Jan 23 2020 bp@suse.de
- blacklist.conf:
  df1a7524741b ("x86/entry/32: Remove unused resume_userspace label")
- commit 175a9c1
* Thu Jan 23 2020 bp@suse.de
- x86/ioapic: Prevent inconsistent state when moving an interrupt
  (bsc#1152489).
- commit a9854ec
* Thu Jan 23 2020 mbrugger@suse.com
- EDAC: Unify the mc_event tracepoint call (jsc#SLE-9482).
- EDAC/ghes: Remove intermediate buffer pvt->detail_location
  (jsc#SLE-9482).
- EDAC/ghes: Fix grain calculation (jsc#SLE-9482).
- EDAC/ghes: Use standard kernel macros for page calculations
  (jsc#SLE-9482).
- EDAC/mc: Reduce indentation level in edac_mc_handle_error()
  (jsc#SLE-9482).
- EDAC/mc: Remove needless zero string termination (jsc#SLE-9482).
- EDAC/mc: Do not BUG_ON() in edac_mc_alloc() (jsc#SLE-9482).
- EDAC: Introduce an mci_for_each_dimm() iterator (jsc#SLE-9482).
- EDAC: Remove EDAC_DIMM_OFF() macro (jsc#SLE-9482).
- EDAC: Replace EDAC_DIMM_PTR() macro with edac_get_dimm()
  function (jsc#SLE-9482).
- commit 242a2b2
* Thu Jan 23 2020 mbrugger@suse.com
- EDAC/mc_sysfs: Make debug messages consistent (jsc#SLE-9482).
- EDAC/mc_sysfs: Remove pointless gotos (jsc#SLE-9482).
- EDAC: Prefer 'unsigned int' to bare use of 'unsigned'
  (jsc#SLE-9482).
- commit 919516b
* Thu Jan 23 2020 mbrugger@suse.com
- EDAC/mc: Cleanup _edac_mc_free() code (jsc#SLE-9482).
- commit 0c79b9b
* Thu Jan 23 2020 ptesarik@suse.cz
- s390/qeth: vnicc Fix init to default (jsc#SLE-7474).
- s390/qeth: Fix vnicc_is_in_use if rx_bcast not set
  (jsc#SLE-7474).
- s390/qeth: fix false reporting of VNIC CHAR config failure
  (jsc#SLE-7474).
- s390/qeth: lock the card while changing its hsuid
  (jsc#SLE-7474).
- s390/qeth: fix qdio teardown after early init error
  (jsc#SLE-7474).
- s390/qeth: don't return -ENOTSUPP to userspace (jsc#SLE-7474).
- s390/qeth: fix promiscuous mode after reset (jsc#SLE-7474).
- s390/qeth: handle error due to unsupported transport mode
  (jsc#SLE-7474).
- s390/qeth: ensure linear access to packet headers
  (jsc#SLE-7474).
- s390/qeth: guard against runt packets (jsc#SLE-7474).
- s390/qeth: don't check drvdata in sysfs code (jsc#SLE-7474).
- s390/qeth: replace qeth_l3_get_addr_buffer() (jsc#SLE-7474).
- s390/qeth: remove VLAN tracking for L3 devices (jsc#SLE-7474).
- s390/qeth: consolidate L3 mcast registration code
  (jsc#SLE-7474).
- s390/qeth: remove gratuitious RX modeset (jsc#SLE-7474).
- s390/qeth: fine-tune L3 mcast locking (jsc#SLE-7474).
- s390/qeth: clean up error path in qeth_core_probe_device()
  (jsc#SLE-7474).
- s390/qeth: handle skb allocation error gracefully
  (jsc#SLE-7474).
- s390/qeth: drop unwanted packets earlier in RX path
  (jsc#SLE-7474).
- s390/qeth: support per-frame invalidation (jsc#SLE-7474).
- s390/qeth: gather more detailed RX dropped/error statistics
  (jsc#SLE-7474).
- s390/qeth: don't cache MAC addresses for multicast IPs
  (jsc#SLE-7474).
- s390/qeth: use helpers for IP address hashing (jsc#SLE-7474).
- s390/qeth: don't set card state in qeth_qdio_clear_card()
  (jsc#SLE-7474).
- commit 97e2cae
* Thu Jan 23 2020 ptesarik@suse.cz
- s390/qeth: keep IRQ disabled until NAPI is really done
  (jsc#SLE-7474).
- s390/qeth: use QDIO_BUFNR() (jsc#SLE-7474).
- s390/qdio: move SSQD Sniffer mask definition (jsc#SLE-7474).
- commit 0fcd468
* Thu Jan 23 2020 tbogendoerfer@suse.de
- Update
  patches.suse/net-mlx5-prevent-memory-leak-in-mlx5_fpga_conn_creat.patch
  (jsc#SLE-8464 bnc#1151927 5.3.11 CVE-2019-19045).
  Added CVE reference
- commit 9835bdc
* Thu Jan 23 2020 wqu@suse.com
- btrfs: relocation: fix reloc_root lifespan and access
  (bsc#1159588).
- commit fc30409
* Wed Jan 22 2020 bp@suse.de
- x86/kgbd: Use NMI_VECTOR not APIC_DM_NMI (bsc#1152489).
- commit d1023df
* Wed Jan 22 2020 bp@suse.de
- blacklist.conf:
  7720804a2ae4 ("x86, perf: Fix the dependency of the x86 insn decoder selftest")
- commit b934c08
* Wed Jan 22 2020 msuchanek@suse.de
- Update
  patches.suse/mm-memory_hotplug-don-t-free-usage-map-when-removing-a-re-added-early-section.patch
  (bsc#1160366 ltc#183002 git fixes (mm/hotplug)).
- commit 4057d37
* Wed Jan 22 2020 tiwai@suse.de
- blacklist.conf: Add iwlwifi revert entry that isn't suitable
- commit 8b00a89
* Wed Jan 22 2020 tiwai@suse.de
- bus: ti-sysc: Fix iterating over clocks (git-fixes).
- clk: Don't try to enable critical clocks if prepare failed
  (git-fixes).
- clk: tegra: Fix double-free in tegra_clk_init() (git-fixes).
- commit 7747d41
* Wed Jan 22 2020 tiwai@suse.de
- blacklist.conf: Add drm/virtio entries, insufficent for SLE15-SP2
- commit c1ea031
* Wed Jan 22 2020 bp@suse.de
- x86/resctrl: Fix potential memory leak (bsc#1152489).
- x86/resctrl: Fix an imbalance in domain_remove_cpu()
  (bsc#1152489).
- commit b6bd4fe
* Wed Jan 22 2020 ykaukab@suse.de
- PCI: dwc: Add validation that PCIe core is set to correct mode
  (jsc#SLE-10562).
- commit a4552c1
* Wed Jan 22 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: register gpu instance before fan boost feature enablment'
- commit 6fe4000
* Wed Jan 22 2020 mgorman@suse.de
- sched/cfs: fix spurious active migration (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- commit 8b16f2e
* Wed Jan 22 2020 tzimmermann@suse.de
- drm/amdgpu: fix license on Kconfig and Makefiles (bsc#1152472)
- commit af71d3c
* Wed Jan 22 2020 tzimmermann@suse.de
- drm/amdgpu: Call find_vma under mmap_sem (bsc#1152489)
- commit 45b9c9d
* Wed Jan 22 2020 tzimmermann@suse.de
- drm/amd/powerplay: Fix error handling in smu_init_fb_allocations() (bsc#1152489)
- commit ac2af40
* Wed Jan 22 2020 mkoutny@suse.com
- exit: panic before exit_mm() on global init exit (bsc#1161549).
- commit e6e6d28
* Wed Jan 22 2020 tiwai@suse.de
- rpmsg: char: release allocated memory (CVE-2019-19053
  bsc#1161520).
- commit bdab989
* Wed Jan 22 2020 tiwai@suse.de
- media: rc: prevent memory leak in cx23888_ir_probe
  (CVE-2019-19054 bsc#1161518).
- commit 91d7fee
* Wed Jan 22 2020 tiwai@suse.de
- libertas: make lbs_ibss_join_existing() return error code
  on rates overflow (CVE-2019-14896 bsc#1157157 CVE-2019-14897
  bsc#1157155).
- libertas: don't exit from lbs_ibss_join_existing() with RCU
  read lock held (CVE-2019-14896 bsc#1157157 CVE-2019-14897
  bsc#1157155).
- commit a649646
* Wed Jan 22 2020 jack@suse.cz
- libnvdimm/region: Enable MAP_SYNC for volatile regions
  (bsc#1161291).
- commit 8ecd112
* Tue Jan 21 2020 lpechacek@suse.cz
- powerpc: drmem: avoid NULL pointer dereference when drmem is
  unavailable (bsc#1160659).
- commit 1775954
* Tue Jan 21 2020 tbogendoerfer@suse.de
- igc: Add PHY power management control (bsc#1160632).
- igc: Add support for TSO (bsc#1160634).
- igc: Add SKU for i225 device (bsc#1160634).
- igc: Remove unused definition (bsc#1160634).
- igc: Fix typo in a comment (bsc#1160634).
- igc: Use Start of Packet signal from PHY for timestamping
  (bsc#1160634).
- igc: Add support for ethtool GET_TS_INFO command (bsc#1160634).
- igc: Add support for TX timestamping (bsc#1160634).
- igc: Add support for RX timestamping (bsc#1160634).
- igc: Add basic skeleton for PTP (bsc#1160634).
- igc: Remove no need declaration of the igc_sw_init
  (bsc#1160634).
- igc: Remove no need declaration of the igc_write_itr
  (bsc#1160634).
- igc: Remove no need declaration of the igc_assign_vector
  (bsc#1160634).
- igc: Remove no need declaration of the igc_free_q_vector
  (bsc#1160634).
- igc: Remove no need declaration of the igc_free_q_vectors
  (bsc#1160634).
- igc: Remove no need declaration of the igc_irq_disable
  (bsc#1160634).
- igc: Remove no need declaration of the igc_irq_enable
  (bsc#1160634).
- igc: Remove no need declaration of the igc_configure_msix
  (bsc#1160634).
- igc: Remove no need declaration of the igc_set_rx_mode
  (bsc#1160634).
- igc: Remove no need declaration of the
  igc_set_interrupt_capability (bsc#1160634).
- igc: Remove no need declaration of the igc_alloc_mapped_page
  (bsc#1160634).
- igc: Remove no need declaration of the igc_configure
  (bsc#1160634).
- igc: Remove no need declaration of the
  igc_set_default_mac_filter (bsc#1160634).
- igc: Remove no need declaration of the igc_power_down_link
  (bsc#1160634).
- igc: Remove no need declaration of the igc_clean_tx_ring
  (bsc#1160634).
- igc: Remove serdes comments from a description of methods
  (bsc#1160634).
- igc: Add legacy power management support (bsc#1160634).
- igc: Add 64 bit DMA access support (bsc#1160634).
- igc: Fix parameter descriptions for a several functions
  (bsc#1160634).
- igc: Fix the parameter description for igc_alloc_rx_buffers
  (bsc#1160634).
- igc: Remove excess parameter description from igc_is_non_eop
  (bsc#1160634).
- igc: Prefer to use the pci_release_mem_regions method
  (bsc#1160634).
- igc: Improve the DMA mapping flow (bsc#1160634).
- igc: Add scatter gather support (bsc#1160634).
- cxgb4: reject overlapped queues in TC-MQPRIO offload
  (jsc#SLE-8389).
- cxgb4: fix Tx multi channel port rate limit (jsc#SLE-8389).
- net: sched: act_ctinfo: fix memory leak (bsc#1154353).
- bnxt_en: Do not treat DSN (Digital Serial Number) read failure
  as fatal (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix ipv6 RFS filter matching logic (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Fix NTUPLE firmware command failures (jsc#SLE-8371
  bsc#1153274).
- net: hns: fix soft lockup when there is not enough memory
  (bsc#1154353).
- net: avoid updating qdisc_xmit_lock_key in
  netdev_update_lockdep_key() (bsc#1154353).
- net/sched: act_ife: initalize ife->metalist earlier
  (bsc#1154353).
- netfilter: nat: fix ICMP header corruption on ICMP errors
  (bsc#1154353).
- netfilter: nf_tables: fix flowtable list del corruption
  (bsc#1154353).
- netfilter: nf_tables: remove WARN and add NLA_STRING upper
  limits (bsc#1154353).
- netfilter: nft_tunnel: ERSPAN_VERSION must not be null
  (bsc#1154353).
- netfilter: nft_tunnel: fix null-attribute check (bsc#1154353).
- netfilter: nf_tables: store transaction list locally while
  requesting module (bsc#1154353).
- netfilter: arp_tables: init netns pointer in xt_tgdtor_param
  struct (bsc#1154353).
- netfilter: fix a use-after-free in mtype_destroy()
  (bsc#1154353).
- net: hns3: pad the short frame before sending to the hardware
  (bsc#1154353).
- macvlan: use skb_reset_mac_header() in macvlan_queue_xmit()
  (bsc#1154353).
- tcp: fix marked lost packets not being retransmitted
  (bsc#1154353).
- mlxsw: spectrum_qdisc: Include MC TCs in Qdisc counters
  (bsc#1154488).
- mlxsw: spectrum: Wipe xstats.backlog of down ports
  (bsc#1154488).
- mlxsw: switchx2: Do not modify cloned SKBs during xmit
  (bsc#1154488).
- mlxsw: spectrum: Do not modify cloned SKBs during xmit
  (bsc#1154488).
- mlxsw: spectrum: Do not enforce same firmware version for
  multiple ASICs (bsc#1154488).
- devlink: correct misspelling of snapshot (bsc#1154353).
- devlink: Wait longer before warning about unset port type
  (bsc#1154353).
- ipv4: Detect rollover in specific fib table dump (bsc#1154353).
- net/tls: fix async operation (bsc#1154353).
- net/tls: avoid spurious decryption error with HW resync
  (bsc#1154353).
- e1000e: Revert "e1000e: Make watchdog use delayed work"
  (jsc#SLE-8100).
- i40e: Set PHY Access flag on X722 (jsc#SLE-8025).
- iavf: remove current MAC address filter on VF reset
  (jsc#SLE-7940).
- igb: Fix SGMII SFP module discovery for 100FX/LX (jsc#SLE-7967
  jsc#SLE-8010).
- ixgbe: Fix calculation of queue with VFs and flow director on
  interface flap (jsc#SLE-7979 jsc#SLE-7981).
- ixgbevf: Remove limit of 10 entries for unicast filter list
  (jsc#SLE-7979 jsc#SLE-7981).
- i40e: Fix virtchnl_queue_select bitmap validation
  (jsc#SLE-8025).
- xprtrdma: Fix oops in Receive handler after device removal
  (jsc#SLE-8449).
- xprtrdma: Fix completion wait during device removal
  (jsc#SLE-8449).
- xprtrdma: Fix create_qp crash on device unload (jsc#SLE-8449).
- commit 42c7e2a
* Tue Jan 21 2020 jgross@suse.com
- blacklist.conf: added 1a8211c7d8717b19c1e9fa41d19fe6a55409765e
- commit 302e64e
* Tue Jan 21 2020 jgross@suse.com
- KVM: vmx: Introduce handle_unexpected_vmexit and handle WAITPKG
  vmexit (jsc#SLE-11070).
- commit f99f84d
* Tue Jan 21 2020 jgross@suse.com
- KVM: vmx: Emulate MSR IA32_UMWAIT_CONTROL (jsc#SLE-11070).
- Refresh
  patches.suse/kvm-vmx-implement-msr_ia32_tsx_ctrl-disable-rtm-functionality.
- commit e194189
* Tue Jan 21 2020 jgross@suse.com
- KVM: x86: Add support for user wait instructions
  (jsc#SLE-11070).
- commit dd3d6b5
* Tue Jan 21 2020 mbenes@suse.cz
- perf/x86/cstate: Add Comet Lake CPU support (jsc#SLE-10621).
- commit 344f793
* Tue Jan 21 2020 mbenes@suse.cz
- perf/x86/msr: Add Comet Lake CPU support (jsc#SLE-10621).
- commit ed2c0f6
* Tue Jan 21 2020 mbenes@suse.cz
- perf/x86/intel: Add Comet Lake CPU support (jsc#SLE-10621).
- commit 03d1cee
* Tue Jan 21 2020 ykaukab@suse.de
- PCI: mobiveil: ls_pcie_g4: fix SError when accessing config space (bsc#1161495).
- PCI: mobiveil: ls_pcie_g4: add Workaround for A-011451 (bsc#1161495).
- PCI: mobiveil: ls_pcie_g4: add Workaround for A-011577 (bsc#1161495).
- commit 2049c57
* Tue Jan 21 2020 tiwai@suse.de
- Revert "rsi: fix potential null dereference in rsi_probe()"
  (git-fixes).
- commit 2ef75f1
* Mon Jan 20 2020 msuchanek@suse.de
- blacklist.conf: Add ppc booke fixes.
  3a0990ca1a00 powerpc/booke: Spelling s/date/data/
  71eb40fc5337 powerpc/kasan: Fix boot failure with RELOCATABLE &&
  FSL_BOOKE
- commit 8f24d42
* Mon Jan 20 2020 tiwai@suse.de
- cfg80211: fix page refcount issue in A-MSDU decap (git-fixes).
- cfg80211: fix memory leak in cfg80211_cqm_rssi_update
  (git-fixes).
- cfg80211: fix memory leak in nl80211_probe_mesh_link
  (git-fixes).
- cfg80211: fix deadlocks in autodisconnect work (git-fixes).
- r8152: add missing endpoint sanity check (git-fixes).
- net: usb: lan78xx: limit size of local TSO packets (git-fixes).
- i2c: iop3xx: Fix memory leak in probe error path (git-fixes).
- i2c: tegra: Properly disable runtime PM on driver's probe error
  (git-fixes).
- i2c: tegra: Fix suspending in active runtime PM state
  (git-fixes).
- mtd: rawnand: gpmi: Restore nfc timing setup after
  suspend/resume (git-fixes).
- mtd: rawnand: gpmi: Fix suspend/resume problem (git-fixes).
- drm/i915: Add missing include file <linux/math64.h> (git-fixes).
- efi/earlycon: Fix write-combine mapping on x86 (git-fixes).
- staging: comedi: ni_routes: allow partial routing information
  (git-fixes).
- staging: comedi: ni_routes: fix null dereference in
  ni_find_route_source() (git-fixes).
- iio: light: vcnl4000: Fix scale for vcnl4040 (git-fixes).
- iio: buffer: align the size of scan bytes to size of the
  largest element (git-fixes).
- iio: chemical: pms7003: fix unmet triggered buffer dependency
  (git-fixes).
- iio: imu: st_lsm6dsx: Fix selection of ST_LSM6DS3_ID
  (git-fixes).
- clk: sunxi-ng: r40: Allow setting parent rate for external
  clock outputs (git-fixes).
- clk: qcom: gcc-sdm845: Add missing flag to votable GDSCs
  (git-fixes).
- dmaengine: k3dma: Avoid null pointer traversal (git-fixes).
- drm/amdgpu: enable gfxoff for raven1 refresh (git-fixes).
- net: nfc: nci: fix a possible sleep-in-atomic-context bug in
  nci_uart_tty_receive() (git-fixes).
- net: gemini: Fix memory leak in gmac_setup_txqs (git-fixes).
- rsi: fix potential null dereference in rsi_probe() (git-fixes).
- commit 4cb2bed
* Mon Jan 20 2020 msuchanek@suse.de
- kernel-binary.spec.in: do not recommend firmware for kvmsmall and azure
  flavor (boo#1161360).
- commit dbe7b27
* Mon Jan 20 2020 msuchanek@suse.de
- torture: Remove exporting of internal functions (bsc#1156395).
- commit 3c30cc1
* Mon Jan 20 2020 msuchanek@suse.de
- config/x86_64/kvmsmall: Enable UINPUT (boo#1161305).
- commit 61a4f71
* Mon Jan 20 2020 tiwai@suse.de
- ASoC: msm8916-wcd-digital: Reset RX interpolation path after
  use (git-fixes).
- ASoC: msm8916-wcd-analog: Fix MIC BIAS Internal1 (git-fixes).
- ASoC: sti: fix possible sleep-in-atomic (git-fixes).
- ASoC: msm8916-wcd-analog: Fix selected events for MIC BIAS
  External1 (git-fixes).
- ASoC: hdac_hda: Fix error in driver removal after failed probe
  (git-fixes).
- ASoC: SOF: Intel: fix HDA codec driver probe with multiple
  controllers (git-fixes).
- ASoC: SOF: Intel: lower print level to dbg if we will reinit
  DSP (git-fixes).
- ASoC: stm32: dfsdm: fix 16 bits record (git-fixes).
- ASoC: Intel: bytcht_es8316: Fix Irbis NB41 netbook quirk
  (git-fixes).
- ASoC: rt5640: Fix NULL dereference on module unload (git-fixes).
- ALSA: seq: Fix racy access for queue timer in proc read
  (git-fixes).
- ALSA: usb-audio: fix sync-ep altsetting sanity check
  (git-fixes).
- ALSA: dice: fix fallback from protocol extension into limited
  functionality (git-fixes).
- ALSA: firewire-tascam: fix corruption due to spin lock without
  restoration in SoftIRQ context (git-fixes).
- commit 5af0dd5
* Mon Jan 20 2020 oneukum@suse.com
- NFC: pn533: fix bulk-message timeout (git-fixes).
- commit 442eed3
* Mon Jan 20 2020 oneukum@suse.com
- USB: serial: quatech2: handle unbound ports (git-fixes).
- commit d0020c8
* Mon Jan 20 2020 oneukum@suse.com
- USB: serial: keyspan: handle unbound ports (git-fixes).
- commit 32ba490
* Mon Jan 20 2020 oneukum@suse.com
- USB: serial: io_edgeport: add missing active-port sanity check
  (git-fixes).
- commit 1494e56
* Mon Jan 20 2020 oneukum@suse.com
- USB: serial: io_edgeport: handle unbound ports on URB completion
  (git-fixes).
- commit 6182181
* Mon Jan 20 2020 oneukum@suse.com
- USB: serial: ch341: handle unbound port at reset_resume
  (git-fixes).
- commit 2b59c4a
* Mon Jan 20 2020 oneukum@suse.com
- blacklist.conf: it removes an attribute from sysfs
- commit 3748cd2
* Mon Jan 20 2020 oneukum@suse.com
- USB: serial: opticon: fix control-message timeouts (git-fixes).
- commit 6bc0895
* Mon Jan 20 2020 mgorman@suse.de
- mm: memcg/slab: call flush_memcg_workqueue() only if memcg
  workqueue is valid (git fixes (mm/slab)).
- mm: memcg/slab: fix percpu slab vmstats flushing (git fixes
  (mm/memcg)).
- mm/shmem.c: thp, shmem: fix conflict of above-47bit hint
  address and PMD alignment (git fixes (mm/pgtable)).
- mm/huge_memory.c: thp: fix conflict of above-47bit hint address
  and PMD alignment (git fixes (mm/pgtable)).
- mm/memory_hotplug: don't free usage map when removing a re-added
  early section (git fixes (mm/hotplug)).
- commit 1508be3
* Mon Jan 20 2020 glin@suse.com
- bpf: Sockmap/tls, fix pop data with SK_DROP return code
  (bsc#1155518).
- bpf: Sockmap/tls, skmsg can have wrapped skmsg that needs
  extra chaining (bsc#1155518).
- bpf: Sockmap/tls, tls_sw can create a plaintext buf > encrypt
  buf (bsc#1155518).
- bpf: Sockmap/tls, msg_push_data may leave end mark in place
  (bsc#1155518).
- bpf: Sockmap, skmsg helper overestimates push, pull, and pop
  bounds (bsc#1155518).
- bpf: Sockmap/tls, push write_space updates through ulp updates
  (bsc#1155518).
- bpf: Sockmap, ensure sock lock held during tear down
  (bsc#1155518).
- net: bpf: Don't leak time wait and request sockets
  (bsc#1155518).
- bpf/sockmap: Read psock ingress_msg before sk_receive_queue
  (bsc#1155518).
- commit 8d7a4ba
* Mon Jan 20 2020 glin@suse.com
- bpf: Sockmap/tls, during free we may call tcp_bpf_unhash()
  in loop (bsc#1155518).
- bpf: Fix incorrect verifier simulation of ARSH under ALU32
  (bsc#1155518).
- bpftool: Fix printing incorrect pointer in btf_dump_ptr
  (bsc#1155518).
- commit 67424a0
* Fri Jan 17 2020 ptesarik@suse.cz
- s390/qeth: consolidate some duplicated HW cmd code
  (jsc#SLE-7474).
- Refresh patches.suse/s390-qeth-fix-initialization-on-old-hw.
- commit 00d9aa3
* Fri Jan 17 2020 ptesarik@suse.cz
- s390/qeth: merge qeth_reply struct into qeth_cmd_buffer
  (jsc#SLE-7542).
- Refresh
  patches.suse/s390-qeth-fix-dangling-io-buffers-after-halt-clear.
- commit 9542e64
* Fri Jan 17 2020 ptesarik@suse.cz
- s390/qeth: return proper errno on IO error (jsc#SLE-7542).
- s390/qeth: fix potential deadlock on workqueue flush
  (jsc#SLE-7542).
- s390/qeth: Fix initialization of vnicc cmd masks during set
  online (jsc#SLE-7542).
- s390/qeth: Fix error handling during VNICC initialization
  (jsc#SLE-7542).
- s390/qdio: clarify size of the QIB parm area (jsc#SLE-7542).
- s390/ctcm: Delete unnecessary checks before the macro call
  "dev_kfree_skb" (jsc#SLE-7542).
- s390/lcs: don't use intparm for channel IO (jsc#SLE-7542).
- s390/ctcm: don't use intparm for channel IO (jsc#SLE-7542).
- s390/qeth: streamline control code for promisc mode
  (jsc#SLE-7542).
- s390/qeth: get vnicc sub-cmd type from reply data
  (jsc#SLE-7542).
- s390/qeth: keep cmd alive after IO completion (jsc#SLE-7542).
- s390/qeth: use correct length field in SNMP cmd callback
  (jsc#SLE-7542).
- s390/qeth: propagate length of processed cmd IO data to callback
  (jsc#SLE-7542).
- s390/qeth: use node_descriptor struct (jsc#SLE-7542).
- commit 8223e8d
* Fri Jan 17 2020 jgross@suse.com
- xen/blkfront: Adjust indentation in xlvbd_alloc_gendisk
  (bsc#1065600).
- commit 5b346da
* Fri Jan 17 2020 ddiss@suse.de
- Refresh patches.suse/target-add-lio-rbd-to-makefile-Kconfig.patch:
  (fate#318836).
- supported.conf: relist target_core_rbd (fate#318836)
- re-enable CONFIG_TCM_RBD=m
- Refresh patches.suse/target-add-rbd-backend.patch:
  (fate#318836).
  + use upstream RBD bvecs API and split out compare&write and
    write-same request support
- Refresh patches.suse/rbd-add-lio-specific-data-area.patch:
  (fate#318836).
  + rebased, with lio_cmd_data moved into union with rq/copyup state
- Add patches.suse/rbd-add-img_request-done-callback.patch:
  (fate#318836).
  + this is needed for target_core_rbd SCSI cmd completion following
    7114edac357b ("rbd: new request completion code")
- Refresh
  patches.suse/rbd-move-structs-used-by-lio-rbd-to-new-header.patch:
  (fate#318836).
  + rebase and expose bvecs instead of sgl API for data payload
- Refresh
  patches.suse/rbd-export-some-functions-used-by-lio-rbd-backend.patch:
  (fate#318836).
  + export bvecs API for data payload
- commit d3df489
* Fri Jan 17 2020 ddiss@suse.de
- Deletions for target_core_rbd refactoring
- Drop upstreamed patches
  patches.suse/target-configfs-add-device-vendor_id-attribute.patch
  patches.suse/target-remove-hardcoded-T10-Vendor-ID-in-INQUIRY-res.patch
- Merge with target-add-rbd-backend.patch
  patches.suse/0001-target_core_rbd-use-RCU-in-free_device.patch
  patches.suse/0002-target_core_rbd-break-up-free_device-callback.patch
  patches.suse/target-rbd-don-t-put-snap_context-twice.patch
  patches.suse/target-rbd-handle-zero-length-UNMAP-requests-early.patch
  patches.suse/target-rbd-use-target_configure_unmap_from_queue-hel.patch
- Remove rbd sgl patches following target_core_rbd bvec conversion
  patches.suse/libceph-add-scatterlist-messenger-data-type.patch
  patches.suse/libceph-fix-scatterlist-last_piece-calculation.patch
  patches.suse/rbd-add-support-for-scatterlist-obj_request_type.patch
  patches.suse/rbd-handle-OBJ_REQUEST_SG-types-for-copyup.patch
- Drop compare-and-write support pending bvecs conversion
  patches.suse/0001-rbd-drop-extra-rbd_img_request_get.patch
  patches.suse/libceph-add-support-for-CMPEXT-compare-extent-reques.patch
  patches.suse/rbd-add-num-ops-calculator-helper.patch
  patches.suse/rbd-add-support-for-COMPARE_AND_WRITE-CMPEXT.patch
  patches.suse/rbd-copy-compare-and-write-osd-requests-before-resub.patch
  patches.suse/rbd-don-t-log-miscompare-as-an-error.patch
  patches.suse/rbd-helper-to-copy-compare-and-write-osd-requests.patch
  patches.suse/rbd-truncate-objects-on-cmpext-short-reads.patch
  patches.suse/target-add-COMPARE_AND_WRITE-sg-creation-helper.patch
  patches.suse/target-add-compare-and-write-callback.patch
  patches.suse/target-compare-and-write-backend-driver-sense-handli.patch
  patches.suse/target-rbd-remove-caw_mutex-usage.patch
  patches.suse/rbd-add-write-test-helper.patch
- Drop SCSI Reservation support pending upstream discussion
  patches.suse/0002-rbd-make-sure-pages-are-freed-by-libceph.patch
  patches.suse/ceph-osd_client-add-support-for-CEPH_OSD_OP_GETXATTR.patch
  patches.suse/libceph-fix-pr_fmt-compile-issues.patch
  patches.suse/rbd-add-cmpsetattr-device-attribute-for-debugging.patch
  patches.suse/rbd-add-getxattr-device-attribute-for-debugging.patch
  patches.suse/rbd-add-rbd_dev_cmpsetxattr-helper.patch
  patches.suse/rbd-add-rbd_dev_getxattr-helper.patch
  patches.suse/rbd-add-rbd_dev_setxattr-helper.patch
  patches.suse/rbd-add-setxattr-device-attribute-for-debugging.patch
  patches.suse/rbd-do-away-with-obj_request-in-cmpsetxattr.patch
  patches.suse/rbd-do-away-with-obj_request-in-getxattr.patch
  patches.suse/rbd-do-away-with-obj_request-in-setxattr.patch
  patches.suse/target-fix-tcm_rbd_gen_it_nexus-for-emulated-XCOPY-s.patch
  patches.suse/target-pr-add-backend-API-for-reservation-handling.patch
  patches.suse/target-pr-fix-core_scsi3_pr_seq_non-caller.patch
  patches.suse/target-pr-split-out-and-export-core_scsi3_pr_seq_non.patch
  patches.suse/target-rbd-SCSI3-check-conflict-support.patch
  patches.suse/target-rbd-add-SCSI2-reservation-entry-to-PR-info.patch
  patches.suse/target-rbd-add-pr_clear-support.patch
  patches.suse/target-rbd-add-pr_preempt-support.patch
  patches.suse/target-rbd-add-pr_read_reservation-support.patch
  patches.suse/target-rbd-add-pr_release-support.patch
  patches.suse/target-rbd-add-pr_report_capabilities-support.patch
  patches.suse/target-rbd-add-pr_reserve-support.patch
  patches.suse/target-rbd-add-stubbed-out-pr_read_full_status.patch
  patches.suse/target-rbd-add-stubbed-out-pr_register_and_move.patch
  patches.suse/target-rbd-add-support-for-PR-register-read-keys.patch
  patches.suse/target-rbd-fix-PR-info-memory-leaks.patch
  patches.suse/target-rbd-handle-SCSI2-reservation-release-on-reset.patch
  patches.suse/target-rbd-implement-SCSI2-reservation-handling.patch
- Remove write-same support pending bvecs conversion
  patches.suse/libceph-add-support-for-write-same-requests.patch
  patches.suse/libceph-use-upstream-write-same-opcode.patch
  patches.suse/rbd-add-support-for-writesame-requests.patch
- commit 1277a52
* Thu Jan 16 2020 tiwai@suse.de
- Documentation/ABI: Add missed attribute for mlxreg-io sysfs
  interfaces (git-fixes).
- Documentation/ABI: Fix documentation inconsistency for mlxreg-io
  sysfs interfaces (git-fixes).
- commit 4873021
* Thu Jan 16 2020 tiwai@suse.de
- platform/x86: asus-wmi: Fix keyboard brightness cannot be set
  to 0 (git-fixes).
- platform/x86: GPD pocket fan: Use default values when wrong
  modparams are given (git-fixes).
- platform/mellanox: fix potential deadlock in the tmfifo driver
  (git-fixes).
- commit 0bb7471
* Thu Jan 16 2020 jeyu@suse.de
- Delete patches.suse/x86-cpu_entry_area-Map-also-trace_idt_table.patch.
  The real fixes have been upstream since v4.14.
- commit 46e9a10
* Thu Jan 16 2020 tbogendoerfer@suse.de
- i40iw: Remove setting of VMA private data and use
  rdma_user_mmap_io (jsc#SLE-8449).
- IB/hfi1: Adjust flow PSN with the correct resync_psn
  (jsc#SLE-8449).
- IB/hfi1: Don't cancel unused work item (jsc#SLE-8449).
- RDMA/bnxt_re: Fix Send Work Entry state check while polling
  completions (jsc#SLE-8372 bsc#1153275).
- RDMA/bnxt_re: Avoid freeing MR resources if dereg fails
  (jsc#SLE-8372 bsc#1153275).
- netfilter: conntrack: dccp, sctp: handle null timeout argument
  (bsc#1154353).
- netfilter: arp_tables: init netns pointer in xt_tgchk_param
  struct (bsc#1154353).
- macvlan: do not assume mac_header is set in macvlan_broadcast()
  (bsc#1154353).
- net: sch_prio: When ungrafting, replace with FIFO (bsc#1154353).
- mlxsw: spectrum_qdisc: Ignore grafting of invisible FIFO
  (bsc#1154488).
- gtp: fix bad unlock balance in gtp_encap_enable_socket
  (bsc#1154353).
- pkt_sched: fq: do not accept silly TCA_FQ_QUANTUM (bsc#1154353).
- net/mlx5: DR, Init lists that are used in rule's member
  (jsc#SLE-8464).
- net/mlx5e: Fix hairpin RSS table size (jsc#SLE-8464).
- net/mlx5: DR, No need for atomic refcount for internal SW
  steering resources (jsc#SLE-8464).
- Revert "net/mlx5: Support lockless FTE read lookups"
  (jsc#SLE-8464).
- net/mlx5: Move devlink registration before interfaces load
  (jsc#SLE-8464).
- net/mlx5e: Always print health reporter message to dmesg
  (jsc#SLE-8464).
- net/mlx5e: Avoid duplicating rule destinations (jsc#SLE-8464).
- sctp: free cmd->obj.chunk for the unprocessed SCTP_CMD_REPLY
  (bsc#1154353).
- net: Google gve: Remove dma_wmb() before ringing doorbell
  (bsc#1154353).
- sch_cake: avoid possible divide by zero in cake_enqueue()
  (bsc#1154353).
- tcp: fix "old stuff" D-SACK causing SACK to be treated as D-SACK
  (bsc#1154353).
- commit b1356f9
* Thu Jan 16 2020 wqu@suse.com
- Delete
  patches.suse/btrfs-suspend-qgroups-during-relocation-recovery.patch.
  This patch is no longer needed for v5.3. Since v5.1 we have proper
  qgroup + balance optimization to avoid unnecessary rescan.
- commit b92eedd
* Thu Jan 16 2020 wqu@suse.com
- Delete
  patches.suse/0001-btrfs-qgroup-Make-qgroup-async-transaction-commit-mo.patch.
  This patch is already upstreamed in v5.1, thus already included.
- commit 5b34f2a
* Wed Jan 15 2020 rgoldwyn@suse.com
- overlayfs: pseudo dev obviates treating btrfs as different
  Delete patches.suse/ovl-treat-btrfs-as-different-mount.patch.
- commit e1e67d4
* Wed Jan 15 2020 rgoldwyn@suse.com
- apparmor: Delete apparmor patches not required for v5.3
- Delete
  patches.suse/0001-apparmor-fix-unnecessary-creation-of-net-compat.patch.
- Delete
  patches.suse/0001-apparmor-patch-to-provide-compatibility-with-v2.x-ne.patch.
- Delete
  patches.suse/0003-apparmor-fix-use-after-free-in-sk_peer_label.patch.
- Delete patches.suse/apparmor-compatibility-with-v2.x-net.patch.
- commit faddc27
* Wed Jan 15 2020 mbrugger@suse.com
- supported.conf: mark gpio-mlxbf as supported
- commit 987e308
* Wed Jan 15 2020 tiwai@suse.de
- arm: Implement copy_thread_tls (git-fixes).
- drm/i915: Hold reference to intel_frontbuffer as we track
  activity (git-fixes).
- drm/i915/tgl: Drop Wa#1178 (git-fixes).
- ARM: vexpress: Set-up shared OPP table instead of individual
  for each CPU (git-fixes).
- commit 5a1c660
* Wed Jan 15 2020 tiwai@suse.de
- blacklist.conf: Add cosmetic entry for drivers/reset/Kconfig
- commit 9ca8239
* Wed Jan 15 2020 hare@suse.de
- acpi: disable deprecated warnings (bsc#1160977).
- commit 509dee8
* Wed Jan 15 2020 bp@suse.de
- Delete patches.suse/ras-cec-disable-cec.patch.
  Now we're behaving the same way as upstream.
- commit 9e8f6dc
* Wed Jan 15 2020 mbrugger@suse.com
- drivers: ipmi: Modify max length of IPMB packet (jsc#SLE-10262).
- drivers: ipmi: Support raw i2c packet in IPMB (jsc#SLE-10262).
- commit 856cc09
* Wed Jan 15 2020 mbrugger@suse.com
- supported.conf: mark ipmb_dev_int as supported (jsc#SLE-10262)
  Also mentioned in  bsc#1119861
- commit 995fffc
* Wed Jan 15 2020 mbrugger@suse.com
- ipmi: fix ipmb_poll()'s return type (jsc#SLE-10262).
- commit 96db5f2
* Wed Jan 15 2020 oneukum@suse.com
- Update
  patches.suse/USB-Fix-Don-t-skip-endpoint-descriptors-with-maxpack.patch
  (bsc#1159811 bsc#1152932).
  Added further bug this fixes
- commit 698a1af
* Wed Jan 15 2020 vbabka@suse.cz
- Refresh
  patches.suse/mm-debug_pagealloc-don-t-rely-on-static-keys-too-ear.patch.
- Update to final upstream version and move to sorted section.
- commit 0b6c359
* Wed Jan 15 2020 tiwai@suse.de
- keys: Fix request_key() cache (git-fixes).
- i2c: fix bus recovery stop mode timing (git-fixes).
- usb: musb: Disable pullup at init (git-fixes).
- USB-PD tcpm: bad warning+size, PPS adapters (git-fixes).
- USB: serial: option: add ZLP support for 0x1bc7/0x9010
  (git-fixes).
- phy/rockchip: inno-hdmi: round clock rate down to closest 1000
  Hz (git-fixes).
- phy: mapphone-mdm6600: Fix uninitialized status value regression
  (git-fixes).
- chardev: Avoid potential use-after-free in 'chrdev_open()'
  (git-fixes).
- staging: rtl8188eu: Add device code for TP-Link TL-WN727N v5.21
  (git-fixes).
- staging: vt6656: set usb_set_intfdata on driver fail
  (git-fixes).
- staging: vt6656: remove bool from vnt_radio_power_on ret
  (git-fixes).
- staging: vt6656: limit reg output to block size (git-fixes).
- staging: vt6656: correct return of vnt_init_registers
  (git-fixes).
- staging: vt6656: Fix non zero logical return of, usb_control_msg
  (git-fixes).
- tty: always relink the port (git-fixes).
- drm/i915: Add Wa_1407352427:icl,ehl (git-fixes).
- drm/i915: Add Wa_1408615072 and Wa_1407596294 to icl,ehl
  (git-fixes).
- gpiolib: acpi: Add honor_wakeup module-option + quirk mechanism
  (git-fixes).
- gpiolib: acpi: Turn dmi_system_id table into a generic quirk
  table (git-fixes).
- Input: add safety guards to input_set_keycode() (git-fixes).
- HID: hid-input: clear unmapped usages (git-fixes).
- HID: Fix slab-out-of-bounds read in hid_field_extract
  (git-fixes).
- tty: link tty and port before configuring it as console
  (git-fixes).
- commit cc6ecc7
* Tue Jan 14 2020 tiwai@suse.de
- drm/i915/gen9: Clear residual context state on context switch
  (CVE-2019-14615 bsc#1160195).
- commit d10cf58
* Tue Jan 14 2020 mbrugger@suse.com
- drivers: ipmi: Support for both IPMB Req and Resp
  (jsc#SLE-10262).
- commit a109ac6
* Tue Jan 14 2020 mbrugger@suse.com
- EDAC, mellanox: Add ECC support for BlueField DDR4
  (jsc#SLE-10262).
- Update config files. Build EDAC_BLUEFIELD as module
- supported.conf: Mark bluefield_edac as supported
- commit bda0819
* Tue Jan 14 2020 mbrugger@suse.com
- platform/mellanox: fix the mlx-bootctl sysfs (jsc#SLE-10262).
- commit c5d7bab
* Tue Jan 14 2020 mbrugger@suse.com
- platform/mellanox: Fix Kconfig indentation (jsc#SLE-10262).
- platform/mellanox: Add bootctl driver for Mellanox BlueField
  Soc (jsc#SLE-10262).
- Update config files: build MLXBF_BOOTCTL as module
- supported.conf: add mlxbf-bootctl
- driver core: add dev_groups to all drivers (jsc#SLE-10262).
- commit 619e678
* Tue Jan 14 2020 mgorman@suse.de
- sched, fair: Allow a small load imbalance between low
  utilisation SD_NUMA domains (bnc#1160896).
- commit fef7d8c
* Tue Jan 14 2020 jeyu@suse.de
- blacklist.conf: Blacklist a11391b6f506 ("scripts: package: mkdebian: add missing rsync dependency")
- commit 4a86d94
* Tue Jan 14 2020 nsaenzjulienne@suse.de
- thermal: Add BCM2711 thermal driver (bsc#1160311).
- Update config files.
- supported.conf: Add bcm2711-thermal
- commit 8743e23
* Tue Jan 14 2020 nsaenzjulienne@suse.de
- scripts/git_sort/git_sort.py: Add thermal tree
- commit b511c78
* Tue Jan 14 2020 trenn@suse.com
- Refresh patches.suse/pstore-backend-autoaction.
- commit 62c0377
* Mon Jan 13 2020 msuchanek@suse.de
- powerpc/pmem: Fix kernel crash due to wrong range value usage
  in flush_dcache_range (bsc#1156395).
- commit 252a29d
* Mon Jan 13 2020 mkubecek@suse.cz
- Update references:
  patches.suse/x86-fpu-Don-t-cache-access-to-fpu_fpregs_owner_ctx.patch
  (add bsc#1158887).
- commit b4c1446
* Mon Jan 13 2020 msuchanek@suse.de
- powerpc/mm: Mark get_slice_psize() & slice_addr_is_low()
  as notrace (bsc#1156395).
- powerpc: Fix __clear_user() with KUAP enabled (bsc#1156395).
- powerpc/fixmap: Use __fix_to_virt() instead of fix_to_virt()
  (bsc#1156395).
- powerpc: Chunk calls to flush_dcache_range in arch_*_memory
  (bsc#1156395).
- commit bb8bcdd
* Mon Jan 13 2020 fdmanana@suse.com
- Btrfs: fix infinite loop during nocow writeback due to race
  (bsc#1160804).
- commit ef1dd9a
* Mon Jan 13 2020 fdmanana@suse.com
- Btrfs: fix removal logic of the tree mod log that leads to
  use-after-free issues (bsc#1160803).
- commit d3f68f5
* Mon Jan 13 2020 mbenes@suse.cz
- tracing: Change offset type to s32 in preempt/irq tracepoints
  (bsc#1160794).
- commit 3de9401
* Mon Jan 13 2020 mbenes@suse.cz
- kernel/trace: Fix do not unregister tracepoints when register
  sched_migrate_task fail (bsc#1160787).
- commit 11f6e8d
* Mon Jan 13 2020 mbenes@suse.cz
- ftrace: Avoid potential division by zero in function profiler
  (bsc#1160784).
- commit 55123bf
* Mon Jan 13 2020 mbenes@suse.cz
- blacklist.conf: b8299d362d08 ("tracing: Have stack tracer compile when MCOUNT_INSN_SIZE is not defined")
  We cannot run into the scenario with our codebase and configs.
- commit 1491d6e
* Mon Jan 13 2020 bp@suse.de
- Update
  patches.suse/x86-fpu-Don-t-cache-access-to-fpu_fpregs_owner_ctx.patch
  (bnc#1151927 5.3.15 CVE-2019-19602).
  Add CVE number.
- commit c2d738c
* Mon Jan 13 2020 tiwai@suse.de
- Move upstreamed qlde patches into sorted section
- commit 8ed9cca
* Mon Jan 13 2020 dkirjanov@suse.com
- patches.suse/0010-netfilter-ipset-avoid-null-deref-when-IPSET_ATTR_LIN.patch:
  (git-fixes).
- patches.suse/0011-netfilter-nft_flow_offload-fix-underflow-in-flowtabl.patch:
  (git-fixes).
- patches.suse/0012-netfilter-bridge-make-sure-to-pull-arp-header-in-br_.patch:
  (git-fixes).
- patches.suse/0009-net-phy-broadcom-Fix-RGMII-delays-configuration-for-.patch:
  (git-fixes).
- patches.suse/0008-net-stmmac-Fix-TSO-descriptor-with-Enhanced-Addressi.patch:
  (git-fixes).
- patches.suse/0007-net-stmmac-selftests-Prevent-false-positives-in-filt.patch:
  (git-fixes).
- patches.suse/0006-net-stmmac-selftests-Fix-L2-Hash-Filter-test.patch:
  (git-fixes).
- patches.suse/0005-net-stmmac-gmac4-Not-all-Unicast-addresses-may-be-av.patch:
  (git-fixes).
- patches.suse/0004-net-stmmac-selftests-Check-if-filtering-is-available.patch:
  (git-fixes).
- patches.suse/0003-net-stmmac-xgmac-Disable-the-Timestamp-interrupt-by-.patch:
  (git-fixes).
- net: stmmac: dwmac-meson8b: Fix signedness bug in probe
  (git-fixes).
- patches.suse/0001-netfilter-nf_tables_offload-avoid-excessive-stack-us.patch:
  (git-fixes).
- commit aa9a965
* Mon Jan 13 2020 palcantara@suse.de
- Delete patches.suse/cifs-fix-set-info.patch.
  Applied to v4.12+, not needed anymore.
- commit b070525
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: hide another #warning'
- commit b0c0990
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: revert "disable bulk moves for now"'
- commit 8d0546c
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Fix KFD-related kernel oops on Hawaii'
- commit c48f714
* Mon Jan 13 2020 tzimmermann@suse.de
- drm/meson: vclk: use the correct G12A frac max value (bsc#1152489)
- commit 7b38ed0
* Mon Jan 13 2020 tzimmermann@suse.de
- drm/mipi-dbi: fix a loop in debugfs code (bsc#1152489)
- commit d510e3b
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix g4x sprite scaling stride check with GTT remapping'
- commit cf03598
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/dp: Fix dsc bpp calculations, v5.'
- commit 44b95e2
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Mark contents as dirty on a write fault'
- commit fa91ba4
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Bump skl+ max plane width to 5k for linear/x-tiled'
- commit 9d6eb9a
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Don't mix srcu tag and negative error codes'
- commit e879648
* Mon Jan 13 2020 msuchanek@suse.de
- powerpc/irq: fix stack overflow verification (bsc#1065729).
- commit 3c46adb
* Mon Jan 13 2020 nsaenzjulienne@suse.de
- Delete patches.suse/firmware-arm_sdei-fix-wrong-of_node_put-in-init-function.patch.
  Applied to v5.0, not needed anymore.
- commit a8b4a26
* Mon Jan 13 2020 msuchanek@suse.de
- powerpc/mm: drop #ifdef CONFIG_MMU in is_ioremap_addr()
  (bsc#1065729).
- powerpc/security: Fix debugfs data leak on 32-bit (bsc#1065729).
- powerpc/pkeys: remove unused pkey_allows_readwrite
  (bsc#1065729).
- powerpc/64s/radix: Fix build failure with RADIX_MMU=n
  (bsc#1065729).
- commit 710230e
* Mon Jan 13 2020 tiwai@suse.de
- HID: hidraw, uhid: Always report EPOLLOUT (git-fixes).
- HID: hidraw: Fix returning EPOLLOUT from hidraw_poll
  (git-fixes).
- hidraw: Return EPOLLOUT from hidraw_poll (git-fixes).
- commit be1efe9
* Mon Jan 13 2020 hare@suse.de
- Enable SCSI patches after review
- Refresh patches.suse/fcoe-reduce-max_sectors.
- commit cdd6e89
* Mon Jan 13 2020 hare@suse.de
- Remove disabled NVMe patches after review
- Delete
  patches.suse/nvme-Do-not-remove-namespaces-during-reset.patch.
- Delete
  patches.suse/nvme-flush-scan_work-when-resetting-controller.patch.
- Delete
  patches.suse/nvme-schedule-requeue-whenever-a-LIVE-state-is-enter.patch.
- Delete
  patches.suse/nvme-skip-nvme_update_disk_info-if-the-controller-is.patch.
- commit 0f8d58e
* Mon Jan 13 2020 tiwai@suse.de
- vlan: vlan_changelink() should propagate errors (git-fixes).
- vlan: fix memory leak in vlan_dev_set_egress_priority
  (git-fixes).
- vxlan: fix tos value before xmit (git-fixes).
- commit cb7ad7e
* Mon Jan 13 2020 tiwai@suse.de
- usb: missing parentheses in USE_NEW_SCHEME (git-fixes).
- usb: ohci-da8xx: ensure error return on variable error is set
  (git-fixes).
- usb: musb: fix idling for suspend after disconnect interrupt
  (git-fixes).
- USB: serial: option: add Telit ME910G1 0x110a composition
  (git-fixes).
- usb: chipidea: host: Disable port power only if previously
  enabled (git-fixes).
- usb: dwc3: gadget: Fix request complete check (git-fixes).
- usb: musb: dma: Correct parameter passed to IRQ handler
  (git-fixes).
- USB: core: fix check for duplicate endpoints (git-fixes).
- sbitmap: only queue kyber's wait callback if not already active
  (git-fixes).
- rfkill: Fix incorrect check to avoid NULL pointer dereference
  (git-fixes).
- usb: typec: fusb302: Fix an undefined reference to
  'extcon_get_state' (git-fixes).
- regulator: fix use after free issue (git-fixes).
- spi: spi-ti-qspi: Fix a bug when accessing non default CS
  (git-fixes).
- spi: spi-cavium-thunderx: Add missing pci_release_regions()
  (git-fixes).
- spi: pxa2xx: Add support for Intel Jasper Lake (git-fixes).
- reset: Do not register resource data for missing resets
  (git-fixes).
- USB: dummy-hcd: use usb_urb_dir_in instead of usb_pipein
  (git-fixes).
- commit fb98c64
* Mon Jan 13 2020 tiwai@suse.de
- phy: cpcap-usb: Fix flakey host idling and enumerating of
  devices (git-fixes).
- phy: cpcap-usb: Fix error path when no host driver is loaded
  (git-fixes).
- powercap: intel_rapl: add NULL pointer check to
  rapl_mmio_cpu_online() (git-fixes).
- pstore/ram: Regularize prz label allocation lifetime
  (git-fixes).
- pinctrl: meson: Fix wrong shift value when get drive-strength
  (git-fixes).
- pinctrl: lochnagar: select GPIOLIB (git-fixes).
- net: ethernet: ti: davinci_cpdma: fix warning "device driver
  frees DMA memory with different size" (git-fixes).
- psi: Fix a division error in psi poll() (git-fixes).
- net: ethernet: ti: ale: clean ale tbl on init and intf restart
  (git-fixes).
- net: ethernet: ti: Add dependency for TI_DAVINCI_EMAC
  (git-fixes).
- commit f56a8be
* Mon Jan 13 2020 tiwai@suse.de
- net: usb: lan78xx: fix possible skb leak (git-fixes).
- net: phylink: fix failure to register on x86 systems
  (git-fixes).
- commit dfe6464
* Mon Jan 13 2020 tiwai@suse.de
- i2c: bcm2835: Store pointer to bus clock (git-fixes).
- mtd: onenand: omap2: Pass correct flags for prep_dma_memcpy
  (git-fixes).
- mtd: rawnand: stm32_fmc2: avoid to lock the CPU bus (git-fixes).
- Input: input_event - fix struct padding on sparc64 (git-fixes).
- commit 016c9c2
* Mon Jan 13 2020 tiwai@suse.de
- gpio: zynq: Fix for bug in zynq_gpio_restore_context API
  (git-fixes).
- HID: hiddev: fix mess in hiddev_open() (git-fixes).
- HID: uhid: Fix returning EPOLLOUT from uhid_char_poll
  (git-fixes).
- efi/gop: Fix memory leak in __gop_query32/64() (git-fixes).
- efi/gop: Return EFI_SUCCESS if a usable GOP was found
  (git-fixes).
- efi/gop: Return EFI_NOT_FOUND if there are no usable GOPs
  (git-fixes).
- commit 07644ef
* Mon Jan 13 2020 ptesarik@suse.cz
- Delete patches.suse/s390-sles15-05-01-gmb.patch (unused code).
- commit 396bd69
* Mon Jan 13 2020 tiwai@suse.de
- staging: comedi: adv_pci1710: fix AI channels 16-31 for PCI-1713
  (git-fixes).
- drm/i915/gt: Mark up virtual engine uabi_instance (git-fixes).
- drm/fb-helper: Round up bits_per_pixel if possible (git-fixes).
- drm/sun4i: tcon: Set RGB DCLK min. divider based on hardware
  model (git-fixes).
- drm/dp_mst: correct the shifting in DP_REMOTE_I2C_READ
  (git-fixes).
- cfg80211: fix double-free after changing network namespace
  (git-fixes).
- drm/exynos: gsc: add missed component_del (git-fixes).
- commit 9472262
* Mon Jan 13 2020 tiwai@suse.de
- can: mscan: mscan_rx_poll(): fix rx path lockup when returning
  from polling to irq mode (git-fixes).
- can: gs_usb: gs_usb_probe(): use descriptors of current
  altsetting (git-fixes).
- can: kvaser_usb: fix interface sanity check (git-fixes).
- can: can_dropped_invalid_skb(): ensure an initialized headroom
  in outgoing CAN sk_buffs (git-fixes).
- commit d7cc7b3
* Mon Jan 13 2020 ptesarik@suse.cz
- Delete patches.suse/s390-sles15-bpf-indirect-call.patch (code removed).
- commit 5611b27
* Mon Jan 13 2020 tiwai@suse.de
- ALSA: hda: enable regmap internal locking (git-fixes).
- ALSA: hda/realtek - Add quirk for the bass speaker on Lenovo
  Yoga X1 7th gen (git-fixes).
- ALSA: hda/realtek - Set EAPD control to default for ALC222
  (git-fixes).
- ASoC: topology: Prevent use-after-free in
  snd_soc_get_pcm_runtime() (git-fixes).
- ASoC: fsl_audmix: add missed pm_runtime_disable (git-fixes).
- ASoC: stm32: spdifrx: fix input pin state management
  (git-fixes).
- ASoC: stm32: spdifrx: fix race condition in irq handler
  (git-fixes).
- ASoC: stm32: spdifrx: fix inconsistent lock state (git-fixes).
- ASoC: soc-core: Set dpcm_playback / dpcm_capture (git-fixes).
- ASoC: SOF: fix fault at driver unload after failed probe
  (git-fixes).
- ALSA: usb-audio: Apply the sample rate quirk for Bose Companion
  5 (git-fixes).
- ALSA: hda/realtek - Add new codec supported for ALCS1200A
  (git-fixes).
- commit 2b19b57
* Mon Jan 13 2020 ptesarik@suse.cz
- Delete outdated kmsg patches:
  - patches.suse/s390-sles15sp1-kmsg-update-2019-01-10.patch
  - patches.suse/s390-sles15sp1-kmsg-update-2019-03-08.patch
  - patches.suse/s390-sles15-00-04-04-kmsg-add-VNIC-Characteristics-msg-documentation.patch
- commit 687aa24
* Mon Jan 13 2020 jroedel@suse.de
- iommu/vt-d: Unlink device if failed to add to group
  (bsc#1160752).
- iommu: Remove device link to group on failure (bsc#1160750).
- iommu/vt-d: Fix adding non-PCI devices to Intel IOMMU
  (bsc#1160751).
- commit 0ea0858
* Mon Jan 13 2020 glin@suse.com
- bpf: Fix passing modified ctx to ld/abs/ind instruction
  (bsc#1155518).
- bpf: cgroup: prevent out-of-order release of cgroup bpf
  (bsc#1155518).
- commit 0a9f272
* Mon Jan 13 2020 hare@suse.de
- megaraid_sas: fixup MSIx interrupt setup during resume
  (bsc#1160647).
- commit c59143f
* Mon Jan 13 2020 clin@suse.com
- devpts_pty_kill(): don't bother with d_delete() (jsc#SLE-9943).
- commit 7312898
* Fri Jan 10 2020 ptesarik@suse.cz
- Update config options that were missing on arm64 in commit
  7dd255172f6798f5ec3ab63db55384fbd980125e (bsc#1158776).
- commit 597cc24
* Fri Jan 10 2020 ptesarik@suse.cz
- Set CONFIG_LOG_CPU_MAX_BUF_SHIFT=12 on arm64 (bsc#1158776).
- commit 855731d
* Fri Jan 10 2020 ptesarik@suse.cz
- Enable CONFIG_VMAP_STACK on arm64 (bsc#1158776).
- commit 51f78da
* Fri Jan 10 2020 ptesarik@suse.cz
- Disable CONFIG_PCCARD on arm64 (bsc#1158776).
- commit 04bc6eb
* Fri Jan 10 2020 nsaenzjulienne@suse.de
- supported.conf: Enable mdio-bcm-unimac (bsc#1160310)
  Needed in order for Raspberry Pi 4's ethernet port to work.
- commit 8c2fc6c
* Fri Jan 10 2020 jeyu@suse.de
- export: avoid code duplication in include/linux/export.h
  (jsc#SLE-10158).
- modpost: remove unneeded local variable in contains_namespace()
  (jsc#SLE-10158).
- scripts/nsdeps: support nsdeps for external module builds
  (jsc#SLE-10158).
  Refresh	patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
- modpost: dump missing namespaces into a single modules.nsdeps
  file (jsc#SLE-10158).
  Refresh	patches.suse/supported-flag
- modpost: free ns_deps_buf.p after writing ns_deps files
  (jsc#SLE-10158).
- modpost: do not invoke extra modpost for nsdeps (jsc#SLE-10158).
  Refresh
  patches.suse/supported-flag
  patches.suse/supported-flag-external
- scripts/nsdeps: make sure to pass all module source files to
  spatch (jsc#SLE-10158).
- scripts/nsdeps: use alternative sed delimiter (jsc#SLE-10158).
- symbol namespaces: revert to previous __ksymtab name scheme
  (jsc#SLE-10158).
- modpost: make updating the symbol namespace explicit
  (jsc#SLE-10158).
- modpost: delegate updating namespaces to separate function
  (jsc#SLE-10158).
- doc: move namespaces.rst from kbuild/ to core-api/
  (jsc#SLE-10158).
- nsdeps: make generated patches independent of locale
  (jsc#SLE-10158).
- nsdeps: fix hashbang of scripts/nsdeps (jsc#SLE-10158).
- kbuild: fix build error of 'make nsdeps' in clean tree
  (jsc#SLE-10158).
- module: rename __kstrtab_ns_* to __kstrtabns_* to avoid symbol
  conflict (jsc#SLE-10158).
- modpost: fix broken sym->namespace for external module builds
  (jsc#SLE-10158).
- module: swap the order of symbol.namespace (jsc#SLE-10158).
- scripts: add_namespace: Fix coccicheck failed (jsc#SLE-10158).
- module: Fix link failure due to invalid relocation on namespace
  offset (jsc#SLE-10158).
- usb-storage: export symbols in USB_STORAGE namespace
  (jsc#SLE-10158).
- usb-storage: remove single-use define for debugging
  (jsc#SLE-10158).
- docs: Add documentation for Symbol Namespaces (jsc#SLE-10158).
- scripts: Coccinelle script for namespace dependencies
  (jsc#SLE-10158).
  Refresh
  patches.suse/supported-flag
  patches.suse/supported-flag-external
- modpost: add support for generating namespace dependencies
  (jsc#SLE-10158).
  Refresh	patches.suse/supported-flag
- export: allow definition default namespaces in Makefiles or
  sources (jsc#SLE-10158).
- module: add config option MODULE_ALLOW_MISSING_NAMESPACE_IMPORTS
  (jsc#SLE-10158).
  Refresh configs (add MODULE_ALLOW_MISSING_NAMESPACE_IMPORTS=n).
- modpost: add support for symbol namespaces (jsc#SLE-10158).
  Refresh	patches.suse/livepatch-modpost-ignore-unresolved-symbols.patch
- module: add support for symbol namespaces (jsc#SLE-10158).
- export: explicitly align struct kernel_symbol (jsc#SLE-10158).
- module: support reading multiple values per modinfo tag
  (jsc#SLE-10158).
- commit 4ff553d
* Fri Jan 10 2020 ptesarik@suse.cz
- Enable CONFIG_SECURITY_DMESG_RESTRICT on arm64 (bsc#1158776).
- commit 08863e8
* Fri Jan 10 2020 mkubecek@suse.cz
- supported.conf: fix order of the entries
- commit 8e2c146
* Fri Jan 10 2020 hare@suse.de
- scsi: add 'disable_async_probing' module argument
  (jsc#SLE-11117,bsc#1156954).
- drivers/base: implement dev_enable_async_probe()
  (jsc#SLE-11117,bsc#1156954).
- commit cbc6624
* Fri Jan 10 2020 jlee@suse.com
- Update config files. (bsc#1160067)
  Disable CONFIG_KEYS_REQUEST_CACHE.
  The CONFIG_KEYS_REQUEST_CACHE adds a cache in task_struct for the result
  of request_key(). But it causes kernel NULL pointer dereference problem
  when we run the long-run testing by the request_key03 test case in LTP.
  The issue can be reproduced on v5.3 mainline kernel and later, even on
  v5.5-rc kernel. The CONFIG_KEYS_REQUEST_CACHE be introduced by
  7743c48e54ee9be9c patch since v5.3 kernel:
  commit 7743c48e54ee9be9c799cbf3b8e3e9f2b8d19e72
  Author: David Howells <dhowells@redhat.com>
  Date:   Wed Jun 19 16:10:15 2019 +0100
    keys: Cache result of request_key*() temporarily in task_struct
  Before this issue be fixed on kernel upstream, Let's disable the
  CONFIG_KEYS_REQUEST_CACHE function on SLE15-SP2 on all architecture.
- commit f6f29a6
* Thu Jan  9 2020 lduncan@suse.com
- scsi: libsas: stop discovering if oob mode is disconnected
  (CVE-2019-19965 bsc#1159911).
- commit 0bb4d37
* Thu Jan  9 2020 tiwai@suse.de
- serial: sprd: Add clearing break interrupt operation
  (git-fixes).
- staging/wlan-ng: add CRC32 dependency in Kconfig (git-fixes).
- usb: gadget: fix wrong endpoint desc (git-fixes).
- selftests: breakpoints: Fix a typo of function name (git-fixes).
- commit 1096b35
* Thu Jan  9 2020 tiwai@suse.de
- samples/seccomp: Zero out members based on seccomp_notif_sizes
  (git-fixes).
- rseq/selftests: Fix: Namespace gettid() for compatibility with
  glibc 2.30 (git-fixes).
- samples/trace_printk: Wait for IRQ work to finish (git-fixes).
- samples: pktgen: fix proc_cmd command result check logic
  (git-fixes).
- commit 168e639
* Thu Jan  9 2020 tiwai@suse.de
- rpmsg: glink: Free pending deferred work on remove (git-fixes).
- rpmsg: glink: Don't send pending rx_done during remove
  (git-fixes).
- rpmsg: glink: Fix rpmsg_register_device err handling
  (git-fixes).
- rpmsg: glink: Put an extra reference during cleanup (git-fixes).
- rpmsg: glink: Fix use after free in open_ack TIMEOUT case
  (git-fixes).
- rpmsg: glink: Fix reuse intents memory leak issue (git-fixes).
- rpmsg: glink: Set tail pointer to 0 at end of FIFO (git-fixes).
- commit eefcc8c
* Thu Jan  9 2020 tiwai@suse.de
- ptp: fix the race between the release of ptp_clock and cdev
  (git-fixes).
- phy: renesas: phy-rcar-gen2: Fix the array off by one warning
  (git-fixes).
- PM / hibernate: memory_bm_find_bit(): Tighten node optimisation
  (git-fixes).
- commit 8fdacf8
* Thu Jan  9 2020 ptesarik@suse.cz
- s390/qeth: fix initialization on old HW (bsc#1160228
  LTC#183076).
- commit 4565d24
* Thu Jan  9 2020 tiwai@suse.de
- media: pulse8-cec: fix lost cec_transmit_attempt_done() call
  (git-fixes).
- media: cec: avoid decrementing transmit_queue_sz if it is 0
  (git-fixes).
- media: cec: CEC 2.0-only bcast messages were ignored
  (git-fixes).
- net: phy: aquantia: add suspend / resume ops for AQR105
  (git-fixes).
- gpiolib: fix up emulated open drain outputs (git-fixes).
- net: usb: lan78xx: Fix error message format specifier
  (git-fixes).
- net: usb: lan78xx: Fix suspend/resume PHY register access error
  (git-fixes).
- iio: st_accel: Fix unused variable warning (git-fixes).
- net: phy: dp83867: enable robust auto-mdix (git-fixes).
- commit 9ace80b
* Thu Jan  9 2020 ptesarik@suse.cz
- s390/qeth: fix dangling IO buffers after halt/clear (bsc#1160227
  LTC#183077).
- commit 889634e
* Thu Jan  9 2020 tiwai@suse.de
- drm/amdgpu/smu: add metrics table lock for vega20 (v2)
  (git-fixes).
- drm/amdgpu/smu: add metrics table lock for navi (v2)
  (git-fixes).
- drm/amdgpu/smu: add metrics table lock (git-fixes).
- commit c292740
* Thu Jan  9 2020 tiwai@suse.de
- drm/amd/display: Reset steer fifo before unblanking the stream
  (git-fixes).
- drm/amd/display: Change the delay time before enabling FEC
  (git-fixes).
- drm/amd/display: Fixed kernel panic when booting with DP-to-HDMI
  dongle (git-fixes).
- drm/amdgpu: add cache flush workaround to gfx8 emit_fence
  (git-fixes).
- drm/amdgpu: add check before enabling/disabling broadcast mode
  (git-fixes).
- drm/nouveau/kms/nv50-: fix panel scaling (git-fixes).
- drm/nouveau: Fix drm-core using atomic code-paths on pre-nv50
  hardware (git-fixes).
- drm/nouveau: Move the declaration of struct nouveau_conn_atom
  up a bit (git-fixes).
- drm/i915/execlists: Fix annotation for decoupling virtual
  request (git-fixes).
- ath9k_htc: Discard undersized packets (git-fixes).
- ath9k_htc: Modify byte order for an error message (git-fixes).
- commit bd77fbc
* Thu Jan  9 2020 tiwai@suse.de
- ata: ahci_brcm: Add missing clock management during recovery
  (git-fixes).
- ata: ahci_brcm: BCM7425 AHCI requires AHCI_HFLAG_DELAY_ENGINE
  (git-fixes).
- ata: ahci_brcm: Fix AHCI resources management (git-fixes).
- ata: libahci_platform: Export again
  ahci_platform_<en/dis>able_phys() (git-fixes).
- commit 02d31e9
* Thu Jan  9 2020 mbenes@suse.cz
- s390/ftrace: save traced function caller (jsc#SLE-11050).
- commit df15586
* Thu Jan  9 2020 mbenes@suse.cz
- s390/unwind: stop gracefully at user mode pt_regs in irq stack
  (jsc#SLE-11050).
- commit cb8ad0f
* Thu Jan  9 2020 msuchanek@suse.de
- drivers/base/memory.c: cache blocks in radix tree to accelerate
  lookup (bsc#1159955 ltc#182993).
- commit a6f9349
* Wed Jan  8 2020 ailiopoulos@suse.com
- xfs: fix missed wakeup on l_flush_wait (git-fixes).
- commit b398e15
* Wed Jan  8 2020 ailiopoulos@suse.com
- iomap: iomap that extends beyond EOF should be marked dirty
  (git-fixes).
- commit 1ec5fb2
* Wed Jan  8 2020 ailiopoulos@suse.com
- xfs: use bitops interface for buf log item AIL flag check
  (git-fixes).
- commit 245f9d1
* Wed Jan  8 2020 ailiopoulos@suse.com
- xfs: change the seconds fields in xfs_bulkstat to signed
  (git-fixes).
- commit 225e4fb
* Wed Jan  8 2020 tiwai@suse.de
- tpm: Handle negative priv->response_len in tpm_common_read()
  (git-fixes).
- commit f84106a
* Wed Jan  8 2020 nsaenzjulienne@suse.de
- supported.conf: enable Raspberry Pi cpufreq driver (bsc#1160461).
  These drivers are required in order to enable CPU frequency scaling on
  the Raspberry Pi family of boards.
- commit 248458d
* Wed Jan  8 2020 tiwai@suse.de
- libertas: Fix two buffer overflows at parsing bss descriptor
  (CVE-2019-14896 bsc#1157157 CVE-2019-14897 bsc#1157155).
- commit 7117d1b
* Wed Jan  8 2020 yousaf.kaukab@suse.com
- PCI: mobiveil: Add PCIe Gen4 RC driver for NXP Layerscape SoCs (bsc#1161495).
- dt-bindings: PCI: Add NXP Layerscape SoCs PCIe Gen4 controller (bsc#1161495).
- PCI: mobiveil: Add 8-bit and 16-bit CSR register accessors (bsc#1161495).
- PCI: mobiveil: Make mobiveil_host_init() can be used to re-init host (bsc#1161495).
- PCI: mobiveil: Add callback function for link up check (bsc#1161495).
- PCI: mobiveil: Add callback function for interrupt initialization (bsc#1161495).
- PCI: mobiveil: Modularize the Mobiveil PCIe Host Bridge IP driver (bsc#1161495).
- PCI: mobiveil: Collect the interrupt related operations into a routine (bsc#1161495).
- PCI: mobiveil: Move the host initialization into a routine (bsc#1161495).
- PCI: mobiveil: Re-abstract the private structure (bsc#1161495).
- commit 3a1031d
* Wed Jan  8 2020 yousaf.kaukab@suse.com
- PCI: mobiveil: Fix csr_read()/write() build issue (bsc#1161495).
- commit 201a79d
* Wed Jan  8 2020 yousaf.kaukab@suse.com
- arm64: PCI: mobiveil: remove patchset v8
  References: bsc#1161495
  Prepare to backport patchset v9
- Delete
  patches.suse/PCI-mobiveil-Add-8-bit-and-16-bit-CSR-register-acces.patch.
- Delete
  patches.suse/PCI-mobiveil-Add-PCIe-Gen4-RC-driver-for-NXP-Layersc.patch.
- Delete
  patches.suse/PCI-mobiveil-Make-mobiveil_host_init-can-be-used-to-.patch.
- Delete
  patches.suse/PCI-mobiveil-Refactor-Mobiveil-PCIe-Host-Bridge-IP-d.patch.
- Refresh
  patches.suse/pci-brcmstb-add-broadcom-stb-pcie-host-controller-driver.patch.
- Refresh
  config/arm64/default
- commit 85f695c
* Wed Jan  8 2020 jroedel@suse.de
- iommu: Don't use sme_active() in generic code (bsc#1160320).
- commit c7574c0
* Wed Jan  8 2020 fdmanana@suse.com
- Btrfs: fix block group remaining RO forever after error during
  device replace (bsc#1160442).
- commit 3e5a343
* Wed Jan  8 2020 jroedel@suse.de
- Update patches.suse/iommu-vt-d-fix-dmar-pte-read-access-not-set-error
  (bsc#1160141, bsc#1159594, bsc#1159592).
- commit 0cb2587
* Wed Jan  8 2020 jroedel@suse.de
- Documentation: Update Documentation for iommu.passthrough
  (bsc#1160320).
- iommu: Disable passthrough mode when SME is active
  (bsc#1160320).
- iommu: Set default domain type at runtime (bsc#1160320).
- iommu: Print default domain type on boot (bsc#1160320).
- ia64: Get rid of iommu_pass_through (bsc#1160320).
- x86/dma: Get rid of iommu_pass_through (bsc#1160320).
- iommu/vt-d: Request passthrough mode from IOMMU core
  (bsc#1160320).
- iommu/amd: Request passthrough mode from IOMMU core
  (bsc#1160320).
- iommu: Use Functions to set default domain type in
  iommu_set_def_domain_type() (bsc#1160320).
- iommu: Add helpers to set/get default domain type (bsc#1160320).
- iommu: Remember when default domain type was set on kernel
  command line (bsc#1160320).
- commit fbe5ae4
* Wed Jan  8 2020 mkubecek@suse.cz
- Disable patches.suse/Documentation-ABI-mark-sys-kernel-fadump_-sysfs-file.patch
  For some reason, these changes result in "make htmldocs" stuck indefinitely
  so that kernel-docs fails to build. Whether it's a sphinx bug or some ReST
  formatting problem (or combination of both), more time will be needed to
  find a proper solution. As the offending patch touches only documentation,
  disable it for now so that we do not block Beta2 submission.
- commit ab61608
* Wed Jan  8 2020 tiwai@suse.de
- drm/sun4i: hdmi: Remove duplicate cleanup calls (git-fixes).
- drm/i915/gvt: Pin vgpu dma address before using (git-fixes).
- drm/i915/gvt: use vgpu lock for active state setting
  (git-fixes).
- drm/i915: Fix pid leak with banned clients (git-fixes).
- drm/i915/gem: Keep request alive while attaching fences
  (git-fixes).
- drm/i915: Fix WARN_ON condition for cursor plane ddb allocation
  (git-fixes).
- drm/i915: Set fence_work.ops before dma_fence_init (git-fixes).
- drm/i915/fbc: Disable fbc by default on all glk+ (git-fixes).
- drm/radeon: fix r1xx/r2xx register checker for POT textures
  (git-fixes).
- drm/amd/display: re-enable wait in pipelock, but add timeout
  (git-fixes).
- drm: limit to INT_MAX in create_blob ioctl (git-fixes).
- drm/amdgpu/gfx10: explicitly wait for cp idle after halt/unhalt
  (git-fixes).
- drm/amdgpu: Avoid accidental thread reactivation (git-fixes).
- drm/amdgpu: fix potential double drop fence reference
  (git-fixes).
- drm/amdgpu: disallow direct upload save restore list from gfx
  driver (git-fixes).
- drm/amd/display: correctly populate dpp refclk in fpga
  (git-fixes).
- drm/tegra: sor: Use correct SOR index on Tegra210 (git-fixes).
- drm/nouveau: Don't grab runtime PM refs for HPD IRQs
  (git-fixes).
- drm/gma500: fix memory disclosures due to uninitialized bytes
  (git-fixes).
- drm/bridge: dw-hdmi: Restore audio when setting a mode
  (git-fixes).
- drm/drm_vblank: Change EINVAL by the correct errno (git-fixes).
- drm/amdgpu: fix amdgpu trace event print string format error
  (git-fixes).
- drm/amd/powerplay: avoid disabling ECC if RAS is enabled for
  VEGA20 (git-fixes).
- drm/amd/display: Fix dongle_caps containing stale information
  (git-fixes).
- drm/amd/display: Program DWB watermarks from correct state
  (git-fixes).
- drm/amd/display: wait for set pipe mcp command completion
  (git-fixes).
- drm/amd/display: Properly round nominal frequency for SPD
  (git-fixes).
- drm/amdkfd: Fix MQD size calculation (git-fixes).
- drm/amdgpu: fix uninitialized variable pasid_mapping_needed
  (git-fixes).
- drm/amd/powerplay: A workaround to GPU RESET on APU (git-fixes).
- drm/amdkfd: fix a potential NULL pointer dereference (v2)
  (git-fixes).
- drm/amd/display: Set number of pipes to 1 if the second pipe
  was disabled (git-fixes).
- drm/amd/display: Handle virtual signal type in disable_link()
  (git-fixes).
- drm/amdgpu: grab the id mgr lock while accessing passid_mapping
  (git-fixes).
- drm/amdgpu/sriov: add ring_stop before ring_create in psp v11
  code (git-fixes).
- drm/amd/display: verify stream link before link test
  (git-fixes).
- drm/bridge: dw-hdmi: Refuse DDC/CI transfers on the internal
  I2C controller (git-fixes).
- drm/sun4i: dsi: Fix TCON DRQ set bits (git-fixes).
- drm/komeda: Workaround for broken FLIP_COMPLETE timestamps
  (git-fixes).
- drm/bridge: analogix-anx78xx: silence -EPROBE_DEFER warnings
  (git-fixes).
- drm: exynos: exynos_hdmi: use cec_notifier_conn_(un)register
  (git-fixes).
- drm/vc4/vc4_hdmi: fill in connector info (git-fixes).
- drm/panel: Add missing drm_panel_init() in panel drivers
  (git-fixes).
- commit a4a0b31
* Wed Jan  8 2020 tbogendoerfer@suse.de
- net/sched: add delete_empty() to filters and use it in
  cls_flower (bsc#1154353).
- tcp: Fix highest_sack and highest_sack_seq (bsc#1154353).
- cxgb4/cxgb4vf: fix flow control display for auto negotiation
  (jsc#SLE-8389).
- mlxsw: spectrum: Use dedicated policer for VRRP packets
  (bsc#1154488).
- mlxsw: spectrum_router: Skip loopback RIFs during MAC validation
  (bsc#1154488).
- net/sched: act_mirred: Pull mac prior redir to non
  mac_header_xmit device (bsc#1154353).
- net_sched: sch_fq: properly set sk->sk_pacing_status
  (bsc#1154353).
- bnx2x: Fix accounting of vlan resources among the PFs
  (bsc#1154395).
- bnx2x: Use appropriate define for vlan credit (bsc#1154395).
- net/mlxfw: Fix out-of-memory error in mfa2 flash burning
  (bsc#1154488).
- sctp: fix err handling of stream initialization (bsc#1154353).
- udp: fix integer overflow while computing available space in
  sk_rcvbuf (bsc#1154353).
- sfc: Include XDP packet headroom in buffer step size
  (jsc#SLE-8314).
- sfc: fix channel allocation with brute force (jsc#SLE-8314).
- net: dst: Force 4-byte alignment of dst_metrics (bsc#1154353).
- net: phy: ensure that phy IDs are correctly typed (bsc#1154353).
- qede: Disable hardware gro when xdp prog is installed
  (jsc#SLE-8401).
- net: ena: fix issues in setting interrupt moderation params
  in ethtool (bsc#1154492).
- net: ena: fix default tx interrupt moderation interval
  (bsc#1154492).
- net: hisilicon: Fix a BUG trigered by wrong bytes_compl
  (bsc#1154353).
- cxgb4: fix refcount init for TC-MQPRIO offload (jsc#SLE-8389).
- net/sched: cls_u32: fix refcount leak in the error path of
  u32_change() (bsc#1154353).
- net, sysctl: Fix compiler warning when only cBPF is present
  (bsc#1154353).
- net/ixgbe: Fix concurrency issues between config flow and XSK
  (jsc#SLE-7979 jsc#SLE-7981).
- net/i40e: Fix concurrency issues between config flow and XSK
  (jsc#SLE-8025).
- net/mlx5e: Fix concurrency issues between config flow and XSK
  (jsc#SLE-8464).
- xsk: Add rcu_read_lock around the XSK wakeup (bsc#1154353).
- net-sysfs: Call dev_hold always in rx_queue_add_kobject
  (bsc#1154353).
- nfp: flower: fix stats id allocation (bsc#1154353).
- net: fix kernel-doc warning in <linux/netdevice.h>
  (bsc#1154353).
- net: annotate lockless accesses to sk->sk_pacing_shift
  (bsc#1154353).
- net: qlogic: Fix error paths in ql_alloc_large_buffers()
  (bsc#1154353).
- sctp: fix memleak on err handling of stream initialization
  (bsc#1154353).
- cxgb4: Fix kernel panic while accessing sge_info (jsc#SLE-8389).
- net: phylink: fix interface passed to mac_link_up (bsc#1154353).
- bnx2x: Fix logic to get total no. of PFs per engine
  (bsc#1154395).
- bnx2x: Do not handle requests from VFs after parity
  (bsc#1154395).
- tcp: refine rule to allow EPOLLOUT generation under mem pressure
  (bsc#1154353).
- tcp: refine tcp_write_queue_empty() implementation
  (bsc#1154353).
- tcp: do not send empty skb from tcp_write_xmit() (bsc#1154353).
- tcp/dccp: fix possible race __inet_lookup_established()
  (bsc#1154353).
- ipv6/addrconf: only check invalid header values when
  NETLINK_F_STRICT_CHK is set (bsc#1154353).
- bnxt: apply computed clamp value for coalece parameter
  (jsc#SLE-8371 bsc#1153274).
- qede: Fix multicast mac configuration (jsc#SLE-8401).
- net: ena: fix napi handler misbehavior when the napi budget
  is zero (bsc#1154492).
- bnxt_en: Add missing devlink health reporters for VFs
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix the logic that creates the health reporters
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Remove unnecessary NULL checks for fw_health
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix bp->fw_health allocation and free logic
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Return error if FW returns more data than dump length
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Free context memory in the open path if firmware has
  been reset (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix MSIX request logic for RDMA driver (jsc#SLE-8371
  bsc#1153274).
- af_packet: set defaule value for tmo (bsc#1154353).
- mlxsw: spectrum_router: Remove unlikely user-triggerable warning
  (bsc#1154488).
- bonding: fix bond_neigh_init() (bsc#1154353).
- neighbour: remove neigh_cleanup() method (bsc#1154353).
- IB/mlx5: Fix device memory flows (jsc#SLE-8446).
- IB/core: Introduce rdma_user_mmap_entry_insert_range() API
  (jsc#SLE-8449).
- IB/mlx5: Fix steering rule of drop and count (jsc#SLE-8446).
- IB/mlx4: Follow mirror sequence of device add during device
  removal (jsc#SLE-8461).
- RDMA/counter: Prevent auto-binding a QP which are not tracked
  with res (jsc#SLE-8449).
- rxe: correctly calculate iCRC for unaligned payloads
  (jsc#SLE-8449).
- RDMA/cma: add missed unregister_pernet_subsys in init failure
  (jsc#SLE-8449).
- net: make socket read/write_iter() honor IOCB_NOWAIT
  (bsc#1154353).
- commit ad46b33
* Tue Jan  7 2020 dwagner@suse.de
- scsi: qla2xxx: Use get_unaligned_*() instead of open-coding
  these functions (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix the endianness of the qla82xx_get_fw_size()
  return type (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Improve readability of the code that handles
  qla_flt_header (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Update driver version to 10.01.00.22-k
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix mtcp dump collection failure (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix stuck session in GNL (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix RIDA Format-2 (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Consolidate fabric scan (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Correct fcport flags handling (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix stuck login session using prli_pend_timer
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use common routine to free fcport struct
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add D-Port Diagnostic reason explanation logs
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix update_fcport for current_topology
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Cleanup unused async_logout_done (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add a shadow variable to hold disc_state history
  of fcport (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix fabric scan hang (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Remove defer flag to indicate immeadiate port
  loss (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix qla2x00_request_irqs() for MSI (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: unregister ports after GPN_FT failure
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: fix rports not being mark as lost in sync fabric
  scan (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- commit c04a5b0
* Tue Jan  7 2020 msuchanek@suse.de
- Make lzo the default pstore compression method (bsc#1159986).
  Pstore has compression enabled, pstore is built-in, pstore default
  compression is deflate, deflate is modular -> pstore initialization
  fails on boot. Switch default compression to lzo which is built-in and
  the only built-in method on SLE15.
- commit f26faac
* Tue Jan  7 2020 tiwai@suse.de
- watchdog: tqmx86_wdt: Fix build error (git-fixes).
- watchdog: Fix the race between the release of watchdog_core_data
  and cdev (git-fixes).
- commit 0917c4e
* Tue Jan  7 2020 tiwai@suse.de
- tty/serial: atmel: fix out of range clock divider handling
  (git-fixes).
- tty: serial: msm_serial: Fix lockup for sysrq and oops
  (git-fixes).
- usb: xhci: Fix build warning seen with CONFIG_PM=n (git-fixes).
- usbip: Fix error path of vhci_recv_ret_submit() (git-fixes).
- USB: EHCI: Do not return -EPIPE when hub is disconnected
  (git-fixes).
- xhci-pci: Allow host runtime PM as default also for Intel Ice
  Lake xHCI (git-fixes).
- usb: usbfs: Suppress problematic bind and unbind uevents
  (git-fixes).
- usb: renesas_usbhs: add suspend event support in gadget mode
  (git-fixes).
- commit 5e7bf42
* Tue Jan  7 2020 tiwai@suse.de
- spi: st-ssc4: add missed pm_runtime_disable (git-fixes).
- spi: tegra20-slink: add missed clk_unprepare (git-fixes).
- spi: pxa2xx: Add missed security checks (git-fixes).
- spi: img-spfi: fix potential double release (git-fixes).
- spi: sprd: adi: Add missing lock protection when rebooting
  (git-fixes).
- spi: sifive: disable clk when probe fails and remove
  (git-fixes).
- spi: Add call to spi_slave_abort() function when spidev driver
  is released (git-fixes).
- commit d4280ba
* Tue Jan  7 2020 tiwai@suse.de
- soundwire: intel: fix PDI/stream mapping for Bulk (git-fixes).
- commit befdf94
* Tue Jan  7 2020 tiwai@suse.de
- staging: rtl8188eu: fix possible null dereference (git-fixes).
- staging: rtl8192u: fix multiple memory leaks on error path
  (git-fixes).
- rtlwifi: fix memory leak in rtl92c_set_fw_rsvdpagepkt()
  (git-fixes).
- rtl8xxxu: fix RTL8723BU connection failure issue after warm
  reboot (git-fixes).
- commit 70d7407
* Tue Jan  7 2020 tiwai@suse.de
- regulator: bd70528: Remove .set_ramp_delay for bd70528_ldo_ops
  (git-fixes).
- regulator: axp20x: Fix axp20x_set_ramp_delay (git-fixes).
- regulator: axp20x: Fix AXP22x ELDO2 regulator enable bitmask
  (git-fixes).
- rtc: sun6i: Add support for RTC clocks on R40 (git-fixes).
- riscv: ftrace: correct the condition logic in function graph
  tracer (git-fixes).
- regulator: max8907: Fix the usage of uninitialized variable
  in max8907_regulator_probe() (git-fixes).
- commit d2746d5
* Tue Jan  7 2020 tiwai@suse.de
- qtnfmac: fix invalid channel information output (git-fixes).
- qtnfmac: fix debugfs support for multiple cards (git-fixes).
- qtnfmac: fix using skb after free (git-fixes).
- commit 339b79a
* Tue Jan  7 2020 tiwai@suse.de
- pstore/ram: Write new dumps to start of recycled zones
  (git-fixes).
- pstore/ram: Fix error-path memory leak in persistent_ram_new()
  callers (git-fixes).
- commit a2e4095
* Tue Jan  7 2020 tiwai@suse.de
- platform/x86: pmc_atom: Add Siemens CONNECT X300 to
  critclk_systems DMI table (git-fixes).
- platform/x86: hp-wmi: Make buffer for HPWMI_FEATURE2_QUERY
  128 bytes (git-fixes).
- pinctrl: amd: fix __iomem annotation in amd_gpio_irq_handler()
  (git-fixes).
- pinctrl: sh-pfc: sh7734: Fix duplicate TCLK1_B (git-fixes).
- pinctrl: devicetree: Avoid taking direct reference to device
  name string (git-fixes).
- power: supply: cpcap-battery: Check voltage before
  orderly_poweroff (git-fixes).
- commit d3f5c31
* Tue Jan  7 2020 tiwai@suse.de
- mod_devicetable: fix PHY module format (git-fixes).
- PCI/PM: Always return devices to D0 when thawing (git-fixes).
- parport: load lowlevel driver if ports not found (git-fixes).
- commit 22bfd6f
* Tue Jan  7 2020 tiwai@suse.de
- mmc: sdhci-of-esdhc: re-implement erratum A-009204 workaround
  (git-fixes).
- mmc: sdhci: Add a quirk for broken command queuing (git-fixes).
- mmc: sdhci: Workaround broken command queuing on Intel GLK
  (git-fixes).
- mmc: sdhci-of-esdhc: fix P2020 errata handling (git-fixes).
- mmc: sdhci: Update the tuning failed messages to pr_debug level
  (git-fixes).
- mmc: sdhci-of-esdhc: Revert "mmc: sdhci-of-esdhc: add erratum
  A-009204 support" (git-fixes).
- mmc: mediatek: fix CMD_TA to 2 for MT8173 HS200/HS400 mode
  (git-fixes).
- mmc: sdhci-msm: Correct the offset and value for DDR_CONFIG
  register (git-fixes).
- misc: fastrpc: fix memory leak from miscdev->name (git-fixes).
- mmc: tmio: Add MMC_CAP_ERASE to allow erase/discard/trim
  requests (git-fixes).
- mmc: core: Drop check for mmc_card_is_removable() in
  mmc_rescan() (git-fixes).
- mmc: block: Add CMD13 polling for MMC IOCTLS with R1B response
  (git-fixes).
- mmc: block: Make card_busy_detect() a bit more generic
  (git-fixes).
- commit 028a842
* Tue Jan  7 2020 tiwai@suse.de
- media: cec: check 'transmit_in_progress', not 'transmitting'
  (git-fixes).
- media: vicodec: media_device_cleanup was called too early
  (git-fixes).
- media: vim2m: media_device_cleanup was called too early
  (git-fixes).
- media: v4l2-ctrl: Lock main_hdl on operations of requests_queued
  (git-fixes).
- media: si470x-i2c: add missed operations in remove (git-fixes).
- media: pvrusb2: Fix oops on tear-down when radio support is
  not present (git-fixes).
- media: vivid: media_device_cleanup was called too early
  (git-fixes).
- media: staging/imx: Use a shorter name for driver (git-fixes).
- commit 0e40744
* Tue Jan  7 2020 tiwai@suse.de
- media: v4l2-core: fix touch support in v4l_g_fmt (git-fixes).
- media: smiapp: Register sensor after enabling runtime PM on
  the device (git-fixes).
- media: imx7-mipi-csis: Add a check for devm_regulator_get
  (git-fixes).
- media: st-mipid02: add a check for devm_gpiod_get_optional
  (git-fixes).
- media: ad5820: Define entity function (git-fixes).
- media: ov5640: Make 2592x1944 mode only available at 15 fps
  (git-fixes).
- media: ov6650: Fix stored frame interval not in sync with
  hardware (git-fixes).
- media: aspeed: clear garbage interrupts (git-fixes).
- media: aspeed: set hsync and vsync polarities to normal before
  starting mode detection (git-fixes).
- commit c8cb4cb
* Tue Jan  7 2020 tiwai@suse.de
- media: cedrus: Fix undefined shift with a SHIFT_AND_MASK_BITS
  macro (git-fixes).
- commit 08552bc
* Tue Jan  7 2020 tiwai@suse.de
- media: ti-vpe: vpe: ensure buffers are cleaned up properly in
  abort cases (git-fixes).
- media: ti-vpe: vpe: fix a v4l2-compliance failure about frame
  sequence number (git-fixes).
- media: ti-vpe: vpe: fix a v4l2-compliance failure about invalid
  sizeimage (git-fixes).
- media: ti-vpe: vpe: Make sure YUYV is set as default format
  (git-fixes).
- media: ti-vpe: vpe: fix a v4l2-compliance warning about invalid
  pixel format (git-fixes).
- media: ti-vpe: vpe: fix a v4l2-compliance failure causing a
  kernel panic (git-fixes).
- media: cx88: Fix some error handling path in 'cx8800_initdev()'
  (git-fixes).
- commit b475671
* Tue Jan  7 2020 tiwai@suse.de
- media: cec-funcs.h: add status_req checks (git-fixes).
- media: flexcop-usb: fix NULL-ptr deref in
  flexcop_usb_transfer_init() (git-fixes).
- media: venus: Fix occasionally failures to suspend (git-fixes).
- media: venus: core: Fix msm8996 frequency table (git-fixes).
- media: i2c: ov2659: Fix missing 720p register config
  (git-fixes).
- media: i2c: ov2659: fix s_stream return value (git-fixes).
- media: cedrus: fill in bus_info for media device (git-fixes).
- media: am437x-vpfe: Setting STD to current value is not an error
  (git-fixes).
- media: vimc: Fix gpf in rmmod path when stream is active
  (git-fixes).
- commit 3bdee4e
* Tue Jan  7 2020 tiwai@suse.de
- mac80211: fix TID field in monitor mode transmit (git-fixes).
- mailbox: imx: Clear the right interrupts at shutdown
  (git-fixes).
- mailbox: imx: Fix Tx doorbell shutdown path (git-fixes).
- commit 8428c64
* Tue Jan  7 2020 tiwai@suse.de
- libata: Fix retrieving of active qcs (git-fixes).
- libata: Ensure ata_port probe has completed before detach
  (git-fixes).
- Revert "libata, freezer: avoid block device removal while
  system is frozen" (git-fixes).
- commit aa59034
* Tue Jan  7 2020 tiwai@suse.de
- leds: an30259a: add a check for devm_regmap_init_i2c
  (git-fixes).
- leds: tlc591xx: update the maximum brightness (git-fixes).
- leds: lm3692x: Handle failure to probe the regulator
  (git-fixes).
- iwlwifi: mvm: fix unaligned read of rx_pkt_status (git-fixes).
- commit 03687f9
* Tue Jan  7 2020 tiwai@suse.de
- irqchip: ingenic: Error out if IRQ domain creation failed
  (git-fixes).
- irqchip: Place CONFIG_SIFIVE_PLIC into the menu (git-fixes).
- irqchip/irq-bcm7038-l1: Enable parent IRQ if necessary
  (git-fixes).
- commit b53401c
* Tue Jan  7 2020 tiwai@suse.de
- ipmi: Don't allow device module unload when in use (git-fixes).
- commit 65e80e2
* Tue Jan  7 2020 tiwai@suse.de
- intel_th: Fix freeing IRQs (git-fixes).
- intel_th: pci: Add Elkhart Lake SOC support (git-fixes).
- intel_th: pci: Add Comet Lake PCH-V support (git-fixes).
- commit d2e079e
* Tue Jan  7 2020 tiwai@suse.de
- Input: ili210x - handle errors from input_mt_init_slots()
  (git-fixes).
- Input: st1232 - do not reset the chip too early (git-fixes).
- Input: atmel_mxt_ts - disable IRQ across suspend (git-fixes).
- commit 6ce709b
* Tue Jan  7 2020 tiwai@suse.de
- iio: dac: ad5446: Add support for new AD5600 DAC (git-fixes).
- iio: dln2-adc: fix iio_triggered_buffer_postenable() position
  (git-fixes).
- staging: iio: ad9834: add a check for devm_clk_get (git-fixes).
- iio: adc: max1027: Reset the device at probe time (git-fixes).
- iio: max31856: add missing of_node and parent references to
  iio_dev (git-fixes).
- iio: light: bh1750: Resolve compiler warning and make code
  more readable (git-fixes).
- commit 0b7fbd3
* Tue Jan  7 2020 tiwai@suse.de
- HID: i2c-hid: Send power-on command after reset (git-fixes).
- commit bc0c11b
* Tue Jan  7 2020 tiwai@suse.de
- HID: i2c-hid: Remove runtime power management (git-fixes).
- Refresh
  patches.suse/HID-i2c-hid-Reset-ALPS-touchpads-on-resume.patch.
- commit 8f8c13b
* Tue Jan  7 2020 tiwai@suse.de
- HID: logitech-hidpp: Silence intermittent get_battery_capacity
  errors (git-fixes).
- HID: Improve Windows Precision Touchpad detection (git-fixes).
- HID: rmi: Check that the RMI_STARTED bit is set before
  unregistering the RMI transport device (git-fixes).
- HID: i2c-hid: fix no irq after reset on raydium 3118
  (git-fixes).
- HID: quirks: Add quirk for HP MSU1465 PIXART OEM mouse
  (git-fixes).
- commit 6c8d52d
* Tue Jan  7 2020 tiwai@suse.de
- gpu: host1x: Allocate gather copy for host1x (git-fixes).
- commit fa0dc6d
* Tue Jan  7 2020 tiwai@suse.de
- gpio: xtensa: fix driver build (git-fixes).
- gpio: Fix error message on out-of-range GPIO in lookup table
  (git-fixes).
- gpio: mxc: Only get the second IRQ when there is more than
  one IRQ (git-fixes).
- fsi: core: Fix small accesses and unaligned offsets via sysfs
  (git-fixes).
- commit 40e8be8
* Tue Jan  7 2020 tiwai@suse.de
- fjes: fix missed check in fjes_acpi_add (git-fixes).
- firmware_loader: Fix labels with comma for builtin firmware
  (git-fixes).
- fbtft: Make sure string is NULL terminated (git-fixes).
- extcon: sm5502: Reset registers during initialization
  (git-fixes).
- commit c1f6bcd
* Tue Jan  7 2020 tiwai@suse.de
- dpaa_eth: fix DMA mapping leak (git-fixes).
- dpaa2-ptp: fix double free of the ptp_qoriq IRQ (git-fixes).
- dpaa2-eth: Fix TX FQID values (git-fixes).
- commit 7ad103e
* Tue Jan  7 2020 tiwai@suse.de
- dmaengine: virt-dma: Fix access after free in vchan_complete()
  (git-fixes).
- dmaengine: Fix access to uninitialized dma_slave_caps
  (git-fixes).
- dmaengine: xilinx_dma: Clear desc_pendingcount in
  xilinx_dma_reset (git-fixes).
- dma-debug: add a schedule point in debug_dma_dump_mappings()
  (git-fixes).
- dma-mapping: Add vmap checks to dma_map_single() (git-fixes).
- commit edbb98f
* Tue Jan  7 2020 tiwai@suse.de
- staging: comedi: gsc_hpdi: check dma_alloc_coherent() return
  value (git-fixes).
- counter: stm32-lptimer-cnt: fix a kernel-doc warning
  (git-fixes).
- counter: stm32-timer-cnt: fix a kernel-doc warning (git-fixes).
- commit 5f1dabd
* Tue Jan  7 2020 tiwai@suse.de
- clocksource: riscv: add notrace to riscv_sched_clock
  (git-fixes).
- clk: Move clk_core_reparent_orphans() under CONFIG_OF
  (git-fixes).
- clk: imx: pll14xx: fix clk_pll14xx_wait_lock (git-fixes).
- clk: imx: clk-imx7ulp: Add missing sentinel of ulp_div_table
  (git-fixes).
- clk: imx: clk-composite-8m: add lock to gate/mux (git-fixes).
- clk: walk orphan list on clock provider registration
  (git-fixes).
- clocksource/drivers/asm9260: Add a check for of_clk_get
  (git-fixes).
- clocksource/drivers/timer-of: Use unique device name instead
  of timer (git-fixes).
- clk: clk-gpio: propagate rate change to parent (git-fixes).
- clk: qcom: Allow constant ratio freq tables for rcg (git-fixes).
- commit c3af1c4
* Tue Jan  7 2020 tiwai@suse.de
- can: flexcan: poll MCR_LPM_ACK instead of GPR ACK for stop
  mode acknowledgment (git-fixes).
- can: flexcan: add low power enter/exit acknowledgment helper
  (git-fixes).
- can: flexcan: fix possible deadlock and out-of-order reception
  after wakeup (git-fixes).
- can: xilinx_can: Fix missing Rx can packets on CANFD2.0
  (git-fixes).
- cdrom: respect device capabilities during opening action
  (git-fixes).
- commit 6b25029
* Tue Jan  7 2020 tiwai@suse.de
- brcmfmac: remove monitor interface when detaching (git-fixes).
- Bluetooth: Fix advertising duplicated flags (git-fixes).
- Bluetooth: Workaround directed advertising bug in Broadcom
  controllers (git-fixes).
- Bluetooth: missed cpu_to_le16 conversion in hci_init4_req
  (git-fixes).
- commit b42e335
* Tue Jan  7 2020 tiwai@suse.de
- ath10k: Revert "ath10k: add cleanup in ath10k_sta_state()"
  (git-fixes).
- ath10k: fix get invalid tx rate for Mesh metric (git-fixes).
- ath10k: fix offchannel tx failure when no
  ath10k_mac_tx_frm_has_freq (git-fixes).
- ath10k: fix backtrace on coredump (git-fixes).
- ath10k: add cleanup in ath10k_sta_state() (git-fixes).
- commit bb2872b
* Tue Jan  7 2020 tiwai@suse.de
- ASoC: SOF: enable sync_write in hdac_bus (git-fixes).
- Refresh
  patches.suse/Revert-ASoC-SOF-Force-polling-mode-on-CFL-and-CNL.patch.
- commit 64ac0e6
* Tue Jan  7 2020 tiwai@suse.de
- ARM: tegra: Fix FLOW_CTLR_HALT register clobbering by
  tegra_resume() (git-fixes).
- ASoC: wm5100: add missed pm_runtime_disable (git-fixes).
- ASoC: wm2200: add missed operations in remove and probe failure
  (git-fixes).
- ASoC: Intel: kbl_rt5663_rt5514_max98927: Add dmic format
  constraint (git-fixes).
- ASoC: rt5677: Mark reg RT5677_PWR_ANLG2 as volatile (git-fixes).
- ASoC: Intel: bytcr_rt5640: Update quirk for Acer Switch 10
  SW5-012 2-in-1 (git-fixes).
- ASoC: wm8904: fix regcache handling (git-fixes).
- ASoC: SOF: topology: set trigger order for FE DAI link
  (git-fixes).
- commit 6a5428c
* Tue Jan  7 2020 tiwai@suse.de
- ALSA: hda/realtek - Enable the bass speaker of ASUS UX431FLC
  (git-fixes).
- ALSA: ice1724: Fix sleep-in-atomic in Infrasonic Quartet
  support code (git-fixes).
- ALSA: hda/realtek - Add Bass Speaker and fixed dac for bass
  speaker (git-fixes).
- ALSA: hda - Apply sync-write workaround to old Intel platforms,
  too (git-fixes).
- ALSA: hda/hdmi - fix atpx_present when CLASS is not VGA
  (git-fixes).
- ALSA: usb-audio: fix set_format altsetting sanity check
  (git-fixes).
- ALSA: hda/realtek - Add headset Mic no shutup for ALC283
  (git-fixes).
- ALSA: usb-audio: set the interface format after resume on Dell
  WD19 (git-fixes).
- 6pack,mkiss: fix possible deadlock (git-fixes).
- ALSA: bebob: expand sleep just after breaking connections for
  protocol version 1 (git-fixes).
- ACPI: button: Add DMI quirk for Medion Akoya E2215T (git-fixes).
- commit e88e392
* Tue Jan  7 2020 tbogendoerfer@suse.de
- ice: Add device ids for E822 devices (bsc#1157177).
- commit 0246f5b
* Tue Jan  7 2020 tbogendoerfer@suse.de
- net: marvell: mvpp2: phylink requires the link interrupt
  (bsc#1117016).
- Delete
  patches.suse/net-mvpp2-fix-condition-for-setting-up-link-interrup.patch.
- commit 8787cfd
* Tue Jan  7 2020 mbenes@suse.cz
- blacklist.conf: 1d8f65798240 ("riscv: ftrace: correct the condition logic in function graph tracer")
  RISCV architecture is not supported.
- commit 2dbbf0b
* Tue Jan  7 2020 mbenes@suse.cz
- tracing: Fix endianness bug in histogram trigger (bsc#1160231).
- commit d1849ae
* Tue Jan  7 2020 mbenes@suse.cz
- tracing: Fix lock inversion in trace_event_enable_tgid_record()
  (bsc#1160229).
- commit 4a84dfe
* Tue Jan  7 2020 tiwai@suse.de
- Move the upstreamed mwifiex fix patches into sorted section
  Refresh tags:
  patches.suse/mwifiex-Fix-heap-overflow-in-mmwifiex_process_tdls_a.patch
  patches.suse/mwifiex-fix-possible-heap-overflow-in-mwifiex_proces.patch
- commit 19bf98d
* Tue Jan  7 2020 tiwai@suse.de
- USB: Fix: Don't skip endpoint descriptors with maxpacket=0
  (bsc#1159811).
- commit 0c3dbbc
* Tue Jan  7 2020 tiwai@suse.de
- tpm: Revert "tpm_tis_core: Turn on the TPM before probing IRQ's"
  (bsc#1159152).
- tpm: Revert "tpm_tis_core: Set TPM_CHIP_FLAG_IRQ before probing
  for interrupts" (bsc#1159152).
- tpm: Revert "tpm_tis: reserve chip for duration of
  tpm_tis_core_init" (bsc#1159152).
- commit cd1e368
* Tue Jan  7 2020 mbenes@suse.cz
- tracing: Have the histogram compare functions convert to u64
  first (bsc#1160215).
- commit db2127f
* Tue Jan  7 2020 mbenes@suse.cz
- tracing: Avoid memory leak in process_system_preds()
  (bsc#1160214).
- commit d628f71
* Tue Jan  7 2020 mkubecek@suse.cz
- config: refresh
  Drop EFI_RCI2_TABLE on arm64 (no longer available).
- commit 18cf2ea
* Tue Jan  7 2020 mkubecek@suse.cz
- fix mainline references
  Fix Patch-mainline:
  patches.suse/btrfs-simplify-inode-locking-for-RWF_NOWAIT.patch
  patches.suse/mm-set-S_SWAPFILE-on-blockdev-swap-devices.patch
  patches.suse/vfs-dont-allow-writes-to-swap-files.patch
- commit a590c11
* Tue Jan  7 2020 ghe@suse.com
- ocfs2: fix the crash due to call ocfs2_get_dlm_debug once less
  (bsc#1158632).
- commit 9a7b95a
* Mon Jan  6 2020 rgoldwyn@suse.com
- btrfs: simplify inode locking for RWF_NOWAIT  (git-fixes).
- commit f4e2cf3
* Mon Jan  6 2020 rgoldwyn@suse.com
- vfs: don't allow writes to swap files  (bsc#1158633).
- Refresh patches.suse/vfs-add-super_operations-get_inode_dev.
- commit 4523846
* Mon Jan  6 2020 rgoldwyn@suse.com
- mm: set S_SWAPFILE on blockdev swap devices  (bsc#1158633).
- commit 84b8de8
* Mon Jan  6 2020 jroedel@suse.de
- blacklist.conf: Add da3cc91b8db4 iommu/mediatek: Add a new tlb_lock for tlb_flush
- commit 615be85
* Mon Jan  6 2020 jroedel@suse.de
- iommu/vt-d: Remove incorrect PSI capability check (bsc#1160142).
- iommu/vt-d: Allocate reserved region for ISA with correct
  permission (bsc#1160140).
- iommu: set group default domain before creating direct mappings
  (bsc#1160139).
- iommu/vt-d: Fix dmar pte read access not set error
  (bsc#1160141).
- iommu/vt-d: Set ISA bridge reserved region as relaxable
  (bsc#1160143).
- iommu/iova: Init the struct iova to fix the possible memleak
  (bsc#1160137).
- iommu/arm-smmu: Remove duplicate error message (bsc#1160135).
- iommu/arm-smmu-v3: Don't display an error when IRQ lines are
  missing (bsc#1160136).
- iommu/mediatek: Correct the flush_iotlb_all callback
  (bsc#1160138).
- commit 2cdf724
* Mon Jan  6 2020 msuchanek@suse.de
- powerpc/tools: Don't quote $objdump in scripts (bsc#1065729).
- commit 82d4ed4
* Mon Jan  6 2020 msuchanek@suse.de
- powerpc/pseries: Drop pointless static qualifier in
  vpa_debugfs_init() (FATE#326394 git-fixes).
- commit 2cd1f04
* Mon Jan  6 2020 msuchanek@suse.de
- powerpc/spinlocks: Include correct header for static key
  (bsc#1160010 ltc#183046).
- commit 3e6e518
* Mon Jan  6 2020 msuchanek@suse.de
- powerpc/fadump: sysfs for fadump memory reservation (bsc#1160018
  ltc#182902 jsc#SLE-9099).
- Documentation/ABI: mark /sys/kernel/fadump_* sysfs files
  deprecated (bsc#1160018 ltc#182902 jsc#SLE-9099).
- powerpc/powernv: move core and fadump_release_opalcore under
  new kobject (bsc#1160018 ltc#182902 jsc#SLE-9099).
- powerpc/fadump: reorganize /sys/kernel/fadump_* sysfs files
  (bsc#1160018 ltc#182902 jsc#SLE-9099).
- sysfs: wrap __compat_only_sysfs_link_entry_to_kobj function to
  change the symlink name (bsc#1160018 ltc#182902 jsc#SLE-9099).
- Documentation/ABI: add ABI documentation for
  /sys/kernel/fadump_* (bsc#1160018 ltc#182902 jsc#SLE-9099).
- commit 3b5b7c0
* Mon Jan  6 2020 msuchanek@suse.de
- powerpc/shared: Use static key to detect shared processor
  (bsc#1160010 ltc#183046).
- powerpc/vcpu: Assume dedicated processors as non-preempt
  (bsc#1160010 ltc#183046).
- powerpc/spinlocks: Refactor SHARED_PROCESSOR (bsc#1160010
  ltc#183046).
- commit 9083e73
* Mon Jan  6 2020 glin@suse.com
- tools: Sync if_link.h (bsc#1155518).
- commit 2837df4
* Mon Jan  6 2020 glin@suse.com
- Revert patches.suse/samples-bpf-fix-build-by-setting-HAVE_ATTR_TEST-to-z.patch (bsc#1160102)
- commit 3b6da48
* Sun Jan  5 2020 ailiopoulos@suse.com
- xfs: properly serialise fallocate against AIO+DIO (bsc#1158751).
- commit e19caef
* Sat Jan  4 2020 ailiopoulos@suse.com
- xfs: attach dquots and reserve quota blocks during unwritten
  conversion (bsc#1158753).
- commit c997f56
* Fri Jan  3 2020 jslaby@suse.cz
- Update
  patches.suse/vcs-prevent-write-access-to-vcsu-devices.patch
  (git-fixes bnc#1151927 5.3.16 bnc#1157813 CVE-2019-19252).
- commit 8980d90
* Fri Jan  3 2020 glin@suse.com
- bpf: Fix precision tracking for unbounded scalars (bsc#1155518).
- commit ab8945b
* Fri Jan  3 2020 mkubecek@suse.cz
- config: refresh
  Only headers update, reorder and diff config cleanup.
- commit c9453fd
* Fri Jan  3 2020 jslaby@suse.cz
- blacklist.conf: add one
- commit d636a45
* Fri Jan  3 2020 jslaby@suse.cz
- nbd: fix shutdown and recv work deadlock v2 (git-fixes).
- net/smc: add fallback check to connect() (git-fixes).
- selftests: net: tls: remove recv_rcvbuf test (git-fixes).
- bonding: fix active-backup transition after link failure
  (git-fixes).
- Revert "mmc: sdhci: Fix incorrect switch to HS mode"
  (git-fixes).
- usbip: Fix receive error in vhci-hcd when using scatter-gather
  (git-fixes).
- io_uring: use current task creds instead of allocating a new
  one (git-fixes).
- arm64: dts: qcom: msm8998-clamshell: Remove retention idle state
  (git-fixes).
- commit 7a4b790
* Fri Jan  3 2020 jslaby@suse.cz
- cpuidle: teo: Avoid using "early hits" incorrectly (git-fixes).
- commit bcc408a
* Fri Jan  3 2020 jslaby@suse.cz
- Linux 5.3.18 (bnc#1151927 5.3.18).
- net: ethernet: ti: cpsw: fix extra rx interrupt (bnc#1151927
  5.3.18).
- tipc: fix ordering of tipc module init and exit routine
  (bnc#1151927 5.3.18).
- openvswitch: support asymmetric conntrack (bnc#1151927 5.3.18).
- commit c9a9590
* Fri Jan  3 2020 jslaby@suse.cz
- Refresh
  patches.suse/net-thunderx-start-phy-before-starting-autonegoti.patch.
  Update upstream status.
- commit 4ab23ed
* Fri Jan  3 2020 jslaby@suse.cz
- Update
  patches.suse/Fixed-updating-of-ethertype-in-function-skb_mpls_pop.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/gre-refetch-erspan-header-from-skb-data-after-pskb_m.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/hsr-fix-a-NULL-pointer-dereference-in-hsr_dev_xmit.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/inet-protect-against-too-small-mtu-values.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/mqprio-Fix-out-of-bounds-access-in-mqprio_dump.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/net-Fixed-updating-of-ethertype-in-skb_mpls_push.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/net-bridge-deny-dev_set_mac_address-when-unregisteri.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update patches.suse/net-dsa-fix-flow-dissection-on-Tx-path.patch
  (git-fixes bnc#1151927 5.3.18).
- Update
  patches.suse/net-ipv6-add-net-argument-to-ip6_dst_lookup_flow.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/net-ipv6_stub-use-ip6_dst_lookup_flow-instead-of-ip6.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/net-mlx5e-Fix-TXQ-indices-to-be-sequential.patch
  (jsc#SLE-8464 bnc#1151927 5.3.18).
- Update
  patches.suse/net-mlx5e-Query-global-pause-state-before-setting-pr.patch
  (jsc#SLE-8464 bnc#1151927 5.3.18).
- Update
  patches.suse/net-sched-fix-dump-qlen-for-sch_mq-sch_mqprio-with-N.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/net-thunderx-start-phy-before-starting-autonegoti.patch
  (bsc#1158107 bnc#1151927 5.3.18).
- Update
  patches.suse/net-tls-Fix-return-values-to-avoid-ENOTSUPP.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/page_pool-do-not-release-pool-until-inflight-0.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/tcp-Protect-accesses-to-.ts_recent_stamp-with-READ-W.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/tcp-fix-rejected-syncookies-due-to-stale-timestamps.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/tcp-md5-fix-potential-overestimation-of-TCP-option-s.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/tcp-tighten-acceptance-of-ACKs-not-matching-a-child-.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/xdp-obtain-the-mem_id-mutex-before-trying-to-remove-.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- commit c82b543
* Fri Jan  3 2020 jslaby@suse.cz
- Linux 5.3.17 (bnc#1151927 5.3.17).
- binder: fix incorrect calculation for num_valid (bnc#1151927
  5.3.17).
- lib: raid6: fix awk build warnings (bnc#1151927 5.3.17).
- staging: gigaset: add endpoint-type sanity check (bnc#1151927
  5.3.17).
- staging: gigaset: fix illegal free on probe errors (bnc#1151927
  5.3.17).
- staging: gigaset: fix general protection fault on probe
  (bnc#1151927 5.3.17).
- iio: humidity: hdc100x: fix IIO_HUMIDITYRELATIVE channel
  reporting (bnc#1151927 5.3.17).
- xhci: handle some XHCI_TRUST_TX_LENGTH quirks cases as default
  behaviour (bnc#1151927 5.3.17).
- usb: dwc3: ep0: Clear started flag on completion (bnc#1151927
  5.3.17).
- USB: atm: ueagle-atm: add missing endpoint check (bnc#1151927
  5.3.17).
- usb: core: urb: fix URB structure initialization function
  (bnc#1151927 5.3.17).
- ovl: relax WARN_ON() on rename to self (bnc#1151927 5.3.17).
- ovl: fix corner case of non-unique st_dev;st_ino (bnc#1151927
  5.3.17).
- ovl: fix lookup failure on multi lower squashfs (bnc#1151927
  5.3.17).
- raid5: need to set STRIPE_HANDLE for batch head (bnc#1151927
  5.3.17).
- block: fix "check bi_size overflow before merge" (bnc#1151927
  5.3.17).
- erofs: zero out when listxattr is called with no xattr
  (bnc#1151927 5.3.17).
- ARM: dts: omap3-tao3530: Fix incorrect MMC card detection GPIO
  polarity (bnc#1151927 5.3.17).
- powerpc/perf: Disable trace_imc pmu (bnc#1151927 5.3.17).
- powerpc/xive: Skip ioremap() of ESB pages for LSI interrupts
  (bnc#1151927 5.3.17).
- arm64: dts: allwinner: a64: Re-add PMU node (bnc#1151927
  5.3.17).
- mm: memcg/slab: wait for !root kmem_cache refcnt killing on
  root kmem_cache destruction (bnc#1151927 5.3.17).
- ACPI: bus: Fix NULL pointer check in acpi_bus_get_private_data()
  (bnc#1151927 5.3.17).
- s390/kaslr: store KASLR offset for early dumps (bnc#1151927
  5.3.17).
- s390/smp,vdso: fix ASCE handling (bnc#1151927 5.3.17).
- Revert "scsi: qla2xxx: Fix memory leak when sending I/O fails"
  (bnc#1151927 5.3.17).
- scsi: qla2xxx: Fix memory leak when sending I/O fails
  (bnc#1151927 5.3.17).
- scsi: zfcp: trace channel log even for FCP command responses
  (bnc#1151927 5.3.17).
- firmware: qcom: scm: Ensure 'a0' status code is treated as
  signed (bnc#1151927 5.3.17).
- mm/shmem.c: cast the type of unmap_start to u64 (bnc#1151927
  5.3.17).
- powerpc: Avoid clang warnings around setjmp and longjmp
  (bnc#1151927 5.3.17).
- powerpc: Allow 64bit VDSO __kernel_sync_dicache to work across
  ranges >4GB (bnc#1151927 5.3.17).
- powerpc: Allow flush_icache_range to work across ranges >4GB
  (bnc#1151927 5.3.17).
- ext2: check err when partial != NULL (bnc#1151927 5.3.17).
- quota: Check that quota is not dirty before release (bnc#1151927
  5.3.17).
- quota: fix livelock in dquot_writeback_dquots (bnc#1151927
  5.3.17).
- ext4: fix a bug in ext4_wait_for_tail_page_commit (bnc#1151927
  5.3.17).
- iio: imu: st_lsm6dsx: fix ODR check in st_lsm6dsx_write_raw
  (bnc#1151927 5.3.17).
- intel_th: pci: Add Tiger Lake CPU support (bnc#1151927 5.3.17).
- intel_th: pci: Add Ice Lake CPU support (bnc#1151927 5.3.17).
- USB: documentation: flags on usb-storage versus UAS (bnc#1151927
  5.3.17).
- USB: uas: heed CAPACITY_HEURISTICS (bnc#1151927 5.3.17).
- USB: uas: honor flag to avoid CAPACITY16 (bnc#1151927 5.3.17).
- usb: Allow USB device to be warm reset in suspended state
  (bnc#1151927 5.3.17).
- usb: gadget: pch_udc: fix use after free (bnc#1151927 5.3.17).
- RDMA/core: Fix ib_dma_max_seg_size() (bnc#1151927 5.3.17).
- omap: pdata-quirks: remove openpandora quirks for mmc3 and
  wl1251 (bnc#1151927 5.3.17).
- omap: pdata-quirks: revert pandora specific gpiod additions
  (bnc#1151927 5.3.17).
- ARM: dts: pandora-common: define wl1251 as child node of mmc3
  (bnc#1151927 5.3.17).
- media: cec.h: CEC_OP_REC_FLAG_ values were swapped (bnc#1151927
  5.3.17).
- ASoC: rt5645: Fixed typo for buddy jack support (bnc#1151927
  5.3.17).
- ASoC: Jack: Fix NULL pointer dereference in snd_soc_jack_report
  (bnc#1151927 5.3.17).
- ASoC: rt5645: Fixed buddy jack support (bnc#1151927 5.3.17).
- cpufreq: powernv: fix stack bloat and hard limit on number of
  CPUs (bnc#1151927 5.3.17).
- cpuidle: Do not unset the driver if it is there already
  (bnc#1151927 5.3.17).
- cpuidle: teo: Fix "early hits" handling for disabled idle states
  (bnc#1151927 5.3.17).
- cpuidle: teo: Consider hits and misses metrics of disabled
  states (bnc#1151927 5.3.17).
- cpuidle: teo: Rename local variable in teo_select() (bnc#1151927
  5.3.17).
- cpuidle: teo: Ignore disabled idle states that are too deep
  (bnc#1151927 5.3.17).
- ar5523: check NULL before memcpy() in ar5523_cmd() (bnc#1151927
  5.3.17).
- cgroup: pids: use atomic64_t for pids->limit (bnc#1151927
  5.3.17).
- workqueue: Fix pwq ref leak in rescuer_thread() (bnc#1151927
  5.3.17).
- workqueue: Fix missing kfree(rescuer) in destroy_workqueue()
  (bnc#1151927 5.3.17).
- workqueue: Fix spurious sanity check failures in
  destroy_workqueue() (bnc#1151927 5.3.17).
- s390/mm: properly clear _PAGE_NOEXEC bit when it is not
  supported (bnc#1151927 5.3.17).
- btrfs: record all roots for rename exchange on a subvol
  (bnc#1151927 5.3.17).
- Btrfs: send, skip backreference walking for extents with many
  references (bnc#1151927 5.3.17).
- btrfs: Remove btrfs_bio::flags member (bnc#1151927 5.3.17).
- btrfs: check page->mapping when loading free space cache
  (bnc#1151927 5.3.17).
- Btrfs: fix metadata space leak on fixup worker failure to set
  range as delalloc (bnc#1151927 5.3.17).
- Btrfs: fix negative subv_writers counter and data space leak
  after buffered write (bnc#1151927 5.3.17).
- btrfs: Avoid getting stuck during cyclic writebacks (bnc#1151927
  5.3.17).
- btrfs: use refcount_inc_not_zero in kill_all_nodes (bnc#1151927
  5.3.17).
- dm zoned: reduce overhead of backing device checks (bnc#1151927
  5.3.17).
- dm writecache: handle REQ_FUA (bnc#1151927 5.3.17).
- md: improve handling of bio with REQ_PREFLUSH in
  md_flush_request() (bnc#1151927 5.3.17).
- blk-mq: make sure that line break can be printed (bnc#1151927
  5.3.17).
- blk-mq: avoid sysfs buffer overflow with too many CPU cores
  (bnc#1151927 5.3.17).
- iio: imu: st_lsm6dsx: move odr_table in
  st_lsm6dsx_sensor_settings (bnc#1151927 5.3.17).
- commit 23a1f41
* Fri Jan  3 2020 jslaby@suse.cz
- Refresh
  patches.suse/reiserfs-fix-extended-attributes-on-the-root-directory.patch.
  Update upstream status.
- commit 0480375
* Thu Jan  2 2020 tiwai@suse.de
- can: kvaser_usb: kvaser_usb_leaf: Fix some info-leaks to USB
  devices (CVE-2019-19947 bsc#1159929).
- commit 507c332
* Thu Jan  2 2020 jslaby@suse.cz
- Update
  patches.suse/0001-ppdev-fix-PPGETTIME-PPSETTIME-ioctls.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/0002-video-hdmi-Fix-AVI-bar-unpack.patch
  (bsc#1152489 bnc#1151927 5.3.17).
- Update
  patches.suse/0029-pinctrl-samsung-Fix-device-node-refcount-leaks-in-S3.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ACPI-LPSS-Add-LNXVIDEO-BYT-I2C1-to-lpss_device_links.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ACPI-LPSS-Add-LNXVIDEO-BYT-I2C7-to-lpss_device_links.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ACPI-LPSS-Add-dmi-quirk-for-skipping-_DEP-check-for-.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/ACPI-OSL-only-free-map-once-in-osl.c.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ACPI-PM-Avoid-attaching-ACPI-PM-domain-to-certain-de.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ACPI-hotplug-PCI-Allocate-resources-directly-under-t.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ACPI-utils-Move-acpi_dev_get_first_match_dev-under-C.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ALSA-fireface-fix-return-value-in-error-path-of-isoc.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ALSA-oxfw-fix-return-value-in-error-path-of-isochron.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ASoC-fsl_audmix-Add-spin-lock-to-protect-tdms.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/PM-devfreq-Lock-devfreq-in-trans_stat_show.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/Revert-nvme-Add-quirk-for-Kingston-NVME-SSD-running-.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/SUNRPC-Fix-another-issue-with-MIC-buffer-space.patch
  (bsc#1154353 bnc#1151927 5.3.17).
- Update patches.suse/USB-adutux-fix-interface-sanity-check.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/USB-idmouse-fix-interface-sanity-checks.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/USB-serial-io_edgeport-fix-epic-endpoint-lookup.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/brcmfmac-disable-PCIe-interrupts-before-bus-reset.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/coresight-Serialize-enabling-disabling-a-link-device.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/edac-altera-use-fast-register-io-for-s10-irqs.patch
  (bsc#1152489 bnc#1151927 5.3.17).
- Update
  patches.suse/edac-ghes-do-not-warn-when-incrementing-refcount-on-0.patch
  (bsc#1152489 bnc#1151927 5.3.17).
- Update
  patches.suse/ext4-Fix-credit-estimate-for-final-inode-freeing.patch
  (bsc#1158380 bnc#1151927 5.3.17).
- Update
  patches.suse/ext4-work-around-deleting-a-file-with-i_nlink-0-safe.patch
  (bsc#1158819 CVE-2019-19447 bnc#1151927 5.3.17).
- Update patches.suse/hwrng-omap-Fix-RNG-wait-loop-timeout.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/iio-ad7949-fix-channels-mixups.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/iio-ad7949-kill-pointless-readback-handling-code.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/iio-adc-ad7124-Enable-internal-reference.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/iio-adc-ad7606-fix-reading-unnecessary-data-from-dev.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/iio-adis16480-Add-debugfs_reg_access-entry.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/iio-adis16480-Fix-scales-factors.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/iio-imu-inv_mpu6050-fix-temperature-reporting-using-.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/intel_th-Fix-a-double-put_device-in-error-path.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/interconnect-qcom-sdm845-Walk-the-list-safely-on-nod.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/iwlwifi-pcie-fix-support-for-transmitting-SKBs-with-.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/media-bdisp-fix-memleak-on-release.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/media-hantro-Fix-s_fmt-for-dynamic-resolution-change.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/media-radio-wl1273-fix-interrupt-masking-on-release.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/media-venus-remove-invalid-compat_ioctl32-handler.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/mfd-rk808-Fix-RK818-ID-template.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/mm-memfd-fix-COW-issue-on-MAP_PRIVATE-and-F_SEAL_FUTURE_WRITE-mappings.patch
  (bnc#1155780 (VM/FS functional and performance backports)
  bnc#1151927 5.3.17).
- Update
  patches.suse/mmc-host-omap_hsmmc-add-code-for-special-init-of-wl1.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/mtd-rawnand-Change-calculating-of-position-page-cont.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/mtd-spear_smi-Fix-Write-Burst-mode.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/net_sched-validate-TCA_KIND-attribute-in-tc_chain_tm.patch
  (bsc#1154353 bnc#1151927 5.3.17).
- Update
  patches.suse/phy-renesas-rcar-gen3-usb2-Fix-sysfs-interface-of-ro.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/pinctrl-armada-37xx-Fix-irq-mask-access-in-armada_37.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/pinctrl-rza2-Fix-gpio-name-typos.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/pinctrl-samsung-Add-of_node_put-before-return-in-err.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/pinctrl-samsung-Fix-device-node-refcount-leaks-in-Ex.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/pinctrl-samsung-Fix-device-node-refcount-leaks-in-in.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/powerpc-Fix-vDSO-clock_getres.patch
  (bsc#1065729 bnc#1151927 5.3.17).
- Update
  patches.suse/powerpc-xive-Prevent-page-fault-issues-in-the-machin.patch
  (bsc#1156882 ltc#182435 bnc#1151927 5.3.17).
- Update
  patches.suse/reiserfs-fix-extended-attributes-on-the-root-directory.patch
  (bsc#1151225 bnc#1151927 5.3.17).
- Update
  patches.suse/rtc-disable-uie-before-setting-time-and-enable-after.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/rtlwifi-rtl8192de-Fix-missing-callback-that-tests-fo.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/rtlwifi-rtl8192de-Fix-missing-code-to-retrieve-RX-bu.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/rtlwifi-rtl8192de-Fix-missing-enable-interrupt-flag.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-lpfc-Fix-bad-ndlp-ptr-in-xri-aborted-handling.patch
  (bsc#1156632,jsc#SLE-8654 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Always-check-the-qla2x00_wait_for_hba_o.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Change-discovery-state-before-PLOGI.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Check-secondary-image-if-reading-the-pr.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Do-command-completion-on-abort-timeout.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update patches.suse/scsi-qla2xxx-Fix-DMA-unmap-leak.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-NVMe-port-discovery-after-a-short-d.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-SRB-leak-on-switch-command-timeout.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update patches.suse/scsi-qla2xxx-Fix-a-dma_pool_free-call.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-a-race-condition-between-aborting-a.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-abort-timeout-race-condition.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-different-size-DMA-Alloc-Unmap.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-double-scsi_done-for-abort-path.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-driver-reload-for-ISP82xx.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update patches.suse/scsi-qla2xxx-Fix-driver-unload-hang.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-flash-read-for-Qlogic-ISPs.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-hang-in-fcport-delete-path.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-message-indicating-vectors-used-by-.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-premature-timer-expiration.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-qla24xx_process_bidir_cmd.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-session-lookup-in-qlt_abort_work.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update patches.suse/scsi-qla2xxx-Fix-stale-session.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update patches.suse/scsi-qla2xxx-Fix-stuck-login-session.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Introduce-the-function-qla2xxx_init_sp.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Make-qla2x00_abort_srb-again-decrease-t.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Make-sure-that-aborted-commands-are-fre.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Really-fix-qla2xxx_eh_abort.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-qla2x00_alloc_fw_dump-set-ha-eft.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/seccomp-avoid-overflow-in-implicit-constant-conversi.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/splice-only-read-in-as-much-information-as-there-is-.patch
  (bsc#1158456 bnc#1151927 5.3.17).
- Update
  patches.suse/staging-rtl8188eu-fix-interface-sanity-check.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/staging-rtl8712-fix-interface-sanity-check.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/staging-vchiq-call-unregister_chrdev_region-when-dri.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/stm-class-Lose-the-protocol-driver-when-dropping-its.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/tpm-add-check-after-commands-attribs-tab-allocation.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/usb-dwc3-gadget-Clear-started-flag-for-non-IOC.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/usb-dwc3-gadget-Fix-logical-condition.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/usb-dwc3-pci-add-ID-for-the-Intel-Comet-Lake-H-varia.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/usb-gadget-configfs-Fix-missing-spin_lock_init.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/usb-host-xhci-tegra-Correct-phy-enable-sequence.patch
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608 bnc#1151927 5.3.17).
- Update
  patches.suse/usb-mon-Fix-a-deadlock-in-usbmon-between-mmap-and-re.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/usb-roles-fix-a-potential-use-after-free.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/usb-typec-fix-use-after-free-in-typec_register_port.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/usb-xhci-only-set-D3hot-for-pci-device.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/virt_wifi-fix-use-after-free-in-virt_wifi_newlink.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/virtio-balloon-fix-managed-page-counts-when-migratin.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/wil6210-check-len-before-memcpy-calls.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/xhci-Fix-memory-leak-in-xhci_add_in_port.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/xhci-Increase-STS_HALT-timeout-in-xhci_suspend.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/xhci-fix-USB3-device-initiated-resume-race-with-root.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/xhci-make-sure-interrupts-are-restored-to-correct-st.patch
  (git-fixes bnc#1151927 5.3.17).
- commit eb92594
* Thu Jan  2 2020 tiwai@suse.de
- Add patch reference for sched fair fix (CVE-2019-19922 bsc#1159717)
- commit 480be0b
* Thu Jan  2 2020 jlee@suse.com
- efi: Make CONFIG_EFI_RCI2_TABLE selectable on x86 only
  (jsc#SLE-10289).
- commit 8c1a561
* Thu Jan  2 2020 jlee@suse.com
- efi: Make unexported efi_rci2_sysfs_init() static
  (jsc#SLE-10289).
- commit 0364d1d
* Thu Jan  2 2020 jlee@suse.com
- Refresh
  patches.suse/0011-PM-hibernate-require-hibernate-snapshot-image-to-be-.patch.
  (fate#316350)
- commit d4f6542
* Thu Jan  2 2020 jlee@suse.com
- Update config files. Add
  CONFIG_HIBERNATE_VERIFICATION_FORCE is not set
- Refresh
  patches.suse/0010-PM-hibernate-a-option-to-request-that-snapshot-image.patch.
  (fate#316350)
- commit 7516b3e
* Thu Jan  2 2020 jlee@suse.com
- Refresh
  patches.suse/0009-PM-hibernate-prevent-EFI-secret-key-to-be-regenerate.patch.
  (fate#316350)
- commit 3a74fdb
* Thu Jan  2 2020 jlee@suse.com
- Update config files. Add CONFIG_HIBERNATE_VERIFICATION=y
- Refresh
  patches.suse/0008-PM-hibernate-Generate-and-verify-signature-for-snaps.patch.
  (fate#316350)
- commit 04482de
* Tue Dec 31 2019 tbogendoerfer@suse.de
- r8152: avoid to call napi_disable twice (bsc#1159949).
- r8152: Re-order napi_disable in rtl8152_close (bsc#1159949).
- commit e318a2d
* Tue Dec 31 2019 jlee@suse.com
- Refresh
  patches.suse/0007-PM-hibernate-encrypt-hidden-area.patch.
  (fate#316350)
- commit 2517349
* Tue Dec 31 2019 jlee@suse.com
- Refresh
  patches.suse/0006-efi-allow-user-to-regenerate-secret-key.patch.
  (fate#316350)
- commit 15f6da6
* Tue Dec 31 2019 jlee@suse.com
- Update config files. Add:
  CONFIG_HIDDEN_AREA=y
  CONFIG_EFI_SECRET_KEY=y
- Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
  (fate#316350)
- commit 9f8bf21
* Tue Dec 31 2019 jlee@suse.com
- Refresh
  patches.suse/0003-x86-KASLR-public-the-function-for-getting-random-lon.patch.
  (fate#316350)
- commit 404b8d6
* Tue Dec 31 2019 jlee@suse.com
- Refresh
  patches.suse/0002-hibernate-avoid-the-data-in-hidden-area-to-be-snapsh.patch.
  (fate#316350)
- commit ef04a2a
* Tue Dec 31 2019 jlee@suse.com
- Update config files. Add:
  [#] CONFIG_HIDDEN_AREA is not set
- Refresh
  patches.suse/0001-security-create-hidden-area-to-keep-sensitive-data.patch.
  (fate#316350)
- commit 11a6e5f
* Mon Dec 30 2019 bp@suse.de
- x86/mce: Fix possibly incorrect severity calculation on AMD
  (bsc#1152489).
- commit f55f1be
* Mon Dec 30 2019 bp@suse.de
- x86/MCE/AMD: Allow Reserved types to be overwritten in
  smca_banks (bsc#1152489).
- commit a0ed031
* Mon Dec 30 2019 glin@suse.com
- bpf: Clear skb->tstamp in bpf_redirect when necessary
  (bsc#1155518).
- vfs: Convert bpf to use the new mount API (bsc#1155518).
- commit 7d014d2
* Mon Dec 30 2019 glin@suse.com
- Refresh patches.suse/bpf-Fix-race-in-btf_resolve_helper_id.patch.
  Refresh
  patches.suse/bpf-Compare-BTF-types-of-functions-arguments-with-ac.patch.
- commit 5dec29f
* Mon Dec 30 2019 glin@suse.com
- samples: bpf: fix syscall_tp due to unused syscall
  (bsc#1155518).
- samples: bpf: Replace symbol compare of trace_event
  (bsc#1155518).
- bpftool: Don't crash on missing jited insns or ksyms
  (bsc#1155518).
- bpf, riscv: Limit to 33 tail calls (bsc#1155518).
- libbpf: Make global data internal arrays mmap()-able, if
  possible (bsc#1155518).
- commit 479ef0d
* Sun Dec 29 2019 mkubecek@suse.cz
- config: refresh
  Clean up options which are no longer available.
- commit 64a3f68
* Sun Dec 29 2019 bp@suse.de
- supported.conf: Mark i10nm_edac as supported
  See bsc#1159522.
- commit 442c0cf
* Fri Dec 27 2019 dbueso@suse.de
- fs/epoll: remove unnecessary wakeups of nested epoll
  (bsc#1159867).
- epoll: simplify ep_poll_safewake() for CONFIG_DEBUG_LOCK_ALLOC
  (bsc#1159867).
- commit 42eb012
* Fri Dec 27 2019 dbueso@suse.de
- x86/mm/pat: Fix off-by-one bugs in interval tree search
  (bsc#1159864).
- locking/refcount: Remove unused 'refcount_error_report()'
  function (bsc#1149032).
- locking/refcount: Consolidate implementations of refcount_t
  (bsc#1149032).
- locking/refcount: Consolidate REFCOUNT_{MAX,SATURATED}
  definitions (bsc#1149032).
- locking/refcount: Move saturation warnings out of line
  (bsc#1149032).
- locking/refcount: Improve performance of generic REFCOUNT_FULL
  code (bsc#1149032).
- locking/refcount: Move the bulk of the REFCOUNT_FULL
  implementation into the <linux/refcount.h> header (bsc#1149032).
- locking/refcount: Remove unused refcount_*_checked() variants
  (bsc#1149032).
- locking/refcount: Ensure integer operands are treated as signed
  (bsc#1149032).
- locking/refcount: Define constants for saturation and max
  refcount values (bsc#1149032).
- lib/smp_processor_id: Don't use cpumask_equal() (bsc#1149032).
- x86/mm/pat: Rename pat_rbtree.c to pat_interval.c (bsc#1159864).
- x86/mm/pat: Drop the rbt_ prefix from external memtype calls
  (bsc#1159864).
- x86/mm/pat: Do not pass 'rb_root' down the memtype tree helper
  functions (bsc#1159864).
- x86/mm/pat: Convert the PAT tree to a generic interval tree
  (bsc#1159864).
- augmented rbtree: rework the RB_DECLARE_CALLBACKS macro
  definition (bsc#1159864).
- augmented rbtree: add new RB_DECLARE_CALLBACKS_MAX macro
  (bsc#1159864).
- augmented rbtree: add comments for RB_DECLARE_CALLBACKS macro
  (bsc#1159864).
- rbtree: avoid generating code twice for the cached versions
  (tools copy) (bsc#1159864).
- commit 27d4ced
* Thu Dec 26 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/net-ibmvnic-Fix-typo-in-retry-check.patch
- commit cdfb8b3
* Thu Dec 26 2019 glin@suse.com
- selftests/bpf: Add static to enable_all_controllers()
  (bsc#1155518).
- commit e1a5909
* Thu Dec 26 2019 glin@suse.com
- libbpf: Add support for field size relocations (bsc#1155518).
- libbpf: Add support for relocatable bitfields (bsc#1155518).
- selftests/bpf: Remove too strict field offset relo test cases
  (bsc#1155518).
- commit 50d1087
* Thu Dec 26 2019 glin@suse.com
- libbpf: Fix usage of u32 in userspace code (bsc#1155518).
- libbpf: Fix bpf_object name determination for
  bpf_object__open_file() (bsc#1155518).
- libbpf: Unpin auto-pinned maps if loading fails (bsc#1155518).
- selftests/bpf: Move test_section_names into test_progs and
  fix it (bsc#1155518).
- Refresh
  patches.suse/selftests-bpf-xdping-is-not-meant-to-be-run-standalo.patch.
- selftests/bpf: Fix dependency ordering for attach_probe test
  (bsc#1155518).
- commit d4cc79c
* Thu Dec 26 2019 glin@suse.com
- bpf: Fix record_func_key to perform backtracking on r3
  (bsc#1155518).
- bpf: Fix cgroup local storage prog tracking (bsc#1155518).
- bpf: Fix missing prog untrack in release_maps (bsc#1155518).
- bpf: Fix build in minimal configurations, again (bsc#1155518).
- samples/bpf: Fix broken xdp_rxq_info due to map order
  assumptions (bsc#1155518).
- libbpf: Fix up generation of bpf_helper_defs.h (bsc#1155518).
- libbpf: Fix global variable relocation (bsc#1155518).
- bpf: Introduce BPF_TRACE_x helper for the tracing tests
  (bsc#1155518).
- selftests/bpf: Add BPF trampoline performance test
  (bsc#1155518).
- selftests/bpf: Ensure core_reloc_kernel is reading test_progs's
  data only (bsc#1155518).
- libbpf: Support initialized global variables (bsc#1155518).
- libbpf: Fix various errors and warning reported by checkpatch.pl
  (bsc#1155518).
- libbpf: Refactor relocation handling (bsc#1155518).
- Refresh
  patches.suse/libbpf-fix-sym-st_value-print-on-32-bit-arches.patch.
- selftests/bpf: Integrate verbose verifier log into test_progs
  (bsc#1155518).
- selftests, bpftool: Skip the build test if not in tree
  (bsc#1155518).
- selftests, bpftool: Set EXIT trap after usage function
  (bsc#1155518).
- selftests/bpf: Add BPF_TYPE_MAP_ARRAY mmap() tests
  (bsc#1155518).
- selftests/bpf: Add a test for attaching BPF prog to another
  BPF prog and subprog (bsc#1155518).
- selftests/bpf: Extend test_pkt_access test (bsc#1155518).
- libbpf: Add support for attaching BPF programs to other BPF
  programs (bsc#1155518).
- selftests/bpf: Add stress test for maximum number of progs
  (bsc#1155518).
- selftests/bpf: Add combined fentry/fexit test (bsc#1155518).
- selftests/bpf: Add fexit tests for BPF trampoline (bsc#1155518).
- selftests/bpf: Add test for BPF trampoline (bsc#1155518).
- selftest/bpf: Simple test for fentry/fexit (bsc#1155518).
- libbpf: Add support to attach to fentry/fexit tracing progs
  (bsc#1155518).
- libbpf: Introduce btf__find_by_name_kind() (bsc#1155518).
- libbpf: Add getter for program size (bsc#1155518).
- bpf: Add cb access in kfree_skb test (bsc#1155518).
- selftests/bps: Clean up removed ints relocations negative tests
  (bsc#1155518).
- selftests/bpf: Add field size relocation tests (bsc#1155518).
- selftest/bpf: Add relocatable bitfield reading tests
  (bsc#1155518).
- selftests: Add tests for automatic map pinning (bsc#1155518).
- libbpf: Add auto-pinning of maps when loading BPF objects
  (bsc#1155518).
- libbpf: Move directory creation into _pin() functions
  (bsc#1155518).
- libbpf: Store map pin path and status in struct bpf_map
  (bsc#1155518).
- libbpf: Fix error handling in bpf_map__reuse_fd() (bsc#1155518).
- libbpf: Add support for prog_tracing (bsc#1155518).
- libbpf: Make DECLARE_LIBBPF_OPTS macro strictly a variable
  declaration (bsc#1155518).
- selftest/bpf: Get rid of a bunch of explicit BPF program type
  setting (bsc#1155518).
- selftests/bpf: Make reference_tracking test use subtests
  (bsc#1155518).
- selftests/bpf: Make a copy of subtest name (bsc#1155518).
- libbpf: Teach bpf_object__open to guess program types
  (bsc#1155518).
- libbpf: Add uprobe/uretprobe and tp/raw_tp section suffixes
  (bsc#1155518).
- libbpf: Add bpf_program__get_{type, expected_attach_type) APIs
  (bsc#1155518).
- bpf, libbpf: Add kernel version section parsing back
  (bsc#1155518).
- selftests/bpf: Make CO-RE reloc test impartial to test_progs
  flavor (bsc#1155518).
- selftests/bpf: Add field existence CO-RE relocs tests
  (bsc#1155518).
- libbpf: Add BPF-side definitions of supported field relocation
  kinds (bsc#1155518).
- libbpf: Add support for field existance CO-RE relocation
  (bsc#1155518).
- libbpf: Refactor bpf_object__open APIs to use common opts
  (bsc#1155518).
- libbpf: Update BTF reloc support to latest Clang format
  (bsc#1155518).
- selftests/bpf: Enforce libbpf build before BPF programs are
  built (bsc#1155518).
- libbpf: Generate more efficient BPF_CORE_READ code
  (bsc#1155518).
- selftests/bpf: Add read-only map values propagation tests
  (bsc#1155518).
- scripts/bpf: Fix xdp_md forward declaration typo (bsc#1155518).
- selftests/bpf: Add BPF_CORE_READ and BPF_CORE_READ_STR_INTO
  macro tests (bsc#1155518).
- libbpf: Add BPF_CORE_READ/BPF_CORE_READ_INTO helpers
  (bsc#1155518).
- libbpf: Move bpf_{helpers, helper_defs, endian, tracing}.h
  into libbpf (bsc#1155518).
- selftests/bpf: Split off tracing-only helpers into bpf_tracing.h
  (bsc#1155518).
- selftests/bpf: Adjust CO-RE reloc tests for new bpf_core_read()
  macro (bsc#1155518).
- selftests/bpf: samples/bpf: Split off legacy stuff from
  bpf_helpers.h (bsc#1155518).
- selftests/bpf: Undo GCC-specific bpf_helpers.h changes
  (bsc#1155518).
- bpftool: Fix bpftool build by switching to
  bpf_object__open_file() (bsc#1155518).
- libbpf: auto-generate list of BPF helper definitions
  (bsc#1155518).
- scripts/bpf: teach bpf_helpers_doc.py to dump BPF helper
  definitions (bsc#1155518).
- uapi/bpf: fix helper docs (bsc#1155518).
- libbpf: Add cscope and tags targets to Makefile (bsc#1155518).
- selftests/bpf: switch tests to new bpf_object__open_{file,
  mem}() APIs (bsc#1155518).
- libbpf: fix bpf_object__name() to actually return object name
  (bsc#1155518).
- libbpf: add bpf_object__open_{file, mem} w/ extensible opts
  (bsc#1155518).
- libbpf: stop enforcing kern_version, populate it for users
  (bsc#1155518).
- libbpf: Fix BTF-defined map's __type macro handling of arrays
  (bsc#1155518).
- libbpf: Bump current version to v0.0.6 (bsc#1155518).
- selftests/bpf: add bpf-gcc support (bsc#1155518).
- bpf: sync bpf.h to tools/ (bsc#1155518).
- bpf: clarify when bpf_trace_printk discards lines (bsc#1155518).
- bpf: fix 'struct pt_reg' typo in documentation (bsc#1155518).
- libbpf: relicense bpf_helpers.h and bpf_endian.h (bsc#1155518).
- tools/bpf: fix core_reloc.c compilation error (bsc#1155518).
- selftests/bpf: add CO-RE relocs misc tests (bsc#1155518).
- selftests/bpf: add CO-RE relocs ints tests (bsc#1155518).
- selftests/bpf: add CO-RE relocs ptr-as-array tests
  (bsc#1155518).
- selftests/bpf: add CO-RE relocs modifiers/typedef tests
  (bsc#1155518).
- selftests/bpf: add CO-RE relocs enum/ptr/func_proto tests
  (bsc#1155518).
- selftests/bpf: add CO-RE relocs array tests (bsc#1155518).
- selftests/bpf: add CO-RE relocs nesting tests (bsc#1155518).
- selftests/bpf: add CO-RE relocs struct flavors tests
  (bsc#1155518).
- selftests/bpf: add CO-RE relocs testing setup (bsc#1155518).
- selftests/bpf: add BPF_CORE_READ relocatable read macro
  (bsc#1155518).
- selftests/bpf: bpf_tcp_gen_syncookie->bpf_helpers (bsc#1155518).
- samples/bpf: switch trace_output sample to perf_buffer API
  (bsc#1155518).
- samples/bpf: convert xdp_sample_pkts_user to perf_buffer API
  (bsc#1155518).
- commit d828ab7
* Mon Dec 23 2019 jack@suse.cz
- ext4: check for directory entries too close to block end
  (bsc#1157717 CVE-2019-19037).
- commit 6bf11c6
* Mon Dec 23 2019 jack@suse.cz
- ext4: fix ext4_empty_dir() for directories with holes.
- commit 54aad4a
* Sun Dec 22 2019 dbueso@suse.de
- futex: Prevent exit livelock (bsc#1149032).
- futex: Provide distinct return value when owner is exiting
  (bsc#1149032).
- futex: Add mutex around futex exit (bsc#1149032).
- futex: Provide state handling for exec() as well (bsc#1149032).
- futex: Sanitize exit state handling (bsc#1149032).
- futex: Mark the begin of futex exit explicitly (bsc#1149032).
- futex: Set task::futex_state to DEAD right after handling
  futex exit (bsc#1149032).
- futex: Split futex_mm_release() for exit/exec (bsc#1149032).
- exit/exec: Seperate mm_release() (bsc#1149032).
- futex: Replace PF_EXITPIDONE with a state (bsc#1149032).
- futex: Move futex exit handling into futex code (bsc#1149032).
- commit 069097a
* Fri Dec 20 2019 vbabka@suse.cz
- mm, debug_pagealloc: don't rely on static keys too early
  (VM debuging functionality, bsc#1159455).
- commit 690a965
* Fri Dec 20 2019 jack@suse.cz
- ext4: work around deleting a file with i_nlink == 0 safely
  (bsc#1158819 CVE-2019-19447).
- commit 126e601
* Fri Dec 20 2019 tiwai@suse.de
- drm/i915/gt: Save irqstate around virtual_context_destroy
  (git-fixes).
- commit 0119c98
* Fri Dec 20 2019 tiwai@suse.de
- Mark already cherry-picked commit ids in i915 patches
  Refresh:
  patches.suse/drm-i915-Don-t-oops-in-dumb_create-ioctl-if-we-have-.patch
  patches.suse/drm-i915-userptr-Try-to-acquire-the-page-lock-around.patch
- commit 051ff5d
* Fri Dec 20 2019 tiwai@suse.de
- drm/i915: Protect context while grabbing its name for the
  request (git-fixes).
- drm/i915: Initialise breadcrumb lists on the virtual engine
  (git-fixes).
- commit 248edd0
* Fri Dec 20 2019 tiwai@suse.de
- net: dsa: fix flow dissection on Tx path (git-fixes).
- net: dsa: LAN9303: select REGMAP when LAN9303 enable
  (git-fixes).
- commit a8aec65
* Fri Dec 20 2019 tiwai@suse.de
- KEYS: asymmetric: return ENOMEM if akcipher_request_alloc()
  fails (git-fixes).
- commit 6067783
* Fri Dec 20 2019 tiwai@suse.de
- mmc: dw_mmc: Fix debugfs on 64-bit platforms (git-fixes).
- mmc: atmel-mci: Fix debugfs on 64-bit platforms (git-fixes).
- debugfs: Add debugfs_create_xul() for hexadecimal unsigned long
  (git-fixes).
- commit 3a9e8a9
* Fri Dec 20 2019 tiwai@suse.de
- tpm: fix invalid locking in NONBLOCKING mode (git-fixes).
- tpm_tis: reserve chip for duration of tpm_tis_core_init
  (git-fixes).
- nvmem: core: fix nvmem_cell_write inline function (git-fixes).
- tools/power/cpupower: Fix initializer override in
  hsw_ext_cstates (git-fixes).
- commit 1d5439f
* Fri Dec 20 2019 tiwai@suse.de
- tools/testing/nvdimm: Fix fallthrough warning (bsc#1159523).
- commit c26d308
* Fri Dec 20 2019 tiwai@suse.de
- net: wireless: intel: iwlwifi: fix GRO_NORMAL packet stalling
  (bsc#1159555).
- commit f735353
* Thu Dec 19 2019 mkubecek@suse.cz
- rpm/kernel-subpackage-spec: fix kernel-default-base build
  There were some issues with recent changes to subpackage dependencies handling:
- a typo in %%kernel_base_conflicts macro name
- copy/pasted "Recommends:" instead of "Provides:", "Obsoletes:" and
  "Conflicts:
- missing escaping of backslashes in macro expansions
  Fixes: f3b74b0ae86b ("rpm/kernel-subpackage-spec: Unify dependency handling.")
  Fixes: 3fd22e219f77 ("rpm/kernel-subpackage-spec: Fix empty Recommends tag (bsc#1143959)")
- commit 762fd66
* Thu Dec 19 2019 fdmanana@suse.com
- Btrfs: send, allow clone operations within the same file
  (bsc#1158746).
- commit 65efe90
* Thu Dec 19 2019 fdmanana@suse.com
- Btrfs: fix hole extent items with a zero size after range
  cloning (bsc#1156782).
- commit c0cfb85
* Thu Dec 19 2019 fdmanana@suse.com
- Btrfs: fix cloning range with a hole when using the NO_HOLES
  feature (bsc#1156782).
- commit 990a52a
* Thu Dec 19 2019 tiwai@suse.de
- supported.conf: Mark intel_rapl-* modules as supported (bsc#1159519)
  Those were marked as unsupported incorrectly.
- commit a95f5c6
* Thu Dec 19 2019 yousaf.kaukab@suse.com
- dpaa_eth: register a device link for the qman portal used
  (bsc#1159537).
- soc: fsl: qbman: allow registering a device link for the portal
  user (bsc#1159537).
- dpaa_eth: extend delays in ndo_stop (bsc#1159537).
- dpaa_eth: remove netdev_err() for user errors (bsc#1159537).
- dpaa_eth: add dropped frames to percpu ethtool stats
  (bsc#1159537).
- dpaa_eth: use a page to store the SGT (bsc#1159537).
- dpaa_eth: cleanup skb_to_contig_fd() (bsc#1159537).
- dpaa_eth: use fd information in dpaa_cleanup_tx_fd()
  (bsc#1159537).
- dpaa_eth: simplify variables used in dpaa_cleanup_tx_fd()
  (bsc#1159537).
- dpaa_eth: avoid timestamp read on error paths (bsc#1159537).
- dpaa_eth: perform DMA unmapping before read (bsc#1159537).
- dpaa_eth: use page backed rx buffers (bsc#1159537).
- dpaa_eth: use only one buffer pool per interface (bsc#1159537).
- dpaa_eth: add newline in dev_err() msg (bsc#1159537).
- fsl/fman: remove unused struct member (bsc#1159537).
- dpaa_eth: change DMA device (bsc#1159537).
- fsl/fman: add API to get the device behind a fman port
  (bsc#1159537).
- dpaa_eth: remove redundant code (bsc#1159537).
- dpaa_eth: defer probing after qbman (bsc#1159537).
- fsl/fman: don't touch liodn base regs reserved on non-PAMU SoCs
  (bsc#1159537).
- dpaa_eth: Use refcount_t for refcount (bsc#1159537).
- soc/fsl/qbman: Update device tree with reserved memory
  (bsc#1159535).
- soc/fsl/qbman: Fixup qman_shutdown_fq() (bsc#1159535).
- soc/fsl/qbman: Disable interrupts during portal recovery
  (bsc#1159535).
- soc/fsl/qbman: Fix drain_mr_fqni() (bsc#1159535).
- soc/fsl/qbman: Cleanup QMan queues if device was already
  initialized (bsc#1159535).
- soc/fsl/qbman: Cleanup buffer pools if BMan was initialized
  prior to bootup (bsc#1159535).
- soc/fsl/qbman: Rework QBMan private memory setup (bsc#1159535).
- commit 622fccb
* Thu Dec 19 2019 lyan@suse.com
- KVM: arm/arm64: vgic: Allow more than 256 vcpus for KVM_IRQ_LINE
  (jsc#SLE-9228).
- Refresh
  patches.suse/KVM-Hyper-V-Add-new-KVM-capability-KVM_CAP_HYPERV_DI.patch.
- commit 4054d0e
* Wed Dec 18 2019 tiwai@suse.de
- ASoC: wm8962: fix lambda value (git-fixes).
- ASoC: SOF: Intel: split cht and byt debug window sizes
  (git-fixes).
- ASoC: SOF: loader: fix snd_sof_fw_parse_ext_data (git-fixes).
- ASoC: SOF: loader: snd_sof_fw_parse_ext_data log warning on
  unknown header (git-fixes).
- ASoC: simple-card: Don't create separate link when platform
  is present (git-fixes).
- ASoC: topology: Check return value for soc_tplg_pcm_create()
  (git-fixes).
- ASoC: topology: Check return value for snd_soc_add_dai_link()
  (git-fixes).
- ASoC: Intel: bytcr_rt5640: Update quirk for Teclast X89
  (git-fixes).
- ASoC: Intel: sst: Add missing include <linux/io.h> (git-fixes).
- ASoC: max98090: fix possible race conditions (git-fixes).
- ASoC: max98090: exit workaround earlier if PLL is locked
  (git-fixes).
- ASoC: max98090: remove msleep in PLL unlocked workaround
  (git-fixes).
- ASoC: AMD: Enable clk in startup intead of hw_params
  (git-fixes).
- ASoC: rt5682: fix i2c arbitration lost issue (git-fixes).
- ALSA: hda - Downgrade error message for single-cmd fallback
  (git-fixes).
- ALSA: hda: Fix regression by strip mask fix (git-fixes).
- ALSA: hda/ca0132 - Fix work handling in delayed HP detection
  (git-fixes).
- ALSA: hda/ca0132 - Avoid endless loop (git-fixes).
- ALSA: hda/ca0132 - Keep power on during processing DSP response
  (git-fixes).
- ALSA: pcm: Avoid possible info leaks from PCM stream buffers
  (git-fixes).
- commit 5704af7
* Wed Dec 18 2019 msuchanek@suse.de
- powerpc/archrandom: fix arch_get_random_seed_int()
  (bsc#1065729).
- powerpc: Fix vDSO clock_getres() (bsc#1065729).
- powerpc/powernv: Disable native PCIe port management
  (bsc#1065729).
- commit 1064493
* Wed Dec 18 2019 msuchanek@suse.de
- ibmveth: Detect unsupported packets before sending to the
  hypervisor (bsc#1159484 ltc#182983).
- commit 258fd08
* Wed Dec 18 2019 dwagner@suse.de
- scsi: lpfc: size cpu map by last cpu id set (bsc#1157160).
- scsi: lpfc: use hdwq assigned cpu for allocation (bsc#1157160).
- commit b9fd3db
* Wed Dec 18 2019 tiwai@suse.de
- efi: Don't attempt to map RCI2 config table if it doesn't exist
  (git-fixes).
- efi/earlycon: Remap entire framebuffer after page initialization
  (git-fixes).
- libtraceevent: Fix memory leakage in copy_filter_type
  (git-fixes).
- commit 360da09
* Wed Dec 18 2019 tiwai@suse.de
- mailbox: tegra: Fix superfluous IRQ error message (git-fixes).
- Revert "pinctrl: sh-pfc: r8a77990: Fix MOD_SEL1 bit31 when
  using SIM0_D" (git-fixes).
- Revert "pinctrl: sh-pfc: r8a77990: Fix MOD_SEL1 bit30 when
  using SSI_SCK2 and SSI_WS2" (git-fixes).
- commit aaa30e6
* Wed Dec 18 2019 tiwai@suse.de
- regulator: rn5t618: fix module aliases (git-fixes).
- regulator: core: fix regulator_register() error paths to
  properly release rdev (git-fixes).
- spi: nxp-fspi: Ensure width is respected in spi-mem operations
  (git-fixes).
- spi: sprd: Fix the incorrect SPI register (git-fixes).
- spi: dw: Correct handling of native chipselect (git-fixes).
- spi: cadence: Correct handling of native chipselect (git-fixes).
- reset: Fix {of,devm}_reset_control_array_get kerneldoc return
  types (git-fixes).
- reset: brcmstb: Remove resource checks (git-fixes).
- commit 76e8bc6
* Wed Dec 18 2019 tiwai@suse.de
- Update patch references for io_uring fixes (CVE-2019-19241 bsc#1159441)
- commit a94274a
* Wed Dec 18 2019 tbogendoerfer@suse.de
- bpf: Force .BTF section start to zero when dumping from vmlinux
  (bsc#1154353).
- libbpf: Fix Makefile' libbpf symbol mismatch diagnostic
  (bsc#1154353).
- commit d383cb0
* Wed Dec 18 2019 tbogendoerfer@suse.de
- bpf: Support pre-2.25-binutils objcopy for vmlinux BTF
  (bsc#1154353).
- libbpf: handle symbol versioning properly for libbpf.a
  (bsc#1154353).
- commit 04f1f8c
* Wed Dec 18 2019 tiwai@suse.de
- usb: dwc3: pci: add ID for the Intel Comet Lake -H variant
  (git-fixes).
- xhci: fix USB3 device initiated resume race with roothub
  autosuspend (git-fixes).
- usb: dwc3: gadget: Clear started flag for non-IOC (git-fixes).
- USB: dummy-hcd: increase max number of devices to 32
  (git-fixes).
- commit b4a9fe8
* Wed Dec 18 2019 tiwai@suse.de
- wil6210: check len before memcpy() calls (git-fixes).
- commit b8cef66
* Wed Dec 18 2019 tiwai@suse.de
- iio: ad7949: fix channels mixups (git-fixes).
- iio: ad7949: kill pointless "readback"-handling code
  (git-fixes).
- commit 172e59a
* Wed Dec 18 2019 tiwai@suse.de
- drm/i915/guc: Skip suspend/resume GuC action on platforms w/o
  GuC submission (git-fixes).
- coresight: Serialize enabling/disabling a link device
  (git-fixes).
- coresight: tmc-etr: Fix perf_data check (git-fixes).
- commit ecf0694
* Wed Dec 18 2019 tiwai@suse.de
- bus: ti-sysc: Fix missing reset delay handling (git-fixes).
- blacklist.conf:
- ASoC: SOF: topology: free kcontrol memory on error (git-fixes).
- commit 4b0268c
* Wed Dec 18 2019 msuchanek@suse.de
- rpm/kernel-subpackage-spec: Unify dependency handling.
- commit f3b74b0
* Wed Dec 18 2019 tiwai@suse.de
- Update patch references for reported CVEs (CVE-2019-18811 bsc#1159374 CVE-2019-19044 bsc#1159370 CVE-2019-19043 bsc#1159375)
- commit 1b9a5c8
* Wed Dec 18 2019 yousaf.kaukab@suse.com
- ASoC: fsl_sai: add IRQF_SHARED (jsc#SLE-9316).
- dmaengine: fsl-qdma: Handle invalid qdma-queue0 IRQ
  (jsc#SLE-9316).
- ASoC: fsl_sai: Fix noise when using EDMA (jsc#SLE-9316).
- dmaengine: fsl-edma: implement .device_synchronize callback
  (jsc#SLE-9316).
- ASoC: fsl_sai: Implement set_bclk_ratio (jsc#SLE-9316).
- ASoC: fsl_sai: Add support for imx8qm (jsc#SLE-9316).
- ASoC: fsl_sai: Add support for imx7ulp/imx8mq (jsc#SLE-9316).
- ASoC: fsl_sai: Add support for SAI new version (jsc#SLE-9316).
- ASoC: fsl_sai: Update Tx/Rx channel enable mask (jsc#SLE-9316).
- ASoC: fsl_sai: Add registers definition for multiple datalines
  (jsc#SLE-9316).
- ASoC: sgtl5000: add ADC mute control (jsc#SLE-9316).
- ASoC: sgtl5000: Fix definition of VAG Ramp Control
  (jsc#SLE-9316).
- ASoC: fsl_sai: mark regmap as fast_io (jsc#SLE-9316).
- ASoC: fsl_sai: derive TX FIFO watermark from FIFO depth
  (jsc#SLE-9316).
- ASoC: fsl_sai: add of_match data (jsc#SLE-9316).
- commit c78e5c0
* Wed Dec 18 2019 tiwai@suse.de
- blacklist.conf: Yet another i915 entries that are already applied
- commit 1d49d40
* Wed Dec 18 2019 mkubecek@suse.cz
- fix mainline reference
- fix Patch-mainline:
  patches.suse/efi-memreserve-Register-reservations-as-reserved-in-.patch
- commit cc91804
* Wed Dec 18 2019 clin@suse.com
- efi/memreserve: Register reservations as 'reserved' in
  /proc/iomem (jsc#SLE-9943).
- commit b90e4d7
* Tue Dec 17 2019 tiwai@suse.de
- drm/hdcp: update content protection property with uevent
  (jsc#SLE-7953).
- drm: uevent for connector status change (jsc#SLE-7953).
- commit 8809d69
* Tue Dec 17 2019 tiwai@suse.de
- blacklist.conf: Yet another couple of i915 entries
- commit 1237ce0
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gvt: Fix cmd length check for MI_ATOMIC (jsc#SLE-7953).
- commit da0f534
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Reduce nested prepare_remote_context() to a trylock
  (jsc#SLE-7953).
- commit 0f19c08
* Tue Dec 17 2019 tiwai@suse.de
- blacklist.conf: Add a few more i915 entries
- commit b08d57a
* Tue Dec 17 2019 tiwai@suse.de
- blacklist.conf: Add a few more bogus fixes for i915
- commit 63135e3
* Tue Dec 17 2019 tiwai@suse.de
- blacklist.conf: Remove entries that are marked already as No-Fix
- commit f8b19cf
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/query: Align flavour of engine data lookup
  (jsc#SLE-7953).
- commit 066f30e
* Tue Dec 17 2019 tiwai@suse.de
- drm: Fix kerneldoc warns in connector-related docs
  (jsc#SLE-7953).
- blacklist.conf:
- commit 78bad1b
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Fix some NULL vs IS_ERR() conditions (jsc#SLE-7953).
- commit af137f7
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Pull obj->userfault tracking under the ggtt->mutex
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Mark-contents-as-dirty-on-a-write-fault.patch.
- commit 4e3c83d
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Generalise the clflush dma-worker (jsc#SLE-7953).
- commit 6efd408
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Allow sharing the idle-barrier from other kernel
  requests (jsc#SLE-7953).
- drm/i915: Lift timeline into intel_context (jsc#SLE-7953).
- blacklist.conf:
- Refresh
  patches.suse/drm-i915-Defer-final-intel_wakeref_put-to-process-co.patch.
- commit f2b1359
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: extract i915_suspend.h from i915_drv.h (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Remove-Master-tables-from-cmdparser.patch.
- Refresh
  patches.suse/drm-i915-cmdparser-Add-support-for-backward-jumps.patch.
- commit c0ae53a
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: extract i915_perf.h from i915_drv.h (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Remove-Master-tables-from-cmdparser.patch.
- Refresh
  patches.suse/drm-i915-cmdparser-Add-support-for-backward-jumps.patch.
- commit 9d4c2ab
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Defer final intel_wakeref_put to process context
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-gen8-Add-RC6-CTX-corruption-WA.patch.
- commit dd53316
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: split out intel_pch.[ch] from i915_drv.[ch]
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-cml-Add-second-PCH-ID-for-CMP.patch.
- commit 2861115
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Isolate i915_getparam_ioctl() (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Disable-Secure-Batches-for-gen6.patch.
- commit 49cdd5f
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: rename intel_drv.h to display/intel_display_types.h
  (jsc#SLE-7953).
- Refresh
  patches.suse/0001-drm-i915-Preload-LUTs-if-the-hw-isn-t-currently-usin.patch.
- Refresh
  patches.suse/drm-i915-avoid-including-intel_drv.h-via-i915_drv.h-.patch.
- commit d61e385
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gt: Move the [class][inst] lookup for engines onto
  the GT (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Add-support-for-mandatory-cmdparsing.patch.
- commit a00ddad
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gem: Make caps.scheduler static (jsc#SLE-7953).
- commit 9158743
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Replace struct_mutex for batch pool serialisation
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Remove-Master-tables-from-cmdparser.patch.
- Refresh
  patches.suse/drm-i915-Support-ro-ppgtt-mapped-cmdparser-shadow-bu.patch.
- Refresh
  patches.suse/drm-i915-cmdparser-Add-support-for-backward-jumps.patch.
- commit 54224b5
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/tgl: Add and use new DC5 and DC6 residency counter
  registers (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Lower-RM-timeout-to-avoid-DSI-hard-hangs.patch.
- commit f24e88e
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/oa: add content to Makefile (jsc#SLE-7953).
- commit 14f0c49
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/tgl: Update north display hotplug detection to TGL
  connections (jsc#SLE-7953).
- drm/i915/tgl: Add hpd interrupt handling (jsc#SLE-7953).
- commit d733dc7
* Tue Dec 17 2019 tiwai@suse.de
- drm/hdcp: reference for srm file format (jsc#SLE-7953).
- drm/i915: update the hdcp state with uevent (jsc#SLE-7953).
- commit 5409f55
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Attach content type property (jsc#SLE-7953).
- drm: Add Content protection type property (jsc#SLE-7953).
- commit 8c5e79f
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/uc: Update drawing for firmware layout (jsc#SLE-7953).
- commit bf9ef45
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Remove set but not used variable 'src_y'
  (jsc#SLE-7953).
- Refresh
  patches.suse/0004-drm-i915-Fix-g4x-sprite-scaling-stride-check-with-GT.patch.
- commit a67f62a
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Make sure cdclk is high enough for DP audio on VLV/CHV
  (jsc#SLE-7953).
- commit 2113501
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/uc: move GuC and HuC files under gt/uc/ (jsc#SLE-7953).
- commit 75e5ecf
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gt: Use intel_gt as the primary object for handling
  resets (jsc#SLE-7953).
- Refresh
  patches.suse/0001-drm-i915-Don-t-mix-srcu-tag-and-negative-error-codes.patch.
- Refresh
  patches.suse/0001-drm-i915-Fix-and-improve-MCR-selection-logic.patch.
- Refresh
  patches.suse/drm-i915-gen8-Add-RC6-CTX-corruption-WA.patch.
- commit fc382c7
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Drop extern qualifiers from header function prototypes
  (jsc#SLE-7953).
- Refresh
  patches.suse/0001-drm-i915-Fix-and-improve-MCR-selection-logic.patch.
- Refresh
  patches.suse/drm-i915-Remove-Master-tables-from-cmdparser.patch.
- Refresh
  patches.suse/drm-i915-cmdparser-Add-support-for-backward-jumps.patch.
- commit c8d7893
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gtt: Compute the radix for gen8 page table levels
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- commit 55aec54
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gtt: Reorder gen8 ppgtt free/clear/alloc
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- commit a16779b
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gtt: Wrap page_table with page_directory
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- commit 71fa45e
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Add engine name to workaround debug print
  (jsc#SLE-7953).
- drm/i915: Add test for invalid flag bits in whitelist entries
  (jsc#SLE-7953).
- drm/i915: Implement read-only support in whitelist selftest
  (jsc#SLE-7953).
- drm/i915/gtt: Use shallow dma pages for scratch (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- commit ec55c4b
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/userptr: Don't mark readonly objects as dirty
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-userptr-Try-to-acquire-the-page-lock-around.patch.
- commit 848bfd7
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gtt: pde entry encoding is identical (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- commit 5787f30
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Markup potential lock for i915_active (jsc#SLE-7953).
- commit bd27d8c
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gem: Free pages before rcu-freeing the object
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Support-ro-ppgtt-mapped-cmdparser-shadow-bu.patch.
- commit b98ab90
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: whitelist PS_(DEPTH|INVOCATION)_COUNT (jsc#SLE-7953).
- commit d4fc9d3
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/execlists: Refactor CSB state machine (jsc#SLE-7953).
- Refresh
  patches.suse/0003-drm-i915-execlists-Process-interrupted-context-on-re.patch.
- commit c69c050
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Sanitize the TypeC FIA lane configuration decoding
  (jsc#SLE-7953).
- commit 7967d8b
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Factor out common parts from TypeC port handling
  functions (jsc#SLE-7953).
- commit 5386d47
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Move the TypeC port handling code to a separate file
  (jsc#SLE-7953).
- commit 5357220
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Convert most of atomic commit to take more intel state
  (jsc#SLE-7953).
- Refresh
  patches.suse/0001-drm-i915-Preload-LUTs-if-the-hw-isn-t-currently-usin.patch.
- commit 4494372
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Pass intel_crtc_state to needs_modeset()
  (jsc#SLE-7953).
- Refresh
  patches.suse/0001-drm-i915-Preload-LUTs-if-the-hw-isn-t-currently-usin.patch.
- commit 7360b01
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: make intel_uc_fw.h self-contained (jsc#SLE-7953).
- drm/i915: make intel_gvt.h self-contained (jsc#SLE-7953).
- drm/i915: make intel_guc_reg.h self-contained (jsc#SLE-7953).
- drm/i915: make intel_guc_fwif.h self-contained (jsc#SLE-7953).
- drm/i915: make intel_guc_ct.h self-contained (jsc#SLE-7953).
- drm/i915: make i915_vgpu.h self-contained (jsc#SLE-7953).
- drm/i915: make i915_pvinfo.h self-contained (jsc#SLE-7953).
- drm/i915: make i915_globals.h self-contained (jsc#SLE-7953).
- drm/i915: make i915_fixed.h self-contained (jsc#SLE-7953).
- drm/i915: add header search path to subdir Makefiles
  (jsc#SLE-7953).
- drm/i915: prefix header search path with $(srctree)/
  (jsc#SLE-7953).
- drm/i915: Move OA files to separate folder (jsc#SLE-7953).
- commit f862e29
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/icl: Add new supported CD clocks (jsc#SLE-7953).
- commit cc4a25c
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/selftests: Fixup atomic reset checking (jsc#SLE-7953).
- commit 0758444
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Rename intel_wakeref_[is]_active (jsc#SLE-7953).
- commit d288f43
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gt: Pass intel_gt to pm routines (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Perform-GGTT-restore-much-earlier-during-re.patch.
- Refresh
  patches.suse/drm-i915-gen8-Add-RC6-CTX-corruption-WA.patch.
- commit a064bcc
* Tue Dec 17 2019 yousaf.kaukab@suse.com
- arm64: ls1028a: enable audio support
  References: jsc#SLE-9316
- commit a7cdc29
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Prevent dereference of engine before NULL check in
  error capture (jsc#SLE-7953).
- commit e9d652e
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Rename i915_timeline to intel_timeline and move
  under gt (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-cmdparser-Add-support-for-backward-jumps.patch.
- commit be168f4
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Save trip via top-level i915 in a few more places
  (jsc#SLE-7953).
- commit 0ade10c
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Move i915_gem_chipset_flush to intel_gt
  (jsc#SLE-7953).
- commit cdfa7d6
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Stop using I915_READ/WRITE in intel_wopcm_init_hw
  (jsc#SLE-7953).
- commit 6bfe1a1
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Convert i915_gem_init_hw to intel_gt (jsc#SLE-7953).
- commit 01ae127
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Convert intel_mocs_init_l3cc_table to intel_gt
  (jsc#SLE-7953).
- commit bc875ea
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Move intel_gt_pm_init under intel_gt_init_early
  (jsc#SLE-7953).
- commit cd30738
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/execlists: Preempt-to-busy (jsc#SLE-7953).
- Refresh
  patches.suse/0001-drm-i915-execlists-Always-clear-pending-inflight-req.patch.
- Refresh
  patches.suse/0003-drm-i915-execlists-Process-interrupted-context-on-re.patch.
- commit 4d9e5f4
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gvt: decouple check_vgpu() from uncore_init()
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- commit 97898e8
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/fbdev: Restore physical addresses for fb_mmap()
  (jsc#SLE-7953).
- drm/i915: make pool objects read-only (jsc#SLE-7953).
- drm/i915: Protect request peeking with RCU (jsc#SLE-7953).
- drm/i915/tgl: MOCS table update (jsc#SLE-7953).
- drm/i915/dp: Do not switch aux to TBT mode for non-TC ports
  (jsc#SLE-7953).
- drm/i915/tgl: Fix doc not corresponding to code (jsc#SLE-7953).
- drm/i915: Fixup preempt-to-busy vs resubmission of a virtual
  request (jsc#SLE-7953).
- drm/i915/execlists: Refactor -EIO markup of hung requests
  (jsc#SLE-7953).
- drm/i915/gt: execlists->active is serialised by the tasklet
  (jsc#SLE-7953).
- drm/i915/execlists: Protect peeking at execlists->active
  (jsc#SLE-7953).
- drm/i915: Fixup preempt-to-busy vs reset of a virtual request
  (jsc#SLE-7953).
- drm/i915: Only enqueue already completed requests
  (jsc#SLE-7953).
- drm/i915/execlists: Drop redundant
  list_del_init(&rq->sched.link) (jsc#SLE-7953).
- drm/i915: Prevent bonded requests from overtaking each other
  on preemption (jsc#SLE-7953).
- drm/i915: Verify the engine after acquiring the active.lock
  (jsc#SLE-7953).
- drm/i915/execlists: Remove incorrect BUG_ON for schedule-out
  (jsc#SLE-7953).
- Revert "drm/i915: Fix DP-MST crtc_mask" (jsc#SLE-7953).
- drm/i915: Use NOEVICT for first pass on attemping to pin a
  GGTT mmap (jsc#SLE-7953).
- drm/i915: Flush the existing fence before GGTT read/write
  (jsc#SLE-7953).
- drm/i915: Hold irq-off for the entire fake lock period
  (jsc#SLE-7953).
- drm/i915/gvt: update RING_START reg of vGPU when the context
  is submitted to i915 (jsc#SLE-7953).
- drm/i915: Select DMABUF_SELFTESTS for the default i915.ko
  debug build (jsc#SLE-7953).
- drm/i915: Update DRIVER_DATE to 20190822 (jsc#SLE-7953).
- drm/i915: Replace i915_vma_put_fence() (jsc#SLE-7953).
- drm/i915: Track ggtt fence reservations under its own mutex
  (jsc#SLE-7953).
- drm/i915/selftests: Fixup a couple of missing serialisation
  with vma (jsc#SLE-7953).
- drm/i915/gtt: Add some range asserts (jsc#SLE-7953).
- drm/i915/execlists: Set priority hint prior to submission
  (jsc#SLE-7953).
- drm/i915: Replace PIN_NONFAULT with calls to PIN_NOEVICT
  (jsc#SLE-7953).
- drm/i915/gtt: Include asm/smp.h (jsc#SLE-7953).
- drm/i915/hdmi: make hdcp2_msg_data const (jsc#SLE-7953).
- drm/i915/hdmi: stylistic cleanup around hdcp2_msg_data
  (jsc#SLE-7953).
- drm/i915/dp: make hdcp2_dp_msg_data const (jsc#SLE-7953).
- drm/i915/dp: avoid shadowing variables (jsc#SLE-7953).
- drm/i915/dp: stylistic cleanup around hdcp2_msg_data
  (jsc#SLE-7953).
- drm/i915/gtt: Relax assertion for pt_used (jsc#SLE-7953).
- drm/i915: Fix DP-MST crtc_mask (jsc#SLE-7953).
- drm/i915/tgl: update DMC firmware to 2.04 (jsc#SLE-7953).
- drm/i915/tgl: Move transcoders to pipes' powerwells
  (jsc#SLE-7953).
- drm/i915/tgl: add support for reading the timestamp frequency
  (jsc#SLE-7953).
- drm/i915/tgl: disable DDIC (jsc#SLE-7953).
- drm/i915: Update DRIVER_DATE to 20190820 (jsc#SLE-7953).
- drm/i915/gtt: Relax pd_used assertion (jsc#SLE-7953).
- drm/i915: Dynamically allocate s0ix struct for VLV
  (jsc#SLE-7953).
- drm/i915/tgl: Gen12 render context size (jsc#SLE-7953).
- drm/i915/tgl: Updated Private PAT programming (jsc#SLE-7953).
- drm/i915/tgl: Introduce initial Tiger Lake workarounds
  (jsc#SLE-7953).
- drm/i915/tgl: Gen12 csb support (jsc#SLE-7953).
- drm/i915/tgl: add GEN12_MAX_CONTEXT_HW_ID (jsc#SLE-7953).
- drm/i915/tgl: add Gen12 default indirect ctx offset
  (jsc#SLE-7953).
- drm/i915/tgl: Report valid VDBoxes with SFC capability
  (jsc#SLE-7953).
- drm/i915: Be defensive when starting vma activity
  (jsc#SLE-7953).
- drm/i915: Serialize insertion into the file->mm.request_list
  (jsc#SLE-7953).
- drm/i915: Sanitize PHY state during display core uninit
  (jsc#SLE-7953).
- drm/i915: Assume exclusive access to objects inside resume
  (jsc#SLE-7953).
- drm/i915: Use 0 for the unordered context (jsc#SLE-7953).
- drm/i915: i915_active.retire() is optional (jsc#SLE-7953).
- drm/i915/gen11: Allow usage of all GPIO pins (jsc#SLE-7953).
- drm/i915: Serialize against vma moves (jsc#SLE-7953).
- drm/i915: Only emit the 'send bug report' once for a GPU hang
  (jsc#SLE-7953).
- drm/i915/gt: Mark up the nested engine-pm timeline lock as
  irqsafe (jsc#SLE-7953).
- drm/i915: Always wrap the ring offset before resetting
  (jsc#SLE-7953).
- drm/i915: Propagate fence errors (jsc#SLE-7953).
- drm/i915/uc: Never fail on HuC firmware errors (jsc#SLE-7953).
- drm/i915/uc: Don't always fail on unavailable GuC firmware
  (jsc#SLE-7953).
- drm/i915/guc: Don't open log relay if GuC is not running
  (jsc#SLE-7953).
- drm/i915/uc: Never fail on uC preparation step (jsc#SLE-7953).
- drm/i915/uc: Cleanup fw fetch on every GuC/HuC init failure
  (jsc#SLE-7953).
- drm/i915/uc: Cleanup fw fetch only if it was successful
  (jsc#SLE-7953).
- drm/i915/selftests: Check the context size (jsc#SLE-7953).
- drm/i915/gtt: Fold gen8 insertions into one (jsc#SLE-7953).
- drm/i915/uc: Add explicit DISABLED state for firmware
  (jsc#SLE-7953).
- drm/i915: Wrappers for display register waits (jsc#SLE-7953).
- drm/i915: Move gmbus definitions out of i915_reg.h
  (jsc#SLE-7953).
- drm/i915: Move engine IDs out of i915_reg.h (jsc#SLE-7953).
- drm/i915: Move i915_power_well_id out of i915_reg.h
  (jsc#SLE-7953).
- drm/i915/execlists: Lift process_csb() out of the irq-off
  spinlock (jsc#SLE-7953).
- drm/i915: Markup expected timeline locks for i915_active
  (jsc#SLE-7953).
- drm/i915/gt: Mark context->active_count as protected by
  timeline->mutex (jsc#SLE-7953).
- drm/i915/wopcm: Fix SPDX tag location (jsc#SLE-7953).
- drm/i915/wopcm: Update error messages (jsc#SLE-7953).
- drm/i915/wopcm: Try to use already locked WOPCM layout
  (jsc#SLE-7953).
- drm/i915/wopcm: Check WOPCM layout separately from calculations
  (jsc#SLE-7953).
- drm/i915/uc: Move FW size sanity check back to fetch
  (jsc#SLE-7953).
- drm/i915/buddy: use kmemleak_update_trace (jsc#SLE-7953).
- drm/i915/buddy: tidy up i915_buddy_fini (jsc#SLE-7953).
- drm/i915: Use the associated uncore for the vm (jsc#SLE-7953).
- drm/i915: Extract intel_frontbuffer active tracking
  (jsc#SLE-7953).
- drm/i915: Protect request retirement with timeline->mutex
  (jsc#SLE-7953).
- drm/i915/gt: Guard timeline pinning without relying on
  struct_mutex (jsc#SLE-7953).
- drm/i915/gt: Convert timeline tracking to spinlock
  (jsc#SLE-7953).
- drm/i915/gt: Track timeline activeness in enter/exit
  (jsc#SLE-7953).
- drm/i915: Move tasklet kicking to __i915_request_queue caller
  (jsc#SLE-7953).
- drm/i915/icl: Add gen11 specific render breadcrumbs
  (jsc#SLE-7953).
- drm/i915/icl: Add command cache invalidate (jsc#SLE-7953).
- drm/i915/icl: Implement gen11 flush including tile cache
  (jsc#SLE-7953).
- drm/i915/selftest/buddy: fixup igt_buddy_alloc_range
  (jsc#SLE-7953).
- drm/i915: Convert a few more bland dmesg info to be device
  specific (jsc#SLE-7953).
- drm/i915: Serialise read/write of the barrier's engine
  (jsc#SLE-7953).
- drm/i915: Print CCID for all renderCS (jsc#SLE-7953).
- drm/i915: Disregard drm_mode_config.fb_base (jsc#SLE-7953).
- drm/i915: Include engine->mmio_base in the debug dump
  (jsc#SLE-7953).
- drm/i915/guc: Remove client->submissions (jsc#SLE-7953).
- drm/i915: Update DRIVER_DATE to 20190813 (jsc#SLE-7953).
- drm/i915: Add _TRANS2() (jsc#SLE-7953).
- drm/i915/bdw+: Move misc display IRQ handling to it own function
  (jsc#SLE-7953).
- drm/i915/gvt: Double check batch buffer size after copy
  (jsc#SLE-7953).
- drm/i915/gvt: Add valid length check for MI variable commands
  (jsc#SLE-7953).
- drm/i915/gvt: Add MI command valid length check (jsc#SLE-7953).
- drm/i915/gvt: Utility for valid command length check
  (jsc#SLE-7953).
- drm/i915/gvt: factor out tlb and mocs register offset table
  (jsc#SLE-7953).
- drm/i915/gvt: no need to check return value of debugfs_create
  functions (jsc#SLE-7953).
- drm/i915/gvt: Fix typo of VBLANK_TIMER_PERIOD (jsc#SLE-7953).
- drm/i915/kvmgt: Use struct_size() helper (jsc#SLE-7953).
- drm/i915/gt: Save/restore interrupts around breadcrumb disable
  (jsc#SLE-7953).
- drm/i915: Push the wakeref->count deferral to the backend
  (jsc#SLE-7953).
- drm/i915/tgl: Fix missing parentheses on
  TGL_TRANS_DDI_FUNC_CTL_VAL_TO_PORT (jsc#SLE-7953).
- drm/i915/uc: Log fw status changes only under debug config
  (jsc#SLE-7953).
- drm/i915/guc: Use a local cancel_port_requests (jsc#SLE-7953).
- drm/i915: drop engine_pin/unpin_breadcrumbs_irq (jsc#SLE-7953).
- drm/i915/guc: keep breadcrumb irq always enabled (jsc#SLE-7953).
- drm/i915/overlay: Switch to using i915_active tracking
  (jsc#SLE-7953).
- drm/i915: Forgo last_fence active request tracking
  (jsc#SLE-7953).
- drm/i915: Extract general GT interrupt handlers (jsc#SLE-7953).
- drm/i915: Extract GT powermanagement interrupt handling
  (jsc#SLE-7953).
- drm/i915/gt: Use the local engine wakeref when checking RING
  registers (jsc#SLE-7953).
- drm/i915/selftests: Prevent the timeslice expiring during
  suppression tests (jsc#SLE-7953).
- drm/i915/execlists: Avoid sync calls during park (jsc#SLE-7953).
- drm/i915/uc: Update copyright and license (jsc#SLE-7953).
- drm/i915/tgl: Fixing up list of PG3 power domains
  (jsc#SLE-7953).
- drm/i915/icl: Remove DDI IO power domain from PG3 power domains
  (jsc#SLE-7953).
- drm/i915/uc: Use -EIO code for GuC initialization failures
  (jsc#SLE-7953).
- drm/i915/uc: Update messages from fw upload step (jsc#SLE-7953).
- drm/i915/uc: Include HuC firmware version in summary
  (jsc#SLE-7953).
- drm/i915/uc: Fail early if there is no GuC fw available
  (jsc#SLE-7953).
- drm/i915: Remove unused debugfs/i915_emon_status (jsc#SLE-7953).
- drm/i915: buddy allocator (jsc#SLE-7953).
- drm/i915/blt: support copying objects (jsc#SLE-7953).
- drm/i915/gtt: disable 2M pages for pre-gen11 (jsc#SLE-7953).
- drm/i915/gtt: enable GTT cache by default (jsc#SLE-7953).
- drm/i915/selftests: move gpu-write-dw into utils (jsc#SLE-7953).
- drm/i915/blt: bump the size restriction (jsc#SLE-7953).
- drm/i915/blt: don't assume pinned intel_context (jsc#SLE-7953).
- drm/i915: split out uncore_mmio_debug (jsc#SLE-7953).
- drm/i915: Stop reconfiguring our shmemfs mountpoint
  (jsc#SLE-7953).
- drm/i915: Push the ring creation flags to the backend
  (jsc#SLE-7953).
- drm/i915/gt: Make deferred context allocation explicit
  (jsc#SLE-7953).
- drm/i915: Remove i915_gem_context_create_gvt() (jsc#SLE-7953).
- drm/i915: Drop the fudge warning on ring restart for ctg/elk
  (jsc#SLE-7953).
- drm/i915: Generalise BSD default selection (jsc#SLE-7953).
- drm/i915: Replace global bsd_dispatch_index with random seed
  (jsc#SLE-7953).
- drm/i915: Check for a second VCS engine more carefully
  (jsc#SLE-7953).
- drm/i915/execlists: Backtrack along timeline (jsc#SLE-7953).
- drm/i915: Free the imported shmemfs file for phys objects
  (jsc#SLE-7953).
- drm/i915: extract i915_gem_shrinker.h from i915_drv.h
  (jsc#SLE-7953).
- drm/i915: extract gem/i915_gem_stolen.h from i915_drv.h
  (jsc#SLE-7953).
- drm/i915: extract i915_memcpy.h from i915_drv.h (jsc#SLE-7953).
- drm/i915: extract i915_sysfs.h from i915_drv.h (jsc#SLE-7953).
- drm/i915: move printing and load error inject to i915_utils.[ch]
  (jsc#SLE-7953).
- drm/i915: move I915_STATE_WARN() and _ON() to intel_display.h
  (jsc#SLE-7953).
- drm/i915: move add_taint_for_CI() to i915_utils.h
  (jsc#SLE-7953).
- drm/i915: remove unused dev_priv->no_aux_handshake
  (jsc#SLE-7953).
- drm/i915: Make debugfs/per_file_stats scale better
  (jsc#SLE-7953).
- drm/i915: Only include active engines in the capture state
  (jsc#SLE-7953).
- drm/i915/selftests: Fixup a missing legacy_idx (jsc#SLE-7953).
- drm/i915/tgl: Fix the read of the DDI that transcoder is
  attached to (jsc#SLE-7953).
- drm/i915: Get transcoder power domain before reading its
  register (jsc#SLE-7953).
- drm/i915: Fix up the inverse mapping for default ctx->engines[]
  (jsc#SLE-7953).
- drm/i915: Allocate kernel_contexts directly (jsc#SLE-7953).
- drm/i915/selftests: Pass intel_context to mock_request
  (jsc#SLE-7953).
- drm/i915/tgl/dsi: Enable blanking packets during BLLP for
  video mode (jsc#SLE-7953).
- drm/i915/tgl: Add mipi dsi support for TGL (jsc#SLE-7953).
- drm/i915/tgl/dsi: Gate the ddi clocks after pll mapping
  (jsc#SLE-7953).
- drm/i915/tgl/dsi: Do not override TA_SURE (jsc#SLE-7953).
- drm/i915/tgl/dsi: Set latency PCS_DW1 for tgl (jsc#SLE-7953).
- drm/i915/tgl/dsi: Program TRANS_VBLANK register (jsc#SLE-7953).
- drm/i915/uc: Hardening firmware fetch (jsc#SLE-7953).
- drm/i915/uc: WOPCM programming errors are not always real
  (jsc#SLE-7953).
- drm/i915: Make wopcm_to_i915() private (jsc#SLE-7953).
- drm/i915: Don't try to partition WOPCM without GuC firmware
  (jsc#SLE-7953).
- drm/i915/uc: Don't fetch HuC fw if GuC fw fetch already failed
  (jsc#SLE-7953).
- drm/i915/uc: HuC firmware can't be supported without GuC
  (jsc#SLE-7953).
- drm/i915/uc: Prefer dev_info for reporting options
  (jsc#SLE-7953).
- drm/i915/perf: Refactor oa object to better manage resources
  (jsc#SLE-7953).
- drm/i915: Include the DRIVER_DATE in the error state
  (jsc#SLE-7953).
- drm/i915: Use intel_engine_lookup_user for probing HAS_BSD etc
  (jsc#SLE-7953).
- drm/i915: Rename engines to match their user interface
  (jsc#SLE-7953).
- drm/i915: Drop expectations of VM_IO from our GGTT mmappings
  (jsc#SLE-7953).
- drm/i915: abstract display suspend/resume operations
  (jsc#SLE-7953).
- drm/i915: move property enums to intel_display_types.h
  (jsc#SLE-7953).
- drm/i915: remove unnecessary includes of intel_display_types.h
  header (jsc#SLE-7953).
- drm/i915: avoid including intel_drv.h via
  i915_drv.h->i915_trace.h (jsc#SLE-7953).
- drm/i915/tc: un-inline intel_tc_port_ref_held() (jsc#SLE-7953).
- drm/i915/mst: un-inline intel_dp_mst_encoder_active_links()
  (jsc#SLE-7953).
- drm/i915/bw: make intel_atomic_get_bw_state() static
  (jsc#SLE-7953).
- drm/i915/irq: un-inline functions to avoid i915_drv.h include
  (jsc#SLE-7953).
- drm/i915/sprite: un-inline icl_is_hdr_plane() (jsc#SLE-7953).
- drm/i915: move intel_display.c function declarations
  (jsc#SLE-7953).
- drm/i915/dmc: Load DMC on TGL (jsc#SLE-7953).
- drm/i915: Use drm_i915_private directly from drv_get_drvdata()
  (jsc#SLE-7953).
- drm/i915/gt: Remove stale kerneldoc for internal MOCS functions
  (jsc#SLE-7953).
- drm/i915/uc: Don't fail on HuC early init errors (jsc#SLE-7953).
- drm/i915/uc: Remove redundant GuC support checks (jsc#SLE-7953).
- drm/i915/huc: Prefer intel_huc_is_supported (jsc#SLE-7953).
- drm/i915/guc: Prefer intel_guc_is_submission_supported
  (jsc#SLE-7953).
- drm/i915: Teach execbuffer to take the engine wakeref not GT
  (jsc#SLE-7953).
- drm/i915: Flush the freed object list on file close
  (jsc#SLE-7953).
- drm/i915: Hide unshrinkable context objects from the shrinker
  (jsc#SLE-7953).
- drm/i915/wopcm: Don't fail on WOPCM partitioning failure
  (jsc#SLE-7953).
- drm/i915/uc: Inject probe errors into intel_uc_init_hw
  (jsc#SLE-7953).
- drm/i915/uc: Move GuC error log to uc and release it on fini
  (jsc#SLE-7953).
- drm/i915/uc: Reorder firmware status codes (jsc#SLE-7953).
- drm/i915/uc: Do full sanitize instead of pure reset
  (jsc#SLE-7953).
- drm/i915: Add i915 to i915_inject_probe_failure (jsc#SLE-7953).
- drm/i915: Report resv_obj allocation failure (jsc#SLE-7953).
- drm/i915: Fix documentation for __intel_wait_for_register_fw*
  (jsc#SLE-7953).
- drm/i915/oa: update the generated files (jsc#SLE-7953).
- drm/i915: Flush extra hard after writing relocations through
  the GTT (jsc#SLE-7953).
- drm/i915/pmu: Atomically acquire the gt_pm wakeref
  (jsc#SLE-7953).
- drm/i915/pmu: Make get_rc6 take intel_gt (jsc#SLE-7953).
- drm/i915/pmu: Convert sampling to gt (jsc#SLE-7953).
- drm/i915/pmu: Convert engine sampling to uncore mmio
  (jsc#SLE-7953).
- drm/i915/pmu: Make more struct i915_pmu centric (jsc#SLE-7953).
- drm/i915/tgl: allow the reg_read ioctl to read the RCS TIMESTAMP
  register (jsc#SLE-7953).
- drm/i915/uc: Stop sanitizing enable_guc modparam (jsc#SLE-7953).
- drm/i915/guc: Use dedicated flag to track submission mode
  (jsc#SLE-7953).
- drm/i915/uc: Consider enable_guc modparam during fw selection
  (jsc#SLE-7953).
- drm/i915/uc: Rename intel_uc_is_using* into intel_uc_supports*
  (jsc#SLE-7953).
- drm/i915/gt: Introduce intel_gt_runtime_suspend/resume
  (jsc#SLE-7953).
- drm/i915/uc: Move uC early functions inside the GT ones
  (jsc#SLE-7953).
- drm/i915/gt: Move gt_cleanup_early out of gem_cleanup_early
  (jsc#SLE-7953).
- drm/i915: Remove lrc default desc from GEM context
  (jsc#SLE-7953).
- drm/i915/ehl: Don't forget to handle port C's hotplug interrupts
  (jsc#SLE-7953).
- drm/i915/ehl: Ungate DDIC and DDID (jsc#SLE-7953).
- drm/i915: Move MOCS setup to intel_mocs.c (jsc#SLE-7953).
- drm/i915/tgl: Tigerlake only has global MOCS registers
  (jsc#SLE-7953).
- drm/i915/tgl: Define MOCS entries for Tigerlake (jsc#SLE-7953).
- drm/i915/tgl: stop using ERROR_GEN6 and DONE_REG (jsc#SLE-7953).
- drm/i915/tgl: Move fault registers to their new offset
  (jsc#SLE-7953).
- drm/i915: remove dangling forward declaration (jsc#SLE-7953).
- drm/i915/uc: Move uC WOPCM setup in uc_init_hw (jsc#SLE-7953).
- drm/i915/uc: Don't enable communication twice on resume
  (jsc#SLE-7953).
- drm/i915/selftests: Pass intel_context to igt_spinner
  (jsc#SLE-7953).
- drm/i915: Avoid ce->gem_context->i915 (jsc#SLE-7953).
- drm/i915: make i915_selftest.h self-contained (jsc#SLE-7953).
- drm/i915/tgl: handle DP aux interrupts (jsc#SLE-7953).
- drm/i915: stop using seqcount for fence pruning (jsc#SLE-7953).
- drm/i915: remove irrelevant DRM_UNLOCKED flag (jsc#SLE-7953).
- drm/i915: Update DRIVER_DATE to 20190730 (jsc#SLE-7953).
- drm/i915/gt: Provide a local intel_context.vm (jsc#SLE-7953).
- drm/i915: Move aliasing_ppgtt underneath its i915_ggtt
  (jsc#SLE-7953).
- drm/i915: Inline engine->init_context into its caller
  (jsc#SLE-7953).
- drm/i915: use upstream version of header tests (jsc#SLE-7953).
- drm/i915/uc: Don't fail on HuC firmware failure (jsc#SLE-7953).
- drm/i915: Flush the i915_vm_release before ggtt shutdown
  (jsc#SLE-7953).
- drm/i915/selftests: Careful not to flush hang_fini on error
  setups (jsc#SLE-7953).
- drm/i915/uc: Fixup kerneldoc after params were flipped and
  renamed (jsc#SLE-7953).
- drm/i915/tgl: update ddi/tc clock_off bits (jsc#SLE-7953).
- drm/i915/tgl: select correct bit for port select (jsc#SLE-7953).
- drm/i915/tgl: skip setting PORT_CL_DW12_* on initialization
  (jsc#SLE-7953).
- drm/i915/uc: Remove redundant RSA offset definition
  (jsc#SLE-7953).
- drm/i915/uc: Remove redundant ucode offset definition
  (jsc#SLE-7953).
- drm/i915/uc: Remove redundant header_offset/size definitions
  (jsc#SLE-7953).
- drm/i915/gt: Add to timeline requires the timeline mutex
  (jsc#SLE-7953).
- drm/i915/uc: Don't sanitize guc_log_level modparam
  (jsc#SLE-7953).
- drm/i915: Do not rely on for loop caching the mask
  (jsc#SLE-7953).
- drm/i915/perf: Initialise err to 0 before looping over
  ce->engines (jsc#SLE-7953).
- drm/i915/guc: init submission structures as part of guc_init
  (jsc#SLE-7953).
- drm/i915/uc: Reorder params in intel_uc_fw_fetch (jsc#SLE-7953).
- drm/i915: Capture vma contents outside of spinlock
  (jsc#SLE-7953).
- drm/i915/uc: Move uc firmware layout definitions to dedicated
  file (jsc#SLE-7953).
- drm/i915/uc: Unify uC firmware upload (jsc#SLE-7953).
- drm/i915/uc: Plumb the gt through fw_upload (jsc#SLE-7953).
- drm/i915/huc: Copy huc rsa only once (jsc#SLE-7953).
- drm/i915/uc: Move xfer rsa logic to common function
  (jsc#SLE-7953).
- drm/i915/uc: Unify uc_fw status tracking (jsc#SLE-7953).
- drm/i915/uc: Unify uC FW selection (jsc#SLE-7953).
- drm/i915: Fix handling of non-supported uC (jsc#SLE-7953).
- drm/i915/uc: Unify uC platform check (jsc#SLE-7953).
- drm/i915/guc: Set GuC init params only once (jsc#SLE-7953).
- drm/i915: Use dev_get_drvdata (jsc#SLE-7953).
- drm/i915/huc: fix status check (jsc#SLE-7953).
- drm/i915: Squelch nop wait-for-idle trace (jsc#SLE-7953).
- drm/i915/selftests: Let igt_vma_partial et al breathe
  (jsc#SLE-7953).
- drm/i915/uc: Sanitize uC when GT is sanitized (jsc#SLE-7953).
- drm/i915/uc: Gt-fy uc reset (jsc#SLE-7953).
- drm/i915: Add HDCP capability info to i915_display_info
  (jsc#SLE-7953).
- drm/i915: Rely on spinlock protection for GPU error capture
  (jsc#SLE-7953).
- drm/i915/gt: Hook up intel_context_fini() (jsc#SLE-7953).
- drm/i915: Remove obsolete engine cleanup (jsc#SLE-7953).
- drm/i915/gtt: Fix rounding for 36b (jsc#SLE-7953).
- drm/i915/dsi: remove set but not used variable 'hfront_porch'
  (jsc#SLE-7953).
- drm/i915/gtt: Don't try to clear failed empty pd allocation
  (jsc#SLE-7953).
- drm/i915/gtt: Correct unshifted 'from' for gen8_ppgtt_alloc
  errors (jsc#SLE-7953).
- Revert "drm/i915: Update description of i915.enable_guc
  modparam" (jsc#SLE-7953).
- Revert "drm/i915/guc: Turn on GuC/HuC auto mode" (jsc#SLE-7953).
- drm/i915/icl: Add Wa_1409178092 (jsc#SLE-7953).
- drm/i915/icl: Verify engine workarounds in GEN8_L3SQCREG4
  (jsc#SLE-7953).
- drm/i915: Skip CS verification of L3 bank registers
  (jsc#SLE-7953).
- drm/i915/execlists: Cancel breadcrumb on preempting the virtual
  engine (jsc#SLE-7953).
- drm/i915: Use maximum write flush for pwrite_gtt (jsc#SLE-7953).
- drm/i915: Drop wmb() inside pread_gtt (jsc#SLE-7953).
- drm/i915/ehl: Use an id of 4 while accessing DPLL4's CR0 and
  CR1 (jsc#SLE-7953).
- drm/i915: Add gen8_de_pipe_fault_mask() (jsc#SLE-7953).
- drm/i915/gt: Push engine stopping into reset-prepare
  (jsc#SLE-7953).
- drm/i915: Update description of i915.enable_guc modparam
  (jsc#SLE-7953).
- drm/i915/oa: Reconfigure contexts on the fly (jsc#SLE-7953).
- drm/i915/gtt: Tidy up ppgtt insertion for gen8 (jsc#SLE-7953).
- drm/i915/gtt: Recursive ppgtt alloc for gen8 (jsc#SLE-7953).
- drm/i915/execlists: Disable preemption under GVT (jsc#SLE-7953).
- drm/i915: Enable hotplug retry (jsc#SLE-7953).
- drm/i915: Add support for retrying hotplug (jsc#SLE-7953).
- drm/i915/ehl: Map MCC pins based on PHY, not port
  (jsc#SLE-7953).
- drm/i915/selftests: Ignore self-preemption suppression under
  gvt (jsc#SLE-7953).
- drm/i915/uc: kill <g,h>uc_to_i915 (jsc#SLE-7953).
- drm/i915/guc: prefer intel_gt in guc interrupt functions
  (jsc#SLE-7953).
- drm/i915/uc: prefer intel_gt over i915 in GuC/HuC paths
  (jsc#SLE-7953).
- drm/i915/uc: Move intel functions to intel_uc (jsc#SLE-7953).
- drm/i915/uc: move GuC/HuC inside intel_gt under a new intel_uc
  (jsc#SLE-7953).
- drm/i915/guc: unify guc irq handling (jsc#SLE-7953).
- drm/i915/guc: move guc irq functions to intel_guc parameter
  (jsc#SLE-7953).
- drm/i915/uc: introduce intel_uc_fw_supported (jsc#SLE-7953).
- drm/i915/uc: replace uc init/fini misc (jsc#SLE-7953).
- drm/i915/guc: Use system workqueue for log capture
  (jsc#SLE-7953).
- drm/i915/tgl: add modular FIA to device info (jsc#SLE-7953).
- drm/i915: Add modular FIA (jsc#SLE-7953).
- drm/i915/gtt: Recursive ppgtt clear for gen8 (jsc#SLE-7953).
- drm/i915/gtt: Recursive cleanup for gen8 (jsc#SLE-7953).
- drm/i915/display: Drop kerneldoc for 'intel_atomic_commit'
  (jsc#SLE-7953).
- drm/i915: Skip SINK_COUNT read on CH7511 (jsc#SLE-7953).
- drm/i915/guc: Turn on GuC/HuC auto mode (jsc#SLE-7953).
- drm/i915/guc: Don't enable GuC/HuC in auto mode on pre-Gen11
  (jsc#SLE-7953).
- drm/i915: Propagate "_probe" function name suffix down
  (jsc#SLE-7953).
- drm/i915: Propagate "_remove" function name suffix down
  (jsc#SLE-7953).
- drm/i915: Propagate "_release" function name suffix down
  (jsc#SLE-7953).
- drm/i915: Replace "_load" with "_probe" consequently
  (jsc#SLE-7953).
- drm/i915: Rename "_load"/"_unload" to match PCI entry points
  (jsc#SLE-7953).
- drm/i915/gtt: Use NULL to encode scratch shadow entries
  (jsc#SLE-7953).
- drm/i915/gtt: Convert vm->scratch into an array (jsc#SLE-7953).
- drm/i915/gtt: Markup i915_ppgtt height (jsc#SLE-7953).
- drm/i915/tgl: Update DPLL clock reference register
  (jsc#SLE-7953).
- drm/i915/tgl: Add DPLL registers (jsc#SLE-7953).
- drm/i915/tgl: Add vbt value mapping for DDC Bus pin
  (jsc#SLE-7953).
- drm/i915/tgl: port to ddc pin mapping (jsc#SLE-7953).
- drm/i915/tgl: Add gmbus gpio pin to port mapping (jsc#SLE-7953).
- drm/i915/gen12: MBUS B credit change (jsc#SLE-7953).
- drm/i915/tgl: apply Display WA #1178 to fix type C dongles
  (jsc#SLE-7953).
- drm/i915/tgl: init ddi port A-C for Tiger Lake (jsc#SLE-7953).
- drm/i915/tgl: Add additional PHYs for Tiger Lake (jsc#SLE-7953).
- drm/i915/tgl: Add additional ports for Tiger Lake
  (jsc#SLE-7953).
- drm/i915/tgl: Add pll manager (jsc#SLE-7953).
- drm/i915/tgl: Add new pll ids (jsc#SLE-7953).
- drm/i915/tgl: Add power well to support 4th pipe (jsc#SLE-7953).
- drm/i915/tgl: Add power well support (jsc#SLE-7953).
- drm/i915/tgl: rename TRANSCODER_EDP_VDSC to use on transcoder A
  (jsc#SLE-7953).
- drm/i915/tgl: Check if pipe D is fused (jsc#SLE-7953).
- drm/i915/tgl: Add TGL PCI IDs (jsc#SLE-7953).
- drm/i915/tgl: Add TGL PCH detection in virtualized environment
  (jsc#SLE-7953).
- drm/i915/tgl: Introduce Tiger Lake PCH (jsc#SLE-7953).
- drm/i915/tgl: add initial Tiger Lake definitions (jsc#SLE-7953).
- drm/i915: Add 4th pipe and transcoder (jsc#SLE-7953).
- drm/i915: Don't overestimate 4:2:0 link symbol clock
  (jsc#SLE-7953).
- drm/i915: Copy name string into ring buffer for
  intel_update/disable_plane tracepoints (jsc#SLE-7953).
- drm/i915/guc: Drop redundant ctx param from kerneldoc
  (jsc#SLE-7953).
- drm/i915: Don't pass stack garbage to pcode in the second data
  register (jsc#SLE-7953).
- drm/i915: Use intel_ types in intel_atomic_commit()
  (jsc#SLE-7953).
- drm/i915: Use intel_ types in intel_{lock,modeset}_all_pipes()
  (jsc#SLE-7953).
- drm/i915: Polish intel_atomic_track_fbs() (jsc#SLE-7953).
- drm/i915: Polish intel_shared_dpll_swap_state() (jsc#SLE-7953).
- drm/i915: Simplify modeset_get_crtc_power_domains() arguments
  (jsc#SLE-7953).
- drm/i915: Check crtc_state->wm.need_postvbl_update before
  grabbing wm.mutex (jsc#SLE-7953).
- drm/i915: Use the "display core" power domain in vlv/chv
  set_cdclk() (jsc#SLE-7953).
- drm/i915/selftests: Hold the vma manager lock while modifying
  mmap_offset (jsc#SLE-7953).
- drm/i915/sdvo: Fix handling if zero hbuf size (jsc#SLE-7953).
- drm/i915/guc: Simplify guc client (jsc#SLE-7953).
- drm/i915/guc: Remove preemption support for current fw
  (jsc#SLE-7953).
- drm/i915/selftests: Ensure we don't clamp a random offset to
  32b (jsc#SLE-7953).
- drm/i915/gt: Drop the duplicate icl workaround (jsc#SLE-7953).
- drm/i915/ehl: Enable DDI-D (jsc#SLE-7953).
- drm/i915: Transition port type checks to phy checks
  (jsc#SLE-7953).
- drm/i915/gen11: Convert combo PHY logic to use new 'enum phy'
  namespace (jsc#SLE-7953).
- drm/i915/gen11: Program ICL_DPCLKA_CFGCR0 according to PHY
  (jsc#SLE-7953).
- drm/i915/gen11: Start distinguishing 'phy' from 'port'
  (jsc#SLE-7953).
- drm/i915: move intel_ddi_set_fia_lane_count to intel_tc.c
  (jsc#SLE-7953).
- drm/i915: fix include order in intel_tc.* (jsc#SLE-7953).
- drm/i915: make new intel_tc.c use uncore accessors
  (jsc#SLE-7953).
- drm/i915/icl: Fixed Input CSC Co-efficients for BT601/709
  (jsc#SLE-7953).
- drm/i915/icl: Fix Y pre-offset for Full Range YCbCr
  (jsc#SLE-7953).
- drm/i915/icl: Handle YCbCr to RGB conversion for BT2020 case
  (jsc#SLE-7953).
- drm/i915/execlists: Record preemption for selftests
  (jsc#SLE-7953).
- drm/i915: Remove unused i915_gem_context_lookup_engine
  (jsc#SLE-7953).
- drm/i915: add infrastructure to hold off preemption on a request
  (jsc#SLE-7953).
- drm/i915: enumerate scratch fields (jsc#SLE-7953).
- drm/i915/icl: Clear the shared port PLLs from the new crtc state
  (jsc#SLE-7953).
- drm/i915: Clear the shared PLL from the put_dplls() hook
  (jsc#SLE-7953).
- drm/i915/sdvo: Add helpers to get the cmd/status string
  (jsc#SLE-7953).
- drm/i915/sdvo: Shrink sdvo_cmd_names[] strings (jsc#SLE-7953).
- drm/i915/sdvo: Remove duplicate SET_INPUT_TIMINGS_PART1 cmd
  name string (jsc#SLE-7953).
- drm/i915/sdvo: Use named initializers for the SDVO command names
  (jsc#SLE-7953).
- drm/i915: Add icl mipi dsi properties (jsc#SLE-7953).
- drm/i915/hdcp: debug logs for sink related failures
  (jsc#SLE-7953).
- drm/i915/gt: Remove presumption of RCS0 (jsc#SLE-7953).
- drm/i915/gt: Apply RCS workarounds to the render class
  (jsc#SLE-7953).
- drm/i915/selftests: Fill in a little more of the dummy fence
  (jsc#SLE-7953).
- drm/i915/selftests: Set igt_spinner.gt for early exit
  (jsc#SLE-7953).
- drm/i915: Update DRIVER_DATE to 20190708 (jsc#SLE-7953).
- drm/i915/selftests: Reorder error cleanup for whitelist checking
  (jsc#SLE-7953).
- drm/i915: Explicitly track active fw_domain timers
  (jsc#SLE-7953).
- drm/i915: Pull assert_forcewake_active() underneath the lock
  (jsc#SLE-7953).
- drm/i915/gtt: Introduce release_pd_entry (jsc#SLE-7953).
- drm/i915/gtt: Setup phys pages for 3lvl pdps (jsc#SLE-7953).
- drm/i915/gtt: Tear down setup and cleanup macros for page dma
  (jsc#SLE-7953).
- drm/i915: Remove set but not used variable 'intel_dig_port'
  (jsc#SLE-7953).
- drm/i915: Remove set but not used variable 'encoder'
  (jsc#SLE-7953).
- drm/i915: Order assert forcewake test (jsc#SLE-7953).
- drm/i915/ehl: Add support for DPLL4 (v10) (jsc#SLE-7953).
- drm/i915: Clean up skl vs. icl plane formats (jsc#SLE-7953).
- drm/i915: Cosmetic fix for skl+ plane switch statement
  (jsc#SLE-7953).
- drm/i915: Deal with cpp==8 for g4x watermarks (jsc#SLE-7953).
- drm/i915: Program plane gamma ramps (jsc#SLE-7953).
- drm/i915: Disable sprite gamma on ivb-bdw (jsc#SLE-7953).
- drm/i915: Add windowing for primary planes on gen2/3 and chv
  (jsc#SLE-7953).
- drm/i915: Move dev_priv->pm_i{m, e}r into intel_gt
  (jsc#SLE-7953).
- drm/i915: Remove some legacy mmio accessors from interrupt
  handling (jsc#SLE-7953).
- drm/i915: Rework some interrupt handling functions to take
  intel_gt (jsc#SLE-7953).
- drm/i915: Show instdone for each engine in debugfs
  (jsc#SLE-7953).
- drm/i915/selftests: Be engine agnostic (jsc#SLE-7953).
- drm/i915/overlay: Stash the kernel context on initialisation
  (jsc#SLE-7953).
- drm/i915/hangcheck: Look at instdone for all engines
  (jsc#SLE-7953).
- drm/i915/selftests: Drain the freedlists between exec passes
  (jsc#SLE-7953).
- drm/i915/gt: Pull engine w/a initialisation into common
  (jsc#SLE-7953).
- drm/i915: Dump w/a lists on all engines (jsc#SLE-7953).
- drm/i915/guc: Upgrade to GuC 33.0.0 (jsc#SLE-7953).
- drm/i915/gtt: Handle double alloc failures (jsc#SLE-7953).
- drm/i915: Show support for accurate sw PMU busyness tracking
  (jsc#SLE-7953).
- drm/i915/gem: Defer obj->base.resv fini until RCU callback
  (jsc#SLE-7953).
- drm/i915/gt: Ignore forcewake acquisition for posting_reads
  (jsc#SLE-7953).
- drm/i915/gt: Assume we hold forcewake for execlists resume
  (jsc#SLE-7953).
- drm/i915/gt: Use caller provided forcewake for
  intel_mocs_init_engine (jsc#SLE-7953).
- drm/i915: Check caller held wakerefs in assert_forcewakes_active
  (jsc#SLE-7953).
- drm/i915: Flush the workqueue before draining (jsc#SLE-7953).
- drm/i915: Move the renderstate setup under gt/ (jsc#SLE-7953).
- drm/i915: Add N & CTS values for 10/12 bit deep color
  (jsc#SLE-7953).
- drm/i915: Use port clock to set correct N value (jsc#SLE-7953).
- drm/i915: Mark up vma->active as safe for use inside shrinkers
  (jsc#SLE-7953).
- drm/i915/execlists: Hesitate before slicing (jsc#SLE-7953).
- drm/i915/selftests: Lock the drm_mm while modifying
  (jsc#SLE-7953).
- drm/i915/selftests: Common live setup/teardown (jsc#SLE-7953).
- drm/i915/display: Handle lost primary_port across suspend
  (jsc#SLE-7953).
- drm/i915: synchronize_irq() against the actual irq
  (jsc#SLE-7953).
- drm/i915/gtt: Don't check PPGTT presence on PPGTT-only platforms
  (jsc#SLE-7953).
- Revert "drm/i915: Introduce private PAT management"
  (jsc#SLE-7953).
- drm/i915: Report if i915_active is still busy upon waiting
  (jsc#SLE-7953).
- drm/i915/ehl: Don't program PHY_MISC on EHL PHY C
  (jsc#SLE-7953).
- drm/i915/ehl: Add third combo PHY offset (jsc#SLE-7953).
- drm/i915/icl: Drop port parameter to icl_get_combo_buf_trans()
  (jsc#SLE-7953).
- drm/i915/guc: Avoid reclaim locks during reset (jsc#SLE-7953).
- drm/i915: WARN about invalid lane reversal in TBT-alt/DP-alt
  modes (jsc#SLE-7953).
- drm/i915: Remove unneeded disconnect in TypeC legacy port mode
  (jsc#SLE-7953).
- drm/i915: Add state verification for the TypeC port mode
  (jsc#SLE-7953).
- drm/i915: Keep the TypeC port mode fixed when the port is active
  (jsc#SLE-7953).
- drm/i915/icl: Reserve all required PLLs for TypeC ports
  (jsc#SLE-7953).
- drm/i915/icl: Split getting the DPLLs to port type specific
  functions (jsc#SLE-7953).
- drm/i915: Sanitize the shared DPLL find/reference interface
  (jsc#SLE-7953).
- drm/i915: Sanitize the shared DPLL reserve/release interface
  (jsc#SLE-7953).
- drm/i915: Keep the TypeC port mode fixed for detect/AUX
  transfers (jsc#SLE-7953).
- drm/i915: Fix the TypeC port mode sanitization during
  loading/resume (jsc#SLE-7953).
- drm/i915: Sanitize the TypeC connect/detect sequences
  (jsc#SLE-7953).
- drm/i915: Handle the TCCOLD power-down event (jsc#SLE-7953).
- drm/i915: Wait for TypeC PHY complete flag to clear in safe mode
  (jsc#SLE-7953).
- drm/i915: Unify the TypeC port notation in debug/error messages
  (jsc#SLE-7953).
- drm/i915: Use the correct AUX power domain in TypeC TBT-alt mode
  (jsc#SLE-7953).
- drm/i915: Don't enable the DDI-IO power in the TypeC TBT-alt
  mode (jsc#SLE-7953).
- drm/i915: Sanitize the terminology used for TypeC port modes
  (jsc#SLE-7953).
- drm/i915: Tune down WARNs about TBT AUX power well enabling
  (jsc#SLE-7953).
- drm/i915/icl: Add support to read out the TBT PLL HW state
  (jsc#SLE-7953).
- drm/i915: Use intel state as much as possible in wm code
  (jsc#SLE-7953).
- drm/i915: Pass intel state to plane functions as well
  (jsc#SLE-7953).
- drm/i915: Use intel_crtc_state in sanitize_watermarks() too
  (jsc#SLE-7953).
- drm/i915: Convert hw state verifier to take more intel state,
  v2 (jsc#SLE-7953).
- drm/i915: rework reading pipe disable fuses (jsc#SLE-7953).
- drm/i915: Make i945gm_vblank_work_func static (jsc#SLE-7953).
- drm/i915/ehl: Add voltage level requirement table
  (jsc#SLE-7953).
- drm/i915/ehl: Remove unsupported cd clocks (jsc#SLE-7953).
- drm/i915: Initialize drm_driver vblank funcs at compile time
  (jsc#SLE-7953).
- drm/i915: Nuke drm_driver irq vfuncs (jsc#SLE-7953).
- drm/i915: Switch to per-crtc vblank vfuncs (jsc#SLE-7953).
- drm/i915/selftests: Drop manual request wakerefs around
  hangcheck (jsc#SLE-7953).
- drm/i915/selftests: Serialise nop reset with retirement
  (jsc#SLE-7953).
- drm/i915: Check backlight type while doing eDP backlight
  initializaiton (jsc#SLE-7953).
- drm/i915/icl: Add missing device ID (jsc#SLE-7953).
- drm/i915/gt: Add some debug tracing for context pinning
  (jsc#SLE-7953).
- drm/i915/gt: Always call kref_init for the timeline
  (jsc#SLE-7953).
- drm/i915/gt: Drop stale commentary for timeline density
  (jsc#SLE-7953).
- drm/i915/selftests: Hold ref on request across waits
  (jsc#SLE-7953).
- drm/i915/guc: Add debug capture of GuC exception (jsc#SLE-7953).
- drm/i915/execlists: Convert recursive defer_request() into
  iterative (jsc#SLE-7953).
- drm/i915/ehl: Add missing VECS engine (jsc#SLE-7953).
- drm/i915/ehl: Add one additional PCH ID to MCC (jsc#SLE-7953).
  Refresh patches.suse/drm-i915-cml-Add-second-PCH-ID-for-CMP.patch
- drm/i915/gem: Clear read/write domains for GPU clear
  (jsc#SLE-7953).
- drm/i915/execlists: Always clear ring_pause if we do not submit
  (jsc#SLE-7953).
- drm/i915/blt: Remove recursive vma->lock (jsc#SLE-7953).
- drm/i915: Local debug BUG_ON for intel_wakeref (jsc#SLE-7953).
- drm/i915: Provide an i915_active.acquire callback
  (jsc#SLE-7953).
- drm/i915: Throw away the active object retirement complexity
  (jsc#SLE-7953).
- drm/i915: Track i915_active using debugobjects (jsc#SLE-7953).
- drm/i915: Remove waiting & retiring from shrinker paths
  (jsc#SLE-7953).
- drm/i915/guc: handle GuC messages received with CTB disabled
  (jsc#SLE-7953).
- drm/i915/guc: reorder enable/disable communication steps
  (jsc#SLE-7953).
- drm/i915/gt: Fixup kerneldoc parameters (jsc#SLE-7953).
- drm/i915/gt: Rename i915_gt_timelines (jsc#SLE-7953).
- drm/i915: Eliminate dual personality of i915_scratch_offset
  (jsc#SLE-7953).
- drm/i915: Make timelines gt centric (jsc#SLE-7953).
- drm/i915: Compartmentalize ring buffer creation (jsc#SLE-7953).
- drm/i915: Store ggtt pointer in intel_gt (jsc#SLE-7953).
- drm/i915: Compartmentalize i915_gem_init_ggtt (jsc#SLE-7953).
- drm/i915: Compartmentalize i915_ggtt_cleanup_hw (jsc#SLE-7953).
- drm/i915: Compartmentalize timeline_init/park/fini
  (jsc#SLE-7953).
- drm/i915: Convert i915_gem_flush_ggtt_writes to intel_gt
  (jsc#SLE-7953).
- drm/i915: Compartmentalize i915_gem_suspend/restore_gtt_mappings
  (jsc#SLE-7953).
- drm/i915: Store intel_gt backpointer in vm (jsc#SLE-7953).
- drm/i915: Make ggtt invalidation work on ggtt (jsc#SLE-7953).
- drm/i915: Compartmentalize i915_ggtt_init_hw (jsc#SLE-7953).
- drm/i915: Compartmentalize i915_ggtt_probe_hw (jsc#SLE-7953).
- drm/i915: Consolidate some open coded mmio rmw (jsc#SLE-7953).
- drm/i915: Convert i915_ppgtt_init_hw to intel_gt (jsc#SLE-7953).
- drm/i915: Store backpointer to intel_gt in the engine
  (jsc#SLE-7953).
- drm/i915: Convert gt workarounds to intel_gt (jsc#SLE-7953).
- drm/i915: Convert init_unused_rings to intel_gt (jsc#SLE-7953).
- drm/i915: Use intel_uncore_rmw in intel_gt_init_swizzling
  (jsc#SLE-7953).
- drm/i915: Convert i915_gem_init_swizzling to intel_gt
  (jsc#SLE-7953).
- drm/i915: Make i915_check_and_clear_faults take intel_gt
  (jsc#SLE-7953).
- drm/i915: Store some backpointers in struct intel_gt
  (jsc#SLE-7953).
- drm/i915: Move intel_gt initialization to a separate file
  (jsc#SLE-7953).
- drm/i915: Introduce struct intel_gt as replacement for anonymous
  i915->gt (jsc#SLE-7953).
- drm/i915: Convert intel_vgt_(de)balloon to uncore
  (jsc#SLE-7953).
- drm/i915/execlists: Keep virtual context alive until after we
  kick (jsc#SLE-7953).
- drm/i915/gtt: Defer address space cleanup to an RCU worker
  (jsc#SLE-7953).
- drm/i915/ehl/dsi: Enable AFE over PPI strap (jsc#SLE-7953).
- drm/i915/ehl/dsi: Set lane latency optimization for DW1
  (jsc#SLE-7953).
- drm/i915/selftests: Use request managed wakerefs (jsc#SLE-7953).
- drm/i915: Rings are always flushed (jsc#SLE-7953).
- drm/i915/execlists: Minimalistic timeslicing (jsc#SLE-7953).
- drm/i915: dynamically allocate forcewake domains (jsc#SLE-7953).
- drm/i915: skip forcewake actions on forcewake-less uncore
  (jsc#SLE-7953).
- drm/i915: kill uncore_to_i915 (jsc#SLE-7953).
- drm/i915: kill uncore_sanitize (jsc#SLE-7953).
- drm/i915: use vfuncs for reg_read/write_fw_domains
  (jsc#SLE-7953).
- drm/i915/ehl: Allow combo PHY A to drive a third external
  display (jsc#SLE-7953).
- drm/i915: Flush the execution-callbacks on retiring
  (jsc#SLE-7953).
- drm/i915: Signal fence completion from i915_request_wait
  (jsc#SLE-7953).
- commit 04e08b4
* Tue Dec 17 2019 yousaf.kaukab@suse.com
- PM / wakeup: Unexport wakeup_source_sysfs_{add,remove}()
  (jsc#SLE-9316).
- PM / wakeup: Register wakeup class kobj after device is added
  (jsc#SLE-9316).
- PM / wakeup: Fix sysfs registration error path (jsc#SLE-9316).
- commit 0972359
* Tue Dec 17 2019 yousaf.kaukab@suse.com
- thermal: qoriq: Add hwmon support (jsc#SLE-9316).
- thermal_hwmon: Add devres wrapper for thermal_add_hwmon_sysfs()
  (jsc#SLE-9316).
- thermal: qoriq: Do not report invalid temperature reading
  (jsc#SLE-9316).
- thermal: qoriq: Enable all sensors before registering them
  (jsc#SLE-9316).
- thermal: qoriq: Convert driver to use regmap API (jsc#SLE-9316).
- thermal: qoriq: Drop unnecessary drvdata cleanup (jsc#SLE-9316).
- thermal: qoriq: Pass data to qoriq_tmu_calibration() directly
  (jsc#SLE-9316).
- thermal: qoriq: Pass data to qoriq_tmu_register_tmu_zone()
  directly (jsc#SLE-9316).
- thermal: qoriq: Embed per-sensor data into struct qoriq_tmu_data
  (jsc#SLE-9316).
- thermal: qoriq: Add local struct qoriq_sensor pointer
  (jsc#SLE-9316).
- thermal: qoriq: Don't store struct thermal_zone_device reference
  (jsc#SLE-9316).
- thermal: qoriq: Add local struct device pointer (jsc#SLE-9316).
- thermal: qoriq: add thermal monitor unit version 2 support
  (jsc#SLE-9316).
- thermal: qoriq: Use __maybe_unused instead of #if
  CONFIG_PM_SLEEP (jsc#SLE-9316).
- thermal: qoriq: Use devm_platform_ioremap_resource() instead
  of of_iomap() (jsc#SLE-9316).
- thermal: qoriq: Fix error path of calling
  qoriq_tmu_register_tmu_zone fail (jsc#SLE-9316).
- thermal: qoriq: Add clock operations (jsc#SLE-9316).
- commit 14652c6
* Tue Dec 17 2019 ggherdovich@suse.cz
- Delete
  patches.suse/cpufreq-intel_pstate-use-setpoint-of-10-on-servers.patch.
  Before v4.14 the intel_pstate powersave frequency governor used a
  P.I.D. controller based algorithm to select frequencies, and this patch
  was necessary to tune the "setpoint" parameter to a more aggressive value
  than in mainline kernel.
  From v4.14 onwards said algorithm is replaced by another where the
  frequency is proportional to non-idle time observed in the recent past,
  and this patch tuning pid_params.setpoint is thus obsolete.
- commit 80607d5
* Tue Dec 17 2019 ggherdovich@suse.cz
- cpufreq: intel_pstate: Temporarily boost P-state when exiting
  from idle (bnc#1066110, bnc#1066845).
- commit 0ab1412
* Tue Dec 17 2019 ggherdovich@suse.cz
- cpufreq, intel_pstate: Ramp up frequency faster when utilisation
  reaches setpoint (bsc#1068680).
- commit 741462c
* Tue Dec 17 2019 ggherdovich@suse.cz
- cpufreq: intel_pstate: Revert upstream changes to iowait
  boosting (bsc#1131437).
- commit 08e273b
* Tue Dec 17 2019 yousaf.kaukab@suse.com
- PM / wakeup: Show wakeup sources stats in sysfs (jsc#SLE-9316).
- PM / wakeup: Use wakeup_source_register() in wakelock.c
  (jsc#SLE-9316).
- PM / wakeup: Drop wakeup_source_init(), wakeup_source_prepare()
  (jsc#SLE-9316).
- commit 4d80f94
* Tue Dec 17 2019 yousaf.kaukab@suse.com
- rtc: fsl-ftm-alarm: remove select FSL_RCPM and default y from
  Kconfig (jsc#SLE-9316).
- mmc: sdhci: fix up CMD12 sending (jsc#SLE-9316).
- soc: fsl: add RCPM driver (jsc#SLE-9316).
- PM: wakeup: Add routine to help fetch wakeup source object
  (jsc#SLE-9316).
- mmc: sdhci-of-esdhc: poll ESDHC_FLUSH_ASYNC_FIFO bit until
  completion (jsc#SLE-9316).
- spi: spi-fsl-qspi: Introduce variable to fix different invalid
  master Id (jsc#SLE-9316).
- rtc: fsl-ftm-alarm: add FTM alarm driver (jsc#SLE-9316).
- mtd: spi-nor: Add support for mt35xu02g (jsc#SLE-9316).
- mmc: sdhci-of-esdhc: add erratum A011334 support in ls1028a
  1.0 SoC (jsc#SLE-9316).
- soc: fsl: guts: Add definition for LS1028A (jsc#SLE-9316).
- spi: fsl-qspi: Enhance binding to extend example for flash entry
  (jsc#SLE-9316).
- commit bfef95e
* Tue Dec 17 2019 jlee@suse.com
- Refresh and enable
  patches.suse/0004-MODSIGN-checking-the-blacklisted-hash-before-loading.patch.
  (fate#316531)
- commit d8c86dc
* Tue Dec 17 2019 jlee@suse.com
- Refresh and enable
  patches.suse/0003-MODSIGN-load-blacklist-from-MOKx.patch.
  (fate#316531)
- commit 9e30e45
* Tue Dec 17 2019 yousaf.kaukab@suse.com
- enetc: remove variable 'tc_max_sized_frame' set but not used
  (jsc#SLE-9316).
- enetc: add software timestamping (jsc#SLE-9316).
- enetc: disable EEE autoneg by default (jsc#SLE-9316).
- enetc: add support Credit Based Shaper(CBS) for hardware offload
  (jsc#SLE-9316).
- enetc: make enetc_setup_tc_mqprio static (jsc#SLE-9316).
- enetc: update TSN Qbv PSPEED set according to adjust link speed
  (jsc#SLE-9316).
- enetc: Configure the Time-Aware Scheduler via tc-taprio offload
  (jsc#SLE-9316).
- enetc: fix return value for enetc_ioctl() (jsc#SLE-9316).
- enetc: ethtool: add wake-on-lan callbacks (jsc#SLE-9316).
- enetc: add ioctl() support for PHY-related ops (jsc#SLE-9316).
- commit c54330b
* Mon Dec 16 2019 jack@suse.cz
- Update tags in
  patches.suse/ext4-add-more-paranoia-checking-in-ext4_expand_extra.patch
  (bnc#1151927 bsc#1159297 CVE-2019-19767 5.3.15).
- commit a5d00e3
* Mon Dec 16 2019 jgross@suse.com
- xen/blkback: Avoid unmapping unmapped grant pages (bsc#1065600).
- commit d227d91
* Mon Dec 16 2019 tiwai@suse.de
- staging: vchiq: call unregister_chrdev_region() when driver
  registration fails (git-fixes).
- xhci: make sure interrupts are restored to correct state
  (git-fixes).
- xhci: Increase STS_HALT timeout in xhci_suspend() (git-fixes).
- usb: xhci: only set D3hot for pci device (git-fixes).
- xhci: Fix memory leak in xhci_add_in_port() (git-fixes).
- usb: dwc3: gadget: Fix logical condition (git-fixes).
- USB: adutux: fix interface sanity check (git-fixes).
- USB: idmouse: fix interface sanity checks (git-fixes).
- USB: serial: io_edgeport: fix epic endpoint lookup (git-fixes).
- usb: mon: Fix a deadlock in usbmon between mmap and read
  (git-fixes).
- usb: typec: fix use after free in typec_register_port()
  (git-fixes).
- usb: roles: fix a potential use after free (git-fixes).
- virtio-balloon: fix managed page counts when migrating pages
  between zones (git-fixes).
- vfio/pci: call irq_bypass_unregister_producer() before freeing
  irq (git-fixes).
- tools: PCI: Fix fd leakage (git-fixes).
- stm class: Lose the protocol driver when dropping its reference
  (git-fixes).
- spi: rspi: Use platform_get_irq_byname_optional() for optional
  irqs (git-fixes).
- commit 6f16787
* Mon Dec 16 2019 tiwai@suse.de
- staging: rtl8712: fix interface sanity check (git-fixes).
- staging: rtl8188eu: fix interface sanity check (git-fixes).
- soc: aspeed: Fix snoop_file_poll()'s return type (git-fixes).
- soc: renesas: Add missing check for non-zero product register
  address (git-fixes).
- serial: 8250-mtk: Use platform_get_irq_optional() for optional
  irq (git-fixes).
- phy: qcom-usb-hs: Fix extcon double register after power cycle
  (git-fixes).
- phy: ti: gmii-sel: fix mac tx internal delay for rgmii-rxid
  (git-fixes).
- phy: renesas: rcar-gen3-usb2: Fix sysfs interface of "role"
  (git-fixes).
- rfkill: allocate static minor (git-fixes).
- phy: renesas: rcar-gen3-usb2: Use platform_get_irq_optional()
  for optional irq (git-fixes).
- software node: Get reference to parent swnode in get_parent op
  (git-fixes).
- driver core: platform: Add platform_get_irq_byname_optional()
  (git-fixes).
- commit 3dd636b
* Mon Dec 16 2019 mkubecek@suse.cz
- config: refresh
- only update headers
- commit 308eb35
* Mon Dec 16 2019 ykaukab@suse.de
- PCI: layerscape: Add LS1028a support (jsc#SLE-9316).
- PCI: layerscape: Add CONFIG_PCI_LAYERSCAPE_EP to build EP/RC
  separately (jsc#SLE-9316).
- PCI: dwc: Return directly when num-lanes is not found
  (jsc#SLE-9316).
- commit a994a9b
* Mon Dec 16 2019 tiwai@suse.de
- moduleparam: fix parameter description mismatch (git-fixes).
- net: wireless: ti: remove local VENDOR_ID and DEVICE_ID
  definitions (git-fixes).
- net: wireless: ti: wl1251 use new SDIO_VENDOR_ID_TI_WL1251
  definition (git-fixes).
- mmc: host: omap_hsmmc: add code for special init of wl1251 to
  get rid of pandora_wl1251_init_card (git-fixes).
- net: wireless: ti: wl1251 add device tree support (git-fixes).
- commit 55a0d46
* Mon Dec 16 2019 tiwai@suse.de
- interconnect: qcom: sdm845: Walk the list safely on node removal
  (git-fixes).
- commit dc37ad8
* Mon Dec 16 2019 tiwai@suse.de
- iio: adc: max9611: Fix too short conversion time delay
  (git-fixes).
- iio: imu: inv_mpu6050: fix temperature reporting using bad unit
  (git-fixes).
- iio: adc: ad7124: Enable internal reference (git-fixes).
- iio: adc: ad7606: fix reading unnecessary data from device
  (git-fixes).
- genalloc: Fix a set of docs build warnings (git-fixes).
- commit f2d6240
* Mon Dec 16 2019 tiwai@suse.de
- firmware: arm_scmi: Avoid double free in error flow (git-fixes).
- commit 83c312d
* Mon Dec 16 2019 tiwai@suse.de
- drm/nouveau/kms/nv50-: Limit MST BPC to 8 (git-fixes).
- drm/nouveau/kms/nv50-: Store the bpc we're using in
  nv50_head_atom (git-fixes).
- drm/nouveau/kms/nv50-: Call outp_atomic_check_view() before
  handling PBN (git-fixes).
- drm: meson: venc: cvbs: fix CVBS mode matching (git-fixes).
- drm/mcde: dsi: Fix invalid pointer dereference if panel cannot
  be found (git-fixes).
- drm/dp_mst: Correct the bug in drm_dp_update_payload_part1()
  (git-fixes).
- drm/mgag200: Store flags from PCI driver data in device
  structure (git-fixes).
- drm/mgag200: Extract device type from flags (git-fixes).
- commit 2452bc1
* Mon Dec 16 2019 tiwai@suse.de
- drm/amdgpu/vi: silence an uninitialized variable warning
  (git-fixes).
- commit 45e781e
* Mon Dec 16 2019 tiwai@suse.de
- drm/amd/display: add default clocks if not able to fetch them
  (git-fixes).
- drm/msm: Sanitize the modeset_is_locked checks in dpu
  (git-fixes).
- drm/msm: include linux/sched/task.h (git-fixes).
- drm/amdgpu: fix bad DMA from INTERRUPT_CNTL2 (git-fixes).
- drm/radeon: fix bad DMA from INTERRUPT_CNTL2 (git-fixes).
- drm: msm: a6xx: fix debug bus register configuration
  (git-fixes).
- commit 42a4df1
* Mon Dec 16 2019 tiwai@suse.de
- drm/tegra: Fix ordering of cleanup code (git-fixes).
- drm: Don't free jobs in wait_event_interruptible() (git-fixes).
- drm/rockchip: Round up _before_ giving to the clock framework
  (git-fixes).
- drm/amd/display: fix struct init in update_bounding_box
  (git-fixes).
- drm/amdgpu/mn: fix documentation for amdgpu_mn_read_lock
  (git-fixes).
- Revert "drm/amdgpu/nbio7.4: add hw bug workaround for vega20"
  (git-fixes).
- drm: rcar_lvds: Fix color mismatches on R-Car H2 ES2.0 and later
  (git-fixes).
- drm/mcde: Fix reference to DOC comment (git-fixes).
- Revert "drm/sun4i: dsi: Change the start delay calculation"
  (git-fixes).
- drm: panel-lvds: Potential Oops in probe error handling
  (git-fixes).
- commit 8624fb2
* Mon Dec 16 2019 tiwai@suse.de
- dmaengine: ti: edma: fix missed failure handling (git-fixes).
- drm/v3d: don't leak bin job if v3d_job_init fails (git-fixes).
- drm: mst: Fix query_payload ack reply struct (git-fixes).
- commit 5a5f2fc
* Mon Dec 16 2019 ykaukab@suse.de
- gpio: mpc8xxx: Add platform device to gpiochip->parent
  (jsc#SLE-9316).
- gpio/mpc8xxx: fix qoriq GPIO reading (jsc#SLE-9316).
- gpio/mpc8xxx: change irq handler from chained to normal
  (jsc#SLE-9316).
- gpio: mpc8xxx: add ls1088a platform special function
  (jsc#SLE-9316).
- gpio: mpc8xxx: Add ls1028a device specify function
  (jsc#SLE-9316).
- commit 748b19d
* Mon Dec 16 2019 tiwai@suse.de
- Update patch reference for ALSA timer fix (CVE-2019-19807 bsc#1159281)
- commit fdd89ba
* Mon Dec 16 2019 nsaenzjulienne@suse.de
- PCI: rockchip: Fix IO outbound ATU register number (git-fixes).
- commit fa4971b
* Mon Dec 16 2019 tiwai@suse.de
- rpm/kernel-subpackage-spec: Fix empty Recommends tag (bsc#1143959)
- commit 3fd22e2
* Mon Dec 16 2019 bp@suse.de
- crypto: ccp - Release all allocated memory if sha type is
  invalid (bsc#1156259 CVE-2019-18808).
- commit 9a2a2b6
* Mon Dec 16 2019 jslaby@suse.cz
- Linux 5.3.16 (bnc#1151927 5.3.16).
- Input: Fix memory leak in psxpad_spi_probe (bnc#1151927 5.3.16).
- io_uring: ensure req->submit is copied when req is deferred
  (bnc#1151927 5.3.16).
- CIFS: Fix NULL-pointer dereference in smb2_push_mandatory_locks
  (bnc#1151927 5.3.16).
- Input: synaptics-rmi4 - don't increment rmiaddr for SMBus
  transfers (bnc#1151927 5.3.16).
- Input: goodix - add upside-down quirk for Teclast X89 tablet
  (bnc#1151927 5.3.16).
- nfsd: Ensure CLONE persists data and metadata changes to the
  target file (bnc#1151927 5.3.16).
- nfsd: restore NFSv3 ACL support (bnc#1151927 5.3.16).
- io_uring: transform send/recvmsg() -ERESTARTSYS to -EINTR
  (bnc#1151927 5.3.16).
- fuse: verify nlink (bnc#1151927 5.3.16).
- fuse: verify attributes (bnc#1151927 5.3.16).
- arm64: dts: exynos: Revert "Remove unneeded address space
  mapping for soc node" (bnc#1151927 5.3.16).
- tty: vt: keyboard: reject invalid keycodes (bnc#1151927 5.3.16).
- serial: stm32: fix clearing interrupt error flags (bnc#1151927
  5.3.16).
- serial: serial_core: Perform NULL checks for break_ctl ops
  (bnc#1151927 5.3.16).
- serial: ifx6x60: add missed pm_runtime_disable (bnc#1151927
  5.3.16).
- serial: pl011: Fix DMA ->flush_buffer() (bnc#1151927 5.3.16).
- x86/PCI: Avoid AMD FCH XHCI USB PME# from D0 defect (bnc#1151927
  5.3.16).
- x86/mm/32: Sync only to VMALLOC_END in vmalloc_sync_all()
  (bnc#1151927 5.3.16).
- Input: synaptics - switch another X1 Carbon 6 to RMI/SMbus
  (bnc#1151927 5.3.16).
- sparc64: implement ioremap_uc (bnc#1151927 5.3.16).
- jbd2: Fix possible overflow in jbd2_log_space_left()
  (bnc#1151927 5.3.16).
- drm/msm: fix memleak on release (bnc#1151927 5.3.16).
- drm: damage_helper: Fix race checking plane->state->fb
  (bnc#1151927 5.3.16).
- drm/i810: Prevent underflow in ioctl (bnc#1151927 5.3.16).
- binder: Handle start==NULL in binder_update_page_range()
  (bnc#1151927 5.3.16).
- binder: Prevent repeated use of ->mmap() via NULL mapping
  (bnc#1151927 5.3.16).
- binder: Fix race between mmap() and binder_alloc_print_pages()
  (bnc#1151927 5.3.16).
- lp: fix sparc64 LPSETTIMEOUT ioctl (bnc#1151927 5.3.16).
- blacklist.conf: remove it
- coresight: etm4x: Fix input validation for sysfs (bnc#1151927
  5.3.16).
- usb: gadget: u_serial: add missing port entry locking
  (bnc#1151927 5.3.16).
- cpufreq: imx-cpufreq-dt: Correct i.MX8MN's default speed grade
  value (bnc#1151927 5.3.16).
- perf scripts python: exported-sql-viewer.py: Fix use of TRUE
  with SQLite (bnc#1151927 5.3.16).
- crypto: ccp - fix uninitialized list head (bnc#1151927 5.3.16).
- KVM: PPC: Book3S HV: XIVE: Fix potential page leak on error path
  (bnc#1151927 5.3.16).
- KVM: PPC: Book3S HV: XIVE: Free previous EQ page when setting
  up a new one (bnc#1151927 5.3.16).
- KVM: x86: Grab KVM's srcu lock when setting nested state
  (bnc#1151927 5.3.16).
- KVM: x86: do not modify masked bits of shared MSRs (bnc#1151927
  5.3.16).
- KVM: arm/arm64: vgic: Don't rely on the wrong pending table
  (bnc#1151927 5.3.16).
- KVM: PPC: Book3S HV: XIVE: Set kvm->arch.xive when VPs are
  allocated (bnc#1151927 5.3.16).
- KVM: nVMX: Always write vmcs02.GUEST_CR3 during nested VM-Enter
  (bnc#1151927 5.3.16).
- sched/core: Avoid spurious lock dependencies (bnc#1151927
  5.3.16).
- perf/core: Consistently fail fork on allocation failures
  (bnc#1151927 5.3.16).
- net: ep93xx_eth: fix mismatch of request_mem_region in remove
  (bnc#1151927 5.3.16).
- ravb: implement MTU change while device is up (bnc#1151927
  5.3.16).
- iwlwifi: pcie: don't consider IV len in A-MSDU (bnc#1151927
  5.3.16).
- xfrm: release device reference for invalid state (bnc#1151927
  5.3.16).
- rsxx: add missed destroy_workqueue calls in remove (bnc#1151927
  5.3.16).
- afs: Fix race in commit bulk status fetch (bnc#1151927 5.3.16).
- MIPS: SGI-IP27: fix exception handler replication (bnc#1151927
  5.3.16).
- selftests: kvm: fix build with glibc >= 2.30 (bnc#1151927
  5.3.16).
- drm/sun4i: tcon: Set min division of TCON0_DCLK to 1
  (bnc#1151927 5.3.16).
- audit_get_nd(): don't unlock parent too early (bnc#1151927
  5.3.16).
- Refresh patches.suse/vfs-add-super_operations-get_inode_dev.
- exportfs_decode_fh(): negative pinned may become positive
  without the parent locked (bnc#1151927 5.3.16).
- cgroup: don't put ERR_PTR() into fc->root (bnc#1151927 5.3.16).
- autofs: fix a leak in autofs_expire_indirect() (bnc#1151927
  5.3.16).
- Input: cyttsp4_core - fix use after free bug (bnc#1151927
  5.3.16).
- commit 8b8fa5f
* Mon Dec 16 2019 jslaby@suse.cz
- Update
  patches.suse/0001-crypto-af_alg-cast-ki_complete-ternary-op-to-int.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/0001-crypto-ecdh-fix-big-endian-bug-in-ECC-library.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/0055-rbd-silence-bogus-uninitialized-warning-in-rbd_object_map_update_finish.patch
  (jsc#SES-1134 bnc#1151927 5.3.16).
- Update patches.suse/ALSA-hda-Add-Cometlake-S-PCI-ID.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-Add-mute-led-support-for-HP-ProBook-645-G4.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-Fix-pending-unsol-events-at-shutdown.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-Modify-stream-stripe-mask-only-when-needed.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-hdmi-fix-pin-setup-on-Tigerlake.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-realtek-Dell-headphone-has-noise-on-unmute-.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-realtek-Enable-internal-speaker-of-ASUS-UX4.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-realtek-Enable-the-headset-mic-on-a-Xiaomi-.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-pcm-Fix-stream-lock-usage-in-snd_pcm_period_ela.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-pcm-oss-Avoid-potential-buffer-overflows.patch
  (git-fixes bnc#1151927 5.3.16).
- Update patches.suse/CIFS-Fix-SMB2-oplock-break-processing.patch
  (bsc#1154355 bnc#1151927 5.3.16).
- Update
  patches.suse/Input-synaptics-rmi4-re-enable-IRQs-in-f34v7_do_refl.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/NFC-nxp-nci-Fix-NULL-pointer-dereference-after-I2C-c.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/RDMA-hns-Correct-the-value-of-HNS_ROCE_HEM_CHUNK_LEN.patch
  (jsc#SLE-8449 bnc#1151927 5.3.16).
- Update
  patches.suse/RDMA-hns-Correct-the-value-of-srq_desc_size.patch
  (jsc#SLE-8449 bnc#1151927 5.3.16).
- Update
  patches.suse/RDMA-qib-Validate-show-store-callbacks-before-callin.patch
  (jsc#SLE-8449 bnc#1151927 5.3.16).
- Update
  patches.suse/SUNRPC-Avoid-RPC-delays-when-exiting-suspend.patch
  (bsc#1154353 bnc#1151927 5.3.16).
- Update
  patches.suse/aio-Fix-io_pgetevents-struct-__compat_aio_sigset-lay.patch
  (bsc#1158373 bnc#1151927 5.3.16).
- Update
  patches.suse/arm64-tegra-Fix-active-low-warning-for-Jetson-TX1-re.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/block-check-bi_size-overflow-before-merge.patch
  (bsc#1158370 bnc#1151927 5.3.16).
- Update
  patches.suse/can-slcan-Fix-use-after-free-Read-in-slcan_open.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/can-ucan-fix-non-atomic-allocation-in-completion-han.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/crypto-atmel-aes-Fix-IV-handling-when-req-nbytes-ivs.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/crypto-crypto4xx-fix-double-free-in-crypto4xx_destro.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/crypto-geode-aes-switch-to-skcipher-for-cbc-aes-fall.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/crypto-user-fix-memory-leak-in-crypto_report.patch
  (CVE-2019-19062 bsc#1157333 git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/crypto-user-fix-memory-leak-in-crypto_reportstat.patch
  (CVE-2019-19050 bsc#1157336 git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/drm-mcde-Fix-an-error-handling-path-in-mcde_probe.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ecryptfs-fix-unlink-and-rmdir-in-face-of-underlying-.patch
  (bsc#1158374 bnc#1151927 5.3.16).
- Update
  patches.suse/edac-ghes-fix-locking-and-memory-barrier-issues.patch
  (bsc#1152489 bnc#1151927 5.3.16).
- Update
  patches.suse/i2c-core-fix-use-after-free-in-of_i2c_notify.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/iomap-Fix-pipe-page-leakage-during-splicing.patch
  (bsc#1158383 bnc#1151927 5.3.16).
- Update patches.suse/kernfs-fix-ino-wrap-around-detection.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/kselftest-Fix-NULL-INSTALL_PATH-for-TARGETS-runlist.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/kvm-x86-fix-out-of-bounds-write-in-kvm_get_emulated_cpuid-cve-2019-19332
  (CVE-2019-19332 bsc#1158827 bnc#1151927 5.3.16).
- Update
  patches.suse/kvm-x86-fix-presentation-of-tsx-feature-in-arch_capabilities
  (CVE-2019-19338 bsc#1158954 bnc#1151927 5.3.16).
- Update
  patches.suse/kvm-x86-remove-a-spurious-export-of-a-static-function
  (bsc#1158954 bnc#1151927 5.3.16).
- Update
  patches.suse/md-raid0-Fix-an-error-message-in-raid0_make_request.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/media-rc-mark-input-device-as-pointing-stick.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/net-hns3-fix-ETS-bandwidth-validation-bug.patch
  (bsc#1154353 bnc#1151927 5.3.16).
- Update
  patches.suse/net-hns3-reallocate-SSU-buffer-size-when-pfc_en-chan.patch
  (bsc#1154353 bnc#1151927 5.3.16).
- Update
  patches.suse/perf-script-Fix-invalid-LBR-binary-mismatch-error.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/rsi-release-skb-if-rsi_prepare_beacon-fails.patch
  (CVE-2019-19071,bsc#1157067 bnc#1151927 5.3.16).
- Update
  patches.suse/sched-pelt-Fix-update-of-blocked-PELT-ordering.patch
  (bnc#1155798 (CPU scheduler functional and performance
  backports) bnc#1151927 5.3.16).
- Update
  patches.suse/spi-Fix-NULL-pointer-when-setting-SPI_CS_HIGH-for-GP.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/spi-Fix-SPI_CS_HIGH-setting-when-using-native-and-GP.patch
  (git-fixes bnc#1151927 5.3.16).
- Update patches.suse/spi-atmel-Fix-CS-high-support.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/spi-spi-fsl-qspi-Clear-TDH-bits-in-FLSHCR-register.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/spi-stm32-qspi-Fix-kernel-oops-when-unbinding-driver.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/thermal-Fix-deadlock-in-thermal-thermal_zone_device_.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/time-Zero-the-upper-32-bits-in-__kernel_timespec-on-.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/tty-serial-fsl_lpuart-use-the-sg-count-from-dma_map_.patch
  (git-fixes bnc#1151927 5.3.16).
- Update patches.suse/tty-serial-msm_serial-Fix-flow-control.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/vcs-prevent-write-access-to-vcsu-devices.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/watchdog-aspeed-Fix-clock-behaviour-for-ast2600.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/x86-resctrl-fix-potential-lockdep-warning.patch
  (bsc#1152489 bnc#1151927 5.3.16).
- commit f542645
* Mon Dec 16 2019 jlee@suse.com
- Delete
  patches.suse/0002-MODSIGN-print-appropriate-status-message-when-gettin.patch.
  Be replaced by
  patches.suse/0001-efi-add-a-function-to-convert-the-status-code-to-a-s.patch
  patches.suse/0002-efi-show-error-messages-only-when-loading-certificat.patch
- commit 167e118
* Mon Dec 16 2019 jlee@suse.com
- efi: show error messages only when loading certificates is
  failed (fate#316531, bnc#854875).
- commit 9ff07ee
* Mon Dec 16 2019 jlee@suse.com
- efi: add a function to convert the status code to a string
  (fate#316531, bnc#854875).
- commit cd7aba4
* Mon Dec 16 2019 msuchanek@suse.de
- Refresh patches.suse/ibmvnic-Fix-typo-in-retry-check.patch.
- commit f89f0b0
* Sun Dec 15 2019 mkubecek@suse.cz
- config: refresh
- update headers
- drop options which are no longer accessible
- commit 82ffcd4
* Sun Dec 15 2019 mkubecek@suse.cz
- series.conf: refresh
  update mainline references and resort:
  patches.suse/scsi-qla2xxx-Add-debug-dump-of-LOGO-payload-and-ELS-.patch
  patches.suse/scsi-qla2xxx-Added-support-for-MPI-and-PEP-regions-f.patch
  patches.suse/scsi-qla2xxx-Allow-PLOGI-in-target-mode.patch
  patches.suse/scsi-qla2xxx-Change-discovery-state-before-PLOGI.patch
  patches.suse/scsi-qla2xxx-Configure-local-loop-for-N2N-target.patch
  patches.suse/scsi-qla2xxx-Correctly-retrieve-and-interpret-active.patch
  patches.suse/scsi-qla2xxx-Don-t-call-qlt_async_event-twice.patch
  patches.suse/scsi-qla2xxx-Don-t-defer-relogin-unconditonally.patch
  patches.suse/scsi-qla2xxx-Drop-superfluous-INIT_WORK-of-del_work.patch
  patches.suse/scsi-qla2xxx-Fix-PLOGI-payload-and-ELS-IOCB-dump-len.patch
  patches.suse/scsi-qla2xxx-Fix-incorrect-SFUB-length-used-for-Secu.patch
  patches.suse/scsi-qla2xxx-Ignore-NULL-pointer-in-tcm_qla2xxx_free.patch
  patches.suse/scsi-qla2xxx-Ignore-PORT-UPDATE-after-N2N-PLOGI.patch
  patches.suse/scsi-qla2xxx-Initialize-free_work-before-flushing-it.patch
  patches.suse/scsi-qla2xxx-Send-Notify-ACK-after-N2N-PLOGI.patch
  patches.suse/scsi-qla2xxx-Use-explicit-LOGO-in-target-mode.patch
- commit b803547
* Sat Dec 14 2019 tiwai@suse.de
- ACPI: PM: Avoid attaching ACPI PM domain to certain devices
  (git-fixes).
- ALSA: hda/realtek - Line-out jack doesn't work on a Dell AIO
  (git-fixes).
- ALSA: hda/hdmi - Fix duplicate unref of pci_dev (git-fixes).
- ALSA: fireface: fix return value in error path of isochronous
  resources reservation (git-fixes).
- ALSA: oxfw: fix return value in error path of isochronous
  resources reservation (git-fixes).
- ALSA: echoaudio: simplify get_audio_levels (git-fixes).
- dma-buf: Fix memory leak in sync_file_merge() (git-fixes).
- commit 1ccb9b7
* Fri Dec 13 2019 lduncan@suse.com
- scsi: bfa: release allocated memory in case of error
  (CVE-2019-19066 bsc#1157303).
- commit 8663bfd
* Fri Dec 13 2019 tiwai@suse.de
- spi: Fix NULL pointer when setting SPI_CS_HIGH for GPIO CS
  (git-fixes).
- commit be424a0
* Fri Dec 13 2019 tiwai@suse.de
- vcs: prevent write access to vcsu devices (git-fixes).
- tty: serial: pch_uart: correct usage of dma_unmap_sg
  (git-fixes).
- tty: serial: imx: use the sg count from dma_map_sg (git-fixes).
- tty: serial: fsl_lpuart: use the sg count from dma_map_sg
  (git-fixes).
- tty: serial: msm_serial: Fix flow control (git-fixes).
- tipc: fix wrong timeout input for tipc_wait_for_cond()
  (git-fixes).
- tipc: fix wrong socket reference counter after tipc_sk_timeout()
  returns (git-fixes).
- commit b38c936
* Fri Dec 13 2019 tiwai@suse.de
- tipc: fix potential memory leak in __tipc_sendmsg() (git-fixes).
- spi: atmel: Fix CS high support (git-fixes).
- spi: dw: Fix Designware SPI loopback (git-fixes).
- spi: atmel: fix handling of cs_change set on non-last xfer
  (git-fixes).
- spi: Fix SPI_CS_HIGH setting when using native and GPIO CS
  (git-fixes).
- spi: spi-fsl-qspi: Clear TDH bits in FLSHCR register
  (git-fixes).
- spi: stm32-qspi: Fix kernel oops when unbinding driver
  (git-fixes).
- tipc: update mon's self addr when node addr generated
  (git-fixes).
- tipc: reduce sensitive to retransmit failures (git-fixes).
- commit 03f889b
* Fri Dec 13 2019 tiwai@suse.de
- platform/chrome: wilco_ec: fix use after free issue (git-fixes).
- rtc: pm8xxx: update kerneldoc for struct pm8xxx_rtc (git-fixes).
- rtc: msm6242: Fix reading of 10-hour digit (git-fixes).
- rtc: bd70528: Add MODULE ALIAS to autoload module (git-fixes).
- rtc: brcmstb-waketimer: add missed clk_disable_unprepare
  (git-fixes).
- rtc: disable uie before setting time and enable after
  (git-fixes).
- pstore: Make pstore_choose_compression() static (git-fixes).
- pinctrl: lewisburg: Update pin list according to v1.1v6
  (git-fixes).
- pinctrl: armada-37xx: Fix irq mask access in
  armada_37xx_irq_set_type() (git-fixes).
- pinctrl: samsung: Fix device node refcount leaks in init code
  (git-fixes).
- commit 12b6898
* Fri Dec 13 2019 tiwai@suse.de
- of: unittest: fix memory leak in attach_node_and_children
  (git-fixes).
- of: overlay: add_changeset_property() memory leak (git-fixes).
- pinctrl: samsung: Fix device node refcount leaks in S3C64xx
  wakeup controller init (git-fixes).
- pinctrl: samsung: Fix device node refcount leaks in S3C24xx
  wakeup controller init (git-fixes).
- pinctrl: samsung: Fix device node refcount leaks in Exynos
  wakeup controller init (git-fixes).
- pinctrl: samsung: Add of_node_put() before return in error path
  (git-fixes).
- pinctrl: sh-pfc: Do not use platform_get_irq() to count
  interrupts (git-fixes).
- pinctrl: sh-pfc: Fix PINMUX_IPSR_PHYS() to set GPSR (git-fixes).
- pinctrl: rza2: Fix gpio name typos (git-fixes).
- hwrng: omap3-rom - Fix missing clock by probing with device tree
  (git-fixes).
- commit d48f475
* Fri Dec 13 2019 tiwai@suse.de
- clk: Add clk_hw_unregister_composite helper function definition
  (git-fixes).
- clk: Fix memory leak in clk_unregister() (git-fixes).
- clk: pxa: fix one of the pxa RTC clocks (git-fixes).
- clk: sprd: Use IS_ERR() to validate the return value of
  syscon_regmap_lookup_by_phandle() (git-fixes).
- clk: qcom: smd: Add missing pnoc clock (git-fixes).
- clk: imx7ulp: Correct DDR clock mux options (git-fixes).
- clk: imx7ulp: Correct system clock source option #7 (git-fixes).
- clk: imx: pll14xx: Fix quick switch of S/K parameter
  (git-fixes).
- clk: renesas: r8a77965: Remove superfluous semicolon
  (git-fixes).
- clk: samsung: exynos5420: Preserve CPU clocks configuration
  during suspend/resume (git-fixes).
- commit 10ab36e
* Fri Dec 13 2019 tiwai@suse.de
- arm64: mm: Fix initialisation of DMA zones on non-NUMA systems
  (git-fixes).
- arm64: tegra: Fix 'active-low' warning for Jetson TX1 regulator
  (git-fixes).
- ARM: OMAP2+: Add missing put_device() call in omapdss_init_of()
  (git-fixes).
- apparmor: fix unsigned len comparison with less than zero
  (git-fixes).
- clk: meson: axg-audio: fix regmap last register (git-fixes).
- ARM: 8937/1: spectre-v2: remove Brahma-B53 from hardening
  (git-fixes).
- ARM: 8918/2: only build return_address() if needed (git-fixes).
- ARM: 8928/1: ARM_ERRATA_775420: Spelling s/date/data/
  (git-fixes).
- arm64: Silence clang warning on mismatched value/register sizes
  (git-fixes).
- commit 7811b6b
* Fri Dec 13 2019 tiwai@suse.de
- ARM: dts: Fix vcsi regulator to be always-on for droid4 to
  prevent hangs (git-fixes).
- commit 228f19d
* Fri Dec 13 2019 tiwai@suse.de
- watchdog: sprd: Fix the incorrect pointer getting from driver
  data (git-fixes).
- staging: wilc1000: potential corruption in
  wilc_parse_join_bss_param() (git-fixes).
- virt_wifi: fix use-after-free in virt_wifi_newlink()
  (git-fixes).
- tpm: Switch to platform_get_irq_optional() (git-fixes).
- commit ff1979e
* Fri Dec 13 2019 tiwai@suse.de
- thermal: Fix deadlock in thermal thermal_zone_device_check
  (git-fixes).
- time: Zero the upper 32-bits in __kernel_timespec on 32-bit
  (git-fixes).
- seccomp: avoid overflow in implicit constant conversion
  (git-fixes).
- rtlwifi: rtl8192de: Fix missing enable interrupt flag
  (git-fixes).
- rtlwifi: rtl8192de: Fix missing callback that tests for hw
  release of buffer (git-fixes).
- rtlwifi: rtl8192de: Fix missing code to retrieve RX buffer
  address (git-fixes).
- rtw88: fix error handling when setup efuse info (git-fixes).
- rtw88: fix NSS of hw_cap (git-fixes).
- rtw88: fix beaconing mode rsvd_page memory violation issue
  (git-fixes).
- tpm: add check after commands attribs tab allocation
  (git-fixes).
- commit 05bccb9
* Fri Dec 13 2019 tiwai@suse.de
- power: supply: bd70528: Add MODULE_ALIAS to allow module auto
  loading (git-fixes).
- PM / devfreq: Lock devfreq in trans_stat_show (git-fixes).
- PM / devfreq: Check NULL governor in available_governors_show
  (git-fixes).
- regulator: core: Let boot-on regulators be powered off
  (git-fixes).
- regulator: ab8500: Remove SYSCLKREQ from enum
  ab8505_regulator_id (git-fixes).
- regulator: ab8500: Remove AB8505 USB regulator (git-fixes).
- regulator: core: Release coupled_rdevs on
  regulator_init_coupling() error (git-fixes).
- regulator: bd70528: Add MODULE_ALIAS to allow module auto
  loading (git-fixes).
- rt2800: remove errornous duplicate condition (git-fixes).
- rtlwifi: Remove unnecessary NULL check in rtl_regd_init
  (git-fixes).
- commit c414c52
* Fri Dec 13 2019 tiwai@suse.de
- PCI: rcar: Fix missing MACCTLR register setting in
  initialization sequence (git-fixes).
- PCI: amlogic: Fix probed clock names (git-fixes).
- PCI: dwc: Fix find_next_bit() usage (git-fixes).
- PCI: aardvark: Fix PCI_EXP_RTCTL register configuration
  (git-fixes).
- PCI: aardvark: Use LTSSM state to build link training flag
  (git-fixes).
- PCI: Apply Cavium ACS quirk to ThunderX2 and ThunderX3
  (git-fixes).
- PCI: Fix Intel ACS quirk UPDCR register address (git-fixes).
- PCI/switchtec: Read all 64 bits of part_event_bitmap
  (git-fixes).
- PCI: Do not use bus number zero from EA capability (git-fixes).
- pinctl: ti: iodelay: fix error checking on
  pinctrl_count_index_with_args call (git-fixes).
- commit f1a197e
* Fri Dec 13 2019 tiwai@suse.de
- PCI: Fix missing bridge dma_ranges resource list cleanup
  (git-fixes).
- PCI/PM: Clear PCIe PME Status even for legacy power management
  (git-fixes).
- PCI/PTM: Remove spurious "d" from granularity message
  (git-fixes).
- PCI: pciehp: Do not disable interrupt twice on suspend
  (git-fixes).
- PCI: pciehp: Avoid returning prematurely from sysfs requests
  (git-fixes).
- mtd: rawnand: brcmnand: Fix NULL pointer assignment (git-fixes).
- mtd: rawnand: Change calculating of position page containing
  BBM (git-fixes).
- mtd: spi-nor: fix silent truncation in spi_nor_read_raw()
  (git-fixes).
- mtd: spi-nor: fix silent truncation in spi_nor_read()
  (git-fixes).
- mtd: cfi_cmdset_0002: only check errors when ready in
  cfi_check_err_status() (git-fixes).
- commit a7c6767
* Fri Dec 13 2019 tiwai@suse.de
- mt76: mt76u: fix endpoint definition order (git-fixes).
- Revert "mt76: mt76x0e: don't use hw encryption for MT7630E"
  (git-fixes).
- mt76: mt76u: rely on usb_interface instead of usb_dev
  (git-fixes).
- mt7601u: fix bbp version check in mt7601u_wait_bbp_ready
  (git-fixes).
- mtd: devices: fix mchp23k256 read and write (git-fixes).
- mtd: spear_smi: Fix Write Burst mode (git-fixes).
- commit 4c444cf
* Fri Dec 13 2019 tiwai@suse.de
- mfd: rk808: Fix RK818 ID template (git-fixes).
- mei: fix modalias documentation (git-fixes).
- mmc: core: fix wl1251 sdio quirks (git-fixes).
- mmc: sdio: fix wl1251 vendor id (git-fixes).
- mmc: sdhci-of-esdhc: fix up erratum A-008171 workaround
  (git-fixes).
- media: hantro: Fix s_fmt for dynamic resolution changes
  (git-fixes).
- media: aspeed-video: Fix memory leaks in aspeed_video_probe
  (git-fixes).
- media: flexcop-usb: ensure -EIO is returned on error condition
  (git-fixes).
- media: venus: remove invalid compat_ioctl32 handler (git-fixes).
- commit 973a35e
* Fri Dec 13 2019 tiwai@suse.de
- media: cedrus: Use correct H264 8x8 scaling list (git-fixes).
- media: exynos4-is: fix wrong mdev and v4l2 dev order in error
  path (git-fixes).
- media: fdp1: Fix R-Car M3-N naming in debug message (git-fixes).
- media: coda: fix deadlock between decoder picture run and
  start command (git-fixes).
- media: exynos4-is: Fix recursive locking in isp_video_release()
  (git-fixes).
- media: radio: wl1273: fix interrupt masking on release
  (git-fixes).
- media: bdisp: fix memleak on release (git-fixes).
- media: ti-vpe: vpe: Fix Motion Vector vpdma stride (git-fixes).
- media: v4l: cadence: Fix how unsued lanes are handled in
  'csi2rx_start()' (git-fixes).
- media: rc: mark input device as pointing stick (git-fixes).
- commit 05115b9
* Fri Dec 13 2019 tiwai@suse.de
- media: ov6650: Fix stored crop rectangle not in sync with
  hardware (git-fixes).
- media: ov6650: Fix stored frame format not in sync with hardware
  (git-fixes).
- media: ov6650: Fix default format not applied on device probe
  (git-fixes).
- media: ov6650: Fix .get_fmt() V4L2_SUBDEV_FORMAT_TRY support
  (git-fixes).
- media: ov6650: Fix some format attributes not under control
  (git-fixes).
- media: ov6650: Fix incorrect use of JPEG colorspace (git-fixes).
- media: ov6650: Fix crop rectangle alignment not passed back
  (git-fixes).
- media: ov6650: Fix control handler not freed on init error
  (git-fixes).
- media: ov6650: Fix MODULE_DESCRIPTION (git-fixes).
- media: max2175: Fix build error without CONFIG_REGMAP_I2C
  (git-fixes).
- commit f24d029
* Fri Dec 13 2019 tiwai@suse.de
- leds: trigger: netdev: fix handling on interface rename
  (git-fixes).
- media: rcar-vin: Fix incorrect return statement in
  rvin_try_format() (git-fixes).
- media: vim2m: Fix abort issue (git-fixes).
- media: vim2m: Fix BUG_ON in vim2m_device_release() (git-fixes).
- media: seco-cec: Add a missing 'release_region()' in an error
  handling path (git-fixes).
- iwlwifi: check kasprintf() return value (git-fixes).
- iwlwifi: pcie: fix support for transmitting SKBs with fraglist
  (git-fixes).
- mac80211: consider QoS Null frames for STA_NULLFUNC_ACKED
  (git-fixes).
- iwlwifi: mvm: consider ieee80211 station max amsdu value
  (git-fixes).
- kernfs: fix ino wrap-around detection (git-fixes).
- commit 199f72e
* Fri Dec 13 2019 tiwai@suse.de
- Input: synaptics-rmi4 - re-enable IRQs in f34v7_do_reflash
  (git-fixes).
- i2c: i2c-stm32f7: fix 10-bits check in slave free id search loop
  (git-fixes).
- i2c: stm32f7: report dma error during probe (git-fixes).
- i2c: stm32f7: fix & reorder remove & probe error handling
  (git-fixes).
- i2c: stm32f7: rework slave_id allocation (git-fixes).
- iio: adis16480: Add debugfs_reg_access entry (git-fixes).
- iio: adis16480: Fix scales factors (git-fixes).
- iio: imu: adis: assign value only if return code zero in read
  funcs (git-fixes).
- iio: imu: adis: assign read val in debugfs hook only if op
  successful (git-fixes).
- intel_th: Fix a double put_device() in error path (git-fixes).
- commit a869d19
* Fri Dec 13 2019 tiwai@suse.de
- docs: admin-guide: Remove threads-max auto-tuning (git-fixes).
- docs: admin-guide: Fix min value of threads-max in kernel.rst
  (git-fixes).
- HID: i2c-hid: Reset ALPS touchpads on resume (git-fixes).
- gpio: mpc8xxx: Don't overwrite default irq_set_type callback
  (git-fixes).
- Documentation: Fix warning in drm-kms-helpers.rst (git-fixes).
- Documentation: debugfs: Document debugfs helper for unsigned
  long values (git-fixes).
- iio: imu: adis16480: assign bias value only if operation
  succeeded (git-fixes).
- hwmon: (pmbus/ibm-cffps) Switch LEDs to blocking brightness call
  (git-fixes).
- gpiolib: acpi: Add Terra Pad 1061 to the
  run_edge_events_on_boot_blacklist (git-fixes).
- Documentation: TLS: Add missing counter description (git-fixes).
- commit fc72e99
* Fri Dec 13 2019 tiwai@suse.de
- docs: networking: devlink-trap: Fix reference to other document
  (git-fixes).
- docs: Fix "make help" suggestion for SPHINXDIR (git-fixes).
- docs: Catch up with the new location of get_user_pages_fast()
  (git-fixes).
- cw1200: Fix a signedness bug in cw1200_load_firmware()
  (git-fixes).
- crypto: virtio - deal with unsupported input sizes (git-fixes).
- crypto: virtio - implement missing support for output IVs
  (git-fixes).
- crypto: tgr192 - remove unneeded semicolon (git-fixes).
- crypto: crypto4xx - fix double-free in crypto4xx_destroy_sdr
  (git-fixes).
- crypto: atmel - Fix authenc support when it is set to m
  (git-fixes).
- commit afa1ae2
* Fri Dec 13 2019 tiwai@suse.de
- can: ucan: fix non-atomic allocation in completion handler
  (git-fixes).
- can: slcan: Fix use-after-free Read in slcan_open (git-fixes).
- compat_ioctl: handle SIOCOUTQNSD (git-fixes).
- Bluetooth: Fix memory leak in hci_connect_le_scan (git-fixes).
- Bluetooth: delete a stray unlock (git-fixes).
- brcmfmac: disable PCIe interrupts before bus reset (git-fixes).
- Bluetooth: hci_core: fix init for HCI_USER_CHANNEL (git-fixes).
- crypto: geode-aes - convert to skcipher API and make thread-safe
  (git-fixes).
- crypto: geode-aes - switch to skcipher for cbc(aes) fallback
  (git-fixes).
- crypto: atmel-aes - Fix IV handling when req->nbytes < ivsize
  (git-fixes).
- commit 1788826
* Fri Dec 13 2019 tiwai@suse.de
- ASoC: fsl_audmix: Add spin lock to protect tdms (git-fixes).
- ASoC: rsnd: fix DALIGN register for SSIU (git-fixes).
- ALSA: cs4236: fix error return comparison of an unsigned integer
  (git-fixes).
- ASoC: SOF: Intel: Broadwell: clarify mutual exclusion with
  legacy driver (git-fixes).
- ASoC: soc-pcm: fixup dpcm_prune_paths() loop continue
  (git-fixes).
- Revert "ASoC: SOF: Force polling mode on CFL and CNL"
  (git-fixes).
- ASoC: simple_card_utils.h: Add missing include (git-fixes).
- ALSA: firewire-motu: Correct a typo in the clock proc string
  (git-fixes).
- ath10k: Correct error handling of dma_map_single() (git-fixes).
- ath10k: Check if station exists before forwarding tx airtime
  report (git-fixes).
- commit d2f34ae
* Fri Dec 13 2019 tiwai@suse.de
- ACPI: sysfs: Change ACPI_MASKABLE_GPE_MAX to 0x100 (git-fixes).
- ACPI: OSL: only free map once in osl.c (git-fixes).
- ACPI / hotplug / PCI: Allocate resources directly under the
  non-hotplug bridge (git-fixes).
- ACPI / utils: Move acpi_dev_get_first_match_dev() under
  CONFIG_ACPI (git-fixes).
- ACPI: LPSS: Add dmi quirk for skipping _DEP check for some
  device-links (git-fixes).
- ACPI: LPSS: Add LNXVIDEO -> BYT I2C1 to lpss_device_links
  (git-fixes).
- ACPI: LPSS: Add LNXVIDEO -> BYT I2C7 to lpss_device_links
  (git-fixes).
- commit e0be9a6
* Thu Dec 12 2019 nsaenzjulienne@suse.de
- hwrng: iproc-rng200 - Add support for BCM2711 (jsc#SLE-7772).
- commit 5106a14
* Thu Dec 12 2019 oneukum@suse.com
- USB: fix kABI padding (jsc#SLE-8133).
- commit 2bf99e9
* Thu Dec 12 2019 oneukum@suse.com
- typeC: add kABI padding (jsc#SLE-8133).
- commit e45f332
* Thu Dec 12 2019 msuchanek@suse.de
- powerpc/pseries/mobility: notify network peers after migration
  (bsc#1152631 ltc#181798).
- commit c61f369
* Thu Dec 12 2019 jslaby@suse.cz
- platform/x86: intel_pmc_core: Add Comet Lake (CML) platform
  support to intel_pmc_core driver (jsc#SLE-11113).
- platform/x86: intel_pmc_core: Fix the SoC naming inconsistency
  (jsc#SLE-11113).
- commit 1e10fa5
* Thu Dec 12 2019 jslaby@suse.cz
- x86/platform/uv: Account for UV Hubless in is_uvX_hub Ops
  (jsc#SLE-10790).
- x86/platform/uv: Check EFI Boot to set reboot type
  (jsc#SLE-10790).
- x86/platform/uv: Decode UVsystab Info (jsc#SLE-10790).
- x86/platform/uv: Add UV Hubbed/Hubless Proc FS Files
  (jsc#SLE-10790).
- x86/platform/uv: Setup UV functions for Hubless UV Systems
  (jsc#SLE-10790).
- x86/platform/uv: Add return code to UV BIOS Init function
  (jsc#SLE-10790).
- x86/platform/uv: Return UV Hubless System Type (jsc#SLE-10790).
- x86/platform/uv: Save OEM_ID from ACPI MADT probe
  (jsc#SLE-10790).
- commit a305bf3
* Thu Dec 12 2019 msuchanek@suse.de
- net/ibmvnic: Fix typo in retry check (bsc#1155689 ltc#182047).
- commit 59fccb6
* Wed Dec 11 2019 tbogendoerfer@suse.de
- mm: Implement no-MMU variant of vmalloc_user_node_flags
  (bsc#1154353).
- bpf: Add bpf_jit_blinding_enabled for !CONFIG_BPF_JIT
  (bsc#1154353).
- powerpc: Add const qual to local_read() parameter (bsc#1154353).
- net: sfp: fix sfp_bus_add_upstream() warning (bsc#1154353).
- commit 0920fda
* Wed Dec 11 2019 tbogendoerfer@suse.de
- RDMA/hns: Fix build error again (jsc#SLE-8449).
- Update config files.
- commit 56e934b
* Wed Dec 11 2019 tiwai@suse.de
- Update patch reference for wimax fix (CVE-2019-19051 bsc#1159024)
- commit a70fc76
* Wed Dec 11 2019 ykaukab@suse.de
- arm64: move patches to sorted section
  No code change.
- Refresh
  patches.suse/PCI-tegra-Fix-CLKREQ-dependency-programming.patch.
- Refresh
  patches.suse/ahci-tegra-use-regulator_bulk_set_supply_names.patch.
- Refresh
  patches.suse/arm64-kpti-Add-NVIDIA-s-Carmel-core-to-the-KPTI-whit.patch.
- Refresh
  patches.suse/clk-Add-API-to-get-index-of-the-clock-parent.patch.
- Refresh
  patches.suse/clk-tegra-Add-suspend-and-resume-support-on-Tegra210.patch.
- Refresh
  patches.suse/clk-tegra-Fix-build-error-without-CONFIG_PM_SLEEP.patch.
- Refresh
  patches.suse/clk-tegra-Move-SOR0-implementation-to-Tegra124.patch.
- Refresh
  patches.suse/clk-tegra-Reimplement-SOR-clock-on-Tegra124.patch.
- Refresh
  patches.suse/clk-tegra-Reimplement-SOR-clocks-on-Tegra210.patch.
- Refresh
  patches.suse/clk-tegra-Remove-last-remains-of-TEGRA210_CLK_SOR1_S.patch.
- Refresh
  patches.suse/clk-tegra-Rename-sor0_lvds-to-sor0_out.patch.
- Refresh
  patches.suse/clk-tegra-Share-clk-and-rst-register-defines-with-Te.patch.
- Refresh
  patches.suse/clk-tegra-Support-for-OSC-context-save-and-restore.patch.
- Refresh
  patches.suse/clk-tegra-Use-fence_udelay-during-PLLU-init.patch.
- Refresh
  patches.suse/clk-tegra-clk-dfll-Add-suspend-and-resume-support.patch.
- Refresh
  patches.suse/clk-tegra-clk-super-Add-restore-context-support.patch.
- Refresh
  patches.suse/clk-tegra-clk-super-Fix-to-enable-PLLP-branches-to-C.patch.
- Refresh
  patches.suse/clk-tegra-divider-Save-and-restore-divider-rate.patch.
- Refresh
  patches.suse/clk-tegra-periph-Add-restore_context-support.patch.
- Refresh
  patches.suse/clk-tegra-pll-Save-and-restore-pll-context.patch.
- Refresh
  patches.suse/clk-tegra-pllout-Save-and-restore-pllout-context.patch.
- Refresh
  patches.suse/cpufreq-tegra124-Add-suspend-and-resume-support.patch.
- Refresh
  patches.suse/dt-bindings-clock-tegra-Rename-SOR0_LVDS-to-SOR0_OUT.patch.
- Refresh
  patches.suse/firmware-tegra-Move-BPMP-resume-to-noirq-phase.patch.
- Refresh
  patches.suse/gpio-max77620-Do-not-allocate-IRQs-upfront.patch.
- Refresh patches.suse/gpio-max77620-Fix-interrupt-handling.patch.
- Refresh patches.suse/gpio-tegra186-Add-debounce-support.patch.
- Refresh
  patches.suse/gpio-tegra186-Derive-register-offsets-from-bank-port.patch.
- Refresh
  patches.suse/gpio-tegra186-Implement-wake-event-support.patch.
- Refresh
  patches.suse/gpio-tegra186-Program-interrupt-route-mapping.patch.
- Refresh
  patches.suse/iommu-tegra-smmu-Fix-client-enablement-order.patch.
- Refresh
  patches.suse/iommu-tegra-smmu-Fix-page-tables-in-4-GiB-memory.patch.
- Refresh
  patches.suse/iommu-tegra-smmu-Use-non-secure-register-for-flushin.patch.
- Refresh
  patches.suse/memory-tegra-Set-DMA-mask-based-on-supported-address.patch.
- Refresh
  patches.suse/mfd-max77620-Do-not-allocate-IRQs-upfront.patch.
- Refresh
  patches.suse/net-stmmac-Only-enable-enhanced-addressing-mode-when.patch.
- Refresh
  patches.suse/net-stmmac-Support-enhanced-addressing-mode-for-DWMA.patch.
- Refresh
  patches.suse/phy-tegra-use-regulator_bulk_set_supply_names.patch.
- Refresh
  patches.suse/phy-tegra-xusb-Add-XUSB-dual-mode-support-on-Tegra21.patch.
- Refresh
  patches.suse/phy-tegra-xusb-Add-usb3-port-fake-support-on-Tegra21.patch.
- Refresh
  patches.suse/phy-tegra-xusb-Add-vbus-override-support-on-Tegra186.patch.
- Refresh
  patches.suse/phy-tegra-xusb-Add-vbus-override-support-on-Tegra210.patch.
- Refresh
  patches.suse/soc-tegra-fuse-Add-FUSE-clock-check-in-tegra_fuse_re.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Add-missing-IRQ-callbacks-on-Tegra194.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Add-reset-sources-and-levels-on-Tegra1.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Add-wake-event-support-on-Tegra210.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Configure-core-power-request-polarity.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Configure-deep-sleep-control-settings.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Fix-crashes-for-hierarchical-interrupt.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Support-wake-events-on-more-Tegra-SoCs.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Use-lower-case-for-hexadecimal-literal.patch.
- Refresh
  patches.suse/usb-host-xhci-tegra-Add-Tegra194-XHCI-support.patch.
- Refresh
  patches.suse/usb-host-xhci-tegra-Correct-phy-enable-sequence.patch.
- Refresh
  patches.suse/usb-host-xhci-tegra-use-devm_platform_ioremap_resour.patch.
- Refresh
  patches.suse/usb-host-xhci-tegra-use-regulator_bulk_set_supply_na.patch.
- Refresh
  patches.suse/xhci-tegra-Parameterize-mailbox-register-addresses.patch.
- commit 3cb7073
* Wed Dec 11 2019 tbogendoerfer@suse.de
- net/tls: allow compiling TLS TOE out (bsc#1154353).
- Update config files.
- commit 6230ee0
* Wed Dec 11 2019 ykaukab@suse.de
- drivers/perf: Add CCPI2 PMU support in ThunderX2 UNCORE driver
  (jsc#SLE-10207,jsc#SLE-9619).
- Documentation: perf: Update documentation for ThunderX2 PMU
  uncore driver (jsc#SLE-10207,jsc#SLE-9619).
- commit 1b0c5b1
* Wed Dec 11 2019 tbogendoerfer@suse.de
- bpf: Introduce BPF trampoline (bsc#1154353).
- Refresh
  patches.suse/bpf-Fix-race-in-btf_resolve_helper_id.patch.
- commit f6e150b
* Wed Dec 11 2019 jroedel@suse.de
- KVM: x86: Remove a spurious export of a static function
  (bsc#1158954).
- commit 00bd7c4
* Wed Dec 11 2019 tbogendoerfer@suse.de
- bpf: Track contents of read-only maps as scalars (bsc#1154353).
- Refresh
  patches.suse/bpf-Implement-accurate-raw_tp-context-access-via-BTF.patch.
- commit 188f581
* Wed Dec 11 2019 tbogendoerfer@suse.de
- net: sockmap: use bitmap for copy info (bsc#1154353).
- Refresh
  patches.suse/net-skmsg-fix-TLS-1.3-crash-with-full-sk_msg.patch.
- commit daf1422
* Wed Dec 11 2019 jack@suse.cz
- patches.suse/block-Warn-if-elevator-parameter-is-used.patch: Update tags
- commit ef8c281
* Wed Dec 11 2019 tbogendoerfer@suse.de
- net_sched: validate TCA_KIND attribute in tc_chain_tmplt_add()
  (bsc#1154353).
- inet: protect against too small mtu values (bsc#1154353).
- gre: refetch erspan header from skb->data after pskb_may_pull()
  (bsc#1154353).
- tcp: Protect accesses to .ts_recent_stamp with
  {READ,WRITE}_ONCE() (bsc#1154353).
- tcp: tighten acceptance of ACKs not matching a child socket
  (bsc#1154353).
- tcp: fix rejected syncookies due to stale timestamps
  (bsc#1154353).
- net/mlx5e: E-switch, Fix Ingress ACL groups in switchdev mode
  for prio tag (jsc#SLE-8464).
- net/mlx5e: ethtool, Fix analysis of speed setting
  (jsc#SLE-8464).
- net/mlx5e: Fix translation of link mode into speed
  (jsc#SLE-8464).
- net/mlx5e: Fix free peer_flow when refcount is 0 (jsc#SLE-8464).
- net/mlx5e: Fix freeing flow with kfree() and not kvfree()
  (jsc#SLE-8464).
- net/mlx5e: Fix SFF 8472 eeprom length (jsc#SLE-8464).
- net/mlx5e: Query global pause state before setting prio2buffer
  (jsc#SLE-8464).
- net/mlx5e: Fix TXQ indices to be sequential (jsc#SLE-8464).
- tcp: md5: fix potential overestimation of TCP option space
  (bsc#1154353).
- net-sysfs: Call dev_hold always in netdev_queue_add_kobject
  (bsc#1154353).
- net/tls: Fix return values to avoid ENOTSUPP (bsc#1154353).
- net: avoid an indirect call in ____sys_recvmsg() (bsc#1154353).
- mqprio: Fix out-of-bounds access in mqprio_dump (bsc#1154353).
- bpf: Fix a bug when getting subprog 0 jited image in
  check_attach_btf_id (bsc#1154353).
- net: hns3: fix VF ID issue for setting VF VLAN (bsc#1154353).
- net: hns3: fix a use after free problem in
  hns3_nic_maybe_stop_tx() (bsc#1154353).
- net: hns3: fix for TX queue not restarted problem (bsc#1154353).
- hsr: fix a NULL pointer dereference in hsr_dev_xmit()
  (bsc#1154353).
- net: Fixed updating of ethertype in skb_mpls_push()
  (bsc#1154353).
- net: sfp: fix hwmon (bsc#1154353).
- net: sfp: fix unbind (bsc#1154353).
- xdp: obtain the mem_id mutex before trying to remove an entry
  (bsc#1154353).
- act_ct: support asymmetric conntrack (bsc#1154353).
- net: ipv6_stub: use ip6_dst_lookup_flow instead of
  ip6_dst_lookup (bsc#1154353).
- net: ipv6: add net argument to ip6_dst_lookup_flow
  (bsc#1154353).
- cls_flower: Fix the behavior using port ranges with hw-offload
  (bsc#1154353).
- net: sched: fix dump qlen for sch_mq/sch_mqprio with NOLOCK
  subqueues (bsc#1154353).
- tcp: refactor tcp_retransmit_timer() (bsc#1154353).
- net/core: Populate VF index in struct ifla_vf_guid
  (bsc#1154353).
- net: bridge: deny dev_set_mac_address() when unregistering
  (bsc#1154353).
- net: fix a leak in register_netdevice() (bsc#1154353).
- Fixed updating of ethertype in function skb_mpls_pop
  (bsc#1154353).
- sch_cake: Add missing NLA policy entry TCA_CAKE_SPLIT_GSO
  (bsc#1154353).
- bpf: Fix build in minimal configurations (bsc#1154353).
- bpf: Fix static checker warning (bsc#1154353).
- SUNRPC: Fix backchannel latency metrics (bsc#1154353).
- SUNRPC: Fix svcauth_gss_proxy_init() (bsc#1154353).
- SUNRPC: Trace gssproxy upcall results (bsc#1154353).
- sunrpc: fix crash when cache_head become valid before update
  (bsc#1154353).
- svcrdma: Improve DMA mapping trace points (bsc#1154353).
- SUNRPC: Capture completion of all RPC tasks (bsc#1154353).
- SUNRPC: Fix another issue with MIC buffer space (bsc#1154353).
- xprtrdma: Replace dprintk in xprt_rdma_set_port (bsc#1154353).
- xprtrdma: Replace dprintk() in rpcrdma_update_connect_private()
  (bsc#1154353).
- xprtrdma: Refine trace_xprtrdma_fixup (bsc#1154353).
- xprtrdma: Report the computed connect delay (bsc#1154353).
- xprtrdma: Wake tasks after connect worker fails (bsc#1154353).
- xprtrdma: Pull up sometimes (bsc#1154353).
- xprtrdma: Refactor rpcrdma_prepare_msg_sges() (bsc#1154353).
- xprtrdma: Move the rpcrdma_sendctx::sc_wr field (bsc#1154353).
- xprtrdma: Remove rpcrdma_sendctx::sc_device (bsc#1154353).
- xprtrdma: Remove rpcrdma_sendctx::sc_xprt (bsc#1154353).
- xprtrdma: Ensure ri_id is stable during MR recycling
  (bsc#1154353).
- xprtrdma: Manage MRs in context of a single connection
  (bsc#1154353).
- xprtrdma: Fix MR list handling (bsc#1154353).
- xprtrdma: Close window between waking RPC senders and posting
  Receives (bsc#1154353).
- xprtrdma: Initialize rb_credits in one place (bsc#1154353).
- xprtrdma: Connection becomes unstable after a reconnect
  (bsc#1154353).
- SUNRPC: Add trace points to observe transport congestion control
  (bsc#1154353).
- SUNRPC: Eliminate log noise in call_reserveresult (bsc#1154353).
- SUNRPC: Avoid RPC delays when exiting suspend (bsc#1154353).
- net/mlx5e: Fix build error without IPV6 (jsc#SLE-8464).
- net: inet_is_local_reserved_port() port arg should be unsigned
  short (bsc#1154353).
- IB: mlx5: no need to check return value of debugfs_create
  functions (jsc#SLE-8446).
- RDMA/hns: Delete unnecessary callback functions for cq
  (jsc#SLE-8449).
- RDMA/hns: Rename the functions used inside creating cq
  (jsc#SLE-8449).
- RDMA/hns: Redefine the member of hns_roce_cq struct
  (jsc#SLE-8449).
- RDMA/hns: Redefine interfaces used in creating cq
  (jsc#SLE-8449).
- RDMA/efa: Expose RDMA read related attributes (jsc#SLE-5640).
- RDMA/efa: Support remote read access in MR registration
  (jsc#SLE-5640).
- RDMA/efa: Store network attributes in device attributes
  (jsc#SLE-5640).
- IB/hfi1: remove redundant assignment to variable ret
  (jsc#SLE-8449).
- RDMA/bnxt_re: Fix missing le16_to_cpu (jsc#SLE-8372
  bsc#1153275).
- RDMA/bnxt_re: Fix chip number validation Broadcom's Gen P5
  series (jsc#SLE-8372 bsc#1153275).
- RDMA/bnxt_re: Fix Kconfig indentation (jsc#SLE-8372
  bsc#1153275).
- IB/mlx5: Implement callbacks for getting VFs GUID attributes
  (jsc#SLE-8446).
- IB/ipoib: Add ndo operation for getting VFs GUID attributes
  (jsc#SLE-8449).
- IB/core: Add interfaces to get VF node and port GUIDs
  (jsc#SLE-8449).
- net/core: Add support for getting VF GUIDs (jsc#SLE-8449).
- RDMA/qedr: Fix null-pointer dereference when calling
  rdma_user_mmap_get_offset (jsc#SLE-8215).
- RDMA/cm: Use refcount_t type for refcount variable
  (jsc#SLE-8449).
- IB/mlx5: Support extended number of strides for Striding RQ
  (jsc#SLE-8446).
- IB/mlx4: Update HW GID table while adding vlan GID
  (jsc#SLE-8461).
- RDMA/iw_cgxb4: Fix an error handling path in 'c4iw_connect()'
  (jsc#SLE-8392).
- RDMA/cma: Use ACK timeout for RoCE packetLifeTime
  (jsc#SLE-8449).
- RDMA/efa: Clear the admin command buffer prior to its submission
  (jsc#SLE-5640).
- RDMA/siw: Cleanup unused mmap structures (jsc#SLE-8381).
- RDMA/qedr: Make qedr_iw_load_qp() static (jsc#SLE-8215).
- RDMA/ocrdma: Fix spelling mistake in variable name
  (jsc#SLE-8449).
- RDMA/qib: Validate ->show()/store() callbacks before calling
  them (jsc#SLE-8449).
- RDMA/i40iw: Fix potential use after free (jsc#SLE-8449).
- RDMA/qedr: Fix potential use after free (jsc#SLE-8215).
- RDMA/srpt: Report the SCSI residual to the initiator
  (jsc#SLE-8449).
- IB/mlx5: Support flow counters offset for bulk counters
  (jsc#SLE-8446).
- RDMA: Change MAD processing function to remove extra casting
  and parameter (jsc#SLE-8449).
- RDMA/hfi1: Delete unreachable code (jsc#SLE-8449).
- RDMA/hns: Modify appropriate printings (jsc#SLE-8449).
- RDMA/hns: Fix non-standard error codes (jsc#SLE-8449).
- RDMA/hns: Modify hns_roce_hw_v2_get_cfg to simplify the code
  (jsc#SLE-8449).
- RDMA/hns: Simplify doorbell initialization code (jsc#SLE-8449).
- RDMA/hns: Replace not intuitive function/macro names
  (jsc#SLE-8449).
- RDMA/hns: Modify fields of struct hns_roce_srq (jsc#SLE-8449).
- RDMA/hns: Delete unnecessary uar from hns_roce_cq
  (jsc#SLE-8449).
- RDMA/hns: Remove unnecessary structure hns_roce_sqp
  (jsc#SLE-8449).
- RDMA/hns: Delete unnecessary variable max_post (jsc#SLE-8449).
- RDMA/mlx5: Rewrite MAD processing logic to be readable
  (jsc#SLE-8446).
- RDMA/ocrdma: Simplify process_mad function (jsc#SLE-8449).
- RDMA/mad: Do not check MAD sizes in roce and ib drivers
  (jsc#SLE-8449).
- RDMA/ocrdma: Make ocrdma_pma_counters() return void
  (jsc#SLE-8449).
- RDMA/mad: Allocate zeroed MAD buffer (jsc#SLE-8449).
- RDMA/qib: Delete empty check_cc_key function (jsc#SLE-8449).
- RDMA/qib: Delete extra line (jsc#SLE-8449).
- RDMA/mad: Delete never implemented functions (jsc#SLE-8449).
- Revert "RDMA/srpt: Postpone HCA removal until after configfs
  directory removal" (jsc#SLE-8449).
- RDMA/qedr: Remove unsupported modify_port callback
  (jsc#SLE-8215).
- RDMA/ocrdma: Remove unsupported modify_port callback
  (jsc#SLE-8449).
- RDMA/hns: Remove unsupported modify_port callback
  (jsc#SLE-8449).
- RDMA/core: Fix return code when modify_port isn't supported
  (jsc#SLE-8449).
- RDMA/qedr: Add iWARP doorbell recovery support (jsc#SLE-8215).
- RDMA/qedr: Add doorbell overflow recovery support
  (jsc#SLE-8215).
- RDMA/qedr: Use the common mmap API (jsc#SLE-8215).
- RDMA/siw: Use the common mmap_xa helpers (jsc#SLE-8381).
- RDMA/efa: Use the common mmap_xa helpers (jsc#SLE-5640).
- RDMA: Connect between the mmap entry and the umap_priv structure
  (jsc#SLE-8449).
- RDMA/core: Create mmap database and cookie helper functions
  (jsc#SLE-8449).
- RDMA/core: Move core content from ib_uverbs to ib_core
  (jsc#SLE-8449).
- IB/mlx5: Test write combining support (jsc#SLE-8446).
- RDMA/mlx5: Return proper error value (jsc#SLE-8446).
- RDMA/odp: Remove broken debugging call to invalidate_range
  (jsc#SLE-8449).
- RDMA/mlx5: Do not race with mlx5_ib_invalidate_range during
  create and destroy (jsc#SLE-8446).
- RDMA/mlx5: Do not store implicit children in the odp_mkeys
  xarray (jsc#SLE-8446).
- RDMA/mlx5: Rework implicit ODP destroy (jsc#SLE-8446).
- RDMA/mlx5: Avoid double lookups on the pagefault path
  (jsc#SLE-8446).
- RDMA/mlx5: Reduce locking in implicit_mr_get_data()
  (jsc#SLE-8446).
- RDMA/mlx5: Use an xarray for the children of an implicit ODP
  (jsc#SLE-8446).
- RDMA/mlx5: Split implicit handling from pagefault_mr
  (jsc#SLE-8446).
- RDMA/mlx5: Set the HW IOVA of the child MRs to their place in
  the tree (jsc#SLE-8446).
- RDMA/mlx5: Lift implicit_mr_alloc() into the two routines that
  call it (jsc#SLE-8446).
- RDMA/mlx5: Rework implicit_mr_get_data (jsc#SLE-8446).
- RDMA/mlx5: Delete struct mlx5_priv->mkey_table (jsc#SLE-8446).
- RDMA/mlx5: Use a dedicated mkey xarray for ODP (jsc#SLE-8446).
- RDMA/mlx5: Split sig_err MR data into its own xarray
  (jsc#SLE-8446).
- RDMA/mlx5: Use SRCU properly in ODP prefetch (jsc#SLE-8446).
- RDMA/vmw_pvrdma: Use resource ids from physical device if
  available (jsc#SLE-8449).
- RDMA/core: Set DMA parameters correctly (jsc#SLE-8449).
- RDMA/siw: Increase DMA max_segment_size parameter
  (jsc#SLE-8381).
- RDMA/rxe: Increase DMA max_segment_size parameter
  (jsc#SLE-8449).
- RDMA/siw: Fix post_recv QP state locking (jsc#SLE-8381).
- RDMA/iw_cxgb4: Report correct port speed/width (jsc#SLE-8392).
- RDMA/qedr: Fix memory leak in user qp and mr (jsc#SLE-8215).
- RDMA/qedr: Fix synchronization methods and memory leaks in qedr
  (jsc#SLE-8215).
- RDMA/qedr: Fix qpids xarray api used (jsc#SLE-8215).
- RDMA/qedr: Fix srqs xarray initialization (jsc#SLE-8215).
- RDMA/hns: Fix memory leak on 'context' on error return path
  (jsc#SLE-8449).
- RDMA/hns: Bugfix for qpc/cqc timer configuration (jsc#SLE-8449).
- RDMA/hns: Fix to support 64K page for srq (jsc#SLE-8449).
- RDMA/srpt: Fix TPG creation (jsc#SLE-8449).
- RDMA/hns: Delete BITS_PER_BYTE redefinition (jsc#SLE-8449).
- RDMA/hns: Prevent undefined behavior in
  hns_roce_set_user_sq_size() (jsc#SLE-8449).
- RDMA/cm: Update copyright together with SPDX tag (jsc#SLE-8449).
- RDMA/cm: Use specific keyword to check define (jsc#SLE-8449).
- RDMA/cm: Delete unused cm_is_active_peer function
  (jsc#SLE-8449).
- RDMA/rxe: Remove useless rxe_init_device_param assignments
  (jsc#SLE-8449).
- RDMA/core: Check that process is still alive before sending
  it to the users (jsc#SLE-8449).
- RDMA/restrack: Remove PID namespace support (jsc#SLE-8449).
- IB/core: Do not notify GID change event of an unregistered
  device (jsc#SLE-8449).
- IB/mlx5: Align usage of QP1 create flags with rest of mlx5
  defines (jsc#SLE-8446).
- IB/mlx5: Remove dead code (jsc#SLE-8446).
- RDMA/uverbs: Add a check for uverbs_attr_get to
  uverbs_copy_to_struct_or_zero (jsc#SLE-8449).
- IB/cma: Honor traffic class from lower netdevice for RoCE
  (jsc#SLE-8449).
- RDMA/nldev: Provide MR statistics (jsc#SLE-8449).
- RDMA/mlx5: Return ODP type per MR (jsc#SLE-8446).
- RDMA/nldev: Allow different fill function per resource
  (jsc#SLE-8449).
- IB/mlx5: Introduce ODP diagnostic counters (jsc#SLE-8446).
- infiniband: fix sw/rdmavt/ kernel-doc notation (jsc#SLE-8449).
- infiniband: fix core/ kernel-doc notation (jsc#SLE-8449).
- infiniband: fix ulp/iser/iser_initiator.c kernel-doc warnings
  (jsc#SLE-8449).
- infiniband: fix ulp/iser/iser_verbs.c kernel-doc notation
  (jsc#SLE-8449).
- infiniband: fix core/verbs.c kernel-doc notation (jsc#SLE-8449).
- infiniband: fix ulp/srpt/ib_srpt.h kernel-doc notation
  (jsc#SLE-8449).
- infiniband: fix ulp/opa_vnic/opa_vnic_internal.h kernel-doc
  notation (jsc#SLE-8449).
- infiniband: fix ulp/iser/iscsi_iser.h kernel-doc warnings
  (jsc#SLE-8449).
- infiniband: fix core/ipwm_util.h kernel-doc warnings
  (jsc#SLE-8449).
- infiniband: fix ulp/iser/iscsi_iser. kernel-doc notation
  (jsc#SLE-8449).
- RDMA/mlx5: Add capability for max sge to get optimized
  performance (jsc#SLE-8446).
- RDMA/rw: Support threshold for registration vs scattering to
  local pages (jsc#SLE-8449).
- RDMA/siw: Fix SQ/RQ drain logic (jsc#SLE-8381).
- ib/srp: Add missing new line after displaying fast_io_fail_tmo
  param (jsc#SLE-8449).
- RDMA/hns: Release qp resources when failed to destroy qp
  (jsc#SLE-8449).
- RDMA/hns: Fix a spelling mistake in a macro (jsc#SLE-8449).
- RDMA/hns: Modify return value of restrack functions
  (jsc#SLE-8449).
- RDMA/hns: Modify variable/field name from vlan to vlan_id
  (jsc#SLE-8449).
- RDMA/hns: Fix wrong parameters when initial mtt of srq->idx_que
  (jsc#SLE-8449).
- RDMA/hns: remove a redundant le16_to_cpu (jsc#SLE-8449).
- IB/mlx5: Introduce and use mkey context setting helper routine
  (jsc#SLE-8446).
- RDMA/iser: Use iser_err instead of pr_err for logging
  (jsc#SLE-8449).
- RDMA/bnxt_re: Enable SRIOV VF support on Broadcom's 57500
  adapter series (jsc#SLE-8372 bsc#1153275).
- RDMA/srp: Calculate max_it_iu_size if remote max_it_iu length
  available (jsc#SLE-8449).
- RDMA/srp: Add parse function for maximum initiator to target
  IU size (jsc#SLE-8449).
- IB/cm: Use container_of() instead of typecast (jsc#SLE-8449).
- IB/mlx5: Remove unnecessary else statement (jsc#SLE-8446).
- IB/mlx5: Remove unnecessary return statement (jsc#SLE-8446).
- RDMA/mlx5: Group boolean parameters to take less space
  (jsc#SLE-8446).
- RDMA/srpt: Postpone HCA removal until after configfs directory
  removal (jsc#SLE-8449).
- RDMA/srpt: Make the code for handling port identities more
  systematic (jsc#SLE-8449).
- RDMA/srpt: Rework the code that waits until an RDMA port is
  no longer in use (jsc#SLE-8449).
- RDMA/srpt: Rework the approach for closing an RDMA channel
  (jsc#SLE-8449).
- RDMA/srpt: Improve a debug message (jsc#SLE-8449).
- RDMA/srpt: Fix handling of iWARP logins (jsc#SLE-8449).
- RDMA/srpt: Fix handling of SR-IOV and iWARP ports
  (jsc#SLE-8449).
- RDMA/srp: Make route resolving error messages more informative
  (jsc#SLE-8449).
- RDMA/srp: Honor the max_send_sge device attribute
  (jsc#SLE-8449).
- RDMA/srp: Remove two casts (jsc#SLE-8449).
- RDMA/siw: Make node GUIDs valid EUI-64 identifiers
  (jsc#SLE-8381).
- RDMA/rxe: Verify modify_device mask (jsc#SLE-8449).
- RDMA/bnxt_re: Remove unsupported modify_device callback
  (jsc#SLE-8372 bsc#1153275).
- RDMA/core: Fix return code when modify_device isn't supported
  (jsc#SLE-8449).
- RDMA/siw: Fix port number endianness in a debug message
  (jsc#SLE-8381).
- RDMA/siw: Simplify several debug messages (jsc#SLE-8381).
- IB/iser: remove redundant macro definitions (jsc#SLE-8449).
- IB/iser: bound protection_sg size by data_sg size
  (jsc#SLE-8449).
- IB/iser: add unlikely checks in the fast path (jsc#SLE-8449).
- RDMA/counter: Prevent QP counter manual binding in auto mode
  (jsc#SLE-8449).
- net/sched: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1154353).
- net/netfilter: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1154353).
- net/core: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1154353).
- bpf/cgroup: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1154353).
- rcu: Upgrade rcu_swap_protected() to rcu_replace_pointer()
  (bsc#1154353).
- net: phy: add helpers phy_(un)lock_mdio_bus (bsc#1154353).
- bpf: Simplify __bpf_arch_text_poke poke type handling
  (bsc#1154353).
- bpf, x86: Emit patchable direct jump as tail call (bsc#1154353).
- bpf: Constant map key tracking for prog array pokes
  (bsc#1154353).
- bpf: Add poke dependency tracking for prog array maps
  (bsc#1154353).
- bpf: Add initial poke descriptor table for jit images
  (bsc#1154353).
- bpf: Move owner type, jited info into array auxiliary data
  (bsc#1154353).
- bpf: Move bpf_free_used_maps into sleepable section
  (bsc#1154353).
- bpf, x86: Generalize and extend bpf_arch_text_poke for direct
  jumps (bsc#1154353).
- bpf: Provide better register bounds after jmp32 instructions
  (bsc#1154353).
- xsk: Fix xsk_poll()'s return type (bsc#1154353).
- mlxsw: spectrum_router: Fix use of uninitialized adjacency index
  (bsc#1154488).
- mlxsw: spectrum_router: After underlay moves, demote conflicting
  tunnels (bsc#1154488).
- bnxt_en: Add support for flashing the device via devlink
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Allow PHY settings on multi-function or NPAR PFs if
  allowed by FW (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add async. event logic for PHY configuration changes
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor the initialization of the ethtool link
  settings (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Skip disabling autoneg before PHY loopback when
  appropriate (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Assign more RSS context resources to the VFs
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Initialize context memory to the value specified by
  firmware (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix suspend/resume path on 57500 chips (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Send FUNC_RESOURCE_QCAPS command in bnxt_resume()
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Combine 2 functions calling the same HWRM_DRV_RGTR
  fw command (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Do driver unregister cleanup in bnxt_init_one()
  failure path (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Disable/enable Bus master during suspend/resume
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add chip IDs for 57452 and 57454 chips (jsc#SLE-8371
  bsc#1153274).
- sfc: fix build without CONFIG_RFS_ACCEL (jsc#SLE-8314).
- net: gro: use vlan API instead of accessing directly
  (bsc#1154353).
- net/mlx5e: Remove redundant pointer check (jsc#SLE-8464).
- net/mlx5e: TC, Stub out ipv6 tun create header function
  (jsc#SLE-8464).
- net/mlx5: DR, Add support for Geneve packets SW steering
  (jsc#SLE-8464).
- net/mlx5: DR, Add HW bits and definitions for Geneve flex parser
  (jsc#SLE-8464).
- net/mlx5: DR, Refactor VXLAN GPE flex parser tunnel code for
  SW steering (jsc#SLE-8464).
- net/mlx5: Don't write read-only fields in
  MODIFY_HCA_VPORT_CONTEXT command (jsc#SLE-8464).
- net: use rhashtable_lookup() instead of rhashtable_lookup_fast()
  (bsc#1154353).
- net: phy: initialise phydev speed and duplex sanely
  (bsc#1154353).
- net: phy: remove phy_ethtool_sset() (bsc#1154353).
- sfc: do ARFS expiry work occasionally even without NAPI poll
  (jsc#SLE-8314).
- sfc: add statistics for ARFS (jsc#SLE-8314).
- sfc: suppress MCDI errors from ARFS (jsc#SLE-8314).
- sfc: change ARFS expiry mechanism (jsc#SLE-8314).
- ice: Update FW API minor version (jsc#SLE-7926).
- ice: remove pointless NULL check of port_info (jsc#SLE-7926).
- ice: Implement ethtool ops for channels (jsc#SLE-7926).
- ice: implement VF stats NDO (jsc#SLE-7926).
- ice: add helpers for virtchnl (jsc#SLE-7926).
- ice: Add ice_pf_to_dev(pf) macro (jsc#SLE-7926).
- ice: Do not use devm* functions for local uses (jsc#SLE-7926).
- ice: Refactor removal of VLAN promiscuous rules (jsc#SLE-7926).
- ice: Fix setting coalesce to handle DCB configuration
  (jsc#SLE-7926).
- ice: Only disable VF state when freeing each VF resources
  (jsc#SLE-7926).
- ice: fix stack leakage (jsc#SLE-7926).
- ice: Don't modify stripping for add/del VLANs on VF
  (jsc#SLE-7926).
- ice: Disallow VF VLAN opcodes if VLAN offloads disabled
  (jsc#SLE-7926).
- ice: Correct capabilities reporting of max TCs (jsc#SLE-7926).
- ice: Store number of functions for the device (jsc#SLE-7926).
- net: inet_is_local_reserved_port() should return bool not int
  (bsc#1154353).
- cxgb4: add stats for MQPRIO QoS offload Tx path (jsc#SLE-8389).
- cxgb4: add UDP segmentation offload support (jsc#SLE-8389).
- cxgb4/chcr: update SGL DMA unmap for USO (jsc#SLE-8389).
- seg6: allow local packet processing for SRv6 End.DT6 behavior
  (bsc#1154353).
- ipv4: use dst hint for ipv4 list receive (bsc#1154353).
- ipv4: move fib4_has_custom_rules() helper to public header
  (bsc#1154353).
- ipv6: introduce and uses route look hints for list input
  (bsc#1154353).
- ipv6: keep track of routes using src (bsc#1154353).
- ipv6: add fib6_has_custom_rules() helper (bsc#1154353).
- bpf: skmsg, fix potential psock NULL pointer dereference
  (bsc#1154353).
- lwtunnel: check erspan options before allocating tun_info
  (bsc#1154353).
- lwtunnel: be STRICT to validate the new LWTUNNEL_IP(6)_OPTS
  (bsc#1154353).
- net: remove the unnecessary strict_start_type in some policies
  (bsc#1154353).
- net: sched: allow flower to match erspan options (bsc#1154353).
- net: sched: allow flower to match vxlan options (bsc#1154353).
- net: sched: add erspan option support to act_tunnel_key
  (bsc#1154353).
- net: sched: add vxlan option support to act_tunnel_key
  (bsc#1154353).
- net: sfp: soft status and control support (bsc#1154353).
- net: sfp: add some quirks for GPON modules (bsc#1154353).
- net: sfp: add support for module quirks (bsc#1154353).
- tcp: warn if offset reach the maxlen limit when using snprintf
  (bsc#1154353).
- ip_gre: Make none-tun-dst gre tunnel store tunnel info as
  metadat_dst in recv (bsc#1154353).
- bpf: Switch bpf_map_{area_alloc,area_mmapable_alloc}() to u64
  size (bsc#1154353).
- bpf: Make array_map_mmap static (bsc#1154353).
- bpf: Fix memory leak on object 'data' (bsc#1154353).
- bpf: Add mmap() support for BPF_MAP_TYPE_ARRAY (bsc#1154353).
- bpf: Convert bpf_prog refcnt to atomic64_t (bsc#1154353).
- bpf: Switch bpf_map ref counter to atomic64_t so bpf_map_inc()
  never fails (bsc#1154353).
- bpf: Support attaching tracing BPF program to other BPF programs
  (bsc#1154353).
- bpf: Compare BTF types of functions arguments with actual types
  (bsc#1154353).
- bpf: Annotate context types (bsc#1154353).
- bpf: Reserve space for BPF trampoline in BPF programs
  (bsc#1154353).
- bpf: Add kernel test functions for fentry testing (bsc#1154353).
- bpf: Add bpf_arch_text_poke() helper (bsc#1154353).
- bpf: Refactor x86 JIT into helpers (bsc#1154353).
- bpf: Support doubleword alignment in bpf_jit_binary_alloc
  (bsc#1154353).
- bpf: Add array support to btf_struct_access (bsc#1154353).
- net: ipconfig: Wait for deferred device probes (bsc#1154353).
- net: page_pool: add the possibility to sync DMA memory for
  device (bsc#1154353).
- net: sched: pie: enable timestamp based delay calculation
  (bsc#1154353).
- cxgb4: add TC-MATCHALL classifier ingress offload
  (jsc#SLE-8389).
- cxgb4: check rule prio conflicts before offload (jsc#SLE-8389).
- cxgb4: add TC-MATCHALL classifier egress offload (jsc#SLE-8389).
- net/mlx5e: Rx, Update page pool numa node when changed
  (jsc#SLE-8464).
- page_pool: Don't recycle non-reusable pages (bsc#1154353).
- page_pool: Add API to update numa node (bsc#1154353).
- lwtunnel: add support for multiple geneve opts (bsc#1154353).
- cxgb4: remove unneeded semicolon for switch block
  (jsc#SLE-8389).
- lwtunnel: change to use nla_put_u8 for
  LWTUNNEL_IP_OPT_ERSPAN_VER (bsc#1154353).
- bnxt_en: Abort waiting for firmware response if there is no
  heartbeat (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add a warning message for driver initiated reset
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Return proper error code for non-existent NVM variable
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Report health status update after reset is done
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Set MASTER flag during driver registration
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Extend ETHTOOL_RESET to hot reset driver (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Increase firmware response timeout for coredump
  commands (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Improve RX buffer error handling (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Update firmware interface spec to 1.10.1.12
  (jsc#SLE-8371 bsc#1153274).
- page_pool: add destroy attempts counter and rename tracepoint
  (bsc#1154353).
- xdp: remove memory poison on free for struct xdp_mem_allocator
  (bsc#1154353).
- net: phy: avoid matching all-ones clause 45 PHY IDs
  (bsc#1154353).
- net: phy: marvell10g: add SFP+ support (bsc#1154353).
- net: phy: add core phylib sfp support (bsc#1154353).
- net: phylink: update to use phy_support_asym_pause()
  (bsc#1154353).
- bonding: symmetric ICMP transmit (bsc#1154353).
- net: core: allow fast GRO for skbs with Ethernet header in head
  (bsc#1154353).
- bnx2x: Remove hw_reset_t function casts (bsc#1154395).
- bnx2x: Remove format_fw_ver_t function casts (bsc#1154395).
- bnx2x: Remove config_init_t function casts (bsc#1154395).
- bnx2x: Remove read_status_t function casts (bsc#1154395).
- bnx2x: Drop redundant callback function casts (bsc#1154395).
- page_pool: do not release pool until inflight == 0
  (bsc#1154353).
- tun: fix data-race in gro_normal_list() (bsc#1154353).
- mlxsw: spectrum_router: Allocate discard adjacency entry when
  needed (bsc#1154488).
- net/tls: Fix unused function warning (bsc#1154353).
- net/mlx5: Add devlink reload (jsc#SLE-8464).
- net/mlx5e: Set netdev name space on creation (jsc#SLE-8464).
- net/mlx5: Remove redundant NULL initializations (jsc#SLE-8464).
- net/mlx5: Read num_vfs before disabling SR-IOV (jsc#SLE-8464).
- net/mlx5: DR, Fix matcher builders select check (jsc#SLE-8464).
- net/mlx5: Add new chain for netfilter flow table offload
  (jsc#SLE-8464).
- net/mlx5: Refactor creating fast path prio chains
  (jsc#SLE-8464).
- net/mlx5: Accumulate levels for chains prio namespaces
  (jsc#SLE-8464).
- net/mlx5: Define fdb tc levels per prio (jsc#SLE-8464).
- net/mlx5: Rename FDB_* tc related defines to FDB_TC_* defines
  (jsc#SLE-8464).
- net/mlx5: Simplify fdb chain and prio eswitch defines
  (jsc#SLE-8464).
- IB/mlx5: Load profile according to RoCE enablement state
  (jsc#SLE-8446).
- IB/mlx5: Rename profile and init methods (jsc#SLE-8446).
- net/mlx5: Handle "enable_roce" devlink param (jsc#SLE-8464).
- net/mlx5: Document flow_steering_mode devlink param
  (jsc#SLE-8464).
- devlink: Add new "enable_roce" generic device param
  (bsc#1154353).
- net/mlx5: fix spelling mistake "metdata" -> "metadata"
  (jsc#SLE-8464).
- net/mlx5: fix kvfree of uninitialized pointer spec
  (jsc#SLE-8464).
- IB/mlx5: Introduce and use mlx5_core_is_vf() (jsc#SLE-8446).
- net/mlx5: E-switch, Enable metadata on own vport (jsc#SLE-8464).
- net/mlx5: Refactor ingress acl configuration (jsc#SLE-8464).
- net/mlx5: Restrict metadata disablement to offloads mode
  (jsc#SLE-8464).
- net/mlx5: E-switch, Offloads shift ACL programming during
  enable/disable vport (jsc#SLE-8464).
- net/mlx5: E-switch, Offloads introduce and use per vport acl
  tables APIs (jsc#SLE-8464).
- net/mlx5: Move ACL drop counters life cycle close to ACL
  lifecycle (jsc#SLE-8464).
- net/mlx5: E-switch, Legacy introduce and use per vport acl
  tables APIs (jsc#SLE-8464).
- net/mlx5: E-switch, Prepare code to handle vport enable error
  (jsc#SLE-8464).
- net/mlx5: Tide up state_lock and vport enabled flag usage
  (jsc#SLE-8464).
- net/mlx5: Move legacy drop counter and rule under legacy
  structure (jsc#SLE-8464).
- net/mlx5: Move metdata fields under offloads structure
  (jsc#SLE-8464).
- net/mlx5: Correct comment for legacy fields (jsc#SLE-8464).
- net/mlx5: Introduce and use mlx5_esw_is_manager_vport()
  (jsc#SLE-8464).
- net/mlx5: E-switch, Introduce and use vlan rule config helper
  (jsc#SLE-8464).
- net/mlx5: E-Switch, Rename ingress acl config in offloads mode
  (jsc#SLE-8464).
- net/mlx5: E-Switch, Rename egress config to generic name
  (jsc#SLE-8464).
- net/mlx5: Fixed a typo in a comment in esw_del_uc_addr()
  (jsc#SLE-8464).
- net/mlx5: Expose optimal performance scatter entries capability
  (jsc#SLE-8446).
- cxgb4: Fix an error code in cxgb4_mqprio_alloc_hw_resources()
  (jsc#SLE-8389).
- bnxt_en: Fix array overrun in bnxt_fill_l2_rewrite_fields()
  (jsc#SLE-8371 bsc#1153274).
- net: sfp: fix spelling mistake "requies" -> "requires"
  (bsc#1154353).
- bridge: implement get_link_ksettings ethtool method
  (bsc#1154353).
- vxlan: implement get_link_ksettings ethtool method
  (bsc#1154353).
- sfc: trace_xdp_exception on XDP failure (jsc#SLE-8314).
- net/sched: actions: remove unused 'order' (bsc#1154353).
- netdevsim: Update dummy reporter's devlink binary interface
  (bsc#1154353).
- net/mlx5: Dump of fw_fatal use updated devlink binary interface
  (jsc#SLE-8464).
- devlink: Allow large formatted message of binary output
  (bsc#1154353).
- cxgb4: make function 'cxgb4_mqprio_free_hw_resources' static
  (jsc#SLE-8389).
- mlxsw: spectrum: Enable EMAD string TLV (bsc#1154488).
- mlxsw: core: Add support for using EMAD string TLV
  (bsc#1154488).
- mlxsw: core: Extend EMAD information reported to devlink hwerr
  (bsc#1154488).
- mlxsw: core: Add support for EMAD string TLV parsing
  (bsc#1154488).
- mlxsw: core: Add EMAD string TLV (bsc#1154488).
- mlxsw: emad: Remove deprecated EMAD TLVs (bsc#1154488).
- mlxsw: core: Parse TLVs' offsets of incoming EMADs
  (bsc#1154488).
- cxgb4: remove redundant assignment to hdr_len (jsc#SLE-8389).
- mlxsw: core: Enable devlink reload only on probe (bsc#1154488).
- net: sfp: allow modules with slow diagnostics to probe
  (bsc#1154353).
- net: sfp: allow sfp to probe slow to initialise GPON modules
  (bsc#1154353).
- net: sfp: move module insert reporting out of probe
  (bsc#1154353).
- net: sfp: split power mode switching from probe (bsc#1154353).
- net: sfp: track upstream's attachment state in state machine
  (bsc#1154353).
- net: sfp: ensure TX_FAULT has deasserted before probing the PHY
  (bsc#1154353).
- net: sfp: allow fault processing to transition to other states
  (bsc#1154353).
- net: sfp: eliminate mdelay() from PHY probe (bsc#1154353).
- net: sfp: split the PHY probe from sfp_sm_mod_init()
  (bsc#1154353).
- net: sfp: control TX_DISABLE and phy only from main state
  machine (bsc#1154353).
- net: sfp: avoid power switch on address-change modules
  (bsc#1154353).
- net: sfp: parse SFP power requirement earlier (bsc#1154353).
- net: sfp: rename T_PROBE_WAIT to T_SERIAL (bsc#1154353).
- net: sfp: handle module remove outside state machine
  (bsc#1154353).
- net: sfp: rename sfp_sm_ins_next() as sfp_sm_mod_next()
  (bsc#1154353).
- net: sfp: move tx disable on device down to main state machine
  (bsc#1154353).
- net: sfp: move sfp sub-state machines into separate functions
  (bsc#1154353).
- net: sfp: fix sfp_bus_put() kernel documentation (bsc#1154353).
- lwtunnel: ignore any TUNNEL_OPTIONS_PRESENT flags set by users
  (bsc#1154353).
- lwtunnel: get nlsize for erspan options properly (bsc#1154353).
- lwtunnel: change to use nla_parse_nested on new options
  (bsc#1154353).
- net: sfp: rework upstream interface (bsc#1154353).
- devlink: disallow reload operation during device cleanup
  (bsc#1154353).
- packet: fix data-race in fanout_flow_is_huge() (bsc#1154353).
- ice: print opcode when printing controlq errors (jsc#SLE-7926).
- ice: use more accurate ICE_DBG mask types (jsc#SLE-7926).
- ice: Introduce and use ice_vsi_type_str (jsc#SLE-7926).
- ice: remove unnecessary conditional check (jsc#SLE-7926).
- ice: Update enum ice_flg64_bits to current specification
  (jsc#SLE-7926).
- ice: delay less (jsc#SLE-7926).
- ice: use pkg_dwnld_status instead of sq_last_status
  (jsc#SLE-7926).
- ice: Change max MSI-x vector_id check in cfg_irq_map
  (jsc#SLE-7926).
- ice: Check if VF is disabled for Opcode and other operations
  (jsc#SLE-7926).
- ice: configure software LLDP in ice_init_pf_dcb (jsc#SLE-7926).
- ice: Fix to change Rx/Tx ring descriptor size via ethtool with
  DCBx (jsc#SLE-7926).
- ice: avoid setting features during reset (jsc#SLE-7926).
- ice: Implement DCBNL support (jsc#SLE-7926).
- ice: Add NDO callback to set the maximum per-queue bitrate
  (jsc#SLE-7926).
- ice: Use ice_ena_vsi and ice_dis_vsi in DCB configuration flow
  (jsc#SLE-7926).
- net: icmp: fix data-race in cmp_global_allow() (bsc#1154353).
- cxgb4: fix 64-bit division on i386 (jsc#SLE-8389).
- cxgb4: Use match_string() helper to simplify the code
  (jsc#SLE-8389).
- net: add a READ_ONCE() in skb_peek_tail() (bsc#1154353).
- net: add annotations on hh->hh_len lockless accesses
  (bsc#1154353).
- net: use u64_stats_t in struct pcpu_lstats (bsc#1154353).
- tun: switch to u64_stats_t (bsc#1154353).
- u64_stats: provide u64_stats_t type (bsc#1154353).
- net: dummy: use standard dev_lstats_add() and dev_lstats_read()
  (bsc#1154353).
- vsockmon: use standard dev_lstats_add() and dev_lstats_read()
  (bsc#1154353).
- veth: use standard dev_lstats_add() and dev_lstats_read()
  (bsc#1154353).
- net: nlmon: use standard dev_lstats_add() and dev_lstats_read()
  (bsc#1154353).
- net: provide dev_lstats_add() helper (bsc#1154353).
- net: provide dev_lstats_read() helper (bsc#1154353).
- net: ethernet: intel: Demote MTU change prints to debug
  (jsc#SLE-7966).
- mlxsw: Add layer 3 devlink-trap exceptions support
  (bsc#1154488).
- mlxsw: Add specific trap for packets routed via invalid nexthops
  (bsc#1154488).
- mlxsw: Add new FIB entry type for reject routes (bsc#1154488).
- devlink: Add layer 3 generic packet exception traps
  (bsc#1154353).
- mlxsw: Add layer 3 devlink-trap support (bsc#1154488).
- devlink: Add layer 3 generic packet traps (bsc#1154353).
- tcp: Remove one extra ktime_get_ns() from cookie_init_timestamp
  (bsc#1154353).
- inetpeer: fix data-race in inet_putpeer / inet_putpeer
  (bsc#1154353).
- mlxsw: spectrum: Fix error return code in
  mlxsw_sp_port_module_info_init() (bsc#1154488).
- cxgb4: add FLOWC based QoS offload (jsc#SLE-8389).
- cxgb4: add Tx and Rx path for ETHOFLD traffic (jsc#SLE-8389).
- cxgb4: add ETHOFLD hardware queue support (jsc#SLE-8389).
- cxgb4: parse and configure TC-MQPRIO offload (jsc#SLE-8389).
- cxgb4: rework queue config and MSI-X allocation (jsc#SLE-8389).
- cxgb4: query firmware for QoS offload resources (jsc#SLE-8389).
- net_sched: gen_estimator: extend packet counter to 64bit
  (bsc#1154353).
- ice: Fix return value when SR-IOV is not supported
  (jsc#SLE-7926).
- ice: Rename VF function ice_vc_dis_vf to match its behavior
  (jsc#SLE-7926).
- ice: Get rid of ice_cleanup_header (jsc#SLE-7926).
- ice: print PCI link speed and width (jsc#SLE-7926).
- ice: print unsupported module message (jsc#SLE-7926).
- ice: write register with correct offset (jsc#SLE-7926).
- ice: Check for null pointer dereference when setting rings
  (jsc#SLE-7926).
- ice: save PCI state in probe (jsc#SLE-7926).
- ice: Adjust DCB INIT for SW mode (jsc#SLE-7926).
- ice: fix driver unload flow (jsc#SLE-7926).
- ice: handle DCBx non-contiguous TC request (jsc#SLE-7926).
- ice: Update Boot Configuration Section read of NVM
  (jsc#SLE-7926).
- ice: add ethtool -m support for reading i2c eeprom modules
  (jsc#SLE-7926).
- tcp: fix data-race in tcp_recvmsg() (bsc#1154353).
- net: silence data-races on sk_backlog.tail (bsc#1154353).
- lwtunnel: add options setting and dumping for erspan
  (bsc#1154353).
- lwtunnel: add options setting and dumping for vxlan
  (bsc#1154353).
- lwtunnel: add options setting and dumping for geneve
  (bsc#1154353).
- lwtunnel: add options process for cmp_encap (bsc#1154353).
- lwtunnel: add options process for arp request (bsc#1154353).
- net: annotate lockless accesses to sk->sk_max_ack_backlog
  (bsc#1154353).
- net: annotate lockless accesses to sk->sk_ack_backlog
  (bsc#1154353).
- net: use helpers to change sk_ack_backlog (bsc#1154353).
- net: avoid potential false sharing in neighbor related code
  (bsc#1154353).
- inet_diag: use jiffies_delta_to_msecs() (bsc#1154353).
- net: neigh: use long type to store jiffies delta (bsc#1154353).
- netdevsim: drop code duplicated by a merge (bsc#1154353).
- cxgb4: Add pci reset handler (jsc#SLE-8389).
- cnic: Set fp_hsi_ver as part of CLIENT_SETUP ramrod
  (bsc#1154395).
- bnx2x: Fix PF-VF communication over multi-cos queues
  (bsc#1154395).
- bnx2x: Enable Multi-Cos feature (bsc#1154395).
- bnx2x: Utilize FW 7.13.15.0 (bsc#1154395).
- net_sched: add TCA_STATS_PKT64 attribute (bsc#1154353).
- net_sched: extend packet counter to 64bit (bsc#1154353).
- net_sched: do not export gnet_stats_basic_packed to uapi
  (bsc#1154353).
- net: hns3: remove unused macros (bsc#1154353).
- vsock: Simplify '__vsock_release()' (bsc#1154353).
- icmp: remove duplicate code (bsc#1154353).
- icmp: add helpers to recognize ICMP error packets (bsc#1154353).
- ice: allow 3k MTU for XDP (jsc#SLE-7926).
- ice: add build_skb() support (jsc#SLE-7926).
- ice: introduce frame padding computation logic (jsc#SLE-7926).
- ice: introduce legacy Rx flag (jsc#SLE-7926).
- ice: Add support for AF_XDP (jsc#SLE-7926).
- ice: Move common functions to ice_txrx_lib.c (jsc#SLE-7926).
- ice: Add support for XDP (jsc#SLE-7926).
- ice: get rid of per-tc flow in Tx queue configuration routines
  (jsc#SLE-7926).
- ice: Introduce ice_base.c (jsc#SLE-7926).
- i40e: implement VF stats NDO (jsc#SLE-8025).
- i40e: enable X710 support (jsc#SLE-8025).
- ixgbe: protect TX timestamping from API misuse (jsc#SLE-7979
  jsc#SLE-7981).
- fm10k: update driver version to match out-of-tree
  (jsc#SLE-8009).
- ixgbe: Make use of cpumask_local_spread to improve RSS locality
  (jsc#SLE-7979 jsc#SLE-7981).
- fm10k: add support for ndo_get_vf_stats operation
  (jsc#SLE-8009).
- fm10k: add missing field initializers to TLV attributes)
  (jsc#SLE-8009).
- ipv6: use jhash2() in rt6_exception_hash() (bsc#1154353).
- net: bridge: fdb: eliminate extra port state tests from
  fast-path (bsc#1154353).
- net/mlx5: DR, Support IPv4 and IPv6 mixed matcher
  (jsc#SLE-8464).
- net/mlx5: LAG, Use affinity type enumerators (jsc#SLE-8464).
- net/mlx5: LAG, Use port enumerators (jsc#SLE-8464).
- net/mlx5: rate limit alloc_ent error messages (jsc#SLE-8464).
- net/mlx5e: Add ToS (DSCP) header rewrite support (jsc#SLE-8464).
- net/mlx5e: Bit sized fields rewrite support (jsc#SLE-8464).
- net/mlx5: WQ, Move short getters into header file
  (jsc#SLE-8464).
- net/mlx5e: TX, Dump WQs wqe descriptors on CQE with error events
  (jsc#SLE-8464).
- net/mlx5: Support lockless FTE read lookups (jsc#SLE-8464).
- net/mlx5: Do not hold group lock while allocating FTE in
  software (jsc#SLE-8464).
- net/mlx5e: Verify that rule has at least one fwd/drop action
  (jsc#SLE-8464).
- net/mlx5: Clear VF's configuration on disabling SRIOV
  (jsc#SLE-8464).
- net/mlx5: Remove unneeded variable in mlx5_unload_one
  (jsc#SLE-8464).
- net/mlx5: FPGA, support network cards with standalone FPGA
  (jsc#SLE-8464).
- net/mlx5: DR, Replace CRC32 implementation to use kernel lib
  (jsc#SLE-8464).
- net: icmp6: provide input address for traceroute6 (bsc#1154353).
- net: icmp: use input address in traceroute (bsc#1154353).
- xsk: Restructure/inline XSKMAP lookup/redirect/flush
  (bsc#1154353).
- bpf: Implement map_gen_lookup() callback for XSKMAP
  (bsc#1154353).
- xsk: Store struct xdp_sock as a flexible array member of the
  XSKMAP (bsc#1154353).
- bpf: Replace prog_raw_tp+btf_id with prog_tracing (bsc#1154353).
- bpf: Enforce 'return 0' in BTF-enabled raw_tp programs
  (bsc#1154353).
- net: bridge: fdb: restore unlikely() when taking over externally
  added entries (bsc#1154353).
- net: bridge: fdb: avoid two atomic bitops in
  br_fdb_external_learn_add() (bsc#1154353).
- net: bridge: fdb: br_fdb_update can take flags directly
  (bsc#1154353).
- bnxt_en: Call bnxt_ulp_stop()/bnxt_ulp_start() during
  suspend/resume (jsc#SLE-8372 bsc#1153275).
- bnxt_en: Call bnxt_ulp_stop()/bnxt_ulp_start() during error
  recovery (jsc#SLE-8372 bsc#1153275).
- bnxt_en: Improve bnxt_ulp_stop()/bnxt_ulp_start() call sequence
  (jsc#SLE-8372 bsc#1153275).
- bnxt_en: flow_offload: offload tunnel decap rules via indirect
  callbacks (jsc#SLE-8372 bsc#1153275).
- bnxt_en: Add support for NAT(L3/L4 rewrite) (jsc#SLE-8372
  bsc#1153275).
- bnxt: Avoid logging an unnecessary message when a flow can't
  be offloaded (jsc#SLE-8372 bsc#1153275).
- bnxt_en: Add support for L2 rewrite (jsc#SLE-8372 bsc#1153275).
- sfc: add XDP counters to ethtool stats (jsc#SLE-8314).
- sfc: handle XDP_TX outcomes of XDP eBPF programs (jsc#SLE-8314).
- sfc: allocate channels for XDP tx queues (jsc#SLE-8314).
- sfc: Enable setting of xdp_prog (jsc#SLE-8314).
- sfc: perform XDP processing on received packets (jsc#SLE-8314).
- sfc: support encapsulation of xdp_frames in efx_tx_buffer
  (jsc#SLE-8314).
- mlxsw: Fix 64-bit division in mlxsw_sp_sb_prs_init
  (bsc#1154488).
- net: hns3: cleanup byte order issues when printed (bsc#1154353).
- net: hns3: cleanup some print format warning (bsc#1154353).
- net: hns3: add or modify some comments (bsc#1154353).
- net: hns3: optimize local variable initialization (bsc#1154353).
- net: hns3: cleanup a format-truncation warning (bsc#1154353).
- net: hns3: cleanup some coding style issues (bsc#1154353).
- net: hns3: cleanup some magic numbers (bsc#1154353).
- net: hns3: add struct netdev_queue debug info for TX timeout
  (bsc#1154353).
- net: hns3: dump some debug information when reset fail
  (bsc#1154353).
- bnxt_en: Add support to collect crash dump via ethtool
  (jsc#SLE-8372 bsc#1153275).
- bnxt_en: Add support to invoke OP-TEE API to reset firmware
  (jsc#SLE-8372 bsc#1153275).
- mlxsw: spectrum: Generalize split count check (bsc#1154488).
- mlxsw: spectrum: Iterate over all ports in gap during unsplit
  create (bsc#1154488).
- mlxsw: spectrum: Fix base port get for split count 4 and 8
  (bsc#1154488).
- mlxsw: spectrum: Use port_module_max_width to compute base
  port index (bsc#1154488).
- mlxsw: spectrum: Remember split base local port and use it in
  unsplit (bsc#1154488).
- mlxsw: spectrum: Introduce resource for getting offset of 4
  lanes split port (bsc#1154488).
- mlxsw: spectrum: Push getting offsets of split ports into a
  helper (bsc#1154488).
- mlxsw: spectrum: Add sanity checks into module info get
  (bsc#1154488).
- mlxsw: spectrum: Pass mapping values in port mapping structure
  (bsc#1154488).
- mlxsw: spectrum: Use mapping of port being split for creating
  split ports (bsc#1154488).
- mlxsw: spectrum: Replace port_to_module array with array of
  structs (bsc#1154488).
- mlxsw: spectrum: Distinguish between unsplittable and split port
  (bsc#1154488).
- mlxsw: spectrum: Move max_width check up before count check
  (bsc#1154488).
- mlxsw: spectrum: Use PMTM register to get max module width
  (bsc#1154488).
- mlxsw: reg: Add Port Module Type Mapping Register (bsc#1154488).
- mlxsw: reg: Extend PMLP tx/rx lane value size to 4 bits
  (bsc#1154488).
- cxgb4/l2t: Simplify 't4_l2e_free()' and '_t4_l2e_free()'
  (jsc#SLE-8389).
- net: sched: update action implementations to support flags
  (bsc#1154353).
- net: sched: extend TCA_ACT space with TCA_ACT_FLAGS
  (bsc#1154353).
- net: sched: modify stats helper functions to support regular
  stats (bsc#1154353).
- net: sched: don't expose action qstats to skb_tc_reinsert()
  (bsc#1154353).
- net: sched: extract qstats update code into functions
  (bsc#1154353).
- net: sched: extract bstats update code into function
  (bsc#1154353).
- net: sched: extract common action counters update code into
  function (bsc#1154353).
- e1000e: Fix compiler warning when CONFIG_PM_SLEEP is not set
  (jsc#SLE-8100).
- e1000e: Add support for Tiger Lake (jsc#SLE-8100).
- i40e: Add UDP segmentation offload support (jsc#SLE-8025).
- ixgbe: Add UDP segmentation offload support (jsc#SLE-7979
  jsc#SLE-7981).
- igb: Add UDP segmentation offload support (jsc#SLE-7967
  jsc#SLE-8010).
- e1000e: Drop unnecessary __E1000_DOWN bit twiddling
  (jsc#SLE-8100).
- e1000e: Use rtnl_lock to prevent race conditions between net
  and pci/pm (jsc#SLE-8100).
- e1000e: Add support for Comet Lake (jsc#SLE-8100).
- vxlan: drop "vxlan" parameter in vxlan_fdb_alloc()
  (bsc#1154353).
- net: phy: marvell: add downshift support for 88E1145
  (bsc#1154353).
- bonding: balance ICMP echoes in layer3+4 mode (bsc#1154353).
- flow_dissector: extract more ICMP information (bsc#1154353).
- flow_dissector: skip the ICMP dissector for non ICMP packets
  (bsc#1154353).
- flow_dissector: add meaningful comments (bsc#1154353).
- mlxsw: Enforce firmware version for Spectrum-2 (bsc#1154488).
- mlxsw: Bump firmware version to 13.2000.2308 (bsc#1154488).
- mlxsw: pci: Increase PCI reset timeout for SN3800 systems
  (bsc#1154488).
- mlxsw: reg: Increase size of MPAR register (bsc#1154488).
- net: bridge: fdb: set flags directly in fdb_create
  (bsc#1154353).
- net: bridge: fdb: convert offloaded to use bitops (bsc#1154353).
- net: bridge: fdb: convert added_by_external_learn to use bitops
  (bsc#1154353).
- net: bridge: fdb: convert added_by_user to bitops (bsc#1154353).
- net: bridge: fdb: convert is_sticky to bitops (bsc#1154353).
- net: bridge: fdb: convert is_static to bitops (bsc#1154353).
- net: bridge: fdb: convert is_local to bitops (bsc#1154353).
- inet: do not call sublist_rcv on empty list (bsc#1154353).
- broadcom: bnxt: Fix use true/false for bool (bsc#1154353).
- cavium: thunder: Fix use true/false for bool type (bsc#1154353).
- net: phy: marvell: add PHY tunable support for more PHY versions
  (bsc#1154353).
- net: phy: marvell: add downshift support for M88E1111
  (bsc#1154353).
- net: phy: marvell: fix downshift function naming (bsc#1154353).
- net: phy: marvell: fix typo in constant
  MII_M1011_PHY_SRC_DOWNSHIFT_MASK (bsc#1154353).
- i40e: prevent memory leak in i40e_setup_macvlans (jsc#SLE-8025).
- i40e: Refactoring VF MAC filters counting to make more reliable
  (jsc#SLE-8025).
- i40e: Fix LED blinking flow for X710T*L devices (jsc#SLE-8025).
- i40e: allow ethtool to report SW and FW versions in recovery
  mode (jsc#SLE-8025).
- i40e: initialize ITRN registers with correct values
  (jsc#SLE-8025).
- i40e: Extend PHY access with page change flag (jsc#SLE-8025).
- i40e: Extract detection of HW flags into a function
  (jsc#SLE-8025).
- i40e: Wrong 'Advertised FEC modes' after set FEC to AUTO
  (jsc#SLE-8025).
- i40e: Fix for persistent lldp support (jsc#SLE-8025).
- sock: remove unneeded semicolon (bsc#1154353).
- mlxsw: spectrum_buffers: remove unneeded semicolon
  (bsc#1154488).
- mvpp2: prefetch frame header (bsc#1154353).
- mvpp2: sync only the received frame (bsc#1154353).
- mvpp2: refactor frame drop routine (bsc#1154353).
- net: Fix various misspellings of "connect" (bsc#1154353).
- net: Fix misspellings of "configure" and "configuration"
  (bsc#1154353).
- bpf: Prepare btf_ctx_access for non raw_tp use case
  (bsc#1154353).
- bpf: Allow __sk_buff tstamp in BPF_PROG_TEST_RUN (bsc#1154353).
- ipvs: batch __ip_vs_dev_cleanup (bsc#1154353).
- ipvs: batch __ip_vs_cleanup (bsc#1154353).
- ipvs: no need to update skb route entry for local destination
  packets (bsc#1154353).
- tcp: add TCP_INFO status for failed client TFO (bsc#1154353).
- mlxsw: spectrum_buffers: Calculate the size of the main pool
  (bsc#1154488).
- mlxsw: spectrum: Use guaranteed buffer size as pool size limit
  (bsc#1154488).
- net: phy: add support for clause 37 auto-negotiation
  (bsc#1154353).
- net: phy: modify assignment to OR for dev_flags in
  phy_attach_direct (bsc#1154353).
- fq_codel: do not include <linux/jhash.h> (bsc#1154353).
- mlxsw: core: Extend QSFP EEPROM size for ethtool (bsc#1154488).
- mlxsw: reg: Add macro for getting QSFP module EEPROM page number
  (bsc#1154488).
- igc: Clean up unused shadow_vfta pointer (jsc#SLE-7966).
- igc: Add Rx checksum support (jsc#SLE-7966).
- igc: Add set_rx_mode support (jsc#SLE-7966).
- e1000e: Add support for S0ix (jsc#SLE-8100).
- igc: Add SCTP CRC checksumming functionality (jsc#SLE-7966).
- net/sched: act_police: re-use tcf_tm_dump() (bsc#1154353).
- net: phy: marvell: remove superseded function
  marvell_set_downshift (bsc#1154353).
- net: phy: marvell: support downshift as PHY tunable
  (bsc#1154353).
- net: hns3: log and clear hardware error after reset complete
  (bsc#1154353).
- net: hns3: do not allocate linear data for fraglist skb
  (bsc#1154353).
- net: hns3: minor cleanup for hns3_handle_rx_bd() (bsc#1154353).
- net: hns3: make struct hns3_enet_ring cacheline aligned
  (bsc#1154353).
- net: hns3: introduce ring_to_netdev() in enet module
  (bsc#1154353).
- net: hns3: minor optimization for barrier in IO path
  (bsc#1154353).
- net: hns3: optimized MAC address in management table
  (bsc#1154353).
- net: hns3: remove struct hns3_nic_ring_data in hns3_enet module
  (bsc#1154353).
- mlxsw: spectrum: Register switched port analyzers (SPAN)
  as resource (bsc#1154488).
- net: phy: avoid NPE if read_page/write_page callbacks are not
  available (bsc#1154353).
- net: sched: Avoid using yield() in a busy waiting loop
  (bsc#1154353).
- pktgen: remove unnecessary assignment in pktgen_xmit()
  (bsc#1154353).
- net: sfp: move fwnode parsing into sfp-bus layer (bsc#1154353).
- net: phylink: use more linkmode_* (bsc#1154353).
- net_sched: sch_fq: remove one obsolete check in fq_dequeue()
  (bsc#1154353).
- net: core: use listified Rx for GRO_NORMAL in napi_gro_receive()
  (bsc#1154353).
- mlxsw: spectrum: Add support for 400Gbps (50Gbps per lane)
  link modes (bsc#1154488).
- ethtool: Add support for 400Gbps (50Gbps per lane) link modes
  (bsc#1154353).
- xdp: Trivial, fix spelling in function description
  (bsc#1154353).
- bpf: Fix cast to pointer from integer of different size warning
  (bsc#1154353).
- flow_dissector: Allow updating the flow dissector program
  atomically (bsc#1154353).
- bpf: Align struct bpf_prog_stats (bsc#1154353).
- bpf/flow_dissector: add mode to enforce global BPF flow
  dissector (bsc#1154353).
- genetlink: do not parse attributes for families with zero
  maxattr (bsc#1154353).
- tcp: improve recv_skip_hint for tcp_zerocopy_receive
  (bsc#1154353).
- netdevsim: implement couple of testing devlink health reporters
  (bsc#1154353).
- devlink: propagate extack down to health reporter ops
  (bsc#1154353).
- devlink: don't do reporter recovery if the state is healthy
  (bsc#1154353).
- sock_get_timeout: drop unnecessary return variable
  (bsc#1154353).
- af_unix: __unix_find_socket_byname() cleanup (bsc#1154353).
- ipvlan: consolidate TSO flags using NETIF_F_ALL_TSO
  (bsc#1154353).
- team: call RCU read lock when walking the port_list
  (bsc#1154353).
- Revert "tun: call dev_get_valid_name() before
  register_netdevice()" (bsc#1154353).
- net: tipc: prepare attrs in __tipc_nl_compat_dumpit()
  (bsc#1154353).
- net: genetlink: always allocate separate attrs for dumpit ops
  (bsc#1154353).
- net: hns3: support tx-scatter-gather-fraglist feature
  (bsc#1154353).
- net: hns3: add support for configuring VF MAC from the host
  (bsc#1154353).
- net: hns3: add support for configuring bandwidth of VF on the
  host (bsc#1154353).
- net: hns3: add support for setting VF trust (bsc#1154353).
- net: hns3: add support for spoof check setting (bsc#1154353).
- net: hns3: add support for setting VF link status on the host
  (bsc#1154353).
- tun: fix memory leak in error path (bsc#1154353).
- netdevsim: fix spelling mistake "forbidded" -> "forbid"
  (bsc#1154353).
- nfp: bpf: make array exp_mask static, makes object smaller
  (bsc#1154353).
- net: hns3: make array tick_array static, makes object smaller
  (bsc#1154353).
- net: hns: make arrays static, makes object smaller
  (bsc#1154353).
- net/tls: store decrypted on a single bit (bsc#1154353).
- net/tls: store async_capable on a single bit (bsc#1154353).
- net/tls: pass context to tls_device_decrypted() (bsc#1154353).
- net/tls: make allocation failure unlikely (bsc#1154353).
- net/tls: mark sk->err being set as unlikely (bsc#1154353).
- net: core: use helper skb_ensure_writable in more places
  (bsc#1154353).
- ipv6: Make ipv6_mc_may_pull() return bool (bsc#1154353).
- net: core: change return type of pskb_may_pull to bool
  (bsc#1154353).
- net: ena: ethtool: support set_channels callback (bsc#1154492).
- net: ena: remove redundant print of number of queues
  (bsc#1154492).
- net: ena: make ethtool -l show correct max number of queues
  (bsc#1154492).
- net: ena: ethtool: get_channels: use combined only
  (bsc#1154492).
- net: ena: multiple queue creation related cleanups
  (bsc#1154492).
- net: ena: change num_queues to num_io_queues for clarity and
  consistency (bsc#1154492).
- netdevsim: implement devlink dev_info op (bsc#1154353).
- net: devlink: fix reporter dump dumpit (bsc#1154353).
- mlxsw: minimal: Add validation for FW version (bsc#1154488).
- mlxsw: core: Push minor/subminor fw version check into helper
  (bsc#1154488).
- mlxsw: thermal: Provide optimization for QSFP modules number
  detection (bsc#1154488).
- mlxsw: hwmon: Provide optimization for QSFP modules number
  detection (bsc#1154488).
- mlxsw: reg: Extend MGPIR register with new field exposing the
  number of QSFP modules (bsc#1154488).
- netdevsim: add couple of debugfs bools to debug devlink reload
  (bsc#1154353).
- devlink: have genetlink code to parse the attrs during dumpit
  (bsc#1154353).
- net: tipc: allocate attrs locally instead of using
  genl_family_attrbuf in compat_dumpit() (bsc#1154353).
- net: tipc: have genetlink code to parse the attrs during dumpit
  (bsc#1154353).
- net: nfc: have genetlink code to parse the attrs during dumpit
  (bsc#1154353).
- net: ieee802154: have genetlink code to parse the attrs during
  dumpit (bsc#1154353).
- net: genetlink: parse attrs and store in contect info struct
  during dumpit (bsc#1154353).
- net: genetlink: push attrbuf allocation and parsing to a
  separate function (bsc#1154353).
- net: genetlink: introduce dump info struct to be available
  during dumpit op (bsc#1154353).
- net: genetlink: push doit/dumpit code from genl_family_rcv_msg
  (bsc#1154353).
- netdevsim: create devlink and netdev instances in namespace
  (bsc#1154353).
- net: devlink: export devlink net setter (bsc#1154353).
- net/tls: add TlsDeviceRxResync statistic (bsc#1154353).
- net/tls: add TlsDecryptError stat (bsc#1154353).
- net/tls: add statistics for installed sessions (bsc#1154353).
- net/tls: add skeleton of MIB statistics (bsc#1154353).
- net/tls: add device decrypted trace point (bsc#1154353).
- net/tls: add tracing for device/offload events (bsc#1154353).
- net: devlink: don't ignore errors during dumpit (bsc#1154353).
- igmp: uninline ip_mc_validate_checksum() (bsc#1154353).
- net: spread "enum sock_flags" (bsc#1154353).
- net/tls: rename tls_hw_* functions tls_toe_* (bsc#1154353).
- net/tls: move TOE-related code to a separate file (bsc#1154353).
- net/tls: move tls_build_proto() on init path (bsc#1154353).
- net/tls: rename tls_device to tls_toe_device (bsc#1154353).
- net/tls: move TOE-related structures to a separate header
  (bsc#1154353).
- net: devlink: allow to change namespaces during reload
  (bsc#1154353).
- netdevsim: take devlink net instead of init_net (bsc#1154353).
- netdevsim: register port netdevices into net of device
  (bsc#1154353).
- netdevsim: implement proper devlink reload (bsc#1154353).
- netdevsim: add all ports in nsim_dev_create() and del them in
  destroy() (bsc#1154353).
- mlxsw: Propagate extack down to register_fib_notifier()
  (bsc#1154488).
- mlxsw: Register port netdevices into net of core (bsc#1154488).
- mlxsw: spectrum: Take devlink net instead of init_net
  (bsc#1154488).
- net: devlink: export devlink net getter (bsc#1154353).
- net: fib_notifier: propagate extack down to the notifier block
  callback (bsc#1154353).
- mlxsw: spectrum_router: Don't rely on missing extack to
  symbolize dump (bsc#1154488).
- net: fib_notifier: propagate possible error during fib notifier
  registration (bsc#1154353).
- net: fib_notifier: make FIB notifier per-netns (bsc#1154353).
- netdevsim: change fib accounting and limitations to be
  per-device (bsc#1154353).
- net: propagate errors correctly in register_netdevice()
  (bsc#1154353).
- mvpp2: remove misleading comment (bsc#1154353).
- net_sched: remove need_resched() from qdisc_run() (bsc#1154353).
- net: introduce per-netns netdevice notifiers (bsc#1154353).
- net: push loops and nb calls into helper functions
  (bsc#1154353).
- ipv6: minor code reorg in inet6_fill_ifla6_attrs()
  (bsc#1154353).
- net: rtnetlink: add possibility to use alternative names as
  message handle (bsc#1154353).
- net: rtnetlink: introduce helper to get net_device instance
  by ifname (bsc#1154353).
- net: rtnetlink: unify the code in __rtnl_newlink get dev with
  the rest (bsc#1154353).
- net: rtnetlink: put alternative names to getlink message
  (bsc#1154353).
- net: rtnetlink: add linkprop commands to add and delete
  alternative ifnames (bsc#1154353).
- net: introduce name_node struct to be used in hashlist
  (bsc#1154353).
- net: procfs: use index hashlist instead of name hashlist
  (bsc#1154353).
- tcp: add ipv6_addr_v4mapped_loopback() helper (bsc#1154353).
- net: core: dev: replace state xoff flag comparison by
  netif_xmit_stopped method (bsc#1154353).
- ipv6: add priority parameter to ip6_xmit() (bsc#1154353).
- rocker: add missing init_net check in FIB notifier
  (bsc#1154353).
- commit 113b872
* Wed Dec 11 2019 tiwai@suse.de
- spi: pxa2xx: Add support for Intel Comet Lake-H (jsc#SLE-7946).
- mtd: spi-nor: intel-spi: Add support for Intel Comet Lake-H
  SPI serial flash (jsc#SLE-7946).
- commit 66b146b
* Wed Dec 11 2019 tiwai@suse.de
- mfd: intel-lpss: Add Intel Comet Lake PCH-H PCI IDs
  (jsc#SLE-7946).
- mfd: intel-lpss: Add default I2C device properties for Gemini
  Lake (jsc#SLE-7946).
- commit a741dd5
* Wed Dec 11 2019 tiwai@suse.de
- i2c: i801: Correct Intel Jasper Lake SOC naming (jsc#SLE-7946).
- i2c: i801: Add support for Intel Comet Lake PCH-H
  (jsc#SLE-7946).
- commit b378292
* Wed Dec 11 2019 tiwai@suse.de
- i2c: i801: Add support for Intel Jasper Lake (jsc#SLE-7946).
- commit a0fd0de
* Wed Dec 11 2019 tiwai@suse.de
- i2c: i801: Bring back Block Process Call support for certain
  platforms (jsc#SLE-7946).
- i2c: i801: Use iTCO version 6 in Cannon Lake PCH and beyond
  (jsc#SLE-7946).
- commit 7cc4af0
* Wed Dec 11 2019 jroedel@suse.de
- KVM: vmx: use MSR_IA32_TSX_CTRL to hard-disable TSX on guest
  that lack it (CVE-2019-19338 bsc#1158954).
- KVM: vmx: implement MSR_IA32_TSX_CTRL disable RTM functionality
  (CVE-2019-19338 bsc#1158954).
- KVM: x86: fix presentation of TSX feature in ARCH_CAPABILITIES
  (CVE-2019-19338 bsc#1158954).
- commit 431ce6a
* Wed Dec 11 2019 jroedel@suse.de
- KVM: x86: fix out-of-bounds write in KVM_GET_EMULATED_CPUID
  (CVE-2019-19332) (CVE-2019-19332 bsc#1158827).
- commit ed2bb4d
* Wed Dec 11 2019 tonyj@suse.de
- libbpf: Fix sym->st_value print on 32-bit arches (bsc#1158962).
- commit ff62fd7
* Tue Dec 10 2019 bp@suse.de
- EDAC/altera: Use fast register IO for S10 IRQs (bsc#1152489).
- commit 48045b4
* Tue Dec 10 2019 dwagner@suse.de
- scsi: qla2xxx: Add debug dump of LOGO payload and ELS IOCB
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Ignore PORT UPDATE after N2N PLOGI (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Don't defer relogin unconditonally (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Send Notify ACK after N2N PLOGI (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Configure local loop for N2N target (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix PLOGI payload and ELS IOCB dump length
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Don't call qlt_async_event twice (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Allow PLOGI in target mode (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Change discovery state before PLOGI (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Drop superfluous INIT_WORK of del_work
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Initialize free_work before flushing it
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use explicit LOGO in target mode (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Ignore NULL pointer in tcm_qla2xxx_free_mcmd
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix incorrect SFUB length used for Secure Flash
  Update MB Cmd (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Added support for MPI and PEP regions for ISP28XX
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Correctly retrieve and interpret active flash
  region (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- commit b9f4605
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Remove logical HW ID'
- commit c366de4
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix g4x sprite scaling stride check with GTT remapping'
- commit ed52fa1
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/dp: Fix dsc bpp calculations, v5.'
- commit 4e094fc
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Mark contents as dirty on a write fault'
- commit f55151a
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Bump skl+ max plane width to 5k for linear/x-tiled'
- commit 69b4952
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Don't mix srcu tag and negative error codes'
- commit 6d16d9a
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Restore relaxed padding (OCL_OOB_SUPPRES_ENABLE) for skl+'
- commit cd7484b
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Limit MST to <= 8bpc once again'
- commit ead6b3f
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/dp: Fix DSC enable code to use cpu_transcoder instead of encoder->type'
- commit d2a961c
* Tue Dec 10 2019 tiwai@suse.de
- Update patch reference for nfc fix (CVE-2019-19526 bsc#1158893)
- commit 9e59e81
* Tue Dec 10 2019 tzimmermann@suse.de
- drm/i915: Preload LUTs if the hw isn't currently using them (bsc#1152489)
- commit 7d0ea8f
* Tue Dec 10 2019 tzimmermann@suse.de
- video/hdmi: Fix AVI bar unpack (bsc#1152489)
- commit 0ac3f29
* Tue Dec 10 2019 tzimmermann@suse.de
- fbdev/sa1100fb: Remove even more dead code (bsc#1152489)
- commit 896a116
* Tue Dec 10 2019 mkubecek@suse.cz
- update mainline references
  update Patch-mainline tags:
  patches.suse/hugetlb-region_chg-provides-only-cache-entry.patch
  patches.suse/hugetlb-remove-duplicated-code.patch
  patches.suse/hugetlbfs-hugetlb_fault_mutex_hash-cleanup.patch
  patches.suse/hugetlbfs-take-read_lock-on-i_mmap-for-PMD-sharing.patch
  patches.suse/include-linux-memcontrol.h-fix-comments-based-on-per-node-memcg.patch
  patches.suse/mm-clean-up-and-clarify-lruvec-lookup-procedure.patch
  patches.suse/mm-drop-mmap_sem-before-calling-balance_dirty_pages-in-write-fault.patch
  patches.suse/mm-emit-tracepoint-when-RSS-changes.patch
  patches.suse/mm-filemap.c-remove-redundant-cache-invalidation-after-async-direct-io-write.patch
  patches.suse/mm-filemap.c-warn-if-stale-pagecache-is-left-after-direct-write.patch
  patches.suse/mm-hugetlb-avoid-looping-to-the-same-hugepage-if-pages-and-vmas.patch
  patches.suse/mm-introduce-compound_nr.patch
  patches.suse/mm-introduce-page_shift.patch
  patches.suse/mm-introduce-page_size.patch
  patches.suse/mm-madvise.c-replace-with-page_size-in-madvise_inject_error.patch
  patches.suse/mm-memcg-clean-up-reclaim-iter-array.patch
  patches.suse/mm-memcg-make-memory.emin-the-baseline-for-utilisation-determination.patch
  patches.suse/mm-memcg-make-scan-aggression-always-exclude-protection.patch
  patches.suse/mm-memcg-proportional-memory.-low-min-reclaim.patch
  patches.suse/mm-memcontrol-remove-dead-code-from-memory_max_write.patch
  patches.suse/mm-memfd-fix-COW-issue-on-MAP_PRIVATE-and-F_SEAL_FUTURE_WRITE-mappings.patch
  patches.suse/mm-memory-failure.c-clean-up-around-tk-pre-allocation.patch
  patches.suse/mm-migrate.c-handle-freed-page-at-the-first-place.patch
  patches.suse/mm-mmap.c-__vma_unlink_prev-is-not-necessary-now.patch
  patches.suse/mm-mmap.c-extract-__vma_unlink_list-as-counterpart-for-__vma_link_list.patch
  patches.suse/mm-mmap.c-prev-could-be-retrieved-from-vma-vm_prev.patch
  patches.suse/mm-mmap.c-rb_parent-is-not-necessary-in-__vma_link_list.patch
  patches.suse/mm-mmap.c-remove-a-never-triggered-warning-in-__vma_adjust.patch
  patches.suse/mm-mmap.c-use-IS_ERR_VALUE-to-check-return-value-of-get_unmapped_area.patch
  patches.suse/mm-page_io.c-annotate-refault-stalls-from-swap_readpage.patch
  patches.suse/mm-rmap.c-don-t-reuse-anon_vma-if-we-just-want-a-copy.patch
  patches.suse/mm-rmap.c-fix-outdated-comment-in-page_get_anon_vma.patch
  patches.suse/mm-rmap.c-reuse-mergeable-anon_vma-as-parent-when-fork.patch
  patches.suse/mm-rmap.c-use-VM_BUG_ON_PAGE-in-__page_check_anon_rmap.patch
  patches.suse/mm-shmem-use-proper-gfp-flags-for-shmem_writepage.patch
  patches.suse/mm-slab-make-kmalloc_info-contain-all-types-of-names.patch
  patches.suse/mm-slab-remove-unused-kmalloc_size.patch
  patches.suse/mm-slab_common-use-enum-kmalloc_cache_type-to-iterate-over-kmalloc-caches.patch
  patches.suse/mm-slub-print-the-offset-of-fault-addresses.patch
  patches.suse/mm-slub.c-clean-up-validate_slab.patch
  patches.suse/mm-slub.c-update-comments.patch
  patches.suse/mm-soft-offline-convert-parameter-to-pfn.patch
  patches.suse/mm-swap.c-piggyback-lru_add_drain_all-calls.patch
  patches.suse/mm-swap.c-trivial-mark_page_accessed-cleanup.patch
  patches.suse/mm-thp-do-not-queue-fully-unmapped-pages-for-deferred-split.patch
  patches.suse/mm-vmalloc-add-more-comments-to-the-adjust_va_to_fit_type.patch
  patches.suse/mm-vmalloc-do-not-keep-unpurged-areas-in-the-busy-tree.patch
  patches.suse/mm-vmalloc-modify-struct-vmap_area-to-reduce-its-size.patch
  patches.suse/mm-vmalloc-remove-preempt_disable-enable-when-doing-preloading.patch
  patches.suse/mm-vmalloc-respect-passed-gfp_mask-when-doing-preloading.patch
  patches.suse/mm-vmalloc-rework-vmap_area_lock.patch
  patches.suse/mm-vmalloc.c-move-area-pages-after-if-statement.patch
  patches.suse/mm-vmalloc.c-remove-unnecessary-highmem_mask-from-parameter-of-gfpflags_allow_blocking.patch
  patches.suse/mm-vmscan-detect-file-thrashing-at-the-reclaim-root.patch
  patches.suse/mm-vmscan-enforce-inactive-active-ratio-at-the-reclaim-root.patch
  patches.suse/mm-vmscan-harmonize-writeback-congestion-tracking-for-nodes-memcgs.patch
  patches.suse/mm-vmscan-memcontrol-remove-mem_cgroup_select_victim_node.patch
  patches.suse/mm-vmscan-move-file-exhaustion-detection-to-the-node-level.patch
  patches.suse/mm-vmscan-move-inactive_list_is_low-swap-check-to-the-caller.patch
  patches.suse/mm-vmscan-naming-fixes-global_reclaim-and-sane_reclaim.patch
  patches.suse/mm-vmscan-remove-unused-lru_pages-argument.patch
  patches.suse/mm-vmscan-replace-shrink_node-loop-with-a-retry-jump.patch
  patches.suse/mm-vmscan-simplify-lruvec_lru_size.patch
  patches.suse/mm-vmscan-split-shrink_node-into-node-part-and-memcgs-part.patch
  patches.suse/mm-vmscan-turn-shrink_node_memcg-into-shrink_lruvec.patch
  patches.suse/mm-vmscan.c-fix-typo-in-comment.patch
  patches.suse/mm-vmscan.c-remove-unused-scan_control-parameter-from-pageout.patch
  patches.suse/rss_stat-add-support-to-detect-RSS-updates-of-external-mm.patch
  patches.suse/shmem-pin-the-file-in-shmem_fault-if-mmap_sem-is-dropped.patch
  patches.suse/vmalloc-lift-the-arm-flag-for-coherent-mappings-to-common-code.patch
- commit fdd2a26
* Mon Dec  9 2019 bp@suse.de
- EDAC/ghes: Do not warn when incrementing refcount on 0
  (bsc#1152489).
- commit b152db6
* Mon Dec  9 2019 tiwai@suse.de
- Update patch reference for a media driver fix (CVE-2019-19533 bsc#1158834)
- commit 035b8ec
* Mon Dec  9 2019 tiwai@suse.de
- Update patch references for USB and HID fixes (CVE-2019-19532 bsc#1158824 CVE-2019-19523)
- commit b7c3995
* Mon Dec  9 2019 mbenes@suse.cz
- xprtrdma: Add unique trace points for posting Local Invalidate
  WRs (bsc#1158811).
- commit 0045bd6
* Mon Dec  9 2019 lhenriques@suse.com
- rbd: silence bogus uninitialized warning in
  rbd_object_map_update_finish() (jsc#SES-1134).
- ceph: increment/decrement dio counter on async requests
  (jsc#SES-1134).
- ceph: take the inode lock before acquiring cap refs
  (jsc#SES-1134).
- rbd: cancel lock_dwork if the wait is interrupted
  (jsc#SES-1134).
- ceph: call ceph_mdsc_destroy from destroy_fs_client
  (jsc#SES-1134).
- libceph: use ceph_kvmalloc() for osdmap arrays (jsc#SES-1134).
- libceph: avoid a __vmalloc() deadlock in ceph_kvmalloc()
  (jsc#SES-1134).
- commit 6eea6f4
* Mon Dec  9 2019 lhenriques@suse.com
- ceph: allow object copies across different filesystems in the
  same cluster (jsc#SES-1134).
- Refresh
  patches.suse/ceph-don-t-allow-copy_file_range-when-stripe_count-1.patch.
- commit 8a618ea
* Mon Dec  9 2019 lhenriques@suse.com
- ceph: include ceph_debug.h in cache.c (jsc#SES-1134).
- ceph: move static keyword to the front of declarations
  (jsc#SES-1134).
- rbd: pull rbd_img_request_create() dout out into the callers
  (jsc#SES-1134).
- libceph: drop unused con parameter of calc_target()
  (jsc#SES-1134).
- ceph: use release_pages() directly (jsc#SES-1134).
- rbd: fix response length parameter for encoded strings
  (jsc#SES-1134).
- ceph: allow arbitrary security.* xattrs (jsc#SES-1134).
- ceph: only set CEPH_I_SEC_INITED if we got a MAC label
  (jsc#SES-1134).
- ceph: turn ceph_security_invalidate_secctx into static inline
  (jsc#SES-1134).
- ceph: add buffered/direct exclusionary locking for reads and
  writes (jsc#SES-1134).
- libceph: handle OSD op ceph_pagelist_append() errors
  (jsc#SES-1134).
- ceph: don't return a value from void function (jsc#SES-1134).
- ceph: don't freeze during write page faults (jsc#SES-1134).
- ceph: update the mtime when truncating up (jsc#SES-1134).
- ceph: fix indentation in __get_snap_name() (jsc#SES-1134).
- ceph: remove incorrect comment above __send_cap (jsc#SES-1134).
- ceph: remove CEPH_I_NOFLUSH (jsc#SES-1134).
- ceph: remove unneeded test in try_flush_caps (jsc#SES-1134).
- ceph: have __mark_caps_flushing return flush_tid (jsc#SES-1134).
- ceph: fix comments over ceph_add_cap (jsc#SES-1134).
- ceph: eliminate session->s_trim_caps (jsc#SES-1134).
- ceph: remove ceph_get_cap_mds and __ceph_get_cap_mds
  (jsc#SES-1134).
- ceph: don't SetPageError on writepage errors (jsc#SES-1134).
- commit 3a5a01d
* Mon Dec  9 2019 lhenriques@suse.com
- ceph: auto reconnect after blacklisted (jsc#SES-1134).
- Refresh
  patches.suse/ceph-return-EINVAL-if-given-fsc-mount-option-on-kern.patch.
- commit a6819c7
* Mon Dec  9 2019 lhenriques@suse.com
- ceph: invalidate all write mode filp after reconnect
  (jsc#SES-1134).
- ceph: return -EIO if read/write against filp that lost file
  locks (jsc#SES-1134).
- ceph: add helper function that forcibly reconnects to ceph
  cluster (jsc#SES-1134).
- ceph: pass filp to ceph_get_caps() (jsc#SES-1134).
- ceph: track and report error of async metadata operation
  (jsc#SES-1134).
- ceph: allow closing session in restarting/reconnect state
  (jsc#SES-1134).
- libceph: add function that clears osd client's abort_err
  (jsc#SES-1134).
- libceph: add function that reset client's entity addr
  (jsc#SES-1134).
- ceph: don't list vxattrs in listxattr() (jsc#SES-1134).
- ceph: allow copy_file_range when src and dst inode are same
  (jsc#SES-1134).
- commit d6afa0a
* Mon Dec  9 2019 bp@suse.de
- EDAC/ghes: Fix locking and memory barrier issues (bsc#1152489).
- commit 7d2325a
* Mon Dec  9 2019 lhenriques@suse.com
- kabi/severities: whitelist libceph, rbd, and ceph (jsc#SES-1134).
- commit 1f1a9d5
* Mon Dec  9 2019 jeyu@suse.de
- kernel/module.c: wakeup processes in module_wq on module unload (git-fixes).
- commit 311cb05
* Mon Dec  9 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Preload LUTs if the hw isn't currently using them'
- commit 7964f08
* Sun Dec  8 2019 tiwai@suse.de
- ALSA: pcm: oss: Avoid potential buffer overflows (git-fixes).
- ALSA: hda: hdmi - Keep old slot assignment behavior for Intel
  platforms (git-fixes).
- ALSA: hda: Modify stream stripe mask only when needed
  (git-fixes).
- ALSA: hda - fixup for the bass speaker on Lenovo Carbon X1
  7th gen (git-fixes).
- ALSA: hda: hdmi - preserve non-MST PCM routing for Intel
  platforms (git-fixes).
- ALSA: hda: hdmi - fix kernel oops caused by invalid PCM idx
  (git-fixes).
- ALSA: hda/realtek - Fix inverted bass GPIO pin on Acer 8951G
  (git-fixes).
- ALSA: hda/realtek - Dell headphone has noise on unmute for
  ALC236 (git-fixes).
- ALSA: hda: hdmi - fix regression in connect list handling
  (git-fixes).
- ALSA: hda/hdmi - enable automatic runtime pm for AMD HDMI
  codecs by default (git-fixes).
- ALSA: hda/hdmi - enable runtime pm for newer AMD display audio
  (git-fixes).
- ALSA: hda/hdmi - Add new pci ids for AMD GPU display audio
  (git-fixes).
- ALSA: hda/hdmi - fix vgaswitcheroo detection for AMD
  (git-fixes).
- commit 4b98432
* Fri Dec  6 2019 jslaby@suse.cz
- Linux 5.3.15 (bnc#1151927 5.3.15).
- openvswitch: remove another BUG_ON() (bnc#1151927 5.3.15).
- openvswitch: drop unneeded BUG_ON() in ovs_flow_cmd_build_info()
  (bnc#1151927 5.3.15).
- net: sched: fix `tc -s class show` no bstats on class with
  nolock subqueues (bnc#1151927 5.3.15).
- selftests: pmtu: use -oneline for ip route list cache
  (bnc#1151927 5.3.15).
- net: macb: add missed tasklet_kill (bnc#1151927 5.3.15).
- selftests: bpf: correct perror strings (bnc#1151927 5.3.15).
- selftests: bpf: test_sockmap: handle file creation failures
  gracefully (bnc#1151927 5.3.15).
- net/tls: use sg_next() to walk sg entries (bnc#1151927 5.3.15).
- net/tls: remove the dead inplace_crypto code (bnc#1151927
  5.3.15).
- selftests/tls: add a test for fragmented messages (bnc#1151927
  5.3.15).
- net: skmsg: fix TLS 1.3 crash with full sk_msg (bnc#1151927
  5.3.15).
- net/tls: free the record on encryption error (bnc#1151927
  5.3.15).
- net/tls: take into account that bpf_exec_tx_verdict() may free
  the record (bnc#1151927 5.3.15).
- x86/fpu: Don't cache access to fpu_fpregs_owner_ctx (bnc#1151927
  5.3.15).
- platform/x86: hp-wmi: Fix ACPI errors caused by passing 0 as
  input size (bnc#1151927 5.3.15).
- platform/x86: hp-wmi: Fix ACPI errors caused by too small buffer
  (bnc#1151927 5.3.15).
- HID: core: check whether Usage Page item is after Usage ID items
  (bnc#1151927 5.3.15).
- ext4: add more paranoia checking in ext4_expand_extra_isize
  handling (bnc#1151927 5.3.15).
- net: disallow ancillary data for __sys_{send,recv}msg_file()
  (bnc#1151927 5.3.15).
- net: separate out the msghdr copy from ___sys_{send,recv}msg()
  (bnc#1151927 5.3.15).
- io_uring: async workers should inherit the user creds
  (bnc#1151927 5.3.15).
- gve: Fix the queue page list allocated pages count (bnc#1151927
  5.3.15).
- openvswitch: fix flow command message size (bnc#1151927 5.3.15).
- net: psample: fix skb_over_panic (bnc#1151927 5.3.15).
- tipc: fix link name length check (bnc#1151927 5.3.15).
- staging: rtl8723bs: Drop ACPI device ids (bnc#1151927 5.3.15).
- staging: rtl8723bs: Add 024c:0525 to the list of SDIO device-ids
  (bnc#1151927 5.3.15).
- staging: wilc1000: fix illegal memory access in
  wilc_parse_join_bss_param() (bnc#1151927 5.3.15).
- staging: rtl8192e: fix potential use after free (bnc#1151927
  5.3.15).
- thunderbolt: Power cycle the router if NVM authentication fails
  (bnc#1151927 5.3.15).
- mei: me: add comet point V device id (bnc#1151927 5.3.15).
- mei: bus: prefix device names on bus with the bus name
  (bnc#1151927 5.3.15).
- usb: dwc2: use a longer core rest timeout in dwc2_core_reset()
  (bnc#1151927 5.3.15).
- USB: serial: ftdi_sio: add device IDs for U-Blox C099-F9P
  (bnc#1151927 5.3.15).
- net: dsa: sja1105: fix sja1105_parse_rgmii_delays() (bnc#1151927
  5.3.15).
- macvlan: schedule bc_work even if error (bnc#1151927 5.3.15).
- mdio_bus: don't use managed reset-controller (bnc#1151927
  5.3.15).
- sctp: cache netns in sctp_ep_common (bnc#1151927 5.3.15).
- sctp: Fix memory leak in sctp_sf_do_5_2_4_dupcook (bnc#1151927
  5.3.15).
- net: fec: fix clock count mis-match (bnc#1151927 5.3.15).
- xfrm: Fix memleak on xfrm state destroy (bnc#1151927 5.3.15).
- ARM: dts: stm32: Fix CAN RAM mapping on stm32mp157c (bnc#1151927
  5.3.15).
- arm64: dts: zii-ultra: fix ARM regulator GPIO handle
  (bnc#1151927 5.3.15).
- ARM: dts: sun8i-a83t-tbs-a711: Fix WiFi resume from suspend
  (bnc#1151927 5.3.15).
- arm64: dts: imx8mm: fix compatible string for sdma (bnc#1151927
  5.3.15).
- ARM: dts: imx6qdl-sabreauto: Fix storm of accelerometer
  interrupts (bnc#1151927 5.3.15).
- arm64: dts: ls1028a: fix a compatible issue (bnc#1151927
  5.3.15).
- reset: fix reset_control_ops kerneldoc comment (bnc#1151927
  5.3.15).
- soundwire: intel: fix intel_register_dai PDI offsets and numbers
  (bnc#1151927 5.3.15).
- thunderbolt: Read DP IN adapter first two dwords in one go
  (bnc#1151927 5.3.15).
- x86/tsc: Respect tsc command line paraemeter for
  clocksource_tsc_early (bnc#1151927 5.3.15).
- perf scripting engines: Iterate on tep event arrays directly
  (bnc#1151927 5.3.15).
- watchdog: pm8916_wdt: fix pretimeout registration flow
  (bnc#1151927 5.3.15).
- mac80211: fix station inactive_time shortly after boot
  (bnc#1151927 5.3.15).
- net/fq_impl: Switch to kvmalloc() for memory allocation
  (bnc#1151927 5.3.15).
- net: stmmac: xgmac: Disable Flow Control when 1 or more queues
  are in AV (bnc#1151927 5.3.15).
- net: stmmac: xgmac: Fix TSA selection (bnc#1151927 5.3.15).
- net: stmmac: xgmac: bitrev32 returns u32 (bnc#1151927 5.3.15).
- net: stmmac: gmac4: bitrev32 returns u32 (bnc#1151927 5.3.15).
- netfilter: ipset: Fix nla_policies to fully support
  NL_VALIDATE_STRICT (bnc#1151927 5.3.15).
- netfilter: nf_tables_offload: skip EBUSY on chain update
  (bnc#1151927 5.3.15).
- netfilter: nf_tables: bogus EOPNOTSUPP on basechain update
  (bnc#1151927 5.3.15).
- net: mscc: ocelot: fix __ocelot_rmw_ix prototype (bnc#1151927
  5.3.15).
- samples/bpf: fix build by setting HAVE_ATTR_TEST to zero
  (bnc#1151927 5.3.15).
- can: mcp251x: mcp251x_restart_work_handler(): Fix potential
  force_quit race condition (bnc#1151927 5.3.15).
- can: flexcan: increase error counters if skb enqueueing via
  can_rx_offload_queue_sorted() fails (bnc#1151927 5.3.15).
- can: rx-offload: can_rx_offload_irq_offload_fifo(): continue
  on error (bnc#1151927 5.3.15).
- can: rx-offload: can_rx_offload_irq_offload_timestamp():
  continue on error (bnc#1151927 5.3.15).
- can: rx-offload: can_rx_offload_offload_one(): use ERR_PTR()
  to propagate error value in case of errors (bnc#1151927 5.3.15).
- can: rx-offload: can_rx_offload_offload_one(): increment
  rx_fifo_errors on queue overflow or OOM (bnc#1151927 5.3.15).
- can: c_can: D_CAN: c_can_chip_config(): perform a sofware
  reset on open (bnc#1151927 5.3.15).
- can: peak_usb: report bus recovery as well (bnc#1151927 5.3.15).
- net: fec: add missed clk_disable_unprepare in remove
  (bnc#1151927 5.3.15).
- block: drbd: remove a stray unlock in __drbd_send_protocol()
  (bnc#1151927 5.3.15).
- nvme-multipath: fix crash in nvme_mpath_clear_ctrl_paths
  (bnc#1151927 5.3.15).
- nvme-rdma: fix a segmentation fault during module unload
  (bnc#1151927 5.3.15).
- ceph: return -EINVAL if given fsc mount option on kernel w/o
  support (bnc#1151927 5.3.15).
- idr: Fix idr_alloc_u32 on 32-bit systems (bnc#1151927 5.3.15).
- idr: Fix integer overflow in idr_for_each_entry (bnc#1151927
  5.3.15).
- XArray: Fix xas_next() with a single entry at 0 (bnc#1151927
  5.3.15).
- ASoC: stm32: sai: add restriction on mmap support (bnc#1151927
  5.3.15).
- ASoC: hdac_hda: fix race in device removal (bnc#1151927 5.3.15).
- ASoC: rockchip: rockchip_max98090: Enable SHDN to fix headset
  detection (bnc#1151927 5.3.15).
- ASoC: compress: fix unsigned integer overflow check (bnc#1151927
  5.3.15).
- drm/amdgpu: add warning for GRBM 1-cycle delay issue in gfx9
  (bnc#1151927 5.3.15).
- drm/amd/swSMU: fix smu workload bit map error (bnc#1151927
  5.3.15).
- drm/amdgpu: dont schedule jobs while in reset (bnc#1151927
  5.3.15).
- clk: ti: dra7-atl-clock: Remove ti_clk_add_alias call
  (bnc#1151927 5.3.15).
- clk: meson: gxbb: let sar_adc_clk_div set the parent clock rate
  (bnc#1151927 5.3.15).
- scripts/gdb: fix debugging modules compiled with hot/cold
  partitioning (bnc#1151927 5.3.15).
- mm/gup_benchmark: fix MAP_HUGETLB case (bnc#1151927 5.3.15).
- commit de8adb7
* Fri Dec  6 2019 jslaby@suse.cz
- Update patches.suse/ALSA-hda-hdmi-add-Tigerlake-support.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/ASoC-SOF-ipc-Fix-memory-leak-in-sof_set_get_large_ct.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/ASoC-SOF-topology-Fix-bytes-control-size-checks.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/ASoC-kirkwood-fix-device-remove-ordering.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/ASoC-kirkwood-fix-external-clock-probe-defer.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/ASoC-msm8916-wcd-analog-Fix-RX1-selection-in-RDAC2-M.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/ASoC-ti-sdma-pcm-Add-back-the-flags-parameter-for-no.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/bpf-Allow-narrow-loads-of-bpf_sysctl-fields-with-off.patch
  (bsc#1155518 bnc#1151927 5.3.15).
- Update
  patches.suse/bpf-Change-size-to-u64-for-bpf_map_-area_alloc-charg.patch
  (bsc#1155518 bnc#1151927 5.3.15).
- Update
  patches.suse/bridge-ebtables-don-t-crash-when-using-dnat-target-i.patch
  (bsc#1154353 bnc#1151927 5.3.15).
- Update
  patches.suse/can-rx-offload-can_rx_offload_offload_one-do-not-inc.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/can-rx-offload-can_rx_offload_queue_tail-fix-error-h.patch
  (git-fixes bnc#1151927 5.3.15).
- Update patches.suse/clk-at91-avoid-sleeping-early.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-at91-fix-update-bit-maps-on-CFG_MOR-write.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-at91-sam9x60-fix-programmable-clock.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-samsung-exynos5420-Preserve-PLL-configuration-du.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-samsung-exynos542x-Move-G3D-subsystem-clocks-to-.patch
  (git-fixes bnc#1151927 5.3.15).
- Update patches.suse/clk-samsung-exynos5433-Fix-error-paths.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-sunxi-Fix-operator-precedence-in-sunxi_divs_clk_.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-sunxi-ng-a80-fix-the-zero-ing-of-bits-16-and-18.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-ti-clkctrl-Fix-failed-to-enable-error-with-doubl.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clocksource-drivers-mediatek-Fix-error-handling.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/drm-amdgpu-register-gpu-instance-before-fan-boost-fe.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/fbdev-c2p-Fix-link-failure-on-non-inlining.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/i40e-Fix-for-ethtool-m-issue-on-X722-NIC.patch
  (jsc#SLE-8025 bnc#1151927 5.3.15).
- Update
  patches.suse/iavf-initialize-ITRN-registers-with-correct-values.patch
  (jsc#SLE-7940 bnc#1151927 5.3.15).
- Update
  patches.suse/ice-fix-potential-infinite-loop-because-loop-counter.patch
  (jsc#SLE-7926 bnc#1151927 5.3.15).
- Update
  patches.suse/idr-Fix-idr_get_next_ul-race-with-idr_remove.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/mac80211-fix-ieee80211_txq_setup_flows-failure-path.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/net-bcmgenet-reapply-manual-settings-to-the-PHY.patch
  (jsc#SLE-7772 bnc#1151927 5.3.15).
- Update
  patches.suse/net-bcmgenet-use-RGMII-loopback-for-MAC-reset.patch
  (jsc#SLE-7772 bnc#1151927 5.3.15).
- Update
  patches.suse/net-mlx5e-Fix-eswitch-debug-print-of-max-fdb-flow.patch
  (jsc#SLE-8464 bnc#1151927 5.3.15).
- Update
  patches.suse/net-mlx5e-Use-correct-enum-to-determine-uplink-port.patch
  (jsc#SLE-8464 bnc#1151927 5.3.15).
- Update
  patches.suse/pinctrl-cherryview-Allocate-IRQ-chip-dynamic.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/powerpc-bpf-Fix-tail-call-implementation.patch
  (bsc#1157698 bnc#1151927 5.3.15).
- Update
  patches.suse/pwm-bcm-iproc-Prevent-unloading-the-driver-module-wh.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/reset-Fix-memory-leak-in-reset_control_array_put.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/slip-Fix-use-after-free-Read-in-slip_open.patch
  (git-fixes bnc#1151927 5.3.15).
- Update patches.suse/soc-imx-gpc-fix-initialiser-format.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/stacktrace-Don-t-skip-first-entry-on-noncurrent-task.patch
  (bnc#1154866 bnc#1151927 5.3.15).
- Update
  patches.suse/thunderbolt-Fix-lockdep-circular-locking-depedency-w.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/watchdog-bd70528-Add-MODULE_ALIAS-to-allow-module-au.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/watchdog-imx_sc_wdt-Pretimeout-should-follow-SCU-fir.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/watchdog-meson-Fix-the-wrong-value-of-left-time.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/x86-resctrl-prevent-null-pointer-dereference-when-reading-mondata.patch
  (bsc#1152489 bnc#1151927 5.3.15).
- commit ac8515c
* Fri Dec  6 2019 jlee@suse.com
- Refresh and enable
  patches.suse/0001-MODSIGN-do-not-load-mok-when-secure-boot-disabled.patch.
  (fate#316531)
- commit 44cbe3a
* Thu Dec  5 2019 nsaenzjulienne@suse.de
- supported.conf: Support Broadcom's Genet Ethernet driver (bsc#158563)
- commit 9ba4eec
* Thu Dec  5 2019 ykaukab@suse.de
- net: thunderx: start phy before starting autonegotiation
  (bsc#1158107).
- commit 7049617
* Thu Dec  5 2019 mbenes@suse.cz
- s390/livepatch: Implement reliable stack tracing for the
  consistency model (jsc#SLE-11050).
- Update config files.
- commit 069014a
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: add stack pointer alignment sanity checks
  (jsc#SLE-11050).
- commit 1bb4634
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: filter out unreliable bogus %%r14 (jsc#SLE-11050).
- commit 2756f26
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: start unwinding from reliable state
  (jsc#SLE-11050).
- commit f610667
* Thu Dec  5 2019 mbenes@suse.cz
- s390/test_unwind: print verbose unwinding results
  (jsc#SLE-11050).
- commit 0357290
* Thu Dec  5 2019 mbenes@suse.cz
- s390: fix register clobbering in CALL_ON_STACK (jsc#SLE-11050).
- commit 0d20bdc
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: always inline get_stack_pointer (jsc#SLE-11050).
- commit b82cd7f
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: stop gracefully at task pt_regs (jsc#SLE-11050).
- commit 02b1171
* Thu Dec  5 2019 mbenes@suse.cz
- s390/head64: correct init_task stack setup (jsc#SLE-11050).
- commit bb6645d
* Thu Dec  5 2019 jack@suse.cz
- blacklist.conf: Add 9163e0184bd7 and 91cbf01178c3
- commit 7e1a7fc
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: make reuse_sp default when unwinding pt_regs
  (jsc#SLE-11050).
- commit d6b50c9
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: report an error if pt_regs are not on stack
  (jsc#SLE-11050).
- commit 13143f4
* Thu Dec  5 2019 mbenes@suse.cz
- s390: avoid misusing CALL_ON_STACK for task stack setup
  (jsc#SLE-11050).
- commit 49822da
* Thu Dec  5 2019 mbenes@suse.cz
- s390: correct CALL_ON_STACK back_chain saving (jsc#SLE-11050).
- commit d1292ec
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: unify task is current checks (jsc#SLE-11050).
- commit f37218c
* Thu Dec  5 2019 mbenes@suse.cz
- s390: disable preemption when switching to nodat stack with
  CALL_ON_STACK (jsc#SLE-11050).
- commit 2b3e23a
* Thu Dec  5 2019 mbenes@suse.cz
- s390: always inline disabled_wait (jsc#SLE-11050).
- commit e18f4f8
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: drop unnecessary code around calling
  ftrace_graph_ret_addr() (jsc#SLE-11050).
- commit f07dfe2
* Thu Dec  5 2019 mbenes@suse.cz
- s390: always inline current_stack_pointer() (jsc#SLE-11050).
- commit b8e1cdf
* Thu Dec  5 2019 mbenes@suse.cz
- s390/process: avoid custom stack unwinding in get_wchan
  (jsc#SLE-11050).
- commit 83d7f05
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: fix get_stack_pointer(NULL, NULL) (jsc#SLE-11050).
- commit cf38773
* Thu Dec  5 2019 mbenes@suse.cz
- s390/stacktrace: use common arch_stack_walk infrastructure
  (jsc#SLE-11050).
- Update config files.
- commit c353280
* Wed Dec  4 2019 jack@suse.cz
- xfs: Sanity check flags of Q_XQUOTARM call (bsc#1158460).
- commit 57267ac
* Wed Dec  4 2019 jack@suse.cz
- fix compat handling of FICLONERANGE, FIDEDUPERANGE and
  FS_IOC_FIEMAP (bsc#1158459).
- commit d29bae9
* Wed Dec  4 2019 jack@suse.cz
- gfs2: add compat_ioctl support (bsc#1158458).
- commit fa0941a
* Wed Dec  4 2019 jack@suse.cz
- ocfs2: fix passing zero to 'PTR_ERR' warning (bsc#1158457).
- commit b1e2fe5
* Wed Dec  4 2019 jack@suse.cz
- splice: only read in as much information as there is pipe
  buffer space (bsc#1158456).
- commit 0d75db3
* Wed Dec  4 2019 jack@suse.cz
- ext4: update direct I/O read lock pattern for IOCB_NOWAIT
  (bsc#1158454).
- iomap: fix return value of iomap_dio_bio_actor on 32bit systems
  (bsc#1158455).
- loop: fix no-unmap write-zeroes request behavior (bsc#1158389).
- commit c9b89d4
* Wed Dec  4 2019 nsaenzjulienne@suse.de
- supported.conf: support gpio-regulator used by Raspberry Pi 4
  (bsc#1158451)
- commit 83d8e7e
* Wed Dec  4 2019 bp@suse.de
- EDAC/amd64: Set grain per DIMM (bsc#1152489).
- commit f4d7468
* Wed Dec  4 2019 mbenes@suse.cz
- ftrace: Introduce PERMANENT ftrace_ops flag (bsc#1120853).
- commit c038bf4
* Wed Dec  4 2019 tiwai@suse.de
- Update patch reference for ieee802154 fix (CVE-2019-19525 bsc#1158417)
- commit 0ca3a8c
* Wed Dec  4 2019 tiwai@suse.de
- Update patch references for input and USB fixes (CVE-2019-19524 bsc#1158413 CVE-2019-19528 bsc#1158407 CVE-2019-19534 bsc#1158398)
- commit 61129d2
* Wed Dec  4 2019 mgorman@suse.de
- mm/page_io.c: annotate refault stalls from swap_readpage
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: shmem: use proper gfp flags for shmem_writepage()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/madvise.c: replace with page_size() in madvise_inject_error()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, thp: do not queue fully unmapped pages for deferred split
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/migrate.c: handle freed page at the first place (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/hugetlb: avoid looping to the same hugepage if !pages
  and !vmas (bnc#1155780 (VM/FS functional and performance
  backports)).
- hugetlb: remove duplicated code (bnc#1155780 (VM/FS functional
  and performance backports)).
- hugetlb: region_chg provides only cache entry (bnc#1155780
  (VM/FS functional and performance backports)).
- hugetlbfs: take read_lock on i_mmap for PMD sharing (bnc#1155780
  (VM/FS functional and performance backports)).
- hugetlbfs: hugetlb_fault_mutex_hash() cleanup (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/vmscan.c: fix typo in comment (bnc#1155780 (VM/FS functional
  and performance backports)).
- mm: vmscan: enforce inactive:active ratio at the reclaim root
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: detect file thrashing at the reclaim root
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: move file exhaustion detection to the node level
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: harmonize writeback congestion tracking for
  nodes & memcgs (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm: vmscan: split shrink_node() into node part and memcgs part
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: turn shrink_node_memcg() into shrink_lruvec()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: replace shrink_node() loop with a retry jump
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: naming fixes: global_reclaim() and sane_reclaim()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: move inactive_list_is_low() swap check to the caller
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: clean up and clarify lruvec lookup procedure (bnc#1155780
  (VM/FS functional and performance backports)).
- mm: vmscan: simplify lruvec_lru_size() (bnc#1155780 (VM/FS
  functional and performance backports)).
- mm/vmscan.c: remove unused scan_control parameter from pageout()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/vmscan: remove unused lru_pages argument (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/vmalloc: rework vmap_area_lock (bnc#1155780 (VM/FS functional
  and performance backports)).
- mm/vmalloc: add more comments to the adjust_va_to_fit_type()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/vmalloc: respect passed gfp_mask when doing preloading
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/vmalloc: remove preempt_disable/enable when doing preloading
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/vmalloc.c: remove unnecessary highmem_mask from parameter
  of gfpflags_allow_blocking() (bnc#1155780 (VM/FS functional
  and performance backports)).
- mm, soft-offline: convert parameter to pfn (bnc#1155780 (VM/FS
  functional and performance backports)).
- mm/memory-failure.c clean up around tk pre-allocation
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, memfd: fix COW issue on MAP_PRIVATE and F_SEAL_FUTURE_WRITE
  mappings (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm/rmap.c: use VM_BUG_ON_PAGE() in __page_check_anon_rmap()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/rmap.c: fix outdated comment in page_get_anon_vma()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/mmap.c: use IS_ERR_VALUE to check return value
  of get_unmapped_area (bnc#1155780 (VM/FS functional and
  performance backports)).
- mm/rmap.c: reuse mergeable anon_vma as parent when fork
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/rmap.c: don't reuse anon_vma if we just want a copy
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/mmap.c: rb_parent is not necessary in __vma_link_list()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/mmap.c: extract __vma_unlink_list() as counterpart for
  __vma_link_list() (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm/mmap.c: __vma_unlink_prev() is not necessary now (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/mmap.c: prev could be retrieved from vma->vm_prev
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/swap.c: piggyback lru_add_drain_all() calls (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/mmap.c: remove a never-triggered warning in __vma_adjust()
  (bnc#1155780 (VM/FS functional and performance backports)).
- rss_stat: add support to detect RSS updates of external mm
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: emit tracepoint when RSS changes (bnc#1155780 (VM/FS
  functional and performance backports)).
- shmem: pin the file in shmem_fault() if mmap_sem is dropped
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: drop mmap_sem before calling balance_dirty_pages() in
  write fault (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm: vmscan: memcontrol: remove mem_cgroup_select_victim_node()
  (bnc#1155780 (VM/FS functional and performance backports)).
- include/linux/memcontrol.h: fix comments based on per-node memcg
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: memcontrol: remove dead code from memory_max_write()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, memcg: clean up reclaim iter array (bnc#1155780 (VM/FS
  functional and performance backports)).
- mm/swap.c: trivial mark_page_accessed() cleanup (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/filemap.c: warn if stale pagecache is left after direct write
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/filemap.c: remove redundant cache invalidation after async
  direct-io write (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm/slub.c: clean up validate_slab() (bnc#1155780 (VM/FS
  functional and performance backports)).
- mm/slub.c: update comments (bnc#1155780 (VM/FS functional and
  performance backports)).
- mm: slub: print the offset of fault addresses (bnc#1155780
  (VM/FS functional and performance backports)).
- mm, slab_common: use enum kmalloc_cache_type to iterate over
  kmalloc caches (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm, slab: remove unused kmalloc_size() (bnc#1155780 (VM/FS
  functional and performance backports)).
- mm, slab: make kmalloc_info[] contain all types of names
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, memcg: make scan aggression always exclude protection
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, memcg: make memory.emin the baseline for utilisation
  determination (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm, memcg: proportional memory.{low,min} reclaim (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/vmalloc.c: move 'area->pages' after if statement (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/vmalloc: modify struct vmap_area to reduce its size
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/vmalloc: do not keep unpurged areas in the busy tree
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: introduce compound_nr() (bnc#1155780 (VM/FS functional
  and performance backports)).
- mm: introduce page_shift() (bnc#1155780 (VM/FS functional and
  performance backports)).
- mm: introduce page_size() (bnc#1155780 (VM/FS functional and
  performance backports)).
- vmalloc: lift the arm flag for coherent mappings to common code
  (bnc#1155780 (VM/FS functional and performance backports)).
- commit d67e35b
* Wed Dec  4 2019 glin@suse.com
- bpf, testing: Convert prog tests to probe_read_{user, kernel}{,
  _str} helper (bsc#1155518).
- bpf, samples: Use bpf_probe_read_user where appropriate
  (bsc#1155518).
- commit e02b4fe
* Wed Dec  4 2019 tiwai@suse.de
- Update patch reference for USB can security fix (CVE-2019-19529 bsc#1158381)
- commit a96958b
* Wed Dec  4 2019 jack@suse.cz
- iomap: Fix pipe page leakage during splicing (bsc#1158383).
- commit b73f21b
* Wed Dec  4 2019 jack@suse.cz
- ext4: Fix credit estimate for final inode freeing (bsc#1158380).
- commit 99e5121
* Wed Dec  4 2019 jack@suse.cz
- ubifs: Fix memory leak in __ubifs_node_verify_hmac error path
  (bsc#1158378).
- commit 7babaf3
* Wed Dec  4 2019 jack@suse.cz
- ubifs: Fix memory leak in read_znode() error path (bsc#1158376).
- commit b3fc39e
* Wed Dec  4 2019 jack@suse.cz
- ecryptfs: fix unlink and rmdir in face of underlying fs
  modifications (bsc#1158374).
- commit 9fe5fae
* Wed Dec  4 2019 jack@suse.cz
- aio: Fix io_pgetevents() struct __compat_aio_sigset layout
  (bsc#1158373).
- commit 569924c
* Wed Dec  4 2019 glin@suse.com
- xdp: Fix cleanup on map free for devmap_hash map type
  (bsc#1155518).
- libbpf: Fix call relocation offset calculation bug
  (bsc#1155518).
- selftests, bpf: Fix test_tc_tunnel hanging (bsc#1155518).
- selftests, bpf: xdping is not meant to be run standalone
  (bsc#1155518).
- bpf: Fix race in btf_resolve_helper_id() (bsc#1155518).
- libbpf: Improve handling of corrupted ELF during map
  initialization (bsc#1155518).
- libbpf: Make btf__resolve_size logic always check size error
  condition (bsc#1155518).
- libbpf: Fix another potential overflow issue in bpf_prog_linfo
  (bsc#1155518).
- libbpf: Fix potential overflow issue (bsc#1155518).
- libbpf: Fix memory leak/double free issue (bsc#1155518).
- libbpf: Fix negative FD close() in xsk_setup_xdp_prog()
  (bsc#1155518).
- bpf: Account for insn->off when doing bpf_probe_read_kernel
  (bsc#1155518).
- bpf: Switch BPF probe insns to bpf_probe_read_kernel
  (bsc#1155518).
- bpf: Add probe_read_{user, kernel} and probe_read_{user,
  kernel}_str helpers (bsc#1155518).
- bpf: Make use of probe_user_write in probe write helper
  (bsc#1155518).
- uaccess: Add strict non-pagefault kernel-space read function
  (bsc#1155518).
- uaccess: Add non-pagefault user-space write function
  (bsc#1155518).
- bpf: Fix bpf jit kallsym access (bsc#1155518).
- libbpf: Don't use kernel-side u32 type in xsk.c (bsc#1155518).
- libbpf: Fix off-by-one error in ELF sanity check (bsc#1155518).
- libbpf: Fix compatibility for kernels without need_wakeup
  (bsc#1155518).
- libbpf: Fix strncat bounds error in libbpf_prog_type_by_name
  (bsc#1155518).
- bpf: Fix build error without CONFIG_NET (bsc#1155518).
- bpf: Fix bpf_attr.attach_btf_id check (bsc#1155518).
- selftests/bpf: Add kfree_skb raw_tp test (bsc#1155518).
- bpf: Check types of arguments passed into helpers (bsc#1155518).
- bpf: Add support for BTF pointers to x86 JIT (bsc#1155518).
- bpf: Add support for BTF pointers to interpreter (bsc#1155518).
- bpf: Attach raw_tp program with BTF via type name (bsc#1155518).
- bpf: Implement accurate raw_tp context access via BTF
  (bsc#1155518).
- libbpf: Auto-detect btf_id of BTF-based raw_tracepoints
  (bsc#1155518).
- bpf: Add attach_btf_id attribute to program load (bsc#1155518).
- bpf: Process in-kernel BTF (bsc#1155518).
- bpf: Add typecast to bpf helpers to help BTF generation
  (bsc#1155518).
- bpf: Add typecast to raw_tracepoints to help BTF generation
  (bsc#1155518).
- bpf/stackmap: Fix deadlock with rq_lock in bpf_get_stack()
  (bsc#1155518).
- libbpf: Fix passing uninitialized bytes to setsockopt
  (bsc#1155518).
- selftests/bpf: Fix btf_dump padding test case (bsc#1155518).
- selftests/bpf: test_progs: add missing \n to CHECK_FAIL
  (bsc#1155518).
- selftests/bpf: test_progs: fix verbose mode garbage
  (bsc#1155518).
- selftests/bpf: test_progs: remove unused ret (bsc#1155518).
- selftests/bpf: test_progs: remove asserts from subtests
  (bsc#1155518).
- selftests/bpf: test_progs: remove global fail/success counts
  (bsc#1155518).
- selftests/bpf: test_progs: test__skip (bsc#1155518).
- selftests/bpf: test_progs: drop extra trailing tab
  (bsc#1155518).
- selftests/bpf: test_progs: test__printf -> printf (bsc#1155518).
- selftests/bpf: test_progs: switch to open_memstream
  (bsc#1155518).
- commit b4301c5
* Wed Dec  4 2019 jack@suse.cz
- blacklist.conf: Add fs/f2fs to blacklist
  We don't care about F2FS as we don't even compile it.
- commit d73a3d9
* Wed Dec  4 2019 jack@suse.cz
- ext4: set error return correctly when ext4_htree_store_dirent
  fails (bsc#1158371).
- commit 7f15da5
* Wed Dec  4 2019 jslaby@suse.cz
- Revert "nvme: Add quirk for Kingston NVME SSD running FW
  E8FK11.T" (git-fixes).
- PCI/MSI: Fix incorrect MSI-X masking on resume (git-fixes).
- commit e6e544b
* Wed Dec  4 2019 jack@suse.cz
- block: check bi_size overflow before merge (bsc#1158370).
- commit b8ddf8c
* Wed Dec  4 2019 mkubecek@suse.cz
- series.conf: cleanup
  update mainline references, refresh and move into sorted section:
  patches.suse/mm-pcp-Share-common-code-between-memory-hotplug-and-percpu-sysctl-handler.patch
  patches.suse/mm-pcpu-Make-zone-pcp-updates-and-reset-internal-to-the-mm.patch
  patches.suse/autonuma-fix-watermark-checking-in-migrate_balanced_pgdat.patch
  patches.suse/autonuma-reduce-cache-footprint-when-scanning-page-tables.patch
  patches.suse/CIFS-Fix-SMB2-oplock-break-processing.patch
  patches.suse/cifs-move-cifsFileInfo_put-logic-into-a-work-queue.patch
- commit f9fc458
* Wed Dec  4 2019 mkubecek@suse.cz
- series.conf: refresh
  update mainline references and resort:
  patches.suse/pci-aardvark-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-altera-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-dwc-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-export-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-faraday-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-ftpci100-use-inbound-resources-for-setup.patch
  patches.suse/pci-iproc-use-inbound-resources-for-setup.patch
  patches.suse/pci-iproc-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-mediatek-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-mobiveil-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-of-add-inbound-resource-parsing-to-helpers.patch
  patches.suse/pci-rcar-use-inbound-resources-for-setup.patch
  patches.suse/pci-rockchip-drop-storing-driver-private-outbound-resource-data.patch
  patches.suse/pci-rockchip-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-v3-semi-use-inbound-resources-for-setup.patch
  patches.suse/pci-v3-semi-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-versatile-enable-compile_test.patch
  patches.suse/pci-versatile-remove-usage-of-phys_offset.patch
  patches.suse/pci-versatile-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-xgene-use-inbound-resources-for-setup.patch
  patches.suse/pci-xgene-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-xilinx-nwl-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-xilinx-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/resource-add-a-resource_list_first_type-helper.patch
- commit 14fed6d
* Tue Dec  3 2019 mkubecek@suse.cz
- fix mainline references
  fix Patch-mainline:
  patches.suse/powercap-intel_rapl-add-support-for-CometLake-Mobile
  patches.suse/powercap-intel_rapl-add-support-for-Cometlake-desktop
- commit 68d56a7
* Tue Dec  3 2019 trenn@suse.com
- powercap/intel_rapl: add support for Cometlake desktop
  (jsc#SLE-8184).
- powercap/intel_rapl: add support for CometLake Mobile
  (jsc#SLE-8184).
- commit f7448e7
* Tue Dec  3 2019 mkubecek@suse.cz
- config: refresh
  Only update headers.
- commit 908f91e
* Tue Dec  3 2019 msuchanek@suse.de
- powerpc/pseries: Enable support for ibm,drc-info property
  (bsc#1157480 ltc#181028).
- PCI: rpaphp: Correctly match ibm, my-drc-index to drc-name
  when using drc-info (bsc#1157480 ltc#181028).
- PCI: rpaphp: Annotate and correctly byte swap DRC properties
  (bsc#1157480 ltc#181028).
- PCI: rpaphp: Add drc-info support for hotplug slot registration
  (bsc#1157480 ltc#181028).
- PCI: rpaphp: Don't rely on firmware feature to imply drc-info
  support (bsc#1157480 ltc#181028).
- PCI: rpaphp: Fix up pointer to first drc-info entry (bsc#1157480
  ltc#181028).
- powerpc/pseries: Add cpu DLPAR support for drc-info property
  (bsc#1157480 ltc#181028).
- powerpc/pseries: Fix drc-info mappings of logical cpus to
  drc-index (bsc#1157480 ltc#181028).
- powerpc/pseries: Fix bad drc_index_start value parsing of
  drc-info entry (bsc#1157480 ltc#181028).
- commit 557da83
* Tue Dec  3 2019 mbrugger@suse.com
- arm64: Update config files. (jsc#SLE-9943 bsc#1158193)
  Bump CONFIG_NODES_SHIFT from 2 to 6
- commit 0cfadc1
* Tue Dec  3 2019 tiwai@suse.de
- rpm/kernel-subpackage-spec: Exclude kernel-firmware recommends (bsc#1143959)
  For reducing the dependency on kernel-firmware in sub packages
- commit d950271
* Tue Dec  3 2019 tiwai@suse.de
- mwifiex: Fix heap overflow in
  mmwifiex_process_tdls_action_frame()
  (CVE-2019-14901,bsc#1157042).
- commit 7889fe2
* Tue Dec  3 2019 nmoreychaisemartin@suse.com
- mlx5: add parameter to disable enhanced IPoIB (bsc#1142095)
- commit 4ea5d32
* Tue Dec  3 2019 mbenes@suse.cz
- livepatch: Selftests of the API for tracking system state
  changes (bsc#1071995 fate#323487).
- supported.conf:
- commit 4fff100
* Tue Dec  3 2019 mbenes@suse.cz
- livepatch: Allow to distinguish different version of system
  state changes (bsc#1071995 fate#323487).
- commit 1b157ca
* Tue Dec  3 2019 mbenes@suse.cz
- livepatch: Basic API to track system state changes (bsc#1071995
  fate#323487).
- Refresh
  patches.suse/livepatch-create-and-include-UAPI-headers.patch.
- commit d8150c3
* Tue Dec  3 2019 mbenes@suse.cz
- livepatch: Keep replaced patches until post_patch callback is
  called (bsc#1071995 fate#323487).
- commit 3c51995
* Tue Dec  3 2019 mbenes@suse.cz
- tracing/kprobe: Check whether the non-suffixed symbol is notrace
  (bsc#1158279).
- commit 8be1214
* Tue Dec  3 2019 jslaby@suse.cz
- Linux 5.3.14 (bnc#1151927 5.3.14).
- staging: comedi: usbduxfast: usbduxfast_ai_cmdtest rounding
  error (bnc#1151927 5.3.14).
- usb-serial: cp201x: support Mark-10 digital force gauge
  (bnc#1151927 5.3.14).
- USB: serial: option: add support for Foxconn T77W968 LTE modules
  (bnc#1151927 5.3.14).
- USB: serial: option: add support for DW5821e with eSIM support
  (bnc#1151927 5.3.14).
- USB: serial: mos7840: add USB ID to support Moxa UPort 2210
  (bnc#1151927 5.3.14).
- USBIP: add config dependency for SGL_ALLOC (bnc#1151927 5.3.14).
- USB: chaoskey: fix error case of a timeout (bnc#1151927 5.3.14).
- usbip: tools: fix fd leakage in the function of
  read_attr_usbip_status (bnc#1151927 5.3.14).
- appledisplay: fix error handling in the scheduled work
  (bnc#1151927 5.3.14).
- media: imon: invalid dereference in imon_touch_event
  (bnc#1151927 5.3.14).
- media: uvcvideo: Fix error path in control parsing failure
  (bnc#1151927 5.3.14).
- media: cxusb: detect cxusb_ctrl_msg error in query (bnc#1151927
  5.3.14).
- media: usbvision: Fix races among open, close, and disconnect
  (bnc#1151927 5.3.14).
- media: usbvision: Fix invalid accesses after device disconnect
  (bnc#1151927 5.3.14).
- media: mceusb: fix out of bounds read in MCE receiver buffer
  (bnc#1151927 5.3.14).
- media: vivid: Set vid_cap_streaming and vid_out_streaming to
  true (bnc#1151927 5.3.14).
- cpufreq: Add NULL checks to show() and store() methods of
  cpufreq (bnc#1151927 5.3.14).
- futex: Prevent robust futex exit race (bnc#1151927 5.3.14).
- x86/entry/32: Fix FIXUP_ESPFIX_STACK with user CR3 (bnc#1151927
  5.3.14).
- x86/pti/32: Calculate the various PTI cpu_entry_area sizes
  correctly, make the CPU_ENTRY_AREA_PAGES assert precise
  (bnc#1151927 5.3.14).
- selftests/x86/sigreturn/32: Invalidate DS and ES when abusing
  the kernel (bnc#1151927 5.3.14).
- selftests/x86/mov_ss_trap: Fix the SYSENTER test (bnc#1151927
  5.3.14).
- x86/entry/32: Fix NMI vs ESPFIX (bnc#1151927 5.3.14).
- x86/entry/32: Unwind the ESPFIX stack earlier on exception entry
  (bnc#1151927 5.3.14).
- x86/entry/32: Move FIXUP_FRAME after pushing %%fs in SAVE_ALL
  (bnc#1151927 5.3.14).
- x86/entry/32: Use %%ss segment where required (bnc#1151927
  5.3.14).
- x86/entry/32: Fix IRET exception (bnc#1151927 5.3.14).
- x86/cpu_entry_area: Add guard page for entry stack on 32bit
  (bnc#1151927 5.3.14).
- x86/pti/32: Size initial_page_table correctly (bnc#1151927
  5.3.14).
- x86/doublefault/32: Fix stack canaries in the double fault
  handler (bnc#1151927 5.3.14).
- x86/xen/32: Simplify ring check in xen_iret_crit_fixup()
  (bnc#1151927 5.3.14).
- x86/xen/32: Make xen_iret_crit_fixup() independent of frame
  layout (bnc#1151927 5.3.14).
- x86/stackframe/32: Repair 32-bit Xen PV (bnc#1151927 5.3.14).
- x86/speculation: Fix redundant MDS mitigation message
  (bnc#1151927 5.3.14).
- x86/speculation: Fix incorrect MDS/TAA mitigation status
  (bnc#1151927 5.3.14).
- x86/insn: Fix awk regexp warnings (bnc#1151927 5.3.14).
- Bluetooth: Fix invalid-free in bcsp_close() (bnc#1151927
  5.3.14).
- ath10k: restore QCA9880-AR1A (v1) detection (bnc#1151927
  5.3.14).
- ath9k_hw: fix uninitialized variable data (bnc#1151927 5.3.14).
- ath10k: Fix HOST capability QMI incompatibility (bnc#1151927
  5.3.14).
- Revert "dm crypt: use WQ_HIGHPRI for the IO and crypt
  workqueues" (bnc#1151927 5.3.14).
- nbd: prevent memory leak (bnc#1151927 5.3.14).
- md/raid10: prevent access of uninitialized resync_pages offset
  (bnc#1151927 5.3.14).
- net: rtnetlink: prevent underflows in do_setvfinfo()
  (bnc#1151927 5.3.14).
- nfc: port100: handle command failure cleanly (bnc#1151927
  5.3.14).
- net/ipv4: fix sysctl max for fib_multipath_hash_policy
  (bnc#1151927 5.3.14).
- drm/i915/pmu: "Frequency" is reported as accumulated cycles
  (bnc#1151927 5.3.14).
- drm/i915: Don't oops in dumb_create ioctl if we have no crtcs
  (bnc#1151927 5.3.14).
- drm/amdgpu: disable gfxoff on original raven (bnc#1151927
  5.3.14).
- drm/amdgpu: disable gfxoff when using register read interface
  (bnc#1151927 5.3.14).
- drm/amd/powerplay: issue no PPSMC_MSG_GetCurrPkgPwr on
  unsupported ASICs (bnc#1151927 5.3.14).
- tools: gpio: Correctly add make dependencies for gpio_utils
  (bnc#1151927 5.3.14).
- fork: fix pidfd_poll()'s return type (bnc#1151927 5.3.14).
- ARM: 8904/1: skip nomap memblocks while finding the
  lowmem/highmem boundary (bnc#1151927 5.3.14).
- vhost/vsock: split packets to send using multiple buffers
  (bnc#1151927 5.3.14).
- commit c30f7a5
* Tue Dec  3 2019 jslaby@suse.cz
- Update
  patches.suse/0001-Revert-Bluetooth-hci_ll-set-operational-frequency-ea.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/0001-USB-serial-mos7720-fix-remote-wakeup.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/0001-USB-serial-mos7840-fix-remote-wakeup.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/0001-b2c2-flexcop-usb-add-sanity-checking.patch
  (bsc#1146540 CVE-2019-15291 bnc#1151927 5.3.14).
- Update patches.suse/0001-virtio_balloon-fix-shrinker-count.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/0001-virtio_console-allocate-inbufs-in-add_port-only-if-i.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/0001-virtio_ring-fix-return-code-on-DMA-mapping-fails.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/ALSA-usb-audio-Fix-NULL-dereference-at-parsing-BADD.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/KVM-PPC-Book3S-HV-Flush-link-stack-on-guest-exit-to-.patch
  (CVE-2019-18660 bsc#1157038 bsc#1157923 ltc#182612 bnc#1151927
  5.3.14).
- Update
  patches.suse/Revert-fs-ocfs2-fix-possible-null-pointer-dereferenc.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/drm-i915-userptr-Try-to-acquire-the-page-lock-around.patch
  (bnc#1156537 bnc#1151927 5.3.14).
- Update
  patches.suse/gpio-bd70528-Use-correct-unit-for-debounce-times.patch
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608 bnc#1151927 5.3.14).
- Update patches.suse/gpio-max77620-Fixup-debounce-delays.patch
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608 bnc#1151927 5.3.14).
- Update
  patches.suse/gve-fix-dma-sync-bug-where-not-all-pages-synced.patch
  (bsc#1154353 bnc#1151927 5.3.14).
- Update
  patches.suse/ipv6-route-return-if-there-is-no-fib_nh_gw_family.patch
  (bsc#1154353 bnc#1151927 5.3.14).
- Update
  patches.suse/mdio_bus-Fix-init-if-CONFIG_RESET_CONTROLLER-n.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/media-vivid-Fix-wrong-locking-that-causes-race-condi.patch
  (CVE-2019-18683,bsc#1155897 bnc#1151927 5.3.14).
- Update
  patches.suse/mlxsw-spectrum_router-Fix-determining-underlay-for-a.patch
  (bsc#1154488 bnc#1151927 5.3.14).
- Update
  patches.suse/mm-ksm.c-don-t-WARN-if-page-is-still-mapped-in-remove_stable_node.patch
  (git fixes (mm/ksm bnc#1151927 5.3.14).
- Update
  patches.suse/mm-memory_hotplug-don-t-access-uninitialized-memmaps-in-shrink_zone_span.patch
  (git fixes (mm/hotplug) bnc#1151927 5.3.14).
- Update
  patches.suse/mm-slub.c-init_on_free-1-should-wipe-freelist-ptr-for-bulk-allocations.patch
  (git fixes (mm/slub) bnc#1151927 5.3.14).
- Update patches.suse/nbd-fix-memory-leak-in-nbd_get_socket.patch
  (git-fixes bnc#1151927 5.3.14).
- Update patches.suse/net-ath10k-Fix-a-NULL-ptr-deref-bug.patch
  (CVE-2019-15099,bsc#1146368 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx4_en-Fix-wrong-limitation-for-number-of-TX-ri.patch
  (jsc#SLE-8460 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx4_en-fix-mlx4-ethtool-N-insertion.patch
  (jsc#SLE-8460 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx5-Fix-auto-group-size-calculation.patch
  (jsc#SLE-8464 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx5-Update-the-list-of-the-PCI-supported-device.patch
  (jsc#SLE-8464 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx5e-Do-not-use-non-EXT-link-modes-in-EXT-mode.patch
  (jsc#SLE-8464 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx5e-Fix-error-flow-cleanup-in-mlx5e_tc_tun_cre.patch
  (jsc#SLE-8464 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx5e-Fix-set-vf-link-state-error-flow.patch
  (jsc#SLE-8464 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlxfw-Verify-FSM-error-code-translation-doesn-t-.patch
  (jsc#SLE-8464 bnc#1151927 5.3.14).
- Update
  patches.suse/net-sched-act_pedit-fix-WARN-in-the-traffic-path.patch
  (bsc#1154353 bnc#1151927 5.3.14).
- Update
  patches.suse/net-sched-ensure-opts_len-IP_TUNNEL_OPTS_MAX-in-act_.patch
  (bsc#1154353 bnc#1151927 5.3.14).
- Update
  patches.suse/net-tls-enable-sk_msg-redirect-to-tls-socket-egress.patch
  (bsc#1154353 bnc#1151927 5.3.14).
- Update
  patches.suse/powerpc-64s-support-nospectre_v2-cmdline-option.patch
  (bsc#1131107 bnc#1151927 5.3.14).
- Update
  patches.suse/powerpc-book3s64-Fix-link-stack-flush-on-context-swi.patch
  (CVE-2019-18660 bsc#1157038 bsc#1157923 ltc#182612 bnc#1151927
  5.3.14).
- Update
  patches.suse/sfc-Only-cancel-the-PPS-workqueue-if-it-exists.patch
  (jsc#SLE-8314 bnc#1151927 5.3.14).
- Update
  patches.suse/taprio-don-t-reject-same-mqprio-settings.patch
  (bsc#1154353 bnc#1151927 5.3.14).
- Update
  patches.suse/usbip-Fix-uninitialized-symbol-nents-in-stub_recv_cm.patch
  (git-fixes bnc#1151927 5.3.14).
- commit 53302d0
* Tue Dec  3 2019 mbenes@suse.cz
- blacklist.conf: 1d200e9d6f63 ("block: Fix writeback throttling W=1 compiler warnings")
- commit e82481b
* Tue Dec  3 2019 jslaby@suse.cz
- hwrng: omap - Fix RNG wait loop timeout (git-fixes).
- commit 76a15d1
* Tue Dec  3 2019 mkubecek@suse.cz
- fix mainline references
- fix mainline references:
  patches.suse/0001-Revert-Bluetooth-hci_ll-set-operational-frequency-ea.patch
  patches.suse/0001-Revert-mfd-syscon-Set-name-of-regmap_config.patch
  patches.suse/0001-USB-serial-mos7720-fix-remote-wakeup.patch
  patches.suse/0001-USB-serial-mos7840-fix-remote-wakeup.patch
  patches.suse/0001-ppdev-fix-PPGETTIME-PPSETTIME-ioctls.patch
- commit d4e2479
* Tue Dec  3 2019 mkubecek@suse.cz
- series.conf: refresh
- update mainline references and resort:
  patches.suse/of-address-fix-of_pci_range_parser_one-translation-of-dma-addresses.patch
  patches.suse/of-address-follow-dma-parent-for-dma-coherent.patch
  patches.suse/of-address-introduce-of_get_next_dma_parent-helper.patch
  patches.suse/of-address-translate-dma-ranges-for-parent-nodes-missing-dma-ranges.patch
  patches.suse/of-factor-out-addr-size-cells-parsing.patch
  patches.suse/of-make-of_dma_get_range-work-on-bus-nodes.patch
  patches.suse/powerpc-book3s64-hash-Use-secondary-hash-for-bolted-.patch
  patches.suse/powerpc-fadump-when-fadump-is-supported-register-the.patch
  patches.suse/powerpc-papr_scm-Fix-an-off-by-one-check-in-papr_scm.patch
  patches.suse/powerpc-pseries-Don-t-fail-hash-page-table-insert-fo.patch
  patches.suse/powerpc-pseries-Don-t-opencode-HPTE_V_BOLTED.patch
  patches.suse/powerpc-pseries-address-checkpatch-warnings-in-dlpar.patch
  patches.suse/powerpc-pseries-safely-roll-back-failed-DLPAR-cpu-ad.patch
  patches.suse/powerpc-security-Fix-wrong-message-when-RFI-Flush-is.patch
  patches.suse/powerpc-security-book3s64-Report-L1TF-status-in-sysf.patch
  patches.suse/powerpc-xive-Prevent-page-fault-issues-in-the-machin.patch
  patches.suse/scsi-lpfc-Add-FA-WWN-Async-Event-reporting.patch
  patches.suse/scsi-lpfc-Add-FC-AL-support-to-lpe32000-models.patch
  patches.suse/scsi-lpfc-Add-additional-discovery-log-messages.patch
  patches.suse/scsi-lpfc-Add-enablement-of-multiple-adapter-dumps.patch
  patches.suse/scsi-lpfc-Add-log-macros-to-allow-print-by-serverity.patch
  patches.suse/scsi-lpfc-Add-registration-for-CPU-Offline-Online-ev.patch
  patches.suse/scsi-lpfc-Change-default-IRQ-model-on-AMD-architectu.patch
  patches.suse/scsi-lpfc-Clarify-FAWNN-error-message.patch
  patches.suse/scsi-lpfc-Complete-removal-of-FCoE-T10-PI-support-on.patch
  patches.suse/scsi-lpfc-Fix-GPF-on-scsi-command-completion.patch
  patches.suse/scsi-lpfc-Fix-NULL-check-before-mempool_destroy-is-n.patch
  patches.suse/scsi-lpfc-Fix-NVME-io-abort-failures-causing-hangs.patch
  patches.suse/scsi-lpfc-Fix-NVMe-ABTS-in-response-to-receiving-an-.patch
  patches.suse/scsi-lpfc-Fix-SLI3-hba-in-loop-mode-not-discovering-.patch
  patches.suse/scsi-lpfc-Fix-a-kernel-warning-triggered-by-lpfc_get.patch
  patches.suse/scsi-lpfc-Fix-a-kernel-warning-triggered-by-lpfc_sli.patch
  patches.suse/scsi-lpfc-Fix-bad-ndlp-ptr-in-xri-aborted-handling.patch
  patches.suse/scsi-lpfc-Fix-configuration-of-BB-credit-recovery-in.patch
  patches.suse/scsi-lpfc-Fix-coverity-errors-on-NULL-pointer-checks.patch
  patches.suse/scsi-lpfc-Fix-device-recovery-errors-after-PLOGI-fai.patch
  patches.suse/scsi-lpfc-Fix-discovery-failures-when-target-device-.patch
  patches.suse/scsi-lpfc-Fix-duplicate-unreg_rpi-error-in-port-offl.patch
  patches.suse/scsi-lpfc-Fix-dynamic-fw-log-enablement-check.patch
  patches.suse/scsi-lpfc-Fix-hardlockup-in-lpfc_abort_handler.patch
  patches.suse/scsi-lpfc-Fix-hdwq-sgl-locks-and-irq-handling.patch
  patches.suse/scsi-lpfc-Fix-host-hang-at-boot-or-slow-boot.patch
  patches.suse/scsi-lpfc-Fix-kernel-crash-at-lpfc_nvme_info_show-du.patch
  patches.suse/scsi-lpfc-Fix-list-corruption-detected-in-lpfc_put_s.patch
  patches.suse/scsi-lpfc-Fix-list-corruption-in-lpfc_sli_get_iocbq.patch
  patches.suse/scsi-lpfc-Fix-lockdep-errors-in-sli_ringtx_put.patch
  patches.suse/scsi-lpfc-Fix-locking-on-mailbox-command-completion.patch
  patches.suse/scsi-lpfc-Fix-lpfc_cpumask_of_node_init.patch
  patches.suse/scsi-lpfc-Fix-miss-of-register-read-failure-check.patch
  patches.suse/scsi-lpfc-Fix-premature-re-enabling-of-interrupts-in.patch
  patches.suse/scsi-lpfc-Fix-pt2pt-discovery-on-SLI3-HBAs.patch
  patches.suse/scsi-lpfc-Fix-reporting-of-read-only-fw-error-errors.patch
  patches.suse/scsi-lpfc-Fix-rpi-release-when-deleting-vport.patch
  patches.suse/scsi-lpfc-Fix-spinlock_irq-issues-in-lpfc_els_flush_.patch
  patches.suse/scsi-lpfc-Fix-unexpected-error-messages-during-RSCN-.patch
  patches.suse/scsi-lpfc-Initialize-cpu_map-for-not-present-cpus.patch
  patches.suse/scsi-lpfc-Make-FW-logging-dynamically-configurable.patch
  patches.suse/scsi-lpfc-Make-function-lpfc_defer_pt2pt_acc-static.patch
  patches.suse/scsi-lpfc-Make-lpfc_debugfs_ras_log_data-static.patch
  patches.suse/scsi-lpfc-Remove-lock-contention-target-write-path.patch
  patches.suse/scsi-lpfc-Revise-interrupt-coalescing-for-missing-sc.patch
  patches.suse/scsi-lpfc-Slight-fast-path-performance-optimizations.patch
  patches.suse/scsi-lpfc-Sync-with-FC-NVMe-2-SLER-change-to-require.patch
  patches.suse/scsi-lpfc-Update-async-event-logging.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.4.0.1.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.6.0.0.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.6.0.1.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.6.0.2.patch
  patches.suse/scsi-lpfc-cleanup-remove-unused-fcp_txcmlpq_cnt.patch
  patches.suse/scsi-lpfc-fix-Coverity-lpfc_cmpl_els_rsp-Null-pointe.patch
  patches.suse/scsi-lpfc-fix-Coverity-lpfc_get_scsi_buf_s3-Null-poi.patch
  patches.suse/scsi-lpfc-fix-build-error-of-lpfc_debugfs.c-for-vfre.patch
  patches.suse/scsi-lpfc-fix-coverity-error-of-dereference-after-nu.patch
  patches.suse/scsi-lpfc-fix-inlining-of-lpfc_sli4_cleanup_poll_lis.patch
  patches.suse/scsi-lpfc-fix-lpfc_nvmet_mrq-to-be-bound-by-hdw-queu.patch
  patches.suse/scsi-lpfc-fix-spelling-error-in-MAGIC_NUMER_xxx.patch
  patches.suse/scsi-lpfc-lpfc_attr-Fix-Use-plain-integer-as-NULL-po.patch
  patches.suse/scsi-lpfc-lpfc_nvmet-Fix-Use-plain-integer-as-NULL-p.patch
  patches.suse/scsi-lpfc-revise-nvme-max-queues-to-be-hdwq-count.patch
  patches.suse/scsi-megaraid_sas-Unique-names-for-MSI-X-vectors.patch
  patches.suse/scsi-megaraid_sas-remove-unused-variables-debugBlk-f.patch
  patches.suse/scsi-mpt3sas-Add-app-owned-flag-support-for-diag-buf.patch
  patches.suse/scsi-mpt3sas-Bump-mpt3sas-driver-version-to-32.100.0.patch
  patches.suse/scsi-mpt3sas-Display-message-before-releasing-diag-b.patch
  patches.suse/scsi-mpt3sas-Fail-release-cmnd-if-diag-buffer-is-rel.patch
  patches.suse/scsi-mpt3sas-Fix-clear-pending-bit-in-ioctl-status.patch
  patches.suse/scsi-mpt3sas-Fix-module-parameter-max_msix_vectors.patch
  patches.suse/scsi-mpt3sas-Free-diag-buffer-without-any-status-che.patch
  patches.suse/scsi-mpt3sas-Maintain-owner-of-buffer-through-Unique.patch
  patches.suse/scsi-mpt3sas-Register-trace-buffer-based-on-NVDATA-s.patch
  patches.suse/scsi-mpt3sas-Reject-NVMe-Encap-cmnds-to-unsupported-.patch
  patches.suse/scsi-mpt3sas-Reuse-diag-buffer-allocated-at-load-tim.patch
  patches.suse/scsi-mpt3sas-Use-Component-img-header-to-get-Package.patch
  patches.suse/scsi-mpt3sas-clear-release-bit-when-buffer-reregiste.patch
  patches.suse/scsi-qedf-Add-port_id-getter.patch
  patches.suse/scsi-qla2xxx-Add-error-handling-for-PLOGI-ELS-passth.patch
  patches.suse/scsi-qla2xxx-Capture-FW-dump-on-MPI-heartbeat-stop-e.patch
  patches.suse/scsi-qla2xxx-Check-for-MB-timeout-while-capturing-IS.patch
  patches.suse/scsi-qla2xxx-Do-command-completion-on-abort-timeout.patch
  patches.suse/scsi-qla2xxx-Dual-FCP-NVMe-target-port-support.patch
  patches.suse/scsi-qla2xxx-Fix-SRB-leak-on-switch-command-timeout.patch
  patches.suse/scsi-qla2xxx-Fix-a-dma_pool_free-call.patch
  patches.suse/scsi-qla2xxx-Fix-device-connect-issues-in-P2P-config.patch
  patches.suse/scsi-qla2xxx-Fix-double-scsi_done-for-abort-path.patch
  patches.suse/scsi-qla2xxx-Fix-driver-unload-hang.patch
  patches.suse/scsi-qla2xxx-Improve-logging-for-scan-thread.patch
  patches.suse/scsi-qla2xxx-Remove-an-include-directive.patch
  patches.suse/scsi-qla2xxx-Retry-PLOGI-on-FC-NVMe-PRLI-failure.patch
  patches.suse/scsi-qla2xxx-Set-remove-flag-for-all-VP.patch
  patches.suse/scsi-qla2xxx-Update-driver-version-to-10.01.00.20-k.patch
  patches.suse/scsi-qla2xxx-Update-driver-version-to-10.01.00.21-k.patch
  patches.suse/scsi-qla2xxx-don-t-use-zero-for-FC4_PRIORITY_NVME.patch
  patches.suse/scsi-qla2xxx-initialize-fc4_type_priority.patch
  patches.suse/scsi-qla2xxx-remove-redundant-assignment-to-pointer-.patch
  patches.suse/scsi-smartpqi-Align-driver-syntax-with-oob.patch
  patches.suse/scsi-smartpqi-add-inquiry-timeouts.patch
  patches.suse/scsi-smartpqi-bump-version-to-1.2.10-025.patch
  patches.suse/scsi-smartpqi-change-TMF-timeout-from-60-to-30-secon.patch
  patches.suse/scsi-smartpqi-clean-up-indentation-of-a-statement.patch
  patches.suse/scsi-smartpqi-correct-syntax-issue.patch
  patches.suse/scsi-smartpqi-fix-LUN-reset-when-fw-bkgnd-thread-is-.patch
  patches.suse/scsi-smartpqi-fix-call-trace-in-device-discovery.patch
  patches.suse/scsi-smartpqi-fix-controller-lockup-observed-during-.patch
  patches.suse/scsi-smartpqi-fix-problem-with-unique-ID-for-physica.patch
  patches.suse/scsi-smartpqi-remove-set-but-not-used-variable-ctrl_.patch
  patches.suse/scsi-smartpqi-remove-unused-manifest-constants.patch
  patches.suse/scsi-target-compare-full-CHAP_A-Algorithm-strings.patch
  patches.suse/scsi-target-fix-SendTargets-All-string-compares.patch
  patches.suse/scsi-target-iscsi-CHAP-add-support-for-SHA1-SHA256-a.patch
  patches.suse/scsi-target-iscsi-rename-some-variables-to-avoid-con.patch
  patches.suse/scsi-target-iscsi-tie-the-challenge-length-to-the-ha.patch
  patches.suse/scsi-target-remove-unused-extension-parameters.patch
  No effect on expanded tree.
- commit 1cb26c8
* Tue Dec  3 2019 mkubecek@suse.cz
- fix mainline references
  Fix patch-mainline tag:
  patches.suse/btrfs-fix-memory-leaks-in-the-test-test_find_first_c.patch
  patches.suse/btrfs-make-test_find_first_clear_extent_bit-fail-on-.patch
- commit 5794053
* Tue Dec  3 2019 neilb@suse.de
- NFSv4.1 - backchannel request should hold ref on xprt
  (bsc#1152624).
- commit 1203c55
* Mon Dec  2 2019 fdmanana@suse.com
- Btrfs: make test_find_first_clear_extent_bit fail on incorrect
  results (bsc#1158210).
- commit e7e7b18
* Mon Dec  2 2019 fdmanana@suse.com
- Btrfs: fix memory leaks in the test
  test_find_first_clear_extent_bit (bsc#1158210).
- commit 04b8200
* Mon Dec  2 2019 oneukum@suse.com
- Revert "mfd: syscon: Set name of regmap_config" (git-fixes).
- commit da59436
* Mon Dec  2 2019 oneukum@suse.com
- blacklist.conf: specific to SPARC64
- commit 6880b65
* Mon Dec  2 2019 oneukum@suse.com
- ppdev: fix PPGETTIME/PPSETTIME ioctls (git-fixes).
- commit 71fc6dc
* Mon Dec  2 2019 oneukum@suse.com
- USB: serial: mos7840: fix remote wakeup (git-fixes).
- commit 6ebc1fd
* Mon Dec  2 2019 oneukum@suse.com
- USB: serial: mos7720: fix remote wakeup (git-fixes).
- commit aeee58e
* Mon Dec  2 2019 oneukum@suse.com
- Revert "Bluetooth: hci_ll: set operational frequency earlier"
  (git-fixes).
- commit 8b8f5bf
* Mon Dec  2 2019 jslaby@suse.cz
- perf script: Fix invalid LBR/binary mismatch error (git-fixes).
- watchdog: aspeed: Fix clock behaviour for ast2600 (git-fixes).
- slip: Fix use-after-free Read in slip_open (git-fixes).
- net/sched: annotate lockless accesses to qdisc->empty
  (git-fixes).
- kselftest: Fix NULL INSTALL_PATH for TARGETS runlist
  (git-fixes).
- md/raid0: Fix an error message in raid0_make_request()
  (git-fixes).
- io_uring: Fix mm_fault with READ/WRITE_FIXED (git-fixes).
- Revert "fs: ocfs2: fix possible null-pointer dereferences in
  ocfs2_xa_prepare_entry()" (git-fixes).
- nbd:fix memory leak in nbd_get_socket() (git-fixes).
- KVM: x86/mmu: Take slots_lock when using kvm_mmu_zap_all_fast()
  (git-fixes).
- ARM: dts: stm32: remove OV5640 pinctrl definition on
  stm32mp157c-ev1 (git-fixes).
- Refresh
  patches.suse/ARM-dts-stm32-change-joystick-pinctrl-definition-on-.patch.
- commit c09426f
* Mon Dec  2 2019 jthumshirn@suse.de
- libnvdimm: Export the target_node attribute for regions and
  namespaces (bsc#1158071).
- commit 9d24c0f
* Mon Dec  2 2019 jslaby@suse.cz
- blacklist.conf: add four more entries
- commit 49fe688
* Mon Dec  2 2019 jslaby@suse.cz
- drm/mcde: Fix an error handling path in 'mcde_probe()'
  (git-fixes).
- usb: gadget: configfs: Fix missing spin_lock_init() (git-fixes).
- usbip: Fix uninitialized symbol 'nents' in
  stub_recv_cmd_submit() (git-fixes).
- commit 53a444b
* Fri Nov 29 2019 ggherdovich@suse.cz
- platform/x86: ISST: Allow additional TRL MSRs (jsc#SLE-10687).
- commit 435b3fb
* Fri Nov 29 2019 mkubecek@suse.cz
- supported.conf: sort
- commit ac3011b
* Fri Nov 29 2019 msuchanek@suse.de
- Update config files.
  ppc64 is lats architecture without PRINTK_TIME. Align with the rest.
- commit 4fb63b6
* Fri Nov 29 2019 ptesarik@suse.cz
- s390: vfio-ap: fix warning reset not completed (jsc#SLE-7524
  LTC#178970).
- commit fd793bf
* Fri Nov 29 2019 ptesarik@suse.cz
- Update config files (bsc#1158055 LTC#182629).
- commit 1b24df4
* Fri Nov 29 2019 tiwai@suse.de
- Move upstreamed patches into sorted section
  Refresh:
  patches.suse/0001-b2c2-flexcop-usb-add-sanity-checking.patch
  patches.suse/driver-core-simplify-definitions-of-platform_get_irq.patch
  patches.suse/drm-amdgpu-Add-DC-feature-mask-to-disable-fractional.patch
- commit 71f50c8
* Fri Nov 29 2019 tiwai@suse.de
- mwifiex: fix possible heap overflow in
  mwifiex_process_country_ie() (CVE-2019-14895 bsc#1157158).
- commit d8b66ee
* Fri Nov 29 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/RDMA-bnxt_re-Fix-stat-push-into-dma-buffer-on-gen-p5-devices.patch
  No effect on expanded tree.
- commit b878e91
* Fri Nov 29 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort
  patches.suse/dma-direct-avoid-a-forward-declaration-for-phys_to_dma.patch
  patches.suse/dma-direct-check-for-overflows-on-32-bit-dma-addresses.patch
  patches.suse/dma-direct-exclude-dma_direct_map_resource-from-the-min_low_pfn-check.patch
  patches.suse/dma-direct-unify-the-dma_capable-definitions.patch
  patches.suse/dma-mapping-treat-dev-bus_dma_mask-as-a-dma-limit.patch
  patches.suse/x86-pci-sta2x11-use-default-dma-address-translation.patch
- commit 3b7773d
* Thu Nov 28 2019 oneukum@suse.com
- virtio_balloon: fix shrinker count (git-fixes).
- commit 923948e
* Thu Nov 28 2019 oneukum@suse.com
- virtio_balloon: fix shrinker scan number of pages (gif-fixes).
- commit 217c80e
* Thu Nov 28 2019 oneukum@suse.com
- virtio_ring: fix return code on DMA mapping fails (git-fixes).
- commit d775d67
* Thu Nov 28 2019 yousaf.kaukab@suse.com
- regulator: core: make regulator_register() EPROBE_DEFER aware
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- regulator: core: Add label to collate of_node_put() statements
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- regulator: core: Add of_node_put() before return
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- commit 48eb6c5
* Thu Nov 28 2019 ptesarik@suse.cz
- net/smc: receive pending data after RCV_SHUTDOWN (jsc#SLE-7521
  LTC#178954).
- net/smc: receive returns without data (jsc#SLE-7521 LTC#178954).
- net/smc: fix SMCD link group creation with VLAN id (jsc#SLE-7521
  LTC#178954).
- commit 83dcb05
* Thu Nov 28 2019 ptesarik@suse.cz
- s390: add support for IBM z15 machines (bsc#1156538 LTC#182406).
- Update config files.
- commit c53f40a
* Thu Nov 28 2019 tbogendoerfer@suse.de
- Update
  patches.suse/RDMA-Fix-goto-target-to-release-the-allocated-memory.patch
  (jsc#SLE-8449 bsc#1157171 CVE-2019-19077).
- commit e1bdb30
* Thu Nov 28 2019 tbogendoerfer@suse.de
- Update
  patches.suse/nfp-flower-fix-memory-leak-in-nfp_flower_spawn_vnic_.patch
  (bnc#1151927 5.3.4 bsc#1157045 CVE-2019-19081).
- commit e720525
* Thu Nov 28 2019 tbogendoerfer@suse.de
- Update
  patches.suse/nfp-flower-prevent-memory-leak-in-nfp_flower_spawn_p.patch
  (bnc#1151927 5.3.4 bsc#1157044 CVE-2019-19080).
- commit 8b64c31
* Thu Nov 28 2019 tbogendoerfer@suse.de
- Update
  patches.suse/RDMA-hfi1-Prevent-memory-leak-in-sdma_init.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9 bsc#1157191 CVE-2019-19065).
- commit 29b1120
* Thu Nov 28 2019 yousaf.kaukab@suse.com
- gpio: stubs in headers should be inline
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- commit d6eb08d
* Thu Nov 28 2019 ptesarik@suse.cz
- s390/cpumsf: Check for CPU Measurement sampling
  (bsc#1156561 LTC#182407).
- commit 02c88d4
* Thu Nov 28 2019 yousaf.kaukab@suse.com
- regulator: add missing 'static inline' to a helper's stub
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- commit a58ac0e
* Thu Nov 28 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/ibmvnic-Bound-waits-for-device-queries.patch
  patches.suse/ibmvnic-Fix-completion-structure-initialization-again.patch
  patches.suse/ibmvnic-Serialize-device-queries.patch
  patches.suse/ibmvnic-Terminate-waiting-device-threads-after-loss-.patch
- commit 223cb4b
* Thu Nov 28 2019 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patches out of sorted section
  patches.suse/CIFS-Fix-SMB2-oplock-break-processing.patch
  patches.suse/cifs-move-cifsFileInfo_put-logic-into-a-work-queue.patch
- update Patch-mainline tag
  patches.suse/smb3-fix-leak-in-open-on-server-perf-counter.patch
- commit 4594952
* Wed Nov 27 2019 msuchanek@suse.de
- powerpc: add link stack flush mitigation in debugfs
  (CVE-2019-18660 bsc#1157038 bsc#1157923 ltc#182612).
- KVM: PPC: Book3S HV: Flush link stack on guest exit to host
  kernel (CVE-2019-18660 bsc#1157038 bsc#1157923 ltc#182612).
- powerpc/book3s64: Fix link stack flush on context switch
  (CVE-2019-18660 bsc#1157038 bsc#1157923 ltc#182612).
- commit 538ee5a
* Wed Nov 27 2019 msuchanek@suse.de
- net/ibmvnic: Ignore H_FUNCTION return from H_EOI to tolerate
  XIVE mode (bsc#1089644, ltc#166495, ltc#165544, git-fixes).
- Delete patches.suse/net-ibmvnic-Fix-EOI-when-running-in-XIVE-mode.patch - reverted upstream
- blacklist.conf: Add the removed patch and revert.
- commit e63bc30
* Wed Nov 27 2019 tiwai@suse.de
- PCI: Fix missing inline for pci_pr3_present() (git-fixes).
- PCI: Add a helper to check Power Resource Requirements _PR3
  existence (git-fixes).
- commit 071c077
* Wed Nov 27 2019 yousaf.kaukab@suse.com
- regulator: provide regulator_bulk_set_supply_names()
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- commit ef060bf
* Wed Nov 27 2019 oneukum@suse.com
- blacklist.conf: no need to watch for android fixes
- commit 4abf123
* Wed Nov 27 2019 ptesarik@suse.cz
- s390/pkey: fix memory leak within _copy_apqns_from_user()
  (jsc#SLE-7533 LTC#178844).
- commit 3fe4d6e
* Wed Nov 27 2019 ptesarik@suse.cz
- s390/crypto: Fix unsigned variable compared with zero
  (jsc#SLE-7545 LTC#179078).
- commit d517803
* Wed Nov 27 2019 ptesarik@suse.cz
- s390/crypto: Support for SHA3 via CPACF (MSA6) (jsc#SLE-7545
  LTC#179078).
- Update config files.
- supported.conf: Add sha3_256_s390 and sha3_512_s390.
- commit 39adadf
* Wed Nov 27 2019 mkubecek@suse.cz
- update upstream references
- move into sorted section:
  patches.suse/sched-pelt-Fix-update-of-blocked-PELT-ordering.patch
- update upstream reference and move into sorted section:
  patches.suse/sched-cpufreq-Move-the-cfs_rq_util_change-call-to-cpufreq_update_util.patch
- update Patch-mainline:
  patches.suse/sched-core-Further-clarify-sched_class-set_next_task.patch
  patches.suse/sched-core-Make-pick_next_task_idle-more-consistent.patch
  patches.suse/sched-core-Optimize-pick_next_task.patch
  patches.suse/sched-core-Simplify-sched_class-pick_next_task.patch
  patches.suse/sched-fair-Add-comments-for-group_type-and-balancing-at-SD_NUMA-level.patch
  patches.suse/sched-fair-Better-document-newidle_balance.patch
  patches.suse/sched-fair-Clean-up-asym-packing.patch
  patches.suse/sched-fair-Fix-rework-of-find_idlest_group.patch
  patches.suse/sched-fair-Optimize-find_idlest_group.patch
  patches.suse/sched-fair-Remove-meaningless-imbalance-calculation.patch
  patches.suse/sched-fair-Rename-sg_lb_stats-sum_nr_running-to-sum_h_nr_running.patch
  patches.suse/sched-fair-Rework-find_idlest_group.patch
  patches.suse/sched-fair-Rework-load_balance.patch
  patches.suse/sched-fair-Spread-out-tasks-evenly-when-not-overloaded.patch
  patches.suse/sched-fair-Use-load-instead-of-runnable-load-in-load_balance.patch
  patches.suse/sched-fair-Use-load-instead-of-runnable-load-in-wakeup-path.patch
  patches.suse/sched-fair-Use-mul_u32_u32.patch
  patches.suse/sched-fair-Use-rq-nr_running-when-balancing-load.patch
  patches.suse/sched-fair-Use-utilization-to-select-misfit-task.patch
  patches.suse/sched-fair-util_est-Implement-faster-ramp-up-EWMA-on-utilization-increases.patch
  patches.suse/sched-pelt-Fix-update-of-blocked-PELT-ordering.patch
  patches.suse/sched-topology-Don-t-set-SD_BALANCE_WAKE-on-cpuset-domain-relax.patch
- commit d845674
* Wed Nov 27 2019 yousaf.kaukab@suse.com
- soc/tegra: pmc: Add reset sources and levels on Tegra194
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Add missing IRQ callbacks on Tegra194
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Use lower-case for hexadecimal literals
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- usb: host: xhci-tegra: Correct phy enable sequence
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: tegra186: Add debounce support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: tegra186: Program interrupt route mapping
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: tegra186: Derive register offsets from bank/port
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- memory: tegra: Set DMA mask based on supported address bits
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Fix build error without CONFIG_PM_SLEEP
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Add suspend and resume support on Tegra210
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Share clk and rst register defines with Tegra
  clock driver (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: clk-super: Fix to enable PLLP branches to CPU
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: clk-dfll: Add suspend and resume support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Use fence_udelay() during PLLU init
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: clk-super: Add restore-context support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: periph: Add restore_context support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Support for OSC context save and restore
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: pll: Save and restore pll context
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: pllout: Save and restore pllout context
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: divider: Save and restore divider rate
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Reimplement SOR clocks on Tegra210
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Reimplement SOR clock on Tegra124
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Rename sor0_lvds to sor0_out
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Move SOR0 implementation to Tegra124
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Remove last remains of TEGRA210_CLK_SOR1_SRC
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: Add API to get index of the clock parent
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- dt-bindings: clock: tegra: Rename SOR0_LVDS to SOR0_OUT
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- mfd: max77620: Do not allocate IRQs upfront
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- arm64: kpti: Add NVIDIA's Carmel core to the KPTI whitelist
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Configure deep sleep control settings
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Configure core power request polarity
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Add wake event support on Tegra210
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Support wake events on more Tegra SoCs
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- cpufreq: tegra124: Add suspend and resume support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- ahci: tegra: use regulator_bulk_set_supply_names()
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- phy: tegra: use regulator_bulk_set_supply_names()
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- phy: tegra: xusb: Add vbus override support on Tegra210
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- phy: tegra: xusb: Add vbus override support on Tegra186
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- phy: tegra: xusb: Add usb3 port fake support on Tegra210
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- phy: tegra: xusb: Add XUSB dual mode support on Tegra210
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- iommu/tegra-smmu: Use non-secure register for flushing
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- iommu/tegra-smmu: Fix page tables in > 4 GiB memory
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- iommu/tegra-smmu: Fix client enablement order
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: tegra: Fix CLKREQ dependency programming
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- usb: host: xhci-tegra: Add Tegra194 XHCI support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- xhci: tegra: Parameterize mailbox register addresses
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: tegra186: Implement wake event support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: max77620: Fix interrupt handling
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: max77620: Do not allocate IRQs upfront
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- usb: host: xhci-tegra: use regulator_bulk_set_supply_names()
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- usb: host: xhci-tegra: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- net: stmmac: Support enhanced addressing mode for DWMAC 4.10
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- net: stmmac: Only enable enhanced addressing mode when needed
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Fix crashes for hierarchical interrupts
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: fuse: Add FUSE clock check in tegra_fuse_readl()
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- firmware: tegra: Move BPMP resume to noirq phase
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: bd70528: Use correct unit for debounce times
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: max77620: Fixup debounce delays
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- thermal: tegra: Fix a typo
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- i2c: tegra: Compile PM functions unconditionally
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- arm64: tegra: Add PCIe slot supply information in p2972-0000
  platform (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: tegra: Add support to enable slot regulators
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: tegra: Add support to configure sideband pins
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: tegra: Add Tegra194 PCIe support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- phy: tegra: Add PCIe PIPE2UPHY support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: dwc: Add support to enable CDM register check
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: dwc: Export dw_pcie_wait_for_link() API
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: dwc: Add extended configuration space capability search
  API (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: dwc: Move config space capability search API
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: dwc: Group DBI registers writes requiring unlocking
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: Disable MSI for Tegra root ports
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: Add #defines for some of PCIe spec r4.0 features
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- pinctrl: tegra: Flush pinctrl writes during resume
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- pinctrl: tegra210: Add Tegra210 pinctrl pm ops
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- pinctrl: tegra: Add suspend and resume support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- net: stmmac: Do not request stmmaceth clock
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- net: stmmac: Make MDIO bus reset optional
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: Add PIO mode support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: report clk rate errors
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: add support to adjust baud rate
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: DT for Adjusted baud rates
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: add support to use 8 bytes trigger
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: set maximum num of uart ports to 8
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: check for FIFO mode enabled status
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: report error to upper tty layer
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: flush the RX fifo on frame error
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: avoid reg access when clk disabled
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: add support to ignore read
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: protect IER against LCR.DLAB
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: add internal loopback functionality
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- dmaengine: tegra210-adma: Don't program FIFO threshold
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- dmaengine: tegra-apb: Support per-burst residue granularity
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: pca953x: Drop %%s for constant string literals
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: pca953x: Remove explicit comparison with 0
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: pca953x: Use GENMASK() consistently
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: pca953x: Switch to use device_get_match_data()
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: Add support for hierarchical IRQ domains
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- commit e2e7db7
* Wed Nov 27 2019 ptesarik@suse.cz
- s390/qeth: use IQD Multi-Write (jsc#SLE-7795 LTC#179220).
- s390/qdio: implement IQD Multi-Write (jsc#SLE-7795 LTC#179220).
- s390/qeth: add xmit_more support for IQD devices (jsc#SLE-7795
  LTC#179220).
- s390/qeth: add BQL support for IQD devices (jsc#SLE-7795
  LTC#179220).
- s390/qeth: when in TX NAPI mode, use napi_consume_skb()
  (jsc#SLE-7795 LTC#179220).
- s390/qeth: add TX NAPI support for IQD devices (jsc#SLE-7795
  LTC#179220).
- s390/qeth: collect accurate TX statistics (jsc#SLE-7795
  LTC#179220).
- s390/qdio: let drivers opt-out from Output Queue scanning
  (jsc#SLE-7795 LTC#179220).
- s390/qdio: enable drivers to poll for Output completions
  (jsc#SLE-7795 LTC#179220).
- commit a827279
* Wed Nov 27 2019 ptesarik@suse.cz
- s390/pkey: Add sysfs attributes to emit AES CIPHER key blobs
  (jsc#SLE-7533 LTC#178844).
- s390/zcrypt: fix wrong handling of cca cipher keygenflags
  (jsc#SLE-7533 LTC#178844).
- s390/paes: Prepare paes functions for large key blobs
  (jsc#SLE-7533 LTC#178844).
- s390/pkey: add CCA AES cipher key support (jsc#SLE-7533
  LTC#178844).
- s390/zcrypt: Add low level functions for CCA AES cipher keys
  (jsc#SLE-7533 LTC#178844).
- s390/zcrypt: extend cca_findcard function and helper
  (jsc#SLE-7533 LTC#178844).
- s390/pkey: pkey cleanup: narrow in-kernel API, fix some variable
  types (jsc#SLE-7533 LTC#178844).
- commit 5c983d1
* Wed Nov 27 2019 nsaenzjulienne@suse.de
- of: Make of_dma_get_range() work on bus nodes (jsc#SLE-7772).
- of/address: Fix of_pci_range_parser_one translation of DMA
  addresses (jsc#SLE-7772).
- of/address: Translate 'dma-ranges' for parent nodes missing
  'dma-ranges' (jsc#SLE-7772).
- of: Factor out #{addr,size}-cells parsing (jsc#SLE-7772).
- of: address: Follow DMA parent for "dma-coherent"
  (jsc#SLE-7772).
- of/address: Introduce of_get_next_dma_parent() helper
  (jsc#SLE-7772).
- commit 6061577
* Wed Nov 27 2019 msuchanek@suse.de
- ibmvnic: Serialize device queries (bsc#1155689 ltc#182047).
- ibmvnic: Bound waits for device queries (bsc#1155689
  ltc#182047).
- ibmvnic: Terminate waiting device threads after loss of service
  (bsc#1155689 ltc#182047).
- ibmvnic: Fix completion structure initialization (bsc#1155689
  ltc#182047).
- commit 0ff402a
* Wed Nov 27 2019 mkubecek@suse.cz
- config: refresh
- drop SOUNDWIRE from ppc64le/kvmsmall (no longer visible)
- update headers
- commit 1859c8f
* Wed Nov 27 2019 mgorman@suse.de
- Refresh
  patches.suse/sched-core-Further-clarify-sched_class-set_next_task.patch.
- Refresh
  patches.suse/sched-core-Make-pick_next_task_idle-more-consistent.patch.
- Refresh patches.suse/sched-core-Optimize-pick_next_task.patch.
- Refresh
  patches.suse/sched-core-Simplify-sched_class-pick_next_task.patch.
- Refresh
  patches.suse/sched-fair-Add-comments-for-group_type-and-balancing-at-SD_NUMA-level.patch.
- Refresh
  patches.suse/sched-fair-Better-document-newidle_balance.patch.
- Refresh patches.suse/sched-fair-Clean-up-asym-packing.patch.
- Refresh
  patches.suse/sched-fair-Fix-rework-of-find_idlest_group.patch.
- Refresh
  patches.suse/sched-fair-Optimize-find_idlest_group.patch.
- Refresh
  patches.suse/sched-fair-Remove-meaningless-imbalance-calculation.patch.
- Refresh
  patches.suse/sched-fair-Rename-sg_lb_stats-sum_nr_running-to-sum_h_nr_running.patch.
- Refresh patches.suse/sched-fair-Rework-find_idlest_group.patch.
- Refresh patches.suse/sched-fair-Rework-load_balance.patch.
- Refresh
  patches.suse/sched-fair-Spread-out-tasks-evenly-when-not-overloaded.patch.
- Refresh
  patches.suse/sched-fair-Use-load-instead-of-runnable-load-in-load_balance.patch.
- Refresh
  patches.suse/sched-fair-Use-load-instead-of-runnable-load-in-wakeup-path.patch.
- Refresh patches.suse/sched-fair-Use-mul_u32_u32.patch.
- Refresh
  patches.suse/sched-fair-Use-rq-nr_running-when-balancing-load.patch.
- Refresh
  patches.suse/sched-fair-Use-utilization-to-select-misfit-task.patch.
- Refresh
  patches.suse/sched-fair-util_est-Implement-faster-ramp-up-EWMA-on-utilization-increases.patch.
- Refresh
  patches.suse/sched-topology-Don-t-set-SD_BALANCE_WAKE-on-cpuset-domain-relax.patch.
- commit 20b4948
* Wed Nov 27 2019 mkubecek@suse.cz
- fix Patch-mainline tags
  fix Patch-mainline:
  patches.suse/0001-Bluetooth-btusb-fix-PM-leak-in-error-case-of-setup.patch
  patches.suse/0001-crypto-af_alg-cast-ki_complete-ternary-op-to-int.patch
  patches.suse/0001-crypto-algif_skcipher-Use-chunksize-instead-of-block.patch
  patches.suse/0001-crypto-ecdh-fix-big-endian-bug-in-ECC-library.patch
  patches.suse/0001-crypto-user-fix-memory-leak-in-crypto_report.patch
  patches.suse/0001-crypto-user-fix-memory-leak-in-crypto_reportstat.patch
  patches.suse/0001-libbpf-Fix-struct-end-padding-in-btf_dump.patch
- commit 03de6a8
* Wed Nov 27 2019 mkubecek@suse.cz
- series.conf: cleanup
  Keep the number of top level section reasonable.
- commit b91f28d
* Wed Nov 27 2019 tiwai@suse.de
- ALSA: usb-audio: Fix Focusrite Scarlett 6i6 gen1 - input
  handling (git-fixes).
- ALSA: usb-audio: Fix NULL dereference at parsing BADD
  (git-fixes).
- ALSA: usb-audio: Fix Scarlett 6i6 Gen 2 port data (git-fixes).
- ALSA: usb-audio: Add skip_validation option (git-fixes).
- ALSA: 6fire: Drop the dead code (git-fixes).
- ALSA: usb-audio: sound: usb: usb true/false for bool return type
  (git-fixes).
- commit f395c96
* Wed Nov 27 2019 tiwai@suse.de
- ALSA: docs: Update about the new PCM sync_stop ops (git-fixes).
- ALSA: pcm: Add card sync_irq field (git-fixes).
- ALSA: pcm: Add the support for sync-stop operation (git-fixes).
- ALSA: pcm: Move PCM_RUNTIME_CHECK() macro into local header
  (git-fixes).
- ALSA: docs: Update document about the default PCM ioctl ops
  (git-fixes).
- ALSA: pcm: Allow NULL ioctl ops (git-fixes).
- ALSA: docs: Update for managed buffer allocation mode
  (git-fixes).
- ALSA: pcm: Introduce managed buffer allocation mode (git-fixes).
- ALSA: timer: Fix the breakage of slave link open (git-fixes).
- ALSA: pcm: Yet another missing check of non-cached buffer type
  (git-fixes).
- ALSA: timer: Fix possible race at assigning a timer instance
  (git-fixes).
- ALSA: timer: Make snd_timer_close() returning void (git-fixes).
- ALSA: timer: Unify master/slave linking code (git-fixes).
- ALSA: timer: Limit max amount of slave instances (git-fixes).
- ALSA: docs: Remove snd_dma_pci_data() usage in documentation
  (git-fixes).
- ALSA: pcm: Create proc files only for non-empty preallocations
  (git-fixes).
- ALSA: pcm: Warn if doubly preallocated (git-fixes).
- ALSA: docs: Update documentation about SG- and vmalloc-buffers
  (git-fixes).
- ALSA: pcm: Handle special page mapping in the default mmap
  handler (git-fixes).
- ALSA: memalloc: Add vmalloc buffer allocation support
  (git-fixes).
- ALSA: memalloc: Allow NULL device for SNDRV_DMA_TYPE_CONTINUOUS
  type (git-fixes).
- commit a9f5790
* Wed Nov 27 2019 tiwai@suse.de
- ALSA: hda/realtek - Enable internal speaker of ASUS UX431FLC
  (git-fixes).
- ALSA: hda/hdmi - Clear codec->relaxed_resume flag at unbinding
  (git-fixes).
- ALSA: hda - Disable audio component for legacy Nvidia HDMI
  codecs (git-fixes).
- ALSA: hda/realtek - Enable the headset-mic on a Xiaomi's laptop
  (git-fixes).
- ALSA: hda/realtek - Move some alc236 pintbls to fallback table
  (git-fixes).
- ALSA: hda/realtek - Move some alc256 pintbls to fallback table
  (git-fixes).
- ALSA: hda - Add mute led support for HP ProBook 645 G4
  (git-fixes).
- ALSA: hda - Add DP-MST support for NVIDIA codecs (git-fixes).
- ALSA: hda - Add DP-MST support for non-acomp codecs (git-fixes).
- ALSA: hda - Add DP-MST jack support (git-fixes).
- ALSA: hda - Rename snd_hda_pin_sense to snd_hda_jack_pin_sense
  (git-fixes).
- ALSA: hda - remove forced polling workaround for CFL and CNL
  (git-fixes).
- ALSA: hda: hdmi - remove redundant code comments (git-fixes).
- ALSA: hda: hdmi - fix port numbering for ICL and TGL platforms
  (git-fixes).
- ALSA: hda/hdmi - Clean up Intel platform-specific fixup checks
  (git-fixes).
- ALSA: hda/hdmi - implement mst_no_extra_pcms flag (git-fixes).
- ALSA: hda: Disable regmap internal locking (git-fixes).
- ALSA: hda - Fix pending unsol events at shutdown (git-fixes).
- ALSA: hda: Allow HDA to be runtime suspended when dGPU is not
  bound to a driver (git-fixes).
- commit 81f6f50
* Wed Nov 27 2019 tiwai@suse.de
- media: vivid: Fix wrong locking that causes race conditions
  on streaming stop (CVE-2019-18683,bsc#1155897).
- media: rcar_drif: fix a memory disclosure
  (CVE-2019-18786,bsc#1156043).
- media: usb: fix memory leak in af9005_identify_state
  (CVE-2019-18809,bsc#1156258).
- commit 5b09130
* Wed Nov 27 2019 jgross@suse.com
- xen/gntdev: Use select for DMA_SHARED_BUFFER (bsc#1065600).
- commit 97a6782
* Tue Nov 26 2019 mgorman@suse.de
- sched/cpufreq: Move the cfs_rq_util_change() call to
  cpufreq_update_util() (bnc#1155798 (CPU scheduler functional
  and performance backports)).
- sched/pelt: Fix update of blocked PELT ordering (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Add comments for group_type and balancing at
  SD_NUMA level (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/fair: Fix rework of find_idlest_group() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/core: Further clarify sched_class::set_next_task()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Use mul_u32_u32() (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched/core: Simplify sched_class::pick_next_task() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/core: Optimize pick_next_task() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/core: Make pick_next_task_idle() more consistent
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Better document newidle_balance() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair/util_est: Implement faster ramp-up EWMA on
  utilization increases (bnc#1155798 (CPU scheduler functional
  and performance backports)).
- sched/fair: Rework find_idlest_group() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/fair: Optimize find_idlest_group() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/fair: Use load instead of runnable load in wakeup
  path (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Use utilization to select misfit task (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Spread out tasks evenly when not overloaded
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Use load instead of runnable load in load_balance()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Use rq->nr_running when balancing load (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Rework load_balance() (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched/fair: Remove meaningless imbalance calculation
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Rename sg_lb_stats::sum_nr_running to
  sum_h_nr_running (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/fair: Clean up asym packing (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched/topology: Don't set SD_BALANCE_WAKE on cpuset domain
  relax (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit 0c439b5
* Tue Nov 26 2019 nsaenzjulienne@suse.de
- arm64: mm: reserve CMA and crashkernel in ZONE_DMA32
  (jsc#SLE-7772).
- commit 8dd0df2
* Tue Nov 26 2019 aaptel@suse.com
- cifs: move cifsFileInfo_put logic into a work-queue
  (bsc#1154355).
- commit 3fc1ff0
* Tue Nov 26 2019 aaptel@suse.com
- CIFS: Fix SMB2 oplock break processing (bsc#1154355).
- commit 6ea244c
* Tue Nov 26 2019 aaptel@suse.com
- cifs: add a helper to find an existing readable handle to a file
  (bsc#1154355).
- commit 86876f3
* Tue Nov 26 2019 aaptel@suse.com
- smb3: fix signing verification of large reads (bsc#1154355).
- commit 151844a
* Tue Nov 26 2019 aaptel@suse.com
- cifs: use existing handle for compound_op(OP_SET_INFO) when
  possible (bsc#1154355).
- commit bbed94e
* Tue Nov 26 2019 aaptel@suse.com
- cifs: create a helper to find a writeable handle by path name
  (bsc#1154355).
- Refresh
  patches.suse/smb3-improve-handling-of-share-deleted-and-share-recreated-.patch.
- commit b4e2014
* Tue Nov 26 2019 aaptel@suse.com
- smb3: Incorrect size for netname negotiate context
  (bsc#1154355).
- commit 2e876d6
* Tue Nov 26 2019 aaptel@suse.com
- cifs: prepare SMB2_Flush to be usable in compounds
  (bsc#1154355).
- commit 94efab3
* Tue Nov 26 2019 oneukum@suse.com
- libbpf: Fix struct end padding in btf_dump (git-fixes).
- commit 3ff85da
* Tue Nov 26 2019 oneukum@suse.com
- crypto: ecdh - fix big endian bug in ECC library (git-fixes).
- commit 3ed4e6a
* Tue Nov 26 2019 oneukum@suse.com
- crypto: user - fix memory leak in crypto_reportstat (git-fixes).
- commit 11b554d
* Tue Nov 26 2019 oneukum@suse.com
- crypto: user - fix memory leak in crypto_report (git-fixes).
- commit 905d0c3
* Tue Nov 26 2019 oneukum@suse.com
- crypto: af_alg - cast ki_complete ternary op to int (git-fixes).
- commit 62b6457
* Tue Nov 26 2019 oneukum@suse.com
- crypto: algif_skcipher - Use chunksize instead of blocksize
  (git-fixes).
- commit 638ebae
* Tue Nov 26 2019 aaptel@suse.com
- smb3: improve handling of share deleted (and share recreated)
  (bsc#1154355).
- Refresh
  patches.suse/smb3-fix-leak-in-open-on-server-perf-counter.patch.
- commit b021da1
* Tue Nov 26 2019 nsaenzjulienne@suse.de
- PCI: brcmstb: add MSI capability (jsc#SLE-7772).
- PCI: brcmstb: add Broadcom STB PCIe host controller driver
  (jsc#SLE-7772).
- config: arm64: enable RPi4 PCIe controller
- supported.conf: add pcie-brcmstb RPi4's PCIe controller
- linux/log2.h: Add roundup/rounddown_pow_two64() family of
  functions (jsc#SLE-7772).
- commit b2ce31d
* Tue Nov 26 2019 nsaenzjulienne@suse.de
- dma-mapping: treat dev->bus_dma_mask as a DMA limit
  (jsc#SLE-7772).
- dma-direct: exclude dma_direct_map_resource from the min_low_pfn
  check (jsc#SLE-7772).
- dma-direct: avoid a forward declaration for phys_to_dma
  (jsc#SLE-7772).
- dma-direct: unify the dma_capable definitions (jsc#SLE-7772).
- x86/PCI: sta2x11: use default DMA address translation
  (jsc#SLE-7772).
- dma-direct: check for overflows on 32 bit DMA addresses
  (jsc#SLE-7772).
- commit 94cc441
* Tue Nov 26 2019 msuchanek@suse.de
- powerpc/book3s64/hash: Use secondary hash for bolted mapping
  if the primary is full (bsc#1157778 ltc#182520).
- powerpc/pseries: Don't fail hash page table insert for bolted
  mapping (bsc#1157778 ltc#182520).
- powerpc/pseries: Don't opencode HPTE_V_BOLTED (bsc#1157778
  ltc#182520).
- commit b6eca43
* Tue Nov 26 2019 msuchanek@suse.de
- seltests/powerpc: Add a selftest for memcpy_mcsafe (bsc#1157774
  ltc#182579).
- powerpc/memcpy: Fix stack corruption for smaller sizes
  (bsc#1157774 ltc#182579).
- commit 34c7004
* Tue Nov 26 2019 msuchanek@suse.de
- Delete patches.suse/soundwire-depend-on-ACPI-OF.patch.
- Update config files.
- blacklist
- commit b6ee2ab
* Tue Nov 26 2019 nsaenzjulienne@suse.de
- PCI: rcar: Use inbound resources for setup (jsc#SLE-7772).
- PCI: iproc: Use inbound resources for setup (jsc#SLE-7772).
- PCI: xgene: Use inbound resources for setup (jsc#SLE-7772).
- PCI: v3-semi: Use inbound resources for setup (jsc#SLE-7772).
- PCI: ftpci100: Use inbound resources for setup (jsc#SLE-7772).
- PCI: of: Add inbound resource parsing to helpers (jsc#SLE-7772).
- Refresh: patches.suse/PCI-mobiveil-Make-mobiveil_host_init-can-be-used-to-.patch
- Refresh: patches.suse/PCI-mobiveil-Refactor-Mobiveil-PCIe-Host-Bridge-IP-d.patch
- PCI: versatile: Enable COMPILE_TEST (jsc#SLE-7772).
- PCI: versatile: Remove usage of PHYS_OFFSET (jsc#SLE-7772).
- PCI: versatile: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: xilinx-nwl: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: xilinx: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: xgene: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: v3-semi: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: rockchip: Drop storing driver private outbound resource
  data (jsc#SLE-7772).
- PCI: rockchip: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: mobiveil: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- Refresh patches.suse/PCI-mobiveil-Refactor-Mobiveil-PCIe-Host-Bridge-IP-d.patch.
- Refresh: patches.suse/PCI-mobiveil-Make-mobiveil_host_init-can-be-used-to-.patch
- PCI: mediatek: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: iproc: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: faraday: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: dwc: Use pci_parse_request_of_pci_ranges() (jsc#SLE-7772).
- PCI: altera: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: aardvark: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: Export pci_parse_request_of_pci_ranges() (jsc#SLE-7772).
- resource: Add a resource_list_first_type helper (jsc#SLE-7772).
- commit 89f0599
* Tue Nov 26 2019 oneukum@suse.com
- Bluetooth: btusb: fix PM leak in error case of setup
  (git-fixes).
- virtio_console: allocate inbufs in add_port() only if it is
  needed (git-fixes).
- commit 74ff161
* Tue Nov 26 2019 yousaf.kaukab@suse.com
- config: arm64: enable options for nvidia jetson tx1
  References: jsc#SLE-9391
- commit 380d090
* Tue Nov 26 2019 nsaenzjulienne@suse.de
- arm64: mm: Fix unused variable warning in zone_sizes_init
  (jsc#SLE-7772).
- commit 6fb4438
* Tue Nov 26 2019 jlee@suse.com
- Delete
  patches.suse/0041-efi-Lock-down-the-kernel-if-booted-in-secure-boot-mo.patch.
  (jsc#SLE-9870)
  This patch be replaced by
  patches.suse/0003-efi-Lock-down-the-kernel-if-booted-in-secure-boot-mode.patch
- commit 736d395
* Tue Nov 26 2019 jlee@suse.com
- Delete patches.suse/0039-efi-Add-EFI_SECURE_BOOT-bit.patch.
  (jsc#SLE-9870)
  This patch be replaced by
  patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch
- commit 06804cf
* Tue Nov 26 2019 nmoreychaisemartin@suse.com
- RDMA/bnxt_re: Fix stat push into dma buffer on gen p5 devices (bsc#1157115)
- commit fc79fc5
* Tue Nov 26 2019 tiwai@suse.de
- ipmi: Fix memory leak in __ipmi_bmc_register
  (CVE-2019-19046,bsc#1157304).
- spi: lpspi: fix memory leak in fsl_lpspi_probe
  (CVE-2019-19064,bsc#1157300).
- spi: gpio: prevent memory leak in spi_gpio_probe
  (CVE-2019-19070,bsc#1157294).
- mwifiex: pcie: Fix memory leak in mwifiex_pcie_init_evt_ring
  (CVE-2019-19057,bsc#1157193).
- mwifiex: pcie: Fix memory leak in mwifiex_pcie_alloc_cmdrsp_buf
  (CVE-2019-19056,bsc#1157197).
- ath10k: fix memory leak (CVE-2019-19078,bsc#1157032).
- rtl8xxxu: prevent leaking urb (CVE-2019-19068,bsc#1157307).
- rtlwifi: prevent memory leak in rtl_usb_probe
  (CVE-2019-19063,bsc#1157298).
- rsi: release skb if rsi_prepare_beacon fails
  (CVE-2019-19071,bsc#1157067).
- crypto: user - fix memory leak in crypto_reportstat
  (CVE-2019-19050,bsc#1157336).
- crypto: user - fix memory leak in crypto_report
  (CVE-2019-19062,bsc#1157333).
- commit f284309
* Tue Nov 26 2019 jlee@suse.com
- efi: Lock down the kernel at the integrity level if booted in
  secure boot mode (jsc#SLE-9870).
- commit d022ad5
* Tue Nov 26 2019 mkubecek@suse.cz
- series.conf: cleanup
- rename patches.suse/scsi-qla2xxx-fix-wait-condition-in-loop.patch
  to patches.suse/scsi-qla2xxx-fix-NPIV-tear-down-process.patch
  (to match mainline commit subject)
- update upstream references and move into sorted section:
  patches.suse/arm64-Fake-the-IminLine-size-on-systems-affected-by-.patch
  patches.suse/arm64-compat-Workaround-Neoverse-N1-1542419-for-comp.patch
  patches.suse/arm64-errata-Hide-CTR_EL0.DIC-on-systems-affected-by.patch
  patches.suse/libertas-fix-a-potential-NULL-pointer-dereference.patch
  patches.suse/net-ath10k-Fix-a-NULL-ptr-deref-bug.patch
  patches.suse/scsi-qla2xxx-fix-NPIV-tear-down-process.patch
- move out of "almost mainline" section (the patch has been effectively
  rejected in this form):
  patches.suse/ibmveth-Update-ethtool-settings-to-reflect-virtual-p.patch
  No effect on expanded tree.
- commit ab5c717
* Tue Nov 26 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/0001-arm64-mm-use-arm64_dma_phys_limit-instead-of-calling.patch
  patches.suse/0002-arm64-rename-variables-used-to-calculate-ZONE_DMA32-.patch
  patches.suse/0003-arm64-use-both-ZONE_DMA-and-ZONE_DMA32.patch
  patches.suse/0004-mm-refresh-ZONE_DMA-and-ZONE_DMA32-comments-in-enum-.patch
  patches.suse/Bluetooth-hci_bcm-Fix-RTS-handling-during-startup.patch
  patches.suse/net-bcmgenet-Add-BCM2711-support.patch
  patches.suse/net-bcmgenet-Add-RGMII_RXID-support.patch
  patches.suse/net-bcmgenet-Add-a-shutdown-callback.patch
  patches.suse/net-bcmgenet-Avoid-touching-non-existent-interrupt.patch
  patches.suse/net-bcmgenet-Fix-error-handling-on-IRQ-retrieval.patch
  patches.suse/net-bcmgenet-Generate-a-random-MAC-if-none-is-valid.patch
  patches.suse/net-bcmgenet-Refactor-register-access-in-bcmgenet_mi.patch
  No effect on expanded tree.
- commit 6d8a72c
* Tue Nov 26 2019 jlee@suse.com
- efi: Lock down the kernel if booted in secure boot mode
  (jsc#SLE-9870).
- Update config files. (jsc#SLE-9870)
- commit 7f8d57d
* Tue Nov 26 2019 jlee@suse.com
- efi: Add an EFI_SECURE_BOOT flag to indicate secure boot mode
  (jsc#SLE-9870).
- commit 4d3145f
* Tue Nov 26 2019 jlee@suse.com
- security: lockdown: expose a hook to lock the kernel down
  (jsc#SLE-9870).
- commit d2adcd5
* Mon Nov 25 2019 tonyj@suse.de
- perf/x86/intel: Support PEBS output to PT (jsc#SLE-8896).
- perf: Allow normal events to output AUX data (jsc#SLE-8896).
- commit bac2bbc
* Mon Nov 25 2019 mkubecek@suse.cz
- update patch references
  Update Patch-mainline:
  patches.suse/bdi-Add-bdi-id.patch
  patches.suse/fs-fs-writeback.c-fix-kernel-doc-warning.patch
  patches.suse/memcg-only-record-foreign-writebacks-with-dirty-pages-when-memcg-is-not-disabled.patch
  patches.suse/mm-debug.c-PageAnon-is-true-for-PageKsm-pages.patch
  patches.suse/mm-debug.c-__dump_page-prints-an-extra-line.patch
  patches.suse/mm-hmm-fix-hmm_range_fault-s-handling-of-swapped-out-pages.patch
  patches.suse/mm-memcontrol-update-lruvec-counters-in-mem_cgroup_move_account.patch
  patches.suse/mm-memory_hotplug-don-t-access-uninitialized-memmaps-in-shrink_pgdat_span.patch
  patches.suse/mm-memory_hotplug-fix-updating-the-node-span.patch
  patches.suse/mm-move-mem_cgroup_uncharge-out-of-__page_cache_release.patch
  patches.suse/mm-shrinker-make-shrinker-not-depend-on-memcg-kmem.patch
  patches.suse/mm-slab.c-fix-kernel-doc-warning-for-__ksize.patch
  patches.suse/mm-thp-extract-split_queue_-into-a-struct.patch
  patches.suse/mm-thp-make-deferred-split-shrinker-memcg-aware.patch
  patches.suse/writeback-Generalize-and-expose-wb_completion.patch
  patches.suse/writeback-Separate-out-wb_get_lookup-from-wb_get_create.patch
  patches.suse/writeback-fix-use-after-free-in-finish_writeback_work.patch
  patches.suse/writeback-memcg-Implement-cgroup_writeback_by_id.patch
  patches.suse/writeback-memcg-Implement-foreign-dirty-flushing.patch
- commit c99b532
* Mon Nov 25 2019 tiwai@suse.de
- Update patch reference for mlx5 driver fix (CVE-2019-19047 bsc#1157715)
- commit 9e3d31d
* Mon Nov 25 2019 tiwai@suse.de
- Update patch reference for vbox driver fix (CVE-2019-19048 bsc#1157720)
- commit a46881b
* Mon Nov 25 2019 mgorman@suse.de
- mm/memory_hotplug: fix updating the node span (git fixes
  (mm/memcontrol)).
- fs/fs-writeback.c: fix kernel-doc warning (git fixes
  (mm/memcontrol)).
- memcg: only record foreign writebacks with dirty pages when
  memcg is not disabled (git fixes (mm/memcontrol)).
- writeback: fix use-after-free in finish_writeback_work()
  (git fixes (mm/memcontrol)).
- commit cdafbd8
* Mon Nov 25 2019 msuchanek@suse.de
- powerpc/bpf: Fix tail call implementation (bsc#1157698).
- commit 68da2db
* Mon Nov 25 2019 mgorman@suse.de
- writeback, memcg: Implement cgroup_writeback_by_id() (git fixes
  (mm/memcontrol)).
- writeback: Separate out wb_get_lookup() from wb_get_create()
  (git fixes (mm/memcontrol)).
- bdi: Add bdi->id (git fixes (mm/memcontrol)).
- writeback: Generalize and expose wb_completion (git fixes
  (mm/memcontrol)).
- commit 14fbce3
* Mon Nov 25 2019 mgorman@suse.de
- mm/ksm.c: don't WARN if page is still mapped in
  remove_stable_node() (git fixes (mm/ksm).
- commit 89108e1
* Mon Nov 25 2019 mgorman@suse.de
- mm/memory_hotplug: don't access uninitialized memmaps in
  shrink_zone_span() (git fixes (mm/hotplug)).
- commit 990c666
* Mon Nov 25 2019 mgorman@suse.de
- mm/debug.c: PageAnon() is true for PageKsm() pages (git fixes
  (mm/debug)).
- mm/debug.c: __dump_page() prints an extra line (git fixes
  (mm/debug)).
- commit c8d910e
* Mon Nov 25 2019 mgorman@suse.de
- mm/memcontrol: update lruvec counters in mem_cgroup_move_account
  (git fixes (mm/memcontrol)).
- mm: thp: make deferred split shrinker memcg aware (git fixes
  (mm/memcontrol)).
- mm: shrinker: make shrinker not depend on memcg kmem (git fixes
  (mm/memcontrol)).
- mm: move mem_cgroup_uncharge out of __page_cache_release()
  (git fixes (mm/memcontrol)).
- mm: thp: extract split_queue_* into a struct (git fixes
  (mm/memcontrol)).
- writeback, memcg: Implement foreign dirty flushing (git fixes
  (mm/memcontrol)).
- commit 0f63fa2
* Mon Nov 25 2019 mgorman@suse.de
- mm/memory_hotplug: don't access uninitialized memmaps in
  shrink_pgdat_span() (git fixes (mm/hotplug)).
- commit 3e5e1ed
* Mon Nov 25 2019 mgorman@suse.de
- mm/slab.c: fix kernel-doc warning for __ksize() (git fixes
  (mm/slab)).
- commit 5cc4ee9
* Mon Nov 25 2019 mgorman@suse.de
- mm/hmm: fix hmm_range_fault()'s handling of swapped out pages
  (git fixes (mm/hmm)).
- commit c8ec9ab
* Mon Nov 25 2019 jslaby@suse.cz
- drm/i915/userptr: Try to acquire the page lock around
  set_page_dirty() (bnc#1156537).
- commit 60d22de
* Mon Nov 25 2019 tbogendoerfer@suse.de
- net-ipv6: IPV6_TRANSPARENT - check NET_RAW prior to NET_ADMIN
  (bsc#1154353).
- sfc: Only cancel the PPS workqueue if it exists (jsc#SLE-8314).
- net-sysfs: fix netdev_queue_add_kobject() breakage
  (bsc#1154353).
- net/mlxfw: Verify FSM error code translation doesn't exceed
  array size (jsc#SLE-8464).
- net/mlx5: Update the list of the PCI supported devices
  (jsc#SLE-8464).
- net/mlx5: Fix auto group size calculation (jsc#SLE-8464).
- net/mlx5e: Add missing capability bit check for IP-in-IP
  (jsc#SLE-8464).
- net/mlx5e: Do not use non-EXT link modes in EXT mode
  (jsc#SLE-8464).
- net/mlx5e: Fix set vf link state error flow (jsc#SLE-8464).
- net/mlx5: DR, Limit STE hash table enlarge based on bytemask
  (jsc#SLE-8464).
- net/mlx5: DR, Skip rehash for tables with byte mask zero
  (jsc#SLE-8464).
- net/mlx5: DR, Fix invalid EQ vector number on CQ creation
  (jsc#SLE-8464).
- net/mlx5e: Reorder mirrer action parsing to check for encap
  first (jsc#SLE-8464).
- net/mlx5e: Fix ingress rate configuration for representors
  (jsc#SLE-8464).
- net/mlx5e: Fix error flow cleanup in
  mlx5e_tc_tun_create_header_ipv4/6 (jsc#SLE-8464).
- ipv6/route: return if there is no fib_nh_gw_family
  (bsc#1154353).
- net-sysfs: Fix reference count leak in
  rx|netdev_queue_add_kobject (bsc#1154353).
- net: hns3: fix a wrong reset interrupt status mask
  (bsc#1154353).
- net/sched: act_pedit: fix WARN() in the traffic path
  (bsc#1154353).
- net: phylink: fix link mode modification in PHY mode
  (bsc#1154353).
- net: phylink: update documentation on create and destroy
  (bsc#1154353).
- taprio: don't reject same mqprio settings (bsc#1154353).
- net/tls: enable sk_msg redirect to tls socket egress
  (bsc#1154353).
- gve: fix dma sync bug where not all pages synced (bsc#1154353).
- net/mlx4_en: Fix wrong limitation for number of TX rings
  (jsc#SLE-8460).
- net: sched: ensure opts_len <= IP_TUNNEL_OPTS_MAX in
  act_tunnel_key (bsc#1154353).
- mlxsw: spectrum_router: Fix determining underlay for a GRE
  tunnel (bsc#1154488).
- net/mlx4_en: fix mlx4 ethtool -N insertion (jsc#SLE-8460).
- net: hns3: cleanup of stray struct hns3_link_mode_mapping
  (bsc#1154353).
- net: hns3: fix ETS bandwidth validation bug (bsc#1154353).
- net: hns3: reallocate SSU' buffer size when pfc_en changes
  (bsc#1154353).
- net: hns3: add compatible handling for MAC VLAN switch parameter
  configuration (bsc#1154353).
- RDMA/hns: Correct the value of srq_desc_size (jsc#SLE-8449).
- RDMA/hns: Correct the value of HNS_ROCE_HEM_CHUNK_LEN
  (jsc#SLE-8449).
- ixgbe: need_wakeup flag might not be set for Tx (jsc#SLE-7979
  jsc#SLE-7981).
- i40e: need_wakeup flag might not be set for Tx (jsc#SLE-8025).
- igb/igc: use ktime accessors for skb->tstamp (jsc#SLE-7967
  jsc#SLE-8010 jsc#SLE-7966).
- i40e: Fix for ethtool -m issue on X722 NIC (jsc#SLE-8025).
- iavf: initialize ITRN registers with correct values
  (jsc#SLE-7940).
- ice: fix potential infinite loop because loop counter being
  too small (jsc#SLE-7926).
- net: hns3: add compatible handling for command
  HCLGE_OPC_PF_RST_DONE (bsc#1154353).
- net/mlx5e: Use correct enum to determine uplink port
  (jsc#SLE-8464).
- net/mlx5: DR, Fix memory leak during rule creation
  (jsc#SLE-8464).
- net/mlx5: DR, Fix memory leak in modify action destroy
  (jsc#SLE-8464).
- net/mlx5e: Fix eswitch debug print of max fdb flow
  (jsc#SLE-8464).
- bridge: ebtables: don't crash when using dnat target in output
  chains (bsc#1154353).
- mlx4_core: fix wrong comment about the reason of subtract one
  from the max_cqes (jsc#SLE-8460).
- net: hns3: Use the correct style for SPDX License Identifier
  (bsc#1154353).
- taprio: fix panic while hw offload sched list swap
  (bsc#1154353).
- net: sched: taprio: fix -Wmissing-prototypes warnings
  (bsc#1154353).
- net: update net_dim documentation after rename (bsc#1154353).
- net: taprio: Fix returning EINVAL when configuring without flags
  (bsc#1154353).
- taprio: Add support for hardware offloading (bsc#1154353).
- taprio: remove unused variable 'entry_list_policy'
  (bsc#1154353).
- commit 3090b61
* Mon Nov 25 2019 jslaby@suse.cz
- Linux 5.3.13 (bnc#1151927 5.3.13).
- arm64: uaccess: Ensure PAN is re-enabled after unhandled
  uaccess fault (bnc#1151927 5.3.13).
- net: cdc_ncm: Signedness bug in cdc_ncm_set_dgram_size()
  (bnc#1151927 5.3.13).
- block, bfq: deschedule empty bfq_queues not referred by any
  process (bnc#1151927 5.3.13).
- mm/memory_hotplug: fix updating the node span (bnc#1151927
  5.3.13).
- mm/memory_hotplug: don't access uninitialized memmaps in
  shrink_pgdat_span() (bnc#1151927 5.3.13).
- fbdev: Ditch fb_edid_add_monspecs (bnc#1151927 5.3.13).
- commit 0c2740a
* Mon Nov 25 2019 mbrugger@suse.com
- driver core: simplify definitions of platform_get_irq*
  (jsc#SLE-7772).
- mm: refresh ZONE_DMA and ZONE_DMA32 comments in 'enum zone_type'
  (jsc#SLE-7772).
- arm64: use both ZONE_DMA and ZONE_DMA32 (jsc#SLE-7772).
  Enable CONFIG_ZONE_DMA and CONFIG_BOUNCE
- arm64: rename variables used to calculate ZONE_DMA32's size
  (jsc#SLE-7772).
- arm64: mm: use arm64_dma_phys_limit instead of calling
  max_zone_dma_phys() (jsc#SLE-7772).
- net: bcmgenet: Add RGMII_RXID support (jsc#SLE-7772).
- net: bcmgenet: Refactor register access in bcmgenet_mii_config
  (jsc#SLE-7772).
- net: bcmgenet: Add BCM2711 support (jsc#SLE-7772).
- net: bcmgenet: Fix error handling on IRQ retrieval
  (jsc#SLE-7772).
- net: bcmgenet: Avoid touching non-existent interrupt
  (jsc#SLE-7772).
- Bluetooth: hci_bcm: Fix RTS handling during startup
  (jsc#SLE-7772).
- net: bcmgenet: Add a shutdown callback (jsc#SLE-7772).
- net: bcmgenet: Generate a random MAC if none is valid
  (jsc#SLE-7772).
- clocksource/drivers/sh_mtu2: Do not loop using
  platform_get_irq_by_name() (jsc#SLE-7772).
- net: bcmgenet: reapply manual settings to the PHY
  (jsc#SLE-7772).
- Revert "net: bcmgenet: soft reset 40nm EPHYs before MAC init"
  (jsc#SLE-7772).
- net: bcmgenet: use RGMII loopback for MAC reset (jsc#SLE-7772).
- iommu/ipmmu-vmsa: Only call platform_get_irq() when interrupt
  is mandatory (jsc#SLE-7772).
- iommu/rockchip: Don't use platform_get_irq to implicitly count
  irqs (jsc#SLE-7772).
- mmc: sdhci-iproc: fix spurious interrupts on Multiblock reads
  with bcm2711 (jsc#SLE-7772).
- mmc: sh_mmcif: Use platform_get_irq_optional() for optional
  interrupt (jsc#SLE-7772).
- mmc: renesas_sdhi: Do not use platform_get_irq() to count
  interrupts (jsc#SLE-7772).
- platform/x86: intel_punit_ipc: Avoid error message when
  retrieving IRQ (jsc#SLE-7772).
- tty: serial: imx: Use platform_get_irq_optional() for optional
  IRQs (jsc#SLE-7772).
- serial: sh-sci: Use platform_get_irq_optional() for optional
  interrupts (jsc#SLE-7772).
- clk: bcm2835: Mark PLLD_PER as CRITICAL (jsc#SLE-7772).
- clk: bcm2835: Add BCM2711_CLOCK_EMMC2 support (jsc#SLE-7772).
- clk: bcm2835: Introduce SoC specific clock registration
  (jsc#SLE-7772).
- dt-bindings: bcm2835-cprman: Add bcm2711 support (jsc#SLE-7772).
- pinctrl: bcm2835: Pass irqchip when adding gpiochip
  (jsc#SLE-7772).
- pinctrl: bcm2835: Add support for BCM2711 pull-up functionality
  (jsc#SLE-7772).
- bluetooth: hci_bcm: Give more time to come out of reset
  (jsc#SLE-7772).
- bluetooth: bcm: Add support for loading firmware for BCM4345C5
  (jsc#SLE-7772).
- Bluetooth: hci_bcm: Fix -Wunused-const-variable warnings
  (jsc#SLE-7772).
- net: bcmgenet: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-7772).
- driver core: platform: Export platform_get_irq_optional()
  (jsc#SLE-7772).
- driver core: platform: Introduce platform_get_irq_optional()
  (jsc#SLE-7772).
- driver core: platform: Add an error message to
  platform_get_irq*() (jsc#SLE-7772).
- mmc: bcm2835: Take SWIOTLB memory size limitation into account
  (jsc#SLE-7772).
- mmc: Remove dev_err() usage after platform_get_irq()
  (jsc#SLE-7772).
- mmc: sdhci-iproc: Add support for emmc2 of the BCM2711
  (jsc#SLE-7772).
- commit 24df065
* Mon Nov 25 2019 glin@suse.com
- bpf, offload: Unlock on error in bpf_offload_dev_create()
  (bsc#1155518).
- commit dc0b929
* Fri Nov 22 2019 mkubecek@suse.cz
- config: refresh
  Just unify the headers.
- commit f54dfa4
* Fri Nov 22 2019 jslaby@suse.cz
- Refresh
  patches.suse/btrfs-fix-log-context-list-corruption-after-rename-e.patch.
  Update upstream status.
- commit 9923f87
* Fri Nov 22 2019 jslaby@suse.cz
- Linux 5.3.12 (bnc#1151927 5.3.12).
- iommu/vt-d: Fix QI_DEV_IOTLB_PFSID and QI_DEV_EIOTLB_PFSID
  macros (bnc#1151927 5.3.12).
- i2c: acpi: Force bus speed to 400KHz if a Silead touchscreen
  is present (bnc#1151927 5.3.12).
- x86/quirks: Disable HPET on Intel Coffe Lake platforms
  (bnc#1151927 5.3.12).
- net/smc: fix fastopen for non-blocking connect() (bnc#1151927
  5.3.12).
- net: gemini: add missed free_netdev (bnc#1151927 5.3.12).
- ax88172a: fix information leak on short answers (bnc#1151927
  5.3.12).
- slcan: Fix memory leak in error path (bnc#1151927 5.3.12).
- slip: Fix memory leak in slip_open error path (bnc#1151927
  5.3.12).
- net: usb: qmi_wwan: add support for Foxconn T77W968 LTE modules
  (bnc#1151927 5.3.12).
- dpaa2-eth: free already allocated channels on probe defer
  (bnc#1151927 5.3.12).
- net/smc: fix refcount non-blocking connect() -part 2
  (bnc#1151927 5.3.12).
- mlxsw: core: Enable devlink reload only on probe (bnc#1151927
  5.3.12).
- devlink: Add method for time-stamp on reporter's dump
  (bnc#1151927 5.3.12).
- tcp: remove redundant new line from tcp_event_sk_skb
  (bnc#1151927 5.3.12).
- devlink: disallow reload operation during device cleanup
  (bnc#1151927 5.3.12).
- mm/page_io.c: do not free shared swap slots (bnc#1151927
  5.3.12).
- mm/memory_hotplug: fix try_offline_node() (bnc#1151927 5.3.12).
- mm: slub: really fix slab walking for init_on_free (bnc#1151927
  5.3.12).
- mm: hugetlb: switch to css_tryget() in
  hugetlb_cgroup_charge_cgroup() (bnc#1151927 5.3.12).
- mm: memcg: switch to css_tryget() in get_mem_cgroup_from_mm()
  (bnc#1151927 5.3.12).
- mm: mempolicy: fix the wrong return value and potential pages
  leak of mbind (bnc#1151927 5.3.12).
- Input: synaptics-rmi4 - destroy F54 poller workqueue when
  removing (bnc#1151927 5.3.12).
- Input: ff-memless - kill timer in destroy() (bnc#1151927
  5.3.12).
- io_uring: ensure registered buffer import returns the IO length
  (bnc#1151927 5.3.12).
- drm/i915: update rawclk also on resume (bnc#1151927 5.3.12).
- ecryptfs_lookup_interpose(): lower_dentry->d_parent is not
  stable either (bnc#1151927 5.3.12).
- ecryptfs_lookup_interpose(): lower_dentry->d_inode is not stable
  (bnc#1151927 5.3.12).
- IB/hfi1: TID RDMA WRITE should not return
  IB_WC_RNR_RETRY_EXC_ERR (bnc#1151927 5.3.12).
- IB/hfi1: Calculate flow weight based on QP MTU for TID RDMA
  (bnc#1151927 5.3.12).
- IB/hfi1: Ensure r_tid_ack is valid before building TID RDMA
  ACK packet (bnc#1151927 5.3.12).
- IB/hfi1: Ensure full Gen3 speed in a Gen4 system (bnc#1151927
  5.3.12).
- Input: synaptics-rmi4 - clear IRQ enables for F54 (bnc#1151927
  5.3.12).
- Input: synaptics-rmi4 - do not consume more data than we have
  (F11, F12) (bnc#1151927 5.3.12).
- Input: synaptics-rmi4 - disable the relative position IRQ in
  the F12 driver (bnc#1151927 5.3.12).
- KVM: MMU: Do not treat ZONE_DEVICE pages as being reserved
  (bnc#1151927 5.3.12).
- cgroup: freezer: call cgroup_enter_frozen() with preemption
  disabled in ptrace_stop() (bnc#1151927 5.3.12).
- scsi: core: Handle drivers which set sg_tablesize to zero
  (bnc#1151927 5.3.12).
- commit 5f76c3b
* Fri Nov 22 2019 jslaby@suse.cz
- Update
  patches.suse/0003-Revert-drm-i915-ehl-Update-MOCS-table-for-EHL.patch
  (bsc#1152489 bnc#1151927 5.3.12).
- Update
  patches.suse/ALSA-usb-audio-Fix-incorrect-NULL-check-in-create_ya.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/ALSA-usb-audio-Fix-incorrect-size-check-for-processi.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/ALSA-usb-audio-Fix-missing-error-check-at-mixer-reso.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/ALSA-usb-audio-not-submit-urb-for-stopped-endpoint.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/IB-hfi1-Use-a-common-pad-buffer-for-9B-and-16B-packe.patch
  (jsc#SLE-8449 bnc#1151927 5.3.12).
- Update
  patches.suse/Input-synaptics-rmi4-fix-video-buffer-size.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/btrfs-fix-log-context-list-corruption-after-rename-e.patch
  (bsc#1156494 bnc#1151927 5.3.12).
- Update
  patches.suse/ipmr-Fix-skb-headroom-in-ipmr_get_route.patch
  (git-fixes bnc#1151927 5.3.12).
- Update patches.suse/mmc-sdhci-of-at91-fix-quirk2-overwrite.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/net-ethernet-dwmac-sun8i-Use-the-correct-function-in.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/ntp-y2038-Remove-incorrect-time_t-truncation.patch
  (git-fixes bnc#1151927 5.3.12).
- commit 4df5d22
* Thu Nov 21 2019 lpechacek@suse.com
- Add crypto modules required by tcrypt (FIPS)
  References: bsc#1153192
- commit 465a0e6
* Wed Nov 20 2019 msuchanek@suse.de
- Refresh patches.suse/scsi-sr-wait-for-the-medium-to-become-ready.patch.
  Fix refleak on -ENXIO.
- commit c02819b
* Wed Nov 20 2019 tiwai@suse.de
- mdio_bus: Fix init if CONFIG_RESET_CONTROLLER=n (git-fixes).
- opp: Reinitialize the list_kref before adding the static OPPs
  again (git-fixes).
- commit 61e3e2f
* Wed Nov 20 2019 tiwai@suse.de
- lib: Remove select of inexistant GENERIC_IO (git-fixes).
- opp: Don't decrement uninitialized list_kref (git-fixes).
- opp: Not all power-domains are scalable (git-fixes).
- commit 85c2a10
* Wed Nov 20 2019 tiwai@suse.de
- software node: Initialize the return value in
  software_node_to_swnode() (git-fixes).
- commit e35cf03
* Wed Nov 20 2019 tiwai@suse.de
- selftests: mlxsw: Adjust test to recent changes (git-fixes).
- selftests: bpf: Skip write only files in debugfs (git-fixes).
- selftests/bpf: fix race in flow dissector tests (git-fixes).
- commit 7648c5c
* Wed Nov 20 2019 tiwai@suse.de
- riscv: fp: add missing __user pointer annotations (git-fixes).
- riscv: init: merge split string literals in preprocessor
  directive (git-fixes).
- riscv: tlbflush: remove confusing comment on
  local_flush_tlb_all() (git-fixes).
- commit d38ab66
* Wed Nov 20 2019 tiwai@suse.de
- ntp/y2038: Remove incorrect time_t truncation (git-fixes).
- NFC: nxp-nci: Fix NULL pointer dereference after I2C
  communication error (git-fixes).
- commit 0b6da77
* Wed Nov 20 2019 tiwai@suse.de
- ipmr: Fix skb headroom in ipmr_get_route() (git-fixes).
- mdio_bus: Fix PTR_ERR applied after initialization to constant
  (git-fixes).
- net: ethernet: dwmac-sun8i: Use the correct function in exit
  path (git-fixes).
- idr: Fix idr_get_next_ul race with idr_remove (git-fixes).
- commit b4c1f6c
* Wed Nov 20 2019 tiwai@suse.de
- i2c: core: fix use after free in of_i2c_notify (git-fixes).
- commit d2cbfd2
* Wed Nov 20 2019 tiwai@suse.de
- arm64: hibernate: check pgd table allocation (git-fixes).
- arm64: cpufeature: Treat ID_AA64ZFR0_EL1 as RAZ when SVE is
  not enabled (git-fixes).
- ARM: aspeed: ast2500 is ARMv6K (git-fixes).
- ARM: 8896/1: VDSO: Don't leak kernel addresses (git-fixes).
- ARM: ux500: add missing of_node_put() (git-fixes).
- commit cb4b4ca
* Wed Nov 20 2019 tiwai@suse.de
- Update patch reference for nl80211 fix (CVE-2019-19055 bsc#1157319)
- commit f616ca4
* Wed Nov 20 2019 tiwai@suse.de
- Update patch reference for can driver fix (CVE-2019-19052 bsc#1157324)
- commit 02e7eba
* Wed Nov 20 2019 bp@suse.de
- x86/resctrl: Fix potential lockdep warning (bsc#1152489).
- x86/resctrl: Prevent NULL pointer dereference when reading
  mondata (bsc#1152489).
- commit c754fb9
* Tue Nov 19 2019 tiwai@suse.de
- Update patch reference for another iio driver fix (CVE-2019-19061 bsc#1157192)
- commit 75969fc
* Tue Nov 19 2019 tiwai@suse.de
- Update s390 patch reference for cpu idle time calculation (bsc#1156773)
- commit 71d745b
* Tue Nov 19 2019 tiwai@suse.de
- Update patch reference for amdgpu fix (CVE-2019-19067 bsc#1157180)
- commit 294533e
* Tue Nov 19 2019 tiwai@suse.de
- Update patch reference for iio driver fix (CVE-2019-19060 bsc#1157178)
- commit 572806f
* Tue Nov 19 2019 tiwai@suse.de
- Update patch reference for of-unittest fix (CVE-2019-19049 bsc#1157173)
- commit 6bfcd8f
* Tue Nov 19 2019 tiwai@suse.de
- Update patch reference for ieee802154 security fix (CVE-2019-19075 bsc#1157162)
- commit 0855aff
* Tue Nov 19 2019 pmladek@suse.com
- tracing: Have error path in predicate_parse() free its allocated
  memory (bsc#1157069 CVE-2019-19072).
- commit 387f713
* Tue Nov 19 2019 tiwai@suse.de
- iwlwifi: dbg_ini: fix memory leak in alloc_sgtable
  (CVE-2019-19058,bsc#1157145).
- commit cb8333d
* Tue Nov 19 2019 tiwai@suse.de
- ath9k: release allocated buffer if timed out
  (CVE-2019-19074,bsc#1157143).
- commit 98c32c1
* Tue Nov 19 2019 tzimmermann@suse.de
- Revert "drm/etnaviv: fix dumping of iommuv2 (bsc#1152472)"
  This reverts commit 48b3bfdd21261e7df15f5aebe2ccb1cc61521bd0.
  ATM the backported patch doesn't build on arm64.
- commit c35e5f9
* Tue Nov 19 2019 dwagner@suse.de
- Drop scsi-qla2xxx-Fix-memory-leak-when-sending-I-O-fails.patch
  This patch has introduces an double free. Upstream has dropped it from
  the scsi-queue before it hit mainline. So let's drop it as well.
- commit 44fa42b
* Mon Nov 18 2019 tiwai@suse.de
- ath9k_htc: release allocated buffer if timed out
  (CVE-2019-19073,bsc#1157070).
- commit 08bd2bd
* Mon Nov 18 2019 tiwai@suse.de
- Update patch reference for fastrpc bug fix (CVE-2019-19069 bsc#1157064)
- commit 69da730
* Mon Nov 18 2019 tiwai@suse.de
- Update patch reference for amdgpu security fix (CVE-2019-19083 bsc#1157049)
- commit 7f52050
* Mon Nov 18 2019 tiwai@suse.de
- drm/amd/display: prevent memory leak
  (CVE-2019-19082,bsc#1157046).
- commit fca18a5
* Mon Nov 18 2019 tzimmermann@suse.de
- Revert "drm/i915/ehl: Update MOCS table for EHL" (bsc#1152489)
- commit 76a5ebd
* Mon Nov 18 2019 tzimmermann@suse.de
- drm/i915/gvt: fix dropping obj reference twice (bsc#1152489)
- commit 4f5c644
* Mon Nov 18 2019 tzimmermann@suse.de
- drm/etnaviv: fix dumping of iommuv2 (bsc#1152472)
- commit 48b3bfd
* Sat Nov 16 2019 tiwai@suse.de
- mmc: sdhci-of-at91: fix quirk2 overwrite (git-fixes).
- Input: synaptics-rmi4 - fix video buffer size (git-fixes).
- commit 22c351b
* Fri Nov 15 2019 tiwai@suse.de
- ALSA: usb-audio: Fix incorrect size check for
  processing/extension units (git-fixes).
- ALSA: usb-audio: Fix incorrect NULL check in
  create_yamaha_midi_quirk() (git-fixes).
- ALSA: pcm: Fix stream lock usage in snd_pcm_period_elapsed()
  (git-fixes).
- ALSA: usb-audio: not submit urb for stopped endpoint
  (git-fixes).
- ALSA: hda: hdmi - fix pin setup on Tigerlake (git-fixes).
- ALSA: hda: Add Cometlake-S PCI ID (git-fixes).
- ALSA: usb-audio: Fix missing error check at mixer resolution
  test (git-fixes).
- commit 8e17c40
* Fri Nov 15 2019 msuchanek@suse.de
- powerpc/xive: Prevent page fault issues in the machine crash
  handler (bsc#1156882 ltc#182435).
- commit 7d95bd5
* Thu Nov 14 2019 msuchanek@suse.de
- Refresh patches.suse/bdev-add-open_finish.patch.
- commit 687caa9
* Thu Nov 14 2019 mkubecek@suse.cz
- supported.conf: drop dax_pmem_compat
  This module is no longer built (jsc#SLE-10690).
- commit 359a9f7
* Thu Nov 14 2019 fdmanana@suse.com
- Btrfs: remove unnecessary condition in btrfs_clone() to avoid
  too much nesting (bsc#1156782).
- commit 4154585
* Thu Nov 14 2019 fdmanana@suse.com
- Btrfs: fix ENOSPC errors, leading to transaction aborts,
  when cloning extents (bsc#1156782).
- commit 6466273
* Thu Nov 14 2019 fdmanana@suse.com
- Btrfs: factor out extent dropping code from hole punch handler
  (bsc#1156782).
- commit 037e1c6
* Thu Nov 14 2019 hare@suse.de
- scsi: virtio_scsi: unplug LUNs when events missed
  (bsc#1156419,jsc#SLE-8281).
- scsi: fcoe: fix null-ptr-deref Read in fc_release_transport
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs-hisi: use devm_platform_ioremap_resource() to
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufshcd: use devm_platform_ioremap_resource() to
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: use devm_platform_ioremap_resource() to
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Use kmemdup in ufshcd_read_string_desc()
  (bsc#1156419,jsc#SLE-8281).
- scsi: arm64: dts: qcom: sdm845: Specify UFS device-reset GPIO
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs-qcom: Implement device_reset vops
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Introduce vops for resetting device
  (bsc#1156419,jsc#SLE-8281).
- scsi: sd: Improve unaligned completion resid message
  (bsc#1156419,jsc#SLE-8281).
- scsi: fnic: fix msix interrupt allocation
  (bsc#1156419,jsc#SLE-8281).
- scsi: fnic: print port speed only at driver init or speed
  (bsc#1156419,jsc#SLE-8281).
- commit fdbb6dd
* Thu Nov 14 2019 hare@suse.de
- scsi: core: fix dh and multipathing for SCSI hosts without
  request batching (bsc#1156419,jsc#SLE-8281).
- scsi: core: fix missing .cleanup_rq for SCSI hosts without
  request batching (bsc#1156419,jsc#SLE-8281).
- commit add131d
* Thu Nov 14 2019 hare@suse.de
- scsi: ufs: remove set but not used variable 'val'
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: remove set but not used variable 'irq_value'
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: fix broken hba->outstanding_tasks
  (bsc#1156419,jsc#SLE-8281).
- scsi: fcoe: remove redundant call to skb_transport_header
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Disable local LCC in .link_startup_notify() in
  Cadence UFS (bsc#1156419,jsc#SLE-8281).
- scsi: bfa: remove redundant assignment to variable error
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs-qcom: Make structure ufs_hba_qcom_vops constant
  (bsc#1156419,jsc#SLE-8281).
- scsi: fnic: remove redundant assignment of variable rc
  (bsc#1156419,jsc#SLE-8281).
- scsi: use __u{8,16,32,64} instead of uint{8,16,32,64}_t in
  uapi headers (bsc#1156419,jsc#SLE-8281).
- scsi: esas2r: Prefer pcie_capability_read_word()
  (bsc#1156419,jsc#SLE-8281).
- scsi: sym53c8xx_2: remove redundant assignment to retv
  (bsc#1156419,jsc#SLE-8281).
- scsi: pmcraid: Fix a typo - pcmraid --> pmcraid
  (bsc#1156419,jsc#SLE-8281).
- commit 6f40ae3
* Thu Nov 14 2019 hare@suse.de
- Update config files: disable CONFIG_DEV_DAX_PMEM_COMPAT (jsc#SLE-10690)
- commit 56d1ae7
* Thu Nov 14 2019 hare@suse.de
- scsi: lpfc: Update lpfc version to 12.6.0.2
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: revise nvme max queues to be hdwq count
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Initialize cpu_map for not present cpus
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix inlining of lpfc_sli4_cleanup_poll_list()
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix: Coverity: lpfc_cmpl_els_rsp(): Null pointer
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix: Coverity: lpfc_get_scsi_buf_s3(): Null
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix lpfc_cpumask_of_node_init()
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix a kernel warning triggered by
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.6.0.1
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Add enablement of multiple adapter dumps
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Change default IRQ model on AMD architectures
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Add registration for CPU Offline/Online events
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Clarify FAWNN error message
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Sync with FC-NVMe-2 SLER change to require Conf
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix dynamic fw log enablement check
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix unexpected error messages during RSCN
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix kernel crash at lpfc_nvme_info_show during
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix configuration of BB credit recovery in
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix duplicate unreg_rpi error in port offline
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Make lpfc_debugfs_ras_log_data static
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix NULL check before mempool_destroy is not
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix spelling error in MAGIC_NUMER_xxx
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix build error of lpfc_debugfs.c for
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: lpfc_nvmet: Fix Use plain integer as NULL pointer
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: lpfc_attr: Fix Use plain integer as NULL pointer
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.6.0.0
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Add additional discovery log messages
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Add FC-AL support to lpe32000 models
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Add FA-WWN Async Event reporting
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Add log macros to allow print by serverity or
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Make FW logging dynamically configurable
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Revise interrupt coalescing for missing scenarios
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Remove lock contention target write path
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Slight fast-path performance optimizations
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix coverity error of dereference after null
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix hardlockup in lpfc_abort_handler
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix bad ndlp ptr in xri aborted handling
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix SLI3 hba in loop mode not discovering devices
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix lockdep errors in sli_ringtx_put
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix reporting of read-only fw error errors
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix lpfc_nvmet_mrq to be bound by hdw queue count
  (bsc#1156632,jsc#SLE-8654).
- scsi: megaraid_sas: remove unused variables 'debugBlk','fusion'
  (bsc#1156632,jsc#SLE-10720).
- scsi: megaraid_sas: Unique names for MSI-X vectors
  (bsc#1156632,jsc#SLE-10720).
- scsi: smartpqi: bump version to 1.2.10-025
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: Align driver syntax with oob
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: remove unused manifest constants
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: fix problem with unique ID for physical
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: correct syntax issue (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: change TMF timeout from 60 to 30 seconds
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: fix LUN reset when fw bkgnd thread is hung
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add inquiry timeouts (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: fix call trace in device discovery
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: fix controller lockup observed during force
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: remove set but not used variable 'ctrl_info'
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: clean up indentation of a statement
  (bsc#1156632,jsc#SLE-8633).
- scsi: mpt3sas: Bump mpt3sas driver version to 32.100.00.00
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Fix module parameter max_msix_vectors
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Reject NVMe Encap cmnds to unsupported HBA
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Use Component img header to get Package ver
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Fail release cmnd if diag buffer is released
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Add app owned flag support for diag buffer
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Reuse diag buffer allocated at load time
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: clear release bit when buffer reregistered
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Maintain owner of buffer through UniqueID
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Free diag buffer without any status check
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Fix clear pending bit in ioctl status
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Display message before releasing diag buffer
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Register trace buffer based on NVDATA settings
  (bsc#1156632,jsc#SLE-10717).
- scsi: bnx2fc: Handle scope bits when array returns BUSY or
  (jsc#SLE-9696).
- scsi: bnx2fc: remove set but not used variables (jsc#SLE-9696).
- scsi: bnx2fc: remove set but not used variable 'fh'
  (jsc#SLE-9696).
- scsi: smartpqi: bump version to 1.2.8-026
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: update copyright (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add new pci ids (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: correct REGNEWD return status
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add gigabyte controller
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: correct hang when deleting 32 lds
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add bay identifier (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add sysfs entries (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add module param to hide vsep
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add pci ids for fiberhome controller
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add module param for exposure order
  (bsc#1156632,jsc#SLE-8633).
- scsi: mpt3sas: Introduce module parameter to override queue
  depth (bsc#1156632,jsc#SLE-10717).
- scsi: csiostor: Prefer pcie_capability_read_word()
  (jsc#SLE-9687).
- scsi: megaraid_sas: Introduce module parameter for default
  queue depth (bsc#1156632,jsc#SLE-10720).
- scsi: mpt3sas: Update driver version to 31.100.00.00
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Run SAS DEVICE STATUS CHANGE EVENT from ISR
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Reduce the performance drop
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Handle fault during HBA initialization
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Add sysfs to know supported features
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Support MEMORY MOVE Tool box command
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Allow ioctls to blocked access status NVMe
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Enumerate SES of a managed PCIe switch
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Update MPI headers to 2.6.8 spec
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Gracefully handle online firmware update
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: memset request frame before reusing
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Add support for PCIe Lane margin
  (bsc#1156632,jsc#SLE-10717).
- scsi: pm80xx: remove redundant assignments to variable rc
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Consolidate internal abort calls in LU reset
  operation (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: replace "%%p" with "%%pK"
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Remove some unnecessary code
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Modify return type of debugfs functions
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Drop free_irq() when devm_request_irq() failed
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Drop SMP resp frame DMA mapping
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Drop kmap_atomic() in SMP command completion
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Make slot buf minimum allocation of PAGE_SIZE
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Don't bother clearing status buffer IU in task
  prep (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Fix out of bound at debug_I_T_nexus_reset()
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Snapshot AXI and RAS register at debugfs
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Snapshot HW cache of IOST and ITCT at debugfs
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Fix pointer usage error in show debugfs
  IOST/ITCT (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Drop hisi_sas_hw.get_free_slot
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Make max IPTT count equal for all hw revisions
  (bsc#1156419,jsc#SLE-8281).
- scsi: ncr53c8xx: Mark expected switch fall-through
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Configure clock in .hce_enable_notify() in Cadence
  UFS (bsc#1156419,jsc#SLE-8281).
- scsi: core: Complain if scsi_target_block() fails
  (bsc#1156419,jsc#SLE-8281).
- scsi: core: Make scsi_internal_device_unblock_nowait() reject
  invalid new_state (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: revamp string descriptor reading
  (bsc#1156419,jsc#SLE-8281).
- scsi: wd33c93: Mark expected switch fall-through
  (bsc#1156419,jsc#SLE-8281).
- scsi: sun3_scsi: Mark expected switch fall-throughs
  (bsc#1156419,jsc#SLE-8281).
- scsi: qlogicpti: Mark expected switch fall-throughs
  (bsc#1156419,jsc#SLE-8281).
- scsi: ibmvfc: Mark expected switch fall-throughs
  (bsc#1156419,jsc#SLE-8281).
- scsi: megaraid_sas: Fix a compilation warning
  (bsc#1156419,jsc#SLE-8281).
- scsi: megaraid_sas: Make a bunch of functions static
  (bsc#1156419,jsc#SLE-8281).
- scsi: mpt3sas: support target smid for [abort|query] task
  (bsc#1156419,jsc#SLE-8281).
- scsi: ibmvscsi_tgt: Mark expected switch fall-throughs
  (bsc#1156419,jsc#SLE-8281).
- scsi: mpt3sas: clean up a couple sizeof() uses
  (bsc#1156419,jsc#SLE-8281).
- scsi: scsi_debugfs: Use for_each_set_bit to simplify code
  (bsc#1156419,jsc#SLE-8281).
- scsi: fdomain_isa: use CFG1_IRQ_MASK (bsc#1156419,jsc#SLE-8281).
- scsi: fdomain: use BSTAT_{MSG|CMD|IO} in fdomain_work()
  (bsc#1156419,jsc#SLE-8281).
- scsi: fdomain: use BCTL_RST in fdomain_reset()
  (bsc#1156419,jsc#SLE-8281).
- scsi: aic94xx: Remove unnecessary null check
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: change msleep to usleep_range
  (bsc#1156419,jsc#SLE-8281).
- scsi: virtio_scsi: implement request batching
  (bsc#1156419,jsc#SLE-8281).
- scsi: core: add support for request batching
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Add history of fatal events
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Do not reset error history during host reset
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Add fatal and auto-hibern8 error history
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Change names related to error history
  (bsc#1156419,jsc#SLE-8281).
- commit 9419833
* Thu Nov 14 2019 msuchanek@suse.de
- powerpc/security/book3s64: Report L1TF status in sysfs
  (bsc#1091041).
- commit 4c13792
* Thu Nov 14 2019 msuchanek@suse.de
- Refresh patches.suse/powerpc-fadump-when-fadump-is-supported-register-the.patch.
  Add upstream metadata.
- commit eb3a775
* Thu Nov 14 2019 msuchanek@suse.de
- powerpc/security: Fix wrong message when RFI Flush is disable
  (bsc#1131107).
- commit f4d03f9
* Thu Nov 14 2019 msuchanek@suse.de
- powerpc/pseries: safely roll back failed DLPAR cpu add
  (bsc#1156700 ltc#182459).
- powerpc/pseries: address checkpatch warnings in
  dlpar_offline_cpu (bsc#1156700 ltc#182459).
- commit ce23e84
* Thu Nov 14 2019 mkubecek@suse.cz
- series.conf: cleanup
  Move queued patches into "almost mainline" section.
- commit b0c29ce
* Wed Nov 13 2019 yousaf.kaukab@suse.com
- arm64: compat: Workaround Neoverse-N1 #1542419 for compat
  user-space (jsc#SLE-10259).
- arm64: Fake the IminLine size on systems affected by Neoverse-N1
  [#1542419] (jsc#SLE-10259).
- arm64: errata: Hide CTR_EL0.DIC on systems affected by
  Neoverse-N1 #1542419 (jsc#SLE-10259).
  Update arm64 configs (eneable ARM64_ERRATUM_1542419).
- commit ecac0a4
* Wed Nov 13 2019 dwagner@suse.de
- scsi: qla2xxx: don't use zero for FC4_PRIORITY_NVME
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: initialize fc4_type_priority (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix a dma_pool_free() call (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove an include directive (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Update driver version to 10.01.00.21-k
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix device connect issues in P2P configuration
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix memory leak when sending I/O fails
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix double scsi_done for abort path (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix driver unload hang (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix SRB leak on switch command timeout
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Do command completion on abort timeout
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Retry PLOGI on FC-NVMe PRLI failure (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- commit e0be784
* Wed Nov 13 2019 dwagner@suse.de
- Refresh series.conf
- commit 043b271
* Wed Nov 13 2019 ohering@suse.de
- hv_netvsc: Fix error handling in netvsc_set_features()
  (fate#323887).
- commit 2074f53
* Wed Nov 13 2019 mkubecek@suse.cz
- config: leave TSX enabled by default
  This is to preserve the behaviour of previous SLE versions. Users who
  wnat to disable TSX can use "tsx=off" on command line.
- commit f1407d4
* Wed Nov 13 2019 tiwai@suse.de
- Update patch references for i915 security fixes (CVE-2019-0154 bsc#1135966 CVE-2019-0155 bsc#1135967)
- commit 697e88e
* Wed Nov 13 2019 jslaby@suse.cz
- Linux 5.3.11 (bnc#1151927 5.3.11).
- x86/speculation/taa: Fix printing of TAA_MSG_SMT on IBRS_ALL
  CPUs (bnc#1151927 5.3.11).
- Documentation: Add ITLB_MULTIHIT documentation (bnc#1151927
  5.3.11).
- kvm: x86: mmu: Recovery of shattered NX large pages (bnc#1151927
  5.3.11).
- kvm: Add helper function for creating VM worker threads
  (bnc#1151927 5.3.11).
- kvm: mmu: ITLB_MULTIHIT mitigation (bnc#1151927 5.3.11).
- cpu/speculation: Uninline and export CPU mitigations helpers
  (bnc#1151927 5.3.11).
- x86/cpu: Add Tremont to the cpu vulnerability whitelist
  (bnc#1151927 5.3.11).
- x86/bugs: Add ITLB_MULTIHIT bug infrastructure (bnc#1151927
  5.3.11).
- x86/tsx: Add config options to set tsx=on|off|auto (bnc#1151927
  5.3.11).
- Update config files.
  Set CONFIG_X86_INTEL_TSX_MODE_OFF=y (the default).
- x86/speculation/taa: Add documentation for TSX Async Abort
  (bnc#1151927 5.3.11).
- x86/tsx: Add "auto" option to the tsx= cmdline parameter
  (bnc#1151927 5.3.11).
- kvm/x86: Export MDS_NO=0 to guests when TSX is enabled
  (bnc#1151927 5.3.11).
- x86/speculation/taa: Add sysfs reporting for TSX Async Abort
  (bnc#1151927 5.3.11).
- x86/speculation/taa: Add mitigation for TSX Async Abort
  (bnc#1151927 5.3.11).
- x86/cpu: Add a "tsx=" cmdline option with TSX disabled by
  default (bnc#1151927 5.3.11).
- x86/cpu: Add a helper function x86_read_arch_cap_msr()
  (bnc#1151927 5.3.11).
- x86/msr: Add the IA32_TSX_CTRL MSR (bnc#1151927 5.3.11).
- drm/i915/cmdparser: Fix jump whitelist clearing (bnc#1151927
  5.3.11).
- drm/i915/gen8+: Add RC6 CTX corruption WA (bnc#1151927 5.3.11).
- drm/i915: Lower RM timeout to avoid DSI hard hangs (bnc#1151927
  5.3.11).
- drm/i915/cmdparser: Ignore Length operands during command
  matching (bnc#1151927 5.3.11).
- drm/i915/cmdparser: Add support for backward jumps (bnc#1151927
  5.3.11).
- drm/i915/cmdparser: Use explicit goto for error paths
  (bnc#1151927 5.3.11).
- drm/i915: Add gen9 BCS cmdparsing (bnc#1151927 5.3.11).
- drm/i915: Allow parsing of unsized batches (bnc#1151927 5.3.11).
- drm/i915: Support ro ppgtt mapped cmdparser shadow buffers
  (bnc#1151927 5.3.11).
- drm/i915: Add support for mandatory cmdparsing (bnc#1151927
  5.3.11).
- drm/i915: Remove Master tables from cmdparser (bnc#1151927
  5.3.11).
- drm/i915: Disable Secure Batches for gen6+ (bnc#1151927 5.3.11).
- drm/i915: Rename gen7 cmdparser tables (bnc#1151927 5.3.11).
- ARM: dts: stm32: change joystick pinctrl definition on
  stm32mp157c-ev1 (bnc#1151927 5.3.11).
- ARM: sunxi: Fix CPU powerdown on A83T (bnc#1151927 5.3.11).
- ARM: dts: imx6-logicpd: Re-enable SNVS power key (bnc#1151927
  5.3.11).
- iio: srf04: fix wrong limitation in distance measuring
  (bnc#1151927 5.3.11).
- intel_th: pci: Add Jasper Lake PCH support (bnc#1151927 5.3.11).
- intel_th: pci: Add Comet Lake PCH support (bnc#1151927 5.3.11).
- x86/dumpstack/64: Don't evaluate exception stacks before setup
  (bnc#1151927 5.3.11).
- x86/apic/32: Avoid bogus LDR warnings (bnc#1151927 5.3.11).
- timekeeping/vsyscall: Update VDSO data unconditionally
  (bnc#1151927 5.3.11).
- perf tools: Fix time sorting (bnc#1151927 5.3.11).
- SMB3: Fix persistent handles reconnect (bnc#1151927 5.3.11).
- btrfs: save i_size to avoid double evaluation of i_size_read
  in compress_file_range (bnc#1151927 5.3.11).
- btrfs: tree-checker: Fix wrong check on max devid (bnc#1151927
  5.3.11).
- btrfs: Consider system chunk array size for new SYSTEM chunks
  (bnc#1151927 5.3.11).
- qede: fix NULL pointer deref in __qede_remove() (bnc#1151927
  5.3.11).
- net: fix data-race in neigh_event_send() (bnc#1151927 5.3.11).
- vsock/virtio: fix sock refcnt holding during the shutdown
  (bnc#1151927 5.3.11).
- net: ethernet: octeon_mgmt: Account for second possible VLAN
  header (bnc#1151927 5.3.11).
- ipv4: Fix table id reference in fib_sync_down_addr (bnc#1151927
  5.3.11).
- ipv6: fixes rt6_probe() and fib6_nh->last_probe init
  (bnc#1151927 5.3.11).
- net: hns: Fix the stray netpoll locks causing deadlock in NAPI
  path (bnc#1151927 5.3.11).
- net: usb: qmi_wwan: add support for DW5821e with eSIM support
  (bnc#1151927 5.3.11).
- CDC-NCM: handle incomplete transfer of MTU (bnc#1151927 5.3.11).
- NFC: st21nfca: fix double free (bnc#1151927 5.3.11).
- netfilter: ipset: Copy the right MAC address in hash:ip,mac
  IPv6 sets (bnc#1151927 5.3.11).
- netfilter: ipset: Fix an error code in ip_set_sockfn_get()
  (bnc#1151927 5.3.11).
- netfilter: nf_tables: Align nft_expr private data to 64-bit
  (bnc#1151927 5.3.11).
- net/smc: fix ethernet interface refcounting (bnc#1151927
  5.3.11).
- selftests/tls: add test for concurrent recv and send
  (bnc#1151927 5.3.11).
- net/tls: add a TX lock (bnc#1151927 5.3.11).
- net/tls: don't pay attention to sk_write_pending when pushing
  partial records (bnc#1151927 5.3.11).
- net: mscc: ocelot: fix NULL pointer on LAG slave removal
  (bnc#1151927 5.3.11).
- net: mscc: ocelot: don't handle netdev events for other netdevs
  (bnc#1151927 5.3.11).
- NFC: fdp: fix incorrect free object (bnc#1151927 5.3.11).
- net: prevent load/store tearing on sk->sk_stamp (bnc#1151927
  5.3.11).
- net: qualcomm: rmnet: Fix potential UAF when unregistering
  (bnc#1151927 5.3.11).
- net/tls: fix sk_msg trim on fallback to copy mode (bnc#1151927
  5.3.11).
- net: sched: prevent duplicate flower rules from tcf_proto
  destroy race (bnc#1151927 5.3.11).
- bonding: fix state transition issue in link monitoring
  (bnc#1151927 5.3.11).
- cgroup,writeback: don't switch wbs immediately on dead wbs if
  the memcg is dead (bnc#1151927 5.3.11).
- blkcg: make blkcg_print_stat() print stats only for online blkgs
  (bnc#1151927 5.3.11).
- ceph: don't allow copy_file_range when stripe_count != 1
  (bnc#1151927 5.3.11).
- ceph: don't try to handle hashed dentries in non-O_CREAT
  atomic_open (bnc#1151927 5.3.11).
- ceph: add missing check in d_revalidate snapdir handling
  (bnc#1151927 5.3.11).
- ceph: fix RCU case handling in ceph_d_revalidate() (bnc#1151927
  5.3.11).
- ceph: fix use-after-free in __ceph_remove_cap() (bnc#1151927
  5.3.11).
- arm64: Do not mask out PTE_RDONLY in pte_same() (bnc#1151927
  5.3.11).
- cpufreq: intel_pstate: Fix invalid EPB setting (bnc#1151927
  5.3.11).
- drm/radeon: fix si_enable_smc_cac() failed issue (bnc#1151927
  5.3.11).
- clk: imx8m: Use SYS_PLL1_800M as intermediate parent of CLK_ARM
  (bnc#1151927 5.3.11).
- mm: memcontrol: fix network errors from failing __GFP_ATOMIC
  charges (bnc#1151927 5.3.11).
- mm: slab: make page_cgroup_ino() to recognize non-compound
  slab pages properly (bnc#1151927 5.3.11).
- dump_stack: avoid the livelock of the dump_lock (bnc#1151927
  5.3.11).
- mm/khugepaged: fix might_sleep() warn with CONFIG_HIGHPTE=y
  (bnc#1151927 5.3.11).
- mm, vmstat: hide /proc/pagetypeinfo from normal users
  (bnc#1151927 5.3.11).
- ocfs2: protect extent tree in ocfs2_prepare_inode_for_write()
  (bnc#1151927 5.3.11).
- mm: thp: handle page cache THP correctly in PageTransCompoundMap
  (bnc#1151927 5.3.11).
- mm: memcontrol: fix NULL-ptr deref in percpu stats flush
  (bnc#1151927 5.3.11).
- clone3: validate stack arguments (bnc#1151927 5.3.11).
- tools: gpio: Use !building_out_of_srctree to determine srctree
  (bnc#1151927 5.3.11).
- usbip: Fix free of unallocated memory in vhci tx (bnc#1151927
  5.3.11).
- usbip: tools: Fix read_usb_vudc_device() error path handling
  (bnc#1151927 5.3.11).
- USB: ldusb: use unsigned size format specifiers (bnc#1151927
  5.3.11).
- USB: Skip endpoints with 0 maxpacket length (bnc#1151927
  5.3.11).
- usb: dwc3: remove the call trace of USBx_GFLADJ (bnc#1151927
  5.3.11).
- usb: gadget: configfs: fix concurrent issue between composite
  APIs (bnc#1151927 5.3.11).
- usb: gadget: composite: Fix possible double free memory bug
  (bnc#1151927 5.3.11).
- usb: fsl: Check memory resource before releasing it (bnc#1151927
  5.3.11).
- scsi: sd: define variable dif as unsigned int instead of bool
  (bnc#1151927 5.3.11).
- scsi: lpfc: Honor module parameter lpfc_use_adisc (bnc#1151927
  5.3.11).
- scsi: ufs-bsg: Wake the device before sending raw upiu commands
  (bnc#1151927 5.3.11).
- powerpc/32s: fix allow/prevent_user_access() when crossing
  segment boundaries (bnc#1151927 5.3.11).
- gve: Fixes DMA synchronization (bnc#1151927 5.3.11).
- iwlwifi: pcie: 0x2720 is qu and 0x30DC is not (bnc#1151927
  5.3.11).
- iwlwifi: pcie: fix all 9460 entries for qnj (bnc#1151927
  5.3.11).
- iwlwifi: pcie: fix PCI ID 0x2720 configs that should be soc
  (bnc#1151927 5.3.11).
- net: ethernet: arc: add the missed clk_disable_unprepare
  (bnc#1151927 5.3.11).
- hv_netvsc: Fix error handling in netvsc_attach() (bnc#1151927
  5.3.11).
- net: mscc: ocelot: refuse to overwrite the port's native vlan
  (bnc#1151927 5.3.11).
- net: mscc: ocelot: fix vlan_filtering when enslaving to bridge
  before link is up (bnc#1151927 5.3.11).
- selftests/bpf: More compatible nc options in test_tc_edt
  (bnc#1151927 5.3.11).
- net: phy: smsc: LAN8740: add PHY_RST_AFTER_CLK_EN flag
  (bnc#1151927 5.3.11).
- net: stmmac: Fix the problem of tso_xmit (bnc#1151927 5.3.11).
- NFSv4: Don't allow a cached open with a revoked delegation
  (bnc#1151927 5.3.11).
- nvme-multipath: fix possible io hang after ctrl reconnect
  (bnc#1151927 5.3.11).
- sched/topology: Allow sched_asym_cpucapacity to be disabled
  (bnc#1151927 5.3.11).
- sched/topology: Don't try to build empty sched domains
  (bnc#1151927 5.3.11).
- perf/x86/uncore: Fix event group support (bnc#1151927 5.3.11).
- perf/x86/amd/ibs: Handle erratum #420 only on the affected
  CPU family (10h) (bnc#1151927 5.3.11).
- perf/x86/amd/ibs: Fix reading of the IBS OpData register and
  thus precise RIP validity (bnc#1151927 5.3.11).
- x86, efi: Never relocate kernel below lowest acceptable address
  (bnc#1151927 5.3.11).
- efi: libstub/arm: Account for firmware reserved memory at the
  base of RAM (bnc#1151927 5.3.11).
- arm64: apply ARM64_ERRATUM_843419 workaround for Brahma-B53 core
  (bnc#1151927 5.3.11).
- arm64: Brahma-B53 is SSB and spectre v2 safe (bnc#1151927
  5.3.11).
- arm64: apply ARM64_ERRATUM_845719 workaround for Brahma-B53 core
  (bnc#1151927 5.3.11).
- arm64: cpufeature: Enable Qualcomm Falkor errata 1009 for Kryo
  (bnc#1151927 5.3.11).
- dc.c:use kzalloc without test (bnc#1151927 5.3.11).
- drm/amd/display: Passive DP->HDMI dongle detection fix
  (bnc#1151927 5.3.11).
- drm/amd/display: add 50us buffer as WA for pstate switch in
  active (bnc#1151927 5.3.11).
- drm/amd/display: do not synchronize "drr" displays (bnc#1151927
  5.3.11).
- drm/amdgpu: If amdgpu_ib_schedule fails return back the error
  (bnc#1151927 5.3.11).
- drm/sched: Set error to s_fence if HW job submission failed
  (bnc#1151927 5.3.11).
- drm/amdgpu/sdma5: do not execute 0-sized IBs (v2) (bnc#1151927
  5.3.11).
- dmaengine: xilinx_dma: Fix control reg update in
  vdma_channel_set_config (bnc#1151927 5.3.11).
- dmaengine: xilinx_dma: Fix 64-bit simple AXIDMA transfer
  (bnc#1151927 5.3.11).
- iommu/amd: Apply the same IVRS IOAPIC workaround to Acer Aspire
  A315-41 (bnc#1151927 5.3.11).
- ARC:: Enable on-board SPI NOR flash IC (bnc#1151927 5.3.11).
- HID: intel-ish-hid: fix wrong error handling in
  ishtp_cl_alloc_tx_ring() (bnc#1151927 5.3.11).
- HID: google: add magnemite/masterball USB ids (bnc#1151927
  5.3.11).
- arm64: errata: Update stale comment (bnc#1151927 5.3.11).
- soundwire: bus: set initial value to port_status (bnc#1151927
  5.3.11).
- configfs: fix a deadlock in configfs_symlink() (bnc#1151927
  5.3.11).
- usbip: Implement SG support to vhci-hcd and stub driver
  (bnc#1151927 5.3.11).
- perf map: Use zalloc for map_groups (bnc#1151927 5.3.11).
- commit 8a2e23a
* Wed Nov 13 2019 jslaby@suse.cz
- mm, meminit: recalculate pcpu batch and high limits after init
  completes (bnc#1155628).
  Update to upstream version (and update metadata).
- commit 8d03909
* Wed Nov 13 2019 jslaby@suse.cz
- Update
  patches.suse/ALSA-bebob-fix-to-detect-configured-source-of-sampli.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-hda-ca0132-Fix-possible-workqueue-stall.patch
  (bsc#1155836 bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-timer-Fix-incorrectly-assigned-timer-instance.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-Clean-up-check_input_term.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-Fix-copy-paste-error-in-the-validator.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-Fix-possible-NULL-dereference-at-crea.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-More-validations-of-descriptor-units.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-Remove-superfluous-bLength-checks.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-Simplify-parse_audio_unit.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-Unify-the-release-of-usb_mixer_elem_i.patch
  (git-fixes bnc#1151927 5.3.11).
- Update patches.suse/ALSA-usb-audio-remove-some-dead-code.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ASoC-SOF-Intel-hda-stream-fix-the-CONFIG_-prefix-mis.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ASoC-rsnd-dma-fix-SSI9-4-5-6-7-busif-dma-address.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/HID-wacom-generic-Treat-serial-number-and-related-fi.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/IB-core-Use-rdma_read_gid_l2_fields-to-compare-GID-L.patch
  (jsc#SLE-8449 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-hns-Prevent-memory-leaks-of-eq-buf_list.patch
  (jsc#SLE-8449 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-iw_cxgb4-Avoid-freeing-skb-twice-in-arp-failure.patch
  (jsc#SLE-8392 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-mlx5-Clear-old-rate-limit-when-closing-QP.patch
  (jsc#SLE-8446 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-nldev-Skip-counter-if-port-doesn-t-match.patch
  (jsc#SLE-8449 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-qedr-Fix-reported-firmware-version.patch
  (jsc#SLE-8215 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-siw-free-siw_base_qp-in-kref-release-routine.patch
  (jsc#SLE-8381 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-uverbs-Prevent-potential-underflow.patch
  (jsc#SLE-8449 bnc#1151927 5.3.11).
- Update
  patches.suse/SUNRPC-Destroy-the-back-channel-when-we-destroy-the-.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/SUNRPC-The-RDMA-back-channel-mustn-t-disappear-while.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/SUNRPC-The-TCP-back-channel-mustn-t-disappear-while-.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/bonding-fix-unexpected-IFF_BONDING-bit-unset.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/bonding-fix-using-uninitialized-mode_lock.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/bonding-use-dynamic-lockdep-key-instead-of-subclass.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/bpf-Fix-use-after-free-in-bpf_get_prog_name.patch
  (bsc#1155518 bnc#1151927 5.3.11).
- Update
  patches.suse/bpf-Fix-use-after-free-in-subprog-s-jited-symbol-rem.patch
  (bsc#1155518 bnc#1151927 5.3.11).
- Update
  patches.suse/bpf-lwtunnel-Fix-reroute-supplying-invalid-dst.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/can-c_can-c_can_poll-only-read-status-register-after.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-dev-add-missing-of_node_put-after-calling-of_get.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-flexcan-disable-completely-the-ECC-mechanism.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-gs_usb-gs_can_open-prevent-memory-leak.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-mcba_usb-fix-use-after-free-on-disconnect.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-peak_usb-fix-a-potential-out-of-sync-while-decod.patch
  (git-fixes bnc#1151927 5.3.11).
- Update patches.suse/can-peak_usb-fix-slab-info-leak.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-rx-offload-can_rx_offload_queue_sorted-fix-error.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-usb_8dev-fix-use-after-free-on-disconnect.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/dmaengine-sprd-Fix-the-link-list-pointer-register-co.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/dmaengine-sprd-Fix-the-possible-memory-leak-issue.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/drm-v3d-Fix-memory-leak-in-v3d_submit_cl_ioctl.patch
  (git-fixes bnc#1151927 5.3.11).
- Update patches.suse/e1000-fix-memory-leaks.patch (jsc#SLE-8100
  bnc#1151927 5.3.11).
- Update
  patches.suse/efi-tpm-Return-EINVAL-when-determining-tpm-final-eve.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/fjes-Handle-workqueue-allocation-failure.patch
  (CVE-2019-16231,bsc#1150466 bnc#1151927 5.3.11).
- Update patches.suse/hwmon-ina3221-Fix-read-timeout-issue.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/igb-Fix-constant-media-auto-sense-switching-when-no-.patch
  (jsc#SLE-7967 jsc#SLE-8010 bnc#1151927 5.3.11).
- Update patches.suse/iio-adc-stm32-adc-fix-stopping-dma.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/iio-imu-adis16480-make-sure-provided-frequency-is-po.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/iio-imu-inv_mpu6050-fix-no-data-on-MPU6050.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/intel_th-gth-Fix-the-window-switching-sequence.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ipvs-don-t-ignore-errors-in-case-refcounting-ip_vs-m.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/ipvs-move-old_secure_tcp-into-struct-netns_ipvs.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/iw_cxgb4-fix-ECN-check-on-the-passive-accept.patch
  (jsc#SLE-8392 bnc#1151927 5.3.11).
- Update
  patches.suse/kvm-x86-powerpc-do-not-allow-clearing-largepages-debugfs-entry
  (bsc#1117665 bnc#1151927 5.3.11).
- Update
  patches.suse/macsec-fix-refcnt-leak-in-module-exit-routine.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/mm-filemap.c-don-t-initiate-writeback-if-mapping-has-no-dirty-pages.patch
  (bnc#1155780 (VM/FS functional and performance backports)
  bnc#1151927 5.3.11).
- Update
  patches.suse/mm-meminit-Recalculate-pcpu-batch-and-high-limits-after-init-completes.patch
  (bnc#1155628 bnc#1151927 5.3.11).
- Update
  patches.suse/mt76-dma-fix-buffer-unmap-with-non-linear-skbs.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/net-hisilicon-Fix-Trying-to-free-already-free-IRQ.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/net-ibmvnic-unlock-rtnl_lock-in-reset-so-linkwatch_e.patch
  (bsc#1152457 ltc#174432 bnc#1151927 5.3.11).
- Update
  patches.suse/net-mlx5-fix-memory-leak-in-mlx5_fw_fatal_reporter_d.patch
  (jsc#SLE-8464 bnc#1151927 5.3.11).
- Update
  patches.suse/net-mlx5-prevent-memory-leak-in-mlx5_fpga_conn_creat.patch
  (jsc#SLE-8464 bnc#1151927 5.3.11).
- Update
  patches.suse/net-mlx5e-TX-Fix-consumer-index-of-error-cqe-dump.patch
  (jsc#SLE-8464 bnc#1151927 5.3.11).
- Update
  patches.suse/net-mlx5e-Tx-Fix-assumption-of-single-WQEBB-of-NOP-i.patch
  (jsc#SLE-8464 bnc#1151927 5.3.11).
- Update
  patches.suse/net-mlx5e-kTLS-Release-reference-on-DUMPed-fragments.patch
  (jsc#SLE-8464 bnc#1151927 5.3.11).
- Update
  patches.suse/net-openvswitch-free-vport-unless-register_netdevice.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/netfilter-nf_flow_table-set-timeout-before-insertion.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/netfilter-nft_payload-fix-missing-check-for-matching.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/nfc-netlink-fix-double-device-reference-drop.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/pinctrl-cherryview-Fix-irq_valid_mask-calculation.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/pinctrl-intel-Avoid-potential-glitches-if-pin-is-in-.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/r8169-fix-page-read-in-r8168g_mdio_read.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/scsi-lpfc-Check-queue-pointer-before-use.patch
  (bsc#1154242 bnc#1151927 5.3.11).
- Update
  patches.suse/scsi-qla2xxx-Initialized-mailbox-to-prevent-driver-l.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.11).
- Update
  patches.suse/scsi-qla2xxx-fixup-incorrect-usage-of-host_byte.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.11).
- Update
  patches.suse/scsi-qla2xxx-stop-timer-in-shutdown-path.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.11).
- Update patches.suse/soundwire-depend-on-ACPI-OF.patch
  (bsc#1148868 bnc#1151927 5.3.11).
- Update patches.suse/soundwire-depend-on-ACPI.patch (bsc#1148868
  bnc#1151927 5.3.11).
- Update
  patches.suse/usb-dwc3-gadget-fix-race-when-disabling-ep-with-canc.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/usb-dwc3-pci-prevent-memory-leak-in-dwc3_pci_probe.patch
  (git-fixes, CVE-2019-18813, bsc#1156278 bnc#1151927 5.3.11).
- Update patches.suse/usb-dwc3-select-CONFIG_REGMAP_MMIO.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/usb-gadget-udc-atmel-Fix-interrupt-storm-in-FIFO-mod.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/virt_wifi-fix-refcnt-leak-in-module-exit-routine.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/wimax-i2400-Fix-memory-leak-in-i2400m_op_rfkill_sw_t.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/xsk-Fix-registration-of-Rx-only-sockets.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- commit 334001e
* Wed Nov 13 2019 jslaby@suse.cz
- Linux 5.3.10 (bnc#1151927 5.3.10).
- selftests: net: reuseport_dualstack: fix uninitalized parameter
  (bnc#1151927 5.3.10).
- rxrpc: Fix handling of last subpacket of jumbo packet
  (bnc#1151927 5.3.10).
- net/mlx5: Fix flow counter list auto bits struct (bnc#1151927
  5.3.10).
- net/smc: fix refcounting for non-blocking connect() (bnc#1151927
  5.3.10).
- net: usb: lan78xx: Disable interrupts before calling
  generic_handle_irq() (bnc#1151927 5.3.10).
- net: ethernet: ftgmac100: Fix DMA coherency issue with SW
  checksum (bnc#1151927 5.3.10).
- selftests: fib_tests: add more tests for metric update
  (bnc#1151927 5.3.10).
- net/smc: keep vlan_id for SMC-R in smc_listen_work()
  (bnc#1151927 5.3.10).
- net/smc: fix closing of fallback SMC sockets (bnc#1151927
  5.3.10).
- perf kmem: Fix memory leak in compact_gfp_flags() (bnc#1151927
  5.3.10).
- perf c2c: Fix memory leak in build_cl_output() (bnc#1151927
  5.3.10).
- perf tools: Fix resource leak of closedir() on the error paths
  (bnc#1151927 5.3.10).
- irqchip/sifive-plic: Skip contexts except supervisor in
  plic_init() (bnc#1151927 5.3.10).
- irqchip/gic-v3-its: Use the exact ITSList for VMOVP (bnc#1151927
  5.3.10).
- cifs: Fix cifsInodeInfo lock_sem deadlock when reconnect occurs
  (bnc#1151927 5.3.10).
- CIFS: Fix retry mid list corruption on reconnects (bnc#1151927
  5.3.10).
- MIPS: bmips: mark exception vectors as char arrays (bnc#1151927
  5.3.10).
- nbd: handle racing with error'ed out commands (bnc#1151927
  5.3.10).
- nbd: protect cmd->status with cmd->lock (bnc#1151927 5.3.10).
- scsi: hpsa: add missing hunks in reset-patch (bnc#1151927
  5.3.10).
- scsi: target: core: Do not overwrite CDB byte 1 (bnc#1151927
  5.3.10).
- scsi: fix kconfig dependency warning related to 53C700_LE_ON_BE
  (bnc#1151927 5.3.10).
- scsi: sni_53c710: fix compilation error (bnc#1151927 5.3.10).
- scsi: scsi_dh_alua: handle RTPG sense code correctly during
  state transitions (bnc#1151927 5.3.10).
- arm64: dts: allwinner: a64: sopine-baseboard: Add PHY regulator
  delay (bnc#1151927 5.3.10).
- arm64: dts: allwinner: a64: Drop PMU node (bnc#1151927 5.3.10).
- arm64: dts: allwinner: a64: pine64-plus: Add PHY regulator delay
  (bnc#1151927 5.3.10).
- ARM: dts: bcm2837-rpi-cm3: Avoid leds-gpio probing issue
  (bnc#1151927 5.3.10).
- ARM: davinci: dm365: Fix McBSP dma_slave_map entry (bnc#1151927
  5.3.10).
- arm64: dts: rockchip: Fix usb-c on Hugsun X99 TV Box
  (bnc#1151927 5.3.10).
- arm64: dts: rockchip: fix RockPro64 sdmmc settings (bnc#1151927
  5.3.10).
- arm64: dts: rockchip: fix RockPro64 sdhci settings (bnc#1151927
  5.3.10).
- arm64: dts: rockchip: fix RockPro64 vdd-log regulator settings
  (bnc#1151927 5.3.10).
- arm64: dts: rockchip: fix Rockpro64 RK808 interrupt line
  (bnc#1151927 5.3.10).
- arm64: dts: imx8mm: Use correct clock for usdhc's ipg clk
  (bnc#1151927 5.3.10).
- arm64: dts: imx8mq: Use correct clock for usdhc's ipg clk
  (bnc#1151927 5.3.10).
- ARM: dts: imx7s: Correct GPT's ipg clock source (bnc#1151927
  5.3.10).
- ARM: dts: vf610-zii-scu4-aib: Specify 'i2c-mux-idle-disconnect'
  (bnc#1151927 5.3.10).
- ARM: dts: imx6q-logicpd: Re-Enable SNVS power key (bnc#1151927
  5.3.10).
- arm64: dts: lx2160a: Correct CPU core idle state name
  (bnc#1151927 5.3.10).
- arm64: dts: zii-ultra: fix ARM regulator states (bnc#1151927
  5.3.10).
- ARM: dts: Use level interrupt for omap4 & 5 wlcore (bnc#1151927
  5.3.10).
- ARM: dts: am3874-iceboard: Fix 'i2c-mux-idle-disconnect' usage
  (bnc#1151927 5.3.10).
- ARM: dts: logicpd-torpedo-som: Remove twl_keypad (bnc#1151927
  5.3.10).
- arm64: dts: Fix gpio to pinmux mapping (bnc#1151927 5.3.10).
- selftests: kvm: fix sync_regs_test with newer gccs (bnc#1151927
  5.3.10).
- selftests: kvm: vmx_set_nested_state_test: don't check for
  VMX support twice (bnc#1151927 5.3.10).
- of: unittest: fix memory leak in unittest_data_add (bnc#1151927
  5.3.10).
- tracing: Fix "gfp_t" format for synthetic events (bnc#1151927
  5.3.10).
- ARM: 8926/1: v7m: remove register save to stack before svc
  (bnc#1151927 5.3.10).
- ARM: 8914/1: NOMMU: Fix exc_ret for XIP (bnc#1151927 5.3.10).
- ARM: 8908/1: add __always_inline to functions called from
  __get_user_check() (bnc#1151927 5.3.10).
- ARM: mm: fix alignment handler faults under memory pressure
  (bnc#1151927 5.3.10).
- selftests/powerpc: Fix compile error on tlbie_test due to
  newer gcc (bnc#1151927 5.3.10).
- selftests/powerpc: Add test case for tlbie vs mtpidr ordering
  issue (bnc#1151927 5.3.10).
- arm64: dts: ti: k3-am65-main: Fix gic-its node unit-address
  (bnc#1151927 5.3.10).
- commit c4dc2d2
* Wed Nov 13 2019 jslaby@suse.cz
- Update
  patches.suse/8250-men-mcb-fix-error-checking-when-get_num_ports-r.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ALSA-hda-Add-Tigerlake-Jasperlake-PCI-ID.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-Intel-sof-rt5682-add-a-check-for-devm_clk_get.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-SOF-Intel-hda-Disable-DMI-L1-entry-during-captu.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-SOF-Intel-hda-fix-warnings-during-FW-load.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-SOF-Intel-initialise-and-verify-FW-crash-dump-d.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-SOF-control-return-true-when-kcontrol-values-ch.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-SOF-loader-fix-kernel-oops-on-firmware-boot-fai.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-SOF-topology-fix-parse-fail-issue-for-byte-bool.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-intel-bytcr_rt5651-add-null-check-to-support_bu.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-intel-sof_rt5682-add-remove-function-to-disable.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-msm8916-wcd-digital-add-missing-MIX2-path-for-R.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-pcm3168a-The-codec-does-not-support-S32_LE.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-rt5682-add-NULL-handler-to-set_jack-function.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-samsung-arndale-Add-missing-OF-node-dereferenci.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-simple_card_utils.h-Fix-potential-multiple-rede.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-topology-Fix-a-signedness-bug-in-soc_tplg_dapm_.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-wm8994-Do-not-register-inapplicable-controls-fo.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-wm_adsp-Don-t-generate-kcontrols-without-READ-f.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/ASoc-rockchip-i2s-Fix-RPM-imbalance.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/cxgb4-fix-panic-when-attaching-to-ULD-fail.patch
  (jsc#SLE-8389 bnc#1151927 5.3.10).
- Update
  patches.suse/cxgb4-request-the-TX-CIDX-updates-to-status-page.patch
  (jsc#SLE-8389 bnc#1151927 5.3.10).
- Update patches.suse/dccp-do-not-leak-jiffies-on-the-wire.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/drm-amdgpu-fix-error-handling-in-amdgpu_bo_list_crea.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/drm-amdgpu-fix-potential-VM-faults.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/drm-komeda-Don-t-flush-inactive-pipes.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/erspan-fix-the-tun_info-options_len-check-for-erspan.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/i2c-aspeed-fix-master-pending-state-handling.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/i2c-mt65xx-fix-NULL-ptr-dereference.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/i2c-stm32f7-fix-a-race-in-slave-mode-with-arbitratio.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/i2c-stm32f7-fix-first-byte-to-send-in-slave-mode.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/i2c-stm32f7-remove-warning-when-compiling-with-W-1.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/inet-stop-leaking-jiffies-on-the-wire.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/ipv4-fix-IPSKB_FRAG_PMTU-handling-with-fragmentation.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update patches.suse/ipv4-fix-route-update-on-metric-change.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update patches.suse/keys-Fix-memory-leak-in-copy_net_ns.patch
  (bsc#1154353 git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/mlxsw-core-Unpublish-devlink-parameters-during-reloa.patch
  (bsc#1154488 bnc#1151927 5.3.10).
- Update
  patches.suse/net-Zeroing-the-structure-ethtool_wolinfo-in-ethtool.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-add-READ_ONCE-annotation-in-__skb_wait_for_more_.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update patches.suse/net-add-skb_queue_empty_lockless.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-annotate-accesses-to-sk-sk_incoming_cpu.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-annotate-lockless-accesses-to-sk-sk_napi_id.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-bcmgenet-don-t-set-phydev-link-from-MAC.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/net-bcmgenet-reset-40nm-EPHY-on-energy-detect.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/net-dsa-b53-Do-not-clear-existing-mirrored-port-mask.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/net-dsa-bcm_sf2-Fix-IMP-setup-for-port-different-tha.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/net-dsa-fix-switch-tree-list.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/net-ensure-correct-skb-tstamp-in-various-fragmenters.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-fix-sk_page_frag-recursion-from-memory-reclaim.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update patches.suse/net-flow_dissector-switch-to-siphash.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-hisilicon-Fix-ping-latency-when-deal-with-high-t.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-hns3-fix-mis-counting-IRQ-vector-numbers-issue.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-mlx4_core-Dynamically-set-guaranteed-amount-of-c.patch
  (jsc#SLE-8460 bnc#1151927 5.3.10).
- Update patches.suse/net-mlx5-Fix-rtable-reference-leak.patch
  (jsc#SLE-8464 bnc#1151927 5.3.10).
- Update
  patches.suse/net-mlx5e-Determine-source-port-properly-for-vlan-pu.patch
  (jsc#SLE-8464 bnc#1151927 5.3.10).
- Update
  patches.suse/net-mlx5e-Fix-ethtool-self-test-link-speed.patch
  (jsc#SLE-8464 bnc#1151927 5.3.10).
- Update
  patches.suse/net-mlx5e-Fix-handling-of-compressed-CQEs-in-case-of.patch
  (jsc#SLE-8464 bnc#1151927 5.3.10).
- Update
  patches.suse/net-mlx5e-Initialize-on-stack-link-modes-bitmap.patch
  (jsc#SLE-8464 bnc#1151927 5.3.10).
- Update
  patches.suse/net-mlx5e-Remove-incorrect-match-criteria-assignment.patch
  (jsc#SLE-8464 bnc#1151927 5.3.10).
- Update
  patches.suse/net-netem-correct-the-parent-s-backlog-when-corrupte.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-netem-fix-error-path-for-corrupted-GSO-frames.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-phy-bcm7xxx-define-soft_reset-for-40nm-EPHY.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/net-phylink-Fix-phylink_dbg-macro.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-reorder-struct-net-fields-to-avoid-false-sharing.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update patches.suse/net-rtnetlink-fix-a-typo-fbd-fdb.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-usb-lan78xx-Connect-PHY-before-registering-MAC.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/net-use-skb_queue_empty_lockless-in-busy-poll-contex.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-use-skb_queue_empty_lockless-in-poll-handlers.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/netns-fix-GFP-flags-in-rtnl_net_notifyid.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/pinctrl-intel-Allocate-IRQ-chip-dynamic.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/pinctrl-ns2-Fix-off-by-one-bugs-in-ns2_pinmux_enable.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/pinctrl-stmfx-fix-null-pointer-on-remove.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/platform-x86-pmc_atom-Add-Siemens-SIMATIC-IPC227E-to.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/r8152-add-device-id-for-Lenovo-ThinkPad-USB-C-Dock-G.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/r8169-fix-wrong-PHY-ID-issue-with-RTL8168dp.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/regulator-da9062-fix-suspend_enable-disable-preparat.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/regulator-of-fix-suspend-min-max-voltage-parsing.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/regulator-pfuze100-regulator-Variable-val-in-pfuze10.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/regulator-ti-abb-Fix-timeout-in-ti_abb_wait_txdone-t.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/scsi-qla2xxx-fix-a-potential-NULL-pointer-dereferenc.patch
  (bsc#1150457 CVE-2019-16233 bnc#1151927 5.3.10).
- Update
  patches.suse/udp-fix-data-race-in-udp_set_dev_scratch.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update patches.suse/udp-use-skb_queue_empty_lockless.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/usb-gadget-udc-core-Fix-segfault-if-udc_bind_to_driv.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/vxlan-check-tun_info-options_len-properly.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- commit db35794
* Wed Nov 13 2019 mkubecek@suse.cz
- refresh config files
- commit 18453ef
* Wed Nov 13 2019 mkubecek@suse.cz
- series.conf: cleanup
- move submitted and accepted patch into "almost mainline" section
- commit 8e9e103
* Tue Nov 12 2019 fdmanana@suse.com
- Btrfs: fix log context list corruption after rename exchange
  operation (bsc#1156494).
- commit 73bdb1d
* Tue Nov 12 2019 jslaby@suse.cz
- Linux 5.3.9 (bnc#1151927 5.3.9).
- Revert "nvme: allow 64-bit results in passthru commands"
  (bnc#1151927 5.3.9).
- scsi: target: cxgbit: Fix cxgbit_fw4_ack() (bnc#1151927 5.3.9).
- s390/idle: fix cpu idle time calculation (bnc#1151927 5.3.9).
- s390/unwind: fix mixing regs and sp (bnc#1151927 5.3.9).
- s390/cmm: fix information leak in cmm_timeout_handler()
  (bnc#1151927 5.3.9).
- NFS: Fix an RCU lock leak in nfs4_refresh_delegation_stateid()
  (bnc#1151927 5.3.9).
- io_uring: ensure we clear io_kiocb->result before each issue
  (bnc#1151927 5.3.9).
- um-ubd: Entrust re-queue to the upper layers (bnc#1151927
  5.3.9).
- arm64: cpufeature: Enable Qualcomm Falkor/Kryo errata 1003
  (bnc#1151927 5.3.9).
- arm64: Ensure VM_WRITE|VM_SHARED ptes are clean by default
  (bnc#1151927 5.3.9).
- KVM: vmx, svm: always run with EFER.NXE=1 when shadow paging
  is active (bnc#1151927 5.3.9).
- drm/amdgpu: Fix SDMA hang when performing VKexample test
  (bnc#1151927 5.3.9).
- iommu/vt-d: Fix panic after kexec -p for kdump (bnc#1151927
  5.3.9).
- fuse: truncate pending writes on O_TRUNC (bnc#1151927 5.3.9).
- fuse: flush dirty data/metadata before non-truncate setattr
  (bnc#1151927 5.3.9).
- ARC: perf: Accommodate big-endian CPU (bnc#1151927 5.3.9).
- perf/aux: Fix tracking of auxiliary trace buffer allocation
  (bnc#1151927 5.3.9).
- perf annotate: Fix multiple memory and file descriptor leaks
  (bnc#1151927 5.3.9).
- net: usb: sr9800: fix uninitialized local variable (bnc#1151927
  5.3.9).
- io_uring: fix up O_NONBLOCK handling for sockets (bnc#1151927
  5.3.9).
- dm snapshot: rework COW throttling to fix deadlock (bnc#1151927
  5.3.9).
- dm snapshot: introduce account_start_copy() and
  account_end_copy() (bnc#1151927 5.3.9).
- serial/sifive: select SERIAL_EARLYCON (bnc#1151927 5.3.9).
- perf/x86/amd: Change/fix NMI latency mitigation to use a
  timestamp (bnc#1151927 5.3.9).
- perf/core: Fix corner case in perf_rotate_context() (bnc#1151927
  5.3.9).
- perf/core: Rework memory accounting in perf_mmap() (bnc#1151927
  5.3.9).
- perf annotate: Don't return -1 for error when doing BPF
  disassembly (bnc#1151927 5.3.9).
- perf annotate: Return appropriate error code for allocation
  failures (bnc#1151927 5.3.9).
- perf annotate: Fix arch specific ->init() failure errors
  (bnc#1151927 5.3.9).
- perf annotate: Propagate the symbol__annotate() error return
  (bnc#1151927 5.3.9).
- perf annotate: Fix the signedness of failure returns
  (bnc#1151927 5.3.9).
- perf annotate: Propagate perf_env__arch() error (bnc#1151927
  5.3.9).
- perf tools: Propagate get_cpuid() error (bnc#1151927 5.3.9).
- perf jevents: Fix period for Intel fixed counters (bnc#1151927
  5.3.9).
- perf script brstackinsn: Fix recovery from LBR/binary mismatch
  (bnc#1151927 5.3.9).
- perf map: Fix overlapped map handling (bnc#1151927 5.3.9).
- perf tests: Avoid raising SEGV using an obvious NULL dereference
  (bnc#1151927 5.3.9).
- libsubcmd: Make _FORTIFY_SOURCE defines dependent on the feature
  (bnc#1151927 5.3.9).
- efi/x86: Do not clean dummy variable in kexec path (bnc#1151927
  5.3.9).
- efi/cper: Fix endianness of PCIe class code (bnc#1151927 5.3.9).
- riscv: Correct the handling of unexpected ebreak in
  do_trap_break() (bnc#1151927 5.3.9).
- riscv: avoid sending a SIGTRAP to a user thread trapped in
  WARN() (bnc#1151927 5.3.9).
- riscv: avoid kernel hangs when trapped in BUG() (bnc#1151927
  5.3.9).
- MIPS: fw: sni: Fix out of bounds init of o32 stack (bnc#1151927
  5.3.9).
- MIPS: include: Mark __xchg as __always_inline (bnc#1151927
  5.3.9).
- MIPS: include: Mark __cmpxchg as __always_inline (bnc#1151927
  5.3.9).
- x86/xen: Return from panic notifier (bnc#1151927 5.3.9).
- s390/uaccess: avoid (false positive) compiler warnings
  (bnc#1151927 5.3.9).
- s390/cio: fix virtio-ccw DMA without PV (bnc#1151927 5.3.9).
- NFSv4: Fix leak of clp->cl_acceptor string (bnc#1151927 5.3.9).
- nfs: Fix nfsi->nrequests count error on nfs_inode_remove_request
  (bnc#1151927 5.3.9).
- fs: cifs: mute -Wunused-const-variable message (bnc#1151927
  5.3.9).
- nbd: fix possible sysfs duplicate warning (bnc#1151927 5.3.9).
- btrfs: silence maybe-uninitialized warning in clone_range
  (bnc#1151927 5.3.9).
- arm64: armv8_deprecated: Checking return value for memory
  allocation (bnc#1151927 5.3.9).
- arm64: vdso32: Don't use KBUILD_CPPFLAGS unconditionally
  (bnc#1151927 5.3.9).
- arm64: Default to building compat vDSO with clang when
  CONFIG_CC_IS_CLANG (bnc#1151927 5.3.9).
- arm64: vdso32: Detect binutils support for dmb ishld
  (bnc#1151927 5.3.9).
- arm64: vdso32: Fix broken compat vDSO build warnings
  (bnc#1151927 5.3.9).
- arm64: ftrace: Ensure synchronisation in PLT setup for
  Neoverse-N1 #1542419 (bnc#1151927 5.3.9).
- arm64: Fix incorrect irqflag restore for priority masking for
  compat (bnc#1151927 5.3.9).
- arm64: cpufeature: Effectively expose FRINT capability to
  userspace (bnc#1151927 5.3.9).
- selftests/kselftest/runner.sh: Add 45 second timeout per test
  (bnc#1151927 5.3.9).
- kselftest: exclude failed TARGETS from runlist (bnc#1151927
  5.3.9).
- fs: ocfs2: fix a possible null-pointer dereference in
  ocfs2_info_scan_inode_alloc() (bnc#1151927 5.3.9).
- fs: ocfs2: fix possible null-pointer dereferences in
  ocfs2_xa_prepare_entry() (bnc#1151927 5.3.9).
- ocfs2: clear zero in unaligned direct IO (bnc#1151927 5.3.9).
- Btrfs: fix inode cache block reserve leak on failure to allocate
  data space (bnc#1151927 5.3.9).
- Refresh
  patches.suse/0001-btrfs-qgroup-Always-free-PREALLOC-META-reserve-in-bt.patch.
- s390/pci: fix MSI message data (bnc#1151927 5.3.9).
- arm64: dts: qcom: Add Asus NovaGo TP370QL (bnc#1151927 5.3.9).
- arm64: dts: qcom: Add HP Envy x2 (bnc#1151927 5.3.9).
- arm64: dts: qcom: Add Lenovo Miix 630 (bnc#1151927 5.3.9).
- commit 613af05
* Tue Nov 12 2019 jslaby@suse.cz
- Update
  patches.suse/0001-btrfs-qgroup-Always-free-PREALLOC-META-reserve-in-bt.patch
  (bsc#1155179 bnc#1151927 5.3.9).
- Update
  patches.suse/0001-thunderbolt-Correct-path-indices-for-PCIe-tunnel.patch
  (jsc#SLE-8714 bnc#1151927 5.3.9).
- Update
  patches.suse/0001-thunderbolt-Use-32-bit-writes-when-writing-ring-prod.patch
  (jsc#SLE-8714 bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-bebob-Fix-prototype-of-helper-function-to-retur.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-hda-realtek-Add-support-for-ALC623.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-hda-realtek-Fix-2-front-mics-of-codec-0x623.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-timer-Fix-mutex-deadlock-at-releasing-card.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-usb-audio-Add-DSD-support-for-Gustard-U16-X26-U.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-usb-audio-DSD-auto-detection-for-Playback-Desig.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-usb-audio-Update-DSD-support-quirks-for-Oppo-an.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/HID-Fix-assumption-that-devices-have-inputs.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/HID-fix-error-message-in-hid_open_report.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/HID-i2c-hid-add-Trekstor-Primebook-C11B-to-descripto.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/HID-logitech-hidpp-do-all-FF-cleanup-in-hidpp_ff_des.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/HID-logitech-hidpp-rework-device-validation.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/HID-logitech-hidpp-split-g920_get_config.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/IB-hfi1-Avoid-excessive-retry-for-TID-RDMA-READ-requ.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9).
- Update
  patches.suse/NFC-pn533-fix-use-after-free-and-memleaks.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-cm-Fix-memory-leak-in-cm_add-remove_one.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-core-Fix-an-error-handling-path-in-res_get_comm.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-hfi1-Prevent-memory-leak-in-sdma_init.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-iw_cxgb4-fix-SRQ-access-from-dump_qp.patch
  (jsc#SLE-8392 bnc#1151927 5.3.9).
- Update patches.suse/RDMA-iwcm-Fix-a-lock-inversion-issue.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-mlx5-Add-missing-synchronize_srcu-for-MW-cases.patch
  (jsc#SLE-8446 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-mlx5-Do-not-allow-rereg-of-a-ODP-MR.patch
  (jsc#SLE-8446 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-mlx5-Order-num_pending_prefetch-properly-with-s.patch
  (jsc#SLE-8446 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-mlx5-Use-irq-xarray-locking-for-mkey_table.patch
  (jsc#SLE-8446 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-nldev-Reshuffle-the-code-to-avoid-need-to-rebin.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-siw-Fix-serialization-issue-in-write_space.patch
  (jsc#SLE-8381 bnc#1151927 5.3.9).
- Update
  patches.suse/Revert-ALSA-hda-Flush-interrupts-on-disabling.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/SUNRPC-fix-race-to-sk_err-after-xs_error_report.patch
  (bsc#1154353 bnc#1151927 5.3.9).
- Update
  patches.suse/UAS-Revert-commit-3ae62a42090f-UAS-fix-alignment-of-.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/USB-gadget-Reject-endpoints-with-0-maxpacket-value.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/USB-ldusb-fix-control-message-timeout.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/USB-ldusb-fix-ring-buffer-locking.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/USB-legousbtower-fix-a-signedness-bug-in-tower_probe.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/USB-serial-whiteheat-fix-line-speed-endianness.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/USB-serial-whiteheat-fix-potential-slab-corruption.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/ath10k-fix-latency-issue-for-QCA988x.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/batman-adv-Avoid-free-alloc-race-when-handling-OGM-b.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/bonding-fix-potential-NULL-deref-in-bond_update_slav.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/dmaengine-cppi41-Fix-cppi41_dma_prep_slave_sg-when-i.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/dmaengine-imx-sdma-fix-size-check-for-sdma-script_nu.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/dmaengine-qcom-bam_dma-Fix-resource-leak.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/dmaengine-tegra210-adma-fix-transfer-failure.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/drm-amdgpu-fix-memory-leak.patch (git-fixes
  bnc#1151927 5.3.9).
- Update
  patches.suse/drm-amdgpu-gfx10-update-gfx-golden-settings.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/drm-amdgpu-gmc10-properly-set-BANK_SELECT-and-FRAGME.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/drm-amdgpu-powerplay-vega10-allow-undervolting-in-p7.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/drm-i915-Fix-PCH-reference-clock-for-FDI-on-HSW-BDW.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/gpio-max77620-Use-correct-unit-for-debounce-times.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/iio-adc-meson_saradc-Fix-memory-allocation-order.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/iio-fix-center-temperature-of-bmc150-accel-core.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/iio-imu-adis16400-fix-memory-leak.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/iio-imu-adis16400-release-allocated-memory-on-failur.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/iio-imu-st_lsm6dsx-fix-waitime-for-st_lsm6dsx-i2c-co.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/iwlwifi-exclude-GEO-SAR-support-for-3168.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/llc-fix-sk_buff-leak-in-llc_conn_service.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/llc-fix-sk_buff-leak-in-llc_sap_state_process.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/misc-fastrpc-prevent-memory-leak-in-fastrpc_dma_buf_.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/msft-hv-1953-HID-hyperv-Use-in-place-iterator-API-in-the-channel-.patch
  (fate#323887 bnc#1151927 5.3.9).
- Update
  patches.suse/nbd-verify-socket-is-supported-during-setup.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/net-ath6kl-Fix-a-NULL-ptr-deref-bug.patch
  (CVE-2019-15098,bsc#1146378,CVE-2019-15290,bsc#1146543
  bnc#1151927 5.3.9).
- Update
  patches.suse/net-sched-sch_sfb-don-t-call-qdisc_put-while-holding.patch
  (bsc#1154353 bnc#1151927 5.3.9).
- Update
  patches.suse/netfilter-conntrack-avoid-possible-false-sharing.patch
  (bsc#1154353 bnc#1151927 5.3.9).
- Update
  patches.suse/nl80211-fix-validation-of-mesh-path-nexthop.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/powerpc-powernv-Fix-CPU-idle-to-be-called-with-IRQs-.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/rtlwifi-Fix-potential-overflow-on-P2P-code.patch
  (bsc#1154372 CVE-2019-17666 bnc#1151927 5.3.9).
- Update
  patches.suse/rtlwifi-rtl_pci-Fix-problem-of-too-small-skb-len.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/rtw88-Fix-misuse-of-GENMASK-macro.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/rxrpc-Fix-call-ref-leak.patch (bsc#1154353
  bnc#1151927 5.3.9).
- Update
  patches.suse/rxrpc-Fix-trace-after-put-looking-at-the-put-peer-re.patch
  (bsc#1154353 bnc#1151927 5.3.9).
- Update
  patches.suse/rxrpc-rxrpc_peer-needs-to-hold-a-ref-on-the-rxrpc_lo.patch
  (bsc#1154353 bnc#1151927 5.3.9).
- Update
  patches.suse/sch_netem-fix-rcu-splat-in-netem_enqueue.patch
  (bsc#1154353 bnc#1151927 5.3.9).
- Update
  patches.suse/sched-fair-Fix-Wunused-but-set-variable-warnings.patch
  (bnc#1155798 (CPU scheduler functional and performance
  backports) bnc#1151927 5.3.9).
- Update
  patches.suse/sched-fair-Fix-low-cpu-usage-with-high-throttling-by-removing-expiration-of-cpu-local-slices.patch
  (bnc#1155798 (CPU scheduler functional and performance
  backports) bnc#1151927 5.3.9).
- Update
  patches.suse/sched-fair-Scale-bandwidth-quota-and-period-without-losing-quota-period-ratio-precision.patch
  (git fixes (sched) bnc#1151927 5.3.9).
- Update
  patches.suse/sched-vtime-Fix-guest-system-mis-accounting-on-task-switch.patch
  (git fixes (cputime accounting) bnc#1151927 5.3.9).
- Update
  patches.suse/scsi-qla2xxx-Fix-partial-flash-write-of-MBI.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.9).
- Update
  patches.suse/serial-8250_omap-Fix-gpio-check-for-auto-RTS-CTS.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/serial-mctrl_gpio-Check-for-NULL-pointer.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/staging-rtl8188eu-fix-null-dereference-when-kzalloc-.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/tracing-Initialize-iter-seq-after-zeroing-in-tracing.patch
  (bsc#1151508 bnc#1151927 5.3.9).
- Update patches.suse/tty-n_hdlc-fix-build-on-SPARC.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/tty-serial-owl-Fix-the-link-time-qualifier-of-owl_ua.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/tty-serial-rda-Fix-the-link-time-qualifier-of-rda_ua.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/usb-storage-Revert-commit-747668dbc061-usb-storage-S.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/usb-xhci-fix-Immediate-Data-Transfer-endianness.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/usb-xhci-fix-__le32-__le64-accessors-in-debugfs-code.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/virt-vbox-fix-memory-leak-in-hgcm_call_preprocess_li.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/virtio_ring-fix-stalls-for-packed-rings.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/x86-cpu-add-comet-lake-to-the-intel-cpu-models-header.patch
  (jsc#SLE-7935 bnc#1151927 5.3.9).
- Update
  patches.suse/xhci-Fix-use-after-free-regression-in-xhci-clear-hub.patch
  (git-fixes bnc#1151927 5.3.9).
- commit d0f752b
* Tue Nov 12 2019 hare@suse.de
- nvme: Move ctrl sqsize to generic space
  (bsc#1156419,jsc#SLE-8281).
- nvme: Add ctrl attributes for queue_count and sqsize
  (bsc#1156419,jsc#SLE-8281).
- commit 20e4a40
* Tue Nov 12 2019 hare@suse.de
- nvmet-tcp: remove superflous check on request sgl
  (bsc#1156419,jsc#SLE-8281).
- commit 19797e4
* Tue Nov 12 2019 hare@suse.de
- nvmet: change ppl to lpp (bsc#1156419,jsc#SLE-8281).
- commit 00bb531
* Tue Nov 12 2019 hare@suse.de
- blk-mq: apply normal plugging for HDD
  (bsc#1156419,jsc#SLE-8281).
- commit 1007f9a
* Tue Nov 12 2019 hare@suse.de
- iocost: bump up default latency targets for hard disks
  (bsc#1156419,jsc#SLE-8281).
- iocost: improve nr_lagging handling (bsc#1156419,jsc#SLE-8281).
- iocost: better trace vrate changes (bsc#1156419,jsc#SLE-8281).
- commit 6d144e8
* Tue Nov 12 2019 hare@suse.de
- block: t10-pi: fix -Wswitch warning (bsc#1156419,jsc#SLE-8281).
- block, bfq: increase update frequency of inject limit
  (bsc#1156419,jsc#SLE-8281).
- block, bfq: reduce upper bound for inject limit to
  max_rq_in_driver+1 (bsc#1156419,jsc#SLE-8281).
- block, bfq: update inject limit only after injection occurred
  (bsc#1156419,jsc#SLE-8281).
- commit 11db1c7
* Tue Nov 12 2019 hare@suse.de
- mmc: queue: Fix bigger segments usage
  (bsc#1156419,jsc#SLE-8281).
- dma-mapping: fix filename references (bsc#1156419,jsc#SLE-8281).
- iommu/dma: add a new dma_map_ops of get_merge_boundary()
  (bsc#1156419,jsc#SLE-8281).
- dma-mapping: introduce dma_get_merge_boundary()
  (bsc#1156419,jsc#SLE-8281).
- mmc: queue: use bigger segments if DMA MAP layer can merge
  the segments (bsc#1156419,jsc#SLE-8281).
- block: add a helper function to merge the segments
  (bsc#1156419,jsc#SLE-8281).
- commit 0574516
* Tue Nov 12 2019 hare@suse.de
- nvmet: fix a wrong error status returned in error log page
  (bsc#1156419,jsc#SLE-8281).
- nvme: send discovery log page change events to userspace
  (bsc#1156419,jsc#SLE-8281).
- nvme: add uevent variables for controller devices
  (bsc#1156419,jsc#SLE-8281).
- nvme: enable aen regardless of the presence of I/O queues
  (bsc#1156419,jsc#SLE-8281).
- nvme-fabrics: allow discovery subsystems accept a kato
  (bsc#1156419,jsc#SLE-8281).
- nvmet: Use PTR_ERR_OR_ZERO() in nvmet_init_discovery()
  (bsc#1156419,jsc#SLE-8281).
- nvme: Remove redundant assignment of cq vector
  (bsc#1156419,jsc#SLE-8281).
- nvme: Assign subsys instance from first ctrl
  (bsc#1156419,jsc#SLE-8281).
- nvme: tcp: remove redundant assignment to variable ret
  (bsc#1156419,jsc#SLE-8281).
- nvme: include admin_q sync with nvme_sync_queues
  (bsc#1156419,jsc#SLE-8281).
- nvme: Treat discovery subsystems as unique subsystems
  (bsc#1156419,jsc#SLE-8281).
- nvme: fix ns removal hang when failing to revalidate due to
  a transient error (bsc#1156419,jsc#SLE-8281).
- nvme: make nvme_report_ns_ids propagate error back
  (bsc#1156419,jsc#SLE-8281).
- nvme: make nvme_identify_ns propagate errors back
  (bsc#1156419,jsc#SLE-8281).
- nvme: pass status to nvme_error_status
  (bsc#1156419,jsc#SLE-8281).
- nvme-fc: Fail transport errors with NVME_SC_HOST_PATH
  (bsc#1156419,jsc#SLE-8281).
- nvme-tcp: fail command with NVME_SC_HOST_PATH_ERROR send failed
  (bsc#1156419,jsc#SLE-8281).
- nvme: fail cancelled commands with NVME_SC_HOST_PATH_ERROR
  (bsc#1156419,jsc#SLE-8281).
- commit b7d6f8e
* Tue Nov 12 2019 hare@suse.de
- block: also check RQF_STATS in blk_mq_need_time_stamp()
  (bsc#1156419,jsc#SLE-8281).
- commit 8e18ffe
* Tue Nov 12 2019 hare@suse.de
- bfq: Fix bfq linkage error (bsc#1156419,jsc#SLE-8281).
- block: bypass blk_set_runtime_active for uninitialized q->dev
  (bsc#1156419,jsc#SLE-8281).
- commit c4398cc
* Tue Nov 12 2019 hare@suse.de
- iocost_monitor: Report debt (bsc#1156419,jsc#SLE-8281).
- iocost_monitor: Report more info with higher accuracy
  (bsc#1156419,jsc#SLE-8281).
- iocost_monitor: Always use strings for json values
  (bsc#1156419,jsc#SLE-8281).
- commit 5643f67
* Tue Nov 12 2019 hare@suse.de
- blk-iocost: Don't let merges push vtime into the future
  (bsc#1156419,jsc#SLE-8281).
- blk-iocost: Account force-charged overage in absolute vtime
  (bsc#1156419,jsc#SLE-8281).
- commit 5e399b3
* Tue Nov 12 2019 hare@suse.de
- bfq: Add per-device weight (bsc#1156419,jsc#SLE-8281).
- bfq: Extract bfq_group_set_weight from bfq_io_set_weight_legacy
  (bsc#1156419,jsc#SLE-8281).
- bfq: Fix the missing barrier in __bfq_entity_update_weight_prio
  (bsc#1156419,jsc#SLE-8281).
- commit c8fb944
* Tue Nov 12 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and move:
  patches.suse/soundwire-depend-on-ACPI-OF.patch
  patches.suse/soundwire-depend-on-ACPI.patch
- commit db2a325
* Tue Nov 12 2019 mkubecek@suse.cz
- update upstream references
- update Patch-mainline:
  patches.suse/mm-gup-fix-a-misnamed-write-argument-and-a-related-bug.patch
  patches.suse/sched-Fix-pick_next_task-vs-change-pattern-race.patch
- commit f1c7235
* Tue Nov 12 2019 mkubecek@suse.cz
- move patches.suse/stacktrace-Don-t-skip-first-entry-on-noncurrent-task.patch into sorted section
- commit 2b73785
* Mon Nov 11 2019 mbrugger@suse.com
- arm64: Update config files. (bsc#1156466)
  Enable HW_RANDOM_OMAP used by machiattobin
  and mark omap-rng as supported
- commit 97cc63c
* Mon Nov 11 2019 hare@suse.de
- block: fix elevator_get_by_features()
  (bsc#1156419,jsc#SLE-8281).
- commit 178e768
* Mon Nov 11 2019 hare@suse.de
- iocost: don't nest spin_lock_irq in ioc_weight_write()
  (bsc#1156419,jsc#SLE-8281).
- nvme-tcp: Initialize sk->sk_ll_usec only with NET_RX_BUSY_POLL
  (bsc#1156419,jsc#SLE-8281).
- blkcg: Fix multiple bugs in blkcg_activate_policy()
  (bsc#1156419,jsc#SLE-8281).
- block: don't release queue's sysfs lock during switching
  elevator (bsc#1156419,jsc#SLE-8281).
- block: fix race between switching elevator and removing queues
  (bsc#1156419,jsc#SLE-8281).
- blk-iocost: Fix incorrect operation order during iocg free
  (bsc#1156419,jsc#SLE-8281).
- commit e443933
* Mon Nov 11 2019 hare@suse.de
- sd: Set ELEVATOR_F_ZBD_SEQ_WRITE for ZBC disks
  (bsc#1156419,jsc#SLE-8281).
- block: Set ELEVATOR_F_ZBD_SEQ_WRITE for nullblk zoned disks
  (bsc#1156419,jsc#SLE-8281).
- block: Delay default elevator initializatio
  (bsc#1156419,jsc#SLE-8281).
- commit 71cd228
* Mon Nov 11 2019 hare@suse.de
- block: Improve default elevator selection
  (bsc#1156419,jsc#SLE-8281).
- block: Introduce elevator features (bsc#1156419,jsc#SLE-8281).
- block: Change elevator_init_mq() to always succeed
  (bsc#1156419,jsc#SLE-8281).
- commit 2d709aa
* Mon Nov 11 2019 hare@suse.de
- block: Cleanup elevator_init_mq() use
  (bsc#1156419,jsc#SLE-8281).
- commit f9e5dd5
* Mon Nov 11 2019 hare@suse.de
- Documentation:kernel-per-CPU-kthreads.txt: Remove reference
  to elevator= (bsc#1156419,jsc#SLE-8281).
- Documenation: switching-sched: Remove notes about elevator
  argument (bsc#1156419,jsc#SLE-8281).
- block: elevator.c: Remove now unused elevator= argument
  (bsc#1156419,jsc#SLE-8281).
- commit 4c19565
* Mon Nov 11 2019 hare@suse.de
- nvme-rdma: Use rq_dma_dir macro (bsc#1156419,jsc#SLE-8281).
- nvme-fc: Use rq_dma_dir macro (bsc#1156419,jsc#SLE-8281).
- nvme-pci: Tidy up nvme_unmap_data (bsc#1156419,jsc#SLE-8281).
- commit f389b9a
* Mon Nov 11 2019 hare@suse.de
- nvme: make fabrics command run on a separate request queue
  (bsc#1156419,jsc#SLE-8281).
- Update
  patches.suse/nvme-rdma-Fix-max_hw_sectors-calculation.patch
  (bsc#1156419,jsc#SLE-8281).
- commit 6ad508a
* Mon Nov 11 2019 hare@suse.de
- nvme-pci: Support shared tags across queues for Apple 2018
  controllers (bsc#1156419,jsc#SLE-8281).
- nvme-pci: Add support for Apple 2018+ models
  (bsc#1156419,jsc#SLE-8281).
- nvme-pci: Add support for variable IO SQ element size
  (bsc#1156419,jsc#SLE-8281).
- nvme-pci: Pass the queue to SQ_SIZE/CQ_SIZE macros
  (bsc#1156419,jsc#SLE-8281).
- nvme: trace bio completion (bsc#1156419,jsc#SLE-8281).
- commit ab59099
* Mon Nov 11 2019 hare@suse.de
- nvmet-tcp: Add TOS for tcp transport (bsc#1156419,jsc#SLE-8281).
- nvme-tcp: Add TOS for tcp transport (bsc#1156419,jsc#SLE-8281).
- nvme-tcp: Use struct nvme_ctrl directly
  (bsc#1156419,jsc#SLE-8281).
- nvme-rdma: Add TOS for rdma transport
  (bsc#1156419,jsc#SLE-8281).
- nvme-fabrics: Add type of service (TOS) configuration
  (bsc#1156419,jsc#SLE-8281).
- nvmet-tcp: fix possible memory leak (bsc#1156419,jsc#SLE-8281).
- nvmet-tcp: fix possible NULL deref (bsc#1156419,jsc#SLE-8281).
- nvmet: trace: parse Get LBA Status command in detail
  (bsc#1156419,jsc#SLE-8281).
- nvme: trace: parse Get LBA Status command in detail
  (bsc#1156419,jsc#SLE-8281).
- nvme: trace: support for Get LBA Status opcode parsed
  (bsc#1156419,jsc#SLE-8281).
- nvme: add Get LBA Status command opcode
  (bsc#1156419,jsc#SLE-8281).
- commit 51901f2
* Mon Nov 11 2019 hare@suse.de
- nvme-tcp: support simple polling (bsc#1156419,jsc#SLE-8281).
- nvme: tcp: selects CRYPTO_CRC32C for nvme-tcp
  (bsc#1156419,jsc#SLE-8281).
- nvme: don't pass cap to nvme_disable_ctrl
  (bsc#1156419,jsc#SLE-8281).
- nvme: move sqsize setting to the core
  (bsc#1156419,jsc#SLE-8281).
- nvme-pci: set ctrl sqsize to the device q_depth
  (bsc#1156419,jsc#SLE-8281).
- nvme: have nvme_init_identify set ctrl->cap
  (bsc#1156419,jsc#SLE-8281).
- nvme-tcp: Use protocol specific operations while reading socket
  (bsc#1156419,jsc#SLE-8281).
- nvme-tcp: cleanup nvme_tcp_recv_pdu (bsc#1156419,jsc#SLE-8281).
- commit bda85fb
* Mon Nov 11 2019 hare@suse.de
- block: centralize PI remapping logic to the block layer
  (bsc#1156419,jsc#SLE-8281).
- block: use symbolic constants for t10_pi type
  (bsc#1156419,jsc#SLE-8281).
- commit e299de5
* Mon Nov 11 2019 jack@suse.cz
- block: elevator.c: Remove now unused elevator= argument
  (bsc#1156055).
- commit 95954cd
* Mon Nov 11 2019 hare@suse.de
- blkcg: add missing NULL check in ioc_cpd_alloc()
  (bsc#1156419,jsc#SLE-8281).
- blkcg: fix missing free on error path of blk_iocost_init()
  (bsc#1156419,jsc#SLE-8281).
- blkcg: blk-iocost: predeclare used structs
  (bsc#1156419,jsc#SLE-8281).
- blkcg: add tools/cgroup/iocost_coef_gen.py
  (bsc#1156419,jsc#SLE-8281).
- blkcg: add tools/cgroup/iocost_monitor.py
  (bsc#1156419,jsc#SLE-8281).
- blkcg: implement blk-iocost (bsc#1156419,jsc#SLE-8281).
- update config files (add BLK_CGROUP_IOCOST=y, BLK_RQ_ALLOC_TIME=y)
- blk-mq: add optional request->alloc_time_ns
  (bsc#1156419,jsc#SLE-8281).
- blkcg: s/RQ_QOS_CGROUP/RQ_QOS_LATENCY/
  (bsc#1156419,jsc#SLE-8281).
- block/rq_qos: implement rq_qos_ops->queue_depth_changed()
  (bsc#1156419,jsc#SLE-8281).
- block/rq_qos: add rq_qos_merge() (bsc#1156419,jsc#SLE-8281).
- blkcg: separate blkcg_conf_get_disk() out of blkg_conf_prep()
  (bsc#1156419,jsc#SLE-8281).
- blkcg: make ->cpd_init_fn() optional (bsc#1156419,jsc#SLE-8281).
- blkcg: pass @q and @blkcg into blkcg_pol_alloc_pd_fn()
  (bsc#1156419,jsc#SLE-8281).
- block: split .sysfs_lock into two locks
  (bsc#1156419,jsc#SLE-8281).
- block: add helper for checking if queue is registered
  (bsc#1156419,jsc#SLE-8281).
- blk-mq: don't hold q->sysfs_lock in blk_mq_map_swqueue
  (bsc#1156419,jsc#SLE-8281).
- block: don't hold q->sysfs_lock in elevator_init_mq
  (bsc#1156419,jsc#SLE-8281).
- block: Remove blk_mq_register_dev() (bsc#1156419,jsc#SLE-8281).
- block: move same page handling from __bio_add_pc_page to the
  callers (bsc#1156419,jsc#SLE-8281).
- block: create a bio_try_merge_pc_page helper
  (bsc#1156419,jsc#SLE-8281).
- block: improve the gap check in __bio_add_pc_page
  (bsc#1156419,jsc#SLE-8281).
- block: sed-opal: Removed duplicate OPAL_METHOD_LENGTH definition
  (bsc#1156419,jsc#SLE-8281).
- block: sed-opal: Remove always false conditional statement
  (bsc#1156419,jsc#SLE-8281).
- block: sed-opal: Add/remove spaces (bsc#1156419,jsc#SLE-8281).
- block: remove struct request_queue queue_head
  (bsc#1156419,jsc#SLE-8281).
- block: annotate refault stalls from IO submission
  (bsc#1156419,jsc#SLE-8281).
- block: stop exporting bio_map_kern (bsc#1156419,jsc#SLE-8281).
- lightnvm: pblk: use kvmalloc for metadata
  (bsc#1156419,jsc#SLE-8281).
- lightnvm: move metadata mapping to lower level driver
  (bsc#1156419,jsc#SLE-8281).
- lightnvm: remove nvm_submit_io_sync_fn
  (bsc#1156419,jsc#SLE-8281).
- commit e17d5ba
* Mon Nov 11 2019 tiwai@suse.de
- Update patch reference for ASoC SOF fix (CVE-2019-18812, bsc#1156277)
- commit 34489e1
* Mon Nov 11 2019 tiwai@suse.de
- ASoC: SOF: Intel: hda-stream: fix the CONFIG_ prefix missing
  (git-fixes).
- commit 0996041
* Mon Nov 11 2019 hare@suse.de
- blk-mq: balance mapping between present CPUs and queues
  (bsc#1156419,jsc#SLE-8281).
- null_blk: implement REQ_OP_ZONE_RESET_ALL
  (bsc#1156419,jsc#SLE-8281).
- scsi: implement REQ_OP_ZONE_RESET_ALL
  (bsc#1156419,jsc#SLE-8281).
- blk-zoned: implement REQ_OP_ZONE_RESET_ALL
  (bsc#1156419,jsc#SLE-8281).
- block: add req op to reset all zones and flag
  (bsc#1156419,jsc#SLE-8281).
- block: Fix a comment in blk_cleanup_queue()
  (bsc#1156419,jsc#SLE-8281).
- block: Fix spelling in the header above blkg_lookup()
  (bsc#1156419,jsc#SLE-8281).
- block: Improve physical block alignment of split bios
  (bsc#1156419,jsc#SLE-8281).
- block: Simplify blk_bio_segment_split()
  (bsc#1156419,jsc#SLE-8281).
- block: Simplify bvec_split_segs() (bsc#1156419,jsc#SLE-8281).
- block: Document the bio splitting functions
  (bsc#1156419,jsc#SLE-8281).
- block: Declare several function pointer arguments 'const'
  (bsc#1156419,jsc#SLE-8281).
- blk-mq: remove blk_mq_complete_request_sync
  (bsc#1156419,jsc#SLE-8281).
- nvme: wait until all completed request's complete fn is called
  (bsc#1156419,jsc#SLE-8281).
- nvme: don't abort completed request in nvme_cancel_request
  (bsc#1156419,jsc#SLE-8281).
- blk-mq: introduce blk_mq_tagset_wait_completed_request()
  (bsc#1156419,jsc#SLE-8281).
- blk-mq: introduce blk_mq_request_completed()
  (bsc#1156419,jsc#SLE-8281).
- commit 0d15be1
* Mon Nov 11 2019 tiwai@suse.de
- soc: imx: gpc: fix initialiser format (git-fixes).
- reset: fix reset_control_get_exclusive kerneldoc comment
  (git-fixes).
- reset: fix reset_control_lookup kerneldoc comment (git-fixes).
- reset: fix of_reset_control_get_count kerneldoc comment
  (git-fixes).
- reset: fix of_reset_simple_xlate kerneldoc comment (git-fixes).
- reset: Fix memory leak in reset_control_array_put() (git-fixes).
- iio: adc: stm32-adc: fix stopping dma (git-fixes).
- iio: imu: inv_mpu6050: fix no data on MPU6050 (git-fixes).
- iio: imu: adis16480: make sure provided frequency is positive
  (git-fixes).
- intel_th: gth: Fix the window switching sequence (git-fixes).
- thunderbolt: Drop unnecessary read when writing LC command in
  Ice Lake (git-fixes).
- thunderbolt: Fix lockdep circular locking depedency warning
  (git-fixes).
- clocksource/drivers/mediatek: Fix error handling (git-fixes).
- pinctrl: cherryview: Allocate IRQ chip dynamic (git-fixes).
- pinctrl: cherryview: Fix irq_valid_mask calculation (git-fixes).
- pinctrl: intel: Avoid potential glitches if pin is in GPIO mode
  (git-fixes).
- watchdog: bd70528: Add MODULE_ALIAS to allow module auto loading
  (git-fixes).
- watchdog: imx_sc_wdt: Pretimeout should follow SCU firmware
  format (git-fixes).
- watchdog: meson: Fix the wrong value of left time (git-fixes).
- mac80211: fix ieee80211_txq_setup_flows() failure path
  (git-fixes).
- nfc: netlink: fix double device reference drop (git-fixes).
- r8169: fix page read in r8168g_mdio_read (git-fixes).
- can: rx-offload: can_rx_offload_offload_one(): do not increase
  the skb_queue beyond skb_queue_len_max (git-fixes).
- can: rx-offload: can_rx_offload_queue_tail(): fix error
  handling, avoid skb mem leak (git-fixes).
- can: rx-offload: can_rx_offload_queue_sorted(): fix error
  handling, avoid skb mem leak (git-fixes).
- can: c_can: c_can_poll(): only read status register after
  status IRQ (git-fixes).
- can: peak_usb: fix slab info leak (git-fixes).
- can: peak_usb: fix a potential out-of-sync while decoding
  packets (git-fixes).
- can: flexcan: disable completely the ECC mechanism (git-fixes).
- can: usb_8dev: fix use-after-free on disconnect (git-fixes).
- can: mcba_usb: fix use-after-free on disconnect (git-fixes).
- can: gs_usb: gs_can_open(): prevent memory leak (git-fixes).
- can: dev: add missing of_node_put() after calling
  of_get_child_by_name() (git-fixes).
- dccp: do not leak jiffies on the wire (git-fixes).
- pwm: bcm-iproc: Prevent unloading the driver module while in
  use (git-fixes).
- drm/amdgpu: register gpu instance before fan boost feature
  enablment (git-fixes).
- drm/i915: Avoid HPD poll detect triggering a new detect cycle
  (git-fixes).
- fbdev: c2p: Fix link failure on non-inlining (git-fixes).
- clk: samsung: exynos5420: Preserve PLL configuration during
  suspend/resume (git-fixes).
- clk: samsung: exynos542x: Move G3D subsystem clocks to its
  sub-CMU (git-fixes).
- clk: samsung: exynos5433: Fix error paths (git-fixes).
- clk: sunxi-ng: a80: fix the zero'ing of bits 16 and 18
  (git-fixes).
- clk: sunxi: Fix operator precedence in sunxi_divs_clk_setup
  (git-fixes).
- clk: ti: clkctrl: Fix failed to enable error with double udelay
  timeout (git-fixes).
- clk: at91: avoid sleeping early (git-fixes).
- clk: at91: sam9x60: fix programmable clock (git-fixes).
- r8152: add device id for Lenovo ThinkPad USB-C Dock Gen 2
  (git-fixes).
- dmaengine: cppi41: Fix cppi41_dma_prep_slave_sg() when idle
  (git-fixes).
- dmaengine: qcom: bam_dma: Fix resource leak (git-fixes).
- dmaengine: sprd: Fix the possible memory leak issue (git-fixes).
- dmaengine: imx-sdma: fix size check for sdma script_number
  (git-fixes).
- dmaengine: tegra210-adma: fix transfer failure (git-fixes).
- dmaengine: sprd: Fix the link-list pointer register
  configuration issue (git-fixes).
- drm/amdgpu: fix error handling in amdgpu_bo_list_create
  (git-fixes).
- drm/amdgpu: fix potential VM faults (git-fixes).
- drm/komeda: Don't flush inactive pipes (git-fixes).
- regulator: pfuze100-regulator: Variable "val" in
  pfuze100_regulator_probe() could be uninitialized (git-fixes).
- regulator: ti-abb: Fix timeout in
  ti_abb_wait_txdone/ti_abb_clear_all_txdone (git-fixes).
- usb: gadget: udc: core: Fix segfault if udc_bind_to_driver()
  for pending driver fails (git-fixes).
- commit d6c29b6
* Mon Nov 11 2019 jack@suse.cz
- block: Warn if elevator= parameter is used (bsc#1156055).
- commit 87814cc
* Mon Nov 11 2019 mgorman@suse.de
- sched: Fix pick_next_task() vs 'change' pattern race (git fixes
  (sched)).
- commit 75aac31
* Mon Nov 11 2019 tiwai@suse.de
- ASoC: SOF: topology: Fix bytes control size checks (git-fixes).
- ASoC: ti: sdma-pcm: Add back the flags parameter for non
  standard dma names (git-fixes).
- ASoC: SOF: ipc: Fix memory leak in sof_set_get_large_ctrl_data
  (git-fixes).
- ASoC: SOF: Fix memory leak in sof_dfsentry_write (git-fixes).
- ASoC: kirkwood: fix device remove ordering (git-fixes).
- ASoC: rsnd: dma: fix SSI9 4/5/6/7 busif dma address (git-fixes).
- ASoC: hdmi-codec: drop mutex locking again (git-fixes).
- ASoC: kirkwood: fix external clock probe defer (git-fixes).
- ASoC: msm8916-wcd-analog: Fix RX1 selection in RDAC2 MUX
  (git-fixes).
- ASoC: SOF: control: return true when kcontrol values change
  (git-fixes).
- ASoC: Intel: sof-rt5682: add a check for devm_clk_get
  (git-fixes).
- ASoC: msm8916-wcd-digital: add missing MIX2 path for RX1/2
  (git-fixes).
- ASoC: wm_adsp: Don't generate kcontrols without READ flags
  (git-fixes).
- ASoC: intel: bytcr_rt5651: add null check to
  support_button_press (git-fixes).
- ASoC: intel: sof_rt5682: add remove function to disable jack
  (git-fixes).
- ASoC: rt5682: add NULL handler to set_jack function (git-fixes).
- ASoC: SOF: Intel: hda: Disable DMI L1 entry during capture
  (git-fixes).
- update config files (add SND_SOC_SOF_HDA_ALWAYS_ENABLE_DMI_L1=y on x86_64)
- ASoC: SOF: Intel: initialise and verify FW crash dump data
  (git-fixes).
- ASoC: SOF: Intel: hda: fix warnings during FW load (git-fixes).
- ASoC: SOF: topology: fix parse fail issue for byte/bool tuple
  types (git-fixes).
- ASoC: SOF: loader: fix kernel oops on firmware boot failure
  (git-fixes).
- ASoC: wm8994: Do not register inapplicable controls for WM1811
  (git-fixes).
- ASoC: samsung: arndale: Add missing OF node dereferencing
  (git-fixes).
- ASoC: pcm3168a: The codec does not support S32_LE (git-fixes).
- commit 6ff8cc0
* Mon Nov 11 2019 jslaby@suse.cz
- Refresh
  patches.suse/stacktrace-Don-t-skip-first-entry-on-noncurrent-task.patch.
  Update upstream status.
- commit fac489f
* Mon Nov 11 2019 mgorman@suse.de
- mm/gup: fix a misnamed "write" argument, and a related bug
  (git fixes (mm/gup)).
- commit d17d319
* Mon Nov 11 2019 mgorman@suse.de
- blacklist.conf: Blacklist change in THP allocation behaviour
- commit e194e08
* Mon Nov 11 2019 mgorman@suse.de
- blacklist.conf: Blacklist change in THP allocation behaviour
- commit 7e51886
* Mon Nov 11 2019 msuchanek@suse.de
- powerpc/mm/mce: Keep irqs disabled during lockless page table
  walk (bsc#1156395).
- commit 9275ddd
* Mon Nov 11 2019 glin@suse.com
- bpf: Change size to u64 for bpf_map_{area_alloc, charge_init}()
  (bsc#1155518).
- commit 04b6b83
* Mon Nov 11 2019 glin@suse.com
- bpf: Allow narrow loads of bpf_sysctl fields with offset > 0
  (bsc#1155518).
- commit 1c48ac9
* Fri Nov  8 2019 tiwai@suse.de
- Move upstreamed CA0132 patch into sorted section
- commit 04d225f
* Fri Nov  8 2019 tiwai@suse.de
- ALSA: timer: Fix incorrectly assigned timer instance
  (git-fixes).
- ALSA: hda: hdmi - add Tigerlake support (git-fixes).
- ALSA: bebob: fix to detect configured source of sampling clock
  for Focusrite Saffire Pro i/o series (git-fixes).
- commit b69261d
* Fri Nov  8 2019 tiwai@suse.de
- HID: Fix assumption that devices have inputs (git-fixes).
- Refresh
  patches.suse/HID-logitech-hidpp-split-g920_get_config.patch.
- commit 313ea5d
* Fri Nov  8 2019 tiwai@suse.de
- HID: wacom: generic: Treat serial number and related fields
  as unsigned (git-fixes).
- USB: serial: whiteheat: fix line-speed endianness (git-fixes).
- USB: gadget: Reject endpoints with 0 maxpacket value
  (git-fixes).
- usb: xhci: fix __le32/__le64 accessors in debugfs code
  (git-fixes).
- net: dsa: bcm_sf2: Fix IMP setup for port different than 8
  (git-fixes).
- rtlwifi: rtl_pci: Fix problem of too small skb->len (git-fixes).
- batman-adv: Avoid free/alloc race when handling OGM buffer
  (git-fixes).
- net: openvswitch: free vport unless register_netdevice()
  succeeds (git-fixes).
- drm/amdgpu/gmc10: properly set BANK_SELECT and FRAGMENT_SIZE
  (git-fixes).
- drm/amdgpu/powerplay/vega10: allow undervolting in p7
  (git-fixes).
- drm/amdgpu/gfx10: update gfx golden settings (git-fixes).
- HID: i2c-hid: add Trekstor Primebook C11B to descriptor override
  (git-fixes).
- misc: fastrpc: prevent memory leak in fastrpc_dma_buf_attach
  (git-fixes).
- iio: imu: adis16400: fix memory leak (git-fixes).
- iio: imu: adis16400: release allocated memory on failure
  (git-fixes).
- iio: fix center temperature of bmc150-accel-core (git-fixes).
- staging: rtl8188eu: fix null dereference when kzalloc fails
  (git-fixes).
- serial: 8250_omap: Fix gpio check for auto RTS/CTS (git-fixes).
- serial: mctrl_gpio: Check for NULL pointer (git-fixes).
- drm/amdgpu: fix memory leak (git-fixes).
- gpio: max77620: Use correct unit for debounce times (git-fixes).
- rtw88: Fix misuse of GENMASK macro (git-fixes).
- commit 7396a58
* Fri Nov  8 2019 tiwai@suse.de
- fjes: Handle workqueue allocation failure
  (CVE-2019-16231,bsc#1150466).
- commit 026d312
* Fri Nov  8 2019 tiwai@suse.de
- Update patch reference tag for dwc3 security fix (CVE-2019-18813, bsc#1156278)
- commit 2c755c4
* Fri Nov  8 2019 mkubecek@suse.cz
- series.conf: move sortable patches into sorted section
- move into sorted section:
  patches.suse/scsi-target-compare-full-CHAP_A-Algorithm-strings.patch
  patches.suse/scsi-target-fix-SendTargets-All-string-compares.patch
  patches.suse/scsi-target-remove-unused-extension-parameters.patch
  patches.suse/scsi-target-iscsi-CHAP-add-support-for-SHA1-SHA256-a.patch
  patches.suse/scsi-target-iscsi-tie-the-challenge-length-to-the-ha.patch
  patches.suse/scsi-target-iscsi-rename-some-variables-to-avoid-con.patch
- commit 80f0994
* Thu Nov  7 2019 msuchanek@suse.de
- Refresh patches.suse/powerpc-fadump-when-fadump-is-supported-register-the.patch.
- commit 035dc7c
* Thu Nov  7 2019 ddiss@suse.de
- patches.suse/scsi-target-iscsi-rename-some-variables-to-avoid-con.patch:
  (jsc#SES-1080).
- patches.suse/scsi-target-iscsi-tie-the-challenge-length-to-the-ha.patch:
  (jsc#SES-1080).
- patches.suse/scsi-target-iscsi-CHAP-add-support-for-SHA1-SHA256-a.patch:
  (jsc#SES-1080).
- patches.suse/scsi-target-remove-unused-extension-parameters.patch:
  (jsc#SES-1080).
- patches.suse/scsi-target-fix-SendTargets-All-string-compares.patch:
  (jsc#SES-1080).
- patches.suse/scsi-target-compare-full-CHAP_A-Algorithm-strings.patch:
  (jsc#SES-1080).
- commit d620bcd
* Thu Nov  7 2019 oneukum@suse.com
- media: Revert "media: vimc: propagate pixel format in the
  stream" (git-fixes).
- commit 34b5c83
* Thu Nov  7 2019 oneukum@suse.com
- media: vimc: stream: fix style of argument description
  (git-fixes).
- commit b398d8c
* Thu Nov  7 2019 oneukum@suse.com
- media: vimc: stream: remove obsolete function doc (git-fixes).
- commit eb41435
* Thu Nov  7 2019 oneukum@suse.com
- media: Revert "media: vimc: Remove or modify stream checks"
  (git-fixes).
- commit 249cb6d
* Thu Nov  7 2019 mkubecek@suse.cz
- supported.conf: cleanup
- drop modules built into vmlinux now:
  crypto/crc32
  drivers/video/macmodes
  fs/autofs4/autofs4
- drop extension
  drivers/hwmon/ina3221
- commit 6d1628e
* Thu Nov  7 2019 mkubecek@suse.cz
- update upstream references
- update Patch-mainline:
  patches.suse/cpusets-Rebuild-root-domain-deadline-accounting-information.patch
  patches.suse/membarrier-Fix-RCU-locking-bug-caused-by-faulty-merge.patch
  patches.suse/sched-Add-task_struct-pointer-to-sched_class-set_curr_task.patch
  patches.suse/sched-Allow-put_prev_task-to-drop-rq-lock.patch
  patches.suse/sched-Rework-CPU-hotplug-task-selection.patch
  patches.suse/sched-Rework-pick_next_task-slow-path.patch
  patches.suse/sched-core-Streamle-calls-to-task_rq_unlock.patch
  patches.suse/sched-fair-Avoid-redundant-EAS-calculation.patch
  patches.suse/sched-fair-Change-task_numa_work-storage-to-static.patch
  patches.suse/sched-fair-Expose-newidle_balance.patch
  patches.suse/sched-fair-Fall-back-to-sched-idle-CPU-if-idle-CPU-isn-t-found.patch
  patches.suse/sched-fair-Fix-Wunused-but-set-variable-warnings.patch
  patches.suse/sched-fair-Fix-low-cpu-usage-with-high-throttling-by-removing-expiration-of-cpu-local-slices.patch
  patches.suse/sched-fair-Introduce-fits_capacity.patch
  patches.suse/sched-fair-Move-init_numa_balancing-below-task_numa_work.patch
  patches.suse/sched-fair-Move-task_numa_work-init-to-init_numa_balancing.patch
  patches.suse/sched-fair-Speed-up-energy-aware-wake-ups.patch
  patches.suse/sched-fair-Start-tracking-SCHED_IDLE-tasks-count-in-cfs_rq.patch
  patches.suse/sched-isolation-Prefer-housekeeping-CPU-in-local-node.patch
  patches.suse/sched-membarrier-Fix-p-mm-membarrier_state-racy-load.patch
  patches.suse/sched-membarrier-Remove-redundant-check.patch
  patches.suse/sched-membarrier-Return-ENOMEM-to-userspace-on-memory-allocation-failure.patch
  patches.suse/sched-membarrier-Skip-IPIs-when-mm-mm_users-1.patch
  patches.suse/sched-rt-deadline-Fix-set_next_task-vs-pick_next_task.patch
  patches.suse/sched-stats-Fix-unlikely-use-of-sched_info_on.patch
  patches.suse/sched-topology-Add-partition_sched_domains_locked.patch
  patches.suse/stop_machine-Fix-stop_cpus_in_progress-ordering.patch
- commit 7497999
* Wed Nov  6 2019 mgorman@suse.de
- membarrier: Fix RCU locking bug caused by faulty merge
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit 49ddad8
* Wed Nov  6 2019 mgorman@suse.de
- sched/fair: Avoid redundant EAS calculation (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Fix -Wunused-but-set-variable warnings (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/membarrier: Return -ENOMEM to userspace on memory
  allocation failure (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/membarrier: Skip IPIs when mm->mm_users == 1 (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/membarrier: Fix p->mm->membarrier_state racy load
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/membarrier: Remove redundant check (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/fair: Speed-up energy-aware wake-ups (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched: Rework pick_next_task() slow-path (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched: Allow put_prev_task() to drop rq->lock (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Expose newidle_balance() (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched: Add task_struct pointer to sched_class::set_curr_task
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched: Rework CPU hotplug task selection (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/{rt,deadline}: Fix set_next_task vs pick_next_task
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- stop_machine: Fix stop_cpus_in_progress ordering (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Fix low cpu usage with high throttling by removing
  expiration of cpu-local slices (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- cpusets: Rebuild root domain deadline accounting information
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/core: Streamle calls to task_rq_unlock() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/topology: Add partition_sched_domains_locked()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Introduce fits_capacity() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/isolation: Prefer housekeeping CPU in local node
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/stats: Fix unlikely() use of sched_info_on() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Fall back to sched-idle CPU if idle CPU isn't
  found (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Start tracking SCHED_IDLE tasks count in cfs_rq
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Change task_numa_work() storage to static
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Move task_numa_work() init to init_numa_balancing()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Move init_numa_balancing() below task_numa_work()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit daa1350
* Wed Nov  6 2019 oneukum@suse.com
- blacklist.conf: rendered moot by subsequent removal of the driver
  (which we didn't compile in SLE15 in the first place)
- commit 4972748
* Wed Nov  6 2019 yousaf.kaukab@suse.com
- enetc: Add mdio bus driver for the PCIe MDIO endpoint
  (jsc#SLE-9316).
- enetc: Clean up makefile (jsc#SLE-9316).
- commit 2f5843d
* Wed Nov  6 2019 yousaf.kaukab@suse.com
- config: arm64: enable nxp ls1028a (jsc#SLE-9263)
  Update supported.conf accordingly
- commit 3c653ff
* Wed Nov  6 2019 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into sorted section:
  patches.suse/rtlwifi-Fix-potential-overflow-on-P2P-code.patch
- whitespace cleanup
  No effect on expanded tree.
- commit 913dbd6
* Wed Nov  6 2019 tiwai@suse.de
- rpm/kernel-source.spec.in: Fix dependency of kernel-devel (bsc#1154043)
- commit ceb9273
* Wed Nov  6 2019 jslaby@suse.cz
- rpm/kernel-binary.spec.in: add COMPRESS_VMLINUX (bnc#1155921)
  Let COMPRESS_VMLINUX determine the compression used for vmlinux. By
  default (historically), it is gz.
- commit c8b2d9f
* Wed Nov  6 2019 glin@suse.com
- selftests/bpf: More compatible nc options in test_lwt_ip_encap
  (bsc#1155518).
- selftests/bpf: Set rp_filter in test_flow_dissector
  (bsc#1155518).
- selftests/bpf: fix endianness issues in test_sysctl
  (bsc#1155518).
- selftests/bpf: improve unexpected success reporting in
  test_syctl (bsc#1155518).
- selftests/bpf: fix "ctx:write sysctl:write read ok" on s390
  (bsc#1155518).
- selftests/bpf: introduce bpf_cpu_to_be64 and bpf_be64_to_cpu
  (bsc#1155518).
- selftests/bpf: fix race in test_tcp_rtt test (bsc#1155518).
- tools: bpftool: move "__printf()" attributes to header file
  (bsc#1155518).
- tools: bpftool: fix format string for p_err() in
  detect_common_prefix() (bsc#1155518).
- tools: bpftool: fix format string for p_err() in
  query_flow_dissector() (bsc#1155518).
- tools: bpftool: fix argument for p_err() in BTF do_dump()
  (bsc#1155518).
- tools: bpftool: fix format strings and arguments for
  jsonw_printf() (bsc#1155518).
- tools: bpftool: fix arguments for p_err() in do_event_pipe()
  (bsc#1155518).
- commit 19d2eb7
* Wed Nov  6 2019 mgorman@suse.de
- series_sort: Move AMD-specific load balancing patch to sorted patch section
- commit c65ad73
* Tue Nov  5 2019 mkubecek@suse.cz
- Update upstream references:
  patches.suse/hugetlbfs-don-t-retry-when-pool-page-allocations-start-to-fail.patch
  patches.suse/mm-compaction-raise-compaction-priority-after-it-withdrawns.patch
  patches.suse/mm-compaction.c-remove-unnecessary-zone-parameter-in-isolate_migratepages.patch
  patches.suse/mm-filemap.c-don-t-initiate-writeback-if-mapping-has-no-dirty-pages.patch
  patches.suse/mm-filemap.c-rewrite-mapping_needs_writeback-in-less-fancy-manner.patch
  patches.suse/mm-mempolicy.c-remove-unnecessary-nodemask-check-in-kernel_migrate_pages.patch
  patches.suse/mm-reclaim-cleanup-should_continue_reclaim.patch
  patches.suse/mm-reclaim-make-should_continue_reclaim-perform-dryrun-detection.patch
  patches.suse/mm-replace-list_move_tail-with-add_page_to_lru_list_tail.patch
  patches.suse/mm-sl-aou-b-guarantee-natural-alignment-for-kmalloc-power-of-two.patch
  patches.suse/mm-sl-ou-b-improve-memory-accounting.patch
  patches.suse/mm-vmscan-do-not-share-cgroup-iteration-between-reclaimers.patch
  patches.suse/sched-topology-Improve-load-balancing-on-AMD-EPYC.patch
- commit 471d837
* Tue Nov  5 2019 tiwai@suse.de
- ALSA: hda/ca0132 - Fix possible workqueue stall (bsc#1155836).
- commit a383566
* Tue Nov  5 2019 tbogendoerfer@suse.de
- supported.conf: mark efa and siw as supported
- commit 6c0057f
* Tue Nov  5 2019 tbogendoerfer@suse.de
- net: fix installing orphaned programs (bsc#1154353).
- net: cls_bpf: fix NULL deref on offload filter removal
  (bsc#1154353).
- net: phylink: Fix phylink_dbg() macro (bsc#1154353).
- inet: stop leaking jiffies on the wire (bsc#1154353).
- ixgbe: Remove duplicate clear_bit() call (jsc#SLE-7979
  jsc#SLE-7981).
- e1000: fix memory leaks (jsc#SLE-8100).
- i40e: Fix receive buffer starvation for AF_XDP (jsc#SLE-8025).
- igb: Fix constant media auto sense switching when no cable is
  connected (jsc#SLE-7967 jsc#SLE-8010).
- igb: Enable media autosense for the i350 (jsc#SLE-7967
  jsc#SLE-8010).
- igb/igc: Don't warn on fatal read failures when the device is
  removed (jsc#SLE-7967 jsc#SLE-8010).
- tcp: increase tcp_max_syn_backlog max value (bsc#1154353).
- netdevsim: Fix use-after-free during device dismantle
  (bsc#1154353).
- cxgb4: fix panic when attaching to ULD fail (jsc#SLE-8389).
- net: annotate lockless accesses to sk->sk_napi_id (bsc#1154353).
- net: annotate accesses to sk->sk_incoming_cpu (bsc#1154353).
- mlxsw: core: Unpublish devlink parameters during reload
  (bsc#1154488).
- qed: Optimize execution time for nvm attributes configuration
  (jsc#SLE-8401).
- vxlan: fix unexpected failure of vxlan_changelink()
  (bsc#1154353).
- qed: fix spelling mistake "queuess" -> "queues" (jsc#SLE-8401).
- net/mlx5e: Initialize on stack link modes bitmap (jsc#SLE-8464).
- net/mlx5e: Fix ethtool self test: link speed (jsc#SLE-8464).
- net/mlx5e: Fix handling of compressed CQEs in case of low NAPI
  budget (jsc#SLE-8464).
- net/mlx5e: Don't store direct pointer to action's tunnel info
  (jsc#SLE-8464).
- net/mlx5: Fix NULL pointer dereference in extended destination
  (jsc#SLE-8464).
- net/mlx5: Fix rtable reference leak (jsc#SLE-8464).
- net/mlx5e: Only skip encap flows update when encap init failed
  (jsc#SLE-8464).
- net/mlx5e: Replace kfree with kvfree when free vhca stats
  (jsc#SLE-8464).
- net/mlx5e: Remove incorrect match criteria assignment line
  (jsc#SLE-8464).
- net/mlx5e: Determine source port properly for vlan push action
  (jsc#SLE-8464).
- net: rtnetlink: fix a typo fbd -> fdb (bsc#1154353).
- bonding: fix using uninitialized mode_lock (bsc#1154353).
- vxlan: check tun_info options_len properly (bsc#1154353).
- erspan: fix the tun_info options_len check for erspan
  (bsc#1154353).
- net: hisilicon: Fix ping latency when deal with high throughput
  (bsc#1154353).
- net/mlx4_core: Dynamically set guaranteed amount of counters
  per VF (jsc#SLE-8460).
- net: hisilicon: Fix "Trying to free already-free IRQ"
  (bsc#1154353).
- net: fix sk_page_frag() recursion from memory reclaim
  (bsc#1154353).
- udp: fix data-race in udp_set_dev_scratch() (bsc#1154353).
- net: add READ_ONCE() annotation in __skb_wait_for_more_packets()
  (bsc#1154353).
- net: use skb_queue_empty_lockless() in busy poll contexts
  (bsc#1154353).
- net: use skb_queue_empty_lockless() in poll() handlers
  (bsc#1154353).
- udp: use skb_queue_empty_lockless() (bsc#1154353).
- net: add skb_queue_empty_lockless() (bsc#1154353).
- ipvs: move old_secure_tcp into struct netns_ipvs (bsc#1154353).
- ipvs: don't ignore errors in case refcounting ip_vs module fails
  (bsc#1154353).
- netfilter: nft_payload: fix missing check for matching length
  in offloads (bsc#1154353).
- netfilter: nf_flow_table: set timeout before insertion into
  hashes (bsc#1154353).
- xsk: Fix registration of Rx-only sockets (bsc#1154353).
- xdp: Handle device unregister for devmap_hash map type
  (bsc#1154353).
- xdp: Prevent overflow in devmap_hash cost calculation for
  32-bit builds (bsc#1154353).
- bpf: lwtunnel: Fix reroute supplying invalid dst (bsc#1154353).
- ipv4: fix route update on metric change (bsc#1154353).
- net: Zeroing the structure ethtool_wolinfo in ethtool_get_wol()
  (bsc#1154353).
- cxgb4: request the TX CIDX updates to status page
  (jsc#SLE-8389).
- netns: fix GFP flags in rtnl_net_notifyid() (bsc#1154353).
- net: sch_generic: Use pfifo_fast as fallback scheduler for
  CAN hardware (bsc#1154353).
- net: remove unnecessary variables and callback (bsc#1154353).
- vxlan: add adjacent link to limit depth level (bsc#1154353).
- net: core: add ignore flag to netdev_adjacent structure
  (bsc#1154353).
- team: fix nested locking lockdep warning (bsc#1154353).
- bonding: use dynamic lockdep key instead of subclass
  (bsc#1154353).
- bonding: fix unexpected IFF_BONDING bit unset (bsc#1154353).
- net: core: add generic lockdep keys (bsc#1154353).
- net: core: limit nested device depth (bsc#1154353).
- keys: Fix memory leak in copy_net_ns (bsc#1154353).
- net/flow_dissector: switch to siphash (bsc#1154353).
- ipv6: include <net/addrconf.h> for missing declarations
  (bsc#1154353).
- bnxt_en: Avoid disabling pci device in bnxt_remove_one()
  for already disabled device (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Minor formatting changes in FW devlink_health_reporter
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Adjust the time to wait before polling firmware
  readiness (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix devlink NVRAM related byte order related issues
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix the size of devlink MSIX parameters (jsc#SLE-8371
  bsc#1153274).
- ipv4: fix IPSKB_FRAG_PMTU handling with fragmentation
  (bsc#1154353).
- net/mlx5: fix memory leak in mlx5_fw_fatal_reporter_dump
  (jsc#SLE-8464).
- net/mlx5: prevent memory leak in mlx5_fpga_conn_create_cq
  (jsc#SLE-8464).
- net/mlx5e: TX, Fix consumer index of error cqe dump
  (jsc#SLE-8464).
- net/mlx5e: kTLS, Enhance TX resync flow (jsc#SLE-8464).
- net/mlx5e: kTLS, Save a copy of the crypto info (jsc#SLE-8464).
- net/mlx5e: kTLS, Remove unneeded cipher type checks
  (jsc#SLE-8464).
- net/mlx5e: kTLS, Limit DUMP wqe size (jsc#SLE-8464).
- net/mlx5e: kTLS, Fix missing SQ edge fill (jsc#SLE-8464).
- net/mlx5e: kTLS, Fix page refcnt leak in TX resync error flow
  (jsc#SLE-8464).
- net/mlx5e: kTLS, Save by-value copy of the record frags
  (jsc#SLE-8464).
- net/mlx5e: kTLS, Save only the frag page to release at
  completion (jsc#SLE-8464).
- net/mlx5e: kTLS, Size of a Dump WQE is fixed (jsc#SLE-8464).
- net/mlx5e: kTLS, Release reference on DUMPed fragments in
  shutdown flow (jsc#SLE-8464).
- net/mlx5e: Tx, Zero-memset WQE info struct upon update
  (jsc#SLE-8464).
- net/mlx5e: Tx, Fix assumption of single WQEBB of NOP in cleanup
  flow (jsc#SLE-8464).
- SUNRPC: Destroy the back channel when we destroy the host
  transport (bsc#1154353).
- SUNRPC: The RDMA back channel mustn't disappear while requests
  are outstanding (bsc#1154353).
- SUNRPC: The TCP back channel mustn't disappear while requests
  are outstanding (bsc#1154353).
- RDMA/hns: Prevent memory leaks of eq->buf_list (jsc#SLE-8449).
- RDMA/iw_cxgb4: Avoid freeing skb twice in arp failure case
  (jsc#SLE-8392).
- RDMA/mlx5: Use irq xarray locking for mkey_table (jsc#SLE-8446).
- IB/core: Avoid deadlock during netlink message handling
  (jsc#SLE-8449).
- RDMA/nldev: Skip counter if port doesn't match (jsc#SLE-8449).
- RDMA/uverbs: Prevent potential underflow (jsc#SLE-8449).
- IB/core: Use rdma_read_gid_l2_fields to compare GID L2 fields
  (jsc#SLE-8449).
- RDMA/qedr: Fix reported firmware version (jsc#SLE-8215).
- RDMA/siw: free siw_base_qp in kref release routine
  (jsc#SLE-8381).
- RDMA/iwcm: move iw_rem_ref() calls out of spinlock
  (jsc#SLE-8449).
- iw_cxgb4: fix ECN check on the passive accept (jsc#SLE-8392).
- IB/hfi1: Use a common pad buffer for 9B and 16B packets
  (jsc#SLE-8449).
- IB/hfi1: Avoid excessive retry for TID RDMA READ request
  (jsc#SLE-8449).
- RDMA/mlx5: Clear old rate limit when closing QP (jsc#SLE-8446).
- net: reorder 'struct net' fields to avoid false sharing
  (bsc#1154353).
- net: netem: correct the parent's backlog when corrupted packet
  was dropped (bsc#1154353).
- net: netem: fix error path for corrupted GSO frames
  (bsc#1154353).
- net: hns3: fix mis-counting IRQ vector numbers issue
  (bsc#1154353).
- mlxsw: spectrum_trap: Push Ethernet header before reporting trap
  (bsc#1154488).
- net: ensure correct skb->tstamp in various fragmenters
  (bsc#1154353).
- tcp: fix a possible lockdep splat in tcp_done() (bsc#1154353).
- net: cavium: Use the correct style for SPDX License Identifier
  (bsc#1154353).
- tcp: annotate sk->sk_wmem_queued lockless reads (bsc#1154353).
- tcp: annotate sk->sk_sndbuf lockless reads (bsc#1154353).
- tcp: annotate sk->sk_rcvbuf lockless reads (bsc#1154353).
- tcp: annotate tp->urg_seq lockless reads (bsc#1154353).
- tcp: annotate tp->snd_nxt lockless reads (bsc#1154353).
- tcp: annotate tp->write_seq lockless reads (bsc#1154353).
- tcp: annotate tp->copied_seq lockless reads (bsc#1154353).
- tcp: annotate tp->rcv_nxt lockless reads (bsc#1154353).
- tcp: add rcu protection around tp->fastopen_rsk (bsc#1154353).
- net: silence KCSAN warnings about sk->sk_backlog.len reads
  (bsc#1154353).
- net: annotate sk->sk_rcvlowat lockless reads (bsc#1154353).
- net: silence KCSAN warnings around sk_add_backlog() calls
  (bsc#1154353).
- tcp: annotate lockless access to tcp_memory_pressure
  (bsc#1154353).
- net: add {READ|WRITE}_ONCE() annotations on ->rskq_accept_head
  (bsc#1154353).
- net: avoid possible false sharing in sk_leave_memory_pressure()
  (bsc#1154353).
- netfilter: conntrack: avoid possible false sharing
  (bsc#1154353).
- netns: fix NLM_F_ECHO mechanism for RTM_NEWNSID (bsc#1154353).
- sctp: add chunks to sk_backlog when the newsk sk_socket is
  not set (bsc#1154353).
- ip6erspan: remove the incorrect mtu limit for ip6erspan
  (bsc#1154353).
- net/mlx5: DR, Allow insertion of duplicate rules (jsc#SLE-8464).
- rxrpc: rxrpc_peer needs to hold a ref on the rxrpc_local record
  (bsc#1154353).
- rxrpc: Fix trace-after-put looking at the put call record
  (bsc#1154353).
- rxrpc: Fix trace-after-put looking at the put connection record
  (bsc#1154353).
- rxrpc: Fix trace-after-put looking at the put peer record
  (bsc#1154353).
- rxrpc: Fix call ref leak (bsc#1154353).
- commit ccf9a99
* Tue Nov  5 2019 mbrugger@suse.com
- rpm/mkspec-dtb: add mt76 based dtb package
- commit 8ff92d0
* Tue Nov  5 2019 tiwai@suse.de
- usb: dwc3: gadget: fix race when disabling ep with cancelled
  xfers (git-fixes).
- USB: serial: whiteheat: fix potential slab corruption
  (git-fixes).
- UAS: Revert commit 3ae62a42090f ("UAS: fix alignment of
  scatter/gather segments") (git-fixes).
- usb-storage: Revert commit 747668dbc061 ("usb-storage: Set
  virt_boundary_mask to avoid SG overflows") (git-fixes).
- usb: xhci: fix Immediate Data Transfer endianness (git-fixes).
- xhci: Fix use-after-free regression in xhci clear hub TT
  implementation (git-fixes).
- USB: ldusb: fix control-message timeout (git-fixes).
- USB: ldusb: fix ring-buffer locking (git-fixes).
- usb: dwc3: pci: prevent memory leak in dwc3_pci_probe
  (git-fixes).
- usb: gadget: udc: atmel: Fix interrupt storm in FIFO mode
  (git-fixes).
- usb: dwc3: select CONFIG_REGMAP_MMIO (git-fixes).
- hwmon: (ina3221) Fix read timeout issue (git-fixes).
- r8169: fix wrong PHY ID issue with RTL8168dp (git-fixes).
- mt76: dma: fix buffer unmap with non-linear skbs (git-fixes).
- nl80211: fix validation of mesh path nexthop (git-fixes).
- wimax: i2400: Fix memory leak in i2400m_op_rfkill_sw_toggle
  (git-fixes).
- virt_wifi: fix refcnt leak in module exit routine (git-fixes).
- macsec: fix refcnt leak in module exit routine (git-fixes).
- keys: Fix memory leak in copy_net_ns (git-fixes).
- drm/i915: Fix PCH reference clock for FDI on HSW/BDW
  (git-fixes).
- drm/v3d: Fix memory leak in v3d_submit_cl_ioctl (git-fixes).
- commit 7b0a0d1
* Tue Nov  5 2019 mgorman@suse.de
- mm, sl[aou]b: guarantee natural alignment for
  kmalloc(power-of-two) (bnc#1155780 (VM/FS functional and
  performance backports)).
- mm, sl[ou]b: improve memory accounting (bnc#1155780 (VM/FS
  functional and performance backports)).
- hugetlbfs: don't retry when pool page allocations start to fail
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, compaction: raise compaction priority after it withdrawns
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, reclaim: cleanup should_continue_reclaim() (bnc#1155780
  (VM/FS functional and performance backports)).
- mm, reclaim: make should_continue_reclaim perform dryrun
  detection (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm/mempolicy.c: remove unnecessary nodemask check in
  kernel_migrate_pages() (bnc#1155780 (VM/FS functional and
  performance backports)).
- mm/compaction.c: remove unnecessary zone parameter in
  isolate_migratepages() (bnc#1155780 (VM/FS functional and
  performance backports)).
- mm: vmscan: do not share cgroup iteration between reclaimers
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/filemap.c: rewrite mapping_needs_writeback in less
  fancy manner (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm/filemap.c: don't initiate writeback if mapping has no
  dirty pages (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm: replace list_move_tail() with add_page_to_lru_list_tail()
  (bnc#1155780 (VM/FS functional and performance backports)).
- commit d426df6
* Tue Nov  5 2019 jslaby@suse.cz
- stacktrace: Don't skip first entry on noncurrent tasks
  (bnc#1154866).
- commit cc9ff55
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0056-acpi-Disable-ACPI-table-override-if-the-kernel-is-lo.patch.
  This patch be replaced by 6ea0e815fc in v5.4-rc1. (jsc#SLE-9870)
- commit 76eea73
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0055-acpi-Ignore-acpi_rsdp-kernel-param-when-the-kernel-h.patch.
  This patch be replaced by 41fa1ee9c6 in v5.4-rc1. (jsc#SLE-9870)
- commit a511e8c
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0054-ACPI-Limit-access-to-custom_method-when-the-kernel-i.patch.
  This patch be replaced by f474e1486 in v5.4-rc1. (jsc#SLE-9870)
- commit 881b574
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0053-asus-wmi-Restrict-debugfs-interface-when-the-kernel-.patch.
  This patch be replaced by 5496197f9b in v5.4-rc1. (jsc#SLE-9870)
- commit 26e7156
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0052-x86-Restrict-MSR-access-when-the-kernel-is-locked-do.patch.
  This patch be replaced by 95f5e95f41 in v5.4-rc1. (jsc#SLE-9870)
- commit d5a4f81
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0051-x86-Lock-down-IO-port-access-when-the-kernel-is-lock.patch.
  This patch be replaced by 9b9d8dda1e in v5.4-rc1. (jsc#SLE-9870)
- commit a338a65
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0050-PCI-Lock-down-BAR-access-when-the-kernel-is-locked-d.patch.
  This patch be replaced by eb627e1772 in v5.4-rc1. (jsc#SLE-9870)
- commit 35fdce5
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0048-hibernate-Disable-when-the-kernel-is-locked-down.patch.
  This patch be replaced by 38bd94b8a in v5.4-rc1. (jsc#SLE-9870)
- commit a36f246
* Tue Nov  5 2019 mkubecek@suse.cz
- update upstream references
- move to "almost mainline" section:
  patches.suse/autonuma-fix-watermark-checking-in-migrate_balanced_pgdat.patch
  patches.suse/autonuma-reduce-cache-footprint-when-scanning-page-tables.patch
- update patch-mainline:
  patches.suse/mm-slub.c-init_on_free-1-should-wipe-freelist-ptr-for-bulk-allocations.patch
  patches.suse/sched-fair-Scale-bandwidth-quota-and-period-without-losing-quota-period-ratio-precision.patch
  patches.suse/sched-vtime-Fix-guest-system-mis-accounting-on-task-switch.patch
  No effect on expanded tree.
- commit 509d57a
* Mon Nov  4 2019 mgorman@suse.de
- Refresh
  patches.suse/sched-topology-Improve-load-balancing-on-AMD-EPYC.patch.
- commit d1f7e6e
* Mon Nov  4 2019 msuchanek@suse.de
- rpm/kernel-subpackage-spec: Mention debuginfo in the subpackage
  description (bsc#1149119).
- commit 525ec92
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0047-kexec_file-restrict-if-the-kernel-is-locked-down.patch.
  This patch be replaced by 155bdd30a in v5.4-rc1. (jsc#SLE-9870)
- commit 539b083
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0047-kexec_file-split-KEXEC_VERIFY_SIG.patch.
  This patch be replaced by 99d5cadfd in v5.4-rc1. (jsc#SLE-9870)
- commit b4392d9
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0046-Copy-secure_boot-flag-in-boot-params-across-kexec-re.patch.
  This patch be replaced by fef5dad987 in v5.4-rc1. (jsc#SLE-9870)
- commit 2ac33a1
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0045-kexec-Disable-at-runtime-if-the-kernel-is-locked-dow.patch.
  This patch be replaced by 7d31f4602f in v5.4-rc1. (jsc#SLE-9870)
- commit 6378a1f
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0043-Restrict-dev-mem-and-dev-kmem-when-the-kernel-is-loc.patch.
  This patch be replaced by 9b9d8dda1e in v5.4-rc1. (jsc#SLE-9870)
- commit 471bb54
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0042-Enforce-module-signatures-if-the-kernel-is-locked-do.patch.
  This patch be replaced by 49fcf732bd in v5.4-rc1. (jsc#SLE-9870)
- commit 0f1ab5f
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0040-Add-the-ability-to-lock-down-access-to-the-running-k.patch.
  This patch be replaced by 9e47d31d6a and 000d388ed3 in v5.4-rc1. (jsc#SLE-9870)
- commit a3aff83
* Mon Nov  4 2019 jslaby@suse.cz
- powerpc/powernv: Fix CPU idle to be called with IRQs disabled
  (git-fixes).
- efi/tpm: Return -EINVAL when determining tpm final events log
  size fails (git-fixes).
- commit 0afb81a
* Mon Nov  4 2019 mgorman@suse.de
- autonuma: Reduce cache footprint when scanning page tables
  (bnc#1155756).
- autonuma: fix watermark checking in migrate_balanced_pgdat()
  (bnc#1155756).
- commit 92ab99b
* Mon Nov  4 2019 glin@suse.com
- bpf: Fix use after free in bpf_get_prog_name (bsc#1155518).
- bpf: Fix use after free in subprog's jited symbol removal
  (bsc#1155518).
- commit 0ffd4be
* Sun Nov  3 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference:
  patches.suse/scsi-lpfc-Check-queue-pointer-before-use.patch
  patches.suse/scsi-qla2xxx-Fix-partial-flash-write-of-MBI.patch
  patches.suse/scsi-qla2xxx-Initialized-mailbox-to-prevent-driver-l.patch
  patches.suse/scsi-qla2xxx-fixup-incorrect-usage-of-host_byte.patch
  patches.suse/scsi-qla2xxx-stop-timer-in-shutdown-path.patch
- no effect on expanded tree
- commit 37e310e
* Fri Nov  1 2019 tiwai@suse.de
- ALSA: timer: Fix mutex deadlock at releasing card (git-fixes).
- ALSA: hda - Fix mutex deadlock in HDMI codec driver (git-fixes).
- Revert "ALSA: hda: Flush interrupts on disabling" (git-fixes).
- ALSA: bebob: Fix prototype of helper function to return negative
  value (git-fixes).
- ALSA: hda/realtek - Fix 2 front mics of codec 0x623 (git-fixes).
- ALSA: hda/realtek - Add support for ALC623 (git-fixes).
- ALSA: usb-audio: Add DSD support for Gustard U16/X26 USB
  Interface (git-fixes).
- commit ed66481
* Fri Nov  1 2019 mkubecek@suse.cz
- Update upstream references:
  patches.suse/mm-meminit-Recalculate-pcpu-batch-and-high-limits-after-init-completes.patch.
  patches.suse/mm-pcp-Share-common-code-between-memory-hotplug-and-percpu-sysctl-handler.patch.
  patches.suse/mm-pcpu-Make-zone-pcp-updates-and-reset-internal-to-the-mm.patch.
- move these patches to "soon to be mainline" section
- commit 8b0a210
* Fri Nov  1 2019 mgorman@suse.de
- sched/vtime: Fix guest/system mis-accounting on task switch
  (git fixes (cputime accounting)).
- sched/fair: Scale bandwidth quota and period without losing
  quota/period ratio precision (git fixes (sched)).
- commit dc7f4dd
* Fri Nov  1 2019 mgorman@suse.de
- mm/slub.c: init_on_free=1 should wipe freelist ptr for bulk
  allocations (git fixes (mm/slub)).
- commit 1fe1553
* Fri Nov  1 2019 mgorman@suse.de
- mm, pcpu: Make zone pcp updates and reset internal to the mm
  (bnc#1155628).
- mm, pcp: Share common code between memory hotplug and percpu
  sysctl handler (bnc#1155628).
- mm, meminit: Recalculate pcpu batch and high limits after init
  completes (bnc#1155628).
- commit ca89c1c
* Thu Oct 31 2019 mkubecek@suse.cz
- refresh config files
  No functional change.
- commit b484ff3
* Thu Oct 31 2019 mkoutny@suse.com
- Update config files: Disable CONFIG_RT_GROUP_SCHED (jsc#SLE-10427)
- commit db9fda6
* Thu Oct 31 2019 jlee@suse.com
- MODSIGN: make new include file self contained (jsc#SLE-9870).
- commit 9916222
* Thu Oct 31 2019 glin@suse.com
- bpf: fix BTF limits (bsc#1155518).
- commit 97d5e03
* Thu Oct 31 2019 jlee@suse.com
- MODSIGN: Export module signature definitions (jsc#SLE-9870).
- Update config files.
- Refresh
  patches.suse/KEYS-Make-use-of-platform-keyring-for-module-signatu.patch.
- commit 10961d4
* Thu Oct 31 2019 mkubecek@suse.cz
- Update references (add CVE-2019-10220 bsc#1144903 bso#14072):
  patches.suse/Make-filldir-64-verify-the-directory-entry-filename-.patch
  patches.suse/filldir-64-remove-WARN_ON_ONCE-for-bad-directory-ent.patch
- commit e4c1e0f
* Wed Oct 30 2019 dwagner@suse.de
- scsi: qla2xxx: stop timer in shutdown path (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix partial flash write of MBI (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Initialized mailbox to prevent driver load
  failure (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: fixup incorrect usage of host_byte (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- commit 1cb635f
* Wed Oct 30 2019 dwagner@suse.de
- Refresh patches.suse/scsi-lpfc-Check-queue-pointer-before-use.patch
- commit 56420bc
* Wed Oct 30 2019 jslaby@suse.cz
- nbd: verify socket is supported during setup (git-fixes).
- commit 85aab98
* Wed Oct 30 2019 jlee@suse.com
- x86/boot/acpi: Move get_cmdline_acpi_rsdp() under #ifdef guard
  (jsc#SLE-9870).
- tracefs: Revert ccbd54ff54e8 ("tracefs: Restrict tracefs when
  the kernel is locked down") (jsc#SLE-9870).
- kexec: Fix file verification on S390 (jsc#SLE-9870).
- security: constify some arrays in lockdown LSM (jsc#SLE-9870).
- lockdown: Print current->comm in restriction messages
  (jsc#SLE-9870).
- efi: Restrict efivar_ssdt_load when the kernel is locked down
  (jsc#SLE-9870).
- tracefs: Restrict tracefs when the kernel is locked down
  (jsc#SLE-9870).
- debugfs: Restrict debugfs when the kernel is locked down
  (jsc#SLE-9870).
- kexec: Allow kexec_file() with appropriate IMA policy when
  locked down (jsc#SLE-9870).
- lockdown: Lock down perf when in confidentiality mode
  (jsc#SLE-9870).
- bpf: Restrict bpf when kernel lockdown is in confidentiality
  mode (jsc#SLE-9870).
- lockdown: Lock down tracing and perf kprobes when in
  confidentiality mode (jsc#SLE-9870).
- lockdown: Lock down /proc/kcore (jsc#SLE-9870).
- x86/mmiotrace: Lock down the testmmiotrace module
  (jsc#SLE-9870).
- lockdown: Lock down module params that specify hardware
  parameters (eg. ioport) (jsc#SLE-9870).
- lockdown: Lock down TIOCSSERIAL (jsc#SLE-9870).
- lockdown: Prohibit PCMCIA CIS storage when the kernel is locked
  down (jsc#SLE-9870).
- acpi: Disable ACPI table override if the kernel is locked down
  (jsc#SLE-9870).
- acpi: Ignore acpi_rsdp kernel param when the kernel has been
  locked down (jsc#SLE-9870).
- ACPI: Limit access to custom_method when the kernel is locked
  down (jsc#SLE-9870).
- x86/msr: Restrict MSR access when the kernel is locked down
  (jsc#SLE-9870).
- x86: Lock down IO port access when the kernel is locked down
  (jsc#SLE-9870).
- PCI: Lock down BAR access when the kernel is locked down
  (jsc#SLE-9870).
- hibernate: Disable when the kernel is locked down
  (jsc#SLE-9870).
- kexec_file: Restrict at runtime if the kernel is locked down
  (jsc#SLE-9870).
- kexec_file: split KEXEC_VERIFY_SIG into KEXEC_SIG and
  KEXEC_SIG_FORCE (jsc#SLE-9870).
- Update config files. (jsc#SLE-9870)
- lockdown: Copy secure_boot flag in boot params across kexec
  reboot (jsc#SLE-9870).
- kexec_load: Disable at runtime if the kernel is locked down
  (jsc#SLE-9870).
- lockdown: Restrict /dev/{mem,kmem,port} when the kernel is
  locked down (jsc#SLE-9870).
- lockdown: Enforce module signatures if the kernel is locked down
  (jsc#SLE-9870).
- security: Add a static lockdown policy LSM (jsc#SLE-9870).
- Update config files. (jsc#SLE-9870)
- security: Add a "locked down" LSM hook (jsc#SLE-9870).
- security: Support early LSMs (jsc#SLE-9870).
- commit f827a66
* Tue Oct 29 2019 dbueso@suse.de
- tasks, sched/core: RCUify the assignment of rq->curr
  (bsc#1155364).
- tasks, sched/core: With a grace period after
  finish_task_switch(), remove unnecessary code (bsc#1155364).
- tasks, sched/core: Ensure tasks are available for a grace
  period after leaving the runqueue (bsc#1155364).
- tasks: Add a count of task RCU users (bsc#1155364).
- commit 270b1d3
* Tue Oct 29 2019 tiwai@suse.de
- net: dsa: fix switch tree list (git-fixes).
- net: dsa: b53: Do not clear existing mirrored port mask
  (git-fixes).
- net: dsa: rtl8366rb: add missing of_node_put after calling
  of_get_child_by_name (git-fixes).
- net: dsa: qca8k: Use up to 7 ports for all operations
  (git-fixes).
- net: dsa: mv88e6xxx: fix SMI bit checking (git-fixes).
- commit 0fcc138
* Tue Oct 29 2019 tiwai@suse.de
- lib/vdso: Make clock_getres() POSIX compliant again (git-fixes).
- commit 88590ee
* Tue Oct 29 2019 tiwai@suse.de
- net: phy: bcm7xxx: define soft_reset for 40nm EPHY (git-fixes).
- net: phy: micrel: Discern KSZ8051 and KSZ8795 PHYs (git-fixes).
- net: phy: fix write to mii-ctrl1000 register (git-fixes).
- commit 904870e
* Tue Oct 29 2019 tiwai@suse.de
- dmaengine: iop-adma.c: fix printk format warning (git-fixes).
- commit bb35c8c
* Tue Oct 29 2019 tiwai@suse.de
- ASoC: core: use list_del_init and move it back to
  soc_cleanup_component (git-fixes).
- ASoC: core: delete component->card_list in soc_remove_component
  only (git-fixes).
- commit bb8cb13
* Tue Oct 29 2019 tiwai@suse.de
- Refresh patches.suse/ASoC-es8328-Fix-copy-paste-error-in-es8328_right_lin.patch
  Add a cherry-picked commit to ignore, too
- commit 758f004
* Tue Oct 29 2019 jslaby@suse.cz
- Linux 5.3.8 (bnc#1151927 5.3.8).
- lib/vdso: Make clock_getres() POSIX compliant again (bnc#1151927
  5.3.8).
- perf/aux: Fix AUX output stopping (bnc#1151927 5.3.8).
- CIFS: Fix use after free of file info structures (bnc#1151927
  5.3.8).
- cifs: Fix missed free operations (bnc#1151927 5.3.8).
- CIFS: avoid using MID 0xFFFF (bnc#1151927 5.3.8).
- MIPS: tlbex: Fix build_restore_pagemask KScratch restore
  (bnc#1151927 5.3.8).
- binder: Don't modify VMA bounds in ->mmap handler (bnc#1151927
  5.3.8).
- io_uring: fix bad inflight accounting for
  SETUP_IOPOLL|SETUP_SQTHREAD (bnc#1151927 5.3.8).
- io_uring: used cached copies of sq->dropped and cq->overflow
  (bnc#1151927 5.3.8).
- io_uring: Fix race for sqes with userspace (bnc#1151927 5.3.8).
- io_uring: Fix broken links with offloading (bnc#1151927 5.3.8).
- io_uring: Fix corrupted user_data (bnc#1151927 5.3.8).
- s390/kaslr: add support for R_390_GLOB_DAT relocation type
  (bnc#1151927 5.3.8).
- s390/zcrypt: fix memleak at release (bnc#1151927 5.3.8).
- fs/dax: Fix pmd vs pte conflict detection (bnc#1151927 5.3.8).
- scsi: core: try to get module before removing device
  (bnc#1151927 5.3.8).
- scsi: ch: Make it possible to open a ch device multiple times
  again (bnc#1151927 5.3.8).
- KVM: PPC: Book3S HV: XIVE: Ensure VP isn't already in use
  (bnc#1151927 5.3.8).
- drm/amdgpu/vce: fix allocation size in enc ring test
  (bnc#1151927 5.3.8).
- drm/amdgpu: user pages array memory leak fix (bnc#1151927
  5.3.8).
- drm/amdgpu/vcn: fix allocation size in enc ring test
  (bnc#1151927 5.3.8).
- drm/amdgpu/uvd7: fix allocation size in enc ring test (v2)
  (bnc#1151927 5.3.8).
- drm/amdgpu/uvd6: fix allocation size in enc ring test (v2)
  (bnc#1151927 5.3.8).
- mmc: cqhci: Commit descriptors before setting the doorbell
  (bnc#1151927 5.3.8).
- of: reserved_mem: add missing of_node_put() for proper
  ref-counting (bnc#1151927 5.3.8).
- opp: of: drop incorrect lockdep_assert_held() (bnc#1151927
  5.3.8).
- tracing: Fix race in perf_trace_buf initialization (bnc#1151927
  5.3.8).
- EDAC/ghes: Fix Use after free in ghes_edac remove path
  (bnc#1151927 5.3.8).
- Btrfs: fix qgroup double free after failure to reserve metadata
  for delalloc (bnc#1151927 5.3.8).
- btrfs: don't needlessly create extent-refs kernel thread
  (bnc#1151927 5.3.8).
- Btrfs: add missing extents release on file extent cluster
  relocation error (bnc#1151927 5.3.8).
- Refresh
  patches.suse/0001-btrfs-qgroup-Always-free-PREALLOC-META-reserve-in-bt.patch.
- x86/apic/x2apic: Fix a NULL pointer deref when handling a
  dying cpu (bnc#1151927 5.3.8).
- irqchip/sifive-plic: Switch to fasteoi flow (bnc#1151927 5.3.8).
- xen/netback: fix error path of xenvif_connect_data()
  (bnc#1151927 5.3.8).
- ipv4: fix race condition between route lookup and invalidation
  (bnc#1151927 5.3.8).
- ipv4: Return -ENETUNREACH if we can't create route but saddr
  is valid (bnc#1151927 5.3.8).
- net: phy: micrel: Update KSZ87xx PHY name (bnc#1151927 5.3.8).
- net: phy: micrel: Discern KSZ8051 and KSZ8795 PHYs (bnc#1151927
  5.3.8).
- net: stmmac: disable/enable ptp_ref_clk in suspend/resume flow
  (bnc#1151927 5.3.8).
- net: phy: Fix "link partner" information disappear issue
  (bnc#1151927 5.3.8).
- rxrpc: use rcu protection while reading sk->sk_user_data
  (bnc#1151927 5.3.8).
- net: i82596: fix dma_alloc_attr for sni_82596 (bnc#1151927
  5.3.8).
- sctp: change sctp_prot .no_autobind with true (bnc#1151927
  5.3.8).
- sched: etf: Fix ordering of packets with same txtime
  (bnc#1151927 5.3.8).
- net: avoid potential infinite loop in tc_ctl_action()
  (bnc#1151927 5.3.8).
- net/sched: fix corrupted L2 header with MPLS 'push' and 'pop'
  actions (bnc#1151927 5.3.8).
- net: avoid errors when trying to pop MLPS header on non-MPLS
  packets (bnc#1151927 5.3.8).
- iwlwifi: pcie: change qu with jf devices to use qu configuration
  (bnc#1151927 5.3.8).
- netdevsim: Fix error handling in nsim_fib_init and nsim_fib_exit
  (bnc#1151927 5.3.8).
- rxrpc: Fix possible NULL pointer access in ICMP handling
  (bnc#1151927 5.3.8).
- mac80211: Reject malformed SSID elements (bnc#1151927 5.3.8).
- net_sched: fix backward compatibility for TCA_ACT_KIND
  (bnc#1151927 5.3.8).
- net_sched: fix backward compatibility for TCA_KIND (bnc#1151927
  5.3.8).
- zram: fix race between backing_dev_show and backing_dev_store
  (bnc#1151927 5.3.8).
- ocfs2: fix panic due to ocfs2_wq is null (bnc#1151927 5.3.8).
- hugetlbfs: don't access uninitialized memmaps in
  pfn_range_valid_gigantic() (bnc#1151927 5.3.8).
- mm: memblock: do not enforce current limit for memblock_phys*
  family (bnc#1151927 5.3.8).
- mm: memcg: get number of pages on the LRU list in memcgroup
  base on lru_zone_size (bnc#1151927 5.3.8).
- mm: memcg/slab: fix panic in __free_slab() caused by premature
  memcg pointer release (bnc#1151927 5.3.8).
- mm/memunmap: don't access uninitialized memmap in
  memunmap_pages() (bnc#1151927 5.3.8).
- mm/page_owner: don't access uninitialized memmaps when reading
  /proc/pagetypeinfo (bnc#1151927 5.3.8).
- mm/memory-failure.c: don't access uninitialized memmaps in
  memory_failure() (bnc#1151927 5.3.8).
- fs/proc/page.c: don't access uninitialized memmaps in
  fs/proc/page.c (bnc#1151927 5.3.8).
- drivers/base/memory.c: don't access uninitialized memmaps in
  soft_offline_page_store() (bnc#1151927 5.3.8).
- nvme-pci: Set the prp2 correctly when using more than 4k page
  (bnc#1151927 5.3.8).
- blk-rq-qos: fix first node deletion of rq_qos_del() (bnc#1151927
  5.3.8).
- filldir: remove WARN_ON_ONCE() for bad directory entries
  (bnc#1151927 5.3.8).
- ceph: just skip unrecognized info in ceph_reply_info_extra
  (bnc#1151927 5.3.8).
- dm cache: fix bugs when a GFP_NOWAIT allocation fails
  (bnc#1151927 5.3.8).
- cpufreq: Avoid cpufreq_suspend() deadlock on system shutdown
  (bnc#1151927 5.3.8).
- arm64: Allow CAVIUM_TX2_ERRATUM_219 to be selected (bnc#1151927
  5.3.8).
- Update config files.
  CAVIUM_TX2_ERRATUM_219=y (the default)
- arm64: Avoid Cavium TX2 erratum 219 when switching TTBR
  (bnc#1151927 5.3.8).
- arm64: Enable workaround for Cavium TX2 erratum 219 when
  running SMT (bnc#1151927 5.3.8).
- arm64: KVM: Trap VM ops when ARM64_WORKAROUND_CAVIUM_TX2_219_TVM
  is set (bnc#1151927 5.3.8).
- xtensa: fix change_bit in exclusive access option (bnc#1151927
  5.3.8).
- xtensa: drop EXPORT_SYMBOL for outs*/ins* (bnc#1151927 5.3.8).
- drm/edid: Add 6 bpc quirk for SDC panel in Lenovo G50
  (bnc#1151927 5.3.8).
- drm/amdgpu/sdma5: fix mask value of POLL_REGMEM packet for
  pipe sync (bnc#1151927 5.3.8).
- drm/amdgpu: Bail earlier when amdgpu.cik_/si_support is not
  set to 1 (bnc#1151927 5.3.8).
- drm/i915/userptr: Never allow userptr into the mappable GGTT
  (bnc#1151927 5.3.8).
- Input: synaptics-rmi4 - avoid processing unknown IRQs
  (bnc#1151927 5.3.8).
- scsi: zfcp: fix reaction on bit error threshold notification
  (bnc#1151927 5.3.8).
- scsi: core: save/restore command resid for error handling
  (bnc#1151927 5.3.8).
- scsi: sd: Ignore a failure to sync cache due to lack of
  authorization (bnc#1151927 5.3.8).
- parisc: Fix vmap memory leak in ioremap()/iounmap() (bnc#1151927
  5.3.8).
- mm/memory-failure: poison read receives SIGKILL instead of
  SIGBUS if mmaped more than once (bnc#1151927 5.3.8).
- mm/slub: fix a deadlock in show_slab_objects() (bnc#1151927
  5.3.8).
- uaccess: implement a proper unsafe_copy_to_user() and switch
  filldir over to it (bnc#1151927 5.3.8).
- elf: don't use MAP_FIXED_NOREPLACE for elf executable mappings
  (bnc#1151927 5.3.8).
- ARM: dts: am4372: Set memory bandwidth limit for DISPC
  (bnc#1151927 5.3.8).
- ARM: OMAP2+: Fix warnings with broken omap2_set_init_voltage()
  (bnc#1151927 5.3.8).
- ARM: OMAP2+: Add missing LCDC midlemode for am335x (bnc#1151927
  5.3.8).
- ARM: OMAP2+: Fix missing reset done flag for am3 and am43
  (bnc#1151927 5.3.8).
- ARM: dts: Fix gpio0 flags for am335x-icev2 (bnc#1151927 5.3.8).
- ARM: dts: Fix wrong clocks for dra7 mcasp (bnc#1151927 5.3.8).
- namespace: fix namespace.pl script to support relative paths
  (bnc#1151927 5.3.8).
- scsi: megaraid: disable device when probe failed after enabled
  device (bnc#1151927 5.3.8).
- scsi: ufs: skip shutdown if hba is not powered (bnc#1151927
  5.3.8).
- Make filldir() verify the directory entry filename is valid
  (bnc#1151927 5.3.8).
- Convert filldir() from __put_user() to unsafe_put_user()
  (bnc#1151927 5.3.8).
- net: phy: fix write to mii-ctrl1000 register (bnc#1151927
  5.3.8).
- net: phy: allow for reset line to be tied to a sleepy GPIO
  controller (bnc#1151927 5.3.8).
- r8152: Set macpassthru in reset_resume callback (bnc#1151927
  5.3.8).
- netfilter: nft_connlimit: disable bh on garbage collection
  (bnc#1151927 5.3.8).
- net: ag71xx: fix mdio subnode support (bnc#1151927 5.3.8).
- net: stmmac: Do not stop PHY if WoL is enabled (bnc#1151927
  5.3.8).
- Refresh
  patches.suse/net-stmmac-Avoid-deadlock-on-suspend-resume.patch.
- net: stmmac: Correctly take timestamp for PTPv2 (bnc#1151927
  5.3.8).
- net: stmmac: dwmac4: Always update the MAC Hash Filter
  (bnc#1151927 5.3.8).
- net: stmmac: xgmac: Not all Unicast addresses may be available
  (bnc#1151927 5.3.8).
- net: dsa: rtl8366rb: add missing of_node_put after calling
  of_get_child_by_name (bnc#1151927 5.3.8).
- mac80211: fix txq null pointer dereference (bnc#1151927 5.3.8).
- nl80211: fix null pointer dereference (bnc#1151927 5.3.8).
- ieee802154: ca8210: prevent memory leak (bnc#1151927 5.3.8).
- net: dsa: qca8k: Use up to 7 ports for all operations
  (bnc#1151927 5.3.8).
- s390/mm: fix -Wunused-but-set-variable warnings (bnc#1151927
  5.3.8).
- mips: Loongson: Fix the link time qualifier of 'serial_exit()'
  (bnc#1151927 5.3.8).
- MIPS: dts: ar9331: fix interrupt-controller size (bnc#1151927
  5.3.8).
- riscv: Fix memblock reservation for device tree blob
  (bnc#1151927 5.3.8).
- RISC-V: Clear load reservations while restoring hart contexts
  (bnc#1151927 5.3.8).
- selftests: kvm: Fix libkvm build error (bnc#1151927 5.3.8).
- xen/efi: Set nonblocking callbacks (bnc#1151927 5.3.8).
- drm/komeda: prevent memory leak in komeda_wb_connector_add
  (bnc#1151927 5.3.8).
- drm: Clear the fence pointer when writeback job signaled
  (bnc#1151927 5.3.8).
- drm: Free the writeback_job when it with an empty fb
  (bnc#1151927 5.3.8).
- drm/amd/display: memory leak (bnc#1151927 5.3.8).
- drm/amdgpu: fix multiple memory leaks in acp_hw_init
  (bnc#1151927 5.3.8).
- loop: change queue block size to match when using DIO
  (bnc#1151927 5.3.8).
- nvme-rdma: fix possible use-after-free in connect timeout
  (bnc#1151927 5.3.8).
- nvme: allow 64-bit results in passthru commands (bnc#1151927
  5.3.8).
- nvme: Add quirk for Kingston NVME SSD running FW E8FK11.T
  (bnc#1151927 5.3.8).
- Added QUIRKs for ADATA XPG SX8200 Pro 512GB (bnc#1151927 5.3.8).
- nvme-rdma: Fix max_hw_sectors calculation (bnc#1151927 5.3.8).
- nvme: fix an error code in nvme_init_subsystem() (bnc#1151927
  5.3.8).
- nvme-pci: Save PCI state before putting drive into deepest state
  (bnc#1151927 5.3.8).
- nvme-tcp: fix wrong stop condition in io_work (bnc#1151927
  5.3.8).
- nvme-pci: Fix a race in controller removal (bnc#1151927 5.3.8).
- blk-mq: honor IO scheduler for multiqueue devices (bnc#1151927
  5.3.8).
- LSM: SafeSetID: Stop releasing uninitialized ruleset
  (bnc#1151927 5.3.8).
- commit 22f2089
* Tue Oct 29 2019 tiwai@suse.de
- blacklist.conf: Add an already cherry-picked i915 entry
- commit 43dfee5
* Tue Oct 29 2019 jslaby@suse.cz
- Update
  patches.suse/0001-btrfs-block-group-Fix-a-memory-leak-due-to-missing-b.patch
  (bsc#1155178 bnc#1151927 5.3.8).
- Update
  patches.suse/0001-btrfs-tracepoints-Fix-bad-entry-members-of-qgroup-ev.patch
  (bsc#1155186 bnc#1151927 5.3.8).
- Update
  patches.suse/0001-btrfs-tracepoints-Fix-wrong-parameter-order-for-qgro.patch
  (bsc#1155184 bnc#1151927 5.3.8).
- Update
  patches.suse/ACPI-CPPC-Set-pcc_data-pcc_ss_id-to-NULL-in-acpi_cpp.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/ACPI-NFIT-Fix-unlock-on-error-in-scrub_show.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/ALSA-hda-Force-runtime-PM-on-Nvidia-HDMI-codecs.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/ALSA-hda-realtek-Add-support-for-ALC711.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/ALSA-hda-realtek-Enable-headset-mic-on-Asus-MJ401TA.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/ALSA-usb-audio-Disable-quirks-for-BOSS-Katana-amplif.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/ASoC-rsnd-Reinitialize-bit-clock-inversion-flag-for-.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/Btrfs-check-for-the-full-sync-flag-while-holding-the.patch
  (bsc#1153713 bnc#1151927 5.3.8).
- Update
  patches.suse/Input-da9063-fix-capability-and-drop-KEY_SLEEP.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/Input-st1232-fix-reporting-multitouch-coordinates.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/PCI-PM-Fix-pci_power_up.patch (git-fixes
  bnc#1151927 5.3.8).
- Update
  patches.suse/RDMA-cxgb4-Do-not-dma-memory-off-of-the-stack.patch
  (jsc#SLE-8392 bnc#1151927 5.3.8).
- Update
  patches.suse/Revert-Input-elantech-enable-SMBus-on-new-2018-syste.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/Revert-drm-radeon-Fix-EEH-during-kexec.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/USB-ldusb-fix-memleak-on-disconnect.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/USB-ldusb-fix-read-info-leaks.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/USB-legousbtower-fix-memleak-on-disconnect.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/USB-serial-ti_usb_3410_5052-fix-port-close-races.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/USB-usblp-fix-use-after-free-on-disconnect.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/cfg80211-wext-avoid-copying-malformed-SSIDs.patch
  (bsc#1153158 CVE-2019-17133 bnc#1151927 5.3.8).
- Update patches.suse/clk-ti-dra7-Fix-mcasp8-clock-bits.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/drm-i915-Favor-last-VBT-child-device-with-conflictin.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/drm-panfrost-Handle-resetting-on-timeout-better.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/drm-ttm-Restore-ttm-prefaulting.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/lib-textsearch-fix-escapes-in-example-code.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/libata-ahci-Fix-PCS-quirk-application.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/md-raid0-fix-warning-message-for-parameter-default_l.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/memstick-jmb38x_ms-Fix-an-error-handling-path-in-jmb.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/mm-compaction-fix-wrong-pfn-handling-in-_reset_isolation_pfn.patch
  (git-fixes (mm/compaction) bnc#1151927 5.3.8).
- Update
  patches.suse/mmc-mxs-fix-flags-passed-to-dmaengine_prep_slave_sg.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/mmc-sdhci-omap-Fix-Tuning-procedure-for-temperatures.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/msft-hv-1955-x86-hyperv-Make-vapic-support-x2apic-mode.patch
  (fate#323887 bnc#1151927 5.3.8).
- Update
  patches.suse/net-aquantia-correctly-handle-macvlan-and-multicast-.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-aquantia-do-not-pass-lro-session-with-invalid-tc.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/net-aquantia-temperature-retrieval-fix.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-aquantia-when-cleaning-hw-cache-it-should-be-tog.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-bcmgenet-Fix-RGMII_MODE_EN-value-for-GENET-v1-2-.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-bcmgenet-Set-phydev-dev_flags-only-for-internal-.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-ethernet-broadcom-have-drivers-select-DIMLIB-as-.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-hisilicon-Fix-usage-of-uninitialized-variable-in.patch
  (bsc#1154353 bnc#1151927 5.3.8).
- Update
  patches.suse/net-ibmvnic-Fix-EOI-when-running-in-XIVE-mode.patch
  (bsc#1089644, ltc#166495, ltc#165544, git-fixes bnc#1151927
  5.3.8).
- Update
  patches.suse/net-ipv6-fix-listify-ip6_rcv_finish-in-case-of-forwa.patch
  (bsc#1154353 bnc#1151927 5.3.8).
- Update
  patches.suse/net-mscc-ocelot-add-missing-of_node_put-after-callin.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-stmmac-Avoid-deadlock-on-suspend-resume.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/pinctrl-armada-37xx-fix-control-of-pins-32-and-up.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/pinctrl-armada-37xx-swap-polarity-on-LED-group.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/pinctrl-cherryview-restore-Strago-DMI-workaround-for.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/scsi-qla2xxx-Fix-N2N-link-reset.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.8).
- Update patches.suse/scsi-qla2xxx-Fix-N2N-link-up-fail.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.8).
- Update
  patches.suse/scsi-qla2xxx-Fix-stale-mem-access-on-driver-unload.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.8).
- Update
  patches.suse/scsi-qla2xxx-Fix-unbound-sleep-in-fcport-delete-path.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.8).
- Update
  patches.suse/scsi-qla2xxx-Silence-fwdump-template-message.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.8).
- Update
  patches.suse/staging-wlan-ng-fix-exit-return-when-sme-key_idx-NUM.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/usb-udc-lpc32xx-fix-bad-bit-shift-operation.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/x86-boot-64-Make-level2_kernel_pgt-pages-invalid-out.patch
  (bnc#1153969 bnc#1151927 5.3.8).
- commit dd1ea62
* Tue Oct 29 2019 jslaby@suse.cz
- x86/boot/64: Round memory hole size up to next PMD page
  (bnc#1153969).
- x86/boot/64: Make level2_kernel_pgt pages invalid outside
  kernel area (bnc#1153969).
- commit ec4e0e8
* Tue Oct 29 2019 mkubecek@suse.cz
- series.conf: refresh
  Update upstream references:
  patches.suse/scsi-lpfc-remove-left-over-BUILD_NVME-defines.patch
- commit b3990ad
* Mon Oct 28 2019 tiwai@suse.de
- HID: logitech-hidpp: do all FF cleanup in hidpp_ff_destroy()
  (git-fixes).
- HID: logitech-hidpp: rework device validation (git-fixes).
- HID: logitech-hidpp: split g920_get_config() (git-fixes).
- HID: fix error message in hid_open_report() (git-fixes).
- virtio_ring: fix stalls for packed rings (git-fixes).
- commit 211812f
* Mon Oct 28 2019 fdmanana@suse.com
- Refresh
  patches.suse/Btrfs-check-for-the-full-sync-flag-while-holding-the.patch.
- commit bee8076
* Mon Oct 28 2019 tiwai@suse.de
- 8250-men-mcb: fix error checking when get_num_ports returns
  - ENODEV (git-fixes).
- drm/komeda: Fix typos in komeda_splitter_validate (git-fixes).
- ACPI: NFIT: Fix unlock on error in scrub_show() (git-fixes).
- vfio/spapr_tce: Fix incorrect tce_iommu_group memory free
  (git-fixes).
- commit 707ac5a
* Mon Oct 28 2019 tiwai@suse.de
- drm/amdgpu: Add DC feature mask to disable fractional pwm
  (bsc#1154010).
- commit 619cd14
* Mon Oct 28 2019 dwagner@suse.de
- scsi: qla2xxx: fix a potential NULL pointer dereference
  (bsc#1150457 CVE-2019-16233).
- commit 0c213e5
* Mon Oct 28 2019 dwagner@suse.de
- Refresh series.conf
  Move patches.suse/scsi-lpfc-remove-left-over-BUILD_NVME-defines.patch
- commit c0faefe
* Mon Oct 28 2019 wqu@suse.com
- btrfs: tracepoints: Fix bad entry members of qgroup events
  (bsc#1155186).
- commit 442159a
* Mon Oct 28 2019 wqu@suse.com
- btrfs: tracepoints: Fix wrong parameter order for qgroup  events
  (bsc#1155184).
- commit 941375b
* Mon Oct 28 2019 wqu@suse.com
- btrfs: qgroup: Always free PREALLOC META reserve in
  btrfs_delalloc_release_extents() (bsc#1155179).
- commit 6d16367
* Mon Oct 28 2019 wqu@suse.com
- btrfs: block-group: Fix a memory leak due to missing
  btrfs_put_block_group() (bsc#1155178).
- commit c8620c7
* Mon Oct 28 2019 tiwai@suse.de
- staging: wlan-ng: fix exit return when sme->key_idx >=
  NUM_WEPKEYS (git-fixes).
- USB: ldusb: fix read info leaks (git-fixes).
- USB: serial: ti_usb_3410_5052: fix port-close races (git-fixes).
- USB: usblp: fix use-after-free on disconnect (git-fixes).
- usb: udc: lpc32xx: fix bad bit shift operation (git-fixes).
- USB: legousbtower: fix a signedness bug in tower_probe()
  (git-fixes).
- USB: legousbtower: fix memleak on disconnect (git-fixes).
- USB: ldusb: fix memleak on disconnect (git-fixes).
- i2c: stm32f7: remove warning when compiling with W=1
  (git-fixes).
- i2c: stm32f7: fix a race in slave mode with arbitration loss
  irq (git-fixes).
- i2c: stm32f7: fix first byte to send in slave mode (git-fixes).
- i2c: mt65xx: fix NULL ptr dereference (git-fixes).
- i2c: aspeed: fix master pending state handling (git-fixes).
- Input: st1232 - fix reporting multitouch coordinates
  (git-fixes).
- mmc: mxs: fix flags passed to dmaengine_prep_slave_sg
  (git-fixes).
- mmc: sdhci-omap: Fix Tuning procedure for temperatures < -20C
  (git-fixes).
- regulator: da9062: fix suspend_enable/disable preparation
  (git-fixes).
- regulator: of: fix suspend-min/max-voltage parsing (git-fixes).
- commit 8eae40b
* Mon Oct 28 2019 jlee@suse.com
- efi: Export Runtime Configuration Interface table to sysfs
  (jsc#SLE-7702).
- Update config files.
- commit da35ab6
* Mon Oct 28 2019 jlee@suse.com
- efi: x86: move efi_is_table_address() into arch/x86
  (jsc#SLE-7702).
- commit 7c42f38
* Fri Oct 25 2019 dbueso@suse.de
- x86/mm: Avoid redundant interrupt disable in load_mm_cr4() (bsc#1154772).
- commit a9a3f29
* Fri Oct 25 2019 jlee@suse.com
- ima: Fix use after free in ima_read_modsig() (jsc#SLE-9870).
- ima: Store the measurement again when appraising a modsig
  (jsc#SLE-9870).
- ima: Define ima-modsig template (jsc#SLE-9870).
- ima: Collect modsig (jsc#SLE-9870).
- ima: Implement support for module-style appended signatures
  (jsc#SLE-9870).
- ima: Factor xattr_verify() out of ima_appraise_measurement()
  (jsc#SLE-9870).
- commit 947fbd9
* Fri Oct 25 2019 jlee@suse.com
- ima: Add modsig appraise_type option for module-style appended
  signatures (jsc#SLE-9870).
- Update config files.
- commit 4fa2098
* Fri Oct 25 2019 jlee@suse.com
- integrity: Select CONFIG_KEYS instead of depending on it
  (jsc#SLE-9870).
- PKCS#7: Introduce pkcs7_get_digest() (jsc#SLE-9870).
- PKCS#7: Refactor verify_pkcs7_signature() (jsc#SLE-9870).
- commit 610313d
* Thu Oct 24 2019 jeffm@suse.com
- Delete patches.suse/btrfs-use-spinlock-to-protect--caching_block_groups-list.patch.
  Qgroup rescan now uses the commit root and skips locking, so the deadlock
  this patch was intended to fix no longer exists.
- commit dc168d3
* Thu Oct 24 2019 msuchanek@suse.de
- Update cdrom autoclose to v4.
- cdrom: export autoclose logic as a separate function
  (bsc#1048585).
- scsi: blacklist: add VMware ESXi cdrom - broken tray emulation
  (bsc#1048585 bsc#1080813).
- Refresh patches.suse/cdrom-factor-out-common-open_for_-code.patch.
- Refresh patches.suse/cdrom-wait-for-the-tray-to-close.patch.
- Refresh patches.suse/scsi-sr-wait-for-the-medium-to-become-ready.patch.
- Delete patches.suse/cdrom-separate-autoclose-into-an-IOCTL.patch.
- Delete patches.suse/docs-cdrom-Add-autoclose-IOCTL.patch.
- Delete patches.suse/scsi-sr-workaround-VMware-ESXi-cdrom-emulation-bug.patch.
- commit 9bf0726
* Thu Oct 24 2019 jeffm@suse.com
- procfs: update and re-enable patch for /proc/sys/fs/procfs-drop-fd-dentries
  Refresh
  patches.suse/procfs-add-tunable-for-fd-fdinfo-dentry-retention.patch.
- commit 3f88bb6
* Thu Oct 24 2019 jeffm@suse.com
- Delete patches.suse/revert-btrfs-qgroup-move-half-of-the-qgroup-accounting-time-out-of-commit-trans.patch.
  It was replaced by setting the flag to skip locking while traversing the
  commit root.
- commit 304f8d0
* Thu Oct 24 2019 jeffm@suse.com
- reiserfs: fix extended attributes on the root directory
  (bsc#1151225).
- commit 90c4321
* Thu Oct 24 2019 jeffm@suse.com
- reiserfs: re-enable reiserfs patches
  Refresh
  patches.suse/reiserfs-mark-read-write-mode-unsupported.patch.
- commit ac1361a
* Thu Oct 24 2019 ggherdovich@suse.cz
- ACPI: acpi_pad: Do not launch acpi_pad threads on idle cpus
  (bsc#1113399).
- commit 1724b68
* Thu Oct 24 2019 tzimmermann@suse.de
- drm/i915/execlists: Always clear pending&inflight requests on reset (bsc#1152489)
- commit 21a0694
* Thu Oct 24 2019 tiwai@suse.de
- ALSA: hda: Add Tigerlake/Jasperlake PCI ID (git-fixes).
- ALSA: usb-audio: Fix copy&paste error in the validator
  (git-fixes).
- ASoC: rsnd: Reinitialize bit clock inversion flag for every
  format setting (git-fixes).
- ASoC: simple_card_utils.h: Fix potential multiple redefinition
  error (git-fixes).
- ASoc: rockchip: i2s: Fix RPM imbalance (git-fixes).
- ASoC: topology: Fix a signedness bug in
  soc_tplg_dapm_widget_create() (git-fixes).
- ALSA: hda/realtek - Add support for ALC711 (git-fixes).
- commit 4dad920
* Thu Oct 24 2019 tiwai@suse.de
- Add CVE reference to FIB security fix patch (CVE-2019-18198, bsc#1154617).
- commit 2b47bbd
* Thu Oct 24 2019 tiwai@suse.de
- net: usb: lan78xx: Connect PHY before registering MAC
  (git-fixes).
- net: ethernet: broadcom: have drivers select DIMLIB as needed
  (git-fixes).
- net: mscc: ocelot: add missing of_node_put after calling
  of_get_child_by_name (git-fixes).
- net: ethernet: stmmac: Fix signedness bug in
  ipq806x_gmac_of_parse() (git-fixes).
- net: nixge: Fix a signedness bug in nixge_probe() (git-fixes).
- net: axienet: fix a signedness bug in probe (git-fixes).
- net: socionext: Fix a signedness bug in ave_probe() (git-fixes).
- net: netsec: Fix signedness bug in netsec_probe() (git-fixes).
- net: broadcom/bcmsysport: Fix signedness in bcm_sysport_probe()
  (git-fixes).
- commit 242e8f9
* Thu Oct 24 2019 tiwai@suse.de
- net: bcmgenet: reset 40nm EPHY on energy detect (git-fixes).
- net: bcmgenet: soft reset 40nm EPHYs before MAC init
  (git-fixes).
- net: bcmgenet: don't set phydev->link from MAC (git-fixes).
- net: bcmgenet: Fix RGMII_MODE_EN value for GENET v1/2/3
  (git-fixes).
- net: bcmgenet: Set phydev->dev_flags only for internal PHYs
  (git-fixes).
- md/raid0: fix warning message for parameter default_layout
  (git-fixes).
- commit 87f7ca5
* Thu Oct 24 2019 tiwai@suse.de
- net: aquantia: correctly handle macvlan and multicast
  coexistence (git-fixes).
- net: aquantia: do not pass lro session with invalid tcp checksum
  (git-fixes).
- net: aquantia: when cleaning hw cache it should be toggled
  (git-fixes).
- net: aquantia: temperature retrieval fix (git-fixes).
- net: aquantia: Fix aq_vec_isr_legacy() return value (git-fixes).
- commit f106659
* Thu Oct 24 2019 tiwai@suse.de
- bus: ti-sysc: Remove unpaired sysc_clkdm_deny_idle()
  (git-fixes).
- commit 6fbfebc
* Thu Oct 24 2019 tiwai@suse.de
- ASoC: sun4i: Revert A83t description (git-fixes).
- ASoC: sunxi: Revert initial A83t support (git-fixes).
- ASoC: sun4i-i2s: Add support for DSP formats (git-fixes).
- ASoC: sun4i-i2s: Replace call to params_width by local variable
  (git-fixes).
- ASoC: sun4i-i2s: Use the actual format width instead of an
  hardcoded one (git-fixes).
- ASoC: sun4i-i2s: Use the physical / slot width for the clocks
  (git-fixes).
- ASoC: sun4i-i2s: Add support for TDM slots (git-fixes).
- ASoC: sun4i-i2s: Support more channels (git-fixes).
- ASoC: sun4i-i2s: Pass the channels number as an argument
  (git-fixes).
- ASoC: sun4i-i2s: Remove duplicated quirks structure (git-fixes).
- ASoC: sun4i-i2s: Register regmap and PCM before our component
  (git-fixes).
- commit 0c68de2
* Thu Oct 24 2019 tiwai@suse.de
- ASoC: sun4i-i2s: Rework MCLK divider calculation (git-fixes).
- Refresh
  patches.suse/ASoC-sun4i-i2s-Fix-the-MCLK-and-BCLK-dividers-on-new.patch.
- commit 65ed49e
* Thu Oct 24 2019 tiwai@suse.de
- ASoC: sun4i-i2s: Fix the LRCK period on A83t (git-fixes).
- ASoC: sun4i-i2s: Fix MCLK Enable bit offset on A83t (git-fixes).
- ASoC: sun4i-i2s: Fix WSS and SR fields for the A83t (git-fixes).
- ASoC: sun4i-i2s: Fix the LRCK polarity (git-fixes).
- ASoC: sun4i-i2s: Fix LRCK and BCLK polarity offsets on newer
  SoCs (git-fixes).
- ASoC: sun4i-i2s: RX and TX counter registers are swapped
  (git-fixes).
- ASoC: sun4i-i2s: Fix the MCLK and BCLK dividers on newer SoCs
  (git-fixes).
- ASoC: sun4i-i2s: Use module clock as BCLK parent on newer SoCs
  (git-fixes).
- ASoC: sun4i-i2s: Move the format configuration to a callback
  (git-fixes).
- ASoC: sun4i-i2s: Move the channel configuration to a callback
  (git-fixes).
- commit fd35f56
* Thu Oct 24 2019 tiwai@suse.de
- ASoC: imx-audmix: register the card on a proper dev (git-fixes).
- ASoC: wm8988: fix typo in wm8988_right_line_controls
  (git-fixes).
- ASoC: sunxi: fix a sound binding broken reference (git-fixes).
- ASoC: ams-delta: Take control over audio mute GPIO pins
  (git-fixes).
- ASoC: Intel: Baytrail: Fix implicit fallthrough warning
  (git-fixes).
- ASoC: meson: g12a-tohdmitx: require regmap mmio (git-fixes).
- ASoC: meson: axg-tdm-formatter: free reset on device removal
  (git-fixes).
- ASoC: wm8737: Fix copy-paste error in wm8737_snd_controls
  (git-fixes).
- ASoC: es8328: Fix copy-paste error in es8328_right_line_controls
  (git-fixes).
- commit d53947e
* Thu Oct 24 2019 tiwai@suse.de
- blacklist.conf: Add path entries for unsupported architectures
- commit cf0a6f3
* Thu Oct 24 2019 tiwai@suse.de
- scripts: setlocalversion: fix a bashism (git-fixes).
- xsk: Fix crash in poll when device does not support
  ndo_xsk_wakeup (git-fixes).
- NTB: fix IDT Kconfig typos/spellos (git-fixes).
- tools/power/x86/intel-speed-select: Fix a read overflow in
  isst_set_tdp_level_msr() (git-fixes).
- commit 9b4c74d
* Thu Oct 24 2019 tiwai@suse.de
- media: MAINTAINERS: hantro: Fix typo in a filepath (git-fixes).
- commit cd10c19
* Thu Oct 24 2019 tiwai@suse.de
- bonding: fix potential NULL deref in bond_update_slave_arr
  (git-fixes).
- llc: fix sk_buff refcounting in llc_conn_state_process()
  (git-fixes).
- llc: fix another potential sk_buff leak in llc_ui_sendmsg()
  (git-fixes).
- llc: fix sk_buff leak in llc_conn_service() (git-fixes).
- llc: fix sk_buff leak in llc_sap_state_process() (git-fixes).
- staging/fbtft: Remove fbtft_device (git-fixes).
- enetc: Fix a signedness bug in enetc_of_get_phy() (git-fixes).
- enetc: Clean up local mdio bus allocation (git-fixes).
- ACPI / property: Fix acpi_graph_get_remote_endpoint() name in
  kerneldoc (git-fixes).
- clocksource/drivers/npcm: Fix GENMASK and timer operation
  (git-fixes).
- commit b262b78
* Thu Oct 24 2019 tiwai@suse.de
- clk: ti: dra7: Fix mcasp8 clock bits (git-fixes).
- bus: ti-sysc: Fix handling of invalid clocks (git-fixes).
- bus: ti-sysc: Fix clock handling for no-idle quirks (git-fixes).
- checkpatch.pl: warn on invalid commit id (git-fixes).
- clk: at91: fix update bit maps on CFG_MOR write (git-fixes).
- clk: actions: Fix factor clk struct member access (git-fixes).
- clk: Evict unregistered clks from parent caches (git-fixes).
- clk: fix devm_platform_ioremap_resource.cocci warnings
  (git-fixes).
- clk: sunxi-ng: v3s: add the missing PLL_DDR1 (git-fixes).
- clk: imx: imx8mm: fix pll mux bit (git-fixes).
- clk: imx8mm: Fix incorrect parents (git-fixes).
- clk: imx8mq: Fix sys3 pll references (git-fixes).
- clk: imx8mm: GPT1 clock mux option #5 should be sys_pll1_80m
  (git-fixes).
- clk: imx8mm: Fix typo of pwm3 clock's mux option #4 (git-fixes).
- clk: qcom: fix QCS404 TuringCC regmap (git-fixes).
- clk: meson: g12a: fix hifi typo in mali parent_names
  (git-fixes).
- commit 989e4b0
* Thu Oct 24 2019 mkubecek@suse.cz
- supported.conf: drop gpio-tegra186 module
  It is built into vmlinux now, not a module.
- commit cc0ff86
* Wed Oct 23 2019 tiwai@suse.de
- mmc: sdhci-pci: Add another Id for Intel CML (jsc#SLE-7946).
- commit 06e352d
* Wed Oct 23 2019 tiwai@suse.de
- drm/i915/cml: Add Missing PCI IDs (jsc#SLE-7930, jsc#SLE-7953).
- commit 9b2cd64
* Wed Oct 23 2019 msuchanek@suse.de
- scsi: sr: wait for the medium to become ready (bsc#1048585).
- scsi: sr: workaround VMware ESXi cdrom emulation bug
  (bsc#1048585 bsc#1080813).
- bdev: add open_finish (bsc#1048585).
- docs: cdrom: Add autoclose IOCTL (bsc#1048585).
- cdrom: separate autoclose into an IOCTL (bsc#1048585).
- cdrom: wait for the tray to close (bsc#1048585).
- cdrom: factor out common open_for_* code (bsc#1048585).
- cdrom: add poll_event_interruptible (bsc#1048585).
- commit 79a9241
* Wed Oct 23 2019 ykaukab@suse.de
- arm64: config: statically link gpio-tegra186
  Driver doesn't load automatically. gpio-tegra already set to same.
- commit 8ae3edf
* Wed Oct 23 2019 ykaukab@suse.de
- cpufreq: tegra186: add CPUFREQ_NEED_INITIAL_FREQ_CHECK flag
  (bsc#1154776).
- commit e492e69
* Wed Oct 23 2019 msuchanek@suse.de
- Remove old cdrom autoclose patches.
- Refresh patches.suse/cdrom-turn-off-autoclose-by-default.patch.
- Delete patches.suse/cdrom-factor-out-common-open_for_-code.patch.
- Delete patches.suse/cdrom-wait-for-tray-to-close.patch.
- Delete patches.suse/delay-add-poll_event_interruptible.patch.
- Delete patches.suse/scsi-sr-wait-for-the-medium-to-become-ready.patch.
- Delete patches.suse/scsi-sr-workaround-VMware-ESXi-cdrom-emulation-bug.patch.
- commit 355491c
* Wed Oct 23 2019 tzimmermann@suse.de
- drm/i915: Don't mix srcu tag and negative error codes (bsc#1152489)
- commit 3b706cc
* Wed Oct 23 2019 tzimmermann@suse.de
- drm/i915/execlists: Process interrupted context on reset (bsc#1152489)
- commit 6dbca2a
* Wed Oct 23 2019 tiwai@suse.de
- fs/libfs.c: fix kernel-doc warning (git-fixes).
- fs/direct-io.c: fix kernel-doc warning (git-fixes).
- Documentation/infiniband: update name of some functions
  (git-fixes).
- docs: kbuild: remove cc-ldoption from document again
  (git-fixes).
- docs: kbuild: fix invalid ReST syntax (git-fixes).
- dmaengine: dw: platform: Switch to
  acpi_dma_controller_register() (git-fixes).
- Documentation: virt: Fix broken reference to virt tree's index
  (git-fixes).
- docs: packing: move it to core-api book and adjust markups
  (git-fixes).
- docs: ipmb: place it at driver-api and convert to ReST
  (git-fixes).
- docs: cgroup-v1/blkio-controller.rst: remove a CFQ left over
  (git-fixes).
- hwmon: (shtc1) fix shtc1 and shtw1 id mask (git-fixes).
- hwmon: (lm75) Fix write operations for negative temperatures
  (git-fixes).
- commit cf25ad9
* Wed Oct 23 2019 tiwai@suse.de
- tun: remove possible false sharing in tun_flow_update()
  (git-fixes).
- vhost/test: stop device before reset (git-fixes).
- xarray.h: fix kernel-doc warning (git-fixes).
- USB: usb-skeleton: fix use-after-free after driver unbind
  (git-fixes).
- usbip: vhci_hcd indicate failed message (git-fixes).
- watchdog: jz4740: Fix unused variable warning in
  jz4740_wdt_probe (git-fixes).
- wcn36xx: use dynamic allocation for large variables (git-fixes).
- mic: avoid statically declaring a 'struct device' (git-fixes).
- commit 03e4263
* Wed Oct 23 2019 tiwai@suse.de
- tty: n_hdlc: fix build on SPARC (git-fixes).
- tty: serial: rda: Fix the link time qualifier of
  'rda_uart_exit()' (git-fixes).
- tty: serial: owl: Fix the link time qualifier of
  'owl_uart_exit()' (git-fixes).
- tty: max310x: fix off-by-one buffer access when storing overrun
  (git-fixes).
- tty: serial: fsl_lpuart: Use appropriate lpuart32_* I/O funcs
  (git-fixes).
- commit 79097ee
* Wed Oct 23 2019 tiwai@suse.de
- serial: fix kernel-doc warning in comments (git-fixes).
- serial: stm32: Use __maybe_unused instead of #if CONFIG_PM_SLEEP
  (git-fixes).
- soc: amlogic: meson-gx-socinfo: Add of_node_put() before return
  (git-fixes).
- soc: renesas: rcar-sysc: Add goto to of_node_put() before return
  (git-fixes).
- spi: bcm-qspi: Fix BSPI QUAD and DUAL mode support when using
  flex mode (git-fixes).
- commit 6cf7966
* Wed Oct 23 2019 tiwai@suse.de
- pinctrl: berlin: as370: fix a typo s/spififib/spdifib
  (git-fixes).
- pinctrl: cherryview: restore Strago DMI workaround for all
  versions (git-fixes).
- pinctrl: intel: Allocate IRQ chip dynamic (git-fixes).
- pinctrl: armada-37xx: swap polarity on LED group (git-fixes).
- pinctrl: stmfx: fix null pointer on remove (git-fixes).
- pinctrl: ns2: Fix off by one bugs in ns2_pinmux_enable()
  (git-fixes).
- pinctrl: armada-37xx: fix control of pins 32 and up (git-fixes).
- commit 9b31ee5
* Wed Oct 23 2019 tiwai@suse.de
- iio: imu: st_lsm6dsx: fix waitime for st_lsm6dsx i2c controller
  (git-fixes).
- iio: adc: meson_saradc: Fix memory allocation order (git-fixes).
- kbuild: correct formatting of header in kbuild module docs
  (git-fixes).
- lib: textsearch: fix escapes in example code (git-fixes).
- lib: dimlib: fix help text typos (git-fixes).
- mtd: spi-nor: fix a memory leak bug (git-fixes).
- mtd: spi-nor: Fix an error code in spi_nor_read_raw()
  (git-fixes).
- mtd: spi-nor: Fix Cadence QSPI RCU Schedule Stall (git-fixes).
- mtd: rawnand: brcmnand: Fix ecc chunk calculation for erased
  page bitfips (git-fixes).
- mtd: rawnand: ingenic: fix devm_platform_ioremap_resource.cocci
  warnings (git-fixes).
- Revert "mwifiex: fix system hang problem after resume"
  (git-fixes).
- iio: dac: ad5380: fix incorrect assignment to val (git-fixes).
- iio: tsl2772: Use devm_add_action_or_reset for tsl2772_chip_off
  (git-fixes).
- media: MAINTAINERS: Remove zoran driver (git-fixes).
- gpio/aspeed: Fix incorrect number of banks (git-fixes).
- gpio: ftgpio: Fix an error handling path in
  'ftgpio_gpio_probe()' (git-fixes).
- gpio: Move gpiochip_lock/unlock_as_irq to gpio/driver.h
  (git-fixes).
- commit e950311
* Wed Oct 23 2019 tiwai@suse.de
- drm/panfrost: Handle resetting on timeout better (git-fixes).
- drm/ttm: Restore ttm prefaulting (git-fixes).
- drm/msm/dsi: Implement reset correctly (git-fixes).
- Revert "drm/radeon: Fix EEH during kexec" (git-fixes).
- drm/i915: Favor last VBT child device with conflicting AUX
  ch/DDC pin (git-fixes).
- drm/i915/cml: Add second PCH ID for CMP (git-fixes).
- drm/i915: Extend Haswell GT1 PSMI workaround to all (git-fixes).
- commit 28cf2c7
* Wed Oct 23 2019 bp@suse.de
- Update
  patches.suse/x86-cpu-add-comet-lake-to-the-intel-cpu-models-header.patch
  (jsc#SLE-7935).
- commit a71e408
* Wed Oct 23 2019 mkubecek@suse.cz
- config: refresh
- commit 3d308bb
* Wed Oct 23 2019 mkubecek@suse.cz
- series.conf: cleanup
  Move two submitted wireless patches to "on the way to mainline" section.
  No effect on expanded tree.
- commit 4d1b347
* Tue Oct 22 2019 tiwai@suse.de
- phylink: fix kernel-doc warnings (git-fixes).
- power: supply: ab8500: remove set but not used variables
  'vbup33_vrtcn' and 'bup_vch_range' (git-fixes).
- power: reset: gpio-restart: Fix typo when gpio reset is not
  found (git-fixes).
- power: supply: Init device wakeup after device_add()
  (git-fixes).
- remoteproc: qcom: q6v5-mss: fixup q6v5_pds_enable error handling
  (git-fixes).
- r8169: fix DMA issue on MIPS platform (git-fixes).
- PM: sleep: Fix possible overflow in pm_system_cancel_wakeup()
  (git-fixes).
- commit ed8c5e4
* Tue Oct 22 2019 tiwai@suse.de
- rt2x00: initialize last_reset (git-fixes).
- virt: vbox: fix memory leak in hgcm_call_preprocess_linaddr
  (git-fixes).
- staging: bcm2835-audio: Fix draining behavior regression
  (git-fixes).
- rtc: pcf2127: bugfix: read rtc disables watchdog (git-fixes).
- rtc: rv3029: revert error handling patch to
  rv3029_eeprom_write() (git-fixes).
- video: of: display_timing: Add of_node_put() in
  of_get_display_timing() (git-fixes).
- ath10k: adjust skb length in ath10k_sdio_mbox_rx_packet
  (git-fixes).
- rtw88: fix wrong rx power calculation (git-fixes).
- rtlwifi: Fix file release memory leak (git-fixes).
- rtw88: fix seq_file memory leak (git-fixes).
- rtlwifi: rtl8821ae: Fix incorrect returned values (git-fixes).
- rtlwifi: rtl8192cu: Fix value set in descriptor (git-fixes).
- rtw88: debug: dump tx power indexes in use (git-fixes).
- regulator: da9211: fix obtaining "enable" GPIO (git-fixes).
- regulator: max77686: fix obtaining "maxim,ena" GPIO (git-fixes).
- commit 39d4733
* Tue Oct 22 2019 tiwai@suse.de
- platform/x86: i2c-multi-instantiate: Fail the probe if no IRQ
  provided (git-fixes).
- platform/x86: classmate-laptop: remove unused variable
  (git-fixes).
- platform/x86: pmc_atom: Add Siemens SIMATIC IPC277E to
  critclk_systems DMI table (git-fixes).
- platform/x86: pmc_atom: Add Siemens SIMATIC IPC227E to
  critclk_systems DMI table (git-fixes).
- commit fb32f25
* Tue Oct 22 2019 tiwai@suse.de
- pinctrl: iproc-gpio: Fix incorrect pinconf configurations
  (git-fixes).
- pinctrl: qcom: sdm845: Fix UFS_RESET pin (git-fixes).
- pinctrl: intel: remap the pin number to gpio offset for irq
  enabled pin (git-fixes).
- commit 9e6b97e
* Tue Oct 22 2019 tiwai@suse.de
- nl80211: fix memory leak in nl80211_get_ftm_responder_stats
  (git-fixes).
- NFC: pn533: fix use-after-free and memleaks (git-fixes).
- PCI: PM: Fix pci_power_up() (git-fixes).
- of: mdio: Fix a signedness bug in of_phy_get_and_connect()
  (git-fixes).
- PCI: Correct pci=resource_alignment parameter example
  (git-fixes).
- phy: ti: am654-serdes: fix an use-after-free in
  serdes_am654_clk_register() (git-fixes).
- paride/pcd: need to set queue to NULL before put_disk
  (git-fixes).
- paride/pf: need to set queue to NULL before put_disk
  (git-fixes).
- commit 6c4192e
* Tue Oct 22 2019 tiwai@suse.de
- mt76: stop rx aggregation on station removal (git-fixes).
- mt76: mt7603: fix watchdog rescheduling in mt7603_set_channel
  (git-fixes).
- mt76: mt7615: fix MT7615_WATCHDOG_TIME definition (git-fixes).
- mt76: usb: fix endian in mt76u_copy (git-fixes).
- mt76: mt76u: fix typo in mt76u_fill_rx_sg (git-fixes).
- mt76: mt7615: fix sparse warnings: warning: restricted __le16
  degrades to integer (git-fixes).
- commit 36419e2
* Tue Oct 22 2019 tiwai@suse.de
- memstick: jmb38x_ms: Fix an error handling path in
  'jmb38x_ms_probe()' (git-fixes).
- staging: most: sound: Fix error path of audio_init (git-fixes).
- media: em28xx: Fix exception handling in em28xx_alloc_urbs()
  (git-fixes).
- media: atmel: atmel-isi: fix timeout value for stop streaming
  (git-fixes).
- media: ov8856: Check reading clock frequency succeeded
  (git-fixes).
- media: imx7.rst: Fix the references to the CSI multiplexer
  (git-fixes).
- media: marvell-ccic: mmp: add MODULE_DEVICE_TABLE (git-fixes).
- media: rcar-vin: Clean up correct notifier in error path
  (git-fixes).
- media: staging/imx: Fix NULL deref in find_pipeline_entity()
  (git-fixes).
- media: vivid: fix potential integer overflow on left shift
  (git-fixes).
- commit 67df550
* Tue Oct 22 2019 tiwai@suse.de
- mailbox: qcom-apcs: fix max_register value (git-fixes).
- commit b903159
* Tue Oct 22 2019 tiwai@suse.de
- mac80211: accept deauth frames in IBSS mode (git-fixes).
- mac80211: don't check if key is NULL in ieee80211_key_link()
  (git-fixes).
- mac80211: vht: add support VHT EXT NSS BW in parsing VHT
  (git-fixes).
- mac80211: minstrel_ht: fix per-group max throughput rate
  initialization (git-fixes).
- commit 53cbd53
* Tue Oct 22 2019 tiwai@suse.de
- leds: lm3532: Fix brightness control for i2c mode (git-fixes).
- Refresh
  patches.suse/leds-lm3532-Fixes-for-the-driver-for-stability.patch.
- commit 2348f20
* Tue Oct 22 2019 tiwai@suse.de
- libata/ahci: Fix PCS quirk application (git-fixes).
- libertas_tf: Use correct channel range in lbtf_geo_init
  (git-fixes).
- led: triggers: Fix dereferencing of null pointer (git-fixes).
- leds: trigger: gpio: GPIO 0 is valid (git-fixes).
- leds: ti-lmu-common: Fix coccinelle issue in TI LMU (git-fixes).
- commit 59a3bf5
* Tue Oct 22 2019 tiwai@suse.de
- iwlwifi: exclude GEO SAR support for 3168 (git-fixes).
- iwlwifi: pcie: fix memory leaks in iwl_pcie_ctxt_info_gen3_init
  (git-fixes).
- iwlwifi: mvm: fix race in sync rx queue notification
  (git-fixes).
- Revert "Input: elantech - enable SMBus on new (2018+) systems"
  (git-fixes).
- Input: da9063 - fix capability and drop KEY_SLEEP (git-fixes).
- ima: initialize the "template" field with the default template
  (git-fixes).
- Input: cros_ec_keyb - add back missing mask for event_type
  (git-fixes).
- iwlwifi: dbg_ini: remove periphery phy and aux regions handling
  (git-fixes).
- commit 5ba2a59
* Tue Oct 22 2019 tiwai@suse.de
- i2c: designware: assert reset when error happen at ->probe()
  (git-fixes).
- crypto: hisilicon - Matching the dma address for dma_pool_free()
  (git-fixes).
- dma-buf: fix stack corruption in dma_fence_chain_release
  (git-fixes).
- brcmfmac: get chip's default RAM info during PCIe setup
  (git-fixes).
- can: xilinx_can: xcan_probe(): skip error message on deferred
  probe (git-fixes).
- can: xilinx_can: xcan_chip_start(): fix failure with invalid
  bus (git-fixes).
- crypto: mediatek - fix uninitialized value of gctx->textlen
  (git-fixes).
- crypto: caam/qi - use print_hex_dump_debug function to print
  debug messages (git-fixes).
- crypto: caam/qi - execute library only on DPAA 1.x (git-fixes).
- crypto: caam - unregister algorithm only if the registration
  succeeded (git-fixes).
- crypto: caam - execute module exit point only if necessary
  (git-fixes).
- crypto: caam - free resources in case caam_rng registration
  failed (git-fixes).
- crypto: ccp - Clean up and exit correctly on allocation failure
  (git-fixes).
- crypto: ccp - Reduce maximum stack usage (git-fixes).
- commit 44f9d1d
* Tue Oct 22 2019 tiwai@suse.de
- ath10k: fix latency issue for QCA988x (git-fixes).
- ath9k: dynack: fix possible deadlock in ath_dynack_node_{de}init
  (git-fixes).
- Bluetooth: hidp: Fix assumptions on the return value of
  hidp_send_message (git-fixes).
- bcma: fix incorrect update of BCMA_CORE_PCI_MDIO_DATA
  (git-fixes).
- ASoC: SOF: Intel: hda: Initialize HDA controller after i915 init
  (git-fixes).
- ALSA: aoa: onyx: always initialize register read value
  (git-fixes).
- ahci: Do not export local variable ahci_em_messages (git-fixes).
- commit 2bdf3d5
* Tue Oct 22 2019 tiwai@suse.de
- act_mirred: Fix mirred_init_module error handling (git-fixes).
- commit 251206c
* Tue Oct 22 2019 tiwai@suse.de
- ACPI: CPPC: Set pcc_data[pcc_ss_id] to NULL in
  acpi_cppc_processor_exit() (git-fixes).
- commit e7cfc10
* Tue Oct 22 2019 tiwai@suse.de
- ALSA: usb-audio: Disable quirks for BOSS Katana amplifiers
  (git-fixes).
- commit 043c45c
* Tue Oct 22 2019 tiwai@suse.de
- ALSA: usb-audio: Update DSD support quirks for Oppo and Rotel
  (git-fixes).
- Refresh
  patches.suse/ALSA-usb-audio-Add-DSD-support-for-EVGA-NU-Audio.patch.
- Refresh
  patches.suse/ALSA-usb-audio-Add-Hiby-device-family-to-quirks-for-.patch.
- commit 468bbcd
* Tue Oct 22 2019 tiwai@suse.de
- ALSA: usb-audio: DSD auto-detection for Playback Designs
  (git-fixes).
- Refresh
  patches.suse/ALSA-usb-audio-Add-DSD-support-for-EVGA-NU-Audio.patch.
- Refresh
  patches.suse/ALSA-usb-audio-Add-Hiby-device-family-to-quirks-for-.patch.
- commit 81fa71f
* Tue Oct 22 2019 tiwai@suse.de
- ALSA: hda - Force runtime PM on Nvidia HDMI codecs (git-fixes).
- ALSA: hda/realtek - Enable headset mic on Asus MJ401TA
  (git-fixes).
- ALSA: hdac: clear link output stream mapping (git-fixes).
- ALSA: hda/realtek: Reduce the Headphone static noise on XPS
  9350/9360 (git-fixes).
- ALSA: hda/realtek - Fix alienware headset mic (git-fixes).
- Add Acer Aspire Ethos 8951G model quirk (git-fixes).
- ALSA: hda/hdmi: remove redundant assignment to variable pcm_idx
  (git-fixes).
- ALSA: hda - Allow runtime PM for controller if component
  notifier is used (git-fixes).
- ALSA: usb-audio: remove some dead code (git-fixes).
- ALSA: usb-audio: Fix possible NULL dereference at
  create_yamaha_midi_quirk() (git-fixes).
- ALSA: usb-audio: Clean up check_input_term() (git-fixes).
- ALSA: usb-audio: Remove superfluous bLength checks (git-fixes).
- ALSA: usb-audio: Unify the release of usb_mixer_elem_info
  objects (git-fixes).
- ALSA: usb-audio: Simplify parse_audio_unit() (git-fixes).
- ALSA: usb-audio: More validations of descriptor units
  (git-fixes).
- ALSA: hda/realtek - Check beep whitelist before assigning in
  all codecs (git-fixes).
- ALSA: hda - Define a fallback_pin_fixup_tbl for alc269 family
  (git-fixes).
- ALSA: hda - Expand pin_match function to match upcoming new tbls
  (git-fixes).
- ALSA: hda/sigmatel - remove unused variable 'stac9200_core_init'
  (git-fixes).
- ALSA: hda: Set fifo_size for both playback and capture streams
  (git-fixes).
- ALSA: hda - Inform too slow responses (git-fixes).
- ALSA: usb-audio: Add Pioneer DDJ-SX3 PCM quirck (git-fixes).
- ALSA: usb-audio: fix PCM device order (git-fixes).
- ALSA: usb-audio: Unify audioformat release code (git-fixes).
- ALSA: hda: Add support of Zhaoxin controller (git-fixes).
- ALSA: usb-audio: Scarlett Gen 2 mixer interface (git-fixes).
- ALSA: line6: sizeof (byte) is always 1, use that fact
  (git-fixes).
- ALSA: hda/hdmi - Allow audio component for AMD/ATI and Nvidia
  HDMI (git-fixes).
- commit 34822c0
* Tue Oct 22 2019 jslaby@suse.cz
- Linux 5.3.7 (bnc#1151927 5.3.7).
- tracing/hwlat: Don't ignore outer-loop duration when calculating
  max_latency (bnc#1151927 5.3.7).
- tracing/hwlat: Report total time spent in all NMIs during the
  sample (bnc#1151927 5.3.7).
- tracing: Get trace_array reference for available_tracers files
  (bnc#1151927 5.3.7).
- ftrace: Get a reference counter for the trace_array on filter
  files (bnc#1151927 5.3.7).
- hwmon: Fix HWMON_P_MIN_ALARM mask (bnc#1151927 5.3.7).
- mtd: rawnand: au1550nd: Fix au_read_buf16() prototype
  (bnc#1151927 5.3.7).
- firmware: google: increment VPD key_len properly (bnc#1151927
  5.3.7).
- mei: avoid FW version request on Ibex Peak and earlier
  (bnc#1151927 5.3.7).
- mei: me: add comet point (lake) LP device ids (bnc#1151927
  5.3.7).
- iio: light: opt3001: fix mutex unlock race (bnc#1151927 5.3.7).
- iio: adc: ad799x: fix probe error handling (bnc#1151927 5.3.7).
- iio: light: add missing vcnl4040 of_compatible (bnc#1151927
  5.3.7).
- iio: light: fix vcnl4000 devicetree hooks (bnc#1151927 5.3.7).
- iio: adc: axp288: Override TS pin bias current for some models
  (bnc#1151927 5.3.7).
- iio: adc: stm32-adc: fix a race when using several adcs with
  dma and irq (bnc#1151927 5.3.7).
- iio: adc: stm32-adc: move registers definitions (bnc#1151927
  5.3.7).
- iio: accel: adxl372: Perform a reset at start up (bnc#1151927
  5.3.7).
- iio: accel: adxl372: Fix push to buffers lost samples
  (bnc#1151927 5.3.7).
- iio: accel: adxl372: Fix/remove limitation for FIFO samples
  (bnc#1151927 5.3.7).
- iio: adc: hx711: fix bug in sampling of data (bnc#1151927
  5.3.7).
- staging: vt6655: Fix memory leak in vt6655_probe (bnc#1151927
  5.3.7).
- Staging: fbtft: fix memory leak in fbtft_framebuffer_alloc
  (bnc#1151927 5.3.7).
- staging: rtl8188eu: fix HighestRate check in
  odm_ARFBRefresh_8188E() (bnc#1151927 5.3.7).
- staging: bcm2835-audio: Fix draining behavior regression
  (bnc#1151927 5.3.7).
- staging/fbtft: Depend on OF (bnc#1151927 5.3.7).
- serial: uartps: Fix uartps_major handling (bnc#1151927 5.3.7).
- serial: uartlite: fix exit path null pointer (bnc#1151927
  5.3.7).
- USB: yurex: fix NULL-derefs on disconnect (bnc#1151927 5.3.7).
- USB: iowarrior: fix use-after-free after driver unbind
  (bnc#1151927 5.3.7).
- USB: iowarrior: fix use-after-free on release (bnc#1151927
  5.3.7).
- USB: iowarrior: fix use-after-free on disconnect (bnc#1151927
  5.3.7).
- USB: chaoskey: fix use-after-free on release (bnc#1151927
  5.3.7).
- USB: adutux: fix use-after-free on release (bnc#1151927 5.3.7).
- USB: ldusb: fix NULL-derefs on driver unbind (bnc#1151927
  5.3.7).
- USB: legousbtower: fix use-after-free on release (bnc#1151927
  5.3.7).
- USB: usb-skeleton: fix NULL-deref on disconnect (bnc#1151927
  5.3.7).
- USB: serial: keyspan: fix NULL-derefs on open() and write()
  (bnc#1151927 5.3.7).
- USB: serial: option: add support for Cinterion CLS8 devices
  (bnc#1151927 5.3.7).
- USB: serial: option: add Telit FN980 compositions (bnc#1151927
  5.3.7).
- USB: serial: ftdi_sio: add device IDs for Sienna and Echelon
  PL-20 (bnc#1151927 5.3.7).
- media: stkwebcam: fix runtime PM after driver unbind
  (bnc#1151927 5.3.7).
- USB: serial: fix runtime PM after driver unbind (bnc#1151927
  5.3.7).
- USB: usblp: fix runtime PM after driver unbind (bnc#1151927
  5.3.7).
- USB: usb-skeleton: fix runtime PM after driver unbind
  (bnc#1151927 5.3.7).
- usb: renesas_usbhs: gadget: Fix usb_ep_set_{halt,wedge}()
  behavior (bnc#1151927 5.3.7).
- usb: renesas_usbhs: gadget: Do not discard queues in
  usb_ep_set_{halt,wedge}() (bnc#1151927 5.3.7).
- xhci: Fix NULL pointer dereference in
  xhci_clear_tt_buffer_complete() (bnc#1151927 5.3.7).
- xhci: Increase STS_SAVE timeout in xhci_suspend() (bnc#1151927
  5.3.7).
- xhci: Prevent deadlock when xhci adapter breaks during init
  (bnc#1151927 5.3.7).
- usb: xhci: wait for CNR controller not ready bit in xhci resume
  (bnc#1151927 5.3.7).
- xhci: Fix USB 3.1 capability detection on early xHCI 1.1 spec
  based hosts (bnc#1151927 5.3.7).
- xhci: Check all endpoints for LPM timeout (bnc#1151927 5.3.7).
- xhci: Prevent device initiated U1/U2 link pm if exit latency
  is too long (bnc#1151927 5.3.7).
- xhci: Fix false warning message about wrong bounce buffer
  write length (bnc#1151927 5.3.7).
- USB: legousbtower: fix open after failed reset request
  (bnc#1151927 5.3.7).
- USB: legousbtower: fix potential NULL-deref on disconnect
  (bnc#1151927 5.3.7).
- USB: legousbtower: fix deadlock on disconnect (bnc#1151927
  5.3.7).
- USB: legousbtower: fix slab info leak at probe (bnc#1151927
  5.3.7).
- usb: typec: ucsi: displayport: Fix for the mode entering routine
  (bnc#1151927 5.3.7).
- usb: typec: ucsi: ccg: Remove run_isr flag (bnc#1151927 5.3.7).
- USB: usblcd: fix I/O after disconnect (bnc#1151927 5.3.7).
- usb: typec: tcpm: usb: typec: tcpm: Fix a signedness bug in
  tcpm_fw_get_caps() (bnc#1151927 5.3.7).
- USB: dummy-hcd: fix power budget for SuperSpeed mode
  (bnc#1151927 5.3.7).
- USB: yurex: Don't retry on unexpected errors (bnc#1151927
  5.3.7).
- USB: adutux: fix NULL-derefs on disconnect (bnc#1151927 5.3.7).
- USB: adutux: fix use-after-free on disconnect (bnc#1151927
  5.3.7).
- USB: microtek: fix info-leak at probe (bnc#1151927 5.3.7).
- USB: rio500: Remove Rio 500 kernel driver (bnc#1151927 5.3.7).
- perf inject jit: Fix JIT_CODE_MOVE filename (bnc#1151927 5.3.7).
- perf llvm: Don't access out-of-scope array (bnc#1151927 5.3.7).
- efi/tpm: Fix sanity check of unsigned tbl_size being less than
  zero (bnc#1151927 5.3.7).
- efi/tpm: Only set 'efi_tpm_final_log_size' after successful
  event log parsing (bnc#1151927 5.3.7).
- efi/tpm: Don't traverse an event log with no events (bnc#1151927
  5.3.7).
- efi/tpm: Don't access event->count when it isn't mapped
  (bnc#1151927 5.3.7).
- efivar/ssdt: Don't iterate over EFI vars if no SSDT override
  was specified (bnc#1151927 5.3.7).
- x86/asm: Fix MWAITX C-state hint value (bnc#1151927 5.3.7).
- MIPS: Disable Loongson MMI instructions for kernel build
  (bnc#1151927 5.3.7).
- MIPS: elf_hwcap: Export userspace ASEs (bnc#1151927 5.3.7).
- NFS: Fix O_DIRECT accounting of number of bytes read/written
  (bnc#1151927 5.3.7).
- CIFS: Force reval dentry if LOOKUP_REVAL flag is set
  (bnc#1151927 5.3.7).
- CIFS: Force revalidate inode when dentry is stale (bnc#1151927
  5.3.7).
- CIFS: Gracefully handle QueryInfo errors during open
  (bnc#1151927 5.3.7).
- cifs: use cifsInodeInfo->open_file_lock while iterating to
  avoid a panic (bnc#1151927 5.3.7).
- drm/i915: Mark contents as dirty on a write fault (bnc#1151927
  5.3.7).
- drm/i915: Bump skl+ max plane width to 5k for linear/x-tiled
  (bnc#1151927 5.3.7).
- drm/i915: Whitelist COMMON_SLICE_CHICKEN2 (bnc#1151927 5.3.7).
- drm/i915: Perform GGTT restore much earlier during resume
  (bnc#1151927 5.3.7).
- io_uring: only flush workqueues on fileset removal (bnc#1151927
  5.3.7).
- btrfs: fix uninitialized ret in ref-verify (bnc#1151927 5.3.7).
- btrfs: allocate new inode in NOFS context (bnc#1151927 5.3.7).
- btrfs: fix balance convert to single on 32-bit host CPUs
  (bnc#1151927 5.3.7).
- btrfs: fix incorrect updating of log root tree (bnc#1151927
  5.3.7).
- Btrfs: fix memory leak due to concurrent append writes with
  fiemap (bnc#1151927 5.3.7).
- Fix the locking in dcache_readdir() and friends (bnc#1151927
  5.3.7).
- arm64/sve: Fix wrong free for task->thread.sve_state
  (bnc#1151927 5.3.7).
- gpio: eic: sprd: Fix the incorrect EIC offset when toggling
  (bnc#1151927 5.3.7).
- gpio: fix getting nonexclusive gpiods from DT (bnc#1151927
  5.3.7).
- gpiolib: don't clear FLAG_IS_OUT when emulating
  open-drain/open-source (bnc#1151927 5.3.7).
- selinux: fix context string corruption in convert_context()
  (bnc#1151927 5.3.7).
- mm/vmpressure.c: fix a signedness bug in
  vmpressure_register_event() (bnc#1151927 5.3.7).
- mm/page_alloc.c: fix a crash in free_pages_prepare()
  (bnc#1151927 5.3.7).
- mm/z3fold.c: claim page in the beginning of free (bnc#1151927
  5.3.7).
- panic: ensure preemption is disabled during panic() (bnc#1151927
  5.3.7).
- commit fe06c63
* Tue Oct 22 2019 jslaby@suse.cz
- Update
  patches.suse/0001-btrfs-relocation-fix-use-after-free-on-dead-relocati.patch
  (bsc#1152972 bnc#1151927 5.3.7).
- Update
  patches.suse/0001-kernel-sysctl.c-do-not-override-max_threads-provided.patch
  (bnc#1150875 bnc#1151927 5.3.7).
- Update
  patches.suse/0002-drm-msm-Use-the-correct-dma_sync-calls-harder.patch
  (bsc#1152472 bnc#1151927 5.3.7).
- Update
  patches.suse/ACPI-PPTT-Add-support-for-ACPI-6.3-thread-flag.patch
  (jsc#SLE-10146 bnc#1151927 5.3.7).
- Update patches.suse/IB-core-Fix-wrong-iterating-on-ports.patch
  (jsc#SLE-8449 bnc#1151927 5.3.7).
- Update patches.suse/RDMA-vmw_pvrdma-Free-SRQ-only-once.patch
  (jsc#SLE-8449 bnc#1151927 5.3.7).
- Update
  patches.suse/arm64-topology-Use-PPTT-to-determine-if-PE-is-a-thre.patch
  (jsc#SLE-10146 bnc#1151927 5.3.7).
- Update
  patches.suse/blk-wbt-fix-performance-regression-in-wbt-scale_up-scale_down.patch
  (bsc#1152489 bnc#1151927 5.3.7).
- commit 942d26b
* Tue Oct 22 2019 msuchanek@suse.de
- kernel-binary.spec.in: Fix build of non-modular kernels (boo#1154578).
- commit 7f1e881
* Tue Oct 22 2019 jroedel@suse.de
- iommu/vt-d: Add Scalable Mode fault information (jsc#SLE-8032).
- iommu/vt-d: Add trace events for device dma map/unmap
  (jsc#SLE-8014).
- commit e17e39f
* Tue Oct 22 2019 acho@suse.com
- rtlwifi: Fix potential overflow on P2P code (bsc#1154372
  CVE-2019-17666).
- commit 6cf6227
* Tue Oct 22 2019 mkubecek@suse.cz
- series.conf: cleanup
  Update upstream references and move into sorted section:
  patches.suse/net-ath6kl-Fix-a-NULL-ptr-deref-bug.patch
  Move into "on the way" section:
  patches.suse/libertas-fix-a-potential-NULL-pointer-dereference.patch
- commit 5ebd03f
* Tue Oct 22 2019 mkubecek@suse.cz
- Fix Patch-mainline tag
  patches.suse/firmware-dmi-fix-unlikely-out-of-bounds-read.patch.
- commit a48c406
* Mon Oct 21 2019 tiwai@suse.de
- libertas: fix a potential NULL pointer dereference
  (CVE-2019-16232,bsc#1150465).
- commit 9f9e4f7
* Mon Oct 21 2019 tiwai@suse.de
- iwlwifi: pcie: fix rb_allocator workqueue allocation
  (CVE-2019-16234,bsc#1150452).
- commit 88957ce
* Mon Oct 21 2019 msuchanek@suse.de
- kernel-binary.spec.in: Obsolete kgraft packages only when not building
  them.
- commit 25f7690
* Mon Oct 21 2019 msuchanek@suse.de
- kernel-subpackage-build: create zero size ghost for uncompressed vmlinux
  (bsc#1154354).
  It is not strictly necessary to uncompress it so maybe the ghost file
  can be 0 size in this case.
- commit 4bf73c8
* Mon Oct 21 2019 jroedel@suse.de
- iommu/amd: Check PM_LEVEL_SIZE() condition in locked section
  (bsc#1154625).
- iommu/amd: Fix incorrect PASID decoding from event log
  (bsc#1154626).
- iommu/io-pgtable-arm: Support all Mali configurations
  (bsc#1154637).
- iommu/io-pgtable-arm: Correct Mali attributes (bsc#1154636).
- iommu/amd: Lock code paths traversing
  protection_domain->dev_list (bsc#1154629).
- iommu/amd: Lock dev_data in attach/detach code paths
  (bsc#1154630).
- iommu/amd: Check for busy devices earlier in attach_device()
  (bsc#1154624).
- iommu/amd: Take domain->lock for complete attach/detach path
  (bsc#1154633).
- iommu/amd: Remove amd_iommu_devtable_lock (bsc#1154631).
- iommu/amd: Remove domain->updated (bsc#1154632).
- iommu/amd: Wait for completion of IOTLB flush in attach_device
  (bsc#1154635).
- iommu/amd: Unmap all L7 PTEs when downgrading page-sizes
  (bsc#1154634).
- iommu/amd: Introduce first_pte_l7() helper (bsc#1154628).
- iommu/amd: Fix pages leak in free_pagetable() (bsc#1154627).
- commit 41aabfd
* Mon Oct 21 2019 pmladek@suse.com
- vsprintf: Prevent crash when dereferencing invalid pointers
  for %%pD (bsc#1154619).
- commit dffedfe
* Mon Oct 21 2019 dwagner@suse.de
- scsi: lpfc: Check queue pointer before use (bsc#1154242).
- commit 7553622
* Mon Oct 21 2019 ohering@suse.de
- x86/hyperv: Set pv_info.name to "Hyper-V" (fate#323887).
- x86/hyperv: Make vapic support x2apic mode (fate#323887).
- Drivers: hv: vmbus: Fix harmless building warnings without
  CONFIG_PM_SLEEP (fate#323887).
- HID: hyperv: Use in-place iterator API in the channel callback
  (fate#323887).
- commit bcf7984
* Mon Oct 21 2019 dwagner@suse.de
- Move patch to upstream section
  Refresh
  patches.suse/scsi-lpfc-remove-left-over-BUILD_NVME-defines.patch.
- commit 4bf6dec
* Mon Oct 21 2019 jdelvare@suse.de
- firmware: dmi: Fix unlikely out-of-bounds read in
  save_mem_devices (git-fixes).
- commit cf1b81f
* Mon Oct 21 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream references:
  patches.suse/cfg80211-wext-avoid-copying-malformed-SSIDs.patch.
  patches.suse/net-ibmvnic-Fix-EOI-when-running-in-XIVE-mode.patch.
- commit 863654c
* Mon Oct 21 2019 dbueso@suse.de
- hrtimer/treewide: Use hrtimer_sleeper_start_expires()
  (bsc#1149032).
- hrtimer: Provide hrtimer_sleeper_start_expires() (bsc#1149032).
- hrtimer: Consolidate hrtimer_init() +  hrtimer_init_sleeper()
  calls (bsc#1149032).
- hrtimer: Remove task argument from hrtimer_init_sleeper()
  (bsc#1149032).
- lib/timerqueue: Rely on rbtree semantics for next timer
  (bsc#1154536).
- x86/math64: Provide a sane mul_u64_u32_div() implementation
  for x86_64 (bsc#1149032).
- sched: Clean up active_mm reference counting (bsc#1149032).
- sched/core: Convert get_task_struct() to return the task
  (bsc#1149032).
- mutex: Fix up mutex_waiter usage (bsc#1149032).
- locking/mutex: Use mutex flags macro instead of hard code
  (bsc#1149032).
- locking/mutex: Make __mutex_owner static to mutex.c
  (bsc#1149032).
- locking/qspinlock,x86: Clarify virt_spin_lock_key (bsc#1149032).
- locking/rwsem: Check for operations on an uninitialized rwsem
  (bsc#1149032).
- locking/rwsem: Make handoff writer optimistically spin on owner
  (bsc#1149032).
- commit 2a492dc
* Fri Oct 18 2019 mkubecek@suse.cz
- Fix Patch-mainline:
  patches.suse/s390-zcrypt-add-base-code-for-cca-crypto-card-info-support
  patches.suse/s390-zcrypt-cex7s-exploitation-support
  patches.suse/s390-zcrypt-move-cca-misc-functions-to-new-code-file
  patches.suse/s390-zcrypt-new-sysfs-attributes-serialnr-and-mkvps
- commit 7dfd2cf
* Fri Oct 18 2019 tbogendoerfer@suse.de
- netdevsim: implement support for devlink region and snapshots
  (bsc#1154353).
- Refresh patches.suse/net-devlink-split-reload-op-into-two.patch.
- commit 8316be1
* Fri Oct 18 2019 tbogendoerfer@suse.de
- netdevsim: register couple of devlink params (bsc#1154353).
- Refresh patches.suse/net-devlink-split-reload-op-into-two.patch.
- commit f83adc1
* Fri Oct 18 2019 tbogendoerfer@suse.de
- SUNRPC: fix race to sk_err after xs_error_report (bsc#1154353).
- commit cf2c098
* Fri Oct 18 2019 tbogendoerfer@suse.de
- netdevsim: Add devlink-trap support (bsc#1154353).
- Refresh patches.suse/net-devlink-split-reload-op-into-two.patch.
- commit bd989c4
* Fri Oct 18 2019 tbogendoerfer@suse.de
- net: hisilicon: Fix usage of uninitialized variable in function
  mdio_sc_cfg_reg_write() (bsc#1154353).
- mlxsw: spectrum: Clear VLAN filters during port initialization
  (bsc#1154488).
- net: ena: clean up indentation issue (bsc#1154492).
- net: hisilicon: Fix signedness bug in hix5hd2_dev_probe()
  (bsc#1154353).
- net: ena: Select DIMLIB for ENA_ETHERNET (bsc#1154492).
- sunrpc: clean up indentation issue (bsc#1154353).
- sunrpc: add a new cache_detail operation for when a cache is
  flushed (bsc#1154353).
- svcrdma: Use llist for managing cache of recv_ctxts
  (jsc#SLE-8449).
- svcrdma: Remove svc_rdma_wq (jsc#SLE-8449).
- SUNRPC: Track writers of the 'channel' file to improve
  cache_listeners_exist (bsc#1154353).
- SUNRPC: Fix congestion window race with disconnect
  (bsc#1154353).
- SUNRPC: Rename xdr_buf_read_netobj to xdr_buf_read_mic
  (bsc#1154353).
- SUNRPC: Don't receive TCP data into a request buffer that has
  been reset (bsc#1154353).
- xprtrdma: Clear xprt->reestablish_timeout on close
  (jsc#SLE-8449).
- xprtrdma: Recycle MRs after disconnect (jsc#SLE-8449).
- xprtrdma: Optimize rpcrdma_post_recvs() (jsc#SLE-8449).
- xprtrdma: Inline XDR chunk encoder functions (jsc#SLE-8449).
- xprtrdma: Fix bc_max_slots return value (jsc#SLE-8449).
- xprtrdma: Clean up xprt_rdma_set_connect_timeout()
  (jsc#SLE-8449).
- xprtrdma: Use an llist to manage free rpcrdma_reps
  (jsc#SLE-8449).
- xprtrdma: Remove rpcrdma_buffer::rb_mrlock (jsc#SLE-8449).
- xprtrdma: Cache free MRs in each rpcrdma_req (jsc#SLE-8449).
- xprtrdma: Ensure creating an MR does not trigger FS writeback
  (jsc#SLE-8449).
- xprtrdma: Move rpcrdma_mr_get out of frwr_map (jsc#SLE-8449).
- xprtrdma: Combine rpcrdma_mr_put and rpcrdma_mr_unmap_and_put
  (jsc#SLE-8449).
- xprtrdma: Simplify rpcrdma_mr_pop (jsc#SLE-8449).
- xprtrdma: Rename rpcrdma_buffer::rb_all (jsc#SLE-8449).
- xprtrdma: Rename CQE field in Receive trace points
  (jsc#SLE-8449).
- xprtrdma: Boost maximum transport header size (jsc#SLE-8449).
- xprtrdma: Fix calculation of ri_max_segs again (jsc#SLE-8449).
- xprtrdma: Update obsolete comment (jsc#SLE-8449).
- xprtrdma: Refresh the documenting comment in frwr_ops.c
  (jsc#SLE-8449).
- SUNRPC: Inline xdr_commit_encode (bsc#1154353).
- SUNRPC: Remove rpc_wake_up_queued_task_on_wq() (bsc#1154353).
- RDMA/hns: Package operations of rq inline buffer into separate
  functions (jsc#SLE-8449).
- RDMA/hns: Optimize cmd init and mode selection for hip08
  (jsc#SLE-8449).
- RDMA/hns: Use devm_platform_ioremap_resource() to simplify code
  (jsc#SLE-8449).
- RDMA/hns: Fix wrong assignment of qp_access_flags
  (jsc#SLE-8449).
- RDMA/hns: Delete the not-used lines (jsc#SLE-8449).
- RDMA/hns: Remove if-else judgment statements for creating srq
  (jsc#SLE-8449).
- RDMA/hns: Add reset process for function-clear (jsc#SLE-8449).
- RDMA/hns: Fix cast from or to restricted __le32 for driver
  (jsc#SLE-8449).
- RDMA/hns: Remove the some magic number (jsc#SLE-8449).
- RDMA/hns: Modify the data structure of hns_roce_av
  (jsc#SLE-8449).
- RDMA/hns: Fix some white space check_mtu_validate()
  (jsc#SLE-8449).
- RDMA/hns: Remove unuseful member (jsc#SLE-8449).
- RDMA/hns: bugfix for slab-out-of-bounds when loading hip08
  driver (jsc#SLE-8449).
- RDMA/hns: Bugfix for slab-out-of-bounds when unloading hip08
  driver (jsc#SLE-8449).
- RDMA/hns: Modify pi vlaue when cq overflows (jsc#SLE-8449).
- RDMA/hns: Bugfix for creating qp attached to srq (jsc#SLE-8449).
- RDMA/hns: Logic optimization of wc_flags (jsc#SLE-8449).
- RDMA/hns: Use the new APIs for printing log (jsc#SLE-8449).
- RDMA/hns: Disable alw_lcl_lpbk of SSU (jsc#SLE-8449).
- RDMA/hns: Remove redundant print in hns_roce_v2_ceq_int()
  (jsc#SLE-8449).
- RDMA/hns: Refactor hns_roce_v2_set_hem for hip08 (jsc#SLE-8449).
- RDMA/hns: Remove unnecessary kzalloc (jsc#SLE-8449).
- RDMA/hns: Refactor irq request code (jsc#SLE-8449).
- RDMA/hns: Split bool statement and assign statement
  (jsc#SLE-8449).
- RDMA/hns: Handling the error return value of hem function
  (jsc#SLE-8449).
- RDMA/hns: Update some comments style (jsc#SLE-8449).
- RDMA/hns: Clean up unnecessary initial assignment
  (jsc#SLE-8449).
- RDMA/hns: Remove unnessary init for cmq reg (jsc#SLE-8449).
- RDMA/hns: Update the prompt message for creating and destroy qp
  (jsc#SLE-8449).
- RDMA/hns: Optimize hns_roce_modify_qp function (jsc#SLE-8449).
- RDMA/hns: Encapsulate some lines for setting sq size in user
  mode (jsc#SLE-8449).
- RDMA/hns: remove obsolete Kconfig comment (jsc#SLE-8449).
- RDMA/hns: Remove not used UAR assignment (jsc#SLE-8449).
- RDMA/hns: remove set but not used variable 'irq_num'
  (jsc#SLE-8449).
- RDMA/hns: Refactor eq table init for hip08 (jsc#SLE-8449).
- RDMA/hns: Refactor hem table mhop check and calculation
  (jsc#SLE-8449).
- RDMA/hns: Package for hns_roce_rereg_user_mr function
  (jsc#SLE-8449).
- RDMA/hns: Optimize hns_roce_mhop_alloc function (jsc#SLE-8449).
- RDMA/hns: optimize the duplicated code for qpc setting flow
  (jsc#SLE-8449).
- RDMA/hns: Use a separated function for setting extend sge
  paramters (jsc#SLE-8449).
- RDMA/hns: Refactor for hns_roce_v2_modify_qp function
  (jsc#SLE-8449).
- RDMA/hns: Refactor the code of creating srq (jsc#SLE-8449).
- RDMA/hns: Package the flow of creating cq (jsc#SLE-8449).
- net: ena: don't wake up tx queue when down (bsc#1154492).
- mlxsw: spectrum_buffers: Add the ability to query the CPU
  port's shared buffer (bsc#1154488).
- mlxsw: spectrum: Register CPU port with devlink (bsc#1154488).
- mlxsw: spectrum_buffers: Prevent changing CPU port's
  configuration (bsc#1154488).
- net: ena: fix incorrect update of intr_delay_resolution
  (bsc#1154492).
- net: ena: fix retrieval of nonadaptive interrupt moderation
  intervals (bsc#1154492).
- net: ena: fix update of interrupt moderation register
  (bsc#1154492).
- net: ena: remove all old adaptive rx interrupt moderation code
  from ena_com (bsc#1154492).
- net: ena: remove ena_restore_ethtool_params() and relevant
  fields (bsc#1154492).
- net: ena: remove old adaptive interrupt moderation code from
  ena_netdev (bsc#1154492).
- net: ena: remove code duplication in
  ena_com_update_nonadaptive_moderation_interval _*()
  (bsc#1154492).
- net: ena: enable the interrupt_moderation in
  driver_supported_features (bsc#1154492).
- net: ena: reimplement set/get_coalesce() (bsc#1154492).
- net: ena: switch to dim algorithm for rx adaptive interrupt
  moderation (bsc#1154492).
- net: ena: add intr_moder_rx_interval to struct ena_com_dev
  and use it (bsc#1154492).
- netdevsim: Set offsets to various protocol layers (bsc#1154353).
- net: hns3: add some DFX info for reset issue (bsc#1154353).
- net: hns3: check NULL pointer before use (bsc#1154353).
- net: hns3: modify some logs format (bsc#1154353).
- net: hns3: fix port setting handle for fibre port (bsc#1154353).
- net: hns3: fix shaper parameter algorithm (bsc#1154353).
- net: hns3: revert to old channel when setting new channel num
  fail (bsc#1154353).
- net: hns3: add ethtool_ops.set_channels support for HNS3 VF
  driver (bsc#1154353).
- net: hns3: make array spec_opcode static const, makes object
  smaller (bsc#1154353).
- net: hns3: make hclge_dbg_get_m7_stats_info static
  (bsc#1154353).
- net: hns3: disable loopback setting in hclge_mac_init
  (bsc#1154353).
- net: hns3: remove explicit conversion to bool (bsc#1154353).
- net: hns3: add client node validity judgment (bsc#1154353).
- net: hns3: fix mis-assignment to hdev->reset_level in
  hclge_reset (bsc#1154353).
- net: hns3: fix double free bug when setting ringparam
  (bsc#1154353).
- net: hns3: fix error VF index when setting VLAN offload
  (bsc#1154353).
- net: hns: Move static keyword to the front of declaration
  (bsc#1154353).
- sunrpc: Use kzfree rather than its implementation (bsc#1154353).
- mvpp2: percpu buffers (bsc#1154353).
- mvpp2: refactor BM pool functions (bsc#1154353).
- net: hns3: remove set but not used variable 'qos' (bsc#1154353).
- net: hns3: remove redundant assignment to pointer reg_info
  (bsc#1154353).
- net: bridge: Populate the pvid flag in br_vlan_get_info
  (bsc#1154353).
- net: hns3: not allow SSU loopback while execute ethtool -t dev
  (bsc#1154353).
- net: hns3: check reset interrupt status when reset fails
  (bsc#1154353).
- net: hns3: add phy selftest function (bsc#1154353).
- net: hns3: implement .process_hw_error for hns3 client
  (bsc#1154353).
- net: hns3: optimize waiting time for TQP reset (bsc#1154353).
- net: hns3: fix incorrect type in assignment (bsc#1154353).
- net: hns3: make some reusable codes into a function
  (bsc#1154353).
- net: hns3: optimize some log printings (bsc#1154353).
- net: hns3: reduce the parameters of some functions
  (bsc#1154353).
- net: hns3: modify base parameter of kstrtouint in
  hclge_dbg_dump_tm_map (bsc#1154353).
- net: hns3: use macro instead of magic number (bsc#1154353).
- net: hns3: code optimization for debugfs related to "dump reg"
  (bsc#1154353).
- mlxsw: spectrum_ptp: Add counters for GC events (bsc#1154488).
- mlxsw: Bump firmware version to 13.2000.1886 (bsc#1154488).
- mlxsw: spectrum: Prevent auto negotiation on number of lanes
  (bsc#1154488).
- mlxsw: Remove 56G speed support (bsc#1154488).
- net: hns3: Fix -Wunused-const-variable warning (bsc#1154353).
- selftests: mlxsw: Add a test case for devlink-trap
  (bsc#1154488).
- selftests: mlxsw: Add test cases for devlink-trap L2 drops
  (bsc#1154488).
- mlxsw: spectrum: Add devlink-trap support (bsc#1154488).
- mlxsw: Add trap group for layer 2 discards (bsc#1154488).
- mlxsw: Add layer 2 discard trap IDs (bsc#1154488).
- mlxsw: reg: Add new trap actions (bsc#1154488).
- mlxsw: core: Add API to set trap action (bsc#1154488).
- netdevsim: Fix build error without CONFIG_INET (bsc#1154353).
- net: hns: add phy_attached_info() to the hns driver
  (bsc#1154353).
- net: hns3: add phy_attached_info() to the hns3 driver
  (bsc#1154353).
- net: hns3: prevent unnecessary MAC TNL interrupt (bsc#1154353).
- net: hns3: change print level of RAS error log from warning
  to error (bsc#1154353).
- net: hns3: fix error and incorrect format (bsc#1154353).
- net: hns3: modify redundant initialization of variable
  (bsc#1154353).
- net: hns3: add or modify comments (bsc#1154353).
- Documentation: Add description of netdevsim traps (bsc#1154353).
- net: bridge: mdb: allow add/delete for host-joined groups
  (bsc#1154353).
- net: bridge: mdb: dump host-joined entries as well
  (bsc#1154353).
- net: bridge: mdb: factor out mdb filling (bsc#1154353).
- net: bridge: mdb: move vlan comments (bsc#1154353).
- net/mvpp2: Replace tasklet with softirq hrtimer (bsc#1154353).
- net: hns3: Make hclge_func_reset_sync_vf static (bsc#1154353).
- mvpp2: no need to check return value of debugfs_create functions
  (bsc#1154353).
- hns3: no need to check return value of debugfs_create functions
  (bsc#1154353).
- net: hns3: refine some macro definitions (bsc#1154353).
- net: hns3: add handshake with VF for PF reset (bsc#1154353).
- net: hns3: refine MAC pause statistics querying function
  (bsc#1154353).
- net: hns3: add function display NCL_CONFIG info (bsc#1154353).
- net: hns3: add check for max TX BD num for tso and non-tso case
  (bsc#1154353).
- net: hns3: add some statitics info to tx process (bsc#1154353).
- net: hns3: add DFX registers information for ethtool -d
  (bsc#1154353).
- net: hns3: modify how pause options is displayed (bsc#1154353).
- net: hns3: add input length check for debugfs write function
  (bsc#1154353).
- net: hns3: clean up for vlan handling in hns3_fill_desc_vtags
  (bsc#1154353).
- net: hns3: fix interrupt clearing error for VF (bsc#1154353).
- net: hns3: fix GFP flag error in hclge_mac_update_stats()
  (bsc#1154353).
- mlxsw: spectrum: Extend to support Spectrum-3 ASIC
  (bsc#1154488).
- net: hns3: activate reset timer when calling reset_event
  (bsc#1154353).
- net: hns3: clear reset interrupt status in hclge_irq_handle()
  (bsc#1154353).
- net: hns3: fix some reset handshake issue (bsc#1154353).
- net: hns3: rename a member in struct
  hclge_mac_ethertype_idx_rd_cmd (bsc#1154353).
- net: hns3: simplify hclge_cmd_query_error() (bsc#1154353).
- net: hns3: minior error handling change for
  hclge_tm_schd_info_init (bsc#1154353).
- net: hns3: minor cleanup in hns3_clean_rx_ring (bsc#1154353).
- net: hns3: remove unnecessary variable in
  hclge_get_mac_vlan_cmd_status() (bsc#1154353).
- net: hns3: refine for set ring parameters (bsc#1154353).
- net: hns3: do not query unsupported commands in debugfs
  (bsc#1154353).
- net: hns3: add handler for NCSI error mailbox (bsc#1154353).
- net: hns3: add link change event report (bsc#1154353).
- net: phy: xgene: use devm_platform_ioremap_resource() to
  simplify code (bsc#1154353).
- mvpp2: use devm_platform_ioremap_resource() to simplify code
  (bsc#1154353).
- net: bridge: mcast: add delete due to fast-leave mdb flag
  (bsc#1154353).
- selftests: mlxsw: Add a test for leftover DSCP rule
  (bsc#1154488).
- selftests: mlxsw: Fix local variable declarations in DSCP tests
  (bsc#1154488).
- net: Remove dev_err() usage after platform_get_irq()
  (bsc#1154353).
- net: hns3: use dev_info() instead of pr_info() (bsc#1154353).
- net: hns3: Add support for using order 1 pages with a 4K buffer
  (bsc#1154353).
- net: hns3: add interrupt affinity support for misc interrupt
  (bsc#1154353).
- net: hns3: make hclge_service use delayed workqueue
  (bsc#1154353).
- net: hns3: add debug messages to identify eth down cause
  (bsc#1154353).
- net: hns3: modify firmware version display format (bsc#1154353).
- net: hns3: change GFP flag during lock period (bsc#1154353).
- net: hns3: remove upgrade reset level when reset fail
  (bsc#1154353).
- net: hns3: add a check for get_reset_level (bsc#1154353).
- net: hns3: add reset checking before set channels (bsc#1154353).
- mlxsw: spectrum_flower: Forbid to offload match on reserved
  TCP flags bits (bsc#1154488).
- mlxsw: spectrum_acl: Track rules that forbid egress block bind
  (bsc#1154488).
- mlxsw: spectrum_flower: Forbid to offload mirred redirect on
  egress (bsc#1154488).
- drivers: net: xgene: Move status variable declaration into
  CONFIG_ACPI block (bsc#1154353).
- mlxsw: spectrum_router: Increase scale of IPv6 nexthop groups
  (bsc#1154488).
- mlxsw: spectrum: Expose KVD size for Spectrum-2 (bsc#1154488).
- drivers: net: xgene: Remove acpi_has_method() calls
  (bsc#1154353).
- platform/mellanox: mlxreg-hotplug: Remove dev_err() usage
  after platform_get_irq() (bsc#1154488).
- commit 25127c6
* Fri Oct 18 2019 ptesarik@suse.cz
- s390/zcrypt: new sysfs attributes serialnr and mkvps
  (jsc#SLE-9582 jsc#IBM-505 LTC#181532).
- Refresh patches.suse/s390-zcrypt-cex7s-exploitation-support.
- commit e3c6694
* Fri Oct 18 2019 ptesarik@suse.cz
- s390/zcrypt: add base code for cca crypto card info support
  (jsc#SLE-9582 jsc#IBM-505 LTC#181532).
- s390/zcrypt: move cca misc functions to new code file
  (jsc#SLE-9582 jsc#IBM-505 LTC#181532).
- commit ade3003
* Fri Oct 18 2019 ptesarik@suse.cz
- Update references in
  patches.suse/Revert-s390-dasd-Add-discard-support-for-ESE-volumes.patch
  (bnc#1151927 5.3.6 jsc#SLE-7885 jsc#IBM-463 LTC#178852).
- Update references in
  patches.suse/s390-dasd-Fix-error-handling-during-online-processin.patch
  (bnc#1151927 5.3.6 jsc#SLE-7885 jsc#IBM-463 LTC#178852).
- commit fae0452
* Fri Oct 18 2019 ptesarik@suse.cz
- s390/zcrypt: CEX7S exploitation support (jsc#SLE-7506
  jsc#IBM-458 LTC#178859).
- commit 99477f1
* Fri Oct 18 2019 tbogendoerfer@suse.de
- selftests/bpf: fix clearing buffered output between
  tests/subtests (bsc#1154353).
- commit 5178748
* Fri Oct 18 2019 tbogendoerfer@suse.de
- libbpf: convert libbpf code to use new btf helpers
  (bsc#1154353).
- Refresh
  patches.suse/libbpf-fix-false-uninitialized-variable-warning.patch.
- commit 234ecb1
* Fri Oct 18 2019 tbogendoerfer@suse.de
- Documentation: Clarify trap's description (bsc#1154353).
- libbpf: Teach btf_dumper to emit stand-alone anonymous enum
  definitions (bsc#1154353).
- libbpf: Remove getsockopt() check for XDP_OPTIONS (bsc#1154353).
- kcm: disable preemption in kcm_parse_func_strparser()
  (bsc#1154353).
- IB/mlx5: Use the original address for the page during free_pages
  (jsc#SLE-8446).
- RDMA/cma: Fix false error message (jsc#SLE-8449).
- kbuild: replace BASH-specific ${@:2} with shift and ${@}
  (bsc#1154353).
- libbpf: add flags to umem config (bsc#1154353).
- tools: bpftool: do not link twice against libbpf.a in Makefile
  (bsc#1154353).
- tools: bpf: account for generated feature/ and libbpf/
  directories (bsc#1154353).
- tools: bpftool: improve and check builds for different make
  invocations (bsc#1154353).
- tools: bpftool: ignore make built-in rules for getting kernel
  version (bsc#1154353).
- tools/bpf: sync bpf.h (bsc#1154353).
- btf: do not use CONFIG_OUTPUT_FORMAT (bsc#1154353).
- libbpf: use LFS (_FILE_OFFSET_BITS) instead of direct mmap2
  syscall (bsc#1154353).
- libbpf: add bpf_btf_get_next_id() to cycle through BTF objects
  (bsc#1154353).
- libbpf: refactor bpf_*_get_next_id() functions (bsc#1154353).
- tools: bpf: synchronise BPF UAPI header with tools
  (bsc#1154353).
- bpf: sync bpf.h to tools/ (bsc#1154353).
- libbpf: add support for need_wakeup flag in AF_XDP part
  (bsc#1154353).
- libbpf: make libbpf.map source of truth for libbpf version
  (bsc#1154353).
- tools: bpftool: compile with $(EXTRA_WARNINGS) (bsc#1154353).
- libbpf: attempt to load kernel BTF from sysfs first
  (bsc#1154353).
- tools: bpftool: add feature check for zlib (bsc#1154353).
- tools: bpftool: fix reading from /proc/config.gz (bsc#1154353).
- libbpf: implement BPF CO-RE offset relocation algorithm
  (bsc#1154353).
- libbpf: add .BTF.ext offset relocation section loading
  (bsc#1154353).
- libbpf: add helpers for working with BTF types (bsc#1154353).
- bpf: sync bpf.h to tools/ (bsc#1154353).
- tools: Add definitions for devmap_hash map type (bsc#1154353).
- tools/libbpf_probes: Add new devmap_hash type (bsc#1154353).
- tools/include/uapi: Add devmap_hash BPF map type (bsc#1154353).
- selftests/bpf: convert send_signal.c to use subtests
  (bsc#1154353).
- selftests/bpf: convert bpf_verif_scale.c to sub-tests API
  (bsc#1154353).
- selftests/bpf: add sub-tests support for test_progs
  (bsc#1154353).
- selftests/bpf: abstract away test log output (bsc#1154353).
- selftest/bpf: centralize libbpf logging management for
  test_progs (bsc#1154353).
- libbpf: return previous print callback from libbpf_set_print
  (bsc#1154353).
- selftests/bpf: add test selectors by number and name to
  test_progs (bsc#1154353).
- selftests/bpf: revamp test_progs to allow more control
  (bsc#1154353).
- selftests/bpf: prevent headers to be compiled as C code
  (bsc#1154353).
- selftests/bpf: support BPF_FLOW_DISSECTOR_F_STOP_AT_ENCAP
  (bsc#1154353).
- libbpf: provide more helpful message on uninitialized global
  var (bsc#1154353).
- tools headers: Grab copy of linux/const.h, needed by
  linux/bits.h (bsc#1154353).
- commit 0d4cc4a
* Fri Oct 18 2019 hare@suse.de
- scsi: lpfc: remove left-over BUILD_NVME defines (bsc#1154268).
- commit bde7b0f
* Fri Oct 18 2019 mkubecek@suse.cz
- series.conf: move unsortable patch out of sorted section
  Move patches.suse/Btrfs-check-for-the-full-sync-flag-while-holding-the.patch
  out of sorted section; it does not have Git-commit tag (yet) so that it
  cannot be sorted without manual update anyway.
- commit dab15c2
* Fri Oct 18 2019 mkubecek@suse.cz
- series.conf: move queued patch into sorted section
  Update patches.suse/cfg80211-wext-avoid-copying-malformed-SSIDs.patch
  Git-repo tag and move it into sorted section.
- commit 9c78ce4
* Thu Oct 17 2019 tbogendoerfer@suse.de
- RDMA/mlx5: Add missing synchronize_srcu() for MW cases
  (jsc#SLE-8446).
- RDMA/mlx5: Put live in the correct place for ODP MRs
  (jsc#SLE-8446).
- RDMA/mlx5: Order num_pending_prefetch properly with
  synchronize_srcu (jsc#SLE-8446).
- RDMA/odp: Lift umem_mutex out of ib_umem_odp_unmap_dma_pages()
  (jsc#SLE-8449).
- RDMA/mlx5: Fix a race with mlx5_ib_update_xlt on an implicit MR
  (jsc#SLE-8446).
- RDMA/mlx5: Do not allow rereg of a ODP MR (jsc#SLE-8446).
- IB/core: Fix wrong iterating on ports (jsc#SLE-8449).
- RDMA/nldev: Reshuffle the code to avoid need to rebind QP in
  error path (jsc#SLE-8449).
- RDMA/cxgb4: Do not dma memory off of the stack (jsc#SLE-8392).
- RDMA/cm: Fix memory leak in cm_add/remove_one (jsc#SLE-8449).
- RDMA/core: Fix an error handling path in 'res_get_common_doit()'
  (jsc#SLE-8449).
- RDMA/i40iw: Associate ibdev to netdev before IB device
  registration (jsc#SLE-8449).
- RDMA/iwcm: Fix a lock inversion issue (jsc#SLE-8449).
- RDMA/iw_cxgb4: fix SRQ access from dump_qp() (jsc#SLE-8392).
- RDMA/hfi1: Prevent memory leak in sdma_init (jsc#SLE-8449).
- RDMA/core: Fix use after free and refcnt leak on ndev in_device
  in iwarp_query_port (jsc#SLE-8449).
- RDMA/siw: Fix serialization issue in write_space()
  (jsc#SLE-8381).
- RDMA/vmw_pvrdma: Free SRQ only once (jsc#SLE-8449).
- mlx5: avoid 64-bit division in dr_icm_pool_mr_create()
  (jsc#SLE-8464).
- devlink: Fix error handling in param and info_get dumpit cb
  (bsc#1154353).
- sk_buff: drop all skb extensions on free and skb scrubbing
  (bsc#1154353).
- bpf: Clean up indentation issue in BTF kflag processing
  (bsc#1154353).
- xsk: relax UMEM headroom alignment (bsc#1154353).
- bpf: fix BTF verification of enums (bsc#1154353).
- net: sched: sch_sfb: don't call qdisc_put() while holding tree
  lock (bsc#1154353).
- net: sched: multiq: don't call qdisc_put() while holding tree
  lock (bsc#1154353).
- net: sched: sch_htb: don't call qdisc_put() while holding tree
  lock (bsc#1154353).
- sch_netem: fix rcu splat in netem_enqueue() (bsc#1154353).
- cxgb4: Signedness bug in init_one() (jsc#SLE-8389).
- net/mlx5: DR, Allow matching on vport based on vhca_id
  (jsc#SLE-8464).
- net/mlx5: DR, Fix getting incorrect prev node in ste_free
  (jsc#SLE-8464).
- net/mlx5: DR, Remove redundant vport number from action
  (jsc#SLE-8464).
- net/mlx5: DR, Fix SW steering HW bits and definitions
  (jsc#SLE-8464).
- qede: qede_fp: simplify a bit 'qede_rx_build_skb()'
  (jsc#SLE-8401).
- IB/hfi1: remove unlikely() from IS_ERR*() condition
  (jsc#SLE-8449).
- mm/gup: add make_dirty arg to put_user_pages_dirty_lock()
  (jsc#SLE-8449).
- PCI/P2PDMA: Update pci_p2pdma_distance_many() documentation
  (jsc#SLE-8449).
- PCI/P2PDMA: Allow IOMMU for host bridge whitelist
  (jsc#SLE-8449).
- PCI/P2PDMA: dma_map() requests that traverse the host bridge
  (jsc#SLE-8449).
- PCI/P2PDMA: Store mapping method in an xarray (jsc#SLE-8449).
- PCI/P2PDMA: Factor out __pci_p2pdma_map_sg() (jsc#SLE-8449).
- PCI/P2PDMA: Introduce pci_p2pdma_unmap_sg() (jsc#SLE-8449).
- PCI/P2PDMA: Add attrs argument to pci_p2pdma_map_sg()
  (jsc#SLE-8449).
- PCI/P2PDMA: Whitelist some Intel host bridges (jsc#SLE-8449).
- PCI/P2PDMA: Factor out host_bridge_whitelist() (jsc#SLE-8449).
- PCI/P2PDMA: Apply host bridge whitelist for ACS (jsc#SLE-8449).
- PCI/P2PDMA: Factor out __upstream_bridge_distance()
  (jsc#SLE-8449).
- PCI/P2PDMA: Add constants for map type results to
  upstream_bridge_distance() (jsc#SLE-8449).
- PCI/P2PDMA: Add provider's pci_dev to pci_p2pdma_pagemap struct
  (jsc#SLE-8449).
- PCI/P2PDMA: Introduce private pagemap structure (jsc#SLE-8449).
- RDMA/efa: Fix incorrect error print (jsc#SLE-5640).
- RDMA/bnxt_re: Fix spelling mistake "missin_resp" ->
  "missing_resp" (jsc#SLE-8372 bsc#1153275).
- IB/{rdmavt, hfi1, qib}: Add a counter for credit waits
  (jsc#SLE-8449).
- IB/hfi1: Add traces for TID RDMA READ (jsc#SLE-8449).
- RDMA/siw: Relax from kmap_atomic() use in TX path
  (jsc#SLE-8381).
- IB/iser: Support up to 16MB data transfer in a single command
  (jsc#SLE-8449).
- RDMA/siw: Fix page address mapping in TX path (jsc#SLE-8381).
- RDMA: Fix goto target to release the allocated memory
  (jsc#SLE-8449).
- RDMA/usnic: Avoid overly large buffers on stack (jsc#SLE-8449).
- RDMA/odp: Add missing cast for 32 bit (jsc#SLE-8449).
- IB/mlx5: Add page fault handler for DC initiator WQE
  (jsc#SLE-8446).
- IB/mlx5: Remove check of FW capabilities in ODP page fault
  handling (jsc#SLE-8446).
- RDMA/iwpm: Delete unnecessary checks before the macro call
  "dev_kfree_skb" (jsc#SLE-8449).
- RDMA/efa: Use existing FIELD_SIZEOF macro (jsc#SLE-5640).
- RDMA/efa: Remove umem check on dereg MR flow (jsc#SLE-5640).
- RDMA/mlx5: RDMA_RX flow type support for user applications
  (jsc#SLE-8446).
- RDMA: Delete DEBUG code (jsc#SLE-8449).
- RDMA/mlx5: Annotate lock dependency in bind/unbind slave port
  (jsc#SLE-8446).
- IB/mlx5: Expose XRQ legacy commands over the DEVX interface
  (jsc#SLE-8446).
- IB/mlx5: Add legacy events to DEVX list (jsc#SLE-8446).
- RDMA/{cxgb3, cxgb4, i40iw}: Remove common code (jsc#SLE-8449).
- RDMA/core: Add common iWARP query port (jsc#SLE-8449).
- RDMA/cxgb3: Use ib_device_set_netdev() (jsc#SLE-8449).
- RDMA: Introduce ib_port_phys_state enum (jsc#SLE-8449).
- RDMA/efa: Rate limit admin queue error prints (jsc#SLE-5640).
- RDMA/core: Introduce ratelimited ibdev printk functions
  (jsc#SLE-8449).
- rdma: Enable ib_alloc_cq to spread work over a device's
  comp_vectors (jsc#SLE-8449).
- mlx5: Fix formats with line continuation whitespace
  (jsc#SLE-8464).
- RDMA/mlx5: Remove DEBUG ODP code (jsc#SLE-8446).
- RDMA/core: fix spelling mistake "Nelink" -> "Netlink"
  (jsc#SLE-8449).
- infiniband: Remove dev_err() usage after platform_get_irq()
  (jsc#SLE-8449).
- RDMA/efa: Expose device statistics (jsc#SLE-5640).
- IB/bnxt_re: Do not notifify GID change event (jsc#SLE-8372
  bsc#1153275).
- IB/mlx5: Support per device q counters in switchdev mode
  (jsc#SLE-8446).
- IB/mlx5: Refactor code for counters allocation (jsc#SLE-8446).
- qed*: Change dpi_addr to be denoted with __iomem (jsc#SLE-8401).
- IB/mlx5: Add CREATE_PSV/DESTROY_PSV for devx interface
  (jsc#SLE-8446).
- RDMA/core: Support netlink commands in non init_net net
  namespaces (jsc#SLE-8449).
- RDMA/mlx4: Annotate boolean arguments as bool and not int
  (jsc#SLE-8461).
- RDMA/mlx4: Separate creation of RWQ and QP (jsc#SLE-8461).
- IB/usnic: Use dev_get_drvdata (jsc#SLE-8449).
- RDMA/qedr: Remove Unneeded variable rc (jsc#SLE-8215).
- RDMA/qib: Unneeded variable ret (jsc#SLE-8449).
- IB/mlx5: Avoid unnecessary typecast (jsc#SLE-8446).
- RDMA/core: Annotate destroy of mutex to ensure that it is
  released as unlocked (jsc#SLE-8449).
- RDMA/hns: Fix comparison of unsigned long variable 'end'
  with less than zero (jsc#SLE-8449).
- RDMA/mlx4: Untag user pointers in mlx4_get_umem_mr
  (jsc#SLE-8461).
- IB/hfi1: Remove unused define (jsc#SLE-8449).
- RDMA/odp: remove ib_ucontext from ib_umem (jsc#SLE-8449).
- RDMA/odp: use mmu_notifier_get/put for 'struct
  ib_ucontext_per_mm' (jsc#SLE-8449).
- RDMA/mlx5: Use odp instead of mr->umem in pagefault_mr
  (jsc#SLE-8446).
- RDMA/mlx5: Use ib_umem_start instead of umem.address
  (jsc#SLE-8446).
- RDMA/core: Make invalidate_range a device operation
  (jsc#SLE-8449).
- RDMA/odp: Use kvcalloc for the dma_list and page_list
  (jsc#SLE-8449).
- RDMA/odp: Check for overflow when computing the umem_odp end
  (jsc#SLE-8449).
- RDMA/odp: Provide ib_umem_odp_release() to undo the allocs
  (jsc#SLE-8449).
- RDMA/odp: Split creating a umem_odp from ib_umem_get
  (jsc#SLE-8449).
- RDMA/odp: Make the three ways to create a umem_odp clear
  (jsc#SLE-8449).
- RMDA/odp: Consolidate umem_odp initialization (jsc#SLE-8449).
- RDMA/odp: Make it clearer when a umem is an implicit ODP umem
  (jsc#SLE-8449).
- RDMA/odp: Iterate over the whole rbtree directly (jsc#SLE-8449).
- RDMA/odp: Use the common interval tree library instead of
  generic (jsc#SLE-8449).
- refresh configs (INTERVAL_TREE=y on s390x)
- mm/mmu_notifiers: add a get/put scheme for the registration
  (jsc#SLE-8449).
- mm/mmu_notifiers: do not speculatively allocate a
  mmu_notifier_mm (jsc#SLE-8449).
- mm/mmu_notifiers: hoist do_mmu_notifier_register down_write
  to the caller (jsc#SLE-8449).
- infiniband: don't bother with d_delete() (jsc#SLE-8449).
- ethtool: implement Energy Detect Powerdown support via
  phy-tunable (bsc#1154353).
- drop_monitor: Better sanitize notified packets (bsc#1154353).
- tcp: Add snd_wnd to TCP_INFO (bsc#1154353).
- tcp: Add TCP_INFO counter for packets received out-of-order
  (bsc#1154353).
- bpf: fix accessing bpf_sysctl.file_pos on s390 (bsc#1154353).
- xdp: Fix race in dev_map_hash_update_elem() when replacing
  element (bsc#1154353).
- kcm: use BPF_PROG_RUN (bsc#1154353).
- net: sched: use get_dev() action API in flow_action infra
  (bsc#1154353).
- net: sched: take reference to psample group in flow_action infra
  (bsc#1154353).
- net: sched: extend flow_action_entry with destructor
  (bsc#1154353).
- qed: fix spelling mistake "fullill" -> "fulfill" (jsc#SLE-8401).
- net: devlink: move reload fail indication to devlink core and
  expose to user (bsc#1154353).
- net: devlink: split reload op into two (bsc#1154353).
- mlx4: Split restart_one into two functions (jsc#SLE-8460).
- cxgb4: Fix spelling typos (jsc#SLE-8389).
- nfp: read chip model from the PluDevice register (bsc#1154353).
- qed: Fix Config attribute frame format (jsc#SLE-8401).
- qed*: Fix size of config attribute dump (jsc#SLE-8401).
- nfp: devlink: set unknown fw_load_policy (bsc#1154353).
- devlink: add unknown 'fw_load_policy' value (bsc#1154353).
- net/mlx5: FWTrace, Reduce stack usage (jsc#SLE-8464).
- net/mlx5: Fix addr's type in mlx5dr_icm_dm (jsc#SLE-8464).
- net/mlx5: Fix rt's type in dr_action_create_reformat_action
  (jsc#SLE-8464).
- kdoc: fix nfp_fw_load documentation (bsc#1154353).
- nfp: devlink: add 'reset_dev_on_drv_probe' support
  (bsc#1154353).
- nfp: devlink: add 'fw_load_policy' support (bsc#1154353).
- nfp: add devlink param infrastructure (bsc#1154353).
- nfp: honor FW reset and loading policies (bsc#1154353).
- nfp: nsp: add support for hwinfo set operation (bsc#1154353).
- nfp: nsp: add support for optional hwinfo lookup (bsc#1154353).
- nfp: nsp: add support for fw_loaded command (bsc#1154353).
- devlink: add 'reset_dev_on_drv_probe' param (bsc#1154353).
- devlink: extend 'fw_load_policy' values (bsc#1154353).
- net/mlx4_en: ethtool: make array modes static const, makes
  object smaller (jsc#SLE-8460).
- net/tls: align non temporal copy to cache lines (bsc#1154353).
- net/tls: remove the record tail optimization (bsc#1154353).
- net/tls: use RCU for the adder to the offload record list
  (bsc#1154353).
- net/tls: unref frags in order (bsc#1154353).
- be2net: make two arrays static const, makes object smaller
  (jsc#SLE-8375).
- net/mlx5e: Add port buffer's congestion counters (jsc#SLE-8464).
- net/mlx5: Expose HW capability bits for port buffer per priority
  congestion counters (jsc#SLE-8464).
- net/mlx5: DR, Remove redundant dev_name print from err log
  (jsc#SLE-8464).
- net/mlx5: DR, Fix error return code in
  dr_domain_init_resources() (jsc#SLE-8464).
- net/mlx5: DR, Remove useless set memory to zero use memset()
  (jsc#SLE-8464).
- net/mlx5e: Remove unnecessary clear_bit()s (jsc#SLE-8464).
- net/mlx5e: kTLS, Remove unused function parameter
  (jsc#SLE-8464).
- net/mlx5: Use PTR_ERR_OR_ZERO rather than its implementation
  (jsc#SLE-8464).
- net/mlx5: fix missing assignment of variable err (jsc#SLE-8464).
- net/mlx5: fix spelling mistake "offlaods" -> "offloads"
  (jsc#SLE-8464).
- net/mlx5e: Remove leftover declaration (jsc#SLE-8464).
- net/mlx5e: Use ipv6_stub to avoid dependency with ipv6 being
  a module (jsc#SLE-8464).
- net/mlx5: Kconfig: Fix MLX5_CORE dependency with
  PCI_HYPERV_INTERFACE (jsc#SLE-8464).
- net/mlx5e: Fix static checker warning of potential pointer
  math issue (jsc#SLE-8464).
- tcp: ulp: fix possible crash in tcp_diag_get_aux_size()
  (bsc#1154353).
- net: fib_notifier: move fib_notifier_ops from struct net into
  per-net struct (bsc#1154353).
- xsk: lock the control mutex in sock_diag interface
  (bsc#1154353).
- xsk: avoid store-tearing when assigning umem (bsc#1154353).
- xsk: avoid store-tearing when assigning queues (bsc#1154353).
- net/mlx5e: Allow XSK frames smaller than a page (jsc#SLE-8464).
- mlx5e: modify driver for handling offsets (jsc#SLE-8464).
- bpf: fix error check in bpf_tcp_gen_syncookie (bsc#1154353).
- nfp: bpf: add simple map op cache (bsc#1154353).
- nfp: bpf: rework MTU checking (bsc#1154353).
- bpf: introduce verifier internal test flag (bsc#1154353).
- xdp: xdp_umem: replace kmap on vmap for umem map (bsc#1154353).
- bpf: add new BPF_BTF_GET_NEXT_ID syscall command (bsc#1154353).
- bpf: add BTF ids in procfs for file descriptors to BTF objects
  (bsc#1154353).
- bpf: Use PTR_ERR_OR_ZERO in xsk_map_inc() (bsc#1154353).
- xsk: support BPF_EXIST and BPF_NOEXIST flags in XSKMAP
  (bsc#1154353).
- bpf: support cloning sk storage on accept() (bsc#1154353).
- bpf: export bpf_map_inc_not_zero (bsc#1154353).
- net: Don't call XDP_SETUP_PROG when nothing is changed
  (bsc#1154353).
- net/mlx5e: Add AF_XDP need_wakeup support (jsc#SLE-8464).
- net/mlx5e: Move the SW XSK code from NAPI poll to a separate
  function (jsc#SLE-8464).
- btf: fix return value check in btf_vmlinux_init() (bsc#1154353).
- net_sched: act_police: add 2 new attributes to support police
  64bit rate and peakrate (bsc#1154353).
- nfp: Drop unnecessary continue in nfp_net_pf_alloc_vnics
  (bsc#1154353).
- net: qed: Move static keyword to the front of declaration
  (jsc#SLE-8401).
- net/tls: dedup the record cleanup (bsc#1154353).
- net/tls: clean up the number of #ifdefs for CONFIG_TLS_DEVICE
  (bsc#1154353).
- net/tls: narrow down the critical area of device_offload_lock
  (bsc#1154353).
- net/tls: don't jump to return (bsc#1154353).
- net/tls: use the full sk_proto pointer (bsc#1154353).
- net/sched: cbs: remove redundant assignment to variable
  port_rate (bsc#1154353).
- devlink: Add new info version tags for ASIC and FW
  (bsc#1154353).
- net/mlx5: Add devlink flow_steering_mode parameter
  (jsc#SLE-8464).
- net/mlx5: Add support to use SMFS in switchdev mode
  (jsc#SLE-8464).
- net/mlx5: Add API to set the namespace steering mode
  (jsc#SLE-8464).
- net/mlx5: Add direct rule fs_cmd implementation (jsc#SLE-8464).
- net/mlx5: DR, Add CONFIG_MLX5_SW_STEERING for software steering
  support (jsc#SLE-8464).
- update configs (MLX5_SW_STEERING=y)
- net/mlx5: DR, Expose APIs for direct rule managing
  (jsc#SLE-8464).
- net/mlx5: DR, Add required FW steering functionality
  (jsc#SLE-8464).
- net/mlx5: DR, Expose steering rule functionality (jsc#SLE-8464).
- net/mlx5: DR, Expose steering action functionality
  (jsc#SLE-8464).
- net/mlx5: DR, Expose steering matcher functionality
  (jsc#SLE-8464).
- net/mlx5: DR, Expose steering table functionality
  (jsc#SLE-8464).
- net/mlx5: DR, Expose steering domain functionality
  (jsc#SLE-8464).
- net/mlx5: DR, Add Steering entry (STE) utilities (jsc#SLE-8464).
- net/mlx5: DR, Expose an internal API to issue RDMA operations
  (jsc#SLE-8464).
- net/mlx5: DR, ICM pool memory allocator (jsc#SLE-8464).
- net/mlx5: DR, Add direct rule command utilities (jsc#SLE-8464).
- net/mlx5: DR, Add the internal direct rule types definitions
  (jsc#SLE-8464).
- net/mlx5: Add flow steering actions to fs_cmd shim layer
  (jsc#SLE-8464).
- net/mlx5: Set only stag for match untagged packets
  (jsc#SLE-8464).
- net/mlx5: Avoid disabling RoCE when uninitialized
  (jsc#SLE-8464).
- net/mlx5: Add HW bits and definitions required for SW steering
  (jsc#SLE-8464).
- net/mlx5: Move device memory management to mlx5_core
  (jsc#SLE-8464).
- mlx5: Add missing init_net check in FIB notifier (jsc#SLE-8464).
- devlink: Use switch-case instead of if-else (bsc#1154353).
- devlink: Make port index data type as unsigned int
  (bsc#1154353).
- net: tls: export protocol version, cipher, tx_conf/rx_conf to
  socket diag (bsc#1154353).
- tcp: ulp: add functions to dump ulp-specific information
  (bsc#1154353).
- net/tls: use RCU protection on icsk->icsk_ulp_data
  (bsc#1154353).
- qede: Add support for dumping the grc data (jsc#SLE-8401).
- qed: Add APIs for configuring grc dump config flags
  (jsc#SLE-8401).
- qede: Add support for reading the config id attributes
  (jsc#SLE-8401).
- qed: Add APIs for reading config id attributes (jsc#SLE-8401).
- udp: Remove unlikely() from IS_ERR*() condition (bsc#1154353).
- net/mlx5e: Remove unlikely() from WARN*() condition
  (jsc#SLE-8464).
- net/mlx5e: Move local var definition into ifdef block
  (jsc#SLE-8464).
- net: sched: cls_matchall: cleanup flow_action before
  deallocating (bsc#1154353).
- sched: act_vlan: implement stats_update callback (bsc#1154353).
- net/mlx5e: Support TSO and TX checksum offloads for IP-in-IP
  tunnels (jsc#SLE-8464).
- net/mlx5e: Improve stateless offload capability check
  (jsc#SLE-8464).
- net/mlx5e: Support RSS for IP-in-IP and IPv6 tunneled packets
  (jsc#SLE-8464).
- net/mlx5e: Change function's position to a more fitting file
  (jsc#SLE-8464).
- net/mlx5e: Add device out of buffer counter (jsc#SLE-8464).
- net/mlx5e: Support LAG TX port affinity distribution
  (jsc#SLE-8464).
- net/mlx5e: Expose new function for TIS destroy loop
  (jsc#SLE-8464).
- net/mlx5e: ethtool, Fix a typo in WOL function names
  (jsc#SLE-8464).
- net/mlx5: Set ODP capabilities for DC transport to max
  (jsc#SLE-8464).
- net/mlx5: fix a -Wstringop-truncation warning (jsc#SLE-8464).
- net/mlx5: Create bypass and loopback flow steering namespaces
  for RDMA RX (jsc#SLE-8464).
- net/mlx5: Add per-namespace flow table default miss action
  support (jsc#SLE-8464).
- net/mlx5: Add lag_tx_port_affinity capability bit
  (jsc#SLE-8464).
- net/mlx5: Expose IP-in-IP capability bit (jsc#SLE-8464).
- net/mlx5: Add support for VNIC_ENV internal rq counter
  (jsc#SLE-8464).
- net/mlx5: Improve functions documentation (jsc#SLE-8464).
- net/mlx5: Add missing include file to lib/crypto.c
  (jsc#SLE-8464).
- net/mlx5: Add XRQ legacy commands opcodes (jsc#SLE-8464).
- net/mlx5: Use debug message instead of warn (jsc#SLE-8464).
- mlx5: Use refcount_t for refcount (jsc#SLE-8464).
- net/mlx5: remove self-assignment on esw->dev (jsc#SLE-8464).
- IB/mlx5: Support MLX5_CMD_OP_QUERY_LAG as a DEVX general command
  (jsc#SLE-8446).
- net/mlx5: Fix mlx5_ifc_query_lag_out_bits (jsc#SLE-8464).
- nfp: add AMDA0058 boards to firmware list (bsc#1154353).
- net: sched: flower: don't take rtnl lock for cls hw offloads
  API (bsc#1154353).
- net: sched: copy tunnel info when setting flow_action
  entry->tunnel (bsc#1154353).
- net: sched: take reference to action dev before calling offloads
  (bsc#1154353).
- net: sched: take rtnl lock in tc_setup_flow_action()
  (bsc#1154353).
- net: sched: conditionally obtain rtnl lock in cls hw offloads
  API (bsc#1154353).
- net: sched: add API for registering unlocked offload block
  callbacks (bsc#1154353).
- net: sched: notify classifier on successful offload add/delete
  (bsc#1154353).
- net: sched: refactor block offloads counter usage (bsc#1154353).
- net: sched: change tcf block offload counter type to atomic_t
  (bsc#1154353).
- net: sched: protect block offload-related fields with
  rw_semaphore (bsc#1154353).
- =?UTF-8?q?net/core/skmsg:=20Delete=20an=20unnecessary=20c?=
  =?UTF-8?q?heck=20before=20the=20function=20call=20=E2=80=9Cconsume=5Fskb?=
  =?UTF-8?q?=E2=80=9D?= (bsc#1154353).
- net: use unlikely for dql_avail case (bsc#1154353).
- drop_monitor: Make timestamps y2038 safe (bsc#1154353).
- net/mlx5: Fix return code in case of hyperv wrong size read
  (jsc#SLE-8464).
- net: ipv6: fix listify ip6_rcv_finish in case of forwarding
  (bsc#1154353).
- net/mlx5e: Add mlx5e HV VHCA stats agent (jsc#SLE-8464).
- net/mlx5: Add HV VHCA control agent (jsc#SLE-8464).
- net/mlx5: Add HV VHCA infrastructure (jsc#SLE-8464).
- net/mlx5: Add wrappers for HyperV PCIe operations
  (jsc#SLE-8464).
- net/mlx5e: Add trace point for neigh update (jsc#SLE-8464).
- net/mlx5e: Add trace point for neigh used value update
  (jsc#SLE-8464).
- net/mlx5e: Add tc flower tracepoints (jsc#SLE-8464).
- net/mlx5e: Only access fully initialized flows in neigh update
  (jsc#SLE-8464).
- net/mlx5e: Refactor neigh update for concurrent execution
  (jsc#SLE-8464).
- net/mlx5e: Refactor neigh used value update for concurrent
  execution (jsc#SLE-8464).
- net/mlx5e: Protect neigh hash encap list with spinlock and rcu
  (jsc#SLE-8464).
- net/mlx5e: Refactor mlx5e_neigh_update_table->encap_lock
  (jsc#SLE-8464).
- net/mlx5e: Extend neigh hash entry with rcu (jsc#SLE-8464).
- net/mlx5e: Always take reference to neigh entry (jsc#SLE-8464).
- net/mlx5e: Extract code that queues neigh update work into
  function (jsc#SLE-8464).
- net/mlx5: Fix the order of fc_stats cleanup (jsc#SLE-8464).
- net/mlx5e: Fix deallocation of non-fully init encap entries
  (jsc#SLE-8464).
- net/mlx5e: Report and recover from CQE with error on RQ
  (jsc#SLE-8464).
- net/mlx5e: RX, Handle CQE with error at the earliest stage
  (jsc#SLE-8464).
- net/mlx5e: Report and recover from rx timeout (jsc#SLE-8464).
- net/mlx5e: Report and recover from CQE error on ICOSQ
  (jsc#SLE-8464).
- net/mlx5e: Split open/close ICOSQ into stages (jsc#SLE-8464).
- net/mlx5e: Add support to rx reporter diagnose (jsc#SLE-8464).
- net/mlx5e: Add helper functions for reporter's basics
  (jsc#SLE-8464).
- net/mlx5e: Add cq info to tx reporter diagnose (jsc#SLE-8464).
- net/mlx5e: Extend tx reporter diagnostics output (jsc#SLE-8464).
- net/mlx5e: Extend tx diagnose function (jsc#SLE-8464).
- net/mlx5e: Generalize tx reporter's functionality
  (jsc#SLE-8464).
- net/mlx5e: Change naming convention for reporter's functions
  (jsc#SLE-8464).
- net/mlx5e: Rename reporter header file (jsc#SLE-8464).
- net: flow_offload: convert block_ing_cb_list to regular list
  type (bsc#1154353).
- be2net: eliminate enable field from be_aic_obj (jsc#SLE-8375).
- Documentation: Add devlink-trap documentation (bsc#1154353).
- devlink: Add generic packet traps and groups (bsc#1154353).
- devlink: Add packet trap infrastructure (bsc#1154353).
- refresh configs
- drop_monitor: Allow user to start monitoring hardware drops
  (bsc#1154353).
- drop_monitor: Add support for summary alert mode for hardware
  drops (bsc#1154353).
- drop_monitor: Add support for packet alert mode for hardware
  drops (bsc#1154353).
- drop_monitor: Consider all monitoring states before performing
  configuration (bsc#1154353).
- drop_monitor: Add basic infrastructure for hardware drops
  (bsc#1154353).
- drop_monitor: Initialize hardware per-CPU data (bsc#1154353).
- drop_monitor: Move per-CPU data init/fini to separate functions
  (bsc#1154353).
- qed: Add driver API for flashing the config attributes
  (jsc#SLE-8401).
- qed: Add API for configuring NVM attributes (jsc#SLE-8401).
- page_pool: fix logic in __page_pool_get_cached (bsc#1154353).
- page_pool: remove unnecessary variable init (bsc#1154353).
- net: devlink: remove redundant rtnl lock assert (bsc#1154353).
- btf: rename /sys/kernel/btf/kernel into /sys/kernel/btf/vmlinux
  (bsc#1154353).
- btf: expose BTF info through sysfs (bsc#1154353).
- xdp: xdp_umem: fix umem pages mapping for 32bits systems
  (bsc#1154353).
- bpf: always allocate at least 16 bytes for setsockopt hook
  (bsc#1154353).
- bpf: add bpf_tcp_gen_syncookie helper (bsc#1154353).
- tcp: add skb-less helpers to retrieve SYN cookie (bsc#1154353).
- tcp: tcp_syn_flood_action read port from socket (bsc#1154353).
- xdp: Add devmap_hash map type for looking up devices by hashed
  index (bsc#1154353).
- xdp: Refactor devmap allocation code for reuse (bsc#1154353).
- include/bpf.h: Remove map_insert_ctx() stubs (bsc#1154353).
- bpf/flow_dissector: support ipv6 flow_label and
  BPF_FLOW_DISSECTOR_F_STOP_AT_FLOW_LABEL (bsc#1154353).
- selftests/bpf: support BPF_FLOW_DISSECTOR_F_PARSE_1ST_FRAG
  (bsc#1154353).
- tools/bpf: sync bpf_flow_keys flags (bsc#1154353).
- bpf/flow_dissector: support flags in BPF_PROG_TEST_RUN
  (bsc#1154353).
- bpf/flow_dissector: pass input flags to BPF flow dissector
  program (bsc#1154353).
- selftests/bpf: Add selftests for bpf_perf_event_output
  (bsc#1154353).
- bpf: Allow bpf_skb_event_output for a few prog types
  (bsc#1154353).
- selftests/bpf: remove perf buffer helpers (bsc#1154353).
- selftests/bpf: switch test_tcpnotify to perf_buffer API
  (bsc#1154353).
- selftests/bpf: convert test_get_stack_raw_tp to perf_buffer API
  (bsc#1154353).
- devlink: send notifications for deleted snapshots on region
  destroy (bsc#1154353).
- drop_monitor: Expose tail drop counter (bsc#1154353).
- drop_monitor: Make drop queue length configurable (bsc#1154353).
- drop_monitor: Add a command to query current configuration
  (bsc#1154353).
- drop_monitor: Allow truncation of dropped packets (bsc#1154353).
- drop_monitor: Add packet alert mode (bsc#1154353).
- drop_monitor: Add alert mode operations (bsc#1154353).
- drop_monitor: Require CAP_NET_ADMIN for drop monitor
  configuration (bsc#1154353).
- drop_monitor: Reset per-CPU data before starting to trace
  (bsc#1154353).
- drop_monitor: Initialize timer and work item upon tracing enable
  (bsc#1154353).
- drop_monitor: Split tracing enable / disable to different
  functions (bsc#1154353).
- nfp: no need to check return value of debugfs_create functions
  (bsc#1154353).
- cxgb4: no need to check return value of debugfs_create functions
  (jsc#SLE-8389).
- mlx5: no need to check return value of debugfs_create functions
  (jsc#SLE-8464).
- net/mlx5e: Use refcount_t for refcount (jsc#SLE-8464).
- net/mlx5e: Use vhca_id in generating representor port_index
  (jsc#SLE-8464).
- net/mlx5e: Simplify querying port representor parent id
  (jsc#SLE-8464).
- net/mlx5: E-switch, Removed unused hwid (jsc#SLE-8464).
- net/mlx5e: Allow concurrent creation of encap entries
  (jsc#SLE-8464).
- net/mlx5e: Protect encap hash table with mutex (jsc#SLE-8464).
- net/mlx5e: Extend encap entry with reference counter
  (jsc#SLE-8464).
- net/mlx5e: Allow concurrent creation of mod_hdr entries
  (jsc#SLE-8464).
- net/mlx5e: Protect mod_hdr hash table with mutex (jsc#SLE-8464).
- net/mlx5e: Protect mod header entry flows list with spinlock
  (jsc#SLE-8464).
- net/mlx5e: Extend mod header entry with reference counter
  (jsc#SLE-8464).
- net/mlx5e: Allow concurrent creation of hairpin entries
  (jsc#SLE-8464).
- net/mlx5e: Protect hairpin hash table with mutex (jsc#SLE-8464).
- net/mlx5e: Protect hairpin entry flows list with spinlock
  (jsc#SLE-8464).
- net/mlx5e: Extend hairpin entry with reference counter
  (jsc#SLE-8464).
- devlink: remove pointless data_len arg from region snapshot
  create (jsc#SLE-8460).
- fq_codel: remove set but not used variables 'prev_ecn_mark'
  and 'prev_drop_count' (bsc#1154353).
- flow_offload: support get multi-subsystem block (bsc#1154353).
- flow_offload: move tc indirect block to flow offload
  (bsc#1154353).
- cls_api: add flow_indr_block_call function (bsc#1154353).
- cls_api: remove the tcf_block cache (bsc#1154353).
- cls_api: modify the tc_indr_block_ing_cmd parameters
  (bsc#1154353).
- net: use listified RX for handling GRO_NORMAL skbs
  (bsc#1154353).
- sfc: falcon: don't score irq moderation points for GRO
  (jsc#SLE-8314).
- sfc: don't score irq moderation points for GRO (jsc#SLE-8314).
- qed: Add new ethtool supported port types based on media
  (jsc#SLE-8401).
- cxgb4: smt: Use normal int for refcount (jsc#SLE-8389).
- cxgb4: smt: Add lock for atomic_dec_and_test (jsc#SLE-8389).
- nfp: flower: encode mac indexes with pre-tunnel rule check
  (bsc#1154353).
- nfp: flower: remove offloaded MACs when reprs are applied to
  OvS bridges (bsc#1154353).
- nfp: flower: offload pre-tunnel rules (bsc#1154353).
- nfp: flower: verify pre-tunnel rules (bsc#1154353).
- nfp: flower: detect potential pre-tunnel rules (bsc#1154353).
- nfp: flower: push vlan after tunnel in merge (bsc#1154353).
- net: sched: add ingress mirred action to hardware IR
  (bsc#1154353).
- net: tc_act: add helpers to detect ingress mirred actions
  (bsc#1154353).
- net: sched: add skbedit of ptype action to hardware IR
  (bsc#1154353).
- net: tc_act: add skbedit_ptype helper functions (bsc#1154353).
- fq_codel: Kill useless per-flow dropped statistic (bsc#1154353).
- Increase fq_codel count in the bulk dropper (bsc#1154353).
- drop_monitor: Use pre_doit / post_doit hooks (bsc#1154353).
- drop_monitor: Add extack support (bsc#1154353).
- drop_monitor: Avoid multiple blank lines (bsc#1154353).
- drop_monitor: Document scope of spinlock (bsc#1154353).
- drop_monitor: Rename and document scope of mutex (bsc#1154353).
- drop_monitor: Use correct error code (bsc#1154353).
- net/mlx5e: Allow dropping specific tunnel packets
  (jsc#SLE-8464).
- net/mlx5e: TX reporter cleanup (jsc#SLE-8464).
- net/mlx5e: Set tx reporter only on successful creation
  (jsc#SLE-8464).
- net/mlx5e: Fix mlx5e_tx_reporter_create return value
  (jsc#SLE-8464).
- net/mlx5e: Rx, checksum handling refactoring (jsc#SLE-8464).
- net/mlx5e: Tx, Soften inline mode VLAN dependencies
  (jsc#SLE-8464).
- net/mlx5e: XDP, Slight enhancement for WQE fetch function
  (jsc#SLE-8464).
- net/mlx5e: XDP, Close TX MPWQE session when no room for inline
  packet left (jsc#SLE-8464).
- net/mlx5e: Tx, Strict the room needed for SQ edge NOPs
  (jsc#SLE-8464).
- net/mlx5: Add flow counter pool (jsc#SLE-8464).
- net/mlx5: Add flow counter bulk infrastructure (jsc#SLE-8464).
- net/mlx5: E-Switch, add ingress rate support (jsc#SLE-8464).
- net/mlx5: E-switch, Tide up eswitch config sequence
  (jsc#SLE-8464).
- net/mlx5: E-Switch, Remove redundant mc_promisc NULL check
  (jsc#SLE-8464).
- net/mlx5: E-Switch, remove redundant error handling
  (jsc#SLE-8464).
- net/mlx5: E-switch, Introduce helper function to enable/disable
  vports (jsc#SLE-8464).
- net/mlx5: E-switch, Initialize TSAR Qos hardware block before
  its user vports (jsc#SLE-8464).
- net/mlx5: E-switch, Combine metadata enable/disable
  functionality (jsc#SLE-8464).
- net/mlx5: E-Switch, Verify support QoS element type
  (jsc#SLE-8464).
- net/mlx5: Make load_one() and unload_one() symmetric
  (jsc#SLE-8464).
- net/mlx5: Fix offset of tisc bits reserved field (jsc#SLE-8464).
- net/mlx5: Add flow counter bulk allocation hardware bits and
  command (jsc#SLE-8464).
- net/mlx5: Refactor and optimize flow counter bulk query
  (jsc#SLE-8464).
- net/mlx5: fix -Wtype-limits compilation warnings (jsc#SLE-8464).
- net/mlx5e: Protect tc flow table with mutex (jsc#SLE-8464).
- net/mlx5e: Rely on rcu instead of rtnl lock when getting upper
  dev (jsc#SLE-8464).
- net/mlx5e: Eswitch, use state_lock to synchronize vlan change
  (jsc#SLE-8464).
- net/mlx5e: Eswitch, change offloads num_flows type to atomic64
  (jsc#SLE-8464).
- net/mlx5e: Protect unready flows with dedicated lock
  (jsc#SLE-8464).
- net/mlx5e: Protect tc flows hashtable with rcu (jsc#SLE-8464).
- net/mlx5e: Change flow flags type to unsigned long
  (jsc#SLE-8464).
- net/mlx5e: Extend tc flow struct with reference counter
  (jsc#SLE-8464).
- net/mlx5e: Simplify get_route_and_out_devs helper function
  (jsc#SLE-8464).
- net/mlx5e: Fix unnecessary flow_block_cb_is_busy call
  (jsc#SLE-8464).
- net/mlx5e: Improve ethtool rxnfc callback structure
  (jsc#SLE-8464).
- net/mlx5e: Avoid warning print when not required (jsc#SLE-8464).
- net/mlx5e: Print a warning when LRO feature is dropped or not
  allowed (jsc#SLE-8464).
- linux: Remove bvec page_offset, use bv_offset (bsc#1154353).
- mlx4/en_netdev: allow offloading VXLAN over VLAN (jsc#SLE-8460).
- net: neigh: remove redundant assignment to variable bucket
  (bsc#1154353).
- net: sfc: falcon: convert to i2c_new_dummy_device
  (jsc#SLE-8314).
- mlx4: avoid large stack usage in mlx4_init_hca() (jsc#SLE-8460).
- qed: reduce maximum stack frame size (jsc#SLE-8401).
- sfc-falcon: Use dev_get_drvdata where possible (jsc#SLE-8314).
- sfc: Use dev_get_drvdata where possible (jsc#SLE-8314).
- nfp: flower: offload MPLS set action (bsc#1154353).
- nfp: flower: offload MPLS pop action (bsc#1154353).
- nfp: flower: offload MPLS push action (bsc#1154353).
- net: sched: include mpls actions in hardware intermediate
  representation (bsc#1154353).
- net/mlx5e: xsk: dynamically allocate mlx5e_channel_param
  (jsc#SLE-8464).
- drivers: Introduce device lookup variants by fwnode
  (jsc#SLE-8449).
- drivers: Introduce device lookup variants by of_node
  (jsc#SLE-8449).
- drivers: Introduce device lookup variants by name
  (jsc#SLE-8449).
- commit 1851aa6
* Thu Oct 17 2019 yousaf.kaukab@suse.com
- ipmi_ssif: avoid registering duplicate ssif interface
  (jsc#SLE-10031).
- commit a68b3cc
* Thu Oct 17 2019 tbogendoerfer@suse.de
- tcp: fix slab-out-of-bounds in tcp_zerocopy_receive()
  (jsc#SLE-7979 jsc#SLE-7981).
- bpf/xskmap: Return ERR_PTR for failure case instead of NULL
  (jsc#SLE-8025).
- xsk: use state member for socket synchronization (jsc#SLE-8025).
- staging: octeon: Fix build failure due to typo (jsc#SLE-7979
  jsc#SLE-7981).
- ftgmac100: Fix build (jsc#SLE-7979 jsc#SLE-7981).
- commit 01068a7
* Thu Oct 17 2019 fdmanana@suse.com
- Btrfs: check for the full sync flag while holding the inode
  lock during fsync (bsc#1153713).
- commit 3467605
* Thu Oct 17 2019 acho@suse.com
- cfg80211: wext: avoid copying malformed SSIDs (bsc#1153158
  CVE-2019-17133).
- commit 3ac14b4
* Wed Oct 16 2019 tbogendoerfer@suse.de
- bnxt_en: Add a new BNXT_FW_RESET_STATE_POLL_FW_DOWN state
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Update firmware interface spec. to 1.10.0.100
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Increase timeout for HWRM_DBG_COREDUMP_XX commands
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Don't proceed in .ndo_set_rx_mode() when device is
  not in open state (jsc#SLE-8371 bsc#1153274).
- ixgbe: fix xdp handle calculations (jsc#SLE-7979 jsc#SLE-7981).
- i40e: fix xdp handle calculations (jsc#SLE-8025).
- ice: Bump version (jsc#SLE-7926).
- ice: Enable DDP package download (jsc#SLE-7926).
- ice: Initialize DDP package structures (jsc#SLE-7926).
- ice: Implement Dynamic Device Personalization (DDP) download
  (jsc#SLE-7926).
- ice: Fix FW version formatting in dmesg (jsc#SLE-7926).
- ice: send driver version to firmware (jsc#SLE-7926).
- i40e: fix potential RX buffer starvation for AF_XDP
  (jsc#SLE-8025).
- net/ixgbevf: make array api static const, makes object smaller
  (jsc#SLE-7979 jsc#SLE-7981).
- iavf: fix MAC address setting for VFs when filter is rejected
  (jsc#SLE-7940).
- i40e: clear __I40E_VIRTCHNL_OP_PENDING on invalid min Tx rate
  (jsc#SLE-8025).
- i40e: use BIT macro to specify the cloud filter field flags
  (jsc#SLE-8025).
- i40e: Fix message for other card without FEC (jsc#SLE-8025).
- i40e: fix missed "Negotiated" string in
  i40e_print_link_message() (jsc#SLE-8025).
- i40e: mark additional missing bits as reserved (jsc#SLE-8025).
- i40e: remove I40E_AQC_ADD_CLOUD_FILTER_OIP (jsc#SLE-8025).
- i40e: use ktime_get_real_ts64 instead of ktime_to_timespec64
  (jsc#SLE-8025).
- ixgbe: use skb_get_queue_mapping in tx path (jsc#SLE-7979
  jsc#SLE-7981).
- ixgbe: fix memory leaks (jsc#SLE-7979 jsc#SLE-7981).
- i40e: Add support for X710 device (jsc#SLE-8025).
- igc: Add tx_csum offload functionality (jsc#SLE-7966).
- ixgbe: sync the first fragment unconditionally (jsc#SLE-7979
  jsc#SLE-7981).
- i40e: Remove EMPR traces from debugfs facility (jsc#SLE-8025).
- i40e: Implement debug macro hw_dbg using dev_dbg (jsc#SLE-8025).
- i40e: fix hw_dbg usage in i40e_hmc_get_object_va (jsc#SLE-8025).
- igc: Remove unneeded PCI bus defines (jsc#SLE-7966).
- iavf: allow permanent MAC address to change (jsc#SLE-7940).
- igc: Add NVM checksum validation (jsc#SLE-7966).
- fm10k: use a local variable for the frag pointer (jsc#SLE-8009).
- igc: Remove useless forward declaration (jsc#SLE-7966).
- e1000e: Make speed detection on hotplugging cable more reliable
  (jsc#SLE-8100).
- ixgbevf: Link lost in VM on ixgbevf when restoring from freeze
  or suspend (jsc#SLE-7979 jsc#SLE-7981).
- iavf: remove unused debug function iavf_debug_d (jsc#SLE-7940).
- ice: Rework around device/function capabilities (jsc#SLE-7926).
- ice: change default number of receive descriptors
  (jsc#SLE-7926).
- ice: Minor refactor in queue management (jsc#SLE-7926).
- ice: Allow for delayed LLDP MIB change registration
  (jsc#SLE-7926).
- ice: update Tx context struct (jsc#SLE-7926).
- ice: Report VF link status with opcode to get resources
  (jsc#SLE-7926).
- ice: Check for DCB capability before initializing DCB
  (jsc#SLE-7926).
- ice: report link down for VF when PF's queues are not enabled
  (jsc#SLE-7926).
- ice: Reliably reset VFs (jsc#SLE-7926).
- ice: change work limit to a constant (jsc#SLE-7926).
- ice: small efficiency fixes (jsc#SLE-7926).
- ice: move code closer together (jsc#SLE-7926).
- ice: clean up arguments (jsc#SLE-7926).
- ice: Check root pointer for validity (jsc#SLE-7926).
- ice: Add ice_get_main_vsi to get PF/main VSI (jsc#SLE-7926).
- ice: Update fields in ice_vsi_set_num_qs when reconfiguring
  (jsc#SLE-7926).
- ixgbe: fix xdp handle calculations (jsc#SLE-7979 jsc#SLE-7981).
- i40e: fix xdp handle calculations (jsc#SLE-8025).
- ixgbe: modify driver for handling offsets (jsc#SLE-7979
  jsc#SLE-7981).
- i40e: modify driver for handling offsets (jsc#SLE-8025).
- xsk: add support to allow unaligned chunk placement
  (jsc#SLE-8025).
- ixgbe: simplify Rx buffer recycle (jsc#SLE-7979 jsc#SLE-7981).
- i40e: simplify Rx buffer recycle (jsc#SLE-8025).
- xsk: remove AF_XDP socket from map when the socket is released
  (jsc#SLE-8025).
- ixgbe: add support for AF_XDP need_wakeup feature (jsc#SLE-7979
  jsc#SLE-7981).
- i40e: add support for AF_XDP need_wakeup feature (jsc#SLE-8025).
- xsk: add support for need_wakeup flag in AF_XDP rings
  (jsc#SLE-8025).
- xsk: replace ndo_xsk_async_xmit with ndo_xsk_wakeup
  (jsc#SLE-7979 jsc#SLE-7981).
- ixgbe: Use kzfree() rather than its implementation (jsc#SLE-7979
  jsc#SLE-7981).
- ice: Only disable VLAN pruning for the VF when all VLANs are
  removed (jsc#SLE-7926).
- ice: Remove enable DCB when SW LLDP is activated (jsc#SLE-7926).
- ice: Report stats when VSI is down (jsc#SLE-7926).
- ice: Always notify FW of VF reset (jsc#SLE-7926).
- ice: Correctly handle return values for init DCB (jsc#SLE-7926).
- ice: Limit Max TCs on devices with more than 4 ports
  (jsc#SLE-7926).
- ice: Cleanup defines in ice_type.h (jsc#SLE-7926).
- ice: print extra message if topology issue (jsc#SLE-7926).
- ice: add print of autoneg state to link message (jsc#SLE-7926).
- ice: update driver unloading field for Queue Shutdown AQ command
  (jsc#SLE-7926).
- ice: add needed PFR during driver unload (jsc#SLE-7926).
- ice: Deduce TSA value from the priority value in the CEE mode
  (jsc#SLE-7926).
- ice: Report what the user set for coalesce [tx|rx]-usecs
  (jsc#SLE-7926).
- ice: Fix resource leak in ice_remove_rule_internal()
  (jsc#SLE-7926).
- ice: Fix EMP reset handling (jsc#SLE-7926).
- bnxt_en: Fix compile error regression with CONFIG_BNXT_SRIOV
  not set (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add FW fatal devlink_health_reporter (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Add bnxt_fw_exception() to handle fatal firmware errors
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add RESET_FW state logic to bnxt_fw_reset_task()
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Do not send firmware messages if firmware is in error
  state (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Retain user settings on a VF after RESET_NOTIFY event
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add devlink health reset reporter (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Handle firmware reset (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Handle RESET_NOTIFY async event from firmware
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add new FW devlink_health_reporter (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Add BNXT_STATE_IN_FW_RESET state (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Enable health monitoring (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Pre-map the firmware health monitoring registers
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Discover firmware error recovery capabilities
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Handle firmware reset status during IF_UP (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Register buffers for VFs before reserving resources
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor bnxt_sriov_enable() (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Prepare bnxt_init_one() to be called multiple times
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Suppress all error messages in hwrm_do_send_msg()
  in silent mode (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Simplify error checking in the SR-IOV message
  forwarding functions (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Convert error code in firmware message response to
  standard code (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Remove the -1 error return code from
  bnxt_hwrm_do_send_msg() (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Use a common function to print the same ethtool -f
  error message (jsc#SLE-8371 bsc#1153274).
- ice: fix adminq calls during remove (jsc#SLE-7926).
- ice: Rework ice_ena_msix_range (jsc#SLE-7926).
- ice: Fix VF configuration issues due to reset (jsc#SLE-7926).
- ice: Alloc queue management bitmaps and arrays dynamically
  (jsc#SLE-7926).
- ice: add support for virtchnl_queue_select.[tx|rx]_queues bitmap
  (jsc#SLE-7926).
- ice: add support for enabling/disabling single queues
  (jsc#SLE-7926).
- ice: fix potential infinite loop (jsc#SLE-7926).
- ice: fix ice_is_tc_ena (jsc#SLE-7926).
- ice: add validation in OP_CONFIG_VSI_QUEUES VF message
  (jsc#SLE-7926).
- ice: Don't clog kernel debug log with VF MDD events errors
  (jsc#SLE-7926).
- ice: Introduce a local variable for a VSI in the rebuild path
  (jsc#SLE-7926).
- ice: shorten local and add debug prints (jsc#SLE-7926).
- ice: Sanitize ice_ena_vsi and ice_dis_vsi (jsc#SLE-7926).
- ice: added sibling head to parse nodes (jsc#SLE-7926).
- ice: Fix ethtool port and PFC stats for 4x25G cards
  (jsc#SLE-7926).
- ice: Don't allow VSI to remove unassociated ucast filter
  (jsc#SLE-7926).
- ice: Fix issues updating VSI MAC filters (jsc#SLE-7926).
- ice: update ethtool stats on-demand (jsc#SLE-7926).
- ice: Add input handlers for virtual channel handlers
  (jsc#SLE-7926).
- ice: Don't clear auto_fec bit in ice_cfg_phy_fec()
  (jsc#SLE-7926).
- ice: Fix flag used for module query (jsc#SLE-7926).
- ice: silence some bogus error messages (jsc#SLE-7926).
- ice: Rename ethtool private flag for lldp (jsc#SLE-7926).
- ice: reject VF attempts to enable head writeback (jsc#SLE-7926).
- ice: Copy dcbx configuration only if mode is correct
  (jsc#SLE-7926).
- ice: Treat DCBx state NOT_STARTED as valid (jsc#SLE-7926).
- ice: Don't call synchronize_irq() for VF's from the host
  (jsc#SLE-7926).
- ice: Account for all states of FW DCBx and LLDP (jsc#SLE-7926).
- ice: Allow egress control packets from PF_VSI (jsc#SLE-7926).
- bnxt_en: Fix allocation of zero statistics block size regression
  (jsc#SLE-8371 bsc#1153274).
- =?UTF-8?q?ethernet:=20Delete=20unnecessary=20checks=20bef?=
  =?UTF-8?q?ore=20the=20macro=20call=20=E2=80=9Cdev=5Fkfree=5Fskb=E2=80=9D?=
  (jsc#SLE-7966).
- i40e: fix retrying in i40e_aq_get_phy_capabilities
  (jsc#SLE-8025).
- i40e: Persistent LLDP support (jsc#SLE-8025).
- i40e: allow reset in recovery mode (jsc#SLE-8025).
- i40e: Remove function i40e_update_dcb_config() (jsc#SLE-8025).
- i40e: Fix crash caused by stress setting of VF MAC addresses
  (jsc#SLE-8025).
- i40e: reset veb.tc_stats when resetting veb.stats
  (jsc#SLE-8025).
- i40e: Update FW API version to 1.9 (jsc#SLE-8025).
- i40e: check_recovery_mode had wrong if statement (jsc#SLE-8025).
- i40e: Add drop mode parameter to set mac config (jsc#SLE-8025).
- i40e: fix shifts of signed values (jsc#SLE-8025).
- i40e: add check on i40e_configure_tx_ring() return value
  (jsc#SLE-8025).
- i40e: Check if transceiver implements DDM before access
  (jsc#SLE-8025).
- i40e: reduce stack usage in i40e_set_fc (jsc#SLE-8025).
- ice: improve print for VF's when adding/deleting MAC filters
  (jsc#SLE-7926).
- ice: Change type for queue counts (jsc#SLE-7926).
- ice: Move VF resources definition to SR-IOV specific file
  (jsc#SLE-7926).
- ice: Increase size of Mailbox receive queue for many VFs
  (jsc#SLE-7926).
- ice: Reduce wait times during VF bringup/reset (jsc#SLE-7926).
- ice: update GLINT_DYN_CTL and GLINT_VECT2FUNC register access
  (jsc#SLE-7926).
- ice: Do not always bring up PF VSI in ice_ena_vsi()
  (jsc#SLE-7926).
- ice: allow empty Rx descriptors (jsc#SLE-7926).
- ice: Fix kernel hang with DCB reset in CEE mode (jsc#SLE-7926).
- ice: Set WB_ON_ITR when we don't re-enable interrupts
  (jsc#SLE-7926).
- ice: fix set pause param autoneg check (jsc#SLE-7926).
- ice: Restructure VFs initialization flows (jsc#SLE-7926).
- ice: Assume that more than one Rx queue is rare in ice_napi_poll
  (jsc#SLE-7926).
- ice: Use the software based tail when checking for hung Tx ring
  (jsc#SLE-7926).
- ixgbe: no need to check return value of debugfs_create functions
  (jsc#SLE-7979 jsc#SLE-7981).
- i40e: no need to check return value of debugfs_create functions
  (jsc#SLE-8025).
- fm10k: no need to check return value of debugfs_create functions
  (jsc#SLE-8009).
- bnxt: no need to check return value of debugfs_create functions
  (jsc#SLE-8371 bsc#1153274).
- i40e: Remove unicast log when VF is leaving multicast mode
  (jsc#SLE-8025).
- i40e: verify string count matches even on early return
  (jsc#SLE-8025).
- i40e: Log info when PF is entering and leaving Allmulti mode
  (jsc#SLE-8025).
- i40e: Update visual effect for advertised FEC mode
  (jsc#SLE-8025).
- i40e: fix code comments (jsc#SLE-8025).
- i40e: don't report link up for a VF who hasn't enabled queues
  (jsc#SLE-8025).
- i40e: Log disable-fw-lldp flag change by ethtool (jsc#SLE-8025).
- i40e: fix incorrect ethtool statistics veb and veb.tc_
  (jsc#SLE-8025).
- fm10k: fix fm10k_get_fault_pf to read correct address
  (jsc#SLE-8009).
- fm10k: convert NON_Q_VECTORS(hw) into NON_Q_VECTORS
  (jsc#SLE-8009).
- fm10k: mark unused parameters with __always_unused
  (jsc#SLE-8009).
- fm10k: cast page_addr to u8 * when incrementing it
  (jsc#SLE-8009).
- fm10k: explicitly return 0 on success path in function
  (jsc#SLE-8009).
- fm10k: remove needless initialization of size local variable
  (jsc#SLE-8009).
- fm10k: remove needless assignment of err local variable
  (jsc#SLE-8009).
- fm10k: remove unnecessary variable initializer (jsc#SLE-8009).
- fm10k: reduce scope of the ring variable (jsc#SLE-8009).
- fm10k: reduce the scope of the result local variable
  (jsc#SLE-8009).
- fm10k: reduce the scope of the local msg variable
  (jsc#SLE-8009).
- fm10k: reduce the scope of the local i variable (jsc#SLE-8009).
- fm10k: reduce the scope of the err variable (jsc#SLE-8009).
- fm10k: reduce the scope of the tx_buffer variable
  (jsc#SLE-8009).
- fm10k: reduce the scope of the q_idx local variable
  (jsc#SLE-8009).
- fm10k: reduce the scope of local err variable (jsc#SLE-8009).
- fm10k: reduce the scope of qv local variable (jsc#SLE-8009).
- fm10k: reduce scope of *p local variable (jsc#SLE-8009).
- fm10k: reduce scope of the err variable (jsc#SLE-8009).
- ice: Bump version number (jsc#SLE-7926).
- ice: Remove flag to track VF interrupt status (jsc#SLE-7926).
- ice: Remove unnecessary flag ICE_FLAG_MSIX_ENA (jsc#SLE-7926).
- ice: Don't return error for disabling LAN Tx queue that does
  exist (jsc#SLE-7926).
- ice: Remove duplicate code in ice_alloc_rx_bufs (jsc#SLE-7926).
- ice: Add stats for Rx drops at the port level (jsc#SLE-7926).
- ice: Update number of VF queue before setting VSI resources
  (jsc#SLE-7926).
- ice: Set up Tx scheduling tree based on alloc VSI Tx queues
  (jsc#SLE-7926).
- ice: Only bump Rx tail and release buffers once per napi_poll
  (jsc#SLE-7926).
- ice: Disable VFs until reset is completed (jsc#SLE-7926).
- ice: Do not configure port with no media (jsc#SLE-7926).
- ice: separate out control queue lock creation (jsc#SLE-7926).
- ice: Always set prefena when configuring an Rx queue
  (jsc#SLE-7926).
- ice: Move vector base setup to PF VSI (jsc#SLE-7926).
- ice: track hardware stat registers past rollover (jsc#SLE-7926).
- ice: add lp_advertising flow control support (jsc#SLE-7926).
- net: Use skb_frag_off accessors (jsc#SLE-7979 jsc#SLE-7981).
- linux: Add skb_frag_t page_offset accessors (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Add PCI IDs for 57500 series NPAR devices (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Support all variants of the 5750X chip family
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor bnxt_init_one() and turn on TPA support on
  57500 chips (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Support TPA counters on 57500 chips (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Allocate the larger per-ring statistics block for
  57500 chips (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor ethtool ring statistics logic (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Add hardware GRO setup function for 57500 chips
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add TPA ID mapping logic for 57500 chips (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Add fast path logic for TPA on 57500 chips
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Set TPA GRO mode flags on 57500 chips properly
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor tunneled hardware GRO logic (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Handle standalone RX_AGG completions (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Expand bnxt_tpa_info struct to support 57500 chips
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor TPA logic (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add TPA structure definitions for BCM57500 chips
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Update firmware interface spec. to 1.10.0.89
  (jsc#SLE-8371 bsc#1153274).
- igc: Add more SKUs for i225 device (jsc#SLE-7966).
- igc: Update the MAC reset flow (jsc#SLE-7966).
- igc: Remove the unused field from a device specification
  structure (jsc#SLE-7966).
- igc: Remove the polarity field from a PHY information structure
  (jsc#SLE-7966).
- net/ixgbevf: fix a compilation error of skb_frag_t (jsc#SLE-7979
  jsc#SLE-7981).
- Build fixes for skb_frag_size conversion (jsc#SLE-7979
  jsc#SLE-7981).
- igb: Use dev_get_drvdata where possible (jsc#SLE-7967).
- i40e: Use dev_get_drvdata (jsc#SLE-8025).
- fm10k: Use dev_get_drvdata (jsc#SLE-8009).
- e1000e: Use dev_get_drvdata where possible (jsc#SLE-8100).
- net: broadcom: Use dev_get_drvdata (jsc#SLE-8371 bsc#1153274).
- net: Convert skb_frag_t to bio_vec (jsc#SLE-7979 jsc#SLE-7981).
- net: Rename skb_frag_t size to bv_len (jsc#SLE-7979
  jsc#SLE-7981).
- net: Rename skb_frag page to bv_page (jsc#SLE-7979
  jsc#SLE-7981).
- net: Reorder the contents of skb_frag_t (jsc#SLE-7979
  jsc#SLE-7981).
- net: Increase the size of skb_frag_t (jsc#SLE-7979
  jsc#SLE-7981).
- net: Use skb accessors in network core (jsc#SLE-7979
  jsc#SLE-7981).
- net: Use skb accessors in network drivers (jsc#SLE-8371
  bsc#1153274).
- commit b79d16a
* Wed Oct 16 2019 yousaf.kaukab@suse.com
- arm64: topology: Use PPTT to determine if PE is a thread
  (jsc#SLE-10146).
- ACPI/PPTT: Add support for ACPI 6.3 thread flag (jsc#SLE-10146).
- commit 72dbea4
* Wed Oct 16 2019 yousaf.kaukab@suse.com
- arm64: synquacer: enable spi driver
  References: jsc#SLE-9968
- commit 6756790
* Wed Oct 16 2019 jthumshirn@suse.de
- blk-wbt: fix performance regression in wbt scale_up/scale_down
  (bsc#1152489).
- commit 214a4b1
* Wed Oct 16 2019 mkubecek@suse.cz
- Update patches.suse/supported-flag references (add bsc#974406).
- commit 6b909a8
* Wed Oct 16 2019 pmladek@suse.com
- tracing: Initialize iter->seq after zeroing in
  tracing_read_pipe() (bsc#1151508).
- commit b84a6ef
* Wed Oct 16 2019 jroedel@suse.de
- kvm: x86, powerpc: do not allow clearing largepages debugfs
  entry (bsc#1117665).
- commit 8126faf
* Wed Oct 16 2019 ykaukab@suse.de
- pinctrl: rockchip: Mark expected switch fall-through
  (bsc#1154208).
- commit 284f3c9
* Wed Oct 16 2019 lpechacek@suse.com
- Refresh patches.suse/supported-flag.
- Delete
  patches.suse/module-Inform-user-when-loading-externally-supported.patch.
  Squash module-Inform-user-when-loading-externally-supported.patch (bsc#974406)
  into supported-flag.
- commit 5be4f6e
* Wed Oct 16 2019 dwagner@suse.de
- scsi: lpfc: Make function lpfc_defer_pt2pt_acc static
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.4.0.1 (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: cleanup: remove unused fcp_txcmlpq_cnt (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Complete removal of FCoE T10 PI support on SLI-4
  adapters (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Update async event logging (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix list corruption detected in
  lpfc_put_sgl_per_hdwq (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix hdwq sgl locks and irq handling (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix spinlock_irq issues in lpfc_els_flush_cmd()
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix list corruption in lpfc_sli_get_iocbq
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix host hang at boot or slow boot (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix coverity errors on NULL pointer checks
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix NVMe ABTS in response to receiving an ABTS
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix discovery failures when target device
  connectivity bounces (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix GPF on scsi command completion (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix locking on mailbox command completion
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix device recovery errors after PLOGI failures
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix rpi release when deleting vport (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix NVME io abort failures causing hangs
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix miss of register read failure check
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix premature re-enabling of interrupts in
  lpfc_sli_host_down (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix pt2pt discovery on SLI3 HBAs (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix reset recovery paths that are not recovering
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Convert existing %%pf users to %%ps (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: fix 12.4.0.0 GPF at boot (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Remove bg debugfs buffers (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Resolve checker warning for lpfc_new_io_buf()
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.4.0.0 (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Merge per-protocol WQ/CQ pairs into single per-cpu
  pair (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Add NVMe sequence level error recovery support
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Support dynamic unbounded SGL lists on G7 hardware
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Add MDS driver loopback diagnostics support
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Add first and second level hardware revisions to
  sysfs reporting (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Migrate to %%px and %%pf in kernel print calls
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Add simple unlikely optimizations to reduce NVME
  latency (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix coverity warnings (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix nvme first burst module parameter description
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix BlockGuard enablement on FCoE adapters
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix reported physical link speed on a disabled
  trunked link (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix Max Frame Size value shown in fdmishow output
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix upcall to bsg done in non-success cases
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix sli4 adapter initialization with MSI
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix nvme sg_seg_cnt display if HBA does not support
  NVME (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix nvme target mode ABTSing a received ABTS
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix hang when downloading fw on port enabled for
  nvme (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix too many sg segments spamming in kernel log
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix crash due to port reset racing vs adapter
  error handling (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix deadlock on host_lock during cable pulls
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix error in remote port address change
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix driver nvme rescan logging (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix sg_seg_cnt for HBAs that don't support NVME
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix propagation of devloss_tmo setting to nvme
  transport (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix loss of remote port after devloss due to lack
  of RPIs (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix devices that don't return after devloss followed
  by rediscovery (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix null ptr oops updating lpfc_devloss_tmo via
  sysfs attribute (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix FLOGI handling across multiple link up/down
  conditions (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix oops when fewer hdwqs than cpus (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix irq raising in lpfc_sli_hba_down (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix Oops in nvme_register with target logout/login
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix issuing init_vpi mbox on SLI-3 card
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix ADISC reception terminating login state if a
  NVME target (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix discovery when target has no GID_FT information
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix port relogin failure due to GID_FT interaction
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix leak of ELS completions on adapter reset
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix failure to clear non-zero eq_delay after io
  rate reduction (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix crash on driver unload in wq free (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix ELS field alignments (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix PLOGI failure with high remoteport count
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Limit xri count for kdump environment (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: remove NULL check before some freeing functions
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: use spin_lock_irqsave in IRQ context (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: remove redundant code (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Remove unnecessary null check before kfree
  (jsc#SLE-8284 jsc#SLE-8654).
- commit d8bfc1f
* Wed Oct 16 2019 dwagner@suse.de
- series.conf: Update qla2xxx patches
  The qla2xxx patches have been added to jebj's queue.
- commit 1b97787
* Wed Oct 16 2019 mkubecek@suse.cz
- Fix Patch-mainline tags:
  patches.suse/0001-ACPI-property-Add-two-new-Thunderbolt-property-GUIDs.patch
  patches.suse/0001-thunderbolt-Add-support-for-Intel-Ice-Lake.patch
  patches.suse/0001-thunderbolt-Correct-path-indices-for-PCIe-tunnel.patch
  patches.suse/0001-thunderbolt-Do-not-fail-adding-switch-if-some-port-i.patch
  patches.suse/0001-thunderbolt-Expose-active-parts-of-NVM-even-if-upgra.patch
  patches.suse/0001-thunderbolt-Hide-switch-attributes-that-are-not-set.patch
  patches.suse/0001-thunderbolt-Move-NVM-upgrade-support-flag-to-struct-.patch
  patches.suse/0001-thunderbolt-Show-key-using-pE-not-pEp.patch
  patches.suse/0001-thunderbolt-Switch-to-use-device_property_count_uXX.patch
  patches.suse/0001-thunderbolt-Use-32-bit-writes-when-writing-ring-prod.patch
- commit 1318e50
* Wed Oct 16 2019 mkubecek@suse.cz
- config: refresh after dependency changes
- commit 4237191
* Wed Oct 16 2019 mkubecek@suse.cz
- series.conf: cleanup
  Update upstream references and resort:
  patches.suse/scsi-qla2xxx-Remove-WARN_ON_ONCE-in-qla2x00_status_c.patch
  Move unsortable
  patches.suse/scsi-qla2xxx-fix-wait-condition-in-loop.patch
  out of sorted section.
- commit 0133508
* Tue Oct 15 2019 dwagner@suse.de
- scsi: qedf: Add port_id getter (jsc#SLE-9711).
- scsi: qedf: Remove always false 'tmp_prio < 0' statement
  (jsc#SLE-9711).
- scsi: qedf: Update the version to 8.42.3.0 (jsc#SLE-9711).
- scsi: qedf: Fix race betwen fipvlan request and response path
  (jsc#SLE-9711).
- scsi: qedf: Use discovery list to traverse rports
  (jsc#SLE-9711).
- scsi: qedf: Decrease the LL2 MTU size to 2500 (jsc#SLE-9711).
- scsi: qedf: Check for module unloading bit before processing
  link update AEN (jsc#SLE-9711).
- scsi: qedf: Initiator fails to re-login to switch after link
  down (jsc#SLE-9711).
- scsi: qedf: Add debug information for unsolicited processing
  (jsc#SLE-9711).
- scsi: qedf: Add support for 20 Gbps speed (jsc#SLE-9711).
- scsi: qedf: Interpret supported caps value correctly
  (jsc#SLE-9711).
- scsi: qedf: Add shutdown callback handler (jsc#SLE-9711).
- scsi: qedf: Update module description string (jsc#SLE-9711).
- scsi: qedf: Fix crash during sg_reset (jsc#SLE-9711).
- scsi: qedf: Stop sending fipvlan request on unload
  (jsc#SLE-9711).
- scsi: qedf: Print message during bailout conditions
  (jsc#SLE-9711).
- commit 723fe3b
* Tue Oct 15 2019 bp@suse.de
- x86/cpu: Add Comet Lake to the Intel CPU models header
  (jsc#SLE-7946).
- commit e9d5845
* Tue Oct 15 2019 msuchanek@suse.de
- soundwire: depend on ACPI || OF (bsc#1148868).
- soundwire: depend on ACPI (bsc#1148868).
- commit 4ebb907
* Tue Oct 15 2019 nborisov@suse.com
- btrfs: Remove metadata_uuid patches
  They are already in upstream 5.0.
- Delete patches.suse/0001-btrfs-Introduce-support-for-FSID-change-without-meta.patch.
- Delete patches.suse/0002-btrfs-Remove-fsid-metadata_fsid-fields-from-btrfs_in.patch.
- Delete patches.suse/0003-btrfs-Add-handling-for-disk-split-brain-scenario-dur.patch.
- Delete patches.suse/0004-btrfs-Introduce-2-more-members-to-struct-btrfs_fs_de.patch.
- Delete patches.suse/0005-btrfs-Handle-one-more-split-brain-scenario-during-fs.patch.
- Delete patches.suse/0006-btrfs-Handle-final-split-brain-possibility-during-fs.patch.
- Delete patches.suse/btrfs-add-sysfs-support-for-metadata_uuid-feature.patch.
- commit 1a7c8f7
* Tue Oct 15 2019 jslaby@suse.cz
- Update
  patches.suse/sched-core-Fix-CPU-controller-for-RT_GROUP_SCHED.patch
  (bnc#1151927 5.3.4 bnc#1135646).
  Add a bnc reference.
- commit 05f45df
* Tue Oct 15 2019 ptesarik@suse.cz
- Delete patches.suse/0201-merge-tag-exynos-drm-fixes-for-v4-12.
- Delete
  patches.suse/0586-merge-branch-drm-next-4-13-into-drm-next.
- Delete
  patches.suse/0680-merge-tag-drm-for-v4-13-of-git-people-freedesktop-org-airlied-linux.
- Delete
  patches.suse/1312-merge-tag-drm-msm-next-2017-08-22-into-drm-next.
- Delete
  patches.suse/3619-merge-airlied-drm-next-into-drm-misc-next.
- Delete
  patches.suse/3625-merge-drm-misc-next-2017-11-30-into-drm-next.
- Delete
  patches.suse/3631-merge-tag-drm-intel-next-2017-11-17-1-into-drm-next.
- Delete
  patches.suse/4330-merge-drm-armada-devel-4-15-into-drm-next.
- Delete patches.suse/5994-backmerge-tag-v4-16-rc7-into-drm-next.
- Delete
  patches.suse/7627-merge-drm-upstream-drm-next-into-drm-misc-next.
- commit 1a3d42d
* Tue Oct 15 2019 vbabka@suse.cz
- Delete patches.suse/x86-mm-fix-fast-gup-paravirt.patch.
  (The problem was solved differently upstream between 4.12 and 5.3)
- commit 0329020
* Tue Oct 15 2019 yousaf.kaukab@suse.com
- arm64: cn99xx: enable patches for silicon revision Ax erratum
  References: PM-1408
  Systems with Ax silicon still in use.
- commit 012b115
* Tue Oct 15 2019 vbabka@suse.cz
- mm, page_owner: rename flag indicating that page is allocated
  (jsc#SLE-8959, bsc#1144653, VM Debug Functionality).
- commit 1a8c019
* Tue Oct 15 2019 vbabka@suse.cz
- mm, page_owner: decouple freeing stack trace from
  debug_pagealloc (jsc#SLE-8959, bsc#1144653, VM Debug Functionality).
- commit 0458b8c
* Tue Oct 15 2019 vbabka@suse.cz
- mm, page_owner: fix off-by-one error in
  __set_page_owner_handle() (jsc#SLE-8959, bsc#1144653, VM
  Debug Functionality).
- commit d9d2cb5
* Tue Oct 15 2019 vbabka@suse.cz
- mm, page_owner, debug_pagealloc: save and dump freeing stack
  trace (jsc#SLE-8959, bsc#1144653, VM Debug Functionality).
- commit 88a816e
* Tue Oct 15 2019 vbabka@suse.cz
- mm, page_owner: keep owner info when freeing the page (jsc#SLE-8959,
  bsc#1144653, VM Debug Functionality).
- commit 59689b6
* Tue Oct 15 2019 vbabka@suse.cz
- mm, page_owner: record page owner for each subpage (jsc#SLE-8959,
  bsc#1144653, VM Debug Functionality).
- commit 6920f27
* Tue Oct 15 2019 dwagner@suse.de
- qla2xxx: Enable T10-DIF with FC-NVMe enabled (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- commit f8cfc4e
* Tue Oct 15 2019 dwagner@suse.de
- scsi: qla2xxx: Fix wait condition in loop (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- commit 39bb1be
* Tue Oct 15 2019 dwagner@suse.de
- scsi: qla2xxx: Update driver version to 10.01.00.20-k
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Improve logging for scan thread (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Capture FW dump on MPI heartbeat stop event
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Check for MB timeout while capturing ISP27/28xx
  FW dump (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Set remove flag for all VP (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add error handling for PLOGI ELS passthrough
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Dual FCP-NVMe target port support (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: remove redundant assignment to pointer host
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove WARN_ON_ONCE in
  qla2x00_status_cont_entry() (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Fix Nport ID display value (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix N2N link up fail (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Fix N2N link reset (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Optimize NPIV tear down process (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix stale mem access on driver unload
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix unbound sleep in fcport delete path
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Silence fwdump template message (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Update driver version to 10.01.00.19-k
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix stale session (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Fix stuck login session (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix driver reload for ISP82xx (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix flash read for Qlogic ISPs (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix message indicating vectors used by driver
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: fix spelling mistake "initializatin" ->
  "initialization" (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix a recently introduced kernel warning
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: cleanup trace buffer initialization (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: qla2x00_alloc_fw_dump: set ha->eft (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix a NULL pointer dereference (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Simplify qla24xx_async_abort_cmd() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove two superfluous if-tests (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Introduce qla2x00_els_dcmd2_free() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Inline the qla2x00_fcport_event_handler()
  function (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Report invalid mailbox status codes (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove superfluous sts_entry_* casts
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Let the compiler check the type of the
  SCSI command context pointer (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Complain if sp->done() is not called from the
  completion path (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Make sure that aborted commands are freed
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Introduce qla2xxx_get_next_handle() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Modify NVMe include directives (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Make qlt_handle_abts_completion() more robust
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix a race condition between aborting and
  completing a SCSI command (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Introduce the function qla2xxx_init_sp()
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Enable type checking for the SRB free and done
  callback functions (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Rework key encoding in qlt_find_host_by_d_id()
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Set the responder mode if appropriate for ELS
  pass-through IOCBs (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Make it explicit that ELS pass-through IOCBs
  use little endian (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Check secondary image if reading the primary
  image fails (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Change the return type of
  qla24xx_read_flash_data() (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Introduce the be_id_t and le_id_t data types
  for FC src/dst IDs (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Complain if a soft reset fails (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use memcpy() and strlcpy() instead of strcpy()
  and strncpy() (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Check the PCI info string output buffer size
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Complain if waiting for pending commands times
  out (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Declare fourth qla2x00_set_model_info() argument
  const (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Always check the qla2x00_wait_for_hba_online()
  return value (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Suppress multiple Coverity complaint
  about out-of-bounds accesses (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Suppress a Coveritiy complaint about integer
  overflow (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove unreachable code from qla83xx_idc_lock()
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix qla24xx_process_bidir_cmd() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Simplify a debug statement (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove dead code (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Complain if parsing the version string fails
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Complain if a mailbox command times out
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use strlcpy() instead of strncpy() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Do not corrupt vha->plogi_ack_list (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Report the firmware status code if a mailbox
  command fails (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix session lookup in qlt_abort_work()
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Simplify qla24xx_abort_sp_done() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove two superfluous tests (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove a superfluous pointer check (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Simplify qlt_lport_dump() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Reduce the number of casts in GID list code
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Verify locking assumptions at runtime
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Change data_dsd into an array (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Declare qla_tgt_cmd.cdb const (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Reduce the scope of three local variables
  in qla2xxx_queuecommand() (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Change the return type of
  qla2x00_update_ms_fdmi_iocb() into void (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Declare the fourth ql_dump_buffer() argument
  const (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove a superfluous forward declaration
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove an include directive from qla_mr.c
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Include the <asm/unaligned.h> header file from
  qla_dsd.h (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use tabs instead of spaces for indentation
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Improve Linux kernel coding style conformance
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Really fix qla2xxx_eh_abort() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Make qla2x00_abort_srb() again decrease the sp
  reference count (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- qla2xxx: remove SGI SN2 support (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- commit 2a36545
* Tue Oct 15 2019 oneukum@suse.com
- ACPI / property: Add two new Thunderbolt property GUIDs to
  the list (jsc#SLE-8714).
- commit 11dee44
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Add support for Intel Ice Lake (jsc#SLE-8714).
- commit 815b577
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Expose active parts of NVM even if upgrade is
  not supported (jsc#SLE-8714).
- commit badef1c
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Hide switch attributes that are not set
  (jsc#SLE-8714).
- commit 5b9d6f9
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Do not fail adding switch if some port is not
  implemented (jsc#SLE-8714).
- commit d0e61eb
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Use 32-bit writes when writing ring
  producer/consumer (jsc#SLE-8714).
- commit df92f6a
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Move NVM upgrade support flag to struct icm
  (jsc#SLE-8714).
- commit 476237e
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Correct path indices for PCIe tunnel
  (jsc#SLE-8714).
- commit 0d8a0ac
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Show key using %%*pE not %%*pEp (jsc#SLE-8714).
- commit 2388d46
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Switch to use device_property_count_uXX()
  (jsc#SLE-8714).
- commit 51e1030
* Tue Oct 15 2019 dwagner@suse.de
- scsi: qla2xxx: Refresh patches ported from SLE15-SP1
- Refresh
  patches.suse/scsi-qla2xxx-Allow-NVMe-IO-to-resume-with-short-cabl.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Correct-error-handling-during-initializ.patch.
- Refresh patches.suse/scsi-qla2xxx-Fix-DMA-unmap-leak.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Fix-NVMe-port-discovery-after-a-short-d.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Fix-abort-timeout-race-condition.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Fix-different-size-DMA-Alloc-Unmap.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Fix-hang-in-fcport-delete-path.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Fix-premature-timer-expiration.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Reject-EH_-abort-device_reset-target_re.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Remove-unnecessary-null-check.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Replace-vmalloc-memset-with-vzalloc.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Retry-fabric-Scan-on-IOCB-queue-full.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Skip-FW-dump-on-LOOP-initialization-err.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Update-driver-version-to-10.01.00.18-k.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Use-Correct-index-for-Q-Pair-array.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Use-common-update-firmware-options-rout.patch.
- commit 44af015
* Tue Oct 15 2019 jslaby@suse.cz
- Linux 5.3.6 (bnc#1151927 5.3.6).
- DTS: ARM: gta04: introduce legacy spi-cs-high to make display
  work again (bnc#1151927 5.3.6).
- mac80211: keep BHs disabled while calling drv_tx_wake_queue()
  (bnc#1151927 5.3.6).
- cfg80211: initialize on-stack chandefs (bnc#1151927 5.3.6).
- cfg80211: validate SSID/MBSSID element ordering assumption
  (bnc#1151927 5.3.6).
- nl80211: validate beacon head (bnc#1151927 5.3.6).
- ieee802154: atusb: fix use-after-free at disconnect (bnc#1151927
  5.3.6).
- KVM: s390: fix __insn32_query() inline assembly (bnc#1151927
  5.3.6).
- KVM: nVMX: Fix consistency check on injected exception error
  code (bnc#1151927 5.3.6).
- KVM: X86: Fix userspace set invalid CR4 (bnc#1151927 5.3.6).
- xen/xenbus: fix self-deadlock after killing user process
  (bnc#1151927 5.3.6).
- xen/balloon: Set pages PageOffline() in balloon_add_region()
  (bnc#1151927 5.3.6).
- selftests: pidfd: Fix undefined reference to pthread_create()
  (bnc#1151927 5.3.6).
- sched: Add __ASSEMBLY__ guards around struct clone_args
  (bnc#1151927 5.3.6).
- drm/omap: fix max fclk divider for omap36xx (bnc#1151927 5.3.6).
- drm/amd/powerplay: change metrics update period from 1ms to
  100ms (bnc#1151927 5.3.6).
- Revert "s390/dasd: Add discard support for ESE volumes"
  (bnc#1151927 5.3.6).
- s390/dasd: Fix error handling during online processing
  (bnc#1151927 5.3.6).
- vfs: Fix EOVERFLOW testing in put_compat_statfs64 (bnc#1151927
  5.3.6).
- tick: broadcast-hrtimer: Fix a race in bc_set_next (bnc#1151927
  5.3.6).
- Btrfs: fix selftests failure due to uninitialized i_mode in
  test inodes (bnc#1151927 5.3.6).
- mmc: tegra: Implement ->set_dma_mask() (bnc#1151927 5.3.6).
- mmc: sdhci: Let drivers define their DMA mask (bnc#1151927
  5.3.6).
- mmc: sdhci-of-esdhc: set DMA snooping based on DMA coherence
  (bnc#1151927 5.3.6).
- mmc: sdhci: improve ADMA error reporting (bnc#1151927 5.3.6).
- libnvdimm: prevent nvdimm from requesting key when security
  is disabled (bnc#1151927 5.3.6).
- libnvdimm/region: Initialize bad block for volatile namespaces
  (bnc#1151927 5.3.6).
- libnvdimm/nfit_test: Fix acpi_handle redefinition (bnc#1151927
  5.3.6).
- =?UTF-8?q?libnvdimm:=20Fix=20endian=20conversion=20issues=C2=A0?=
  (bnc#1151927 5.3.6).
- i2c: qcom-geni: Disable DMA processing on the Lenovo Yoga C630
  (bnc#1151927 5.3.6).
- iommu/amd: Fix downgrading default page-sizes in alloc_pte()
  (bnc#1151927 5.3.6).
- nfp: abm: fix memory leak in nfp_abm_u32_knode_replace
  (bnc#1151927 5.3.6).
- mlxsw: spectrum_flower: Fail in case user specifies multiple
  mirror actions (bnc#1151927 5.3.6).
- net: dsa: microchip: Always set regmap stride to 1 (bnc#1151927
  5.3.6).
- netfilter: nf_tables: allow lookups in dynamic sets (bnc#1151927
  5.3.6).
- bpf: Fix bpf_event_output re-entry issue (bnc#1151927 5.3.6).
- selftests/bpf: adjust strobemeta loop to satisfy latest clang
  (bnc#1151927 5.3.6).
- libbpf: fix false uninitialized variable warning (bnc#1151927
  5.3.6).
- powerpc/mm: Fix an Oops in kasan_mmu_init() (bnc#1151927 5.3.6).
- powerpc/mm: Add a helper to select PAGE_KERNEL_RO or
  PAGE_READONLY (bnc#1151927 5.3.6).
- x86/purgatory: Disable the stackleak GCC plugin for the
  purgatory (bnc#1151927 5.3.6).
- sched/core: Fix migration to invalid CPU in
  __set_cpus_allowed_ptr() (bnc#1151927 5.3.6).
- sched/membarrier: Call sync_core only before usermode for same
  mm (bnc#1151927 5.3.6).
- sched/membarrier: Fix private expedited registration check
  (bnc#1151927 5.3.6).
- ima: fix freeing ongoing ahash_request (bnc#1151927 5.3.6).
- ima: always return negative code for error (bnc#1151927 5.3.6).
- 9p: Transport error uninitialized (bnc#1151927 5.3.6).
- 9p: avoid attaching writeback_fid on mmap with type PRIVATE
  (bnc#1151927 5.3.6).
- riscv: Avoid interrupts being erroneously enabled in
  handle_exception() (bnc#1151927 5.3.6).
- Revert "locking/pvqspinlock: Don't wait if vCPU is preempted"
  (bnc#1151927 5.3.6).
- pwm: stm32-lp: Add check in case requested period cannot be
  achieved (bnc#1151927 5.3.6).
- blk-mq: move lockdep_assert_held() into elevator_exit
  (bnc#1151927 5.3.6).
- drivers: thermal: qcom: tsens: Fix memory leak from qfprom read
  (bnc#1151927 5.3.6).
- thermal: Fix use-after-free when unregistering thermal zone
  device (bnc#1151927 5.3.6).
- thermal_hwmon: Sanitize thermal_zone type (bnc#1151927 5.3.6).
- watchdog: aspeed: Add support for AST2600 (bnc#1151927 5.3.6).
- watchdog: imx2_wdt: fix min() calculation in
  imx2_wdt_set_timeout (bnc#1151927 5.3.6).
- drm/amdgpu: Check for valid number of registers to read
  (bnc#1151927 5.3.6).
- drm/radeon: Bail earlier when radeon.cik_/si_support=0 is passed
  (bnc#1151927 5.3.6).
- drm/atomic: Reject FLIP_ASYNC unconditionally (bnc#1151927
  5.3.6).
- drm/atomic: Take the atomic toys away from X (bnc#1151927
  5.3.6).
- ntb: point to right memory window index (bnc#1151927 5.3.6).
- timer: Read jiffies once when forwarding base clk (bnc#1151927
  5.3.6).
- perf unwind: Fix libunwind build failure on i386 systems
  (bnc#1151927 5.3.6).
- perf build: Add detection of java-11-openjdk-devel package
  (bnc#1151927 5.3.6).
- perf probe: Fix to clear tev->nargs in clear_probe_trace_event()
  (bnc#1151927 5.3.6).
- perf tools: Fix segfault in cpu_cache_level__read() (bnc#1151927
  5.3.6).
- perf stat: Fix a segmentation fault when using repeat forever
  (bnc#1151927 5.3.6).
- perf stat: Reset previous counts on repeat with interval
  (bnc#1151927 5.3.6).
- usercopy: Avoid HIGHMEM pfn warning (bnc#1151927 5.3.6).
- selftests/seccomp: fix build on older kernels (bnc#1151927
  5.3.6).
- pNFS: Ensure we do clear the return-on-close layout stateid
  on fatal errors (bnc#1151927 5.3.6).
- SUNRPC: Don't try to parse incomplete RPC messages (bnc#1151927
  5.3.6).
- SUNRPC: RPC level errors should always set task->tk_rpc_status
  (bnc#1151927 5.3.6).
- xprtrdma: Send Queue size grows after a reconnect (bnc#1151927
  5.3.6).
- xprtrdma: Toggle XPRT_CONGESTED in xprtrdma's slot methods
  (bnc#1151927 5.3.6).
- fs: nfs: Fix possible null-pointer dereferences in
  encode_attrs() (bnc#1151927 5.3.6).
- s390/cio: exclude subchannels with no parent from pseudo check
  (bnc#1151927 5.3.6).
- s390/cio: avoid calling strlen on null pointer (bnc#1151927
  5.3.6).
- s390/topology: avoid firing events before kobjs are created
  (bnc#1151927 5.3.6).
- xen/pci: reserve MCFG areas earlier (bnc#1151927 5.3.6).
- include/trace/events/writeback.h: fix -Wstringop-truncation
  warnings (bnc#1151927 5.3.6).
- kernel/elfcore.c: include proper prototypes (bnc#1151927 5.3.6).
- ceph: reconnect connection if session hang in opening state
  (bnc#1151927 5.3.6).
- ceph: fetch cap_gen under spinlock in ceph_add_cap (bnc#1151927
  5.3.6).
- ceph: fix directories inode i_blkbits initialization
  (bnc#1151927 5.3.6).
- fuse: fix memleak in cuse_channel_open (bnc#1151927 5.3.6).
- fuse: fix request limit (bnc#1151927 5.3.6).
- selftests/tpm2: Add the missing TEST_FILES assignment
  (bnc#1151927 5.3.6).
- power: supply: sbs-battery: only return health when battery
  present (bnc#1151927 5.3.6).
- power: supply: sbs-battery: use correct flags field (bnc#1151927
  5.3.6).
- MIPS: Treat Loongson Extensions as ASEs (bnc#1151927 5.3.6).
- powerpc/603: Fix handling of the DIRTY flag (bnc#1151927 5.3.6).
- powerpc/32s: Fix boot failure with DEBUG_PAGEALLOC without KASAN
  (bnc#1151927 5.3.6).
- powerpc/kasan: Fix shadow area set up for modules (bnc#1151927
  5.3.6).
- powerpc/kasan: Fix parallel loading of modules (bnc#1151927
  5.3.6).
- powerpc/ptdump: Fix addresses display on PPC32 (bnc#1151927
  5.3.6).
- tracing: Make sure variable reference alias has correct
  var_ref_idx (bnc#1151927 5.3.6).
- drm/nouveau/kms/nv50-: Don't create MSTMs for eDP connectors
  (bnc#1151927 5.3.6).
- drm/i915: to make vgpu ppgtt notificaiton as atomic operation
  (bnc#1151927 5.3.6).
- drm/i915/gvt: update vgpu workload head pointer correctly
  (bnc#1151927 5.3.6).
- can: mcp251x: mcp251x_hw_reset(): allow more time after a reset
  (bnc#1151927 5.3.6).
- crypto: cavium/zip - Add missing single_release() (bnc#1151927
  5.3.6).
- crypto: skcipher - Unmap pages after an external error
  (bnc#1151927 5.3.6).
- crypto: caam/qi - fix error handling in ERN handler (bnc#1151927
  5.3.6).
- crypto: caam - fix concurrency issue in givencrypt descriptor
  (bnc#1151927 5.3.6).
- crypto: ccree - use the full crypt length value (bnc#1151927
  5.3.6).
- crypto: qat - Silence smp_processor_id() warning (bnc#1151927
  5.3.6).
- crypto: ccree - account for TEE not ready to report (bnc#1151927
  5.3.6).
- coresight: etm4x: Use explicit barriers on enable/disable
  (bnc#1151927 5.3.6).
- staging: erofs: detect potential multiref due to corrupted
  images (bnc#1151927 5.3.6).
- staging: erofs: avoid endless loop of invalid lookback distance
  0 (bnc#1151927 5.3.6).
- staging: erofs: add two missing erofs_workgroup_put for
  corrupted images (bnc#1151927 5.3.6).
- staging: erofs: some compressed cluster should be submitted
  for corrupted images (bnc#1151927 5.3.6).
- staging: erofs: fix an error handling in erofs_readdir()
  (bnc#1151927 5.3.6).
- KVM: s390: Test for bad access register and size at the start
  of S390_MEM_OP (bnc#1151927 5.3.6).
- PM / devfreq: tegra: Fix kHz to Hz conversion (bnc#1151927
  5.3.6).
- ASoC: sgtl5000: Improve VAG power and mute control (bnc#1151927
  5.3.6).
- ASoC: Define a set of DAPM pre/post-up events (bnc#1151927
  5.3.6).
- nbd: fix max number of supported devs (bnc#1151927 5.3.6).
- s390/sclp: Fix bit checked for has_sipl (bnc#1151927 5.3.6).
- s390/process: avoid potential reading of freed stack
  (bnc#1151927 5.3.6).
- tools lib traceevent: Do not free tep->cmdlines in
  add_new_comm() on failure (bnc#1151927 5.3.6).
- tools lib traceevent: Fix "robust" test of
  do_generate_dynamic_list_file (bnc#1151927 5.3.6).
- commit 09e8239
* Tue Oct 15 2019 vbabka@suse.cz
- mm, compaction: fix wrong pfn handling in
  __reset_isolation_pfn() (git-fixes (mm/compaction)).
- commit b7593ee
* Tue Oct 15 2019 jslaby@suse.cz
- Update
  patches.suse/0001-drm-msm-dsi-Fix-return-value-check-for-clk_get_paren.patch
  (bsc#1152472 bnc#1151927 5.3.6).
- Update
  patches.suse/0002-drm-mali-dp-Mark-expected-switch-fall-through.patch
  (bsc#1152472 bnc#1151927 5.3.6).
- Update
  patches.suse/0003-drm-i915-dp-Fix-dsc-bpp-calculations-v5.patch
  (bsc#1152472 bnc#1151927 5.3.6).
- Update
  patches.suse/0004-drm-amdgpu-Fix-KFD-related-kernel-oops-on-Hawaii.patch
  (bsc#1152472 bnc#1151927 5.3.6).
- Update
  patches.suse/KVM-PPC-Book3S-Enable-XIVE-native-capability-only-if.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/KVM-PPC-Book3S-HV-Check-for-MMU-ready-on-piggybacked.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/KVM-PPC-Book3S-HV-Don-t-lose-pending-doorbell-reques.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/KVM-PPC-Book3S-HV-Don-t-push-XIVE-context-when-not-u.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/KVM-PPC-Book3S-HV-Fix-race-in-re-enabling-XIVE-escal.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/KVM-PPC-Book3S-HV-XIVE-Free-escalation-interrupts-be.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/PCI-Restore-Resizable-BAR-size-bits-correctly-for-1M.patch
  (bsc#1143841 bnc#1151927 5.3.6).
- Update
  patches.suse/PCI-vmd-Fix-config-addressing-when-using-bus-offsets.patch
  (git-fixes bnc#1151927 5.3.6).
- Update
  patches.suse/PCI-vmd-Fix-shadow-offsets-to-reflect-spec-changes.patch
  (git-fixes bnc#1151927 5.3.6).
- Update
  patches.suse/libnvdimm-altmap-track-namespace-boundaries-in-altmap.patch
  (bsc#1150305 bnc#1151927 5.3.6).
- Update
  patches.suse/msft-hv-1911-PCI-hv-Avoid-use-of-hv_pci_dev-pci_slot-after-freein.patch
  (bsc#1142701 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-book3s64-mm-Don-t-do-tlbie-fixup-for-some-ha.patch
  (bsc#1152161 ltc#181664 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-book3s64-radix-Rename-CPU_FTR_P9_TLBIE_BUG-f.patch
  (bsc#1152161 ltc#181664 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-mce-Fix-MCE-handling-for-huge-pages.patch
  (jsc#SLE-7730 jsc#SLE-8330 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-mce-Schedule-work-from-irq_work.patch
  (jsc#SLE-7730 jsc#SLE-8330 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-mm-Fixup-tlbie-vs-mtpidr-mtlpidr-ordering-is.patch
  (bsc#1152161 ltc#181664 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-powernv-Restrict-OPAL-symbol-map-to-only-be-.patch
  (bsc#1152885 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-powernv-ioda-Fix-race-in-TCE-level-allocatio.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-pseries-Fix-cpu_hotplug_lock-acquisition-in-.patch
  (bsc#1065729 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-xive-Implement-get_irqchip_state-method-for-.patch
  (bsc#1065729 bnc#1151927 5.3.6).
- commit e5cdb69
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: move local to extent inode logging into bmap helper
  (bsc#1153965).
- commit f0be3ee
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: remove broken error handling on failed attr sf to leaf
  change (bsc#1153964).
- commit 82cbfae
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: log the inode on directory sf to block format change
  (bsc#1153963).
- commit 09a957a
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: get allocation alignment from the buftarg (bsc#1153962).
- commit a48cb33
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: assure zeroed memory buffers for certain kmem allocations
  (bsc#1153957).
- commit 077c951
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: add kmem_alloc_io() (bsc#1153956).
- commit ef9a9c2
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: add kmem allocation trace points (bsc#1153955).
- commit 2ee9365
* Mon Oct 14 2019 ailiopoulos@suse.com
- fs: xfs: Remove KM_NOSLEEP and KM_SLEEP (bsc#1153954).
- commit 5c16078
* Mon Oct 14 2019 msuchanek@suse.de
- KVM: PPC: Book3S HV: use smp_mb() when setting/clearing host_ipi
  flag (bsc#1061840).
- commit 5c3f332
* Mon Oct 14 2019 msuchanek@suse.de
- net/ibmvnic: Fix EOI when running in XIVE mode (bsc#1089644,
  ltc#166495, ltc#165544, git-fixes).
- commit 7298d5a
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: Fix tail rounding in xfs_alloc_file_space() (bsc#1153917).
- commit 9a4ea01
* Mon Oct 14 2019 mkubecek@suse.cz
- series.conf: refresh sorted section
  Update upstream reference:
  patches.suse/powerpc-pseries-Remove-confusing-warning-message.patch
- commit dcc4e8b
* Sat Oct 12 2019 msuchanek@suse.de
- Refresh patches.suse/powerpc-papr_scm-Fix-an-off-by-one-check-in-papr_scm.patch
- commit 2e48c74
* Fri Oct 11 2019 msuchanek@suse.de
- powerpc/pseries: Remove confusing warning message (bsc#1109158).
- commit 1ec9a94
* Thu Oct 10 2019 mkubecek@suse.cz
- supported.conf: sort
  No functional change, fix order only.
- commit 624292b
* Wed Oct  9 2019 jack@suse.cz
- patches.suse/jbd2-flush_descriptor-Do-not-decrease-buffer-head-s-ref-count.patch:
  Update tags.
- commit 7a9890d
* Wed Oct  9 2019 yousaf.kaukab@suse.com
- arm64: enable Nvidia Jetson TX2
  References: SLE-9388
- commit 4c4ee96
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/amd/display: support "dummy pstate" (bsc#1152472)
- commit f26d6de
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/i915: Trust programmed MCR in read_subslice_reg (bsc#1152472)
- commit ceae560
* Wed Oct  9 2019 jslaby@suse.cz
- net: stmmac: Avoid deadlock on suspend/resume (git-fixes).
- commit 9c4865d
* Wed Oct  9 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: hide another #warning'
- commit 57d5b16
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/amdgpu: revert "disable bulk moves for now" (bsc#1152472)
- commit 0df34be
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/amd/display: Embed DCN2 SOC bounding box (bsc#1152472)
- commit 095c537
* Wed Oct  9 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Allow sharing the idle-barrier from other kernel requests'
- commit fdee26c
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/i915: Fix g4x sprite scaling stride check with GTT remapping (bsc#1152472)
- commit 2cb06d6
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/i915/dp: Fix dsc bpp calculations, v5. (bsc#1152472)
- commit def17f6
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/i915: Fix and improve MCR selection logic (bsc#1152472)
- commit f2d1229
* Wed Oct  9 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm: Fix kerneldoc warns in connector-related docs'
- commit a7d220e
* Wed Oct  9 2019 jslaby@suse.cz
- PCI: vmd: Fix shadow offsets to reflect spec changes
  (git-fixes).
- PCI: vmd: Fix config addressing when using bus offsets
  (git-fixes).
- commit d1eff9d
* Wed Oct  9 2019 jslaby@suse.cz
- Refresh
  patches.suse/PCI-Restore-Resizable-BAR-size-bits-correctly-for-1M.patch.
  Update upstream status and sort.
- commit 586dc90
* Wed Oct  9 2019 jslaby@suse.cz
- blacklist.conf: add 0df3e42167ca
- commit eb1317e
* Wed Oct  9 2019 mkubecek@suse.cz
- config: refresh configs
- commit 26e5ee3
* Wed Oct  9 2019 mkubecek@suse.cz
- Fix references (v5.4-rc2 -> v5.4-rc3)
  patches.suse/0001-kernel-sysctl.c-do-not-override-max_threads-provided.patch.
- Update references and move into sorted section
  patches.suse/PCI-mobiveil-Fix-the-CPU-base-address-setup-in-inbou.patch.
  patches.suse/scsi-qla2xxx-Fix-Relogin-to-prevent-modifying-scan_s.patch.
- commit 6fdd32d
* Tue Oct  8 2019 hare@suse.de
- config: enable CONFIG_PCIE_BW (jsc#SLE-9858)
- commit 4f573d4
* Tue Oct  8 2019 jslaby@suse.cz
- blacklist.conf: add a91bcc2b6537
- commit 4ff0ba8
* Tue Oct  8 2019 jslaby@suse.cz
- Linux 5.3.5 (bnc#1151927 5.3.5).
- net: qlogic: Fix memory leak in ql_alloc_large_buffers
  (bnc#1151927 5.3.5).
- nfc: fix memory leak in llcp_sock_bind() (bnc#1151927 5.3.5).
- sch_dsmark: fix potential NULL deref in dsmark_init()
  (bnc#1151927 5.3.5).
- ipv6: Handle missing host route in __ipv6_ifa_notify
  (bnc#1151927 5.3.5).
- net: ipv4: avoid mixed n_redirects and rate_tokens usage
  (bnc#1151927 5.3.5).
- cxgb4:Fix out-of-bounds MSI-X info array access (bnc#1151927
  5.3.5).
- rxrpc: Fix rxrpc_recvmsg tracepoint (bnc#1151927 5.3.5).
- qmi_wwan: add support for Cinterion CLS8 devices (bnc#1151927
  5.3.5).
- udp: only do GSO if # of segs > 1 (bnc#1151927 5.3.5).
- udp: fix gso_segs calculations (bnc#1151927 5.3.5).
- ipv6: drop incoming packets having a v4mapped source address
  (bnc#1151927 5.3.5).
- ptp_qoriq: Initialize the registers' spinlock before calling
  ptp_qoriq_settime (bnc#1151927 5.3.5).
- net: dsa: sja1105: Fix sleeping while atomic in
  .port_hwtstamp_set (bnc#1151927 5.3.5).
- net: dsa: sja1105: Initialize the meta_lock (bnc#1151927 5.3.5).
- net/rds: Fix error handling in rds_ib_add_one() (bnc#1151927
  5.3.5).
- net: dsa: rtl8366: Check VLAN ID and not ports (bnc#1151927
  5.3.5).
- tipc: fix unlimited bundling of small messages (bnc#1151927
  5.3.5).
- xen-netfront: do not use ~0U as error return value for
  xennet_fill_frags() (bnc#1151927 5.3.5).
- tcp: adjust rto_base in retransmits_timed_out() (bnc#1151927
  5.3.5).
- vsock: Fix a lockdep warning in __vsock_release() (bnc#1151927
  5.3.5).
- hso: fix NULL-deref on tty open (bnc#1151927 5.3.5).
- net: sched: cbs: Avoid division by zero when calculating the
  port rate (bnc#1151927 5.3.5).
- net: sched: taprio: Avoid division by zero on invalid link speed
  (bnc#1151927 5.3.5).
- net: socionext: netsec: always grab descriptor lock (bnc#1151927
  5.3.5).
- net: sched: taprio: Fix potential integer overflow in
  taprio_set_picos_per_byte (bnc#1151927 5.3.5).
- net: dsa: sja1105: Prevent leaking memory (bnc#1151927 5.3.5).
- net: dsa: sja1105: Ensure PTP time for rxtstamp reconstruction
  is not in the past (bnc#1151927 5.3.5).
- net: Unpublish sk from sk_reuseport_cb before call_rcu
  (bnc#1151927 5.3.5).
- erspan: remove the incorrect mtu limit for erspan (bnc#1151927
  5.3.5).
- sch_cbq: validate TCA_CBQ_WRROPT to avoid crash (bnc#1151927
  5.3.5).
- 9p/cache.c: Fix memory leak in v9fs_cache_session_get_cookie
  (bnc#1151927 5.3.5).
- kexec: bail out upon SIGKILL when allocating memory (bnc#1151927
  5.3.5).
- i2c: tegra: Move suspend handling to NOIRQ phase (bnc#1151927
  5.3.5).
- i2c-cht-wc: Fix lockdep warning (bnc#1151927 5.3.5).
- pktcdvd: remove warning on attempting to register
  non-passthrough dev (bnc#1151927 5.3.5).
- block, bfq: push up injection only after setting service time
  (bnc#1151927 5.3.5).
- mips: properly account for stack randomization and stack guard
  gap (bnc#1151927 5.3.5).
- arm: use STACK_TOP when computing mmap base address (bnc#1151927
  5.3.5).
- arm: properly account for stack randomization and stack guard
  gap (bnc#1151927 5.3.5).
- arm64: consider stack randomization for mmap base only when
  necessary (bnc#1151927 5.3.5).
- kmemleak: increase DEBUG_KMEMLEAK_EARLY_LOG_SIZE default to 16K
  (bnc#1151927 5.3.5).
- ocfs2: wait for recovering done after direct unlock request
  (bnc#1151927 5.3.5).
- kbuild: clean compressed initramfs image (bnc#1151927 5.3.5).
- mm: add dummy can_do_mlock() helper (bnc#1151927 5.3.5).
- fat: work around race with userspace's read via blockdev while
  mounting (bnc#1151927 5.3.5).
- tools/power/x86/intel-speed-select: Fix high priority core
  mask over count (bnc#1151927 5.3.5).
- hypfs: Fix error number left in struct pointer member
  (bnc#1151927 5.3.5).
- mfd: intel-lpss: Remove D3cold delay (bnc#1151927 5.3.5).
- PCI: tegra: Fix OF node reference leak (bnc#1151927 5.3.5).
- PCI: histb: Propagate errors for optional regulators
  (bnc#1151927 5.3.5).
- PCI: imx6: Propagate errors for optional regulators (bnc#1151927
  5.3.5).
- PCI: exynos: Propagate errors for optional PHYs (bnc#1151927
  5.3.5).
- PCI: rockchip: Propagate errors for optional regulators
  (bnc#1151927 5.3.5).
- PCI: layerscape: Add the bar_fixed_64bit property to the
  endpoint driver (bnc#1151927 5.3.5).
- PCI: pci-hyperv: Fix build errors on non-SYSFS config
  (bnc#1151927 5.3.5).
- PCI: Use static const struct, not const static struct
  (bnc#1151927 5.3.5).
- PCI: Add pci_info_ratelimited() to ratelimit PCI separately
  (bnc#1151927 5.3.5).
- smack: use GFP_NOFS while holding inode_smack::smk_lock
  (bnc#1151927 5.3.5).
- security: smack: Fix possible null-pointer dereferences in
  smack_socket_sock_rcv_skb() (bnc#1151927 5.3.5).
- Smack: Don't ignore other bprm->unsafe flags if
  LSM_UNSAFE_PTRACE is set (bnc#1151927 5.3.5).
- HID: wacom: Fix several minor compiler warnings (bnc#1151927
  5.3.5).
- HID: apple: Fix stuck function keys when using FN (bnc#1151927
  5.3.5).
- selinux: fix residual uses of current_security() for the
  SELinux blob (bnc#1151927 5.3.5).
- crypto: hisilicon - Fix double free in sec_free_hw_sgl()
  (bnc#1151927 5.3.5).
- power: supply: register HWMON devices with valid names
  (bnc#1151927 5.3.5).
- rtc: pcf85363/pcf85263: fix regmap error in set_time
  (bnc#1151927 5.3.5).
- rtc: snvs: fix possible race condition (bnc#1151927 5.3.5).
- rtc: bd70528: fix driver dependencies (bnc#1151927 5.3.5).
- soundwire: intel: fix channel number reported by hardware
  (bnc#1151927 5.3.5).
- ARM: 8905/1: Emit __gnu_mcount_nc when using Clang 10.0.0 or
  newer (bnc#1151927 5.3.5).
- ARM: 8903/1: ensure that usable memory in bank 0 starts from
  a PMD-aligned address (bnc#1151927 5.3.5).
- ARM: 8898/1: mm: Don't treat faults reported from cache
  maintenance as writes (bnc#1151927 5.3.5).
- ARM: 8875/1: Kconfig: default to AEABI w/ Clang (bnc#1151927
  5.3.5).
- mips/atomic: Fix smp_mb__{before,after}_atomic() (bnc#1151927
  5.3.5).
- mips/atomic: Fix loongson_llsc_mb() wreckage (bnc#1151927
  5.3.5).
- MIPS: tlbex: Explicitly cast _PAGE_NO_EXEC to a boolean
  (bnc#1151927 5.3.5).
- MIPS: Don't use bc_false uninitialized in __mm_isBranchInstr
  (bnc#1151927 5.3.5).
- MIPS: Ingenic: Disable broken BTB lookup optimization
  (bnc#1151927 5.3.5).
- f2fs: fix to drop meta/node pages during umount (bnc#1151927
  5.3.5).
- ext4: fix potential use after free after remounting with
  noblock_validity (bnc#1151927 5.3.5).
- scsi: core: Reduce memory required for SCSI logging (bnc#1151927
  5.3.5).
- dm raid: fix updating of max_discard_sectors limit (bnc#1151927
  5.3.5).
- dm zoned: fix invalid memory access (bnc#1151927 5.3.5).
- ARM: dts: dir685: Drop spi-cpol from the display (bnc#1151927
  5.3.5).
- clk: sprd: add missing kfree (bnc#1151927 5.3.5).
- clk: at91: select parent if main oscillator or bypass is enabled
  (bnc#1151927 5.3.5).
- clk: Make clk_bulk_get_all() return a valid "id" (bnc#1151927
  5.3.5).
- clk: renesas: cpg-mssr: Set GENPD_FLAG_ALWAYS_ON for clock
  domain (bnc#1151927 5.3.5).
- clk: renesas: mstp: Set GENPD_FLAG_ALWAYS_ON for clock domain
  (bnc#1151927 5.3.5).
- clk: sunxi-ng: v3s: add missing clock slices for MMC2 module
  clocks (bnc#1151927 5.3.5).
- clk: imx: clk-pll14xx: unbypass PLL by default (bnc#1151927
  5.3.5).
- clk: imx: pll14xx: avoid glitch when set rate (bnc#1151927
  5.3.5).
- clk: imx8mq: Mark AHB clock as critical (bnc#1151927 5.3.5).
- clk: sunxi: Don't call clk_hw_get_name() on a hw that isn't
  registered (bnc#1151927 5.3.5).
- clk: zx296718: Don't reference clk_init_data after registration
  (bnc#1151927 5.3.5).
- clk: sprd: Don't reference clk_init_data after registration
  (bnc#1151927 5.3.5).
- clk: sirf: Don't reference clk_init_data after registration
  (bnc#1151927 5.3.5).
- clk: meson: axg-audio: Don't reference clk_init_data after
  registration (bnc#1151927 5.3.5).
- clk: actions: Don't reference clk_init_data after registration
  (bnc#1151927 5.3.5).
- clk: ingenic/jz4740: Fix "pll half" divider not read/written
  properly (bnc#1151927 5.3.5).
- clk: qcom: gcc-sdm845: Use floor ops for sdcc clks (bnc#1151927
  5.3.5).
- clk: qoriq: Fix -Wunused-const-variable (bnc#1151927 5.3.5).
- vfio_pci: Restore original state on release (bnc#1151927 5.3.5).
- powerpc/eeh: Clean up EEH PEs after recovery finishes
  (bnc#1151927 5.3.5).
- selftests/powerpc: Retry on host facility unavailable
  (bnc#1151927 5.3.5).
- powerpc/eeh: Clear stale EEH_DEV_NO_HANDLER flag (bnc#1151927
  5.3.5).
- powerpc/perf: fix imc allocation failure handling (bnc#1151927
  5.3.5).
- powerpc/futex: Fix warning: 'oldval' may be used uninitialized
  in this function (bnc#1151927 5.3.5).
- powerpc/ptdump: fix walk_pagetables() address mismatch
  (bnc#1151927 5.3.5).
- PCI: rpaphp: Avoid a sometimes-uninitialized warning
  (bnc#1151927 5.3.5).
- arm64: fix unreachable code issue with cmpxchg (bnc#1151927
  5.3.5).
- kbuild: Do not enable -Wimplicit-fallthrough for clang for now
  (bnc#1151927 5.3.5).
- drm/amdgpu/si: fix ASIC tests (bnc#1151927 5.3.5).
- drm/amd/display: fix trigger not generated for freesync
  (bnc#1151927 5.3.5).
- drm/amd/display: support spdif (bnc#1151927 5.3.5).
- drm/amd/display: fix MPO HUBP underflow with Scatter Gather
  (bnc#1151927 5.3.5).
- drm/amd/powerpaly: fix navi series custom peak level value error
  (bnc#1151927 5.3.5).
- drm/amdgpu/sdma5: fix number of sdma5 trap irq types for navi1x
  (bnc#1151927 5.3.5).
- drm/amd/display: Register VUPDATE_NO_LOCK interrupts for DCN2
  (bnc#1151927 5.3.5).
- drm/amd/display: reprogram VM config when system resume
  (bnc#1151927 5.3.5).
- drm/amd/display: Fix frames_to_insert math (bnc#1151927 5.3.5).
- drm/amd/display: fix issue where 252-255 values are clipped
  (bnc#1151927 5.3.5).
- drm/nouveau/volt: Fix for some cards having 0 maximum voltage
  (bnc#1151927 5.3.5).
- drm/nouveau/kms/tu102-: disable input lut when input is already
  FP16 (bnc#1151927 5.3.5).
- dma-buf/sw_sync: Synchronize signal vs syncpt free (bnc#1151927
  5.3.5).
- gpu: drm: radeon: Fix a possible null-pointer dereference in
  radeon_connector_set_property() (bnc#1151927 5.3.5).
- drm/radeon: Fix EEH during kexec (bnc#1151927 5.3.5).
- drm/amdgpu: Fix hard hang for S/G display BOs (bnc#1151927
  5.3.5).
- drm/amd/display: Copy GSL groups when committing a new context
  (bnc#1151927 5.3.5).
- drm/amd/display: Clear FEC_READY shadow register if DPCD write
  fails (bnc#1151927 5.3.5).
- drm/amd/display: fix not calling ppsmu to trigger PME
  (bnc#1151927 5.3.5).
- drm/amd/display: Power-gate all DSCs at driver init time
  (bnc#1151927 5.3.5).
- drm/amd/display: add monitor patch to add T7 delay (bnc#1151927
  5.3.5).
- drm/rockchip: Check for fast link training before enabling psr
  (bnc#1151927 5.3.5).
- drm/panel: check failure cases in the probe func (bnc#1151927
  5.3.5).
- drm/stm: attach gem fence to atomic state (bnc#1151927 5.3.5).
- drm/tinydrm/Kconfig: drivers: Select BACKLIGHT_CLASS_DEVICE
  (bnc#1151927 5.3.5).
- drm/panel: simple: fix AUO g185han01 horizontal blanking
  (bnc#1151927 5.3.5).
- drm/vkms: Avoid assigning 0 for possible_crtc (bnc#1151927
  5.3.5).
- drm/bridge: tc358767: Increase AUX transfer length limit
  (bnc#1151927 5.3.5).
- drm/vkms: Fix crc worker races (bnc#1151927 5.3.5).
- drm/mcde: Fix uninitialized variable (bnc#1151927 5.3.5).
- pinctrl: meson-gxbb: Fix wrong pinning definition for uart_c
  (bnc#1151927 5.3.5).
- pinctrl: amd: disable spurious-firing GPIO IRQs (bnc#1151927
  5.3.5).
- pinctrl: tegra: Fix write barrier placement in pmx_writel
  (bnc#1151927 5.3.5).
- pinctrl: stmfx: update pinconf settings (bnc#1151927 5.3.5).
- ipmi_si: Only schedule continuously in the thread in maintenance
  mode (bnc#1151927 5.3.5).
- mbox: qcom: add APCS child device for QCS404 (bnc#1151927
  5.3.5).
- mailbox: mediatek: cmdq: clear the event in cmdq initial flow
  (bnc#1151927 5.3.5).
- pstore: fs superblock limits (bnc#1151927 5.3.5).
- vfs: set fs_context::user_ns for reconfigure (bnc#1151927
  5.3.5).
- NFC: fix attrs checks in netlink interface (bnc#1151927 5.3.5).
- commit 3f4d1b8
* Tue Oct  8 2019 jslaby@suse.cz
- Update
  patches.suse/0001-video-ssd1307fb-Start-page-range-at-page_offset.patch
  (bsc#1152472 bnc#1151927 5.3.5).
- Update
  patches.suse/0003-drm-amd-display-Use-proper-enum-conversion-functions.patch
  (bsc#1152472 bnc#1151927 5.3.5).
- Update
  patches.suse/0005-drm-bridge-sii902x-fix-missing-reference-to-mclk-clo.patch
  (bsc#1152472 bnc#1151927 5.3.5).
- Update
  patches.suse/PCI-mobiveil-Fix-the-CPU-base-address-setup-in-inbou.patch
  (fate#326572 bnc#1151927 5.3.5).
- Update
  patches.suse/livepatch-nullify-obj-mod-in-klp_module_coming-s-error-path.patch
  (bsc#1071995 fate#323487 bnc#1151927 5.3.5).
- Update
  patches.suse/msft-hv-1950-KVM-hyperv-Fix-Direct-Synthetic-timers-assert-an-int.patch
  (fate#323887 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-64s-exception-machine-check-use-correct-cfar.patch
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-64s-radix-Fix-memory-hotplug-section-page-ta.patch
  (bsc#1065729 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-dump-kernel-log-before-carrying-out-fadump-o.patch
  (bsc#1149940 ltc#179958 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-powernv-ioda2-Allocate-TCE-table-levels-on-d.patch
  (bsc#1061840 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-pseries-correctly-track-irq-state-in-default.patch
  (bsc#1150727 ltc#178925 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-pseries-mobility-use-cond_resched-when-updat.patch
  (bsc#1153112 ltc#181778 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-rtas-use-device-model-APIs-and-serialization.patch
  (bsc#1144123 ltc#178840 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-xmon-Check-for-HV-mode-when-dumping-XIVE-inf.patch
  (bsc#1142019 bnc#1151927 5.3.5).
- commit 37e2aaf
* Tue Oct  8 2019 jslaby@suse.cz
- Update
  patches.suse/0001-btrfs-Fix-a-regression-which-we-can-t-convert-to-SIN.patch
  (bsc#1152973 bnc#1151927 5.3.4).
- Update
  patches.suse/0001-btrfs-qgroup-Fix-the-wrong-target-io_tree-when-freei.patch
  (bsc#1152974 bnc#1151927 5.3.4).
- Update
  patches.suse/0001-ipmi-move-message-error-checking-to-avoid-deadlock.patch
  (bsc#1152489 bnc#1151927 5.3.4).
- Update
  patches.suse/0002-btrfs-qgroup-Fix-reserved-data-space-leak-if-we-have.patch
  (bsc#1152975 bnc#1151927 5.3.4).
- Update
  patches.suse/0002-drm-fix-module-name-in-edid_firmware-log-message.patch
  (bsc#1152472 bnc#1151927 5.3.4).
- Update
  patches.suse/alarmtimer-Use-EOPNOTSUPP-instead-of-ENOTSUPP.patch
  (bsc#1151680 bnc#1151927 5.3.4).
- Update
  patches.suse/edac-amd64-decode-syndrome-before-translating-address.patch
  (bsc#1152489 bnc#1151927 5.3.4).
- Update
  patches.suse/edac-amd64-recognize-dram-device-type-ecc-capability.patch
  (bsc#1152489 bnc#1151927 5.3.4).
- Update
  patches.suse/hwmon-k10temp-Add-support-for-AMD-family-17h-model-7.patch
  (bsc#1153137 bnc#1151927 5.3.4).
- Update
  patches.suse/iommu-iova-avoid-false-sharing-on-fq_timer_on
  (bsc#1151675 bnc#1151927 5.3.4).
- Update
  patches.suse/iommu-vt-d-fix-wrong-analysis-whether-devices-share-the-same-bus
  (bsc#1151679 bnc#1151927 5.3.4).
- Update
  patches.suse/scsi-qla2xxx-Fix-Relogin-to-prevent-modifying-scan_s.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.4).
- Update
  patches.suse/scsi-scsi_dh_rdac-zero-cdb-in-send_mode_select.patch
  (bsc#1149313 bnc#1151927 5.3.4).
- Update
  patches.suse/tpm_tis_core-Set-TPM_CHIP_FLAG_IRQ-before-probing-fo.patch
  (bsc#1082555 bnc#1151927 5.3.4).
- Update
  patches.suse/x86-amd_nb-Add-PCI-device-IDs-for-family-17h-model-7.patch
  (bsc#1153137 bnc#1151927 5.3.4).
- commit 78212b5
* Tue Oct  8 2019 jslaby@suse.cz
- Linux 5.3.4 (bnc#1151927 5.3.4).
- Btrfs: fix race setting up and completing qgroup rescan workers
  (bnc#1151927 5.3.4).
- btrfs: adjust dirty_metadata_bytes after writeback failure of
  extent buffer (bnc#1151927 5.3.4).
- ARM: dts: am3517-evm: Fix missing video (bnc#1151927 5.3.4).
- ARM: dts: logicpd-torpedo-baseboard: Fix missing video
  (bnc#1151927 5.3.4).
- ARM: omap2plus_defconfig: Fix missing video (bnc#1151927 5.3.4).
- CIFS: Fix oplock handling for SMB 2.1+ protocols (bnc#1151927
  5.3.4).
- CIFS: fix max ea value size (bnc#1151927 5.3.4).
- smb3: fix leak in "open on server" perf counter (bnc#1151927
  5.3.4).
- i2c: riic: Clear NACK in tend isr (bnc#1151927 5.3.4).
- tcp: better handle TCP_USER_TIMEOUT in SYN_SENT state
  (bnc#1151927 5.3.4).
- tcp_bbr: fix quantization code to not raise cwnd if not probing
  bandwidth (bnc#1151927 5.3.4).
- net: phy: micrel: add Asym Pause workaround for KSZ9021
  (bnc#1151927 5.3.4).
- nfp: flower: fix memory leak in nfp_flower_spawn_vnic_reprs
  (bnc#1151927 5.3.4).
- nfp: flower: prevent memory leak in nfp_flower_spawn_phy_reprs
  (bnc#1151927 5.3.4).
- vrf: Do not attempt to create IPv6 mcast rule if IPv6 is
  disabled (bnc#1151927 5.3.4).
- net/rds: Check laddr_check before calling it (bnc#1151927
  5.3.4).
- iwlwifi: fw: don't send GEO_TX_POWER_LIMIT command to FW
  version 36 (bnc#1151927 5.3.4).
- mt76: mt7615: fix mt7615 firmware path definitions (bnc#1151927
  5.3.4).
- ipv6: do not free rt if FIB_LOOKUP_NOREF is set on suppress rule
  (bnc#1151927 5.3.4).
- openvswitch: change type of UPCALL_PID attribute to NLA_UNSPEC
  (bnc#1151927 5.3.4).
- net: stmmac: Fix page pool size (bnc#1151927 5.3.4).
- macsec: drop skb sk before calling gro_cells_receive
  (bnc#1151927 5.3.4).
- net/mlx5e: Fix matching on tunnel addresses type (bnc#1151927
  5.3.4).
- net/mlx5e: Fix traffic duplication in ethtool steering
  (bnc#1151927 5.3.4).
- net/mlx5: Add device ID of upcoming BlueField-2 (bnc#1151927
  5.3.4).
- net/sched: cbs: Fix not adding cbs instance to list (bnc#1151927
  5.3.4).
- ppp: Fix memory leak in ppp_write (bnc#1151927 5.3.4).
- skge: fix checksum byte order (bnc#1151927 5.3.4).
- arcnet: provide a buffer big enough to actually receive packets
  (bnc#1151927 5.3.4).
- nfc: enforce CAP_NET_RAW for raw sockets (bnc#1151927 5.3.4).
- ieee802154: enforce CAP_NET_RAW for raw sockets (bnc#1151927
  5.3.4).
- ax25: enforce CAP_NET_RAW for raw sockets (bnc#1151927 5.3.4).
- appletalk: enforce CAP_NET_RAW for raw sockets (bnc#1151927
  5.3.4).
- mISDN: enforce CAP_NET_RAW for raw sockets (bnc#1151927 5.3.4).
- net: sched: fix possible crash in tcf_action_destroy()
  (bnc#1151927 5.3.4).
- net_sched: add policy validation for action attributes
  (bnc#1151927 5.3.4).
- net_sched: add max len check for TCA_KIND (bnc#1151927 5.3.4).
- net: qrtr: Stop rx_worker before freeing node (bnc#1151927
  5.3.4).
- net/phy: fix DP83865 10 Mbps HDX loopback disable function
  (bnc#1151927 5.3.4).
- usbnet: ignore endpoints with invalid wMaxPacketSize
  (bnc#1151927 5.3.4).
- cdc_ncm: fix divide-by-zero caused by invalid wMaxPacketSize
  (bnc#1151927 5.3.4).
- ipv6: fix a typo in fib6_rule_lookup() (bnc#1151927 5.3.4).
- sch_netem: fix a divide by zero in tabledist() (bnc#1151927
  5.3.4).
- ipv4: Revert removal of rt_uses_gateway (bnc#1151927 5.3.4).
- selftests: Update fib_nexthop_multiprefix to handle missing
  ping6 (bnc#1151927 5.3.4).
- selftests: Update fib_tests to handle missing ping6 (bnc#1151927
  5.3.4).
- net/sched: act_sample: don't push mac header on ip6gre ingress
  (bnc#1151927 5.3.4).
- usbnet: sanity checking of packet sizes and device mtu
  (bnc#1151927 5.3.4).
- kvm: x86: Add "significant index" flag to a few CPUID leaves
  (bnc#1151927 5.3.4).
- KVM: x86/mmu: Use fast invalidate mechanism to zap MMIO sptes
  (bnc#1151927 5.3.4).
- block: fix null pointer dereference in blk_mq_rq_timed_out()
  (bnc#1151927 5.3.4).
- drm/amdgpu/display: fix 64 bit divide (bnc#1151927 5.3.4).
- drm/amd/display: Restore backlight brightness after system
  resume (bnc#1151927 5.3.4).
- drm/amd/display: Add missing HBM support and raise Vega20's uclk
  (bnc#1151927 5.3.4).
- drm/amd/display: dce11.x /dce12 update formula input
  (bnc#1151927 5.3.4).
- SUNRPC: Fix buffer handling of GSS MIC without slack
  (bnc#1151927 5.3.4).
- SUNRPC: Dequeue the request from the receive queue while we're
  re-encoding (bnc#1151927 5.3.4).
- binfmt_elf: Do not move brk for INTERP-less ET_EXEC (bnc#1151927
  5.3.4).
- lib/lzo/lzo1x_compress.c: fix alignment bug in lzo-rle
  (bnc#1151927 5.3.4).
- memcg, kmem: do not fail __GFP_NOFAIL charges (bnc#1151927
  5.3.4).
- fuse: fix beyond-end-of-page access in fuse_parse_cache()
  (bnc#1151927 5.3.4).
- fuse: fix missing unlock_page in fuse_writepage() (bnc#1151927
  5.3.4).
- fuse: fix deadlock with aio poll and fuse_iqueue::waitq.lock
  (bnc#1151927 5.3.4).
- tpm: Wrap the buffer from the caller to tpm_buf in tpm_send()
  (bnc#1151927 5.3.4).
- KEYS: trusted: correctly initialize digests and fix locking
  issue (bnc#1151927 5.3.4).
- ALSA: hda/realtek - PCI quirk for Medion E4254 (bnc#1151927
  5.3.4).
- memcg, oom: don't require __GFP_FS when invoking memcg OOM
  killer (bnc#1151927 5.3.4).
- mm/compaction.c: clear total_{migrate,free}_scanned before
  scanning a new zone (bnc#1151927 5.3.4).
- z3fold: fix memory leak in kmem cache (bnc#1151927 5.3.4).
- z3fold: fix retry mechanism in page reclaim (bnc#1151927 5.3.4).
- hwrng: core - don't wait on add_early_randomness() (bnc#1151927
  5.3.4).
- gfs2: clear buf_in_tr when ending a transaction in
  sweep_bh_for_rgrps (bnc#1151927 5.3.4).
- quota: fix wrong condition in is_quota_modification()
  (bnc#1151927 5.3.4).
- ext4: fix punch hole for inline_data file systems (bnc#1151927
  5.3.4).
- ext4: fix warning inside ext4_convert_unwritten_extents_endio
  (bnc#1151927 5.3.4).
- mtd: rawnand: stm32_fmc2: avoid warnings when building with
  W=1 option (bnc#1151927 5.3.4).
- RDMA: Fix double-free in srq creation error flow (bnc#1151927
  5.3.4).
- IB/mlx5: Free mpi in mp_slave mode (bnc#1151927 5.3.4).
- IB/hfi1: Define variables as unsigned long to fix KASAN warning
  (bnc#1151927 5.3.4).
- IB/hfi1: Do not update hcrc for a KDETH packet during fault
  injection (bnc#1151927 5.3.4).
- randstruct: Check member structs in is_pure_ops_struct()
  (bnc#1151927 5.3.4).
- printk: Do not lose last line in kmsg buffer dump (bnc#1151927
  5.3.4).
- ARM: samsung: Fix system restart on S3C6410 (bnc#1151927 5.3.4).
- powerpc/imc: Dont create debugfs files for cpu-less nodes
  (bnc#1151927 5.3.4).
- drm/amd/powerplay/smu7: enforce minimal VBITimeout (v2)
  (bnc#1151927 5.3.4).
- efifb: BGRT: Improve efifb_bgrt_sanity_check (bnc#1151927
  5.3.4).
- platform/chrome: cros_ec_rpmsg: Fix race with host command
  when probe failed (bnc#1151927 5.3.4).
- smb3: fix unmount hang in open_shroot (bnc#1151927 5.3.4).
- smb3: allow disabling requesting leases (bnc#1151927 5.3.4).
- xfs: Fix stale data exposure when readahead races with hole
  punch (bnc#1151927 5.3.4).
- fs: Export generic_fadvise() (bnc#1151927 5.3.4).
- mm: Handle MADV_WILLNEED through vfs_fadvise() (bnc#1151927
  5.3.4).
- ovl: filter of trusted xattr results in audit (bnc#1151927
  5.3.4).
- ovl: Fix dereferencing possible ERR_PTR() (bnc#1151927 5.3.4).
- btrfs: Relinquish CPUs in btrfs_compare_trees (bnc#1151927
  5.3.4).
- btrfs: fix allocation of free space cache v1 bitmap pages
  (bnc#1151927 5.3.4).
- btrfs: Detect unbalanced tree with empty leaf before crashing
  btree operations (bnc#1151927 5.3.4).
- Btrfs: fix use-after-free when using the tree modification log
  (bnc#1151927 5.3.4).
- btrfs: tree-checker: Add ROOT_ITEM check (bnc#1151927 5.3.4).
- btrfs: extent-tree: Make sure we only allocate extents from
  block groups with the same type (bnc#1151927 5.3.4).
- btrfs: delayed-inode: Kill the BUG_ON() in
  btrfs_delete_delayed_dir_index() (bnc#1151927 5.3.4).
- ath10k: fix channel info parsing for non tlv target (bnc#1151927
  5.3.4).
- i40e: check __I40E_VF_DISABLE bit in i40e_sync_filters_subtask
  (bnc#1151927 5.3.4).
- cfg80211: Purge frame registrations on iftype change
  (bnc#1151927 5.3.4).
- mt76: mt7615: always release sem in mt7615_load_patch
  (bnc#1151927 5.3.4).
- mt76: round up length on mt76_wr_copy (bnc#1151927 5.3.4).
- zd1211rw: remove false assertion from zd_mac_clear()
  (bnc#1151927 5.3.4).
- rtw88: pci: Use DMA sync instead of remapping in RX ISR
  (bnc#1151927 5.3.4).
- rtw88: pci: Rearrange the memory usage for skb in RX ISR
  (bnc#1151927 5.3.4).
- libertas: Add missing sentinel at end of if_usb.c fw_table
  (bnc#1151927 5.3.4).
- e1000e: add workaround for possible stalled packet (bnc#1151927
  5.3.4).
- /dev/mem: Bail out upon SIGKILL (bnc#1151927 5.3.4).
- staging: erofs: cannot set EROFS_V_Z_INITED_BIT if
  fill_inode_lazy fails (bnc#1151927 5.3.4).
- kvm: Nested KVM MMUs need PAE root too (bnc#1151927 5.3.4).
- KVM: x86: set ctxt->have_exception in x86_decode_insn()
  (bnc#1151927 5.3.4).
- KVM: x86: always stop emulation on page fault (bnc#1151927
  5.3.4).
- KVM: x86: Manually calculate reserved bits when loading PDPTRS
  (bnc#1151927 5.3.4).
- KVM: x86: Disable posted interrupts for non-standard IRQs
  delivery modes (bnc#1151927 5.3.4).
- ACPI / LPSS: Save/restore LPSS private registers also on
  Lynxpoint (bnc#1151927 5.3.4).
- ACPI / PCI: fix acpi_pci_irq_enable() memory leak (bnc#1151927
  5.3.4).
- ACPI: custom_method: fix memory leaks (bnc#1151927 5.3.4).
- ACPI / processor: don't print errors for processorIDs == 0xff
  (bnc#1151927 5.3.4).
- ACPI / APEI: Release resources if gen_pool_add() fails
  (bnc#1151927 5.3.4).
- ACPI / CPPC: do not require the _PSD method (bnc#1151927 5.3.4).
- PM / devfreq: passive: fix compiler warning (bnc#1151927 5.3.4).
- PM / devfreq: passive: Use non-devm notifiers (bnc#1151927
  5.3.4).
- PM / devfreq: exynos-bus: Correct clock enable sequence
  (bnc#1151927 5.3.4).
- PM / devfreq: Fix kernel oops on governor module load
  (bnc#1151927 5.3.4).
- cpufreq: imx-cpufreq-dt: Add i.MX8MN support (bnc#1151927
  5.3.4).
- cpufreq: ap806: Add NULL check after kcalloc (bnc#1151927
  5.3.4).
- sched/cpufreq: Align trace event behavior of fast switching
  (bnc#1151927 5.3.4).
- cpuidle: teo: Allow tick to be stopped if PM QoS is used
  (bnc#1151927 5.3.4).
- dmaengine: ti: edma: Do not reset reserved paRAM slots
  (bnc#1151927 5.3.4).
- dmaengine: bcm2835: Print error in case setting DMA mask fails
  (bnc#1151927 5.3.4).
- leds: lm3532: Fixes for the driver for stability (bnc#1151927
  5.3.4).
- led: triggers: Fix a memory leak bug (bnc#1151927 5.3.4).
- leds: leds-lp5562 allow firmware files up to the maximum length
  (bnc#1151927 5.3.4).
- media: videobuf-core.c: poll_wait needs a non-NULL buf pointer
  (bnc#1151927 5.3.4).
- media: ov9650: add a sanity check (bnc#1151927 5.3.4).
- media: aspeed-video: address a protential usage of an
  unitialized var (bnc#1151927 5.3.4).
- media: saa7134: fix terminology around
  saa7134_i2c_eeprom_md7134_gate() (bnc#1151927 5.3.4).
- media: sn9c20x: Add MSI MS-1039 laptop to flip_dmi_table
  (bnc#1151927 5.3.4).
- media: saa7146: add cleanup in hexium_attach() (bnc#1151927
  5.3.4).
- media: cpia2_usb: fix memory leaks (bnc#1151927 5.3.4).
- media: cec-notifier: clear cec_adap in cec_notifier_unregister
  (bnc#1151927 5.3.4).
- media: ttusb-dec: Fix info-leak in ttusb_dec_send_command()
  (bnc#1151927 5.3.4).
- media: dvb-core: fix a memory leak bug (bnc#1151927 5.3.4).
- media: mceusb: fix (eliminate) TX IR signal length limit
  (bnc#1151927 5.3.4).
- media: dvb-frontends: use ida for pll number (bnc#1151927
  5.3.4).
- media: gspca: zero usb_buf on error (bnc#1151927 5.3.4).
- media: hdpvr: add terminating 0 at end of string (bnc#1151927
  5.3.4).
- media: radio/si470x: kill urb on error (bnc#1151927 5.3.4).
- media: imx: mipi csi-2: Don't fail if initial state times-out
  (bnc#1151927 5.3.4).
- media: i2c: ov5645: Fix power sequence (bnc#1151927 5.3.4).
- media: omap3isp: Don't set streaming state on random subdevs
  (bnc#1151927 5.3.4).
- media: omap3isp: Set device on omap3isp subdevs (bnc#1151927
  5.3.4).
- media: vsp1: fix memory leak of dl on error return path
  (bnc#1151927 5.3.4).
- media: rc: imon: Allow iMON RC protocol for ffdc 7e device
  (bnc#1151927 5.3.4).
- media: em28xx: modules workqueue not inited for 2nd device
  (bnc#1151927 5.3.4).
- media: fdp1: Reduce FCP not found message level to debug
  (bnc#1151927 5.3.4).
- media: i2c: tda1997x: prevent potential NULL pointer access
  (bnc#1151927 5.3.4).
- media: mtk-mdp: fix reference count on old device tree
  (bnc#1151927 5.3.4).
- media: media/platform: fsl-viu.c: fix build for MICROBLAZE
  (bnc#1151927 5.3.4).
- media: staging: tegra-vde: Fix build error (bnc#1151927 5.3.4).
- media: iguanair: add sanity checks (bnc#1151927 5.3.4).
- media: don't drop front-end reference count for ->detach
  (bnc#1151927 5.3.4).
- media: hantro: Set DMA max segment size (bnc#1151927 5.3.4).
- media: i2c: ov5640: Check for devm_gpiod_get_optional() error
  (bnc#1151927 5.3.4).
- media: vivid: fix device init when no_error_inj=1 and fb
  disabled (bnc#1151927 5.3.4).
- media: hdpvr: Add device num check and handling (bnc#1151927
  5.3.4).
- media: exynos4-is: fix leaked of_node references (bnc#1151927
  5.3.4).
- media: vivid: work around high stack usage with clang
  (bnc#1151927 5.3.4).
- media: vivid:add sanity check to avoid divide error and set
  value to 1 if 0 (bnc#1151927 5.3.4).
- media: vb2: reorder checks in vb2_poll() (bnc#1151927 5.3.4).
- media: dib0700: fix link error for dibx000_i2c_set_speed
  (bnc#1151927 5.3.4).
- media: mtk-cir: lower de-glitch counter for rc-mm protocol
  (bnc#1151927 5.3.4).
- ASoC: dt-bindings: sun4i-spdif: Fix dma-names warning
  (bnc#1151927 5.3.4).
- ASoC: Intel: Haswell: Adjust machine device private context
  (bnc#1151927 5.3.4).
- ASoC: sun4i-i2s: Don't use the oversample to calculate BCLK
  (bnc#1151927 5.3.4).
- ASoC: SOF: reset DMA state in prepare (bnc#1151927 5.3.4).
- ASoC: SOF: pci: mark last_busy value at runtime PM init
  (bnc#1151927 5.3.4).
- ASoC: sgtl5000: Fix charge pump source assignment (bnc#1151927
  5.3.4).
- ASoC: sgtl5000: Fix of unmute outputs on probe (bnc#1151927
  5.3.4).
- ASoC: tlv320aic31xx: suppress error message for EPROBE_DEFER
  (bnc#1151927 5.3.4).
- ASoC: SOF: Intel: hda: Make hdac_device device-managed
  (bnc#1151927 5.3.4).
- ASoC: dmaengine: Make the pcm->name equal to pcm->id if the
  name is not set (bnc#1151927 5.3.4).
- ASoC: fsl_ssi: Fix clock control issue in master mode
  (bnc#1151927 5.3.4).
- ASoC: es8316: fix headphone mixer volume table (bnc#1151927
  5.3.4).
- ASoC: Intel: NHLT: Fix debug print format (bnc#1151927 5.3.4).
- ASoC: Intel: Fix use of potentially uninitialized variable
  (bnc#1151927 5.3.4).
- ASoC: Intel: Skylake: Use correct function to access iomem space
  (bnc#1151927 5.3.4).
- ASoC: mchp-i2s-mcc: Wait for RX/TX RDY only if controller is
  running (bnc#1151927 5.3.4).
- ASoC: mchp-i2s-mcc: Fix unprepare of GCLK (bnc#1151927 5.3.4).
- ASoC: uniphier: Fix double reset assersion when transitioning
  to suspend state (bnc#1151927 5.3.4).
- ASoC: hdac_hda: fix page fault issue by removing race
  (bnc#1151927 5.3.4).
- ASoC: rsnd: don't call clk_get_rate() under atomic context
  (bnc#1151927 5.3.4).
- ALSA: firewire-motu: add support for MOTU 4pre (bnc#1151927
  5.3.4).
- ALSA: hda/realtek - Blacklist PC beep for Lenovo ThinkCentre
  M73/93 (bnc#1151927 5.3.4).
- ALSA: hda - Drop unsol event handler for Intel HDMI codecs
  (bnc#1151927 5.3.4).
- ALSA: hda - Add a quirk model for fixing Huawei Matebook X
  right speaker (bnc#1151927 5.3.4).
- ALSA: usb-audio: Skip bSynchAddress endpoint check if it is
  invalid (bnc#1151927 5.3.4).
- ALSA: i2c: ak4xxx-adda: Fix a possible null pointer dereference
  in build_adc_controls() (bnc#1151927 5.3.4).
- ALSA: hda - Show the fatal CORB/RIRB error more clearly
  (bnc#1151927 5.3.4).
- ALSA: hda/hdmi - Don't report spurious jack state changes
  (bnc#1151927 5.3.4).
- ALSA: hda: Flush interrupts on disabling (bnc#1151927 5.3.4).
- ALSA: firewire-tascam: check intermediate state of clock status
  and retry (bnc#1151927 5.3.4).
- ALSA: firewire-tascam: handle error code when getting current
  source of clock (bnc#1151927 5.3.4).
- mmc: core: Clarify sdio_irq_pending flag for
  MMC_CAP2_SDIO_IRQ_NOTHREAD (bnc#1151927 5.3.4).
- mmc: mtk-sd: Re-store SDIO IRQs mask at system resume
  (bnc#1151927 5.3.4).
- mmc: dw_mmc: Re-store SDIO IRQs mask at system resume
  (bnc#1151927 5.3.4).
- mmc: core: Add helper function to indicate if SDIO IRQs is
  enabled (bnc#1151927 5.3.4).
- mmc: sdhci: Fix incorrect switch to HS mode (bnc#1151927 5.3.4).
- block: make rq sector size accessible for block stats
  (bnc#1151927 5.3.4).
- md/raid0: avoid RAID0 data corruption due to layout confusion
  (bnc#1151927 5.3.4).
- raid5: don't set STRIPE_HANDLE to stripe which is in batch list
  (bnc#1151927 5.3.4).
- raid5: don't increment read_errors on EILSEQ return (bnc#1151927
  5.3.4).
- md/raid1: fail run raid1 array when active disk less than one
  (bnc#1151927 5.3.4).
- closures: fix a race on wakeup from closure_sync (bnc#1151927
  5.3.4).
- block: mq-deadline: Fix queue restart handling (bnc#1151927
  5.3.4).
- nvme-multipath: fix ana log nsid lookup when nsid is not found
  (bnc#1151927 5.3.4).
- nvmet: fix data units read and written counters in SMART log
  (bnc#1151927 5.3.4).
- md: don't report active array_state until after
  revalidate_disk() completes (bnc#1151927 5.3.4).
- md: only call set_in_sync() when it is expected to succeed
  (bnc#1151927 5.3.4).
- nbd: add missing config put (bnc#1151927 5.3.4).
- blk-mq: Fix memory leak in blk_mq_init_allocated_queue error
  handling (bnc#1151927 5.3.4).
- loop: Add LOOP_SET_DIRECT_IO to compat ioctl (bnc#1151927
  5.3.4).
- md: don't call spare_active in md_reap_sync_thread if all
  member devices can't work (bnc#1151927 5.3.4).
- md: don't set In_sync if array is frozen (bnc#1151927 5.3.4).
- md/raid1: end bio when the device faulty (bnc#1151927 5.3.4).
- md/raid6: Set R5_ReadError when there is read failure on parity
  disk (bnc#1151927 5.3.4).
- scsi: implement .cleanup_rq callback (bnc#1151927 5.3.4).
- blk-mq: add callback of .cleanup_rq (bnc#1151927 5.3.4).
- libata/ahci: Drop PCS quirk for Denverton and beyond
  (bnc#1151927 5.3.4).
- io_uring: fix wrong sequence setting logic (bnc#1151927 5.3.4).
- s390/crypto: xts-aes-s390 fix extra run-time crypto self tests
  finding (bnc#1151927 5.3.4).
- s390/kasan: provide uninstrumented __strlen (bnc#1151927 5.3.4).
- posix-cpu-timers: Sanitize bogus WARNONS (bnc#1151927 5.3.4).
- x86/apic/vector: Warn when vector space exhaustion breaks
  affinity (bnc#1151927 5.3.4).
- x86/apic: Make apic_pending_intr_clear() more robust
  (bnc#1151927 5.3.4).
- x86/apic: Soft disable APIC before initializing it (bnc#1151927
  5.3.4).
- x86/reboot: Always use NMI fallback when shutdown via reboot
  vector IPI fails (bnc#1151927 5.3.4).
- irqchip/gic-v3-its: Fix LPI release for Multi-MSI devices
  (bnc#1151927 5.3.4).
- x86/mm/pti: Do not invoke PTI functions when PTI is disabled
  (bnc#1151927 5.3.4).
- x86/mm/pti: Handle unaligned address gracefully in
  pti_clone_pagetable() (bnc#1151927 5.3.4).
- tools/power/x86/intel-speed-select: Fix memory leak (bnc#1151927
  5.3.4).
- platform/x86: intel_int0002_vgpio: Fix wakeups not working on
  Cherry Trail (bnc#1151927 5.3.4).
- platform/x86: intel_pmc_core_pltdrv: Module removal warning fix
  (bnc#1151927 5.3.4).
- platform/x86: intel_pmc_core: Do not ioremap RAM (bnc#1151927
  5.3.4).
- x86/platform/intel/iosf_mbi Rewrite locking (bnc#1151927 5.3.4).
- x86/mm: Fix cpumask_of_node() error condition (bnc#1151927
  5.3.4).
- x86/cpu: Add Tiger Lake to Intel family (bnc#1151927 5.3.4).
- sched/psi: Correct overly pessimistic size calculation
  (bnc#1151927 5.3.4).
- sched/fair: Use rq_lock/unlock in online_fair_sched_group
  (bnc#1151927 5.3.4).
- rcu/tree: Fix SCHED_FIFO params (bnc#1151927 5.3.4).
- sched/core: Fix CPU controller for !RT_GROUP_SCHED (bnc#1151927
  5.3.4).
- rcu/tree: Call setschedule() gp ktread to SCHED_FIFO outside
  of atomic region (bnc#1151927 5.3.4).
- sched/deadline: Fix bandwidth accounting at all levels after
  offline migration (bnc#1151927 5.3.4).
- time/tick-broadcast: Fix tick_broadcast_offline() lockdep
  complaint (bnc#1151927 5.3.4).
- sched/fair: Fix imbalance due to CPU affinity (bnc#1151927
  5.3.4).
- kprobes: Prohibit probing on BUG() and WARN() address
  (bnc#1151927 5.3.4).
- libtraceevent: Change users plugin directory (bnc#1151927
  5.3.4).
- perf evlist: Use unshare(CLONE_FS) in sb threads to let
  setns(CLONE_NEWNS) work (bnc#1151927 5.3.4).
- perf script: Fix memory leaks in list_scripts() (bnc#1151927
  5.3.4).
- perf report: Fix --ns time sort key output (bnc#1151927 5.3.4).
- perf trace beauty ioctl: Fix off-by-one error in cmd->string
  table (bnc#1151927 5.3.4).
- libperf: Fix alignment trap with xyarray contents in 'perf stat'
  (bnc#1151927 5.3.4).
- tools headers: Fixup bitsperlong per arch includes (bnc#1151927
  5.3.4).
- perf unwind: Fix libunwind when tid != pid (bnc#1151927 5.3.4).
- perf record: Support aarch64 random socket_id assignment
  (bnc#1151927 5.3.4).
- perf tools: Fix paths in include statements (bnc#1151927 5.3.4).
- perf test vfs_getname: Disable ~/.perfconfig to get default
  output (bnc#1151927 5.3.4).
- perf config: Honour $PERF_CONFIG env var to specify alternate
  .perfconfig (bnc#1151927 5.3.4).
- efi: cper: print AER info of PCIe fatal error (bnc#1151927
  5.3.4).
- idle: Prevent late-arriving interrupts from disrupting offline
  (bnc#1151927 5.3.4).
- rcu: Add destroy_work_on_stack() to match INIT_WORK_ONSTACK()
  (bnc#1151927 5.3.4).
- arm64: dts: rockchip: limit clock rate of MMC controllers for
  RK3328 (bnc#1151927 5.3.4).
- ARM: dts: exynos: Mark LDO10 as always-on on Peach Pit/Pi
  Chromebooks (bnc#1151927 5.3.4).
- arm64: dts: qcom: qcs404-evb: Mark WCSS clocks protected
  (bnc#1151927 5.3.4).
- arm64: dts: meson: fix boards regulators states format
  (bnc#1151927 5.3.4).
- arm64: dts: imx8mq: Correct OPP table according to latest
  datasheet (bnc#1151927 5.3.4).
- ARM: dts: imx7-colibri: disable HS400 (bnc#1151927 5.3.4).
- ARM: dts: imx7d: cl-som-imx7: make ethernet work again
  (bnc#1151927 5.3.4).
- base: soc: Export soc_device_register/unregister APIs
  (bnc#1151927 5.3.4).
- firmware: qcom_scm: Use proper types for dma mappings
  (bnc#1151927 5.3.4).
- soc: amlogic: meson-clk-measure: protect measure with a mutex
  (bnc#1151927 5.3.4).
- soc: renesas: Enable ARM_ERRATA_754322 for affected Cortex-A9
  (bnc#1151927 5.3.4).
- soc: renesas: rmobile-sysc: Set GENPD_FLAG_ALWAYS_ON for
  always-on domain (bnc#1151927 5.3.4).
- firmware: arm_scmi: Check if platform has released shmem before
  using (bnc#1151927 5.3.4).
- ARM: zynq: Use memcpy_toio instead of memcpy on smp bring-up
  (bnc#1151927 5.3.4).
- ARM: OMAP2+: move platform-specific asm-offset.h to
  arch/arm/mach-omap2 (bnc#1151927 5.3.4).
- ARM: at91: move platform-specific asm-offset.h to
  arch/arm/mach-at91 (bnc#1151927 5.3.4).
- net: lpc-enet: fix printk format strings (bnc#1151927 5.3.4).
- ARM: xscale: fix multi-cpu compilation (bnc#1151927 5.3.4).
- dmaengine: iop-adma: use correct printk format strings
  (bnc#1151927 5.3.4).
- parisc: Disable HP HSC-PCI Cards to prevent kernel crash
  (bnc#1151927 5.3.4).
- ia64:unwind: fix double free for mod->arch.init_unw_table
  (bnc#1151927 5.3.4).
- irqchip/sifive-plic: set max threshold for ignored handlers
  (bnc#1151927 5.3.4).
- m68k: Prevent some compiler warnings in Coldfire builds
  (bnc#1151927 5.3.4).
- arm64: Use correct ll/sc atomic constraints (bnc#1151927 5.3.4).
- jump_label: Don't warn on __exit jump entries (bnc#1151927
  5.3.4).
- arm64: tlb: Ensure we execute an ISB following walk cache
  invalidation (bnc#1151927 5.3.4).
- kasan/arm64: fix CONFIG_KASAN_SW_TAGS && KASAN_INLINE
  (bnc#1151927 5.3.4).
- arm64: kpti: ensure patched kernel text is fetched from PoU
  (bnc#1151927 5.3.4).
- arm64: entry: Move ct_user_exit before any other exception
  (bnc#1151927 5.3.4).
- powerpc/Makefile: Always pass --synthetic to nm if supported
  (bnc#1151927 5.3.4).
- arm64/efi: Move variable assignments after SECTIONS (bnc#1151927
  5.3.4).
- arm64/prefetch: fix a -Wtype-limits warning (bnc#1151927 5.3.4).
- arm64: mm: free the initrd reserved memblock in a aligned manner
  (bnc#1151927 5.3.4).
- iommu/amd: Silence warnings under memory pressure (bnc#1151927
  5.3.4).
- iommu/amd: Override wrong IVRS IOAPIC on Raven Ridge systems
  (bnc#1151927 5.3.4).
- iommu/arm-smmu-v3: Disable detection of ATS and PRI (bnc#1151927
  5.3.4).
- gpio: madera: Add support for Cirrus Logic CS47L92 (bnc#1151927
  5.3.4).
- gpio: madera: Add support for Cirrus Logic CS47L15 (bnc#1151927
  5.3.4).
- spi: ep93xx: Repair SPI CS lookup tables (bnc#1151927 5.3.4).
- spi: dw-mmio: Clock should be shut when error occurs
  (bnc#1151927 5.3.4).
- spi: bcm2835: Work around DONE bit erratum (bnc#1151927 5.3.4).
- spi: spi-fsl-dspi: Exit the ISR with IRQ_NONE when it's not ours
  (bnc#1151927 5.3.4).
- regulator: Defer init completion for a while after late_initcall
  (bnc#1151927 5.3.4).
- regulator: lm363x: Fix n_voltages setting for lm36274
  (bnc#1151927 5.3.4).
- regulator: lm363x: Fix off-by-one n_voltages for lm3632
  ldo_vpos/ldo_vneg (bnc#1151927 5.3.4).
- hwmon: (acpi_power_meter) Change log level for 'unsafe software
  power cap' (bnc#1151927 5.3.4).
- RAS: Build debugfs.o only when enabled in Kconfig (bnc#1151927
  5.3.4).
- EDAC/amd64: Support more than two controllers for chip selects
  handling (bnc#1151927 5.3.4).
- EDAC, pnd2: Fix ioremap() size in dnv_rd_reg() (bnc#1151927
  5.3.4).
- EDAC/altera: Use the proper type for the IRQ status bits
  (bnc#1151927 5.3.4).
- EDAC/mc: Fix grain_bits calculation (bnc#1151927 5.3.4).
- tpm_tis_core: Turn on the TPM before probing IRQ's (bnc#1151927
  5.3.4).
- Update patches.suse/tpm_tis_core-Set-TPM_CHIP_FLAG_IRQ-before-probing-fo.patch
- commit 44d74c4
* Tue Oct  8 2019 mhocko@suse.com
- kernel/sysctl.c: do not override max_threads provided by
  userspace (bnc#1150875).
- commit c8680bd
* Mon Oct  7 2019 msuchanek@suse.de
- powerpc/pseries/mobility: use cond_resched when updating device
  tree (bsc#1153112 ltc#181778).
- powerpc/rtas: allow rescheduling while changing cpu states
  (bsc#1153112 ltc#181778).
- commit 6d0719a
* Mon Oct  7 2019 msuchanek@suse.de
- powerpc/64s/pseries: radix flush translations before MMU is
  enabled at boot (bsc#1055186).
- commit 90a9436
* Mon Oct  7 2019 martin.wilck@suse.com
- block: drop device references in bsg_queue_rq() (bsc#1153217).
- commit b02e448
* Mon Oct  7 2019 tbogendoerfer@suse.de
- Re-activated still not upstream mvpp2 patch (bsc#1117016)
- commit 6e10d56
* Mon Oct  7 2019 tbogendoerfer@suse.de
- Delete
  patches.suse/lustre-Simplify-ib_post_-send-recv-srq_recv-calls.patch.
  No longer needed.
- commit 8d0fb6b
* Mon Oct  7 2019 jthumshirn@suse.de
- libnvdimm/altmap: Track namespace boundaries in altmap
  (bsc#1150305).
- commit 458a137
* Mon Oct  7 2019 jslaby@suse.cz
- Linux 5.3.3 (bnc#1151927 5.3.3).
- commit d0d68ea
* Mon Oct  7 2019 pvorel@suse.cz
- alarmtimer: Use EOPNOTSUPP instead of ENOTSUPP (bsc#1151680).
- commit 87f78af
* Mon Oct  7 2019 ohering@suse.de
- scsi: storvsc: setup 1:1 mapping between hardware queue and
  CPU queue (fate#323887).
- commit 96ad9b0
* Sun Oct  6 2019 mkubecek@suse.cz
- hwmon: (k10temp) Add support for AMD family 17h, model 70h CPUs
  (bsc#1153137).
- x86/amd_nb: Add PCI device IDs for family 17h, model 70h
  (bsc#1153137).
- commit 6e407a5
* Fri Oct  4 2019 msuchanek@suse.de
- powerpc/64s/radix: tidy up TLB flushing code (bsc#1152885).
- powerpc/64s: remove register_process_table callback
  (bsc#1152885).
- commit 33f6003
* Fri Oct  4 2019 mkubecek@suse.cz
- Linux 5.3.2 (bnc#1151927 5.3.2).
- ALSA: usb-audio: Add DSD support for EVGA NU Audio (bnc#1151927
  5.3.2).
- ALSA: hda - Add laptop imic fixup for ASUS M9V laptop
  (bnc#1151927 5.3.2).
- ALSA: hda - Apply AMD controller workaround for Raven platform
  (bnc#1151927 5.3.2).
- ALSA: usb-audio: Add Hiby device family to quirks for native
  DSD support (bnc#1151927 5.3.2).
- ALSA: dice: fix wrong packet parameter for Alesis iO26
  (bnc#1151927 5.3.2).
- Revert "mm/z3fold.c: fix race between migration and destruction"
  (bnc#1151927 5.3.2).
- platform/x86: i2c-multi-instantiate: Derive the device name
  from parent (bnc#1151927 5.3.2).
- HID: Add quirk for HP X500 PIXART OEM mouse (bnc#1151927 5.3.2).
- HID: prodikeys: Fix general protection fault during probe
  (bnc#1151927 5.3.2).
- HID: sony: Fix memory corruption issue on cleanup (bnc#1151927
  5.3.2).
- HID: logitech-dj: Fix crash when initial
  logi_dj_recv_query_paired_devices fails (bnc#1151927 5.3.2).
- HID: logitech: Fix general protection fault caused by Logitech
  driver (bnc#1151927 5.3.2).
- HID: hidraw: Fix invalid read in hidraw_ioctl (bnc#1151927
  5.3.2).
- crypto: talitos - fix missing break in switch statement
  (bnc#1151927 5.3.2).
- mtd: cfi_cmdset_0002: Use chip_good() to retry in
  do_write_oneword() (bnc#1151927 5.3.2).
- clk: imx: imx8mm: fix audio pll setting (bnc#1151927 5.3.2).
- drm/amd/display: Don't replace the dc_state for fast updates
  (bnc#1151927 5.3.2).
- drm/amd/display: Skip determining update type for async updates
  (bnc#1151927 5.3.2).
- drm/amd/display: Allow cursor async updates for framebuffer
  swaps (bnc#1151927 5.3.2).
- drm/amd/display: readd -msse2 to prevent Clang from emitting
  libcalls to undefined SW FP routines (bnc#1151927 5.3.2).
- netfilter: add missing IS_ENABLED(CONFIG_NF_TABLES) check to
  header-file (bnc#1151927 5.3.2).
- clocksource/drivers: Do not warn on probe defer (bnc#1151927
  5.3.2).
- clocksource/drivers/timer-of: Do not warn on deferred probe
  (bnc#1151927 5.3.2).
- objtool: Clobber user CFLAGS variable (bnc#1151927 5.3.2).
- commit 8866153
* Fri Oct  4 2019 mkubecek@suse.cz
- Update references (add bnc#1151927 5.3.2) and refresh
  patches.suse/powerpc-xive-Fix-bogus-error-code-returned-by-OPAL.patch
- commit cf3b8a7
* Fri Oct  4 2019 wqu@suse.com
- btrfs: qgroup: Fix reserved data space leak if we have  multiple
  reserve calls (bsc#1152975).
- commit 453d0eb
* Fri Oct  4 2019 wqu@suse.com
- btrfs: qgroup: Fix the wrong target io_tree when freeing
  reserved data space (bsc#1152974).
- commit f48e436
* Fri Oct  4 2019 wqu@suse.com
- btrfs: Fix a regression which we can't convert to SINGLE
  profile (bsc#1152973).
- commit eee41e6
* Fri Oct  4 2019 wqu@suse.com
- btrfs: relocation: fix use-after-free on dead relocation  roots
  (bsc#1152972).
- commit 39b83a8
* Thu Oct  3 2019 msuchanek@suse.de
- powerpc: add machine check safe copy_to_user (jsc#SLE-7730
  jsc#SLE-8330).
  Update config files.
- powerpc/memcpy: Add memcpy_mcsafe for pmem (jsc#SLE-7730
  jsc#SLE-8330).
- powerpc/mce: Handle UE event for memcpy_mcsafe (jsc#SLE-7730
  jsc#SLE-8330).
- extable: Add function to search only kernel exception table
  (jsc#SLE-7730 jsc#SLE-8330).
- powerpc/mce: Make machine_check_ue_event() static (jsc#SLE-7730
  jsc#SLE-8330).
- powerpc/mce: Fix MCE handling for huge pages (jsc#SLE-7730
  jsc#SLE-8330).
- powerpc/mce: Schedule work from irq_work (jsc#SLE-7730
  jsc#SLE-8330).
- commit 12b3809
* Thu Oct  3 2019 msuchanek@suse.de
- powerpc/powernv: Restrict OPAL symbol map to only be readable
  by root (bsc#1152885).
- powerpc/rtas: Unexport rtas_online_cpus_mask,
  rtas_offline_cpus_mask (bsc#1152885).
- commit a002009
* Thu Oct  3 2019 msuchanek@suse.de
- KVM: PPC: Book3S: Enable XIVE native capability only if OPAL
  has required functions (bsc#1061840).
- commit c8b5967
* Thu Oct  3 2019 msuchanek@suse.de
- dma-mapping: explicitly wire up ->mmap and ->get_sgtable
  (bsc#1152879).
- commit 4e5b600
* Thu Oct  3 2019 msuchanek@suse.de
- powerpc/powernv/ioda2: Allocate TCE table levels on demand
  for default DMA window (bsc#1061840).
- commit af7925a
* Thu Oct  3 2019 msuchanek@suse.de
- powerpc/pseries: Call H_BLOCK_REMOVE when supported
  (bsc#1109158).
- powerpc/pseries: Read TLB Block Invalidate Characteristics
  (bsc#1109158).
- commit 4883057
* Thu Oct  3 2019 mkubecek@suse.cz
- config: refresh configs
- commit b8eafb3
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/xive: Fix bogus error code returned by OPAL
  (bsc#1065729).
- commit 9e22168
* Wed Oct  2 2019 msuchanek@suse.de
- blacklist.conf: Add duplicate commit id.
- commit f9863f0
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/papr_scm: Fix an off-by-one check in papr_scm_meta_{get,
  set} (bsc#1152243 ltc#181472).
- net/ibmvnic: prevent more than one thread from running in reset
  (bsc#1152457 ltc#174432).
- net/ibmvnic: unlock rtnl_lock in reset so linkwatch_event can
  run (bsc#1152457 ltc#174432).
- powerpc/mm: Fixup tlbie vs mtpidr/mtlpidr ordering issue on
  POWER9 (bsc#1152161 ltc#181664).
- powerpc/book3s64/radix: Rename CPU_FTR_P9_TLBIE_BUG feature flag
  (bsc#1152161 ltc#181664).
- powerpc/book3s64/mm: Don't do tlbie fixup for some hardware
  revisions (bsc#1152161 ltc#181664).
- commit 4d9184c
* Wed Oct  2 2019 ohering@suse.de
- irqdomain: Add the missing assignment of domain->fwnode for
  named fwnode (fate#323887).
- commit e4b9c3f
* Wed Oct  2 2019 ohering@suse.de
- KVM: vmx: fix build warnings in hv_enable_direct_tlbflush()
  on i386 (fate#323887).
- KVM: x86: announce KVM_CAP_HYPERV_ENLIGHTENED_VMCS support
  only when it is available (fate#323887).
- KVM/Hyper-V: Add new KVM capability
  KVM_CAP_HYPERV_DIRECT_TLBFLUSH (fate#323887).
- commit 68b44d1
* Wed Oct  2 2019 ohering@suse.de
- cpu/SMT: create and export cpu_smt_possible() (fate#323887).
- smp/hotplug: Track booted once CPUs in a cpumask (fate#323887).
- commit 48d9519
* Wed Oct  2 2019 ohering@suse.de
- KVM: x86: hyper-v: set NoNonArchitecturalCoreSharing CPUID
  bit when SMT is impossible (fate#323887).
- commit 231241b
* Wed Oct  2 2019 ohering@suse.de
- KVM: hyperv: Fix Direct Synthetic timers assert an interrupt
  w/o lapic_in_kernel (fate#323887).
- commit 8f924d6
* Wed Oct  2 2019 ohering@suse.de
- KVM/Hyper-V/VMX: Add direct tlb flush support (fate#323887).
- commit ef750e3
* Wed Oct  2 2019 ohering@suse.de
- x86/Hyper-V: Fix definition of struct hv_vp_assist_page
  (fate#323887).
- commit 1239e74
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Resume after fixing up old primary channels
  (fate#323887).
- commit 9e12e34
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Suspend after cleaning up hv_sock and sub
  channels (fate#323887).
- commit 36c8dd5
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Clean up hv_sock channels by force upon
  suspend (fate#323887).
- commit 9f06b05
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Suspend/resume the vmbus itself for
  hibernation (fate#323887).
- commit 4bd7f09
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Ignore the offers when resuming from
  hibernation (fate#323887).
- commit fe8f660
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Implement suspend/resume for VSC drivers
  for hibernation (fate#323887).
- commit 344d3ff
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Add a helper function is_sub_channel()
  (fate#323887).
- commit 3b1ed7d
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Suspend/resume the synic for hibernation
  (fate#323887).
- commit 121172c
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Break out synic enable and disable
  operations (fate#323887).
- commit 561f047
* Wed Oct  2 2019 ohering@suse.de
- HID: hv: Remove dependencies on PAGE_SIZE for ring buffer
  (fate#323887).
- commit 60e6c9f
* Wed Oct  2 2019 ohering@suse.de
- Tools: hv: move to tools buildsystem (fate#323887).
- commit a3f0abd
* Wed Oct  2 2019 ohering@suse.de
- hv_balloon: Reorganize the probe function (fate#323887).
- commit 8480408
* Wed Oct  2 2019 ohering@suse.de
- hv_balloon: Use a static page for the balloon_up send buffer
  (fate#323887).
- commit 9e12837
* Wed Oct  2 2019 ohering@suse.de
- PCI: hv: Use bytes 4 and 5 from instance ID as the PCI domain
  numbers (fate#323887).
- commit 113e837
* Wed Oct  2 2019 ohering@suse.de
- PCI: hv: Detect and fix Hyper-V PCI domain number collision
  (fate#323887, bsc#1150423).
- commit a0e547e
* Wed Oct  2 2019 ohering@suse.de
- hv_netvsc: Sync offloading features to VF NIC (fate#323887).
- commit 392e859
* Wed Oct  2 2019 ohering@suse.de
- hv_netvsc: Allow scatter-gather feature to be tunable
  (fate#323887).
- commit 0aa9a52
* Wed Oct  2 2019 ohering@suse.de
- PCI: hv: Add a Hyper-V PCI interface driver for software
  backchannel interface (fate#323887).
- commit 381f060
* Wed Oct  2 2019 ohering@suse.de
- PCI: hv: Add a paravirtual backchannel in software
  (fate#323887).
- commit 9b88ba8
* Wed Oct  2 2019 ohering@suse.de
- x86/hyperv: Hide pv_ops access for CONFIG_PARAVIRT=n
  (fate#323887).
- commit 334c380
* Wed Oct  2 2019 ohering@suse.de
- clocksource/drivers/hyperv: Enable TSC page clocksource on 32bit
  (fate#323887).
- commit ddf471b
* Wed Oct  2 2019 ohering@suse.de
- clocksource/drivers/hyperv: Add Hyper-V specific sched clock
  function (fate#323887).
- commit 0442bbf
* Wed Oct  2 2019 ohering@suse.de
- clocksource/drivers/hyperv: Allocate Hyper-V TSC page statically
  (fate#323887).
- commit 8fc74ac
* Wed Oct  2 2019 ohering@suse.de
- PCI: hv: Allocate a named fwnode instead of an address-based
  one (fate#323887).
- commit 38fe080
* Wed Oct  2 2019 ohering@suse.de
- drivers: hv: vmbus: Replace page definition with Hyper-V
  specific one (fate#323887).
- commit a1e5f69
* Wed Oct  2 2019 ohering@suse.de
- x86/hyperv: Add functions to allocate/deallocate page for
  Hyper-V (fate#323887).
- commit 357181d
* Wed Oct  2 2019 ohering@suse.de
- x86/hyperv: Create and use Hyper-V page definitions
  (fate#323887).
- commit 0a58e81
* Wed Oct  2 2019 ohering@suse.de
- add mainline tag to a hyperv patch
- commit 994aada
* Wed Oct  2 2019 mkubecek@suse.cz
- series.conf: cleanup
  Move unsortable patch out of sorted section.
- commit 636b696
* Tue Oct  1 2019 mwilck@suse.com
- scsi: scsi_dh_rdac: zero cdb in send_mode_select()
  (bsc#1149313).
- commit e7cd81e
* Tue Oct  1 2019 lduncan@suse.com
- Removed guarded st driver patch: already upstream
- commit b34f3cb
* Tue Oct  1 2019 yousaf.kaukab@suse.com
- arm64: mmc: remove patches already applied to v5.3
  Both patches landed in v5.0
- commit 075db4d
* Tue Oct  1 2019 yousaf.kaukab@suse.com
- arm64: remove 0001-irqchip-gic-v3-its-fix-build-warnings.patch
  Not required on v5.3
- commit db9714b
* Tue Oct  1 2019 yousaf.kaukab@suse.com
- config: arm64: lx2160: enable mobiveil pcie controller driver
- commit 21c2539
* Tue Oct  1 2019 yousaf.kaukab@suse.com
- PCI: mobiveil: Add PCIe Gen4 RC driver for NXP Layerscape SoCs
  (fate#326572).
- PCI: mobiveil: Add 8-bit and 16-bit CSR register accessors
  (fate#326572).
- PCI: mobiveil: Make mobiveil_host_init() can be used to re-init
  host (fate#326572).
- PCI: mobiveil: Refactor Mobiveil PCIe Host Bridge IP driver
  (fate#326572).
- PCI: mobiveil: Fix the CPU base address setup in inbound window
  (fate#326572).
- commit 1e982e0
* Tue Oct  1 2019 ykaukab@suse.de
- arm64: lx2160: remove mobiveil PCIe driver v5
  Preparing to bring in v8. Most of the patches are already included in
  v5.3.
- commit 136f3e5
* Tue Oct  1 2019 ykaukab@suse.de
- PCI: Add quirk to disable MSI-X support for Amazon's Annapurna
  Labs Root Port (bsc#1152187,bsc#1152525).
- PCI/VPD: Prevent VPD access for Amazon's Annapurna Labs Root
  Port (bsc#1152187,bsc#1152525).
- PCI: Add ACS quirk for Amazon Annapurna Labs root ports
  (bsc#1152187,bsc#1152525).
- PCI: Add Amazon's Annapurna Labs vendor ID
  (bsc#1152187,bsc#1152525).
- commit cb75ccf
* Tue Oct  1 2019 oneukum@suse.com
- usb: typec: tps6598x: Fix build error without CONFIG_REGMAP_I2C
  (bsc#1152489).
- commit 50acd22
* Tue Oct  1 2019 oneukum@suse.com
- usb: dwc3: meson-g12a: fix suspend resume regulator unbalanced
  disables (bsc#1152489).
- commit f417fe7
* Tue Oct  1 2019 oneukum@suse.com
- b2c2-flexcop-usb: add sanity checking (bsc#1146540
  CVE-2019-15291).
- commit 300993f
* Tue Oct  1 2019 oneukum@suse.com
- ipmi: move message error checking to avoid deadlock
  (bsc#1152489).
- commit 78528fd
* Tue Oct  1 2019 bp@suse.de
- x86/cpufeatures: Enable a new AVX512 CPU feature (jsc#SLE-7925).
- commit 400d642
* Tue Oct  1 2019 jslaby@suse.cz
- Update config files.
  Enable CONFIG_X86_5LEVEL (jsc#SLE-9308).
- commit fad1d7e
* Tue Oct  1 2019 tzimmermann@suse.de
- drm/mgag200: Don't unpin the current cursor image's buffer. (bsc#1152472)
- commit 6389bb6
* Tue Oct  1 2019 tzimmermann@suse.de
- drm/mgag200: Set cursor scanout address to correct BO (bsc#1152472)
- commit fba11f2
* Tue Oct  1 2019 tzimmermann@suse.de
- drm/mgag200: Pin displayed cursor BO to video memory (bsc#1152472)
- commit 1cd88ec
* Tue Oct  1 2019 tzimmermann@suse.de
- drm/mgag200: add in missing { } around if block (bsc#1152472)
- commit 5ad6864
* Tue Oct  1 2019 mkubecek@suse.cz
- series.conf: cleanup
  Let's keep the number of top level sections reasonable.
  Update tags (do not use "Patch-mainline: no"):
  patches.suse/printk-console-Correctly-mark-console-that-is-used-w.patch
  patches.suse/printk-panic-Avoid-deadlock-in-printk-after-stopping-CPUs-by-NMI.patch
- commit 9121df0
* Mon Sep 30 2019 bp@suse.de
- EDAC/amd64: Recognize DRAM device type ECC capability
  (bsc#1152489).
- commit abc7ef1
* Mon Sep 30 2019 bp@suse.de
- EDAC/amd64: Decode syndrome before translating address
  (bsc#1152489).
- commit 3c4a52a
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/amdgpu: Fix KFD-related kernel oops on Hawaii (bsc#1152472)
- commit 3c6a999
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/amdkfd: fix a use after free race with mmu_notifer unregister (bsc#1152472)
- commit 792d1c5
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/mcde: Fix DSI transfers (bsc#1152472)
- commit a87cce0
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/msm: Use the correct dma_sync calls harder (bsc#1152472)
- commit 33411e0
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/msm/dsi: Fix return value check for clk_get_parent (bsc#1152472)
- commit b591595
* Mon Sep 30 2019 pmladek@suse.com
- Refresh
  patches.suse/printk-console-Correctly-mark-console-that-is-used-w.patch
- commit d007d29
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix GFXOFF on Picasso and Raven2'
- commit 0b48ba5
* Mon Sep 30 2019 tzimmermann@suse.de
- Revert "drm/amdgpu: free up the first paging queue v2" (bsc#1152472)
- commit beca648
* Mon Sep 30 2019 tzimmermann@suse.de
- Revert "drm/amd/display: Fix underscan not using proper scaling" (bsc#1152472)
- commit 6bc7400
* Mon Sep 30 2019 tzimmermann@suse.de
- Revert "drm/amd/display: add global master update lock for DCN2" (bsc#1152472)
- commit 13bba8c
* Mon Sep 30 2019 tzimmermann@suse.de
- Revert "drm/amd/display: navi10 bring up skip dsc encoder config" (bsc#1152472)
- commit f5b512e
* Mon Sep 30 2019 tzimmermann@suse.de
- Revert "drm/amd/display: skip dsc config for navi10 bring up" (bsc#1152472)
- commit e06dd1d
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Calculate bpc based on max_requested_bpc'
- commit ba7e6fb
* Mon Sep 30 2019 vbabka@suse.cz
- Update config files. Enable CONFIG_DEBUG_PAGEALLOC.
- commit c9d1113
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/gfx9: update pg_flags after determining if gfx off is possible'
- commit 1687748
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/amdgpu: fix transform feedback GDS hang on gfx10 (v2)"'
- commit 1b720a9
* Mon Sep 30 2019 tzimmermann@suse.de
- drm: fix module name in edid_firmware log message (bsc#1152472)
- commit b1ccfe7
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/imx: Drop unused imx-ipuv3-crtc.o build (bsc#1152472)
- commit c76be29
* Mon Sep 30 2019 vbabka@suse.cz
- x86/kconfig: Remove X86_DIRECT_GBPAGES dependency on
  !DEBUG_PAGEALLOC (PM-1168, bsc#1144653, VM Debug Functionality).
- commit bebf778
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Do not create a new max_bpc prop for MST connectors'
- commit 2f54da8
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix HW readout for crtc_clock in HDMI mode'
- commit d17d39c
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix wrong escape clock divisor init for GLK'
- commit de225fb
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: fix possible memory leak in intel_hdcp_auth_downstream()'
- commit 81e8a9e
* Mon Sep 30 2019 tzimmermann@suse.de
- drm: rcar-du: lvds: Fix bridge_to_rcar_lvds (bsc#1152472)
- commit 7243441
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/amd/display: Use proper enum conversion functions (bsc#1152472)
- commit 8362493
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/amd/display: Support uclk switching for DCN2 (bsc#1152472)
- commit 4b2f15b
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/rockchip: fix VOP_WIN_GET macro (bsc#1152472)
- commit 6dccec7
* Mon Sep 30 2019 tzimmermann@suse.de
- drm: mali-dp: Mark expected switch fall-through (bsc#1152472)
- commit d5b02fc
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/syncobj: fix leaking dma_fence in drm_syncobj_query_ioctl (bsc#1152472)
- commit f87cd1c
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/connector: Fix warning in debug message'
- commit 99fb862
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/bridge: sii902x: fix missing reference to mclk clock (bsc#1152472)
- commit 33a37f2
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/panel: make drm_panel.h self-contained (bsc#1152472)
- commit 24e6b1f
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/lima: Reduce the amount of logs on deferred probe (bsc#1152472)
- commit 7fc211d
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/lima: Mark 64-bit number as ULL (bsc#1152472)
- commit a47d898
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix GEN8_MCR_SELECTOR programming'
- commit 7f9b12e
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/vbt: Fix VBT parsing for the PSR section'
- commit d8eb2fd
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Lock the engine while dumping the active request'
- commit eaa408b
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/perf: add missing delay for OA muxes configuration'
- commit 3e3bf58
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/perf: ensure we keep a reference on the driver'
- commit 2030c79
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gtt: Mark the freed page table entries with scratch'
- commit 1cbd1c3
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gtt: Defer the free for alloc error paths'
- commit 68741a8
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Deal with machines that expose less than three QGV points'
- commit 984d843
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix memleak in runtime wakeref tracking'
- commit e990311
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: fix whitelist selftests with readonly registers'
- commit 8c63a7c
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix the TBT AUX power well enabling'
- commit e962027
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Lift intel_engines_resume() to callers'
- commit b42e83a
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Only recover active engines'
- commit 562ba01
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix various tracepoints for gen2'
- commit 53b1384
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/perf: fix ICL perf register offsets'
- commit f94a6d1
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Keep rings pinned while the context is active'
- commit ddd1ccc
* Mon Sep 30 2019 tzimmermann@suse.de
- video: backlight: Drop default m for {LCD,BACKLIGHT_CLASS_DEVICE} (bsc#1152472)
- commit 85cda2a
* Mon Sep 30 2019 tzimmermann@suse.de
- video: ssd1307fb: Start page range at page_offset (bsc#1152472)
- commit 8809ebe
* Mon Sep 30 2019 pmladek@suse.com
- printk/panic: Avoid deadlock in printk() after stopping CPUs
  by NMI (bsc#1148712).
- commit dd62e61
* Mon Sep 30 2019 pvorel@suse.cz
- blacklist.conf: blacklist 34cd83bb8a46
- commit e519fc0
* Mon Sep 30 2019 mkubecek@suse.cz
- series.conf: cleanup
- commit 56e35ef
* Mon Sep 30 2019 jlee@suse.com
- KEYS: Make use of platform keyring for module signature verify
  (FATE#314508, FATE#316531).
- commit 0722d07
* Fri Sep 27 2019 mbenes@suse.cz
- livepatch: Nullify obj->mod in klp_module_coming()'s error path
  (bsc#1071995 fate#323487).
- commit a28c007
* Thu Sep 26 2019 jlee@suse.com
- Delete
  patches.suse/0006-modsign-Use-secondary-trust-keyring-for-module-signi.patch.
  This patch be replaced by e84cd7ee63 in v5.0-rc1.
- commit e937c06
* Thu Sep 26 2019 jlee@suse.com
- Delete
  patches.suse/0001-KEYS-Allow-unrestricted-boot-time-addition-of-keys-t.patch.
  This patch be replaced by 60740accf78 in v5.0-rc1. The UEFI keys will be add
  to platform keyring instead of secondary certificates keyring.
- commit bc249e1
* Thu Sep 26 2019 jlee@suse.com
- Delete
  patches.suse/0005-MODSIGN-Allow-the-db-UEFI-variable-to-be-suppressed.patch.
  This patch be replaced by 386b49f51dc in v5.0-rc1
- commit 58a4a2d
* Thu Sep 26 2019 jlee@suse.com
- Delete
  patches.suse/0003-efi-Add-an-EFI-signature-blob-parser.patch.
  This patch be replaced by 0bc9ae395b in v5.0-rc1.
- commit 1c1cc93
* Thu Sep 26 2019 jlee@suse.com
- Delete patches.suse/0002-efi-Add-EFI-signature-data-types.patch.
  This patch be replaced by 5c126ba22f in v5.0-rc1.
- commit 3868a56
* Wed Sep 25 2019 ailiopoulos@suse.com
- Delete patches.suse/squashfs-3.4.patch.
  Deprecate squashfs-3.4 legacy fs format support (jsc#SLE-9416)
- commit e1d0aab
* Wed Sep 25 2019 jlee@suse.com
- Delete
  patches.suse/0004-MODSIGN-Import-certificates-from-UEFI-Secure-Boot.patch.
  This patch be replaced by 15ea0e1e3e in v5.0-rc1.
- commit d558f60
* Wed Sep 25 2019 mkubecek@suse.cz
- supported.conf: cleanup
- drop obsolete mask sound/oss/*
- drop removed module nf_conntrack_slp
- commit 30def80
* Wed Sep 25 2019 jslaby@suse.cz
- config.conf: disable vanilla flavour
  As was discussed on the labs conf 2019, vanilla flavour is barely
  used. Given we are not going to use stable patches when building
  kernel-vanilla, it becomes a yet bit more useless. So disable it for
  now only. If nobody cares, we can drop also the configs later.
- commit 4223115
* Wed Sep 25 2019 jslaby@suse.cz
- Linux 5.3.1 (bnc#1151927 5.3.1).
- ovl: fix regression caused by overlapping layers detection
  (bnc#1151927 5.3.1).
- xen-netfront: do not assume sk_buff_head list is empty in
  error handling (bnc#1151927 5.3.1).
- net: stmmac: Hold rtnl lock in suspend/resume callbacks
  (bnc#1151927 5.3.1).
- ip6_gre: fix a dst leak in ip6erspan_tunnel_xmit (bnc#1151927
  5.3.1).
- udp: correct reuseport selection with connected sockets
  (bnc#1151927 5.3.1).
- net_sched: let qdisc_put() accept NULL pointer (bnc#1151927
  5.3.1).
- net: dsa: Fix load order between DSA drivers and taggers
  (bnc#1151927 5.3.1).
- net/sched: fix race between deactivation and dequeue for NOLOCK
  qdisc (bnc#1151927 5.3.1).
- nl80211: Fix possible Spectre-v1 for CQM RSSI thresholds
  (bnc#1151927 5.3.1).
- firmware: google: check if size is valid when decoding VPD data
  (bnc#1151927 5.3.1).
- phy: qcom-qmp: Correct ready status, again (bnc#1151927 5.3.1).
- phy: renesas: rcar-gen3-usb2: Disable clearing VBUS in
  over-current (bnc#1151927 5.3.1).
- serial: sprd: correct the wrong sequence of arguments
  (bnc#1151927 5.3.1).
- tty/serial: atmel: reschedule TX after RX was started
  (bnc#1151927 5.3.1).
- USB: usbcore: Fix slab-out-of-bounds bug during device reset
  (bnc#1151927 5.3.1).
- KVM: coalesced_mmio: add bounds checking (bnc#1151927 5.3.1).
- media: tm6000: double free if usb disconnect while streaming
  (bnc#1151927 5.3.1).
- media: technisat-usb2: break out of loop at end of buffer
  (bnc#1151927 5.3.1).
- floppy: fix usercopy direction (bnc#1151927 5.3.1).
- Documentation: sphinx: Add missing comma to list of strings
  (bnc#1151927 5.3.1).
- Revert "arm64: Remove unnecessary ISBs from set_{pte,pmd,pud}"
  (bnc#1151927 5.3.1).
- commit af71771
* Tue Sep 24 2019 msuchanek@suse.de
- enable VFIO-CCW and CCW IOMMU (bsc#1151192 jsc#SLE-6138)
- config changes (s390x only)
  - VFIO_CCW=m
  - S390_CCW_IOMMU=y
- supported.conf: add vfio_ccw as externally supported (by IBM)
  supported.conf: Add vfio_ccw (bsc#1151192 jsc#SLE-6138).
- commit bbfc15f
* Tue Sep 24 2019 hare@suse.de
- Compile nvme.ko as module (bsc#1150846, bsc#1150850, bsc#1161889)
- commit 12cab35
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/64s/radix: Fix memory hotplug section page table
  creation (bsc#1065729).
- commit 431bc28
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/pseries: Fix cpu_hotplug_lock acquisition in
  resize_hpt() (bsc#1065729).
- commit e574522
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/xive: Implement get_irqchip_state method for XIVE to
  fix shutdown race (bsc#1065729).
- commit a9647b9
* Mon Sep 23 2019 msuchanek@suse.de
- tpm_tis_core: Set TPM_CHIP_FLAG_IRQ before probing for
  interrupts (bsc#1082555).
- commit d3b1602
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/64s/radix: Fix memory hot-unplug page table split
  (bsc#1065729).
- powerpc/powernv/ioda: Fix race in TCE level allocation
  (bsc#1061840).
- KVM: PPC: Book3S HV: Don't lose pending doorbell request on
  migration on P9 (bsc#1061840).
- KVM: PPC: Book3S HV: Check for MMU ready on piggybacked virtual
  cores (bsc#1061840).
- KVM: PPC: Book3S HV: Don't push XIVE context when not using
  XIVE device (bsc#1061840).
- KVM: PPC: Book3S HV: Fix race in re-enabling XIVE escalation
  interrupts (bsc#1061840).
- KVM: PPC: Book3S HV: XIVE: Free escalation interrupts before
  disabling the VP (bsc#1061840).
- commit 3411cdc
* Mon Sep 23 2019 jroedel@suse.de
- iommu/dma: Fix for dereferencing before null checking
  (bsc#1151674).
- iommu/iova: Avoid false sharing on fq_timer_on (bsc#1151675).
- iommu/vt-d: Fix wrong analysis whether devices share the same
  bus (bsc#1151679).
- iommu/ipmmu-vmsa: Move IMTTBCR_SL0_TWOBIT_* to restore sort
  order (bsc#1151676).
- iommu/mediatek: Fix VLD_PA_RNG register backup when suspend
  (bsc#1151678).
- iommu/mediatek: Fix iova_to_phys PA start for 4GB mode
  (bsc#1151677).
- commit 6809156
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/64s/exception: reduce page fault unnecessary loads
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Remove pointless KVM handler name
  bifurcation (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: program check handler do not branch
  into a macro (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: move interrupt entry code above the
  common handler (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: INT_COMMON add DAR, DSISR, reconcile
  options (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Expand EXCEPTION_PROLOG_COMMON_1 and
  2 into caller (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Expand EXCEPTION_COMMON macro into caller
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Add INT_COMMON gas macro to generate
  common exception code (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Merge EXCEPTION_PROLOG_COMMON_2/3
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: KVM_HANDLER reorder arguments to match
  other macros (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Add INT_KVM_HANDLER gas macro
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: INT_HANDLER support HDAR/HDSISR and
  use it in HDSI (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Add the virt variant of the denorm
  interrupt handler (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: remove EXCEPTION_PROLOG_0/1, rename _2
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exceptions: Use keyword params to shorten arg lists
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Replace PROLOG macros and EXC helpers
  with a gas macro (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: remove 0xb00 handler (jsc#PM-1334
  jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Fix performance monitor virt handler
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Add EXC_HV_OR_STD, which selects HSRR
  if HVMODE (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: move head-64.h exception code to
  exception-64s.S (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Fix DAR load for handle_page_fault
  error case (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check improve labels and comments
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: untangle early machine check handler
  branch (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check move unrecoverable handling
  out of line (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: simplify machine check early path
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check move tramp code
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check restructure to reuse
  common macros (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check pseries should skip
  the late handler for kernel MCEs (jsc#PM-1334 jsc#SLE-9246
  jsc#SLE-9251).
- powerpc/64s/pseries: machine check convert to use common event
  code (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/powernv: machine check dump SLB contents
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check use correct cfar for late
  handler (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check remove
  machine_check_pSeries_0 branch (jsc#PM-1334 jsc#SLE-9246
  jsc#SLE-9251).
- powerpc/64s/exception: machine check pseries should always
  run the early handler (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check adjust RFI target
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check fix KVM guest test
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check remove bitrotted comment
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check fwnmi remove HV case
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- commit 0e08ffb
* Mon Sep 23 2019 msuchanek@suse.de
- kexec_elf: support 32 bit ELF files (jsc#PM-1333 jsc#SLE-9255
  jsc#SLE-9527).
- kexec_elf: remove unused variable in kexec_elf_load()
  (jsc#PM-1333 jsc#SLE-9255 jsc#SLE-9527).
- kexec_elf: remove Elf_Rel macro (jsc#PM-1333 jsc#SLE-9255
  jsc#SLE-9527).
- kexec_elf: remove PURGATORY_STACK_SIZE (jsc#PM-1333 jsc#SLE-9255
  jsc#SLE-9527).
- kexec_elf: remove parsing of section headers (jsc#PM-1333
  jsc#SLE-9255 jsc#SLE-9527).
- kexec_elf: change order of elf_*_to_cpu() functions (jsc#PM-1333
  jsc#SLE-9255 jsc#SLE-9527).
- kexec: add KEXEC_ELF (jsc#PM-1333 jsc#SLE-9255 jsc#SLE-9527).
- new config options:
  - KEXEC_ELF=y (ppc64le only, autoselected)
- commit 2985288
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/fadump: support holes in kernel boot memory area
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: remove RMA_START and RMA_END macros (jsc#PM-1318
  jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: update documentation about option to release
  opalcore (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: consider f/w load area (jsc#PM-1318 jsc#SLE-9099
  jsc#SLE-9176).
- powerpc/opalcore: provide an option to invalidate
  /sys/firmware/opal/core file (jsc#PM-1318 jsc#SLE-9099
  jsc#SLE-9176).
- powerpc/opalcore: export /sys/firmware/opal/core for analysing
  opal crashes (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- new config options:
  - OPAL_CORE=n (ppc64le only)
- powerpc/fadump: update documentation about
  CONFIG_PRESERVE_FA_DUMP (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: add support to preserve crash data on FADUMP
  disabled kernel (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: improve how crashed kernel's memory is reserved
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: consider reserved ranges while releasing memory
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: make crash memory ranges array allocation
  generic (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: process architected register state data provided
  by firmware (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: make use of memblock's bottom up allocation mode
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: Update documentation about OPAL platform support
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: handle invalidation of crashdump and
  re-registraion (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: Warn before processing partial crashdump
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: process the crashdump by exporting it as
  /proc/vmcore (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: support copying multiple kernel boot memory
  regions (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: define OPAL register/un-register callback
  functions (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: reset metadata address during clean up
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: register kernel metadata address with opal
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: improve fadump_reserve_mem() (jsc#PM-1318
  jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: add fadump support on powernv (jsc#PM-1318
  jsc#SLE-9099 jsc#SLE-9176).
- powerpc/opal: add MPIPL interface definitions (jsc#PM-1318
  jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: use FADump instead of fadump for how it is
  pronounced (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- pseries/fadump: move out platform specific support from generic
  code (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- Refresh patches.suse/powerpc-fadump-when-fadump-is-supported-register-the.patch.
- powerpc/fadump: release all the memory above boot memory size
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: add source info while displaying region contents
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- pseries/fadump: define RTAS register/un-register callback
  functions (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- Refresh patches.suse/powerpc-fadump-when-fadump-is-supported-register-the.patch.
- powerpc/fadump: introduce callbacks for platform specific
  operations (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: move rtas specific definitions to platform code
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: use helper functions to reserve/release cpu
  notes buffer (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: Improve fadump documentation (jsc#PM-1318
  jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: declare helper functions in internal header file
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: add helper functions (jsc#PM-1318 jsc#SLE-9099
  jsc#SLE-9176).
- powerpc/fadump: move internal macros/definitions to a new header
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- commit deefc64
* Mon Sep 23 2019 msuchanek@suse.de
- Refresh sorted section.
- Refresh patches.suse/powerpc-dump-kernel-log-before-carrying-out-fadump-o.patch with upstream status.
- commit 9991920
* Wed Sep 18 2019 jroedel@suse.de
- Update config files.
  Disable CONFIG_ARM_SMMU_DISABLE_BYPASS_BY_DEFAULT. Not all drivers are
  ready for this yet, so enabling this config option causes regressions.
  See bsc#1150577 for an example.
- commit 76ac02e
* Mon Sep 16 2019 jroedel@suse.de
- Delete patches.suse/0001-iommu-vt-d-Fix-race-condition-in-add_unmap.patch.
- commit b0363d2
* Mon Sep 16 2019 mkubecek@suse.cz
- Update to 5.3 final
- Eliminated 3 patches
- Refresh configs
  - NF_CONNTRACK_SLP is gone
- commit 6baef36
* Fri Sep 13 2019 tonyj@suse.de
- Move guarded patch into it's own out of tree section
- commit 081b55b
* Fri Sep 13 2019 msuchanek@suse.de
- powerpc/pseries: correctly track irq state in default idle
  (bsc#1150727 ltc#178925).
- commit 97a4665
* Wed Sep 11 2019 mgorman@suse.de
- series.conf: Add note on why pcc-cpufreq patch is being held for evaluation
- commit a514b48
* Tue Sep 10 2019 mkubecek@suse.cz
- Delete patches.suse/netfilter-ip_conntrack_slp.patch (FATE#324143 jsc#SLE-8944 bsc#1127886).
  This veteran out of tree patch is no longer needed since the userspace
  conntrack helper (in conntrack-tools / conntrackd) has reached Factory.
- commit d6f0b71
* Tue Sep 10 2019 mkubecek@suse.cz
- Update and reenable
  patches.suse/Revert-netfilter-conntrack-remove-helper-hook-again.patch
  (FATE#324143 jsc#SLE-8944 bsc#1127886).
- commit 029452e
* Tue Sep 10 2019 msuchanek@suse.de
- powerpc: dump kernel log before carrying out fadump or kdump
  (bsc#1149940 ltc#179958).
- commit 4b365d2
* Tue Sep 10 2019 msuchanek@suse.de
- Refresh patches.suse/net-ibmvnic-Fix-missing-in-__ibmvnic_reset.patch.
- commit 0ebba63
* Tue Sep 10 2019 mkubecek@suse.cz
- series.conf: update sorted section banner
  Make the commit above sorted section less ambiguous. In particular, state
  clearly that patches without Git-commit which cannot be handled by git-sort
  do not belong in it.
- commit 1506bb8
* Tue Sep 10 2019 mkubecek@suse.cz
- series.conf: move unsortable patch out of sorted section
  Patch without Git-commit cannot be sorted so that there is no point having
  it into the sorted section.
- commit f18376e
* Mon Sep  9 2019 msuchanek@suse.de
- net/ibmvnic: Fix missing { in __ibmvnic_reset (bsc#1149652
  ltc#179635).
- commit a3cd2bf
* Mon Sep  9 2019 msuchanek@suse.de
- net/ibmvnic: free reset work of removed device from queue
  (bsc#1149652 ltc#179635).
- commit e64984b
* Mon Sep  9 2019 ailiopoulos@suse.com
- Refresh
  patches.suse/xfs-repair-malformed-inode-items-during-log-recovery.patch.
- commit cbb6da0
* Mon Sep  9 2019 mgorman@suse.de
- config: enable SLAB_FREELIST_HARDENED (bsc#1127808)
  Enable SLAB_FREELIST_HARDENED on all architectures. This obscures the
  free object pointer on a per-cache basis making it more difficult to
  locate kernel objects via exploits probing the cache metadata.
  This change was requested by the upstream openSUSE community to make
  the kernel more resistent to slab freelist attacks. Tests conducted
  by the kernel performance teams confirmed that the performance impact
  is detectable but negligible.
- commit 39e9013
* Mon Sep  9 2019 guillaume.gardet@arm.com
- rpm/constraints.in: lower disk space required for ARM
  With a requirement of 35GB, only 2 slow workers are usable for ARM.
  Current aarch64 build requires 27G and armv6/7 requires 14G.
  Set requirements respectively to 30GB and 20GB.
- commit f84c163
* Mon Sep  9 2019 mkubecek@suse.cz
- Update to 5.3-rc8
- refresh armv6hl configs (IXP4xx drivers no longer visible)
- commit 3dea797
* Mon Sep  9 2019 mkubecek@suse.cz
- config: enable STACKPROTECTOR_STRONG also on armv6hl
  Recently reenabled armv6hl architecture has STACKPROTECTOR_STRONG disabled,
  enable it here as well.
- commit 8c0677d
* Fri Sep  6 2019 msuchanek@suse.de
- powerpc/tm: Fix restoring FP/VMX facility incorrectly on
  interrupts (CVE-2019-15031 bsc#1149713).
- powerpc/tm: Fix FP/VMX unavailable exceptions inside a
  transaction (CVE-2019-15030 bsc#1149713).
- commit ca72e89
* Thu Sep  5 2019 mkubecek@suse.cz
- series.conf: move unsortable patch out of sorted section
- commit 8a360b5
* Thu Sep  5 2019 msuchanek@suse.de
- powerpc/xmon: Add a dump of all XIVE interrupts (bsc#1142019).
- powerpc/xive: Fix dump of XIVE interrupt under pseries
  (bsc#1142019).
- powerpc/xmon: Check for HV mode when dumping XIVE info from OPAL
  (bsc#1142019).
- commit 68e4d5a
* Wed Sep  4 2019 mbenes@suse.cz
- Enable klp-convert patches
  Enable patches.suse/livepatch-create-and-include-UAPI-headers.patch
  Enable and refresh patches.suse/livepatch-modpost-ignore-unresolved-symbols.patch
  Still not in upstream. Submitted though. It seems the final upstream
  version will be a bit different, but we need these two patches for our
  use case.
- commit f385ff2
* Wed Sep  4 2019 mbenes@suse.cz
- Enable patches.suse/livepatch-mark-the-kernel-unsupported-when-disabling.patch
  Still SUSE-specific and still needed.
- commit cd16e71
* Tue Sep  3 2019 msuchanek@suse.de
- powerpc/fadump: when fadump is supported register the fadump
  sysfs files (bsc#1146352).
- commit da248a6
* Tue Sep  3 2019 mkubecek@suse.cz
- config: enable STACKPROTECTOR_STRONG (jsc#SLE-9120 bsc#1130365)
  Enable CONFIG_STACKPROTECTOR_STRONG on all architectures except s390x
  (where the feature is not available). This extends the number of functions
  which are protected by "stack canary" check to catch functions writing past
  their stack frame.
  This change was requested by SUSE security to make our kernels more
  resistant to some types of stack overflow attacks. Tests performed by
  kernel performance teams confirmed that performance impact is acceptable.
- commit 4c43fab
* Tue Sep  3 2019 neilb@suse.com
- Refresh
  patches.suse/0001-NFS-flush-out-dirty-data-on-file-fput.patch.
- Refresh
  patches.suse/0001-NFSv4-don-t-let-hanging-mounts-block-other-mounts.patch.
- NFS: Allow multiple connections to NFSv4.0 servers
  (fate#322786).
- Refresh patches.suse/nfs-set-acl-perm.patch.
- Delete
  patches.suse/0001-NFSv4-handle-EINVAL-from-EXCHANGE_ID-better.patch.
- Delete
  patches.suse/0001-SUNRPC-Allow-creation-of-RPC-clients-with-multiple-c.patch.
- Delete
  patches.suse/0001-sunrpc-include-sup-groups-in-hash.patch.
- Delete
  patches.suse/0002-NFS-Add-a-mount-option-to-specify-number-of-TCP-conn.patch.
- Delete
  patches.suse/0003-NFSv4-Allow-multiple-connections-to-NFSv4.x-x-0-serv.patch.
- Delete
  patches.suse/0004-pNFS-Allow-multiple-connections-to-the-DS.patch.
- Delete
  patches.suse/0005-NFS-Display-the-nconnect-mount-option-if-it-is-set.patch.
- Delete
  patches.suse/0007-SUNRPC-Mask-XIDs-to-prevent-replay-cache-collision.patch.
- Delete patches.suse/NFS-optional-NFSv4_2-fix.patch.
- Delete patches.suse/NFS-optional-NFSv4_2.patch.
- Delete patches.suse/d-lookup-fairness.fix.
- Delete
  patches.suse/getcwd-close-race-with-d_move-called-by-lustre.patch.
- Delete
  patches.suse/sunrpc-cache-handle-missing-listeners-better.patch.
- Delete
  patches.suse/vfs-use-synchronize_rcu_expedited-in-namespace_unlock.patch.
- commit 4685373
* Mon Sep  2 2019 mkubecek@suse.cz
- Update to 5.3-rc7
- Refresh configs
  - IXP4xx SoC drivers not visible
  - gcc 9.2.1
- commit 9bff5f9
* Sun Sep  1 2019 mkubecek@suse.cz
- config: armv7hl: Enable cadence watchdog
  CONFIG_CADENCE_WATCHDOG is required for Zynq-7000 based MIYR Zturn board.
- commit c4cbe5e
* Fri Aug 30 2019 jthumshirn@suse.de
- Delete patches.suse/nvdimm-testing-provide-SZ_4G.patch.
  The patch was SLE15{,-SP1} specific to provide a constant already
  contained in kernel 5.3.
- commit 4ea3f92
* Fri Aug 30 2019 dmueller@suse.com
- config.conf: Update ARMv6 config files
- commit c17167d
* Fri Aug 30 2019 dmueller@suse.com
- config.conf: Reenable ARMv7 config for Kernel 5.3
  All modules plus errata's enabled. Reused other
  values from x86_64 update.
- commit b1c627e
* Fri Aug 30 2019 tzimmermann@suse.de
- Add "drm/ttm: Remove warning about inconsistent mapping information"
  This patch removes a warning that causes bug reports unnecessarily.
- commit 4a7bc21
* Fri Aug 30 2019 tzimmermann@suse.de
- Add "Reserve 64MiB of CMA for RPi3's VC4"
  Taking this patch from SLE15-SP1 with updates for v5.3. Enables display
  when booting RPi3 installer.
- commit 9fab830
* Fri Aug 30 2019 tzimmermann@suse.de
- Remove "drm/msm: fix address space warning"
  The respective code was removed in v4.20.
- commit 3d7e3d1
* Fri Aug 30 2019 jslaby@suse.cz
- Refresh
  patches.suse/0003-kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
  Add more placeholders to device.h. In particular, to structs bus_type,
  device_driver, class, and device.
- commit c4220a5
* Thu Aug 29 2019 msuchanek@suse.de
- scsi: cxlflash: Mark expected switch fall-throughs
  (bsc#1148868).
- commit ea514bf
* Wed Aug 28 2019 tiwai@suse.de
- mwifiex: Fix three heap overflow at
  parsing element in cfg80211_ap_settings
  (CVE-2019-14814,bsc#1146512,CVE-2019-14815,bsc#1146514,CVE-2019-14816,bsc#1146516).
- commit 528fd68
* Wed Aug 28 2019 mkubecek@suse.cz
- supported.conf: drop obsolete entries
  Drop supported.conf entries not matching any module built on any
  supported architecture. This commit mostly drops entries for modules
  built in master branch but not SLE15-SP2. Moved and no longer existing
  modules were handled in previous commits in master branch.
- commit 97fd102
* Wed Aug 28 2019 mkubecek@suse.cz
- supported.conf: mark more core networking modules supported
  Two more netfilter modules and one more *_diag should be supported too.
- commit bee2dd8
* Wed Aug 28 2019 mkubecek@suse.cz
- supported.conf: update status of some networking core modules
  This marks new networking modules which should be supported as such; it is
  mostly netfilter and traffic control modules which have been following the
  "support all of them" policy for some time.
- commit 65e1131
* Wed Aug 28 2019 mkubecek@suse.cz
- supported.conf: obsolete paths cleanup
  Update paths for existing modules which were moved, clean up duplicate
  entries and drop entries for modules which no longer exist (either not
  built any more or built into the image now).
- commit 3bb142a
* Wed Aug 28 2019 msuchanek@suse.de
- powerpc/64s: support nospectre_v2 cmdline option (bsc#1131107).
- commit 9cef94b
* Tue Aug 27 2019 mkubecek@suse.cz
- series.conf: add section for SUSE kabi padding patches
  Leave "kABI consistency patches" only for patches.kabi/*
- commit 81c3a75
* Tue Aug 27 2019 mkubecek@suse.cz
- series.conf: move unguarded patches from review section
- commit 6de2b58
* Tue Aug 27 2019 mkubecek@suse.cz
- rpm: raise required disk space for binary packages
  Current disk space constraints (10 GB on s390x, 25 GB on other
  architectures) no longer suffice for 5.3 kernel builds. The statistics
  show ~30 GB of disk consumption on x86_64 and ~11 GB on s390x so raise
  the constraints to 35 GB in general and 14 GB on s390x.
- commit 527cb66
* Tue Aug 27 2019 mhocko@suse.com
- enable and refresh
  patches.suse/memcg-deprecate-memory.force_empty-knob.patch.
- enable patches.suse/mm-inform-about-enabling-mirrored-memory.patch
  both patches are minimal and still useful to identify future
  supportability problems.
- commit 93500e8
* Tue Aug 27 2019 jack@suse.cz
- Update patches.suse/ext4-unsupported-features.patch
  (fate#317919, SLE-8615).
- commit 3b1bc66
* Tue Aug 27 2019 jack@suse.cz
- Refresh and enable valid patches from SLE15-SP1:
- Refresh patches.suse/ext4-dont-warn-when-enabling-DAX.patch.
- Refresh patches.suse/ext4-unsupported-features.patch.
- Refresh patches.suse/unsupported-features.patch.
- commit 9ef1a75
* Tue Aug 27 2019 jack@suse.cz
- Remove patches obsoleted by upstream changes:
- Delete
  patches.suse/arch-powerpc-dax-Add-MAP_SYNC-mmap-flag.patch.
- Delete
  patches.suse/block-Don-t-revalidate-bdev-of-hidden-gendisk.patch.
- Delete patches.suse/fs-speedup-clean-bdev-aliases.patch.
- Delete
  patches.suse/mm-migrate-Fix-reference-check-race-between-__find_get_block-and-migration.patch.
- Delete patches.suse/powerpc-Add-pmem.h.patch.
- commit 21008fb
* Tue Aug 27 2019 bpoirier@suse.com
- Refresh patches.suse/qlge-Deduplicate-lbq_buf_size.patch.
- Refresh
  patches.suse/qlge-Deduplicate-rx-buffer-queue-management.patch.
- Refresh patches.suse/qlge-Remove-bq_desc.maplen.patch.
- Refresh
  patches.suse/qlge-Remove-useless-dma-synchronization-calls.patch.
  Reenable qlge patch series for bsc#1106061
- commit b2971c6
* Mon Aug 26 2019 mgorman@suse.de
- sched: Further improve spurious CPU_IDLE active migrations
  (bnc# 986383).
- Update
  patches.suse/cpufreq-ondemand-set-default-up_threshold-to-30-on-multi-core-systems.patch
  (bnc#464461,bnc#981838,bnc#1064414,bnc#1144943).
- Refresh
  patches.suse/mm-Warn-users-of-node-memory-hot-remove-if-the-memory-ratio-is-a-high-risk.patch.
- Update
  patches.suse/sched-Fix-up-proc-sched_debug-to-print-only-runnable-tasks-again.patch
  (none, should be posted upstream).
- Update
  patches.suse/sched-fair-Enable-SIS_AVG_CPU-by-default.patch
  (bsc#1061593,bsc#1148030).
- Refresh
  patches.suse/sched-topology-Improve-load-balancing-on-AMD-EPYC.patch.
- Delete
  patches.suse/0001-Revert-mm-vmacache-optimize-overflow-system-wide-flu.patch.
- Delete
  patches.suse/0001-sched-wake_q-Reduce-reference-counting-for-special-u.patch.
- Delete
  patches.suse/cpufreq-intel_pstate-Ramp-up-frequency-faster-when-utilisation-reaches-setpoint.patch.
- Delete
  patches.suse/cpufreq-intel_pstate-Temporarily-boost-P-state-when-exiting-from-idle.patch.
- Delete
  patches.suse/cpufreq-intel_pstate-Update-setpoint-for-unspecified-ACPI-profile.patch.
- Delete
  patches.suse/cpufreq-intel_pstate-Use-load-based-policy-by-default-but-allow-PID-to-be-used.patch.
- Delete
  patches.suse/mm-Adjust-watermark-boost-factor-tunable.patch.
- Delete
  patches.suse/mm-migrate-Fix-reference-check-race-between-__find_get_block-and-migration.patch.
- Delete
  patches.suse/mm-page_alloc.c-use-a-single-function-to-free-page.patch.
- commit 9de058d
* Mon Aug 26 2019 jgross@suse.com
- usb: Introduce Xen pvUSB frontend (xen hcd) (fate#315712).
- Update config files.
- usb: Add Xen pvUSB protocol description (fate#315712).
- commit b32b2bd
* Mon Aug 26 2019 mhocko@suse.com
- Delete
  patches.suse/mm-sparse-do-not-swamp-log-with-huge-vmemmap-allocat-fix.patch.
  not applicable as explained in the patch description.
- commit fbed5c2
* Mon Aug 26 2019 mhocko@suse.com
- Delete
  patches.suse/mm-__init_single_page-do-not-zero-core-struct-pages.patch.
  Not applicable because it was a fallout of a partial backport as noted
  in the changelog.
- commit 1e8b220
* Mon Aug 26 2019 mhocko@suse.com
- Delete
  patches.suse/0001-memory_hotplug-add-missing-newlines-to-debugging-out.patch.
  merged as 1ecc07fd0a6d350bbf4dc176e0d654661b304a30 in 5.0
- commit 5aa2923
* Mon Aug 26 2019 mhocko@suse.com
- Delete
  patches.suse/0001-x86-speculation-Prepare-entry-code-for-Spectre-v1-sw.patch.
- Delete
  patches.suse/0002-x86-speculation-Enable-Spectre-v1-swapgs-mitigations.patch.
- Delete
  patches.suse/x86-speculation-swapgs-exclude-ATOMs-from-speculating-through-SWAPGS.patch.
  swapgs fixes have been merged in 5.3-rc3.
- commit 24d8d43
* Mon Aug 26 2019 oneukum@suse.com
- Delete
  patches.suse/0049-commit-833689044e13a3fb8c6c03ad868375670d97010b.patch.
  No longer needed in SP2
- commit 13a1350
* Mon Aug 26 2019 oneukum@suse.com
- Refresh
  patches.suse/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
  Shifted kABI placeholders back where they belong
- commit 2d913e0
* Mon Aug 26 2019 tiwai@suse.de
- Update reference for ath6kl fix (CVE-2019-15290,bsc#1146543).
- commit b08d3d5
* Mon Aug 26 2019 tiwai@suse.de
- Fix a NULL-ptr-deref bug in ath6kl_usb_alloc_urb_from_pipe
  (CVE-2019-15098,bsc#1146378).
- Fix a NULL-ptr-deref bug in ath10k_usb_alloc_urb_from_pipe
  (CVE-2019-15099,bsc#1146368).
- commit 758e216
* Mon Aug 26 2019 jslaby@suse.cz
- Delete patches.suse/tty-make-R3964-line-discipline-fail.patch.
  We no longer build (and support) R3964.
- commit 85b2e98
* Mon Aug 26 2019 jslaby@suse.cz
- Delete
  patches.suse/mlxsw-spectrum-Forbid-linking-to-devices-fix.patch.
  This was a fix for a bad commit in 4.12.* stable.
- commit e8f9b29
* Mon Aug 26 2019 jslaby@suse.cz
- Refresh
  patches.suse/0003-kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
  Enable it and add one more placeholder to mm_context_t.
- commit 00e7e80
* Mon Aug 26 2019 jslaby@suse.cz
- Delete
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Delete
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Delete
  patches.suse/0003-x86-idle-Control-Indirect-Branch-Speculation-in-idle.patch.
- Delete
  patches.suse/0004-x86-enter-Create-macros-to-restrict-unrestrict-Indir.patch.
- Delete
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- Delete patches.suse/IBRS-forbid-shooting-in-foot.patch.
- Delete patches.suse/do-not-default-to-ibrs-on-skl.patch.
  Drop IBRS as we disabled it later anyway.
- commit c03b8fa
* Mon Aug 26 2019 bpoirier@suse.com
- Fix a double free bug in rsi_91x_deinit (bnc#1147116
  CVE-2019-15504).
- commit 8ae43d1
* Sun Aug 25 2019 mkubecek@suse.cz
- Update to 5.3-rc6
- commit 2831011
* Sun Aug 25 2019 ailiopoulos@suse.com
- Delete
  patches.suse/0001-module-warn-if-module-init-probe-takes-long.patch.
- commit f81e033
* Sun Aug 25 2019 ailiopoulos@suse.com
- Delete
  patches.suse/xfs-add-option-to-mount-with-barrier-0-or-barrier-1.patch.
  Since v4.10-rc1 xfs has deprecated all options that explicitly control
  barriers with commit 4cf4573d899c ("xfs: deprecate barrier/nobarrier
  mount option").
  Drop backwards-compat patch for parsing the obsolete barrier=[0|1]
  syntax of the option, since supporting this causes more confusion and
  gives the false impression that disabling barriers is still a
  possibility.
- commit 0ac0c38
* Sun Aug 25 2019 ailiopoulos@suse.com
- xfs: remove experimental tag for dax support (FATE#324503).
- commit f13a4a4
* Sun Aug 25 2019 ailiopoulos@suse.com
- Delete patches.suse/xfs-unsupported-features.patch.
  Drop unsupported features patch which was marking reflink and rmap
  as unsupported. The experimental tags were dropped for both features
  and thus marked stable upstream on v4.16-rc1, with the two following
  commits:
  commit 1e369b0e199b ("xfs: remove experimental tag for reflinks")
  commit 76883f7988e6 ("xfs: remove experimental tag for reverse mapping")
  While we follow upstream here, SLE15.2 xfsprogs/mkfs.xfs will not be
  switching on reflink/rmap by default for newly created filesystems.
  Regarding dax, contrary to upstream we have been supporting it for a
  while and removing the experimental tag, and we will continue doing so.
  The related patch for DAX will be posted as a separate commit for
  clarity.
- commit f84ab02
* Fri Aug 23 2019 ohering@suse.de
- remove stale SLE15-SP1 patches, keep a pci-hyperv patch (bsc#1142701)
- commit b0bbc9a
* Fri Aug 23 2019 msuchanek@suse.de
- Fix livepatch build.
- commit b7e78e8
* Fri Aug 23 2019 tiwai@suse.de
- Move a PCI fix patch to the-stairway-to-heaven section
- commit 3c94e42
* Fri Aug 23 2019 tiwai@suse.de
- Drop downstream DRM mgag200 patches
  Some of them are no longer applicable, some are invalid, and the rest
  won't be taken by upstream.  Let's rip them off.
- commit 1108d1d
* Fri Aug 23 2019 mbrugger@suse.com
- Delete patches.suse/irq-stub-affinity.patch.
- commit f5fe3d1
* Fri Aug 23 2019 mkubecek@suse.cz
- series.conf: move submitted patch out of sorted section
  Move
  patches.suse/ibmveth-Update-ethtool-settings-to-reflect-virtual-p.patch
  from sorted section to "soon to be mainline" section.
  For SLE15-SP2, we only want patches which git_sort can do something with in
  sorted section. Moreover, upstream discussion suggests that this patch is
  unlikely to be accepted in this form.
- commit 46df5db
* Fri Aug 23 2019 msuchanek@suse.de
- Remove obsolete build fix.
  Delete patches.suse/Fix-build-error-in-drmem.c.patch.
- commit 39eb823
* Fri Aug 23 2019 msuchanek@suse.de
- Restore ibmveth patch.
  Refresh patches.suse/ibmveth-Update-ethtool-settings-to-reflect-virtual-p.patch.
- commit d129c25
* Fri Aug 23 2019 msuchanek@suse.de
- Remove obsolete kABI padding in paca.
  Delete patches.suse/powerpc-KABI-add-aux_ptr-to-hole-in-paca_struct-to-e.patch.
- commit ae6527d
* Fri Aug 23 2019 msuchanek@suse.de
- Restore s390 crash KMP export.
- commit 2850611
* Fri Aug 23 2019 msuchanek@suse.de
- Delete obsolete pkey and bcm2835 patches.
- commit 7f76e58
* Fri Aug 23 2019 hare@suse.de
- Delete
  patches.suse/qla2xxx-Enable-T10-DIF-with-FC-NVMe-enabled.patch.
- Delete patches.suse/s390-sles15-03-01-rwlock.patch.
- Delete
  patches.suse/scsi-qla2xxx-do-not-crash-on-uninitialized-pool-list.patch.
- Delete
  patches.suse/scsi-qla2xxx-qla2x00_alloc_fw_dump-set-ha-eft.patch.
- commit 9c5d24e
* Fri Aug 23 2019 hare@suse.de
- Refresh patches.suse/md-display-timeout-error.patch.
- commit 83d69fe
* Fri Aug 23 2019 hare@suse.de
- Delete patches.suse/nvme-multipath-round-robin-I-O-policy.patch.
- commit cb248a3
* Fri Aug 23 2019 hare@suse.de
- Delete patches.suse/qla2xxx-always-allocate-qla_tgt_wq.patch.
- commit 7005228
* Fri Aug 23 2019 hare@suse.de
- Delete
  patches.suse/block-Fix-a-NULL-pointer-dereference-in-generic_make.patch.
- commit 5284ba5
* Fri Aug 23 2019 hare@suse.de
- Delete
  patches.suse/dasd_fba-Display-00000000-for-zero-page-when-dumping.patch.
- Delete patches.suse/s390-sles15-message-catalog.patch.
- commit 6885922
* Fri Aug 23 2019 tiwai@suse.de
- Revive some downstream DRM patches and delete obsoleted patches
  Refreshed for 5.3:
  patches.suse/drm-i915-Disable-tv-output-on-i9x5gm
  patches.suse/drm-mgag200-Implement-basic-PM-support
  Deleted, as no longer needed for 5.3:
  patches.suse/HID-quirks-fix-support-for-Apple-Magic-Keyboards.patch
  patches.suse/Input-synaptics-Add-intertouch-blacklist-for-Thinkpa.patch
  patches.suse/drm-i915-CVE-2018-20669-access-check.patch
  patches.suse/kernel-Export-mm_access.patch
  patches.suse/mmc-version-check-printk-downgrade
  patches.suse/tpm-Downgrade-error-level
  patches.suse/tty-Don-t-return-EAGAIN-in-blocking-read.patch
- commit d9bc0ec
* Fri Aug 23 2019 mkubecek@suse.cz
- Delete
  patches.suse/irda-Fix-memory-leak-caused-by-repeated-binds-of-ird.patch
  patches.suse/irda-Only-insert-new-objects-into-the-global-databas.patch
  These are CVE fixes for a driver dropped in mainline 4.17.
- commit 2f68f7e
* Fri Aug 23 2019 mkubecek@suse.cz
- import non-mainline SLE15-SP1 patches
  Import all SLE15-SP1 (kernel-source commit 0181a93c80e7) patches which are
  not in mainline yet (as of commit 59c36bc8d377). All patches are added at
  the end of series.conf with a guard indicating who is/was responsible for
  them (using first of From:, Signed-off-by:, Acked-by:, Reviewed-by: and
  commiter with address containing '@suse.' or '@novell.').
  Some of non-mainline patches in SLE15-SP1 branch match existing SLE15-SP2
  patches. For these, SLE15-SP2 version (inherited from master branch) is
  preserved.
  This commit has no effect on expanded tree.
- commit ec8941d
* Fri Aug 23 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Fix kernel-livepatch description typo.
- commit 36acf91
* Thu Aug 22 2019 msuchanek@suse.de
- Pull packaging cleanup from mkubecek.
- Parametrize kgraft vs livepatch.
- commit 16f6816
* Thu Aug 22 2019 msuchanek@suse.de
- rpm/config.sh: Enable livepatch.
- commit e001776
* Thu Aug 22 2019 mkubecek@suse.cz
- config: restore correct PHYSICAL_START and PHYSICAL_ALIGN on x86_64
  These were already fixed in master by kernel-source commit baa2434a5ab6 but
  old (and wrong) values were restored by merge of SLE15-SP1 config. Fix them
  also in SLE15-SP2 now.
- commit 9b6f95a
* Thu Aug 22 2019 mkubecek@suse.cz
- config: update from SLE15-SP2
  In general, we want features and drivers from SLE also in openSUSE unless
  we have a good reason not to. Enable most config options which were
  disabled in master but enabled in SLE15-SP2 (inherited from SLE15-SP1).
- commit 769684a
* Wed Aug 21 2019 msuchanek@suse.de
- powerpc/rtas: use device model APIs and serialization during
  LPM (bsc#1144123 ltc#178840).
- commit 9f79b99
* Wed Aug 21 2019 mkubecek@suse.cz
- series.conf: reorganize sections
  With ~40 patches in master branch, we have accumulated way too many
  sections in series.conf, some of them being very specific. While new SLE
  and Leap branches are going to have more patches, vast majority of them is
  going to end up in the sorted section (e.g. less than 1%% of SLE15-SP1
  patches are neither sorted nor stable baskports right now - and that
  includes quite a few which would actually belong into the sorted section
  but are left outside for historical reasons).
  After the reorganization, series.conf is ordered like this:
  - stable backports (patches.kernel.org/*)
  - tweaks applied to vanilla (patches.rpmify/*)
  - sorted section (not in master)
  - unsorted patches expected to get into mainline soon
  - permanent and longterm non-upstream patches
  - kabi hacks (not in master)
  This commit has no effect on expanded tree.
- commit 8ac1895
* Wed Aug 21 2019 mkubecek@suse.cz
- series.conf: cleanup
  Only whitespace and comments, no efect on expanded tree.
- commit bf21808
* Tue Aug 20 2019 mkubecek@suse.cz
- config: import SLE15-SP1 configs
  Replace configs inherited from master branch by proper SLE ones. With few
  obvious exceptions, the initial SLE15-SP2 configs were created using these
  rules (for each option, use first rule which applies):
  - use value explicitly changed with reference to a feature or a bug
  - use value from SLE15-SP1 if the option exists there
  - use value from master if the option exists there
  - use upstream default
  The configs will need review by people responsible for specific kernel
  subsystems and architectures.
  Also update supported.conf with new modules:
  - add intel_pmc_core_pltdrv as unsupported
  - fix cfb{copyarea,fillrect,imgblt} path and mark "+base" as virtio-gpu
    depends on them
- commit dded633
* Mon Aug 19 2019 bp@suse.de
- Update config files.
  As per https://jira.suse.com/browse/SLE-7041
  Factory first!
- commit 126cef1
* Mon Aug 19 2019 mkubecek@suse.cz
- Update README.BRANCH
- drop Jeff Mahoney (inherited from master)
- add Miroslav Benes as comaintainer
- drop misleading paragraph left from master branch
- commit 4300e4e
* Mon Aug 19 2019 mkubecek@suse.cz
- Update to 5.3-rc5
- Refresh configs
  - RDMA_SIW available on i386 (=m)
  - clean up unavailable options
- commit cadbe00
* Sun Aug 18 2019 afaerber@suse.de
- config: arm64: Enable I2C_IMX (boo#1146026)
  Needed for Google Coral board.
- commit 8803b04
* Thu Aug 15 2019 msuchanek@suse.de
- Revert "Workaround gcc regression on ppc64 (bko#204125)."
  This reverts commit 8b84d1d46ff90146bb6ba5b760a54ddd87a1a680.
  Works for me 5.3-rc4-65-g329120423947
- commit d8f9e6c
* Mon Aug 12 2019 msuchanek@suse.de
- config.conf: syms should not depend on kernel-zfcpdump
  Kernel-zfcpdump is not modular so kernel-zfcpdump-devel does not make
  sense and is not built. kernel-syms cannot depend on it.
- commit 473ac28
* Mon Aug 12 2019 msuchanek@suse.de
- rpm/mkspec: Correct tarball URL for rc kernels.
- commit c4ef18d
* Sun Aug 11 2019 mkubecek@suse.cz
- config: refresh with gcc7
  Unlike master branch, SLE15-SP2 is supposed to be built with gcc7. At
  the moment, this only makes a significant difference on aarch64 (which
  we already refreshed with gcc 7.4.0 for this reason) but let's refresh
  all configs to make it more visible.
- commit 67e1879
* Sun Aug 11 2019 mkubecek@suse.cz
- Update to 5.3-rc4
- Refresh
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
- commit 5402233
* Fri Aug  9 2019 msuchanek@suse.de
- rpm/config.sh: Enable building DTBs.
- commit 7de292a
* Fri Aug  9 2019 msuchanek@suse.de
- rpm/mkspec: Make building DTBs optional.
- commit 7c057c8
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: fix supported modules depending on unsupported on non-x86_64 architectures
  Some more "unsupported module needed by supported one" errors were reported
  on aarch64 and ppc64le.
- commit 6b609de
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: drop obsolete entry for hyperv_fb
  The module moved to a different directory, the obsolete entry causes
  file conflict betwen kernel-default and kernel-default-extra.
- commit 6b112e5
* Fri Aug  9 2019 msuchanek@suse.de
- rpm/modflist: Simplify compression support.
- commit fd135a6
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: close with respect to dependencies
  Modules which some supported module depends on must be supported as well.
  Also drop obsolete entries for rtsx_pci and rtsx_usb which were moved
  between 4.12 and 5.3.
- commit b781c36
* Fri Aug  9 2019 mkubecek@suse.cz
- rpm: support compressed modules
  Some of our scripts and scriptlets in rpm/ do not expect module files not
  ending with ".ko" which currently leads to failure in preuninstall
  scriptlet of cluster-md-kmp-default (and probably also other subpackages).
  Let those which could be run on compressed module files recognize ".ko.xz"
  in addition to ".ko".
- commit 18fcdff
* Fri Aug  9 2019 msuchanek@suse.de
- Bring back MODVERDIR to Makefile.modpost (bsc#1066369).
- commit 6cc69f5
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: sort again
  Make the order compatible with scripts/supported-conf-fixup (LC_ALL=C).
- commit 4a4b5dd
* Fri Aug  9 2019 msuchanek@suse.de
- supported.conf: Sort alphabetically, align comments.
- commit 5189766
* Fri Aug  9 2019 mkubecek@suse.cz
- series.conf: cleanup
  Move patches.suse/0001-oracleasm-4.0-compat-changes.patch
  to more appropriate place.
- commit 2080902
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: drop extensions
  To make things more consistent, drop all ".ko" extensions.
- commit 398461b
* Fri Aug  9 2019 mkubecek@suse.cz
- Update patches.suse/supported-flag.
  Fix ReST table.
- commit 0692bf4
* Thu Aug  8 2019 msuchanek@suse.de
- Use upstream TAINT_AUX for TAINT_EXTERNAL_SUPPORT.
  Refresh patches.suse/supported-flag.
- commit a4999e0
* Thu Aug  8 2019 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: add dm-crypt for building with cryptsetup
  Co-Authored-By: Adam Spiers <aspiers@suse.com>
- commit 7cf5b9e
* Thu Aug  8 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Enable supported.conf check.
- commit 96adf4d
* Thu Aug  8 2019 msuchanek@suse.de
- Update arm64 config files.
- commit 1e7a157
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: add missing entries for all architectures
  As list of built modules depends on architecture, we must also add entries
  for modules which are not built (or do not even exist) on x86_64 but are
  built on other architectures (aarch64, ppc64le, s390x).
- commit 8f74082
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: add missing entries
  Add all modules currently built but not listed in supported.conf.
  Another update will be necessary once we replace configs inherited from
  master with true SLE15-SP2 configs. This is also why entries for modules
  not built are left in the file for now.
- commit 0f5033c
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: sort
  Also remove one commented out line.
- commit b539157
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: cleanup
  Remove duplicate and shadowed entries.
- commit 25e91ec
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: update from SLE15-SP1
  Differences from current SLE15-SP1 supported.conf:
  - f71808e_wdt and it87_wdt supported (jdelvare)
  - bpfilter marked +base (tiwai, bsc#1106751)
  - unified indentation
- commit 02162e4
* Wed Aug  7 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: support partial rt debug config.
- commit af37821
* Wed Aug  7 2019 msuchanek@suse.de
- rpm/config.sh: Update OBS build project to 15 SP1.
- commit 03e63ed
* Wed Aug  7 2019 afaerber@suse.de
- config: arm64: Update to 5.3-rc3
- commit f1f49f3
* Wed Aug  7 2019 mkubecek@suse.cz
- config: disable preemption
  Full update to configs based on SLE15-SP1 will follow later.
- commit 84c63fb
* Wed Aug  7 2019 afaerber@suse.de
- config: Enable SENSORS_GPIO_FAN for all of Arm (boo#1144723)
  We already had it for armv6hl but were lacking it on arm64.
  Add it on armv7hl for consistency while at it.
- commit 607ebeb
* Wed Aug  7 2019 mkubecek@suse.cz
- series.conf: add sorted section
  Also mark kabi section on top explicitly as intended only for kabi patches
  related to stable backports and add kabi section for the rest at the end of
  the file (so that these can be dropped easily).
- commit 3df2daa
* Wed Aug  7 2019 msuchanek@suse.de
- README.BRANCH: Change branch name to 15 SP2
- commit 5135437
* Wed Aug  7 2019 msuchanek@suse.de
- config.conf: Remove non-SLE configs.
- Update config files with SLE product number.
- commit f002b36
* Wed Aug  7 2019 msuchanek@suse.de
- rpm/config.sh: Update to 15 SP2
  - update IBS project
  - update bugzilla product
  - sort series
- commit 41fafbc
* Mon Aug  5 2019 mkubecek@suse.cz
- Update to 5.3-rc3
- Eliminated 1 patch
- Refresh
  - patches.suse/supported-flag
  - patches.suse/supported-flag-external
- Refresh configs
- commit 571863b
* Fri Aug  2 2019 bwiedemann@suse.de
- kernel-binary: Drop .kernel-binary.spec.buildenv (boo#1154578).
  Without this patch,
  /usr/src/linux-@VERSION@-@RELEASE_SHORT@-obj/x86_64/vanilla/.kernel-binary.spec.buildenv
  contained rpm %%_smp_mflags in a line like
  export MAKE_ARGS=" --output-sync -j4"
  This made it hard to produce bit-identical builds.
- commit 789d131
* Thu Aug  1 2019 mkubecek@suse.cz
- config: refresh x86_64/default
  With HBMC_AM654 disabled, nothing selects MULTIPLEXER any more.
- commit 07a1a73
* Wed Jul 31 2019 jdelvare@suse.de
- Update config files: CONFIG_HBMC_AM654=n
  The TI AM654 is an ARM64 SoC, so disable the driver on all other
  architectures.
- commit 042f63f
* Tue Jul 30 2019 schwab@suse.de
- packaging: add support for riscv64
- commit c2885ea
* Sun Jul 28 2019 mkubecek@suse.cz
- Update to 5.3-rc2
- Eliminated 1 patch
  - patches.suse/dma-mapping-use-dma_get_mask-in-dma_addressing_limit.patch
- Refresh
  - patches.suse/netfilter-ip_conntrack_slp.patch
- Config changes
  - NF_TABLES_BRIDGE=m (was =y)
- commit fc5ebf3
* Sat Jul 27 2019 msuchanek@suse.de
- rpm/macros.kernel-source: KMPs should depend on kmod-compat to build.
  kmod-compat links are used in find-provides.ksyms, find-requires.ksyms,
  and find-supplements.ksyms in rpm-config-SUSE.
- commit f97ca49
* Sat Jul 27 2019 msuchanek@suse.de
- scripts/run_oldconfig.sh: Fix update-vanilla
  When CC is set we want to use it for native only. Cross-compilation
  still needs the crosscompilers.
- commit 3b9fcdb
* Wed Jul 24 2019 msuchanek@suse.de
- dma-mapping: use dma_get_mask in dma_addressing_limited
  (https://lore.kernel.org/lkml/cda1952f-0265-e055-a3ce-237c59069a3f@suse.com/T/#u).
- commit c584343
* Wed Jul 24 2019 msuchanek@suse.de
- scripts/arch-symbols: add missing link.
- commit ee7c635
* Tue Jul 23 2019 tiwai@suse.de
- rpm/config.sh: enable kernel module compression (bsc#1135854)
- commit b333e24
* Tue Jul 23 2019 tiwai@suse.de
- Add kernel module compression support (bsc#1135854)
  For enabling the kernel module compress, add the item COMPRESS_MODULES="xz"
  in config.sh, then mkspec will pass it to the spec file.
- commit cdf5806
* Tue Jul 23 2019 msuchanek@suse.de
- Workaround gcc regression on ppc64 (bko#204125).
- commit 8b84d1d
* Tue Jul 23 2019 msuchanek@suse.de
- config.conf: Add ppc64 kvmsmall config (bsc#1137361).
- Remove superfluous i2c drivers from ppc64 config
  - CONFIG_I2C_ALGOPCA=m
  - CONFIG_I2C_AMD8111=m
  - CONFIG_I2C_CBUS_GPIO=m
  - CONFIG_I2C_DESIGNWARE_CORE=y
  - CONFIG_I2C_DESIGNWARE_PLATFORM=y
  - CONFIG_I2C_DESIGNWARE_PCI=m
  - CONFIG_I2C_OCORES=m
  - CONFIG_I2C_PCA_PLATFORM=m
  Can't get rid of i2c in kvmsmall anyway but at least the DW i2c is gone.
- commit 3d0102c
* Mon Jul 22 2019 jeffm@suse.com
- config: enable PPPoE for kvmsmall (bsc#1133945).
- commit 39d218a
* Mon Jul 22 2019 jeffm@suse.com
- config: remove unnecessary drivers from kvmsmall
  The initial merge was incomplete and needed revisiting, which didn't really
  happen.  Since then, new options have been added and not removed from
  kvmsmall, leading to grow in size.
  This commit uses the following blacklist:
  _(BT|CHARGER|CHROMEOS|CROS|DVB|DW|EDAC|FPGA|GPIO|GNSS|HID|INFINIBAND|IR|JOYSTICK|LEDS|MFD|PINCTRL|REGULATOR|RTC|SENSORS|SND_SOC|STAGING|TOUCHSCREEN|VIDEO|XEN|XILINX)[_=]
  ... along with some manual removal of NET_VENDORs with no relevant drivers.
- commit e850d85
* Mon Jul 22 2019 mkubecek@suse.cz
- rpm/klp-symbols: update to work with kernel >= 5.3
  Since mainline commit b7dca6dd1e59 ("kbuild: create *.mod with full
  directory path and remove MODVERDIR") in v5.3-rc1, *.mod files are created
  in the build tree rather than in a single directory .tmp_versions
  ($MODVERDIR). They also do not provide path to the *.ko module file on
  their first line as the path is the same (except for the suffix).
  Update klp-symbols script to handle this new layout and format of *.mod
  files to fix build of 5.3-rc1 and newer kernel.
  Note: this is a quick band-aid to fix master branch build without risk of
  breaking any other branch. A more proper cleanup will follow.
- commit c32f8e7
* Mon Jul 22 2019 mkubecek@suse.cz
- Update to 5.3-rc1
- Eliminated 89 patches (83 stable, 6 other)
- ARM configs need update
- Refresh
  patches.suse/btrfs-8447-serialize-subvolume-mounts-with-potentially-mi.patch
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/netfilter-ip_conntrack_slp.patch
  patches.suse/rpm-kernel-config
  patches.suse/supported-flag
  patches.suse/vfs-add-super_operations-get_inode_dev
- replace patches.rpmify/BPF-UMH-do-not-detect-if-compiler-can-link-userspace.patch
  with patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch
- New config options:
  - General setup
  - HEADER_TEST=y
  - KERNEL_HEADER_TEST=y
  - PREEMPT_LL=n
  - UCLAMP_TASK=y
  - UCLAMP_BUCKETS_COUNT=5
  - Processor type and features
  - ACRN_GUEST=y
  - LEGACY_VSYSCALL_XONLY=y
  - IO Schedulers
  - BFQ_CGROUP_DEBUG=n (=y in */debug)
  - Networking
  - NFT_SYNPROXY=m
  - NFT_BRIDGE_META=m
  - NF_CONNTRACK_BRIDGE=m
  - NET_ACT_MPLS=m
  - NET_ACT_CTINFO=m
  - NET_ACT_CT=m
  - BT_HCIBTUSB_MTK=y
  - GVE=m
  - MLX5_FPGA_IPSEC=y
  - MLX5_FPGA_TLS=y
  - MLX5_TLS=y
  - STMMAC_SELFTESTS=n
  - XILINX_AXI_EMAC=m
  - SFP=m
  - NXP_TJA11XX_PHY=m
  - PHY_MIXEL_MIPI_DPHY=m
  - File systems
  - UBIFS_FS_ZSTD=y
  - SUNRPC_DISABLE_INSECURE_ENCTYPES=n
  - CEPH_FS_SECURITY_LABEL=y
  - Generic driver options
  - FW_LOADER_COMPRESS=y
  - Storage
  - SCSI_FDOMAIN_PCI=m
  - SCSI_FDOMAIN_ISA=n
  - PCMCIA_FDOMAIN=n
  - Input
  - KEYBOARD_APPLESPI=m
  - Power supply and hardware monitoring
  - POWER_SUPPLY_HWMON=y
  - CHARGER_WILCO=m
  - SENSORS_IRPS5401=m
  - SENSORS_PXE1610=m
  - REGULATOR_ARIZONA_LDO1=m
  - REGULATOR_ARIZONA_MICSUPP=m
  - REGULATOR_SLG51000=m
  - Multimedia
  - DVB_USB_CXUSB_ANALOG=y
  - VIDEO_TDA1997X=m
  - VIDEO_TLV320AIC23B=m
  - VIDEO_ADV7180=m
  - VIDEO_ADV7183=m
  - VIDEO_ADV7604=m
  - VIDEO_ADV7604_CEC=y
  - VIDEO_ADV7842=m
  - VIDEO_ADV7842_CEC=y
  - VIDEO_BT819=m
  - VIDEO_BT856=m
  - VIDEO_BT866=m
  - VIDEO_KS0127=m
  - VIDEO_ML86V7667=m
  - VIDEO_SAA7110=m
  - VIDEO_TC358743=m
  - VIDEO_TC358743_CEC=y
  - VIDEO_TVP514X=m
  - VIDEO_TVP7002=m
  - VIDEO_TW9910=m
  - VIDEO_VPX3220=m
  - VIDEO_SAA7185=m
  - VIDEO_ADV7170=m
  - VIDEO_ADV7175=m
  - VIDEO_ADV7343=m
  - VIDEO_ADV7393=m
  - VIDEO_ADV7511=m
  - VIDEO_ADV7511_CEC=y
  - VIDEO_AD9389B=m
  - VIDEO_AK881X=m
  - VIDEO_THS8200=m
  - VIDEO_IMX214=m
  - VIDEO_IMX258=m
  - VIDEO_IMX274=m
  - VIDEO_IMX319=m
  - VIDEO_IMX355=m
  - VIDEO_OV2659=m
  - VIDEO_OV2680=m
  - VIDEO_OV2685=m
  - VIDEO_OV5647=m
  - VIDEO_OV6650=m
  - VIDEO_OV5670=m
  - VIDEO_OV5695=m
  - VIDEO_OV7251=m
  - VIDEO_OV772X=m
  - VIDEO_OV7740=m
  - VIDEO_OV8856=m
  - VIDEO_OV9640=m
  - VIDEO_OV9650=m
  - VIDEO_OV13858=m
  - VIDEO_VS6624=m
  - VIDEO_MT9M001=m
  - VIDEO_MT9M032=m
  - VIDEO_MT9M111=m
  - VIDEO_MT9P031=m
  - VIDEO_MT9T001=m
  - VIDEO_MT9T112=m
  - VIDEO_MT9V032=m
  - VIDEO_MT9V111=m
  - VIDEO_SR030PC30=m
  - VIDEO_NOON010PC30=m
  - VIDEO_M5MOLS=m
  - VIDEO_RJ54N1=m
  - VIDEO_S5K6AA=m
  - VIDEO_S5K6A3=m
  - VIDEO_S5K4ECGX=m
  - VIDEO_S5K5BAF=m
  - VIDEO_SMIAPP=m
  - VIDEO_ET8EK8=m
  - VIDEO_S5C73M3=m
  - VIDEO_AD5820=m
  - VIDEO_AK7375=m
  - VIDEO_DW9714=m
  - VIDEO_DW9807_VCM=m
  - VIDEO_ADP1653=m
  - VIDEO_LM3560=m
  - VIDEO_LM3646=m
  - SDR_MAX2175=m
  - VIDEO_THS7303=m
  - VIDEO_I2C=m
  - VIDEO_ST_MIPID02=n
  - VIDEO_GS1662=m
  - DVB_S5H1432=m
  - DVB_DIB9000=m
  - DVB_CXD2880=m
  - DVB_MN88443X=m
  - DVB_LNBH29=m
  - DVB_LGS8GL5=m
  - Graphics
  - DRM_AMD_DC_DCN2_0=y
  - DRM_AMD_DC_DSC_SUPPORT=y
  - DRM_I915_FORCE_PROBE=""
  - DRM_I915_DEBUG_MMIO=n
  - DRM_I915_USERFAULT_AUTOSUSPEND=250
  - DRM_I915_SPIN_REQUEST=5
  - DRM_PANEL_OSD_OSD101T2587_53TS=m
  - DRM_PANEL_SAMSUNG_S6E63M0=m
  - Sound
  - SND_SOC_INTEL_CML_H=m
  - SND_SOC_INTEL_CML_LP=m
  - SND_SOC_INTEL_BYT_CHT_CX2072X_MACH=m
  - SND_SOC_SOF_COMETLAKE_LP_SUPPORT=y
  - SND_SOC_SOF_COMETLAKE_H_SUPPORT=y
  - SND_SOC_CX2072X=m
  - InfiniBand
  - RDMA_SIW=m
  - Platform specific drivers
  - XIAOMI_WMI=m
  - ACPI_CMPC=m
  - SAMSUNG_Q10=m
  - INTEL_SPEED_SELECT_INTERFACE=m
  - CROS_EC_ISHTP=m
  - WILCO_EC_EVENTS=m
  - WILCO_EC_TELEMETRY=m
  - Industrial I/O
  - XILINX_XADC=n
  - ADF4371=n
  - DPS310=n
  - LEDs
  - LEDS_SPI_BYTE=m
  - LEDS_TI_LMU_COMMON=m
  - LEDS_LM3697=m
  - LEDS_LM36274=m
  - Other drivers
  - MTD_HYPERBUS=m
  - HBMC_AM654=m
  - XILINX_SDFEC=n
  - GPIO_XILINX=m
  - WATCHDOG_OPEN_TIMEOUT=0
  - MFD_CS47L15=y
  - MFD_CS47L92=y
  - MFD_ROHM_BD70528=n
  - RTC_DRV_BD70528=m
  - DW_EDMA=m
  - DW_EDMA_PCIE=m
  - COMMON_CLK_SI5341=m
  - EXTCON_FSA9480=m
  - NTB_MSI=y
  - NTB_MSI_TEST=n
  - RAS_CEC_DEBUG=n
  - AL_FIC=n
  - Virtualization
  - VIRTIO_PMEM=m
  - Security options
  - KEYS_REQUEST_CACHE=y
  - Kernel hardening options
  - INIT_ON_ALLOC_DEFAULT_ON=n
  - INIT_ON_FREE_DEFAULT_ON=n
  - Cryptographic API
  - CRYPTO_XXHASH=n
  - CRYPTO_DEV_ATMEL_ECC=m
  - CRYPTO_DEV_ATMEL_SHA204A=m
  - Kernel hacking
  - HEADERS_INSTALL=n
  - REED_SOLOMON_TEST=n
  - TEST_BLACKHOLE_DEV=n
  - TEST_MEMINIT=n
- commit 0a6d0d9
* Sun Jul 21 2019 mkubecek@suse.cz
- Revert "netfilter: conntrack: remove helper hook again"
  (http://lkml.kernel.org/r/20190718092128.zbw4qappq6jsb4ja@breakpoint.cc).
- commit 8e9a006
* Sun Jul 21 2019 jslaby@suse.cz
- Linux 5.2.2 (bnc#1012628).
- x86/entry/32: Fix ENDPROC of common_spurious (bnc#1012628).
- crypto/NX: Set receive window credits to max number of CRBs
  in RxFIFO (bnc#1012628).
- crypto: talitos - fix hash on SEC1 (bnc#1012628).
- crypto: talitos - move struct talitos_edesc into talitos.h
  (bnc#1012628).
- s390/qdio: don't touch the dsci in tiqdio_add_input_queues()
  (bnc#1012628).
- s390/qdio: (re-)initialize tiqdio list entries (bnc#1012628).
- s390: fix stfle zero padding (bnc#1012628).
- s390/ipl: Fix detection of has_secure attribute (bnc#1012628).
- ARC: hide unused function unw_hdr_alloc (bnc#1012628).
- x86/irq: Seperate unused system vectors from spurious entry
  again (bnc#1012628).
- x86/irq: Handle spurious interrupt after shutdown gracefully
  (bnc#1012628).
- x86/ioapic: Implement irq_get_irqchip_state() callback
  (bnc#1012628).
- genirq: Add optional hardware synchronization for shutdown
  (bnc#1012628).
- genirq: Fix misleading synchronize_irq() documentation
  (bnc#1012628).
- genirq: Delay deactivation in free_irq() (bnc#1012628).
- firmware: improve LSM/IMA security behaviour (bnc#1012628).
- drivers: base: cacheinfo: Ensure cpu hotplug work is done
  before Intel RDT (bnc#1012628).
- nilfs2: do not use unexported cpu_to_le32()/le32_to_cpu()
  in uapi header (bnc#1012628).
- Input: synaptics - enable SMBUS on T480 thinkpad trackpad
  (bnc#1012628).
- e1000e: start network tx queue only when link is up
  (bnc#1012628).
- Revert "e1000e: fix cyclic resets at link up with active tx"
  (bnc#1012628).
- commit 93f0a54
* Tue Jul 16 2019 lpechacek@suse.com
- rpm/kernel-binary.spec.in: build kernel-*-kgraft only for default SLE kernel
  RT and Azure variants are excluded for the moment. (bsc#1141600)
- commit 620816f
* Sun Jul 14 2019 jslaby@suse.cz
- Linux 5.2.1 (bnc#1012628).
- staging: rtl8712: reduce stack usage, again (bnc#1012628).
- staging: bcm2835-camera: Handle empty EOS buffers whilst
  streaming (bnc#1012628).
- staging: bcm2835-camera: Remove check of the number of buffers
  supplied (bnc#1012628).
- staging: bcm2835-camera: Ensure all buffers are returned on
  disable (bnc#1012628).
- staging: bcm2835-camera: Replace spinlock protecting context_map
  with mutex (bnc#1012628).
- staging: fsl-dpaa2/ethsw: fix memory leak of switchdev_work
  (bnc#1012628).
- staging: vchiq: revert "switch to wait_for_completion_killable"
  (bnc#1012628).
- staging: vchiq: make wait events interruptible (bnc#1012628).
- staging: vchiq_2835_arm: revert "quit using custom
  down_interruptible()" (bnc#1012628).
- VMCI: Fix integer overflow in VMCI handle arrays (bnc#1012628).
- Revert "x86/build: Move _etext to actual end of .text"
  (bnc#1012628).
- carl9170: fix misuse of device driver API (bnc#1012628).
- coresight: tmc-etf: Do not call smp_processor_id from
  preemptible (bnc#1012628).
- coresight: tmc-etr: alloc_perf_buf: Do not call smp_processor_id
  from preemptible (bnc#1012628).
- coresight: tmc-etr: Do not call smp_processor_id() from
  preemptible (bnc#1012628).
- coresight: etb10: Do not call smp_processor_id from preemptible
  (bnc#1012628).
- coresight: Potential uninitialized variable in probe()
  (bnc#1012628).
- iio: adc: stm32-adc: add missing vdda-supply (bnc#1012628).
- binder: return errors from buffer copy functions (bnc#1012628).
- binder: fix memory leak in error path (bnc#1012628).
- lkdtm: support llvm-objcopy (bnc#1012628).
- HID: Add another Primax PIXART OEM mouse quirk (bnc#1012628).
- staging: mt7621-pci: fix PCIE_FTS_NUM_LO macro (bnc#1012628).
- staging: comedi: amplc_pci230: fix null pointer deref on
  interrupt (bnc#1012628).
- staging: bcm2835-camera: Restore return behavior of
  ctrl_set_bitrate() (bnc#1012628).
- staging: wilc1000: fix error path cleanup in
  wilc_wlan_initialize() (bnc#1012628).
- staging: comedi: dt282x: fix a null pointer deref on interrupt
  (bnc#1012628).
- p54: fix crash during initialization (bnc#1012628).
- drivers/usb/typec/tps6598x.c: fix 4CC cmd write (bnc#1012628).
- drivers/usb/typec/tps6598x.c: fix portinfo width (bnc#1012628).
- usb: renesas_usbhs: add a workaround for a race condition of
  workqueue (bnc#1012628).
- usb: dwc2: use a longer AHB idle timeout in dwc2_core_reset()
  (bnc#1012628).
- usb: gadget: ether: Fix race between gether_disconnect and
  rx_submit (bnc#1012628).
- usb: gadget: f_fs: data_len used before properly set
  (bnc#1012628).
- p54usb: Fix race between disconnect and firmware loading
  (bnc#1012628).
- Revert "serial: 8250: Don't service RX FIFO if interrupts are
  disabled" (bnc#1012628).
- USB: serial: option: add support for GosunCn ME3630 RNDIS mode
  (bnc#1012628).
- USB: serial: ftdi_sio: add ID for isodebug v1 (bnc#1012628).
- mwifiex: Don't abort on small, spec-compliant vendor IEs
  (bnc#1012628).
- Documentation/admin: Remove the vsyscall=native documentation
  (bnc#1012628).
- Documentation: Add section about CPU vulnerabilities for Spectre
  (bnc#1012628).
- x86/tls: Fix possible spectre-v1 in do_get_thread_area()
  (bnc#1012628).
- x86/ptrace: Fix possible spectre-v1 in ptrace_get_debugreg()
  (bnc#1012628).
- perf header: Assign proper ff->ph in
  perf_event__synthesize_features() (bnc#1012628).
- perf thread-stack: Fix thread stack return from kernel for
  kernel-only case (bnc#1012628).
- perf pmu: Fix uncore PMU alias list for ARM64 (bnc#1012628).
- perf intel-pt: Fix itrace defaults for perf script intel-pt
  documentation (bnc#1012628).
- perf auxtrace: Fix itrace defaults for perf script
  (bnc#1012628).
- perf intel-pt: Fix itrace defaults for perf script
  (bnc#1012628).
- block, bfq: NULL out the bic when it's no longer valid
  (bnc#1012628).
- block: fix .bi_size overflow (bnc#1012628).
- tpm: Fix TPM 1.2 Shutdown sequence to prevent future TPM
  operations (bnc#1012628).
- tpm: Actually fail on TPM errors during "get random"
  (bnc#1012628).
- ALSA: hda/realtek - Headphone Mic can't record after S3
  (bnc#1012628).
- ALSA: usb-audio: Fix parse of UAC2 Extension Units
  (bnc#1012628).
- media: stv0297: fix frequency range limit (bnc#1012628).
- udf: Fix incorrect final NOT_ALLOCATED (hole) extent length
  (bnc#1012628).
- fscrypt: don't set policy for a dead directory (bnc#1012628).
- crypto: talitos - rename alternative AEAD algos (bnc#1012628).
- crypto: lrw - use correct alignmask (bnc#1012628).
- commit 51ca500
* Thu Jul 11 2019 glin@suse.com
- net: bpfilter: print umh messages to /dev/kmsg (bsc#1140221).
- commit 139acc9
* Wed Jul 10 2019 jslaby@suse.cz
- rpm/kernel-binary.spec.in: handle modules.builtin.modinfo
  It was added in 5.2.
- commit eb88df3
* Tue Jul  9 2019 rgoldwyn@suse.com
- Disable CONFIG_OVERLAY_FS_REDIRECT_ALWAYS_FOLLOW in config (bsc#1140494)
- commit 8d950e4
* Mon Jul  8 2019 mkubecek@suse.cz
- Update to 5.2 final
- Eliminated 1 patch
- commit b36439f
* Sun Jul  7 2019 msuchanek@suse.de
- Refresh tpm: tpm_ibm_vtpm: Fix unallocated banks (boo#1139244).
- commit 99f9469
* Fri Jul  5 2019 tiwai@suse.de
- config: align CONFIG_PHYSICAL_START and CONFIG_PHYSICAL_ALIGN to default values
  As suggested in bsc#1067593, our kconfig keeps the old default values
  while the upstream took different (actually swapped) values for x86
  CONFIG_PHYSICAL_START and CONFIG_PHYSICAL_ALIGN.   Let's follow the
  upstream default now.
- commit baa2434
* Fri Jul  5 2019 mkubecek@suse.cz
- Rename patches.suse/[PATCH]_tpm:_fixes_uninitialized_allocated_banks_for_IBM_vtpm_driver
  to patches.suse/tpm-fixes-uninitialized-allocated-banks-for-IBM-vtpm-driver.patch
  Let's not risk some tool somewhere does not handle special characters correctly.
- commit 8a3fff9
* Thu Jul  4 2019 msuchanek@suse.de
- tpm: fixes uninitialized allocated banks for IBM vtpm driver
  (boo#1139244).
- Delete patches.suse/Revert-tpm-pass-an-array-of-tpm_extend_digest-struct.patch.
- commit 43ec0a5
* Wed Jul  3 2019 msuchanek@suse.de
- crypto: user - prevent operating on larval algorithms
  (bsc#1133401).
- Delete patches.suse/crypto-algapi-guard-against-uninitialized-spawn-list.patch.
- commit 90eea5d
* Wed Jul  3 2019 schwab@suse.de
- rpm/dtb.spec.in.in: don't make dtb directory inaccessible
  There is no reason to lock down the dtb directory for ordinary users.
- commit a69437a
* Wed Jul  3 2019 jslaby@suse.cz
- Update config files.
  Set CONFIG_SCSI_SCAN_ASYNC=y (bnc#1137686).
- commit a156b11
* Wed Jul  3 2019 mkubecek@suse.cz
- config: switch to SLUB allocator (Jira:PM-1158)
- new config options:
  - SLUB=y
  - SLUB_DEBUG=y
  - SLUB_MEMCG_SYSFS_ON=y
  - SLAB_FREELIST_HARDENED=n
  - SLUB_CPU_PARTIAL=y
  - SLUB_DEBUG_ON=n
  - SLUB_STATS=n
- commit 0ab8cfd
* Sun Jun 30 2019 mkubecek@suse.cz
- Update to 5.2-rc7
- Refresh configs
- commit 2d405cc
* Sun Jun 30 2019 msuchanek@suse.de
- Delete patches.rpmify/BPF-UMH-do-not-detect-if-compiler-can-link-userspace.patch.
  Obsoleted by the gcc9 cross-compilers with libc.
- commit 0e0679b
* Sun Jun 30 2019 msuchanek@suse.de
- Revert "tpm: pass an array of tpm_extend_digest structures to
  tpm_pcr_extend()" (boo#1139244).
- commit b09a129
* Fri Jun 28 2019 msuchanek@suse.de
- Refresh patches.suse/supported-flag.
  Supported kernel does not build with the patch in master so imported
  patch from SLE15.
- commit 10d9b2c
* Thu Jun 27 2019 msuchanek@suse.de
- Update config files
  - Add core options from SLE15 which are not enabled on master for no
  obvious reason
  - Add core option from x86 which are not enabled on non-x86 for no
  obvious reason
  - Enable fadump
  Changes:
  Scheduling:
    +CONFIG_CONTEXT_TRACKING=y
  - CONFIG_TICK_CPU_ACCOUNTING=y
    +CONFIG_VIRT_CPU_ACCOUNTING_GEN=y
    +CONFIG_VIRT_CPU_ACCOUNTING=y
    +CONFIG_IRQ_TIME_ACCOUNTING=y
    +CONFIG_TASKS_RCU=y
    +CONFIG_RT_GROUP_SCHED=y
  mm:
    +# CONFIG_TRANSPARENT_HUGEPAGE_ALWAYS is not set
    +CONFIG_TRANSPARENT_HUGEPAGE_MADVISE=y
    +CONFIG_FRONTSWAP=y
    +CONFIG_ZSWAP=y
  arc/ppc:
    +CONFIG_FA_DUMP=y
  fs:
    +CONFIG_9P_FSCACHE=y
  net:
    +CONFIG_TIPC=m
    +CONFIG_TIPC_DIAG=m
    +CONFIG_TIPC_MEDIA_UDP=y
  misc:
  - CONFIG_SERIAL_SIFIVE=m
    +CONFIG_SYSCTL_SYSCALL=y
  debug&test:
    +CONFIG_PAGE_EXTENSION=y
    +CONFIG_PAGE_OWNER=y
    +CONFIG_DEBUG_MISC=y
    +CONFIG_RCU_TRACE=y
    +CONFIG_KGDB_SERIAL_CONSOLE=y
    +CONFIG_SCOM_DEBUGFS=y
    +CONFIG_CRYPTO_TEST=m
    +CONFIG_RCU_TORTURE_TEST=m
    +CONFIG_TEST_FIRMWARE=m
    +CONFIG_TEST_LIVEPATCH=m
    +CONFIG_TEST_LKM=m
    +CONFIG_TEST_SYSCTL=m
    +CONFIG_TORTURE_TEST=m
- commit ce08519
* Mon Jun 24 2019 msuchanek@suse.de
- crypto: algapi - guard against uninitialized spawn list in
  crypto_remove_spawns (bsc#1133401).
- commit 543f67d
* Mon Jun 24 2019 tiwai@suse.de
- fonts: Prefer a bigger font for high resolution screens
  (bsc#1138496).
- fonts: Use BUILD_BUG_ON() for checking empty font table
  (bsc#1138496).
- fonts: Fix coding style (bsc#1138496).
- commit f99f70b
* Sun Jun 23 2019 mkubecek@suse.cz
- Update to 5.2-rc6
- Eliminated 5 patches
  - patches.suse/net-phy-rename-Asix-Electronics-PHY-driver.patch
  - patches.suse/tcp-limit-payload-size-of-sacked-skbs.patch
  - patches.suse/tcp-tcp_fragment-should-apply-sane-memory-limits.patch
  - patches.suse/tcp-add-tcp_min_snd_mss-sysctl.patch
  - patches.suse/tcp-enforce-tcp_min_snd_mss-in-tcp_mtu_probing.patch
- Refresh
  - patches.suse/apparmor-compatibility-with-v2.x-net.patch
- commit 75acedc
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: rpm does not support multiline condition
- commit aceae50
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: Use -c grep option in klp project detection.
- commit 5def2a2
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: fix missing \
- commit 8325214
* Wed Jun 19 2019 mkubecek@suse.cz
- config: refresh i386/default
- commit a562f5a
* Wed Jun 19 2019 jslaby@suse.cz
- Update config files.
  Enable SECURITY_YAMA to allow protection against ptrace attacks
  (bnc#1128245).
- commit f841e66
* Tue Jun 18 2019 jslaby@suse.cz
- Update config files.
  Set HARDENED_USERCOPY=y (bnc#1127808). This can be disabled on the
  commandline using hardened_usercopy=n.
- commit 3b85d22
* Tue Jun 18 2019 tiwai@suse.de
- config: enable CONFIG_FONT_TER16x32 for HiDPI monitors (boo#1138496)
- commit 073136d
* Mon Jun 17 2019 mkubecek@suse.cz
- tcp: enforce tcp_min_snd_mss in tcp_mtu_probing()
  (CVE-2019-11479 bsc#1137586).
- tcp: add tcp_min_snd_mss sysctl (CVE-2019-11479 bsc#1137586).
- tcp: tcp_fragment() should apply sane memory limits
  (CVE-2019-11478 bsc#1137586).
- tcp: limit payload size of sacked skbs (CVE-2019-11477
  bsc#1137586).
- commit ab45ff3
* Sun Jun 16 2019 mkubecek@suse.cz
- Update to 5.2-rc5
- Config changes:
  - Sound:
  - SND_SOC_SOF_NOCODEC_SUPPORT=n on x86, =y on ARM
  - Storage:
  - MQ_IOSCHED_DEADLINE m -> y on arm64
- commit b5857f8
* Thu Jun 13 2019 msuchanek@suse.de
- Build klp-symbols in kernel devel projects.
- commit ffd0ed9
* Thu Jun 13 2019 jdelvare@suse.de
- supported.conf: Enable it87_wdt and f71808e_wdt
  Both drivers are for watchdog devices included in Super-I/O chipsets
  which are popular on x86 PC mainboards. Code is clean and simple,
  so supporting them isn't a problem.
- commit b818771
* Mon Jun 10 2019 lduncan@suse.com
- scsi: mpt3sas_ctl: fix double-fetch bug in _ctl_ioctl_main()
  (bsc#1136922 cve-2019-12456).
- commit 42064d5
* Mon Jun 10 2019 mkubecek@suse.cz
- Update to 5.2-rc4
- Eliminated 1 patch
  - patches.rpmify/mlx5-avoid-64-bit-division.patch
- Refresh configs
  - IKHEADERS_PROC -> IKHEADERS
- commit c8bdb02
* Fri Jun  7 2019 mvedovati@suse.com
- rpm/post.sh: correct typo in err msg (bsc#1137625)
- commit 9fe85cc
* Thu Jun  6 2019 jslaby@suse.cz
- s390: drop meaningless 'targets' from tools Makefile (s390
  kmp build fix).
- commit b4eda05
* Wed Jun  5 2019 mvedovati@suse.com
- Enhance kvmsmall configuration (bsc#1137361)
  Add a minimal set of modules to  kvmsmall, to make this config usable
  to set up guest VMs interacting with the host.
- commit 34c4eab
* Wed Jun  5 2019 mkubecek@suse.cz
- config: refresh configs
  No functional change.
- commit cbc8b7e
* Tue Jun  4 2019 jslaby@suse.cz
- Update config files.
  Enable CRASH_DUMP and RELOCATABLE on ppc64le to be on par with the
  other archs and to allow for kdump (bnc#1135217).
- commit a6a9f0e
* Mon Jun  3 2019 mkubecek@suse.cz
- Update to 5.2-rc3
- Eliminated 1 patch
  - patches.suse/kvm-memunmap-also-needs-HAS_IOMEM.patch
- commit 038ee83
* Wed May 29 2019 mkubecek@suse.cz
- config: refresh vanilla configs
- commit cbe6c1c
* Wed May 29 2019 mkubecek@suse.cz
- reenable ARM architectures
- commit 194828b
* Wed May 29 2019 mkubecek@suse.cz
- refresh configs after Tumbleweed switch to gcc9 as default
- commit 3b7ae7e
* Wed May 29 2019 yousaf.kaukab@suse.com
- config: armv7hl: lpae: Update to v5.2.0-rc2
- commit 38ac345
* Wed May 29 2019 yousaf.kaukab@suse.com
- config: armv7hl: Update to v5.2.0-rc2
- commit 737b08e
* Wed May 29 2019 yousaf.kaukab@suse.com
- config: armv6hl: Update to v5.2.0-rc2
- commit c7bc712
* Tue May 28 2019 yousaf.kaukab@suse.com
- config: arm64: Update to v5.2.0-rc2
- commit 18d0586
* Mon May 27 2019 mkubecek@suse.cz
- Update to 5.2-rc2
- Eliminated 4 patches
  - patches.suse/dm-make-sure-to-obey-max_io_len_target_boundary.patch
  - patches.suse/kvm-make-kvm_vcpu_-un-map-dependency-on-CONFIG_HAS_I.patch
  - patches.suse/vfio_pci-Add-local-source-directory-as-include.patch
  - patches.suse/x86-kvm-pmu-Set-AMD-s-virt-PMU-version-to-1.patch
- add s390x/zfcpdump build fix
  - patches.suse/kvm-memunmap-also-needs-HAS_IOMEM.patch
- commit b02c459
* Wed May 22 2019 msuchanek@suse.de
- Delete patches.suse/Revert-Bluetooth-btusb-driver-to-enable-the-usb-wake.patch (boo#1130448).
  Should be fixed in 5.1-rc5
  commit 771acc7e4a6e5dba779cb1a7fd851a164bc81033
  Author: Brian Norris <briannorris@chromium.org>
  Date:   Tue Apr 9 11:49:17 2019 -0700
    Bluetooth: btusb: request wake pin with NOAUTOEN
- commit b225e5a
* Wed May 22 2019 jslaby@suse.cz
- dm: make sure to obey max_io_len_target_boundary (bnc#1135868).
- commit dbeb07c
* Mon May 20 2019 mkubecek@suse.cz
- kvm: make kvm_vcpu_(un)map dependency on CONFIG_HAS_IOMEM
  explicit.
  Fixes build of s390x/zfcpdump.
- commit b33dbfc
* Mon May 20 2019 mkubecek@suse.cz
- config: refresh vanilla configs
- commit 4c41263
* Mon May 20 2019 mkubecek@suse.cz
- net: phy: rename Asix Electronics PHY driver.
  Fix duplicate module name asix by renaming phy driver to ax88796b.
- Update config files.
- commit df18320
* Mon May 20 2019 mkubecek@suse.cz
- mlx5: avoid 64-bit division.
  Fix i386 build.
- commit 89c5a47
* Mon May 20 2019 mkubecek@suse.cz
- Update to 5.2-rc1
- Eliminated 106 patches (105 stable, 1 other)
- ARM configs need update
- Refresh
  patches.rpmify/scripts-mkmakefile-honor-second-argument.patch
  patches.suse/dm-mpath-leastpending-path-update
  patches.suse/supported-flag
  patches.suse/supported-flag-external
  patches.suse/vfs-add-super_operations-get_inode_dev
- New config options:
  - General setup
  - IKHEADERS_PROC=n
  - SHUFFLE_PAGE_ALLOCATOR=y
  - Security
  - SECURITY_TOMOYO_INSECURE_BUILTIN_SETTING=n
  - Filesystems
  - UNICODE=y
  - UNICODE_NORMALIZATION_SELFTEST=n
  - Crypto
  - CRYPTO_ECRDSA=m
  - Networking
  - BATMAN_ADV_SYSFS=y
  - BT_MTKSDIO=m
  - XILINX_LL_TEMAC=m
  - MT7615E=m
  - RTW88=m
  - RTW88_8822BE=y
  - RTW88_8822CE=y
  - RTW88_DEBUG=n
  - RTW88_DEBUGFS=n
  - INFINIBAND_EFA=m
  - Storage
  - DM_DUST=m
  - MTD drivers
  - MTD_RAW_NAND=m
  - MTD_NAND_ECC_SW_BCH=y
  - MTD_NAND_ECC_SW_HAMMING_SMC=n
  - Input
  - KEYBOARD_QT1050=m
  - TOUCHSCREEN_IQS5XX=m
  - INPUT_GPIO_VIBRA=n
  - INPUT_REGULATOR_HAPTIC=m
  - HID_MACALLY=m
  - HID_U2FZERO=m
  - INPUT_MAX77650_ONKEY=m
  - Serial
  - NULL_TTY=m
  - SERIAL_SIFIVE=m
  - Power management
  - CHARGER_MANAGER=y
  - CHARGER_LT3651=m
  - CHARGER_UCS1002=m
  - SENSORS_IR38064=m
  - SENSORS_ISL68137=m
  - SENSORS_LTC2978_REGULATOR=y
  - THERMAL_MMIO=m
  - MFD_MAX77650=m
  - MFD_STMFX=m
  - REGULATOR_DEBUG=n
  - REGULATOR_FIXED_VOLTAGE=m
  - REGULATOR_VIRTUAL_CONSUMER=m
  - REGULATOR_USERSPACE_CONSUMER=m
  - REGULATOR_88PG86X=m
  - REGULATOR_ACT8865=m
  - REGULATOR_AD5398=m
  - REGULATOR_AXP20X=m
  - REGULATOR_DA9062=m
  - REGULATOR_DA9210=m
  - REGULATOR_DA9211=m
  - REGULATOR_FAN53555=m
  - REGULATOR_GPIO=m
  - REGULATOR_ISL9305=m
  - REGULATOR_ISL6271A=m
  - REGULATOR_LM363X=m
  - REGULATOR_LP3971=m
  - REGULATOR_LP3972=m
  - REGULATOR_LP872X=m
  - REGULATOR_LP8755=m
  - REGULATOR_LTC3589=m
  - REGULATOR_LTC3676=m
  - REGULATOR_MAX1586=m
  - REGULATOR_MAX77650=m
  - REGULATOR_MAX8649=m
  - REGULATOR_MAX8660=m
  - REGULATOR_MAX8907=m
  - REGULATOR_MAX8952=m
  - REGULATOR_MAX8973=m
  - REGULATOR_MCP16502=m
  - REGULATOR_MT6311=m
  - REGULATOR_PFUZE100=m
  - REGULATOR_PV88060=m
  - REGULATOR_PV88080=m
  - REGULATOR_PV88090=m
  - REGULATOR_PWM=m
  - REGULATOR_QCOM_SPMI=m
  - REGULATOR_SY8106A=m
  - REGULATOR_TPS51632=m
  - REGULATOR_TPS62360=m
  - REGULATOR_TPS65023=m
  - REGULATOR_TPS6507X=m
  - REGULATOR_TPS65132=m
  - REGULATOR_TPS6524X=m
  - REGULATOR_VCTRL=m
  - CHARGER_MAX77650=m
  - Media
  - MEDIA_CONTROLLER_REQUEST_API=y
  - VIDEO_V4L2_SUBDEV_API=y
  - V4L2_FLASH_LED_CLASS=m
  - VIDEO_COBALT=n
  - VIDEO_IPU3_CIO2=m
  - VIDEO_CADENCE_CSI2RX=m
  - VIDEO_CADENCE_CSI2TX=m
  - VIDEO_MUX=m
  - VIDEO_XILINX=m
  - VIDEO_XILINX_TPG=m
  - VIDEO_VIMC=m
  - VIDEO_IPU3_IMGU=m
  - DRM
  - NOUVEAU_LEGACY_CTX_SUPPORT=n
  - DRM_PANEL_FEIYANG_FY07024DI26A30D=n
  - DRM_PANEL_ROCKTECH_JH057N00900=n
  - DRM_PANEL_RONBO_RB070D30=n
  - Sound
  - SND_SOC_FSL_AUDMIX=n
  - SND_SOC_SOF_TOPLEVEL=y
  - SND_SOC_SOF_PCI=m
  - SND_SOC_SOF_ACPI=m
  - SND_SOC_SOF_NOCODEC=n
  - SND_SOC_SOF_STRICT_ABI_CHECKS=n
  - SND_SOC_SOF_DEBUG=n
  - SND_SOC_SOF_INTEL_TOPLEVEL=y
  - SND_SOC_SOF_BAYTRAIL_SUPPORT=y
  - SND_SOC_SOF_BROADWELL_SUPPORT=y
  - SND_SOC_SOF_MERRIFIELD_SUPPORT=y
  - SND_SOC_SOF_APOLLOLAKE_SUPPORT=y
  - SND_SOC_SOF_GEMINILAKE_SUPPORT=y
  - SND_SOC_SOF_CANNONLAKE_SUPPORT=y
  - SND_SOC_SOF_COFFEELAKE_SUPPORT=y
  - SND_SOC_SOF_ICELAKE_SUPPORT=y
  - SND_SOC_SOF_HDA_LINK=y
  - SND_SOC_SOF_HDA_AUDIO_CODEC=y
  - SND_SOC_INTEL_SOF_RT5682_MACH=m
  - USB
  - TYPEC_NVIDIA_ALTMODE=m
  - LEDS
  - LEDS_LM3532=m
  - LEDS_REGULATOR=m
  - LEDS_MAX77650=m
  - Platform
  - CROS_EC_RPMSG=m
  - CROS_USBPD_LOGGER=m
  - CLK_SIFIVE=n
  - IXP4XX_QMGR=n
  - IXP4XX_NPE=m
  - IIO
  - CC10001_ADC=n
  - TI_ADS8344=n
  - FXAS21002C=n
  - MB1232=n
  - MAX31856=m
  - Misc drivers
  - I2C_AMD_MP2=m
  - PINCTRL_STMFX=n
  - FIELDBUS_DEV=n
  - KPC2000=n
  - NVMEM_SYSFS=y
  - COUNTER=n
  - GPIO_MAX77650=m
  - Library
  - PACKING=n
  - Debugging and testing
  - DEBUG_INFO_BTF=n
  - DEBUG_MISC=n
  - DEBUG_PLIST=n
  - TEST_STRSCPY=n
  - x86
  - ACPI_HMAT=y
  - INTEL_CHT_INT33FE=m
  - INTEL_ISH_FIRMWARE_DOWNLOADER=m
  - i386
  - MEMORY_HOTPLUG=y
  - MEMORY_HOTPLUG_DEFAULT_ONLINE=n
  - MEMORY_HOTREMOVE
  - XEN_BALLOON_MEMORY_HOTPLUG=y
  - XEN_BALLOON_MEMORY_HOTPLUG_LIMIT=4
  - DEV_DAX_KMEM=m
  - MEMORY_NOTIFIER_ERROR_INJECT=m
  - ACPI_HOTPLUG_MEMORY=y
  - ppc64 / ppc64le
  - PPC_KUEP=y
  - PPC_KUAP=y
  - PPC_KUAP_DEBUG=n
  - MTD_NAND_DENALI_PCI=m
  - MTD_NAND_CAFE=m
  - MTD_NAND_GPIO=m
  - MTD_NAND_PLATFORM=m
  - MTD_NAND_NANDSIM=m
  - MTD_NAND_RICOH=m
  - MTD_NAND_DISKONCHIP=m
  - MTD_NAND_DISKONCHIP_PROBE_ADVANCED=n
  - MTD_NAND_DISKONCHIP_BBTWRITE=n
  - INTEGRITY_PLATFORM_KEYRING=y
  - OPTIMIZE_INLINING=y
  - XMON_DEFAULT_RO_MODE=y
  - s390x
  - KEXEC_VERIFY_SIG=n
  - RELOCATABLE=y
  - RANDOMIZE_BASE=y
  - PROTECTED_VIRTUALIZATION_GUEST=y
  - LCD_CLASS_DEVICE=n
  - BACKLIGHT_CLASS_DEVICE=n
  - INTEGRITY_PLATFORM_KEYRING=y
  - OPTIMIZE_INLINING=n
- commit c8b1101
* Fri May 17 2019 jslaby@suse.cz
- Revert "selinux: do not report error on connect(AF_UNSPEC)"
  (git-fixes).
- Revert "Don't jump to compute_result state from check_result
  state" (git-fixes).
- commit 3d34296
* Fri May 17 2019 jslaby@suse.cz
- Linux 5.1.3 (bnc#1012628).
- f2fs: Fix use of number of devices (bnc#1012628).
- PCI: hv: Add pci_destroy_slot() in pci_devices_present_work(),
  if necessary (bnc#1012628).
- PCI: hv: Add hv_pci_remove_slots() when we unload the driver
  (bnc#1012628).
- PCI: hv: Fix a memory leak in hv_eject_device_work()
  (bnc#1012628).
- virtio_ring: Fix potential mem leak in
  virtqueue_add_indirect_packed (bnc#1012628).
- powerpc/booke64: set RI in default MSR (bnc#1012628).
- powerpc/powernv/idle: Restore IAMR after idle (bnc#1012628).
- powerpc/book3s/64: check for NULL pointer in pgd_alloc()
  (bnc#1012628).
- drivers/virt/fsl_hypervisor.c: prevent integer overflow in ioctl
  (bnc#1012628).
- drivers/virt/fsl_hypervisor.c: dereferencing error pointers
  in ioctl (bnc#1012628).
- isdn: bas_gigaset: use usb_fill_int_urb() properly
  (bnc#1012628).
- flow_dissector: disable preemption around BPF calls
  (bnc#1012628).
- net: phy: fix phy_validate_pause (bnc#1012628).
- tuntap: synchronize through tfiles array instead of
  tun->numqueues (bnc#1012628).
- tuntap: fix dividing by zero in ebpf queue selection
  (bnc#1012628).
- vrf: sit mtu should not be updated when vrf netdev is the link
  (bnc#1012628).
- vlan: disable SIOCSHWTSTAMP in container (bnc#1012628).
- tipc: fix hanging clients using poll with EPOLLOUT flag
  (bnc#1012628).
- selinux: do not report error on connect(AF_UNSPEC)
  (bnc#1012628).
- packet: Fix error path in packet_init (bnc#1012628).
- net: ucc_geth - fix Oops when changing number of buffers in
  the ring (bnc#1012628).
- net: seeq: fix crash caused by not set dev.parent (bnc#1012628).
- net: macb: Change interrupt and napi enable order in open
  (bnc#1012628).
- net: ethernet: stmmac: dwmac-sun8i: enable support of unicast
  filtering (bnc#1012628).
- net: dsa: Fix error cleanup path in dsa_init_module
  (bnc#1012628).
- ipv4: Fix raw socket lookup for local traffic (bnc#1012628).
- fib_rules: return 0 directly if an exactly same rule exists
  when NLM_F_EXCL not supplied (bnc#1012628).
- dpaa_eth: fix SG frame cleanup (bnc#1012628).
- bridge: Fix error path for kobject_init_and_add() (bnc#1012628).
- bonding: fix arp_validate toggling in active-backup mode
  (bnc#1012628).
- Don't jump to compute_result state from check_result state
  (bnc#1012628).
- rtlwifi: rtl8723ae: Fix missing break in switch statement
  (bnc#1012628).
- mwl8k: Fix rate_idx underflow (bnc#1012628).
- USB: serial: fix unthrottle races (bnc#1012628).
- virt: vbox: Sanity-check parameter types for hgcm-calls coming
  from userspace (bnc#1012628).
- kernfs: fix barrier usage in __kernfs_new_node() (bnc#1012628).
- i2c: core: ratelimit 'transfer when suspended' errors
  (bnc#1012628).
- selftests/seccomp: Handle namespace failures gracefully
  (bnc#1012628).
- hwmon: (occ) Fix extended status bits (bnc#1012628).
- hwmon: (pwm-fan) Disable PWM if fetching cooling data fails
  (bnc#1012628).
- platform/x86: dell-laptop: fix rfkill functionality
  (bnc#1012628).
- platform/x86: thinkpad_acpi: Disable Bluetooth for some machines
  (bnc#1012628).
- platform/x86: sony-laptop: Fix unintentional fall-through
  (bnc#1012628).
- commit 073196d
* Thu May 16 2019 mwilck@suse.com
- Update config files: disable CONFIG_IDE for ppc64/ppc64le (bsc#1135333)
- commit 012b7ed
* Wed May 15 2019 mkubecek@suse.cz
- x86/kvm/pmu: Set AMD's virt PMU version to 1
  (https://patchwork.kernel.org/patch/10936271/).
- commit d737fc7
* Tue May 14 2019 jslaby@suse.cz
- Linux 5.1.2 (bnc#1012628).
- x86/speculation/mds: Fix documentation typo (bnc#1012628).
- Documentation: Correct the possible MDS sysfs values
  (bnc#1012628).
- x86/mds: Add MDSUM variant to the MDS documentation
  (bnc#1012628).
- x86/speculation/mds: Add 'mitigations=' support for MDS
  (bnc#1012628).
- s390/speculation: Support 'mitigations=' cmdline option
  (bnc#1012628).
- powerpc/speculation: Support 'mitigations=' cmdline option
  (bnc#1012628).
- x86/speculation: Support 'mitigations=' cmdline option
  (bnc#1012628).
- cpu/speculation: Add 'mitigations=' cmdline option
  (bnc#1012628).
- x86/speculation/mds: Print SMT vulnerable on MSBDS with
  mitigations off (bnc#1012628).
- x86/speculation/mds: Fix comment (bnc#1012628).
- x86/speculation/mds: Add SMT warning message (bnc#1012628).
- x86/speculation: Move arch_smt_update() call to after mitigation
  decisions (bnc#1012628).
- x86/speculation/mds: Add mds=full,nosmt cmdline option
  (bnc#1012628).
- Documentation: Add MDS vulnerability documentation
  (bnc#1012628).
- Documentation: Move L1TF to separate directory (bnc#1012628).
- x86/speculation/mds: Add mitigation mode VMWERV (bnc#1012628).
- x86/speculation/mds: Add sysfs reporting for MDS (bnc#1012628).
- x86/speculation/mds: Add mitigation control for MDS
  (bnc#1012628).
- x86/speculation/mds: Conditionally clear CPU buffers on idle
  entry (bnc#1012628).
- x86/kvm/vmx: Add MDS protection when L1D Flush is not active
  (bnc#1012628).
- x86/speculation/mds: Clear CPU buffers on exit to user
  (bnc#1012628).
- x86/speculation/mds: Add mds_clear_cpu_buffers() (bnc#1012628).
- x86/kvm: Expose X86_FEATURE_MD_CLEAR to guests (bnc#1012628).
- x86/speculation/mds: Add BUG_MSBDS_ONLY (bnc#1012628).
- x86/speculation/mds: Add basic bug infrastructure for MDS
  (bnc#1012628).
- x86/speculation: Consolidate CPU whitelists (bnc#1012628).
- x86/msr-index: Cleanup bit defines (bnc#1012628).
- commit 5a8c05f
* Tue May 14 2019 mkubecek@suse.cz
- config: keep LSM empty in s390x/zfcpdump
  This config doesn't really build AppArmor and always had
  DEFAULT_SECURITY_DAC so it seems more consistent to keep LSM list empty.
- commit 3073856
* Tue May 14 2019 mkubecek@suse.cz
- config: enable AppArmor by default again (bsc#1134906)
  AppArmor used to be enabled in kernel by default by after the recent
  introduction of CONFIG_LSM, we disabled all LSM modules. Enable AppArmor
  again.
- commit 953db35
* Tue May 14 2019 mkubecek@suse.cz
- Update upstream reference:
  patches.suse/efifb-Omit-memory-map-check-on-legacy-boot.patch
- commit 133a780
* Sat May 11 2019 jslaby@suse.cz
- Linux 5.1.1 (bnc#1012628).
- arm64: futex: Bound number of LDXR/STXR loops in FUTEX_WAKE_OP
  (bnc#1012628).
- locking/futex: Allow low-level atomic operations to return
  - EAGAIN (bnc#1012628).
- i3c: Fix a shift wrap bug in i3c_bus_set_addr_slot_status()
  (bnc#1012628).
- ASoC: Intel: avoid Oops if DMA setup fails (bnc#1012628).
- UAS: fix alignment of scatter/gather segments (bnc#1012628).
- Bluetooth: hci_bcm: Fix empty regulator supplies for Intel Macs
  (bnc#1012628).
- Bluetooth: Fix not initializing L2CAP tx_credits (bnc#1012628).
- Bluetooth: Align minimum encryption key size for LE and BR/EDR
  connections (bnc#1012628).
- Bluetooth: hidp: fix buffer overflow (bnc#1012628).
- scsi: qla2xxx: Fix device staying in blocked state
  (bnc#1012628).
- scsi: qla2xxx: Set remote port devloss timeout to 0
  (bnc#1012628).
- scsi: qla2xxx: Fix incorrect region-size setting in optrom
  SYSFS routines (bnc#1012628).
- scsi: lpfc: change snprintf to scnprintf for possible overflow
  (bnc#1012628).
- soc: sunxi: Fix missing dependency on REGMAP_MMIO (bnc#1012628).
- ACPI / LPSS: Use acpi_lpss_* instead of acpi_subsys_* functions
  for hibernate (bnc#1012628).
- cpufreq: armada-37xx: fix frequency calculation for opp
  (bnc#1012628).
- iio: adc: qcom-spmi-adc5: Fix of-based module autoloading
  (bnc#1012628).
- intel_th: pci: Add Comet Lake support (bnc#1012628).
- genirq: Prevent use-after-free and work list corruption
  (bnc#1012628).
- usb-storage: Set virt_boundary_mask to avoid SG overflows
  (bnc#1012628).
- USB: cdc-acm: fix unthrottle races (bnc#1012628).
- USB: serial: f81232: fix interrupt worker not stop
  (bnc#1012628).
- usb: dwc3: Fix default lpm_nyet_threshold value (bnc#1012628).
- usb: dwc3: Allow building USB_DWC3_QCOM without EXTCON
  (bnc#1012628).
- staging: most: sound: pass correct device when creating a
  sound card (bnc#1012628).
- staging: most: cdev: fix chrdev_region leak in mod_exit
  (bnc#1012628).
- staging: wilc1000: Avoid GFP_KERNEL allocation from atomic
  context (bnc#1012628).
- staging: greybus: power_supply: fix prop-descriptor request size
  (bnc#1012628).
- ubsan: Fix nasty -Wbuiltin-declaration-mismatch GCC-9 warnings
  (bnc#1012628).
- Drivers: hv: vmbus: Remove the undesired put_cpu_ptr() in
  hv_synic_cleanup() (bnc#1012628).
- commit 8e0a089
* Thu May  9 2019 guillaume.gardet@free.fr
- Sign non-x86 kernels when possible (boo#1134303)
- commit bac621c
* Mon May  6 2019 mkubecek@suse.cz
- Update to 5.1 final
- Eliminated 1 patch
- New config options:
  - PCI:
  - PCIE_BW=n (recommended default)
- commit a974d8b
* Tue Apr 30 2019 mkubecek@suse.cz
- rdma: fix build errors on s390 and MIPS due to bad ZERO_PAGE use
  (http://lkml.kernel.org/r/20190429052136.GA21672@unicorn.suse.cz).
- Delete
  patches.suse/rdma-fix-argument-of-ZERO_PAGE-in-rdma_umap_fault.patch.
- commit a764394
* Mon Apr 29 2019 mkubecek@suse.cz
- Update to 5.1-rc7
- add patches.suse/rdma-fix-argument-of-ZERO_PAGE-in-rdma_umap_fault.patch
  (tentative s390x build fix)
- New config options:
  - ARM:
  - KEYBOARD_SNVS_PWRKEY=m
  - armv7hl:
  - FRAME_POINTER=y
  - UNWINDER_FRAME_POINTER=y
- commit 04c1966
* Sun Apr 21 2019 mkubecek@suse.cz
- Update to v5.1-rc6
- New config options:
  - IIO:
  - SENSIRION_SGP30=n
- commit ab97af0
* Tue Apr 16 2019 mkubecek@suse.cz
- series.conf: cleanup
  patches.suse/ext2-fsync-err was deleted in 2011 but its (commented out)
  line in series.conf was left behind.
- commit d2aebe3
* Mon Apr 15 2019 jkosina@suse.cz
- Delete
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Delete
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Delete
  patches.suse/0003-x86-idle-Control-Indirect-Branch-Speculation-in-idle.patch.
- Delete
  patches.suse/0004-x86-enter-Create-macros-to-restrict-unrestrict-Indir.patch.
- Delete
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
  Drop SUSE-specific IBRS-on-SKL implementation. Please refer to
  page 16 of [1]
  [1] https://software.intel.com/security-software-guidance/api-app/sites/default/files/Retpoline-A-Branch-Target-Injection-Mitigation.pdf
- commit 5e8da3a
* Mon Apr 15 2019 mkubecek@suse.cz
- Update to 5.1-rc5
- commit 2fd333d
* Thu Apr 11 2019 msuchanek@suse.de
- Do not provide kernel-default from kernel-default-base (boo#1132154, bsc#1106751).
- commit 0e54e61
* Thu Apr 11 2019 msuchanek@suse.de
- rpm/kernel-subpackage-spec: only provide firmware actually present in
  subpackage.
- commit 839debd
* Wed Apr 10 2019 msuchanek@suse.de
- kernel-subpackage-spec: Add dummy package to ensure subpackages are
  rebuilt with kernel update (bsc#1106751).
  In factory packages are not rebuilt automatically so a dependency is
  needed on the old kernel to get a rebuild with the new kernel. THe
  subpackage itself cannot depend on the kernel so add another empty
  pacakge that does depend on it.
- commit 6d14837
* Tue Apr  9 2019 jdelvare@suse.de
- Disable CONFIG_SERIO_OLPC_APSP on all but armv7
  This driver is only used by ARMv7-based OLPC laptops.
- commit 7b1b640
* Tue Apr  9 2019 jdelvare@suse.de
- Disable CONFIG_SENSORS_OCC_*
  These drivers are running on the BMC of PowerPC servers. The BMC runs
  OpenBMC and is not a target for SUSE distributions.
- commit a82eb87
* Mon Apr  8 2019 mkubecek@suse.cz
- config: disable DEVKMEM (bsc#1128045)
- commit 1478096
* Mon Apr  8 2019 mkubecek@suse.cz
- Update to 5.1-rc4
- Refresh configs
- commit e334e4f
* Mon Apr  1 2019 tiwai@suse.de
- efifb: Omit memory map check on legacy boot (bsc#1127339).
- commit 8a60576
* Mon Apr  1 2019 mkubecek@suse.cz
- Update to 5.1-rc3
- Eliminated 1 patch
- Config changes:
  - SECURITY_DEFAULT_* are back
  - enable CONFIG_OF in i386/pae and copy dependent options from default
- commit 7474ec2
* Thu Mar 28 2019 yousaf.kaukab@suse.com
- config: arm64: enable CPPC support
- commit c97748e
* Tue Mar 26 2019 msuchanek@suse.de
- Revert "Bluetooth: btusb: driver to enable the usb-wakeup
  feature" (boo#1130448).
  System still wakes up when connected BT device is powered off.
- Revert "Bluetooth: btusb: driver to enable the usb-wakeup
  feature" (boo#1130448).
- commit 1172cb0
* Tue Mar 26 2019 mkubecek@suse.cz
- Revert "parport: daisy: use new parport device model"
  (http://lkml.kernel.org/r/20190313064557.GA14531@unicorn.suse.cz).
- Delete
  patches.suse/parport-daisy-do-not-try-to-load-lowlevel-driver.patch.
- commit 7da01f5
* Tue Mar 26 2019 jbeulich@suse.com
- patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch:
  Fix re-basing mistake - IBRS enabling should not be skipped for PV Xen.
- commit 177c0f8
* Tue Mar 26 2019 mkubecek@suse.cz
- parport: daisy: do not try to load lowlevel driver
  (http://lkml.kernel.org/r/20190313064557.GA14531@unicorn.suse.cz).
- commit 4f8876e
* Mon Mar 25 2019 mkubecek@suse.cz
- Update to 5.1-rc2
- New config options:
  - CHARLCD_BL_FLASH=y
  - PARPORT_PANEL=m (renamed from PANEL)
  - PANEL=m
- commit ede8a59
* Fri Mar 22 2019 msuchanek@suse.de
- Do not provide kernel-default-srchash from kernel-default-base.
- commit d6c71ce
* Thu Mar 21 2019 mkubecek@suse.cz
- config: apply recent changes to ARM configs
- CONFIG_PREEMPT_VOLUNTARY=y
- disable CONFIG_IMA_ARCH_POLICY
- enable CONFIG_IMA_APPRAISE_BOOTPARAM
- CONFIG_LSM=""
- commit fd95045
* Wed Mar 20 2019 yousaf.kaukab@suse.com
- config: arm64: Update to v5.1-rc1
- commit 590226b
* Wed Mar 20 2019 msuchanek@suse.de
- rpm/kernel-subpackage-build: handle arm kernel zImage.
- commit 81a63c3
* Wed Mar 20 2019 jslaby@suse.cz
- config: disable IMA_ARCH_POLICY for now
  When IMA_ARCH_POLICY was enabled during the 5.0-rc* stage, IMA causes
  kdump load to fail:
  kexec_file_load failed: Permission denied
  ima: impossible to appraise a kernel image without a file descriptor; try using kexec_file_load syscall.
  We have to fix kexec tooling before enabling IMA for everyone.
  BTW IMA_APPRAISE_BOOTPARAM was disabled by IMA_ARCH_POLICY=y. So
  restore the original state (and functionality).
- commit f738bd5
* Wed Mar 20 2019 yousaf.kaukab@suse.com
- config: armv6hl: Update to v5.1-rc1
  CONFIG_BPFILTER_UMH is disabled due to bsc#1127188
- commit 608f8e5
* Wed Mar 20 2019 tiwai@suse.de
- rpm/kernel-source.changes.old: Really drop old changelogs (bsc#1098995)
- commit 93056b5
* Tue Mar 19 2019 yousaf.kaukab@suse.com
- config: armv7hl: Update to v5.1-rc1
  CONFIG_BPFILTER_UMH is disabled due to bsc#1127188
- commit 0042582
* Mon Mar 18 2019 mkubecek@suse.cz
- Update to 5.1-rc1
- Eliminated 74 patches (73 stable, 1 other)
- ARM configs need update
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
  patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch
  patches.suse/genksyms-add-override-flag.diff
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/readahead-request-tunables.patch
  patches.suse/supported-flag
  patches.suse/vfs-add-super_operations-get_inode_dev
- New config options:
  - General:
  - IO_URING=y
  - PRINTK_CALLER=n
  - File systems:
  - CONFIG_SUNRPC_DISABLE_INSECURE_ENCTYPES=n
  - VALIDATE_FS_PARSER=n
  - Networking:
  - NET_DEVLINK=y
  - XDP_SOCKETS_DIAG=m
  - MT7603E=m
  - TI_CPSW_PHY_SEL=n
  - Power management:
  - CPU_IDLE_GOV_TEO=y
  - DAX:
  - DEV_DAX_KMEM=m
  - DEV_DAX_PMEM_COMPAT=m
  - USB:
  - USB_AUTOSUSPEND_DELAY=2
  - USB_EHCI_FSL=m
  - Graphics:
  - DRM_ETNAVIV=n
  - DRM_NOUVEAU_SVM=n
  - VIDEO_FB_IVTV_FORCE_PAT=n
  - Sound:
  - SND_SOC_CROS_EC_CODEC=m
  - SND_SOC_CS35L36=m
  - SND_SOC_CS4341=m
  - SND_SOC_FSL_MICFIL=n
  - SND_SOC_MAX98373=m
  - SND_SOC_MT6358=n
  - SND_SOC_MTK_BTCVSD=m
  - SND_SOC_RK3328=n
  - SND_SOC_WM8904=n
  - SND_SOC_XILINX_AUDIO_FORMATTER=n
  - SND_SOC_XILINX_SPDIF=n
  - Input:
  - HID_MALTRON=m
  - HID_VIEWSONIC=m
  - TTY:
  - LDISC_AUTOLOAD=y
  - RTC:
  - RTC_DRV_ABEOZ9=m
  - RTC_DRV_RV3028=m
  - RTC_DRV_SD3078=m
  - RTC_DRV_WILCO_EC=m
  - Industrial IO:
  - AD7606_IFACE_PARALLEL=n
  - AD7606_IFACE_SPI=n
  - AD7768_1=n
  - MAX44009=m
  - PMS7003=n
  - SPS30=n
  - TI_DAC7612=n
  - Misc drivers:
  - ALTERA_FREEZE_BRIDGE=m
  - EDAC_I10NM=m
  - EXTCON_PTN5150=m
  - GNSS_MTK_SERIAL=m
  - GPIO_AMD_FCH=m
  - GPIO_TQMX86=m
  - HABANA_AI=m
  - INPUT_MSM_VIBRATOR=n
  - INTEL_MEI_HDCP=m
  - INTERCONNECT=m
  - IR_RCMM_DECODER=m
  - MFD_TQMX86=m
  - MLX_WDT=m
  - SPI_MTK_QUADSPI=m
  - SPI_NXP_FLEXSPI=n
  - SPI_SIFIVE=n
  - WILCO_EC=m
  - WILCO_EC_DEBUGFS=n
  - Virtualization:
  - HYPERV_IOMMU=y
  - Security:
  - LSM=""
  - SECURITY_SAFESETID=n
  - Testing:
  - TEST_LIVEPATCH=n
  - TEST_STACKINIT=n
  - TEST_VMALLOC=n
  - x86:
  - PCENGINES_APU2=m
  - ppc64/ppc64le:
  - NVRAM=m
  - KCOV=n
  - s390x:
  UID16=y
  DMA_FENCE_TRACE=n
  SCSI_GDTH=n
  UDMABUF=y
  - */debug:
  - PRINTK_CALLER=n
- commit b493de0
* Mon Mar 18 2019 msuchanek@suse.de
- Trim build dependencies of sample subpackage spec file (FATE#326579,
  jsc#SLE-4117, jsc#SLE-3853, bsc#1128910).
- commit 2eae420
* Sun Mar 17 2019 mkubecek@suse.cz
- Drop stale disabled patches
  As discussed in
  http://mailman.suse.de/mlarch/SuSE/kernel/2019/kernel.2019.02/msg00118.html
  http://mailman.suse.de/mlarch/SuSE/kernel/2019/kernel.2019.03/msg00016.html
  some of our patches have been disabled for quite long and attempts to get
  them reviewed failed. Let's drop them now:
  patches.suse/0036-arm-Add-BTB-invalidation-on-switch_mm-for-Cortex-A9-.patch
  patches.suse/0037-arm-Invalidate-BTB-on-prefetch-abort-outside-of-user.patch
  patches.suse/0038-arm-KVM-Invalidate-BTB-on-guest-exit.patch
  patches.suse/0039-arm-Add-icache-invalidation-on-switch_mm-for-Cortex-.patch
  patches.suse/0040-arm-Invalidate-icache-on-prefetch-abort-outside-of-u.patch
  patches.suse/0041-arm-KVM-Invalidate-icache-on-guest-exit-for-Cortex-A.patch
  patches.suse/binutils2_26.patch
  patches.suse/dm-mpath-accept-failed-paths
  patches.suse/pstore-backend-autoaction
- commit 55d6d1e
* Sun Mar 17 2019 mkubecek@suse.cz
- config: enable RANDOM_TRUST_CPU
  The outcome from mailing list discussion when this config option
  appeared was that it makes more sense to enable it by default and let
  those who do not trust their CPU override it on command line; but then
  I forgot to actually change the value.
- commit 138b5df
* Fri Mar 15 2019 tiwai@suse.de
- Update config files: disable CONFIG_FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER (bsc#1127552)
  The deferred fbcon takeover makes little sense with the current openSUSE
  boot setup, and it's harmful (more glitches, etc).  Disable it for now.
- commit 14fa903
* Fri Mar 15 2019 msuchanek@suse.de
- Remove the previous subpackage infrastructure.
  This partially reverts commit 9b3ca32c11854156b2f950ff5e26131377d8445e
  ("Add kernel-subpackage-build.spec (FATE#326579).")
- commit a5ee24e
* Fri Mar 15 2019 msuchanek@suse.de
- Add sample kernel-default-base spec file (FATE#326579, jsc#SLE-4117,
  jsc#SLE-3853, bsc#1128910).
- commit 35c4a52
* Thu Mar 14 2019 msuchanek@suse.de
- Install extra rpm scripts for kernel subpackaging (FATE#326579,
  jsc#SLE-4117, jsc#SLE-3853, bsc#1128910).
- commit ad7c227
* Thu Mar 14 2019 jslaby@suse.cz
- Linux 5.0.2 (bnc#1012628).
- perf/x86/intel: Implement support for TSX Force Abort
  (bnc#1012628).
- x86: Add TSX Force Abort CPUID/MSR (bnc#1012628).
- perf/x86/intel: Generalize dynamic constraint creation
  (bnc#1012628).
- perf/x86/intel: Make cpuc allocations consistent (bnc#1012628).
- ath9k: Avoid OF no-EEPROM quirks without qca,no-eeprom
  (bnc#1012628).
- scripts/gdb: replace flags (MS_xyz -> SB_xyz) (bnc#1012628).
- staging: erofs: compressed_pages should not be accessed again
  after freed (bnc#1012628).
- staging: erofs: keep corrupted fs from crashing kernel in
  erofs_namei() (bnc#1012628).
- gfs2: Fix missed wakeups in find_insert_glock (bnc#1012628).
- bpf: Stop the psock parser before canceling its work
  (bnc#1012628).
- Revert "PCI/PME: Implement runtime PM callbacks" (bnc#1012628).
- media: Revert "media: rc: some events are dropped by userspace"
  (bnc#1012628).
- drm: disable uncached DMA optimization for ARM and arm64
  (bnc#1012628).
- ARM: dts: exynos: Fix max voltage for buck8 regulator on Odroid
  XU3/XU4 (bnc#1012628).
- ARM: dts: exynos: Add minimal clkout parameters to Exynos3250
  PMU (bnc#1012628).
- ARM: dts: exynos: Fix pinctrl definition for eMMC RTSN line
  on Odroid X2/U3 (bnc#1012628).
- arm64: dts: hikey: Revert "Enable HS200 mode on eMMC"
  (bnc#1012628).
- arm64: dts: hikey: Give wifi some time after power-on
  (bnc#1012628).
- arm64: dts: zcu100-revC: Give wifi some time after power-on
  (bnc#1012628).
- x86/PCI: Fixup RTIT_BAR of Intel Denverton Trace Hub
  (bnc#1012628).
- scsi: aacraid: Fix missing break in switch statement
  (bnc#1012628).
- iscsi_ibft: Fix missing break in switch statement (bnc#1012628).
- Input: elan_i2c - add id for touchpad found in Lenovo s21e-20
  (bnc#1012628).
- Input: wacom_serial4 - add support for Wacom ArtPad II tablet
  (bnc#1012628).
- media: uvcvideo: Fix 'type' check leading to overflow
  (bnc#1012628).
- commit 815c1bc
* Mon Mar 11 2019 mkubecek@suse.cz
- Update patches.suse/0001-media-usb-pwc-Don-t-use-coherent-DMA-buffers-for-ISO.patch
  upstream reference.
- commit ff7c8cd
* Sun Mar 10 2019 jslaby@suse.cz
- Linux 5.0.1 (bnc#1012628).
- exec: Fix mem leak in kernel_read_file (bnc#1012628).
- Bluetooth: Fix locking in bt_accept_enqueue() for BH context
  (bnc#1012628).
- Bluetooth: btrtl: Restore old logic to assume firmware is
  already loaded (bnc#1012628).
- selftests: firmware: fix verify_reqs() return value
  (bnc#1012628).
- Revert "selftests: firmware: remove use of non-standard diff
  - Z option" (bnc#1012628).
- Revert "selftests: firmware: add
  CONFIG_FW_LOADER_USER_HELPER_FALLBACK to config" (bnc#1012628).
- USB: serial: cp210x: fix GPIO in autosuspend (bnc#1012628).
- gnss: sirf: fix premature wakeup interrupt enable (bnc#1012628).
- xtensa: fix get_wchan (bnc#1012628).
- aio: Fix locking in aio_poll() (bnc#1012628).
- MIPS: irq: Allocate accurate order pages for irq stack
  (bnc#1012628).
- alpha: wire up io_pgetevents system call (bnc#1012628).
- applicom: Fix potential Spectre v1 vulnerabilities
  (bnc#1012628).
- usb: xhci: Fix for Enabling USB ROLE SWITCH QUIRK on
  INTEL_SUNRISEPOINT_LP_XHCI (bnc#1012628).
- xhci: tegra: Prevent error pointer dereference (bnc#1012628).
- tracing: Fix event filters and triggers to handle negative
  numbers (bnc#1012628).
- x86/boot/compressed/64: Do not read legacy ROM on EFI system
  (bnc#1012628).
- x86/CPU/AMD: Set the CPB bit unconditionally on F17h
  (bnc#1012628).
- tipc: fix RDM/DGRAM connect() regression (bnc#1012628).
- team: Free BPF filter when unregistering netdev (bnc#1012628).
- sky2: Disable MSI on Dell Inspiron 1545 and Gateway P-79
  (bnc#1012628).
- sctp: call iov_iter_revert() after sending ABORT (bnc#1012628).
- qmi_wwan: Add support for Quectel EG12/EM12 (bnc#1012628).
- net-sysfs: Fix mem leak in netdev_register_kobject
  (bnc#1012628).
- net: sched: put back q.qlen into a single location
  (bnc#1012628).
- net: mscc: Enable all ports in QSGMII (bnc#1012628).
- net: dsa: mv8e6xxx: fix number of internal PHYs for 88E6x90
  family (bnc#1012628).
- net: dsa: mv88e6xxx: handle unknown duplex modes gracefully
  in mv88e6xxx_port_set_duplex (bnc#1012628).
- net: dsa: mv88e6xxx: add call to mv88e6xxx_ports_cmode_init
  to probe for new DSA framework (bnc#1012628).
- ip6mr: Do not call __IP6_INC_STATS() from preemptible context
  (bnc#1012628).
- staging: android: ashmem: Avoid range_alloc() allocation with
  ashmem_mutex held (bnc#1012628).
- staging: android: ashmem: Don't call fallocate() with
  ashmem_mutex held (bnc#1012628).
- staging: android: ion: fix sys heap pool's gfp_flags
  (bnc#1012628).
- staging: wilc1000: fix to set correct value for 'vif_num'
  (bnc#1012628).
- staging: comedi: ni_660x: fix missing break in switch statement
  (bnc#1012628).
- staging: erofs: fix illegal address access under memory pressure
  (bnc#1012628).
- staging: erofs: fix race of initializing xattrs of a inode at
  the same time (bnc#1012628).
- staging: erofs: fix memleak of inode's shared xattr array
  (bnc#1012628).
- staging: erofs: fix fast symlink w/o xattr when fs xattr is on
  (bnc#1012628).
- driver core: Postpone DMA tear-down until after devres release
  (bnc#1012628).
- USB: serial: ftdi_sio: add ID for Hjelmslund Electronics USB485
  (bnc#1012628).
- USB: serial: cp210x: add ID for Ingenico 3070 (bnc#1012628).
- USB: serial: option: add Telit ME910 ECM composition
  (bnc#1012628).
- binder: create node flag to request sender's security context
  (bnc#1012628).
- staging: erofs: fix mis-acted TAIL merging behavior
  (bnc#1012628).
- cpufreq: Use struct kobj_attribute instead of struct global_attr
  (bnc#1012628).
- commit 47a2a02
* Thu Mar  7 2019 msuchanek@suse.de
- KMPs: provide and conflict a kernel version specific KMP name
  (bsc#1127155, bsc#1109137).
- commit 5568093
* Wed Mar  6 2019 msuchanek@suse.de
- Revert "Drop multiversion(kernel) from the KMP template (fate#323189)"
  (bsc#1109137).
  This reverts commit 71504d805c1340f68715ad41958e5ef35da2c351.
- commit adade9f
* Tue Mar  5 2019 mkubecek@suse.cz
- config: disable BPFILTER_UMH on non-x86 architectures (bsc#1127188)
  CONFIG_BPFILTER_UMH depends on ability to compile and link a userspace
  binary so that it currently doesn't work in our kbuild check setups using
  a cross compiler. Disable the option on architectures where cross compiler
  is used (i.e. all except x86_64 and i386).
- commit cfb8371
* Mon Mar  4 2019 msuchanek@suse.de
- KMPs: obsolete older KMPs of the same flavour (bsc#1127155, bsc#1109137).
- commit 821419f
* Mon Mar  4 2019 mkubecek@suse.cz
- Update to 5.0 final
- Refresh configs
- commit 8f71df2
* Wed Feb 27 2019 msuchanek@suse.de
- BPF: UMH: do not detect if compiler can link userspace program
  (boo#1127188).
- commit 784e336
* Mon Feb 25 2019 mkubecek@suse.cz
- Update to 5.0-rc8
- Eliminated 1 patch
- commit 4ddf057
* Fri Feb 22 2019 mkubecek@suse.cz
- net: crypto set sk to NULL when af_alg_release (CVE-2019-8912
  bsc#1125907).
- commit 3aed52e
* Fri Feb 22 2019 mkubecek@suse.cz
- config: enable PREEMPT_VOLUNTARY (bsc#1125004)
  Switch to PREEMPT_VOLUNTARY everywhere except s390x/zfcpdump.
- commit f62cec7
* Tue Feb 19 2019 mbenes@suse.cz
- rpm/klp-symbols: Remove the second column in Symbols.list
  Symbols.list file contains also a symbol type next to its name.
  klp-convert cannot handle it well and it is superfluous anyway.
- commit 62a0a00
* Mon Feb 18 2019 msuchanek@suse.de
- powerpc/tm: Flip the HTM switch default to disabled
  (bsc#1125580, jsc#SLE-16056).
- commit e5be95e
* Mon Feb 18 2019 mkubecek@suse.cz
- Update to 5.0-rc7
- commit b094e66
* Mon Feb 11 2019 mkubecek@suse.cz
- Update to 5.0-rc6
- commit eb4b248
* Fri Feb  8 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Build livepatch support in SUSE release
  projects (bsc#1124167).
- commit 7519080
* Sun Feb  3 2019 mkubecek@suse.cz
- Update to 5.0-rc5
- Config changes:
  - x86:
  - X86_RESCTRL renamed to X86_CPU_RESCTRL
- commit a42dcc6
* Wed Jan 30 2019 mwilck@suse.com
- rpm/kernel-binary.spec.in: fix initrd permissions (bsc#1123697)
  dracut has been using permissions 0600 for the initrd for a long
  time. On SLE15 or higher, that leads to a permission mismatch
  reported by "rpm -V". Set the permissions correctly for our
  ghost file.
- commit 9e5e2a5
* Mon Jan 28 2019 tiwai@suse.de
- doc/README.SUSE: Correct description for building a kernel (bsc#1123348)
  The obsoleted make cloneconfig is corrected.  Also the order of make
  scripts and make prepare are corrected as well.
- commit 17a2073
* Mon Jan 28 2019 tiwai@suse.de
- rpm/release-projects: Add SUSE:Maintenance:* for MU kernels (bsc#1123317)
- commit c784b79
* Mon Jan 28 2019 mkubecek@suse.cz
- Update to 5.0-rc4
- commit 8e6abff
* Thu Jan 24 2019 ptesarik@suse.cz
- Add product identifying information to VMCOREINFO (bsc#1123015).
- commit 68ca35e
* Thu Jan 24 2019 msuchanek@suse.de
- rpm/kernel-*.spec.in: replace update srchash dependencies (FATE#325312).
  Due to some limitations version cannot be matched so move the hash into
  the provide name.
- commit 219bcec
* Tue Jan 22 2019 oneukum@suse.com
- media: usb: pwc: Don't use coherent DMA buffers for ISO transfer
  (bsc#1054610).
- commit 59d243a
* Mon Jan 21 2019 mkubecek@suse.cz
- Update to 5.0-rc3
- Config changes:
  - ARM64:
  - HSA_AMD=y
- commit 05bf5c0
* Mon Jan 14 2019 mkubecek@suse.cz
- Update to 5.0-rc2
- Config changes:
  - x86:
  - RESCTRL renamed to X86_RESCTRL
- commit 879eb5c
* Fri Jan 11 2019 afaerber@suse.de
- config: arm64: Update to 5.0-rc1
- commit 88c2434
* Mon Jan  7 2019 mkubecek@suse.cz
- config: restore accidentally lost BPFILTER_UMH (ppc64, ppc64le, s390x)
- commit a56baa9
* Mon Jan  7 2019 mkubecek@suse.cz
- vfio_pci: Add local source directory as include.
- commit ea6d6e3
* Mon Jan  7 2019 mkubecek@suse.cz
- Update to 5.0-rc1
- Eliminated 1 patch
- ARM configs need update
- Config changes:
  - PM:
  - ENERGY_MODEL=y
  - Networking:
  - CAN_FLEXCAN=m
  - USB_NET_AQC111=m
  - QTNFMAC_PCIE=m
  - VIRT_WIFI=m
  - PCI:
  - PCI_MESON=n
  - SCSI:
  - SCSI_UFS_CDNS_PLATFORM=m
  - NVME:
  - NVME_TCP=m
  - NVME_TARGET_TCP=m
  - Graphics:
  - DRM_PANEL_OLIMEX_LCD_OLINUXINO=n
  - DRM_PANEL_SAMSUNG_S6D16D0=n
  - DRM_PANEL_TRULY_NT35597_WQXGA=n
  - TINYDRM_HX8357D=n
  - Sound:
  - SND_SOC_AMD_ACP3x=n
  - SND_SOC_INTEL_KBL_RT5660_MACH=m
  - SND_SOC_XILINX_I2S=n
  - SND_SOC_AK4118=n
  - Multimedia:
  - VIDEO_ASPEED=m
  - VIDEO_SECO_CEC=m
  - VIDEO_SECO_RC=y
  - I3C:
  - I3C=m
  - CDNS_I3C_MASTER=m
  - DW_I3C_MASTER=m
  - IIO:
  - AD7124=n
  - AD7949=n
  - TI_DAC7311=n
  - VCNL4035=n
  - SENSORS_RM3100_I2C=n
  - SENSORS_RM3100_SPI=n
  - MCP41010=m
  - PHY:
  - PHY_CADENCE_SIERRA=m
  - PHY_FSL_IMX8MQ_USB=m
  - misc drivers:
  - MTD_PHYSMAP_GPIO_ADDR=y
  - SPI_MXIC=n
  - MISC_ALCOR_PCI=m
  - RC_XBOX_DVD=m
  - PINCTRL_OCELOT=n
  - GPIO_CADENCE=m
  - SENSORS_OCC_P8_I2C=m
  - TQMX86_WDT=m
  - MMC_ALCOR=m
  - MMC_SDHCI_AM654=m
  - LEDS_TRIGGER_AUDIO=m
  - SERIO_OLPC_APSP=m
  - Security:
  - INTEGRITY_PLATFORM_KEYRING=y
  - IMA_ARCH_POLICY=y
  - Crypto:
  - CRYPTO_ADIANTUM=m
  - CRYPTO_STREEBOG=m
  - CRYPTO_STATS=n
  - Library:
  - RAID6_PQ_BENCHMARK=y (preserve current behaviour)
  - Testing:
  - TEST_OBJAGG=n
  - x86:
  - RESCTRL=y
  - HUAWEI_WMI=m
  - i386:
  - PVH=y
  - MTD_PHYSMAP_OF=m
  - ppc*:
  - PVPANIC=m
  - FB_LOGO_CENTER=n
  - FSI_OCC=m
  - DEBUG_VIRTUAL=n
  - SENSORS_OCC_P9_SBE=m
  - s390x:
  - PCCARD=n
  - RAPIDIO
  - other RapidIO options copy other architectures
  - DMADEVICES related options copy other architectures
  - */debug:
  - CRYPTO_STATS=y
  - TTY_PRINTK_LEVEL=6
- commit 6a4ceaa
* Mon Dec 24 2018 mkubecek@suse.cz
- Update to 4.20 final
- Eliminated 1 patch
- Refresh configs
- commit ba5c149
* Fri Dec 21 2018 mkubecek@suse.cz
- rtlwifi: Fix leak of skb when processing C2H_BT_INFO
  (bsc#1116448).
- commit 9d82d20
* Mon Dec 17 2018 mkubecek@suse.cz
- Update to 4.20-rc7
- Config changes:
  - ARM:
  - MEDIA_CONTROLLER_REQUEST_API=y
- commit 4731528
* Mon Dec 10 2018 afaerber@suse.de
- config: arm: Enable EFI support (boo#1104833)
- commit 7050650
* Mon Dec 10 2018 afaerber@suse.de
- config: armv7hl: Update to 4.20-rc5
- commit f01387b
* Mon Dec 10 2018 jslaby@suse.cz
- Delete
  patches.suse/blk-mq-fix-corruption-with-direct-issue.patch.
  It is in 4.20-rc6 as ffe81d45322c but was partially reverted by
  c616cbee97ae, so this patch still applies cleanly, but is unwanted.
  Drop it.
- commit 7670339
* Mon Dec 10 2018 mkubecek@suse.cz
- Update to 4.20-rc6
- Eliminated 1 patch
- Refresh configs
- commit 93f10c3
* Sat Dec  8 2018 msuchanek@suse.de
- Include modules.fips in kernel-binary as well as kernel-binary-base
  (FATE#323247).
- commit e42315d
* Fri Dec  7 2018 jslaby@suse.cz
- x86/build: Fix compiler support check for CONFIG_RETPOLINE
  (KMP build).
- commit fb5fd39
* Wed Dec  5 2018 mkubecek@suse.cz
- blk-mq: fix corruption with direct issue (bko#201685).
- commit 8970eff
* Tue Dec  4 2018 jroedel@suse.de
- blacklist.conf: Blacklist MAINTAINERS file
- commit c4b3c90
* Mon Dec  3 2018 afaerber@suse.de
- config: armv6hl: Update to 4.20-rc5
- commit c85b385
* Mon Dec  3 2018 guillaume.gardet@free.fr
- config: armv7hl: Build some options as modules (boo#1104833)
  Enable HISI_THERMAL=m while at it.
- commit c9b9dd6
* Mon Dec  3 2018 mkubecek@suse.cz
- Update to 4.20-rc5
- Config changes:
  - General:
  - PSI_DEFAULT_DISABLED=y
  - Sound:
  - SND_SOC_INTEL_SKYLAKE_HDAUDIO_CODEC=y
  - ARM:
  - ARM64_ERRATUM_1286807=y
- commit 2ccaf30
* Mon Nov 26 2018 mkubecek@suse.cz
- Update to 4.20-rc4
- Config changes:
  - Networking:
  - MT76_LEDS=y (split from MT76_CORE)
- commit 1ac69b7
* Fri Nov 23 2018 msuchanek@suse.de
- Build ppc64le for POWER8+ (FATE#325617).
- commit f6da51b
* Fri Nov 23 2018 msuchanek@suse.de
- Revert "Remove Cell/PS3 support from ppc64 kernel (boo#1114846)"
  This reverts commit fd6aaf7f98693355e7dcc5e4e1926fb1664d803b.
  Fixed upstream in 43c6494fa149 ("powerpc/io: Fix the IO workarounds code
  to work with Radix")
- commit 4f86993
* Tue Nov 20 2018 rgoldwyn@suse.com
- apparmor: fix unnecessary creation of net-compat (bsc#1116724).
- commit f5cf767
* Mon Nov 19 2018 mkubecek@suse.cz
- Update to 4.20-rc3
- Refresh configs
- commit 81d20d2
* Tue Nov 13 2018 msuchanek@suse.de
- Add kernel-subpackage-build.spec (FATE#326579).
  - add kernel-subpackage-build.spec.in and support scripts
  - hook it in mkspec
  - extend the mechanism that copies dependencies inside
  kernel-binary.spec.in from kernel-%%build_flavor to
  kernel-%%build_flavor-base to also handle
  kernel-subpackage-build.spec.in using BINARY DEPS marker.
  - expand %%name in kernel-%%build_flavor so the dependencies are expanded
  correctly in kernel-subpackage-build.spec.in
- commit 9b3ca32
* Mon Nov 12 2018 mkubecek@suse.cz
- Update to 4.20-rc2
- Eliminated 1 patch
- Config changes:
  - I2C:
    I2C_NVIDIA_GPU=m
  - USB:
    UCSI_CCG=m
- commit 1c08d7f
* Sun Nov 11 2018 afaerber@suse.de
- config: arm64: Update to 4.20-rc1
- commit 2d02cd8
* Thu Nov  8 2018 jslaby@suse.cz
- doc/README.SUSE: correct GIT url
  No more gitorious, github we use.
- commit 31864f3
* Tue Nov  6 2018 mkubecek@suse.cz
- config: reenable BPFILTER_UMH on ppc64
- commit 46cb36e
* Tue Nov  6 2018 agraf@suse.de
- Remove Cell/PS3 support from ppc64 kernel (boo#1114846)
- commit fd6aaf7
* Mon Nov  5 2018 mkubecek@suse.cz
- scripts/mkmakefile: honor second argument.
- commit 78325a6
* Mon Nov  5 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: add macros.s into kernel-*-devel
  Starting with 4.20-rc1, file arch/*/kernel/macros.s is needed to build out
  of tree modules. Add it to kernel-${flavor}-devel packages if it exists.
- commit 09d14c8
* Mon Nov  5 2018 mkubecek@suse.cz
- series.conf: delete an obsolete comment
- commit c3bd57d
* Mon Nov  5 2018 jslaby@suse.cz
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
  Adapt to 4.20.
- commit dcaec93
* Mon Nov  5 2018 mkubecek@suse.cz
- Update to 4.20-rc1
- ARM configs need updating
- disabled (needs refresh):
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch
- Config changes:
  - General:
  - PSI=y
  - Networking:
  - NFT_XFRM=m
  - NET_SCH_TAPRIO=m
  - BATMAN_ADV_TRACING=n
  - NCSI_OEM_CMD_GET_MAC=y
  - EEPROM_EE1004=m
  - SCSI_UFS_BSG=y
  - SCSI_MYRB=m
  - SCSI_MYRS=m
  - IXGBE_IPSEC=y
  - IXGBEVF_IPSEC=y
  - IGC=m
  - NI_XGE_MANAGEMENT_ENET=m
  - MT76x0E=m
  - File systems:
  - EROFS_FS_IO_MAX_RETRIES=5 (default)
  - AFS_DEBUG_CURSOR=n
  - CONFIG_UBIFS_FS_AUTHENTICATION=y
  - Crypto:
  - CRYPTO_OFB=m
  - CRYPTO_STATS=n
  - ASYMMETRIC_TPM_KEY_SUBTYPE=m
  - PKCS8_PRIVATE_KEY_PARSER=m
  - TPM_KEY_PARSER=m
  - Graphics:
  - VIDEO_VICODEC=m
  - DRM_FBDEV_LEAK_PHYS_SMEM=n
  - DRM_I915_DEBUG_RUNTIME_PM=n
  - DRM_TOSHIBA_TC358764=n
  - DRM_TI_SN65DSI86=n
  - Sound:
  - SND_SOC_INTEL_KBL_DA7219_MAX98927_MACH=m
  - SND_SOC_INTEL_SKL_HDA_DSP_GENERIC_MACH=m
  - SND_SOC_MAX98088=n
  - SND_SOC_PCM3060_I2C=n
  - SND_SOC_PCM3060_SPI=n
  - SND_SOC_NAU8822=n
  - Input devices:
  - HID_BIGBEN_FF=m
  - Platform:
  - LG_LAPTOP=m
  - INTEL_ATOMISP2_PM=m
  - IIO:
  - ADXL372_SPI=n
  - ADXL372_I2C=n
  - MCP3911=n
  - QCOM_SPMI_ADC5=n
  - LTC1660=n
  - VL53L0X_I2C=m
  - Misc drivers:
  - UDMABUF=y
  - MFD_AT91_USART=n
  - LEDS_AN30259A=n
  - LEDS_TRIGGER_PATTERN=m
  - PHY_CADENCE_DP=m
  - STM_PROTO_BASIC=m
  - STM_PROTO_SYS_T=m
  - Testing:
  - TEST_XARRAY=n
  - TEST_MEMCAT_P=n
  - x86:
  - X86_CPA_STATISTICS=n (y for -debug)
  - i386:
  - MSCC_OCELOT_SWITCH_OCELOT=m
  - ppc64, ppc64le:
  - PAPR_SCM=m
  - PCI_P2PDMA=y
  - STACKPROTECTOR=y
  - STACKPROTECTOR_STRONG=n
  - BLK_DEV_PMEM=m
  - ND_BLK=m
  - BTT=y
  - NVDIMM_PFN=y
  - NVDIMM_DAX=y
  - OF_PMEM=m
  - DEV_DAX_PMEM=m
  - FAIL_FUNCTION=n
  - ENA_ETHERNET=m
  - s390:
  - VMAP_STACK=y
  - S390_AP_IOMMU=n
  - ZCRYPT_MULTIDEVNODES=y
  - KASAN=n
  - */debug:
  - INTEL_IOMMU_DEBUGFS=y
  - BPF_KPROBE_OVERRIDE=y
  - CONFIG_X86_CPA_STATISTICS=y
  - CONFIG_CRYPTO_STATS=y
- commit f29310b
* Sun Nov  4 2018 mkubecek@suse.cz
- rpm: use syncconfig instead of silentoldconfig where available
  Since mainline commit 0085b4191f3e ("kconfig: remove silentoldconfig
  target"), "make silentoldconfig" can be no longer used. Use "make
  syncconfig" instead if available.
- commit a239c6e
* Fri Nov  2 2018 mkubecek@suse.cz
- series.conf: more descriptive name for network driver section
  We have two networking sections in series.conf: one for networking core and
  one for network drivers. The latter is among other driver related sections
  but it may not be obvious that it is not intended for core networking
  patches. Change the label to "Network drivers" to make its purpose more
  apparent.
- commit 7968e32
* Fri Nov  2 2018 mkubecek@suse.cz
- config: enable SCSI_AACRAID on ppc64le and ppc64 (bsc#1114523)
- commit 5f3762b
* Tue Oct 30 2018 jslaby@suse.cz
- Refresh
  patches.suse/netfilter-bridge-define-INT_MIN-INT_MAX-in-userspace.patch.
  Update upstream status.
- commit 37417fa
* Mon Oct 29 2018 jmoreira@suse.de
- Add version information to KLP_SYMBOLS file
- commit f77f8d2
* Thu Oct 25 2018 mwilck@suse.com
- rpm/kernel-binary.spec.in: allow unsupported modules for -extra
  (bsc#1111183). SLE-15 and later only.
- commit 0d585a8
* Wed Oct 24 2018 mkubecek@suse.cz
- series.conf: move patches.suse/netfilter-bridge-define-INT_MIN-INT_MAX-in-userspace.patch to netfilter section
- commit 7656685
* Wed Oct 24 2018 jslaby@suse.cz
- netfilter: bridge: define INT_MIN & INT_MAX in userspace
  (4.19 fixes).
- commit e7213f6
* Mon Oct 22 2018 mkubecek@suse.cz
- Update to 4.19 final
- Refresh configs
- commit b4c35bb
* Mon Oct 15 2018 mkubecek@suse.cz
- Update to 4.19-rc8
- commit 2e61ca8
* Fri Oct 12 2018 tzimmermann@suse.de
- README: Clean-up trailing whitespace
- commit 06542f9
* Thu Oct 11 2018 tzimmermann@suse.de
- README: Update documentation wrt. Patch-mainline
  Common practice is to set Patch-mainline to a Linux release tag. More
  than 95%% of all patches follow this convention. The remaining 5%% have
  been fixed accordingly in SLE15.
  The README file is inconsistent wrt. to the content of Patch-mainline.
  In some places it refers to a release tag, in others it refers to a version
  number. With this cleanup, it refers to release tags everywhere.
  This change is a follow-up for commit 1d81d2699cd3.
- commit 57326f5
* Tue Oct  9 2018 msuchanek@suse.de
- Revert "Limit kernel-source build to architectures for which we build binaries"
  This reverts commit d6435125446d740016904abe30a60611549ae812.
- commit 48b03c4
* Mon Oct  8 2018 mkubecek@suse.cz
- Update to 4.19-rc7
- commit 63b130b
* Thu Oct  4 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1110716)
  Enable ST LPS25H pressure sensor.
- commit 9882f33
* Tue Oct  2 2018 nborisov@suse.com
- Update config files. (boo##1109665)
- commit 76516eb
* Mon Oct  1 2018 msuchanek@suse.de
- rpm/mkspec: fix ppc64 kernel-source build.
- commit 85c9272
* Sun Sep 30 2018 mkubecek@suse.cz
- Update to 4.19-rc6
- Eliminated 2 patches
- commit 80aa112
* Fri Sep 28 2018 lduncan@suse.com
- Added CVE numbers for two patches (bsc#1107829)
- commit e3ac2a8
* Fri Sep 28 2018 lduncan@suse.com
- scsi: target: iscsi: Use bin2hex instead of a re-implementation
  (bsc#1107829).
- scsi: target: iscsi: Use hex2bin instead of a re-implementation
  (bsc#1107829).
- commit 8791706
* Thu Sep 27 2018 msuchanek@suse.de
- rpm/mkspec: build dtbs for architectures marked -!needs_updating
- commit 2d47640
* Thu Sep 27 2018 msuchanek@suse.de
- Limit kernel-source build to architectures for which we build binaries
  (bsc#1108281).
- commit d643512
* Tue Sep 25 2018 mbrugger@suse.com
- arm64: Update config files.
  Increase NR_CPUS to 480 (fate#325592)
- commit d5464c0
* Mon Sep 24 2018 mkubecek@suse.cz
- Update to 4.19-rc5
- commit b44d7bc
* Mon Sep 17 2018 mkubecek@suse.cz
- Update to 4.19-rc4
- Eliminated 1 patch
- Config changes:
  - Filesystems:
  - EROFS_FS=m
  - EROFS_FS_DEBUG=n
  - EROFS_FS_XATTR=y
  - EROFS_FS_POSIX_ACL=y
  - EROFS_FS_SECURITY=y
  - EROFS_FS_USE_VM_MAP_RAM=n
  - EROFS_FAULT_INJECTION=n
  - EROFS_FS_ZIP=n
- commit 625b101
* Fri Sep 14 2018 mkubecek@suse.cz
- ip: frags: fix crash in ip_do_fragment() (bsc#1108533).
- commit ba41502
* Fri Sep 14 2018 msuchanek@suse.de
- doc/README.SUSE: Remove mentions of cloneconfig (bsc#1103636).
- commit 3371adc
* Thu Sep 13 2018 jbohac@suse.cz
- Delete patches.suse/x86_64-hpet-64bit-timer.patch.
  We removed the patch from SLE15 in commit
  20efbd0c034fea7c97243120a025587d0dbac1c2
  and we don't need it in future versions of SLE.
- commit aa4eb67
* Mon Sep 10 2018 msuchanek@suse.de
- macros.kernel-source: pass -b properly in kernel module package
  (bsc#1107870).
- commit 66709cd
* Mon Sep 10 2018 mkubecek@suse.cz
- Update to 4.19-rc3
- refresh configs
- commit d3995d7
* Fri Sep  7 2018 jeffm@suse.com
- config: disable HFS_FS
  It has no maintainer and has been a source of fuzzer bugs.  hfsplus handles
  the HFS+ file system that became the default on MacOS in 1998.
- commit 0d9481c
* Fri Sep  7 2018 tiwai@suse.de
- supported.conf: Add bpfilter to kernel-default-base (bsc#1106751)
- commit 8f1f1b6
* Mon Sep  3 2018 jslaby@suse.cz
- rpm/kernel-binary.spec.in: fix call of split-modules
  split-modules is called with some parameters depending on config
  options. But since we do not use backslash consistelny, the call to
  split-modules might be evaluated so that also the following cat
  command is appended. Avoid this behaviour by using backslashes
  everywhere and add %%nil to the end.
  This perhaps never happens, but stay on the safe side.
- commit 32df888
* Mon Sep  3 2018 mkubecek@suse.cz
- Update to 4.19-rc2
- refresh configs
- commit a9462db
* Sat Sep  1 2018 afaerber@suse.de
- config: arm64: Increase SERIAL_8250_RUNTIME_UARTS to 32 (boo#1073193)
  (cherry picked from commit 0dbc49ba128ef0931ca04cf22ec5c638534f5b23)
- commit 6aae50e
* Sat Sep  1 2018 afaerber@suse.de
- config: Enable SERIAL_SC16IS7XX_SPI on arm and x86 (bsc#1105672, fate#326668)
  (cherry picked from commit cdc9eced6d892ff77abbeef5f0d5eb38c114602c)
- commit 22a4d36
* Sat Sep  1 2018 afaerber@suse.de
- config: Consistently increase SERIAL_8250_NR_UARTS to 32 (boo#1073193)
  (cherry picked from commit acb36abf212a3a7428d958798d678d82351f4658)
- commit 090b553
* Sat Sep  1 2018 afaerber@suse.de
- config: armv7hl: Update to 4.19-rc1
- commit d1f42dc
* Sat Sep  1 2018 afaerber@suse.de
- config: armv7hl: Update to 4.18.5 (bsc#1012628)
  (cherry picked from commit fa0ebc5508eedec2c9108cafdf854a8c53a28a83)
  [AF: Don't re-enable the configs yet]
- commit f2722e4
* Sat Sep  1 2018 afaerber@suse.de
- config: armv6hl: Update to 4.19-rc1
- commit 2f56919
* Fri Aug 31 2018 afaerber@suse.de
- config: armv6hl: Update to 4.18.5 (bsc#1012628)
  (cherry picked from commit e9071067714392290f6b0d525c77c8abfa8cf075)
  [AF: Don't re-enable configs yet]
- commit d01db43
* Fri Aug 31 2018 afaerber@suse.de
- config: arm64: Update to 4.19-rc1
- commit a6a88d1
* Wed Aug 29 2018 mkubecek@suse.cz
- powerpc/boot: Fix missing crc32poly.h when building with
  KERNEL_XZ.
- Delete
  patches.rpmify/Revert-lib-Use-existing-define-with-polynomial.patch.
- commit cba84f7
* Wed Aug 29 2018 mkubecek@suse.cz
- kernel-binary: check also bzImage on s390/s390x
  Starting with 4.19-rc1, uncompressed image is no longer built on s390x.
  If file "image" is not found in arch/s390/boot after the build, try bzImage
  instead.
  For now, install bzImage under the name image-* until we know grub2 and our
  grub2 scripts can handle correct name.
- commit 92b52c6
* Tue Aug 28 2018 jbeulich@suse.com
- Refresh patches.suse/supported-flag after upstream commit b2c5cdcfd4.
- Refresh
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch.
- commit 8b0e2e5
* Mon Aug 27 2018 mkubecek@suse.cz
- Revert "lib: Use existing define with polynomial".
- commit 1dc6366
* Mon Aug 27 2018 mkubecek@suse.cz
- Update to 4.19-rc1
- Eliminated 179 patches (167 stable, 12 other)
- ARM configs need updating
- Config changes:
  - Block:
  - BLK_CGROUP_IOLATENCY=y
  - Networking:
  - XFRM_INTERFACE=m
  - NETFILTER_NETLINK_OSF=m
  - NFT_TUNNEL=m
  - NFT_OSF=m
  - NFT_TPROXY=m
  - NET_SCH_ETF=m
  - NET_SCH_SKBPRIO=m
  - NET_SCH_CAKE=m
  - CAN_UCAN=m
  - BT_HCIUART_RTL=y
  - BT_MTKUART=m
  - BCMGENET=m
  - SYSTEMPORT=m
  - BNXT_HWMON=y
  - NET_VENDOR_CADENCE=y	(rename)
  - BE2NET_BE2=y
  - BE2NET_BE3=y
  - BE2NET_LANCER=y
  - BE2NET_SKYHAWK=y
  - MLX5_EN_ARFS=y
  - MLX5_EN_RXNFC=y
  - NET_VENDOR_NETERION=y
  - NET_VENDOR_PACKET_ENGINES=y
  - MT76x0U=m
  - MT76x2U=m
  - IEEE802154_HWSIM=m
  - File systems:
  - OVERLAY_FS_METACOPY=n
  - UBIFS_FS_XATTR=y
  - PSTORE_ZSTD_COMPRESS=y
  - CIFS_ALLOW_INSECURE_LEGACY=y
  - Security:
  - RANDOM_TRUST_CPU=n
  - IMA_APPRAISE_BUILD_POLICY=n
  - Hacking:
  - CONSOLE_LOGLEVEL_QUIET=4
  - KPROBE_EVENTS_ON_NOTRACE=n
  - TEST_BITFIELD=n
  - TEST_IDA=n
  - Library:
  - CRC64=m
  - Graphics:
  - VIDEO_CROS_EC_CEC=m
  - DRM_DP_CEC=y
  - DRM_VKMS=m
  - TINYDRM_ILI9341=n
  - FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER=y
  - Sound:
  - SND_SOC_INTEL_GLK_RT5682_MAX98357A_MACH=m
  - SND_SOC_ES7241=n
  - SND_SOC_SIMPLE_AMPLIFIER=n
  - Input:
  - TOUCHSCREEN_ADC=m
  - TOUCHSCREEN_BU21029=m
  - HID_COUGAR=m
  - USB:
  - TYPEC_DP_ALTMODE=m
  - Multifunction:
  - MFD_MADERA=m
  - MFD_MADERA_I2C=m
  - MFD_MADERA_SPI=m
  - GPIO_MADERA=m
  - MFD_CS47L35=y
  - MFD_CS47L85=y
  - MFD_CS47L90=y
  - IIO:
  - BME680=m
  - AD5758=n
  - SI1133=n
  - ISL29501=m
  - FPGA:
  - FPGA_DFL=m
  - FPGA_DFL_FME=m
  - FPGA_DFL_FME_MGR=m
  - FPGA_DFL_FME_BRIDGE=m
  - FPGA_DFL_FME_REGION=m
  - FPGA_DFL_AFU=m
  - FPGA_DFL_PCI=m
  - XILINX_PR_DECOUPLER=m
  - Power management:
  - IDLE_INJECT=y
  - CHARGER_ADP5061=m
  - CHARGER_CROS_USBPD=m
  - SENSORS_MLXREG_FAN=m
  - SENSORS_NPCM7XX=m
  - Misc drivers:
  - GNSS=m
  - GNSS_SERIAL=m
  - GNSS_SIRF_SERIAL=m
  - GNSS_UBX_SERIAL=m
  - MTD_SPI_NAND=m
  - NVM_PBLK_DEBUG=n
  - PINCTRL_ICELAKE=m
  - COMMON_CLK_MAX9485=n
  - IOMMU_DEFAULT_PASSTHROUGH=n
  - XEN:
  - XEN_GRANT_DMA_ALLOC=y
  - XEN_GNTDEV_DMABUF=y
  - x86:
  - STAGING_GASKET_FRAMEWORK=m
  - STAGING_APEX_DRIVER=m
  - XIL_AXIS_FIFO=m
  - TOUCHSCREEN_DMI=y
  - I2C_MULTI_INSTANTIATE=m
  - CROS_EC_I2C=m
  - CROS_EC_SPI=m
  - MLXREG_IO=m
  - i386:
  - PCIE_XILINX=y
  - MFD_ROHM_BD718XX=n
  - DRM_PANEL_ILITEK_ILI9881C=n
  - MMC_SDHCI_OF_DWCMSHC=n
  - PAGE_TABLE_ISOLATION=y
  - PowerPC:
  - I2C_MUX_PINCTRL=m
  - I2C_DEMUX_PINCTRL=m
  - I2C_FSI=m
  - DEBUG_PINCTRL=n
  - PINCTRL_AMD=m
  - PINCTRL_MCP23S08=n
  - PINCTRL_SINGLE=n
  - PINCTRL_SX150X=n
  - LEDS_AAT1290=n
  - FSI_NEW_DEV_NODE=n
  - FSI_SBEFIFO=m
  - S/390:
  - KERNEL_GZIP=y
  - S2IO=m
  - VXGE=m
  - VXGE_DEBUG_TRACE_ALL=n
  - HAMACHI=m
  - YELLOWFIN=m
  - MDIO_BCM_UNIMAC=m
  - ISM=m
  - */debug:
  - NVM_PBLK_DEBUG=y
  - IOMMU_DEBUGFS=y
  - PREEMPTIRQ_DELAY_TEST=m
- commit a3b9cac
* Fri Aug 24 2018 jslaby@suse.cz
- Linux 4.18.5 (bnc#1012628).
- reiserfs: fix broken xattr handling (heap corruption, bad
  retval) (bnc#1012628).
- i2c: imx: Fix race condition in dma read (bnc#1012628).
- i2c: core: ACPI: Properly set status byte to 0 for multi-byte
  writes (bnc#1012628).
- PCI: pciehp: Fix unprotected list iteration in IRQ handler
  (bnc#1012628).
- PCI: pciehp: Fix use-after-free on unplug (bnc#1012628).
- PCI: Skip MPS logic for Virtual Functions (VFs) (bnc#1012628).
- PCI: aardvark: Size bridges before resources allocation
  (bnc#1012628).
- PCI: hotplug: Don't leak pci_slot on registration failure
  (bnc#1012628).
- PCI / ACPI / PM: Resume all bridges on suspend-to-RAM
  (bnc#1012628).
- PCI: Restore resized BAR state on resume (bnc#1012628).
- parisc: Remove ordered stores from syscall.S (bnc#1012628).
- parisc: Remove unnecessary barriers from spinlock.h
  (bnc#1012628).
- drm/amdgpu/pm: Fix potential Spectre v1 (bnc#1012628).
- drm/i915/kvmgt: Fix potential Spectre v1 (bnc#1012628).
- ext4: fix spectre gadget in ext4_mb_regular_allocator()
  (bnc#1012628).
- powerpc64s: Show ori31 availability in spectre_v1 sysfs file
  not v2 (bnc#1012628).
- x86/mm/init: Remove freed kernel image areas from alias mapping
  (bnc#1012628).
- x86/mm/init: Add helper for freeing kernel image pages
  (bnc#1012628).
- x86/mm/init: Pass unconverted symbol addresses to
  free_init_pages() (bnc#1012628).
- mm: Allow non-direct-map arguments to free_reserved_area()
  (bnc#1012628).
- pty: fix O_CLOEXEC for TIOCGPTPEER (bnc#1012628).
- EDAC: Add missing MEM_LRDDR4 entry in edac_mem_types[]
  (bnc#1012628).
- commit d918293
* Fri Aug 24 2018 vbabka@suse.cz
- x86/speculation/l1tf: Suggest what to do on systems with too
  much RAM (bsc#1105536).
- x86/speculation/l1tf: Fix off-by-one error when warning that
  system has too much RAM (bsc#1105536).
- x86/speculation/l1tf: Fix overflow in l1tf_pfn_limit() on 32bit
  (OBS failures reported on IRC).
- commit f3b24ad
* Fri Aug 24 2018 jslaby@suse.cz
- Update config files.
- Delete
  patches.suse/revert-mm-relax-deferred-struct-page-requirements.patch.
  We actually do not this non-upstream revert. We only need the config
  change. That is: leave DEFERRED_STRUCT_PAGE_INIT=n for i386 as it was
  before 4.16.
- commit 161b8ee
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.4 (bnc#1012628).
- l2tp: use sk_dst_check() to avoid race on sk->sk_dst_cache
  (bnc#1012628).
- net_sched: fix NULL pointer dereference when delete tcindex
  filter (bnc#1012628).
- net_sched: Fix missing res info when create new tc_index filter
  (bnc#1012628).
- r8169: don't use MSI-X on RTL8168g (bnc#1012628).
- ALSA: hda - Sleep for 10ms after entering D3 on Conexant codecs
  (bnc#1012628).
- ALSA: hda - Turn CX8200 into D3 as well upon reboot
  (bnc#1012628).
- ALSA: vx222: Fix invalid endian conversions (bnc#1012628).
- ALSA: virmidi: Fix too long output trigger loop (bnc#1012628).
- ALSA: cs5535audio: Fix invalid endian conversion (bnc#1012628).
- ALSA: dice: fix wrong copy to rx parameters for Alesis iO26
  (bnc#1012628).
- ALSA: hda: Correct Asrock B85M-ITX power_save blacklist entry
  (bnc#1012628).
- ALSA: memalloc: Don't exceed over the requested size
  (bnc#1012628).
- ALSA: vxpocket: Fix invalid endian conversions (bnc#1012628).
- ALSA: seq: Fix poll() error return (bnc#1012628).
- media: gl861: fix probe of dvb_usb_gl861 (bnc#1012628).
- USB: serial: sierra: fix potential deadlock at close
  (bnc#1012628).
- USB: serial: pl2303: add a new device id for ATEN (bnc#1012628).
- USB: option: add support for DW5821e (bnc#1012628).
- ACPI / PM: save NVS memory for ASUS 1025C laptop (bnc#1012628).
- tty: serial: 8250: Revert NXP SC16C2552 workaround
  (bnc#1012628).
- serial: 8250_exar: Read INT0 from slave device, too
  (bnc#1012628).
- serial: 8250_dw: always set baud rate in dw8250_set_termios
  (bnc#1012628).
- serial: 8250_dw: Add ACPI support for uart on Broadcom SoC
  (bnc#1012628).
- uio: fix wrong return value from uio_mmap() (bnc#1012628).
- misc: sram: fix resource leaks in probe error path
  (bnc#1012628).
- Revert "uio: use request_threaded_irq instead" (bnc#1012628).
- Bluetooth: avoid killing an already killed socket (bnc#1012628).
- isdn: Disable IIOCDBGVAR (bnc#1012628).
- net: sock_diag: Fix spectre v1 gadget in __sock_diag_cmd()
  (bnc#1012628).
- r8169: don't use MSI-X on RTL8106e (bnc#1012628).
- ip_vti: fix a null pointer deferrence when create vti fallback
  tunnel (bnc#1012628).
- net: ethernet: mvneta: Fix napi structure mixup on armada 3700
  (bnc#1012628).
- net: mvneta: fix mvneta_config_rss on armada 3700 (bnc#1012628).
- cls_matchall: fix tcf_unbind_filter missing (bnc#1012628).
- commit a7b92e4
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.3 (bnc#1012628).
- x86/speculation/l1tf: Exempt zeroed PTEs from inversion
  (bnc#1012628).
- commit a14f6a3
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.2 (bnc#1012628).
- x86/mm: Add TLB purge to free pmd/pte page interfaces
  (bnc#1012628).
- ioremap: Update pgtable free interfaces with addr (bnc#1012628).
- Bluetooth: hidp: buffer overflow in hidp_process_report
  (bnc#1012628).
- crypto: skcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: skcipher - fix aligning block size in skcipher_copy_iv()
  (bnc#1012628).
- crypto: ablkcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: blkcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: vmac - separate tfm and request context (bnc#1012628).
- crypto: vmac - require a block cipher with 128-bit block size
  (bnc#1012628).
- crypto: x86/sha256-mb - fix digest copy in
  sha256_mb_mgr_get_comp_job_avx2() (bnc#1012628).
- crypto: ccp - Fix command completion detection race
  (bnc#1012628).
- crypto: ccp - Check for NULL PSP pointer at module unload
  (bnc#1012628).
- crypto: ccree - fix iv handling (bnc#1012628).
- crypto: ccree - fix finup (bnc#1012628).
- kbuild: verify that $DEPMOD is installed (bnc#1012628).
- x86/mm: Disable ioremap free page handling on x86-PAE
  (bnc#1012628).
- xen/pv: Call get_cpu_address_sizes to set x86_virt/phys_bits
  (bnc#1012628).
- x86/mm/pti: Clear Global bit more aggressively (bnc#1012628).
- x86/platform/UV: Mark memblock related init code and data
  correctly (bnc#1012628).
- x86/hyper-v: Check for VP_INVAL in hyperv_flush_tlb_others()
  (bnc#1012628).
- x86: i8259: Add missing include file (bnc#1012628).
- x86/l1tf: Fix build error seen if CONFIG_KVM_INTEL is disabled
  (bnc#1012628).
- commit 51ef786
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.1 (bnc#1012628).
- x86/init: fix build with CONFIG_SWAP=n (bnc#1012628).
- cpu/hotplug: Non-SMP machines do not make use of booted_once
  (bnc#1012628).
- x86/smp: fix non-SMP broken build due to redefinition of
  apic_id_is_primary_thread (bnc#1012628).
- commit 7e40689
* Tue Aug 21 2018 msuchanek@suse.de
- ACPICA: Clear status of all events when entering sleep states
  (boo#1104529).
- commit 5d7a9a7
* Tue Aug 21 2018 msuchanek@suse.de
- Delete patches.suse/Revert-ACPICA-Events-Stop-unconditionally-clearing-A.patch.
- commit fb1dc2b
* Fri Aug 17 2018 mkubecek@suse.cz
- rpm/constraints.in: raise memory constraints
  Build statistics show that most architectures already need more than 2 GB.
  Require 4 GB except s390x where the memory usage is much lower and we might
  have trouble finding any compliant worker.
- commit 494fb32
* Thu Aug 16 2018 msuchanek@suse.de
- Revert "ACPICA: Events: Stop unconditionally clearing ACPI
  IRQs during suspend/resume" (boo#1104529, bko#196249).
- commit 5dac824
* Wed Aug 15 2018 mkubecek@suse.cz
- Update config files.
- commit 07db4aa
* Wed Aug 15 2018 jslaby@suse.cz
- Linux 4.18.1-rc1
  It contains the L1TF fixes, so push the rc1 for now.
- x86/paravirt: Fix spectre-v2 mitigations for paravirt guests
  (bnc#1012628).
- x86/speculation: Protect against userspace-userspace spectreRSB
  (bnc#1012628).
- kprobes/x86: Fix %%p uses in error messages (bnc#1012628).
- x86/irqflags: Provide a declaration for native_save_fl
  (bnc#1012628).
- x86/speculation/l1tf: Increase 32bit PAE __PHYSICAL_PAGE_SHIFT
  (bnc#1012628).
- x86/speculation/l1tf: Change order of offset/type in swap entry
  (bnc#1012628).
- x86/speculation/l1tf: Protect swap entries against L1TF
  (bnc#1012628).
- x86/speculation/l1tf: Protect PROT_NONE PTEs against speculation
  (bnc#1012628).
- x86/speculation/l1tf: Make sure the first page is always
  reserved (bnc#1012628).
- x86/speculation/l1tf: Add sysfs reporting for l1tf
  (bnc#1012628).
- x86/speculation/l1tf: Disallow non privileged high MMIO
  PROT_NONE mappings (bnc#1012628).
- x86/speculation/l1tf: Limit swap file size to MAX_PA/2
  (bnc#1012628).
- x86/bugs: Move the l1tf function and define pr_fmt properly
  (bnc#1012628).
- sched/smt: Update sched_smt_present at runtime (bnc#1012628).
- x86/smp: Provide topology_is_primary_thread() (bnc#1012628).
- x86/topology: Provide topology_smt_supported() (bnc#1012628).
- cpu/hotplug: Make bringup/teardown of smp threads symmetric
  (bnc#1012628).
- cpu/hotplug: Split do_cpu_down() (bnc#1012628).
- cpu/hotplug: Provide knobs to control SMT (bnc#1012628).
- x86/cpu: Remove the pointless CPU printout (bnc#1012628).
- x86/cpu/AMD: Remove the pointless detect_ht() call
  (bnc#1012628).
- x86/cpu/common: Provide detect_ht_early() (bnc#1012628).
- x86/cpu/topology: Provide detect_extended_topology_early()
  (bnc#1012628).
- x86/cpu/intel: Evaluate smp_num_siblings early (bnc#1012628).
- x86/CPU/AMD: Do not check CPUID max ext level before parsing
  SMP info (bnc#1012628).
- x86/cpu/AMD: Evaluate smp_num_siblings early (bnc#1012628).
- x86/apic: Ignore secondary threads if nosmt=force (bnc#1012628).
- x86/speculation/l1tf: Extend 64bit swap file size limit
  (bnc#1012628).
- x86/cpufeatures: Add detection of L1D cache flush support
  (bnc#1012628).
- x86/CPU/AMD: Move TOPOEXT reenablement before reading
  smp_num_siblings (bnc#1012628).
- x86/speculation/l1tf: Protect PAE swap entries against L1TF
  (bnc#1012628).
- x86/speculation/l1tf: Fix up pte->pfn conversion for PAE
  (bnc#1012628).
- Revert "x86/apic: Ignore secondary threads if nosmt=force"
  (bnc#1012628).
- cpu/hotplug: Boot HT siblings at least once (bnc#1012628).
- x86/KVM: Warn user if KVM is loaded SMT and L1TF CPU bug being
  present (bnc#1012628).
- x86/KVM/VMX: Add module argument for L1TF mitigation
  (bnc#1012628).
- x86/KVM/VMX: Add L1D flush algorithm (bnc#1012628).
- x86/KVM/VMX: Add L1D MSR based flush (bnc#1012628).
- x86/KVM/VMX: Add L1D flush logic (bnc#1012628).
- x86/KVM/VMX: Split the VMX MSR LOAD structures to have an
  host/guest numbers (bnc#1012628).
- x86/KVM/VMX: Add find_msr() helper function (bnc#1012628).
- x86/KVM/VMX: Separate the VMX AUTOLOAD guest/host number
  accounting (bnc#1012628).
- x86/KVM/VMX: Extend add_atomic_switch_msr() to allow VMENTER
  only MSRs (bnc#1012628).
- x86/KVM/VMX: Use MSR save list for IA32_FLUSH_CMD if required
  (bnc#1012628).
- cpu/hotplug: Online siblings when SMT control is turned on
  (bnc#1012628).
- x86/litf: Introduce vmx status variable (bnc#1012628).
- x86/kvm: Drop L1TF MSR list approach (bnc#1012628).
- x86/l1tf: Handle EPT disabled state proper (bnc#1012628).
- x86/kvm: Move l1tf setup function (bnc#1012628).
- x86/kvm: Add static key for flush always (bnc#1012628).
- x86/kvm: Serialize L1D flush parameter setter (bnc#1012628).
- x86/kvm: Allow runtime control of L1D flush (bnc#1012628).
- cpu/hotplug: Expose SMT control init function (bnc#1012628).
- cpu/hotplug: Set CPU_SMT_NOT_SUPPORTED early (bnc#1012628).
- x86/bugs, kvm: Introduce boot-time control of L1TF mitigations
  (bnc#1012628).
- Documentation: Add section about CPU vulnerabilities
  (bnc#1012628).
- x86/speculation/l1tf: Unbreak !__HAVE_ARCH_PFN_MODIFY_ALLOWED
  architectures (bnc#1012628).
- x86/KVM/VMX: Initialize the vmx_l1d_flush_pages' content
  (bnc#1012628).
- Documentation/l1tf: Fix typos (bnc#1012628).
- cpu/hotplug: detect SMT disabled by BIOS (bnc#1012628).
- x86/KVM/VMX: Don't set l1tf_flush_l1d to true from
  vmx_l1d_flush() (bnc#1012628).
- x86/KVM/VMX: Replace 'vmx_l1d_flush_always' with
  'vmx_l1d_flush_cond' (bnc#1012628).
- x86/KVM/VMX: Move the l1tf_flush_l1d test to vmx_l1d_flush()
  (bnc#1012628).
- x86/irq: Demote irq_cpustat_t::__softirq_pending to u16
  (bnc#1012628).
- x86/KVM/VMX: Introduce per-host-cpu analogue of l1tf_flush_l1d
  (bnc#1012628).
- x86: Don't include linux/irq.h from asm/hardirq.h (bnc#1012628).
- x86/irq: Let interrupt handlers set kvm_cpu_l1tf_flush_l1d
  (bnc#1012628).
- x86/KVM/VMX: Don't set l1tf_flush_l1d from
  vmx_handle_external_intr() (bnc#1012628).
- Documentation/l1tf: Remove Yonah processors from not vulnerable
  list (bnc#1012628).
- x86/speculation: Simplify sysfs report of VMX L1TF vulnerability
  (bnc#1012628).
- x86/speculation: Use ARCH_CAPABILITIES to skip L1D flush on
  vmentry (bnc#1012628).
- KVM: VMX: Tell the nested hypervisor to skip L1D flush on
  vmentry (bnc#1012628).
- cpu/hotplug: Fix SMT supported evaluation (bnc#1012628).
- x86/speculation/l1tf: Invert all not present mappings
  (bnc#1012628).
- x86/speculation/l1tf: Make pmd/pud_mknotpresent() invert
  (bnc#1012628).
- x86/mm/pat: Make set_memory_np() L1TF safe (bnc#1012628).
- x86/mm/kmmio: Make the tracer robust against L1TF (bnc#1012628).
- tools headers: Synchronise x86 cpufeatures.h for L1TF additions
  (bnc#1012628).
- x86/microcode: Allow late microcode loading with SMT disabled
  (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Update config files.
- commit a23e15c
* Tue Aug 14 2018 mkubecek@suse.cz
- Update upstream reference:
  patches.suse/hv-netvsc-Fix-NULL-dereference-at-single-queue-mode-.patch.
- commit 0425184
* Tue Aug 14 2018 tiwai@suse.de
- hv/netvsc: Fix NULL dereference at single queue mode fallback
  (bsc#1104708).
- commit a0cb9f6
* Mon Aug 13 2018 jslaby@suse.cz
- Refresh
  patches.suse/platform-x86-ideapad-laptop-Apply-no_hw_rfkill-to-Y2.
  Update upstream info.
- commit 799dc2a
* Mon Aug 13 2018 mkubecek@suse.cz
- Update to 4.18-final.
- Refresh configs
- commit 06ab9b3
* Tue Aug  7 2018 mkubecek@suse.cz
- config: refresh s390x/vanilla
  Add new option CONFIG_SYSTEM_DATA_VERIFICATION=n
- commit 3ee2023
* Mon Aug  6 2018 mkubecek@suse.cz
- Update to 4.18-rc8
- commit 9928e10
* Mon Jul 30 2018 mkubecek@suse.cz
- Update to 4.18-rc7
- commit 68c9705
* Tue Jul 24 2018 dmueller@suse.com
- Reenable v8.1/v8.2 aarch64 extensions
  These were enabled already in SLE15 and we want to default to the
  upstream defaults, which enable these features.
  Config changes:
  - aarch64:
    HW_AFDBM=y
    PAN=y
    LSE_ATOMICS=y
    VHE=y
    UAO=y
    SVE=y
- commit 7fdc027
* Mon Jul 23 2018 msuchanek@suse.de
- Update config files.
- commit 8efadc7
* Mon Jul 23 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: Add more stuff to Recommends
  ... and move bc to Recommends as well.  All these packages are needed for
  building a kernel manually from scratch with kernel-source files.
- commit 6fcec9a
* Mon Jul 23 2018 mkubecek@suse.cz
- Update to 4.18-rc6
- Config changes:
  - NF_TABLES_SET=m (replaces NFT_SET_{RBTREE,HASH,BITMAP})
- commit 31ad2a8
* Sun Jul 22 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: require bc for kernel-source
  This is needed for building include/generated/timeconst.h from
  kernel/time/timeconst.bc.
- commit d725e3b
* Tue Jul 17 2018 tiwai@suse.de
- Update config files: enable CONFIG_I2C_PXA for arm64 (bsc#1101465)
- commit d02f285
* Mon Jul 16 2018 rgoldwyn@suse.com
- apparmor: patch to provide compatibility with v2.x net rules (bsc#1100944).
- Delete patches.suse/0001-AppArmor-basic-networking-rules.patch.
- Delete
  patches.suse/0002-apparmor-update-apparmor-basic-networking-rules-for-.patch.
- Delete
  patches.suse/0003-apparmor-Fix-quieting-of-audit-messages-for-network-.patch.
- Delete patches.suse/apparmor-check-all-net-profiles.patch.
- commit 1947b35
* Mon Jul 16 2018 msuchanek@suse.de
- Pass x86 as architecture on x86_64 and i386 (bsc#1093118).
- commit 5f24fb0
* Mon Jul 16 2018 msuchanek@suse.de
- Revert "kconfig: only write '# CONFIG_FOO is not set' for
  visible symbols" (bsc#1093118).
- commit 2b9e26a
* Mon Jul 16 2018 mkubecek@suse.cz
- Update to 4.18-rc5
- commit b3f752f
* Mon Jul  9 2018 tiwai@suse.de
- alarmtimer: Prevent overflow for relative nanosleep
  (CVE-2018-13053 bsc#1099924).
- commit e98ba10
* Mon Jul  9 2018 mkubecek@suse.cz
- Update to 4.18-rc4
- Eliminated 1 patch
- Config changes:
  - s390x:
  - RSEQ=y
  - DEBUG_REQ=n
- commit 36e98dd
* Wed Jul  4 2018 dsterba@suse.com
- Update patches.suse/btrfs-8447-serialize-subvolume-mounts-with-potentially-mi.patch (bsc#951844 bsc#1024015 bsc#1099745).
  Refresh and update for Tumbleweed. No better patch version yet.
- commit dd5896f
* Mon Jul  2 2018 mkubecek@suse.cz
- Update to 4.18-rc3
- Eliminated 6 patches
- Config changes:
  - Input:
  - INPUT_SC27XX_VIBRA=m (aarch64 only)
- commit d44a642
* Fri Jun 29 2018 jslaby@suse.cz
- Refresh
  patches.suse/input-psmouse-fix-button-reporting-for-basic-protoco.patch.
  Update upstream status.
- commit 1e6a85a
* Wed Jun 27 2018 mkubecek@suse.cz
- bpf: enforce correct alignment for instructions (bsc#1099078).
- commit 55e3263
* Tue Jun 26 2018 tiwai@suse.de
- platform/x86: ideapad-laptop: Apply no_hw_rfkill to Y20-15IKBM,
  too (bsc#1098626).
- commit 0d1073f
* Mon Jun 25 2018 jslaby@suse.cz
- Input: psmouse - fix button reporting for basic protocols
  (bnc#1098392).
- commit faf690b
* Mon Jun 25 2018 msuchanek@suse.de
- rpm/kernel-source.changes.old: Add pre-SLE15 history (bsc#1098995).
- commit 631659e
* Mon Jun 25 2018 msuchanek@suse.de
- Refresh patches.suse/s390-fix-random-crashes-illegal-operation-0001-ilc-1.patch.
- commit ff0a7a4
* Sun Jun 24 2018 mkubecek@suse.cz
- Update to 4.18-rc2
- Eliminated 1 patch
- Config changes:
  - aarch64: reenable DWMAC_SOCFPGA (=m)
- commit cc9e91e
* Sun Jun 24 2018 afaerber@suse.de
- config: arm64: Update to 4.18-rc1
- commit b301d60
* Sat Jun 23 2018 mkubecek@suse.cz
- proc: fix missing final NUL in get_mm_cmdline() rewrite
  (https://www.mail-archive.com/linux-kernel@vger.kernel.org/msg1715032.html).
- commit f348790
* Sat Jun 23 2018 mkubecek@suse.cz
- Documentation: e1000: Fix docs build error.
- Documentation: e100: Fix docs build error.
- Documentation: e1000: Use correct heading adornment.
- Documentation: e100: Use correct heading adornment.
- commit 95284f7
* Sat Jun 23 2018 jslaby@suse.cz
- x86/stacktrace: Do not unwind after user regs (bnc#1058115).
- x86/stacktrace: Remove STACKTRACE_DUMP_ONCE (bnc#1058115).
- x86/stacktrace: Clarify the reliable success paths
  (bnc#1058115).
- x86/stacktrace: Do not fail for ORC with regs on stack
  (bnc#1058115).
- x86/unwind/orc: Detect the end of the stack (bnc#1058115).
- x86/stacktrace: Enable HAVE_RELIABLE_STACKTRACE for the ORC
  unwinder (bnc#1058115).
- Delete
  patches.suse/0001-x86-stacktrace-do-now-unwind-after-user-regs.patch.
- Delete
  patches.suse/0002-x86-stacktrace-make-clear-the-success-paths.patch.
- Delete
  patches.suse/0003-x86-stacktrace-remove-STACKTRACE_DUMP_ONCE-from-__sa.patch.
- Delete
  patches.suse/0004-x86-stacktrace-do-not-fail-for-ORC-with-regs-on-stac.patch.
- Delete
  patches.suse/0005-x86-stacktrace-orc-mark-it-as-reliable.patch.
  Replace the ORC patches by the upstream patches. Finally...
- commit c19d75b
* Thu Jun 21 2018 msuchanek@suse.de
- s390: Correct register corruption in critical section cleanup
  (boo#1095717).
- commit 62d3537
* Mon Jun 18 2018 msuchanek@suse.de
- macros.kernel-source: define linux_arch for KMPs (boo#1098050).
  CONFIG_64BIT is no longer defined so KMP spec files need to include
  %%{?linux_make_arch} in any make call to build modules or descent into
  the kernel directory for any reason.
- commit 5dc40af
* Mon Jun 18 2018 mkubecek@suse.cz
- config: update ppc64le configs
- commit fa9e020
* Mon Jun 18 2018 mkubecek@suse.cz
- config: enable NETDEVSIM (as module)
- commit e218eff
* Mon Jun 18 2018 mkubecek@suse.cz
- Update to 4.18-rc1.
- Eliminated 66 patches (62 stable, 4 other).
- ARM configs need updating.
- Config changes:
  - General:
  - RSEQ=y
  - i386:
  - BPF_JIT=y
  - BPF_JIT_ALWAYS_ON=y
  - powerpc:
  - LD_DEAD_CODE_DATA_ELIMINATION=n (experimental)
  - s390:
  - FW_LOADER_USER_HELPER=y
  - PCI:
  - PCI_HOST_GENERIC=y
  - Network:
  - TLS_DEVICE=y
  - XDP_SOCKETS=y
  - NFT_CONNLIMIT=m
  - NFT_SOCKET=m
  - IP_VS_MH=m
  - IP_VS_MH_TAB_INDEX=12 (default)
  - NF_TPROXY_IPV4=m
  - NF_TPROXY_IPV6=m
  - BPFILTER=y
  - BPFILTER_UMH=m
  - FAILOVER=m
  - MLX5_EN_TLS=y
  - NET_VENDOR_MICROSEMI=y
  - MSCC_OCELOT_SWITCH=m
  - MSCC_OCELOT_SWITCH_OCELOT=m
  - NFP_APP_ABM_NIC=y
  - MDIO_MSCC_MIIM=m
  - ASIX_PHY=m
  - DP83TC811_PHY=m
  - MICROCHIP_T1_PHY=m
  - NET_FAILOVER=m
  - Block:
  - DM_WRITECACHE=m
  - Input:
  - MOUSE_PS2_ELANTECH_SMBUS=y
  - TOUCHSCREEN_CHIPONE_ICN8505=m
  - HID_STEAM=m
  - Misc:
  - SPI_MEM=y
  - GPIOLIB_FASTPATH_LIMIT=512 (default)
  - VIDEO_CADENCE=y
  - LCD_OTM3225A=n
  - CHROMEOS_TBMC=m
  - FPGA_MGR_MACHXO2_SPI=m
  - Graphics:
  - DRM_I2C_NXP_TDA9950=m
  - DRM_I915_DEBUG_GUC=n
  - DRM_CDNS_DSI=n
  - DRM_THINE_THC63LVD1024=n
  - DRM_XEN=y
  - DRM_XEN_FRONTEND=m
  - Sound:
  - SND_SOC_SSM2305=n
  - SND_SOC_TSCS454=n
  - SND_SOC_WM8782=n
  - SND_SOC_MT6351=n
  - SND_XEN_FRONTEND=m
  - LED:
  - LEDS_CR0014114=m
  - LEDS_LM3601X=m
  - USB:
  - TYPEC_RT1711H=m
  - IIO:
  - AD5686_SPI=n
  - AD5696_I2C=n
  - TI_DAC5571=n
  - TSL2772=n
  - IIO_RESCALE=n
  - Filesystems:
  - PROC_VMCORE_DEVICE_DUMP=y
  - EVM_ADD_XATTRS=y
  - Testing:
  - TEST_OVERFLOW=n
  - Crypto:
  - CRYPTO_AEGIS128=m
  - CRYPTO_AEGIS128L=m
  - CRYPTO_AEGIS256=m
  - CRYPTO_AEGIS128_AESNI_SSE2=m
  - CRYPTO_AEGIS128L_AESNI_SSE2=m
  - CRYPTO_AEGIS256_AESNI_SSE2=m
  - CRYPTO_MORUS640=m
  - CRYPTO_MORUS640_SSE2=m
  - CRYPTO_MORUS1280=m
  - CRYPTO_MORUS1280_SSE2=m
  - CRYPTO_MORUS1280_AVX2=m
  - CRYPTO_ZSTD=m
- commit 549a5bb
* Mon Jun 18 2018 mkubecek@suse.cz
- rpm: ignore CONFIG_GCC_VERSION when checking for oldconfig changes
  Since 4.18-rc1, "make oldconfig" writes gcc version and capabilities into
  generated .config. Thus whenever we build the package or run checks with
  different gcc version than used to update config/*/*, check for "outdated
  configs" fails.
  As a quick band-aid, omit the lines with CONFIG_GCC_VERSION from both
  configs before comparing them. This way, the check won't fail unless run
  with newer gcc which would add new capabilities. More robust solution will
  require a wider discussion.
- commit 546ef32
* Sat Jun 16 2018 jslaby@suse.cz
- Revert "mm: relax deferred struct page requirements"
  (bnc#1092466).
- Update config files.
- commit 802b05f
* Sat Jun 16 2018 jslaby@suse.cz
- Linux 4.17.2 (bnc#1012628).
- crypto: omap-sham - fix memleak (bnc#1012628).
- crypto: vmx - Remove overly verbose printk from AES XTS init
  (bnc#1012628).
- crypto: vmx - Remove overly verbose printk from AES init
  routines (bnc#1012628).
- crypto: cavium - Limit result reading attempts (bnc#1012628).
- crypto: cavium - Fix fallout from CONFIG_VMAP_STACK
  (bnc#1012628).
- crypto: caam - fix size of RSA prime factor q (bnc#1012628).
- crypto: caam/qi - fix IV DMA mapping and updating (bnc#1012628).
- crypto: caam - fix IV DMA mapping and updating (bnc#1012628).
- crypto: caam - fix DMA mapping dir for generated IV
  (bnc#1012628).
- crypto: caam - strip input zeros from RSA input buffer
  (bnc#1012628).
- Input: elan_i2c - add ELAN0612 (Lenovo v330 14IKB) ACPI ID
  (bnc#1012628).
- Input: goodix - add new ACPI id for GPD Win 2 touch screen
  (bnc#1012628).
- crypto: ccree - correct host regs offset (bnc#1012628).
- tty: pl011: Avoid spuriously stuck-off interrupts (bnc#1012628).
- arm64: defconfig: Enable CONFIG_PINCTRL_MT7622 by default
  (bnc#1012628).
- doc: fix sysfs ABI documentation (bnc#1012628).
- vmw_balloon: fixing double free when batching mode is off
  (bnc#1012628).
- serial: 8250: omap: Fix idling of clocks for unused uarts
  (bnc#1012628).
- serial: samsung: fix maxburst parameter for DMA transactions
  (bnc#1012628).
- tty/serial: atmel: use port->name as name in request_irq()
  (bnc#1012628).
- serial: sh-sci: Stop using printk format %%pCr (bnc#1012628).
- usb: gadget: udc: renesas_usb3: disable the controller's irqs
  for reconnecting (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should fail if devm_phy_get()
  returns error (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should call devm_phy_get()
  before add udc (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should call pm_runtime_enable()
  before add udc (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should remove debugfs
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix double phy_put()
  (bnc#1012628).
- usb: gadget: function: printer: avoid wrong list handling in
  printer_write() (bnc#1012628).
- usb: typec: wcove: Remove dependency on HW FSM (bnc#1012628).
- usb: core: message: remove extra endianness conversion in
  usb_set_isoch_delay (bnc#1012628).
- phy: qcom-qusb2: Fix crash if nvmem cell not specified
  (bnc#1012628).
- Input: xpad - add GPD Win 2 Controller USB IDs (bnc#1012628).
- usb-storage: Add compatibility quirk flags for G-Technologies
  G-Drive (bnc#1012628).
- usb-storage: Add support for FL_ALWAYS_SYNC flag in the UAS
  driver (bnc#1012628).
- usbip: vhci_sysfs: fix potential Spectre v1 (bnc#1012628).
- NFC: pn533: don't send USB data off of the stack (bnc#1012628).
- staging: android: ion: Switch to pr_warn_once in
  ion_buffer_destroy (bnc#1012628).
- kvm: x86: use correct privilege level for
  sgdt/sidt/fxsave/fxrstor access (bnc#1012628).
- KVM: x86: pass kvm_vcpu to kvm_read_guest_virt and
  kvm_write_guest_virt_system (bnc#1012628).
- kvm: nVMX: Enforce cpl=0 for VMX instructions (bnc#1012628).
- kvm: fix typo in flag name (bnc#1012628).
- KVM: x86: introduce linear_{read,write}_system (bnc#1012628).
- KVM: X86: Fix reserved bits check for MOV to CR3 (bnc#1012628).
- blkdev_report_zones_ioctl(): Use vmalloc() to allocate large
  buffers (bnc#1012628).
- crypto: chelsio - request to HW should wrap (bnc#1012628).
- commit 202985c
* Thu Jun 14 2018 mkubecek@suse.cz
- socket: close race condition between sock_close() and
  sockfs_setattr() (CVE-2018-12232 bsc#1097593).
- commit 94bf968
* Thu Jun 14 2018 jslaby@suse.cz
- config.conf: disable syzkaller
  I doubt anybody else (other than me) uses the flavor, so save a lot of
  build resources by this. Leaving syzkaller configs and stuff in place
  so people still can build it if they want.
  The build is currently broken, so this "fixes" it too:
  ERROR: "__sanitizer_cov_trace_cmpd" [drivers/gpu/drm/amd/amdgpu/amdgpu.ko] undefined!
  ERROR: "__sanitizer_cov_trace_cmpf" [drivers/gpu/drm/amd/amdgpu/amdgpu.ko] undefined!
- commit bdee95f
* Tue Jun 12 2018 jslaby@suse.cz
- Linux 4.17.1 (bnc#1012628).
- netfilter: nf_flow_table: attach dst to skbs (bnc#1012628).
- bnx2x: use the right constant (bnc#1012628).
- ip6mr: only set ip6mr_table from setsockopt when ip6mr_new_table
  succeeds (bnc#1012628).
- ipv6: omit traffic class when calculating flow hash (bnc#1012628
  bsc#1095042).
- l2tp: fix refcount leakage on PPPoL2TP sockets (bnc#1012628).
- netdev-FAQ: clarify DaveM's position for stable backports
  (bnc#1012628).
- net: metrics: add proper netlink validation (bnc#1012628).
- net/packet: refine check for priv area size (bnc#1012628).
- rtnetlink: validate attributes in do_setlink() (bnc#1012628).
- sctp: not allow transport timeout value less than HZ/5 for
  hb_timer (bnc#1012628).
- team: use netdev_features_t instead of u32 (bnc#1012628).
- vrf: check the original netdevice for generating redirect
  (bnc#1012628).
- net: dsa: b53: Fix for brcm tag issue in Cygnus SoC
  (bnc#1012628).
- ipmr: fix error path when ipmr_new_table fails (bnc#1012628).
- PCI: hv: Do not wait forever on a device that has disappeared
  (bnc#1012628).
- Delete
  patches.suse/ipv6-omit-traffic-class-when-calculating-flow-hash.patch.
- commit 17c8abe
* Fri Jun  8 2018 tiwai@suse.de
- mtd: spi-nor: intel-spi: Fix atomic sequence handling
  (bsc#1073836).
- commit c31c53d
* Fri Jun  8 2018 mkubecek@suse.cz
- ipv6: omit traffic class when calculating flow hash
  (bsc#1095042).
- commit 1307c29
* Fri Jun  8 2018 tiwai@suse.de
- Delete patches.suse/iwlwifi-expose-default-fallback-ucode-api.
  The workaround is no longer needed as the upstream driver code catches
  up the actual firmware version
- commit d6e069d
* Fri Jun  8 2018 tiwai@suse.de
- Update patch tag of the upstreamed btusb fix
- commit f531f64
* Mon Jun  4 2018 mkubecek@suse.cz
- config: enable preemption in i386/debug
- commit b181e22
* Mon Jun  4 2018 mkubecek@suse.cz
- Update to 4.17-final
- commit fb45ad0
* Mon May 28 2018 mkubecek@suse.cz
- Update to 4.17-rc7
- Eliminated 1 patch
- Config changes:
  - reenable SSB_DRIVER_PCICORE and dependencies after revert of
    commit 882164a4a928
- commit c78299c
* Thu May 24 2018 tiwai@suse.de
- Bluetooth: Apply QCA Rome patches for some ATH3012 models
  (bsc#1082504).
- commit e2f793c
* Wed May 23 2018 msuchanek@suse.de
- mkspec: only build docs for default variant kernel.
- commit 045f5ac
* Mon May 21 2018 mkubecek@suse.cz
- Makefile: disable PIE before testing asm goto (bsc#1092456).
- commit 67bdb0d
* Mon May 21 2018 mkubecek@suse.cz
- Update to 4.17-rc6
- commit 6912f6b
* Thu May 17 2018 msuchanek@suse.de
- kernel-{binary,docs}.spec sort dependencies.
- commit d2ab971
* Thu May 17 2018 mgalbraith@suse.de
- Fix config/x86_64/debug, turn PREEMPT_NONE off, and PREEMPT_DEBUG on.
- commit 3ec7274
* Wed May 16 2018 msuchanek@suse.de
- macros.kernel-source: Fix building non-x86 KMPs
- commit 8631d05
* Tue May 15 2018 jeffm@suse.com
- reiserfs: package in separate KMP (FATE#323394).
- commit d14f152
* Mon May 14 2018 msuchanek@suse.de
- macros.kernel-source: ignore errors when using make to print kernel release
  There is no way to handle the errors anyway and including the error into
  package version does not give good results.
- commit 282e9a6
* Mon May 14 2018 mkubecek@suse.cz
- Update to 4.17-rc5
- commit 80e3a99
* Fri May 11 2018 msuchanek@suse.de
- Revert "kernel-binary: do not package extract-cert when not signing modules"
  This reverts commit 10a8bc496a553b8069d490a8ae7508bdb19f58d9.
- commit 1f7acca
* Mon May  7 2018 mkubecek@suse.cz
- Update to 4.17-rc4
- Eliminated 2 patches
- Update to 4.17-rc3
- Eliminated 2 patches
- commit a993a00
* Wed May  2 2018 msuchanek@suse.de
- kernel-binary: also default klp_symbols to 0 here.
- commit e35f14a
* Wed May  2 2018 msuchanek@suse.de
- klp_symbols: make --klp-symbols argument semantic sane
  It selects build of klp symbols and defaults to off
- commit 0e53042
* Wed May  2 2018 jslaby@suse.cz
- tools: power/acpi, revert to LD = gcc (build fix).
- Delete
  patches.suse/revert-tools-fix-cross-compile-var-clobbering.patch.
  Replace by the upstream commit.
- commit c7b3cf9
* Mon Apr 30 2018 mkubecek@suse.cz
- Update to 4.17-rc3
- Eliminated 1 patch
- Config changes:
  - x86_64 and i386
  - SND_SST_ATOM_HIFI2_PLATFORM_ACPI=m
  - armv7hl
  - CONFIG_NFT_REDIR_IPV4=m (sync with other configs)
  - CONFIG_NFT_REDIR_IPV6=m (sync with other configs)
- commit 088acbb
* Sun Apr 29 2018 afaerber@suse.de
- config: armv7hl: Update to 4.17-rc2
- commit e76ffdc
* Sun Apr 29 2018 afaerber@suse.de
- config: armv6hl: Update to 4.17-rc2
- commit 7ac1254
* Sun Apr 29 2018 afaerber@suse.de
- config: arm64: Update to 4.17-rc2
- commit 8535e20
* Fri Apr 27 2018 msuchanek@suse.de
- kernel-binary: only install modules.fips on modular kernels.
- commit 2cb2bec
* Tue Apr 24 2018 msuchanek@suse.de
- split-modules: use MAKE_ARGS
- commit d8fe174
* Tue Apr 24 2018 mcgrof@suse.com
- xfs: set format back to extents if xfs_bmap_extents_to_btree
  (bsc#1090717, CVE-2018-10323).
- commit 41ecb40
* Tue Apr 24 2018 msuchanek@suse.de
- kernel-binary: pass MAKE_ARGS to install script as well.
- commit ce62ae7
* Tue Apr 24 2018 mkubecek@suse.cz
- Update config files.
- commit becf16d
* Tue Apr 24 2018 msuchanek@suse.de
- kernel-binary: pass ARCH= to kernel build
  Recent kernel does not save CONFIG_64BIT so it has to be specified by
  arch.
- commit fb21b73
* Tue Apr 24 2018 mkubecek@suse.cz
- config: fix i386 configs
  Since mainline commit f467c5640c29 ("kconfig: only write '# CONFIG_FOO is
  not set' for visible symbols"), make silentoldconfig (or make syncconfig as
  it is called now) doesn't add CONFIG_64BIT line into i386 configs if called
  with ARCH=i386.
  During the build, it's called without ARCH=i386 so that it requests this
  option to be entered manually and the build fails. Long term solution would
  probably be passing ARCH=%%{cpu_arch} to all make commands; for now, just
  add CONFIG_64BIT line to i386/pae to fix the build as is.
- commit d9a33ad
* Tue Apr 24 2018 mkubecek@suse.cz
- Documentation: typec.rst: Use literal-block element with
  ascii art.
- commit 1aebada
* Mon Apr 23 2018 jeffm@suse.com
- README.BRANCH: Added Michal Kubecek as co-maintainer.
- commit 53ecad7
* Mon Apr 23 2018 mkubecek@suse.cz
- Update to 4.17-rc2
- Eliminated 2 patches
- Config changes:
  - s390x:
  - KEXEC_FILE=y
- commit 8aad964
* Fri Apr 20 2018 mkubecek@suse.cz
- Update to 4.17-rc1.
- Eliminated 55 patches (51 stable 4.16.x)
- ARM configs need updating.
- Config changes:
  - x86:
  - ACPI_TAD=m
  - s390:
  - EXPOLINE_FULL=y
  - VT=y
  - CONSOLE_TRANSLATIONS=y
  - VT_CONSOLE=y
  - VT_HW_CONSOLE_BINDING=n
  - DUMMY_CONSOLE_COLUMNS=80
  - DUMMY_CONSOLE_ROWS=25
  - SPEAKUP=n
  - Network:
  - NF_TABLES_INET=y
  - NF_TABLES_NETDEV=y
  - NF_TABLES_ARP=y
  - NF_TABLES_BRIDGE=y
  - NET_EMATCH_IPT=m
  - ICE=m
  - RSI_COEX=y
  - IEEE802154_MCR20A=m
  - INFINIBAND_EXP_LEGACY_VERBS_NEW_UAPI=n
  - Filesystems:
  - OVERLAY_FS_XINO_AUTO=n
  - PSTORE_DEFLATE_COMPRESS=m
  - PSTORE_LZ4HC_COMPRESS=m
  - PSTORE_842_COMPRESS=n
  - PSTORE_DEFLATE_COMPRESS_DEFAULT=deflate
  - Crypto:
  - CRYPTO_CFB=m
  - CRYPTO_SM4=m
  - CRYPTO_SPECK=m
  - CRYPTO_DEV_CHELSIO_TLS=m
  - Input:
  - JOYSTICK_PXRC=m
  - HID_ELAN=m
  - HID_GOOGLE_HAMMER=m
  - Sound:
  - SND_SOC_INTEL_CHT_BSW_NAU8824_MACH=m
  - SND_SOC_INTEL_KBL_DA7219_MAX98357A_MACH=m
  - SND_SOC_AK4458=n
  - SND_SOC_AK5558=n
  - SND_SOC_BD28623=n
  - SND_SOC_MAX9867=n
  - SND_SOC_PCM1789_I2C=n
  - SND_SOC_TDA7419=m
  - SND_SOC_MAX9759=n
  - USB:
  - TYPEC_MUX_PI3USB30532=m
  - USB_ROLES_INTEL_XHCI=m
  - GPIO:
  - GPIO_104_DIO_48E=m
  - GPIO_104_IDIO_16=m
  - GPIO_104_IDI_48=m
  - GPIO_GPIO_MM=m
  - GPIO_WINBOND=m
  - GPIO_WS16C48=m
  - Media:
  - CEC_PIN_ERROR_INJ=n
  - CXD2880_SPI_DRV=m
  - MTK_MMC=n
  - IIO:
  - 104_QUAD_8=m
  - CIO_DAC=n
  - AD5272=m
  - MCP4018=m
  - MLX90632=m
  - Other:
  - THERMAL_STATISTICS=y
  - EBC_C384_WDT=m
  - LEDS_MLXREG=m
  - COMMON_CLK_SI544=n
  - STX104=n
  - LV0104CS=n
  - Remote controlers:
  - IR_IMON_DECODER=m
  - IR_IMON_RAW=m
  - INTEL_TH_ACPI=m
  - Debugging:
  - DEBUG_RWSEMS=n
- commit 4e61ecf
* Fri Apr 20 2018 mkubecek@suse.cz
- config: enable TCP_MD5SIG (bsc#1090162)
- commit 1cfc938
* Fri Apr 20 2018 mkubecek@suse.cz
- x86/power/64: Fix page-table setup for temporary text mapping
  (https://patchwork.kernel.org/patch/10342491/).
- x86/ldt: Fix support_pte_mask filtering in map_ldt_struct()
  (https://patchwork.kernel.org/patch/10342491/).
- commit 3c56473
* Thu Apr 19 2018 msuchanek@suse.de
- HID: redragon: Fix modifier keys for Redragon Asura Keyboard
  (https://build.opensuse.org/request/show/597583).
  Update config files.
- commit e9bd8ea
* Thu Apr 19 2018 jslaby@suse.cz
- Linux 4.16.3 (bnc#1012628).
- cdc_ether: flag the Cinterion AHS8 modem by gemalto as WWAN
  (bnc#1012628).
- rds: MP-RDS may use an invalid c_path (bnc#1012628).
- slip: Check if rstate is initialized before uncompressing
  (bnc#1012628).
- vhost: fix vhost_vq_access_ok() log check (bnc#1012628).
- l2tp: fix races in tunnel creation (bnc#1012628).
- l2tp: fix race in duplicate tunnel detection (bnc#1012628).
- ip_gre: clear feature flags when incompatible o_flags are set
  (bnc#1012628).
- vhost: Fix vhost_copy_to_user() (bnc#1012628).
- lan78xx: Correctly indicate invalid OTP (bnc#1012628).
- sparc64: Properly range check DAX completion index
  (bnc#1012628).
- media: v4l2-compat-ioctl32: don't oops on overlay (bnc#1012628).
- media: v4l: vsp1: Fix header display list status check in
  continuous mode (bnc#1012628).
- ipmi: Fix some error cleanup issues (bnc#1012628).
- parisc: Fix out of array access in match_pci_device()
  (bnc#1012628).
- parisc: Fix HPMC handler by increasing size to multiple of 16
  bytes (bnc#1012628).
- iwlwifi: add a bunch of new 9000 PCI IDs (bnc#1012628).
- Drivers: hv: vmbus: do not mark HV_PCIE as perf_device
  (bnc#1012628).
- PCI: hv: Serialize the present and eject work items
  (bnc#1012628).
- PCI: hv: Fix 2 hang issues in hv_compose_msi_msg()
  (bnc#1012628).
- KVM: PPC: Book3S HV: trace_tlbie must not be called in realmode
  (bnc#1012628).
- perf intel-pt: Fix overlap detection to identify consecutive
  buffers correctly (bnc#1012628).
- perf intel-pt: Fix sync_switch (bnc#1012628).
- perf intel-pt: Fix error recovery from missing TIP packet
  (bnc#1012628).
- perf intel-pt: Fix timestamp following overflow (bnc#1012628).
- perf/core: Fix use-after-free in uprobe_perf_close()
  (bnc#1012628).
- radeon: hide pointless #warning when compile testing
  (bnc#1012628).
- x86/mce/AMD: Pass the bank number to smca_get_bank_type()
  (bnc#1012628).
- x86/mce/AMD, EDAC/mce_amd: Enumerate Reserved SMCA bank type
  (bnc#1012628).
- x86/mce/AMD: Get address from already initialized block
  (bnc#1012628).
- ath9k: Protect queue draining by rcu_read_lock() (bnc#1012628).
- x86/uapi: Fix asm/bootparam.h userspace compilation errors
  (bnc#1012628).
- x86/apic: Fix signedness bug in APIC ID validity checks
  (bnc#1012628).
- sunrpc: remove incorrect HMAC request initialization
  (bnc#1012628).
- f2fs: fix heap mode to reset it back (bnc#1012628).
- block: Change a rcu_read_{lock,unlock}_sched() pair into
  rcu_read_{lock,unlock}() (bnc#1012628).
- nvme: Skip checking heads without namespaces (bnc#1012628).
- lib: fix stall in __bitmap_parselist() (bnc#1012628).
- zboot: fix stack protector in compressed boot phase
  (bnc#1012628).
- blk-mq: Directly schedule q->timeout_work when aborting a
  request (bnc#1012628).
- blk-mq: order getting budget and driver tag (bnc#1012628).
- blk-mq: make sure that correct hctx->next_cpu is set
  (bnc#1012628).
- blk-mq: don't keep offline CPUs mapped to hctx 0 (bnc#1012628).
- ovl: Set d->last properly during lookup (bnc#1012628).
- ovl: fix lookup with middle layer opaque dir and absolute path
  redirects (bnc#1012628).
- ovl: set i_ino to the value of st_ino for NFS export
  (bnc#1012628).
- ovl: set lower layer st_dev only if setting lower st_ino
  (bnc#1012628).
- xen: xenbus_dev_frontend: Fix XS_TRANSACTION_END handling
  (bnc#1012628).
- hugetlbfs: fix bug in pgoff overflow checking (bnc#1012628).
- nfsd: fix incorrect umasks (bnc#1012628).
- scsi: scsi_dh: Don't look for NULL devices handlers by name
  (bnc#1012628).
- scsi: qla2xxx: Fix small memory leak in qla2x00_probe_one on
  probe failure (bnc#1012628).
- Revert "scsi: core: return BLK_STS_OK for DID_OK in
  __scsi_error_from_host_byte()" (bnc#1012628).
- apparmor: fix logging of the existence test for signals
  (bnc#1012628).
- apparmor: fix display of .ns_name for containers (bnc#1012628).
- apparmor: fix resource audit messages when auditing peer
  (bnc#1012628).
- block/loop: fix deadlock after loop_set_status (bnc#1012628).
- nfit: fix region registration vs block-data-window ranges
  (bnc#1012628).
- s390/qdio: don't retry EQBS after CCQ 96 (bnc#1012628).
- s390/qdio: don't merge ERROR output buffers (bnc#1012628).
- s390/ipl: ensure loadparm valid flag is set (bnc#1012628).
- s390/compat: fix setup_frame32 (bnc#1012628).
- get_user_pages_fast(): return -EFAULT on access_ok failure
  (bnc#1012628).
- mm/gup_benchmark: handle gup failures (bnc#1012628).
- getname_kernel() needs to make sure that ->name != ->iname in
  long case (bnc#1012628).
- Bluetooth: Fix connection if directed advertising and privacy
  is used (bnc#1012628).
- Bluetooth: hci_bcm: Treat Interrupt ACPI resources as always
  being active-low (bnc#1012628).
- rtl8187: Fix NULL pointer dereference in priv->conf_mutex
  (bnc#1012628).
- Refresh patches.suse/0001-AppArmor-basic-networking-rules.patch.
- commit 771261a
* Thu Apr 19 2018 msuchanek@suse.de
- objtool, perf: Fix GCC 8 -Wrestrict error (bsc#1084620).
- commit 0c6114f
* Wed Apr 18 2018 msuchanek@suse.de
- supported.conf: update from openSUSE-15.0
- commit 4ef3f17
* Mon Apr 16 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1089764)
  Increase NR_CPUS to 384
- commit 6f06d9e
* Thu Apr 12 2018 jslaby@suse.cz
- Linux 4.16.2 (bnc#1012628).
- nfp: use full 40 bits of the NSP buffer address (bnc#1012628).
- net_sched: fix a missing idr_remove() in u32_delete_key()
  (bnc#1012628).
- vti6: better validate user provided tunnel names (bnc#1012628).
- ip6_tunnel: better validate user provided tunnel names
  (bnc#1012628).
- ip6_gre: better validate user provided tunnel names
  (bnc#1012628).
- ipv6: sit: better validate user provided tunnel names
  (bnc#1012628).
- ip_tunnel: better validate user provided tunnel names
  (bnc#1012628).
- net: fool proof dev_valid_name() (bnc#1012628).
- vlan: also check phy_driver ts_info for vlan's real device
  (bnc#1012628).
- sky2: Increase D3 delay to sky2 stops working after suspend
  (bnc#1012628).
- sctp: sctp_sockaddr_af must check minimal addr length for
  AF_INET6 (bnc#1012628).
- sctp: do not leak kernel memory to user space (bnc#1012628).
- pptp: remove a buggy dst release in pptp_connect()
  (bnc#1012628).
- net/sched: fix NULL dereference in the error path of
  tcf_bpf_init() (bnc#1012628).
- net/ipv6: Increment OUTxxx counters after netfilter hook
  (bnc#1012628).
- net: dsa: Discard frames from unused ports (bnc#1012628).
- arp: fix arp_filter on l3slave devices (bnc#1012628).
- sparc64: Oracle DAX driver depends on SPARC64 (bnc#1012628).
- commit 8ea896b
* Wed Apr 11 2018 jslaby@suse.cz
- Update config files.
  s390x/vanilla fails to build without this.
- commit e8d83e8
* Tue Apr 10 2018 msuchanek@suse.de
- rpm/package-descriptions: fix typo in kernel-azure
- Add azure kernel description.
- commit af0f13e
* Mon Apr  9 2018 tiwai@suse.de
- media: v4l2-core: fix size of devnode_nums[] bitarray
  (bsc#1088640).
- commit 6fcb3b5
* Mon Apr  9 2018 jslaby@suse.cz
- Linux 4.16.1 (bnc#1012628).
- signal: Correct the offset of si_pkey and si_lower in struct
  siginfo on m68k (bnc#1012628).
- Fix slab name "biovec-(1<<(21-12))" (bnc#1012628).
- vt: change SGR 21 to follow the standards (bnc#1012628).
- Input: i8042 - enable MUX on Sony VAIO VGN-CS series to fix
  touchpad (bnc#1012628).
- Input: i8042 - add Lenovo ThinkPad L460 to i8042 reset list
  (bnc#1012628).
- Input: ALPS - fix TrackStick detection on Thinkpad L570 and
  Latitude 7370 (bnc#1012628).
- Revert "base: arch_topology: fix section mismatch build
  warnings" (bnc#1012628).
- staging: comedi: ni_mio_common: ack ai fifo error interrupts
  (bnc#1012628).
- siox: fix possible buffer overflow in device_add_store
  (bnc#1012628).
- Btrfs: fix unexpected cow in run_delalloc_nocow (bnc#1012628).
- Bluetooth: hci_bcm: Add 6 new ACPI HIDs (bnc#1012628).
- crypto: x86/cast5-avx - fix ECB encryption when long sg follows
  short one (bnc#1012628).
- crypto: arm,arm64 - Fix random regeneration of S_shipped
  (bnc#1012628).
- crypto: ccp - return an actual key size from RSA max_size
  callback (bnc#1012628).
- crypto: caam - Fix null dereference at error path (bnc#1012628).
- crypto: ahash - Fix early termination in hash walk
  (bnc#1012628).
- crypto: talitos - fix IPsec cipher in length (bnc#1012628).
- crypto: testmgr - Fix incorrect values in PKCS#1 test vector
  (bnc#1012628).
- crypto: inside-secure - fix clock management (bnc#1012628).
- crypto: talitos - don't persistently map req_ctx->hw_context
  and req_ctx->buf (bnc#1012628).
- crypto: ccp - Fill the result buffer only on digest, finup,
  and final ops (bnc#1012628).
- crypto: lrw - Free rctx->ext with kzfree (bnc#1012628).
- parport_pc: Add support for WCH CH382L PCI-E single parallel
  port card (bnc#1012628).
- media: usbtv: prevent double free in error case (bnc#1012628).
- /dev/mem: Avoid overwriting "err" in read_mem() (bnc#1012628).
- mei: remove dev_err message on an unsupported ioctl
  (bnc#1012628).
- serial: 8250: Add Nuvoton NPCM UART (bnc#1012628).
- USB: serial: cp210x: add ELDAT Easywave RX09 id (bnc#1012628).
- USB: serial: ftdi_sio: add support for Harman
  FirmwareHubEmulator (bnc#1012628).
- USB: serial: ftdi_sio: add RT Systems VX-8 cable (bnc#1012628).
- bitmap: fix memset optimization on big-endian systems
  (bnc#1012628).
- commit 4bf9d1e
* Fri Apr  6 2018 agraf@suse.de
- armv6hl: Disable uacces with memcpy (boo#1080435)
- commit 5eeeb1b
* Wed Apr  4 2018 rgoldwyn@suse.com
- apparmor: Check all profiles attached to the label (bsc#1085996).
- commit b249c9e
* Wed Apr  4 2018 jslaby@suse.cz
- Revert "tools: fix cross-compile var clobbering" (build fix).
- commit 590ff92
* Mon Apr  2 2018 jeffm@suse.com
- Update to 4.16-final.
- commit 1b10c5b
* Mon Mar 26 2018 tiwai@suse.de
- brcmsmac: allocate ucode with GFP_KERNEL (bsc#1085174).
- commit 2971d91
* Mon Mar 26 2018 jeffm@suse.com
- Update to 4.16-rc7.
- Eliminated 1 patch.
- commit 7a36f2f
* Fri Mar 23 2018 agraf@suse.de
- armv7hl: Disable uacces with memcpy (boo#1080435)
- commit b8a701a
* Mon Mar 19 2018 msuchanek@suse.de
- kernel-*.spec: remove remaining occurences of %%release from dependencies
  There is a mix of %%release and %%source_rel in manually added
  dependencies and the %%release dependencies tend to fail due to rebuild
  sync issues. So get rid of them.
- commit b4ec514
* Mon Mar 19 2018 jeffm@suse.com
- Update to 4.16-rc6.
- commit a98eb00
* Mon Mar 19 2018 jeffm@suse.com
- Refresh patches.suse/kernel-add-release-status-to-kernel-build.patch.
- commit cf5ff13
* Thu Mar 15 2018 tiwai@suse.de
- Bluebooth: btusb: Fix quirk for Atheros 1525/QCA6174
  (bsc#1082504).
- commit 8413b00
* Wed Mar 14 2018 jeffm@suse.com
- config: sync i386/default
  Some options had been removed completely.
- commit 95f48d7
* Wed Mar 14 2018 jeffm@suse.com
- rpm/kernel-source.spec.in: Add check-module-license to Sources
  The package builds in the build service but the script won't make it
  into the SRPM if it's not in the Sources list.
- commit 031ed9e
* Tue Mar 13 2018 msuchanek@suse.de
- mkspec: fix perl warning
- commit f15670f
* Mon Mar 12 2018 jeffm@suse.com
- Update to 4.16-rc5.
- Eliminated 1 patch.
- commit 0dfffad
* Sun Mar 11 2018 afaerber@suse.de
- config: armv7hl: Update to 4.16-rc4
- commit ad451a4
* Sun Mar 11 2018 afaerber@suse.de
- config: armv6hl: Update to 4.16-rc4
- commit 6c846e1
* Sat Mar 10 2018 tiwai@suse.de
- Refresh to upstream patch (bsc#1083694)
  patches.suse/Documentation-sphinx-Fix-Directive-import-error.patch
- commit 2d62679
* Sat Mar 10 2018 jeffm@suse.com
- kernel: add release status to kernel build (bsc#FATE#325281).
- commit c51605f
* Fri Mar  9 2018 jeffm@suse.com
- rpm: use %%_sourcedir prefix for release-projects
- rpm: set SUSE_KERNEL_RELEASED based on project name
  Set SUSE_KERNEL_RELEASED in the config only if the project name matches
  a list of projects that are part of official release channels.  This
  list of projects is maintained per-branch.
- commit a391a5b
* Fri Mar  9 2018 jeffm@suse.com
- config: added new 'kvmsmall' flavor
  This flavor is an unreleased internal configuration intended for kernel
  developers to use in simple virtual machines.  It contains only the
  device drivers necessary to use a KVM virtual machine *without* device
  passthrough enabled.  Common local and network file systems are enabled.
  All device mapper targets are enabled.  Only the network and graphics
  drivers for devices that qemu emulates are enabled.  Many subsystems
  enabled in the default kernel are entirely disabled.  This kernel is
  meant to be small and to build very quickly.  There will be no kABI
  stability and its configuration may be changed arbitrarily.
- commit 088f1da
* Fri Mar  9 2018 jeffm@suse.com
- config: convert kvmsmall to fragment config
- commit 7a5941a
* Fri Mar  9 2018 jeffm@suse.com
- config: disabled some more options for kvmsmall
  Disable CAN, BT, rare partition types, unused mouse protocols, UIO,
  STM, and others.
- commit 4707d44
* Fri Mar  9 2018 jeffm@suse.com
- config: added new 'kvmsmall' flavor
  This flavor is intended for kernel developers to use in simple virtual
  machines.  It contains only the device drivers necessary to use a
  KVM virtual machine *without* device passthrough enabled.  Common
  local and network file systems are enabled.  All device mapper targets
  are enabled.  Only the network and graphics drivers for devices that qemu
  emulates are enabled.  Many subsystems enabled in the default kernel
  are entirely disabled.  This kernel is meant to be small and to build
  very quickly.
- commit 3c99d1f
* Thu Mar  8 2018 msuchanek@suse.de
- mkspec: do not build dtbs for architectures with no kernel.
- commit 8394abf
* Thu Mar  8 2018 jeffm@suse.com
- kconfig: move SUSE options from init/Kconfig to init/Kconfig.suse
- commit b7f69ff
* Wed Mar  7 2018 afaerber@suse.de
- config: arm64: Update to 4.16-rc4
- commit 0bb9ed4
* Wed Mar  7 2018 tiwai@suse.de
- rpm/kernel-binary.spec.in: Check module licenses (bsc#1083215,bsc#1083527)
- commit e41de0c
* Tue Mar  6 2018 jslaby@suse.cz
- Update config files.
  Enable module signing (bnc#1082905):
  * CONFIG_MODULE_SIG=y
  * # CONFIG_MODULE_SIG_FORCE is not set
  * # CONFIG_MODULE_SIG_ALL is not set
  * # CONFIG_MODULE_SIG_SHA1 is not set
  * # CONFIG_MODULE_SIG_SHA224 is not set
  * CONFIG_MODULE_SIG_SHA256=y
  * # CONFIG_MODULE_SIG_SHA384 is not set
  * # CONFIG_MODULE_SIG_SHA512 is not set
  * CONFIG_MODULE_SIG_HASH="sha256"
  * CONFIG_MODULE_SIG_KEY="certs/signing_key.pem"
  * CONFIG_SECONDARY_TRUSTED_KEYRING=y
  * CONFIG_SYSTEM_BLACKLIST_KEYRING=y
  * CONFIG_SYSTEM_BLACKLIST_HASH_LIST=""
  This commit synchronizes these options with SLE15.
  We do not add patches for loading keys from the shim layer (as in
  SLE15) for the time being. They were rejected multiple times in
  upstream and we do not want to forward-port them infinitely. This only
  means that loading KMPs with none/invalid signatures generates this:
  <module_name>: loading out-of-tree module taints kernel.
  <module_name>: module verification failed: signature and/or required key missing - tainting kernel
  But the modules load fine after that as we have MODULE_SIG_FORCE set
  to 'n'.
  Tested in qemu+OVMF and bare metal and everything looks fine.
- commit 2539ea5
* Mon Mar  5 2018 msuchanek@suse.de
- rpm: provide %%name%%-srchash = <kernel-source commit hash> (FATE#325312).
  - Also use for kernel-obs-build dependency.
- commit b6fccdf
* Mon Mar  5 2018 jeffm@suse.com
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- commit 1ba5305
* Mon Mar  5 2018 jeffm@suse.com
- Update to 4.16-rc4.
- IBRS patches need review.
- commit 061459a
* Sun Mar  4 2018 msuchanek@suse.de
- arch-symbols: use bash as interpreter since the script uses bashism.
- commit 4cdfb23
* Fri Mar  2 2018 msuchanek@suse.de
- kernel-binary: do not BuildIgnore m4.
  It is actually needed for regenerating zconf when it is not up-to-date
  due to merge.
- commit 967b28b
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: add build requirement for flex
  In addition to bison, we also need flex for "make oldconfig".
- commit 83d831c
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: remove m4 from BuildIgnore list
  As bison depends on m4, we cannot set !BuildIgnore for it any more.
- commit d7695e1
* Fri Mar  2 2018 tiwai@suse.de
- Documentation/sphinx: Fix Directive import error (bsc#1083694).
- commit 7f94eb1
* Wed Feb 28 2018 msuchanek@suse.de
- bs-upload-kernel: do not set %%opensuse_bs
  Since SLE15 it is not set in the distribution project so do not set it
  for kernel projects either.
- commit d696aa0
* Wed Feb 28 2018 jslaby@suse.cz
- Linux 4.15.7 (bnc#1012628).
- microblaze: fix endian handling (bnc#1012628).
- drm/i915/breadcrumbs: Ignore unsubmitted signalers
  (bnc#1012628).
- arm64: __show_regs: Only resolve kernel symbols when running
  at EL1 (bnc#1012628).
- drm/amdgpu: add new device to use atpx quirk (bnc#1012628).
- drm/amdgpu: Avoid leaking PM domain on driver unbind (v2)
  (bnc#1012628).
- drm/amdgpu: add atpx quirk handling (v2) (bnc#1012628).
- drm/amdgpu: only check mmBIF_IOV_FUNC_IDENTIFIER on tonga/fiji
  (bnc#1012628).
- drm/amdgpu: Add dpm quirk for Jet PRO (v2) (bnc#1012628).
- drm/amdgpu: fix VA hole handling on Vega10 v3 (bnc#1012628).
- drm/amdgpu: disable MMHUB power gating on raven (bnc#1012628).
- drm: Handle unexpected holes in color-eviction (bnc#1012628).
- drm/atomic: Fix memleak on ERESTARTSYS during non-blocking
  commits (bnc#1012628).
- drm/cirrus: Load lut in crtc_commit (bnc#1012628).
- usb: renesas_usbhs: missed the "running" flag in usb_dmac with
  rx path (bnc#1012628).
- usb: gadget: f_fs: Use config_ep_by_speed() (bnc#1012628).
- usb: gadget: f_fs: Process all descriptors during bind
  (bnc#1012628).
- Revert "usb: musb: host: don't start next rx urb if current
  one failed" (bnc#1012628).
- usb: ldusb: add PIDs for new CASSY devices supported by this
  driver (bnc#1012628).
- usb: phy: mxs: Fix NULL pointer dereference on i.MX23/28
  (bnc#1012628).
- usb: dwc3: ep0: Reset TRB counter for ep0 IN (bnc#1012628).
- usb: dwc3: gadget: Set maxpacket size for ep0 IN (bnc#1012628).
- usb: host: ehci: use correct device pointer for dma ops
  (bnc#1012628).
- drm/edid: Add 6 bpc quirk for CPT panel in Asus UX303LA
  (bnc#1012628).
- Add delay-init quirk for Corsair K70 RGB keyboards
  (bnc#1012628).
- arm64: cpufeature: Fix CTR_EL0 field definitions (bnc#1012628).
- arm64: Disable unhandled signal log messages by default
  (bnc#1012628).
- arm64: Remove unimplemented syscall log message (bnc#1012628).
- usb: ohci: Proper handling of ed_rm_list to handle race
  condition between usb_kill_urb() and finish_unlinks()
  (bnc#1012628).
- ohci-hcd: Fix race condition caused by ohci_urb_enqueue()
  and io_watchdog_func() (bnc#1012628).
- net: thunderbolt: Run disconnect flow asynchronously when
  logout is received (bnc#1012628).
- net: thunderbolt: Tear down connection properly on suspend
  (bnc#1012628).
- PCI/cxgb4: Extend T3 PCI quirk to T4+ devices (bnc#1012628).
- irqchip/mips-gic: Avoid spuriously handling masked interrupts
  (bnc#1012628).
- irqchip/gic-v3: Use wmb() instead of smb_wmb() in
  gic_raise_softirq() (bnc#1012628).
- uapi/if_ether.h: move __UAPI_DEF_ETHHDR libc define
  (bnc#1012628).
- mm: don't defer struct page initialization for Xen pv guests
  (bnc#1012628).
- mm, swap, frontswap: fix THP swap if frontswap enabled
  (bnc#1012628).
- x86/oprofile: Fix bogus GCC-8 warning in nmi_setup()
  (bnc#1012628).
- x86/apic/vector: Handle vector release on CPU unplug correctly
  (bnc#1012628).
- Kbuild: always define endianess in kconfig.h (bnc#1012628).
- iio: adis_lib: Initialize trigger before requesting interrupt
  (bnc#1012628).
- iio: buffer: check if a buffer has been set up when poll is
  called (bnc#1012628).
- iio: srf08: fix link error "devm_iio_triggered_buffer_setup"
  undefined (bnc#1012628).
- iio: adc: stm32: fix stm32h7_adc_enable error handling
  (bnc#1012628).
- RDMA/uverbs: Sanitize user entered port numbers prior to access
  it (bnc#1012628).
- RDMA/uverbs: Fix circular locking dependency (bnc#1012628).
- RDMA/uverbs: Fix bad unlock balance in ib_uverbs_close_xrcd
  (bnc#1012628).
- RDMA/uverbs: Protect from command mask overflow (bnc#1012628).
- RDMA/uverbs: Protect from races between lookup and destroy of
  uobjects (bnc#1012628).
- genirq/matrix: Handle CPU offlining proper (bnc#1012628).
- extcon: int3496: process id-pin first so that we start with
  the right status (bnc#1012628).
- PKCS#7: fix certificate blacklisting (bnc#1012628).
- PKCS#7: fix certificate chain verification (bnc#1012628).
- X.509: fix NULL dereference when restricting key with
  unsupported_sig (bnc#1012628).
- X.509: fix BUG_ON() when hash algorithm is unsupported
  (bnc#1012628).
- i2c: bcm2835: Set up the rising/falling edge delays
  (bnc#1012628).
- i2c: designware: must wait for enable (bnc#1012628).
- cfg80211: fix cfg80211_beacon_dup (bnc#1012628).
- MIPS: Drop spurious __unused in struct compat_flock
  (bnc#1012628).
- scsi: ibmvfc: fix misdefined reserved field in
  ibmvfc_fcp_rsp_info (bnc#1012628).
- xtensa: fix high memory/reserved memory collision (bnc#1012628).
- MIPS: boot: Define __ASSEMBLY__ for its.S build (bnc#1012628).
- kconfig.h: Include compiler types to avoid missed struct
  attributes (bnc#1012628).
- arm64: mm: don't write garbage into TTBR1_EL1 register
  (bnc#1012628).
- netfilter: drop outermost socket lock in getsockopt()
  (bnc#1012628).
- commit 48cfb35
* Wed Feb 28 2018 jeffm@suse.com
- kernel: add product-identifying information to kernel build (FATE#325281).
- commit 450b8db
* Tue Feb 27 2018 msuchanek@suse.de
- Revert "rpm/kernel-binary.spec.in: Also require m4 for build."
  This reverts commit 0d7b4b3f948c2efb67b7d1b95b5e1dcae225991c.
- commit f5686d2
* Tue Feb 27 2018 tiwai@suse.de
- kernel-binary: do not package extract-cert when not signing modules
  (boo#1080250).
- commit 10a8bc4
* Mon Feb 26 2018 jeffm@suse.com
- Update to 4.16-rc3.
- Eliminated 2 patches.
- commit a1d0a5c
* Mon Feb 26 2018 jeffm@suse.com
- Update to 4.16-rc2.
- Eliminated 1 patch.
- Config changes:
  - i386:
  - X86_MINIMUM_CPU_FAMILY (set automatically by oldconfig).
- commit 70f217f
* Mon Feb 26 2018 jeffm@suse.com
- Update to 4.16-rc1.
- Eliminated 624 patches (mostly 4.15.x).
- ARM configs need updating.
- Config changes:
  - General:
  - CC_STACKPROTECTOR_REGULAR=y
  - x86:
  - ACPI_SPCR_TABLE=y
  - ACER_WIRELESS=m
  - GPD_POCKET_FAN=m
  - INTEL_CHTDC_TI_PWRBTN=m
  - MELLANOX_PLATFORM=y
  - MLXREG_HOTPLUG=m
  - JAILHOUSE_GUEST=y
  - i386:
  - MLX_PLATFORM=m
  - DEFERRED_STRUCT_PAGE_INIT=y
  - powerpc:
  - PPC_MEM_KEYS=y
  - OCXL=m
  - PPC_IRQ_SOFT_MASK_DEBUG=n
  - s390:
  - KERNEL_NOBP=y
  - EXPOLINE=y
  - EXPOLINE_FULL=y
  - PCI:
  - PCIE_CADENCE_HOST=y
  - PCIE_CADENCE_EP=y
  - Network:
  - NF_FLOW_TABLE=m
  - NF_FLOW_TABLE_IPV4=m
  - NF_FLOW_TABLE_IPV6=m
  - IP6_NF_MATCH_SRH=m
  - BT_HCIBTUSB_AUTOSUSPEND=y
  - NET_VENDOR_CORTINA=y
  - GEMINI_ETHERNET=m
  - NET_VENDOR_SOCIONEXT=y
  - NETDEVSIM=n
  - NFT_FLOW_OFFLOAD=m
  - NF_FLOW_TABLE_INET=m
  - Block:
  - BLK_DEV_NULL_BLK_FAULT_INJECTION=n
  - SATA_MOBILE_LPM_POLICY=0
  - DM_UNSTRIPED=m
  - MMC_SDHCI_F_SDH30=n
  - Misc:
  - MISC_RTSX_PCI=m
  - MISC_RTSX_USB=m
  - HW_RANDOM_TPM=y (from m)
  - I2C_GPIO_FAULT_INJECTOR=n
  - PINCTRL_AXP209=m
  - GPIO_WINBOND=m
  - GPIO_PCIE_IDIO_24=m
  - SENSORS_W83773G=m
  - MFD_CROS_EC_CHARDEV=n
  - RAVE_SP_CORE=n
  CAVIUM_PTP=m
  - Graphics:
  - DRM_PANEL_ILITEK_IL9322=n
  - TINYDRM_ILI9225=n
  - TINYDRM_ST7735R=n
  - Sound:
  - SND_SOC_INTEL_SST_TOPLEVEL=y
  - SND_SST_ATOM_HIFI2_PLATFORM_PCI=m
  - SND_SOC_INTEL_BYT_MAX98090_MACH=m
  - SND_SOC_INTEL_BYT_RT5640_MACH=m
  - SND_SOC_MAX98373=n
  - SND_SOC_PCM186X_I2C=n
  - SND_SOC_PCM186X_SPI=n
  - SND_SOC_TAS6424=n
  - SND_SOC_TLV320AIC32X4_I2C=n
  - SND_SOC_TLV320AIC32X4_SPI=n
  - SND_SOC_TSCS42XX=n
  - SOUNDWIRE=y
  - SOUNDWIRE_INTEL=m
  - Input:
  - HID_JABRA=n
  - USB:
  - USB_XHCI_DBGCAP=n
  - LEDS:
  - LEDS_LM3692X=n
  - LEDS_TRIGGER_NETDEV=m
  - LEDS_LP8860=n
  - RTC:
  - RTC_DRV_CROS_EC=n
  - VIRT:
  - VBOXGUEST=m
  - VIRTIO_MENU=y
  - KVM_AMD_SEV=y
  - Filesystems:
  - CIFS_SMB_DIRECT=n (still experimental)
  - Other:
  - UNISYSSPAR=n
  - XILINX_VCU=n
  - IIO_BUFFER_HW_CONSUMER=n
  - SD_ADC_MODULATOR=n
  - OF_FPGA_REGION=n
  - SIOX=n
  - SLIMBUS=n
  - BPF_KPROBE_OVERRIDE=n
  - FPGA_BRIDGE=n
  - Sensors:
  - ST_UVIS25=n
  - ZOPT2201=n
  - Media:
  - MT76x2E=m
  - LIRC=y
  - DVB_MMAP=n (still experimental)
  - DVB_ULE_DEBUG=n
  - Testing:
  - FAIL_FUNCTION=n
  - RUNTIME_TESTING_MENU=y
  - FIND_BIT_BENCHMARK=n
  - Crypto:
  - CHELSIO_IPSEC_INLINE=n
  - CRYPTO_DEV_SP_PSP=y
- commit 955d7ce
* Sun Feb 25 2018 jslaby@suse.cz
- bpf: cpumap: use GFP_KERNEL instead of GFP_ATOMIC in
  __cpu_map_entry_alloc() (git-fixes).
- commit b050949
* Sun Feb 25 2018 jslaby@suse.cz
- ptr_ring: prevent integer overflow when calculating size
  (git-fixes).
- commit f95a8d4
* Sun Feb 25 2018 jslaby@suse.cz
- Linux 4.15.6 (bnc#1012628).
- vmalloc: fix __GFP_HIGHMEM usage for vmalloc_32 on 32b systems
  (bnc#1012628).
- mei: me: add cannon point device ids for 4th device
  (bnc#1012628).
- mei: me: add cannon point device ids (bnc#1012628).
- crypto: s5p-sss - Fix kernel Oops in AES-ECB mode (bnc#1012628).
- usbip: keep usbip_device sockfd state in sync with tcp_socket
  (bnc#1012628).
- xhci: fix xhci debugfs errors in xhci_stop (bnc#1012628).
- xhci: xhci debugfs device nodes weren't removed after device
  plugged out (bnc#1012628).
- xhci: Fix xhci debugfs devices node disappearance after
  hibernation (bnc#1012628).
- xhci: Fix NULL pointer in xhci debugfs (bnc#1012628).
- staging: iio: ad5933: switch buffer mode to software
  (bnc#1012628).
- staging: iio: adc: ad7192: fix external frequency setting
  (bnc#1012628).
- staging: fsl-mc: fix build testing on x86 (bnc#1012628).
- binder: replace "%%p" with "%%pK" (bnc#1012628).
- binder: check for binder_thread allocation failure in
  binder_poll() (bnc#1012628).
- staging: android: ashmem: Fix a race condition in pin ioctls
  (bnc#1012628).
- ANDROID: binder: synchronize_rcu() when using POLLFREE
  (bnc#1012628).
- ANDROID: binder: remove WARN() for redundant txn error
  (bnc#1012628).
- dn_getsockoptdecnet: move nf_{get/set}sockopt outside sock lock
  (bnc#1012628).
- arm64: dts: add #cooling-cells to CPU nodes (bnc#1012628).
- ARM: 8743/1: bL_switcher: add MODULE_LICENSE tag (bnc#1012628).
- video: fbdev/mmp: add MODULE_LICENSE (bnc#1012628).
- ASoC: ux500: add MODULE_LICENSE tag (bnc#1012628).
- soc: qcom: rmtfs_mem: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- net_sched: gen_estimator: fix lockdep splat (bnc#1012628).
- net: avoid skb_warn_bad_offload on IS_ERR (bnc#1012628).
- rds: tcp: atomically purge entries from rds_tcp_conn_list
  during netns delete (bnc#1012628).
- rds: tcp: correctly sequence cleanup on netns deletion
  (bnc#1012628).
- netfilter: xt_RATEEST: acquire xt_rateest_mutex for hash insert
  (bnc#1012628).
- netfilter: xt_cgroup: initialize info->priv in
  cgroup_mt_check_v1() (bnc#1012628).
- netfilter: on sockopt() acquire sock lock only in the required
  scope (bnc#1012628).
- netfilter: ipt_CLUSTERIP: fix out-of-bounds accesses in
  clusterip_tg_check() (bnc#1012628).
- netfilter: x_tables: avoid out-of-bounds reads in
  xt_request_find_{match|target} (bnc#1012628).
- netfilter: x_tables: fix int overflow in xt_alloc_table_info()
  (bnc#1012628).
- kcov: detect double association with a single task
  (bnc#1012628).
- KVM: x86: fix escape of guest dr6 to the host (bnc#1012628).
- blk_rq_map_user_iov: fix error override (bnc#1012628).
- staging: android: ion: Switch from WARN to pr_warn
  (bnc#1012628).
- staging: android: ion: Add __GFP_NOWARN for system contig heap
  (bnc#1012628).
- crypto: x86/twofish-3way - Fix %%rbp usage (bnc#1012628).
- media: pvrusb2: properly check endpoint types (bnc#1012628).
- selinux: skip bounded transition processing if the policy
  isn't loaded (bnc#1012628).
- selinux: ensure the context is NUL terminated in
  security_context_to_sid_core() (bnc#1012628).
- ptr_ring: try vmalloc() when kmalloc() fails (bnc#1012628).
- ptr_ring: fail early if queue occupies more than
  KMALLOC_MAX_SIZE (bnc#1012628).
- tun: fix tun_napi_alloc_frags() frag allocator (bnc#1012628).
- commit 71fd692
* Thu Feb 22 2018 jslaby@suse.cz
- powerpc/pseries: Add empty update_numa_cpu_lookup_table()
  for NUMA=n (git-fixes).
- commit 4a82466
* Thu Feb 22 2018 jslaby@suse.cz
- Linux 4.15.5 (bnc#1012628).
- scsi: smartpqi: allow static build ("built-in") (bnc#1012628).
- IB/umad: Fix use of unprotected device pointer (bnc#1012628).
- IB/qib: Fix comparison error with qperf compare/swap test
  (bnc#1012628).
- IB/mlx4: Fix incorrectly releasing steerable UD QPs when have
  only ETH ports (bnc#1012628).
- IB/core: Fix two kernel warnings triggered by rxe registration
  (bnc#1012628).
- IB/core: Fix ib_wc structure size to remain in 64 bytes boundary
  (bnc#1012628).
- IB/core: Avoid a potential OOPs for an unused optional parameter
  (bnc#1012628).
- selftests: seccomp: fix compile error seccomp_bpf (bnc#1012628).
- kselftest: fix OOM in memory compaction test (bnc#1012628).
- RDMA/rxe: Fix a race condition related to the QP error state
  (bnc#1012628).
- RDMA/rxe: Fix a race condition in rxe_requester() (bnc#1012628).
- RDMA/rxe: Fix rxe_qp_cleanup() (bnc#1012628).
- cpufreq: powernv: Dont assume distinct pstate values for
  nominal and pmin (bnc#1012628).
- swiotlb: suppress warning when __GFP_NOWARN is set
  (bnc#1012628).
- PM / devfreq: Propagate error from devfreq_add_device()
  (bnc#1012628).
- mwifiex: resolve reset vs. remove()/shutdown() deadlocks
  (bnc#1012628).
- ocfs2: try a blocking lock before return AOP_TRUNCATED_PAGE
  (bnc#1012628).
- trace_uprobe: Display correct offset in uprobe_events
  (bnc#1012628).
- powerpc/radix: Remove trace_tlbie call from radix__flush_tlb_all
  (bnc#1012628).
- powerpc/kernel: Block interrupts when updating TIDR
  (bnc#1012628).
- powerpc/vas: Don't set uses_vas for kernel windows
  (bnc#1012628).
- powerpc/numa: Invalidate numa_cpu_lookup_table on cpu remove
  (bnc#1012628).
- powerpc/mm: Flush radix process translations when setting MMU
  type (bnc#1012628).
- powerpc/xive: Use hw CPU ids when configuring the CPU queues
  (bnc#1012628).
- dma-buf: fix reservation_object_wait_timeout_rcu once more v2
  (bnc#1012628).
- s390: fix handling of -1 in set{,fs}[gu]id16 syscalls
  (bnc#1012628).
- arm64: dts: msm8916: Correct ipc references for smsm
  (bnc#1012628).
- ARM: lpc3250: fix uda1380 gpio numbers (bnc#1012628).
- ARM: dts: STi: Add gpio polarity for "hdmi,hpd-gpio" property
  (bnc#1012628).
- ARM: dts: nomadik: add interrupt-parent for clcd (bnc#1012628).
- arm: dts: mt7623: fix card detection issue on bananapi-r2
  (bnc#1012628).
- arm: spear600: Add missing interrupt-parent of rtc
  (bnc#1012628).
- arm: spear13xx: Fix dmas cells (bnc#1012628).
- arm: spear13xx: Fix spics gpio controller's warning
  (bnc#1012628).
- x86/gpu: add CFL to early quirks (bnc#1012628).
- x86/kexec: Make kexec (mostly) work in 5-level paging mode
  (bnc#1012628).
- x86/xen: init %%gs very early to avoid page faults with stack
  protector (bnc#1012628).
- x86: PM: Make APM idle driver initialize polling state
  (bnc#1012628).
- mm, memory_hotplug: fix memmap initialization (bnc#1012628).
- x86/entry/64: Clear extra registers beyond syscall arguments,
  to reduce speculation attack surface (bnc#1012628).
- x86/entry/64/compat: Clear registers for compat syscalls,
  to reduce speculation attack surface (bnc#1012628).
- compiler-gcc.h: Introduce __optimize function attribute
  (bnc#1012628).
- compiler-gcc.h: __nostackprotector needs gcc-4.4 and up
  (bnc#1012628).
- crypto: sun4i_ss_prng - fix return value of
  sun4i_ss_prng_generate (bnc#1012628).
- crypto: sun4i_ss_prng - convert lock to _bh in
  sun4i_ss_prng_generate (bnc#1012628).
- powerpc/mm/radix: Split linear mapping on hot-unplug
  (bnc#1012628).
- x86/mm/pti: Fix PTI comment in entry_SYSCALL_64() (bnc#1012628).
- x86/speculation: Update Speculation Control microcode blacklist
  (bnc#1012628).
- x86/speculation: Correct Speculation Control microcode blacklist
  again (bnc#1012628).
- Revert "x86/speculation: Simplify
  indirect_branch_prediction_barrier()" (bnc#1012628).
- KVM/x86: Reduce retpoline performance impact in
  slot_handle_level_range(), by always inlining iterator helper
  methods (bnc#1012628).
- X86/nVMX: Properly set spec_ctrl and pred_cmd before merging
  MSRs (bnc#1012628).
- KVM/nVMX: Set the CPU_BASED_USE_MSR_BITMAPS if we have a valid
  L02 MSR bitmap (bnc#1012628).
- x86/speculation: Clean up various Spectre related details
  (bnc#1012628).
- PM / runtime: Update links_count also if !CONFIG_SRCU
  (bnc#1012628).
- PM: cpuidle: Fix cpuidle_poll_state_init() prototype
  (bnc#1012628).
- platform/x86: wmi: fix off-by-one write in wmi_dev_probe()
  (bnc#1012628).
- x86/entry/64: Clear registers for exceptions/interrupts,
  to reduce speculation attack surface (bnc#1012628).
- x86/entry/64: Merge SAVE_C_REGS and SAVE_EXTRA_REGS, remove
  unused extensions (bnc#1012628).
- x86/entry/64: Merge the POP_C_REGS and POP_EXTRA_REGS macros
  into a single POP_REGS macro (bnc#1012628).
- x86/entry/64: Interleave XOR register clearing with PUSH
  instructions (bnc#1012628).
- x86/entry/64: Introduce the PUSH_AND_CLEAN_REGS macro
  (bnc#1012628).
- x86/entry/64: Use PUSH_AND_CLEAN_REGS in more cases
  (bnc#1012628).
- x86/entry/64: Get rid of the ALLOC_PT_GPREGS_ON_STACK and
  SAVE_AND_CLEAR_REGS macros (bnc#1012628).
- x86/entry/64: Indent PUSH_AND_CLEAR_REGS and POP_REGS properly
  (bnc#1012628).
- x86/entry/64: Fix paranoid_entry() frame pointer warning
  (bnc#1012628).
- x86/entry/64: Remove the unused 'icebp' macro (bnc#1012628).
- selftests/x86: Fix vDSO selftest segfault for vsyscall=none
  (bnc#1012628).
- selftests/x86: Clean up and document sscanf() usage
  (bnc#1012628).
- selftests/x86/pkeys: Remove unused functions (bnc#1012628).
- selftests/x86: Fix build bug caused by the 5lvl test which
  has been moved to the VM directory (bnc#1012628).
- selftests/x86: Do not rely on "int $0x80" in test_mremap_vdso.c
  (bnc#1012628).
- gfs2: Fixes to "Implement iomap for block_map" (bnc#1012628).
- selftests/x86: Do not rely on "int $0x80" in
  single_step_syscall.c (bnc#1012628).
- selftests/x86: Disable tests requiring 32-bit support on pure
  64-bit systems (bnc#1012628).
- objtool: Fix segfault in ignore_unreachable_insn()
  (bnc#1012628).
- x86/debug, objtool: Annotate WARN()-related UD2 as reachable
  (bnc#1012628).
- x86/debug: Use UD2 for WARN() (bnc#1012628).
- x86/speculation: Fix up array_index_nospec_mask() asm constraint
  (bnc#1012628).
- nospec: Move array_index_nospec() parameter checking into
  separate macro (bnc#1012628).
- x86/speculation: Add <asm/msr-index.h> dependency (bnc#1012628).
- x86/mm: Rename flush_tlb_single() and flush_tlb_one() to
  __flush_tlb_one_[user|kernel]() (bnc#1012628).
- selftests/x86/mpx: Fix incorrect bounds with old _sigfault
  (bnc#1012628).
- x86/cpu: Rename cpu_data.x86_mask to cpu_data.x86_stepping
  (bnc#1012628).
- x86/spectre: Fix an error message (bnc#1012628).
- x86/cpu: Change type of x86_cache_size variable to unsigned int
  (bnc#1012628).
- x86/entry/64: Fix CR3 restore in paranoid_exit() (bnc#1012628).
- drm/ttm: Don't add swapped BOs to swap-LRU list (bnc#1012628).
- drm/ttm: Fix 'buf' pointer update in ttm_bo_vm_access_kmap()
  (v2) (bnc#1012628).
- drm/qxl: unref cursor bo when finished with it (bnc#1012628).
- drm/qxl: reapply cursor after resetting primary (bnc#1012628).
- drm/amd/powerplay: Fix smu_table_entry.handle type
  (bnc#1012628).
- drm/ast: Load lut in crtc_commit (bnc#1012628).
- drm: Check for lessee in DROP_MASTER ioctl (bnc#1012628).
- arm64: Add missing Falkor part number for branch predictor
  hardening (bnc#1012628).
- drm/radeon: Add dpm quirk for Jet PRO (v2) (bnc#1012628).
- drm/radeon: adjust tested variable (bnc#1012628).
- x86/smpboot: Fix uncore_pci_remove() indexing bug when
  hot-removing a physical CPU (bnc#1012628).
- rtc-opal: Fix handling of firmware error codes, prevent busy
  loops (bnc#1012628).
- mbcache: initialize entry->e_referenced in
  mb_cache_entry_create() (bnc#1012628).
- mmc: sdhci: Implement an SDHCI-specific bounce buffer
  (bnc#1012628).
- mmc: bcm2835: Don't overwrite max frequency unconditionally
  (bnc#1012628).
- Revert "mmc: meson-gx: include tx phase in the tuning process"
  (bnc#1012628).
- mlx5: fix mlx5_get_vector_affinity to start from completion
  vector 0 (bnc#1012628).
- Revert "apple-gmux: lock iGP IO to protect from vgaarb changes"
  (bnc#1012628).
- jbd2: fix sphinx kernel-doc build warnings (bnc#1012628).
- ext4: fix a race in the ext4 shutdown path (bnc#1012628).
- ext4: save error to disk in __ext4_grp_locked_error()
  (bnc#1012628).
- ext4: correct documentation for grpid mount option
  (bnc#1012628).
- mm: hide a #warning for COMPILE_TEST (bnc#1012628).
- mm: Fix memory size alignment in devm_memremap_pages_release()
  (bnc#1012628).
- MIPS: Fix typo BIG_ENDIAN to CPU_BIG_ENDIAN (bnc#1012628).
- MIPS: CPS: Fix MIPS_ISA_LEVEL_RAW fallout (bnc#1012628).
- MIPS: Fix incorrect mem=X@Y handling (bnc#1012628).
- PCI: Disable MSI for HiSilicon Hip06/Hip07 only in Root Port
  mode (bnc#1012628).
- PCI: iproc: Fix NULL pointer dereference for BCMA (bnc#1012628).
- PCI: pciehp: Assume NoCompl+ for Thunderbolt ports
  (bnc#1012628).
- PCI: keystone: Fix interrupt-controller-node lookup
  (bnc#1012628).
- video: fbdev: atmel_lcdfb: fix display-timings lookup
  (bnc#1012628).
- console/dummy: leave .con_font_get set to NULL (bnc#1012628).
- rbd: whitelist RBD_FEATURE_OPERATIONS feature bit (bnc#1012628).
- xen: Fix {set,clear}_foreign_p2m_mapping on autotranslating
  guests (bnc#1012628).
- xenbus: track caller request id (bnc#1012628).
- seq_file: fix incomplete reset on read from zero offset
  (bnc#1012628).
- tracing: Fix parsing of globs with a wildcard at the beginning
  (bnc#1012628).
- mpls, nospec: Sanitize array index in mpls_label_ok()
  (bnc#1012628).
- rtlwifi: rtl8821ae: Fix connection lost problem correctly
  (bnc#1012628).
- arm64: proc: Set PTE_NG for table entries to avoid traversing
  them twice (bnc#1012628).
- xprtrdma: Fix calculation of ri_max_send_sges (bnc#1012628).
- xprtrdma: Fix BUG after a device removal (bnc#1012628).
- blk-wbt: account flush requests correctly (bnc#1012628).
- target/iscsi: avoid NULL dereference in CHAP auth error path
  (bnc#1012628).
- iscsi-target: make sure to wake up sleeping login worker
  (bnc#1012628).
- dm: correctly handle chained bios in dec_pending()
  (bnc#1012628).
- Btrfs: fix deadlock in run_delalloc_nocow (bnc#1012628).
- Btrfs: fix crash due to not cleaning up tree log block's dirty
  bits (bnc#1012628).
- Btrfs: fix extent state leak from tree log (bnc#1012628).
- Btrfs: fix use-after-free on root->orphan_block_rsv
  (bnc#1012628).
- Btrfs: fix unexpected -EEXIST when creating new inode
  (bnc#1012628).
- 9p/trans_virtio: discard zero-length reply (bnc#1012628).
- mtd: nand: vf610: set correct ooblayout (bnc#1012628).
- ALSA: hda - Fix headset mic detection problem for two Dell
  machines (bnc#1012628).
- ALSA: usb-audio: Fix UAC2 get_ctl request with a RANGE attribute
  (bnc#1012628).
- ALSA: hda/realtek - Add headset mode support for Dell laptop
  (bnc#1012628).
- ALSA: hda/realtek - Enable Thinkpad Dock device for ALC298
  platform (bnc#1012628).
- ALSA: hda/realtek: PCI quirk for Fujitsu U7x7 (bnc#1012628).
- ALSA: usb-audio: add implicit fb quirk for Behringer UFX1204
  (bnc#1012628).
- ALSA: usb: add more device quirks for USB DSD devices
  (bnc#1012628).
- ALSA: seq: Fix racy pool initializations (bnc#1012628).
- mvpp2: fix multicast address filter (bnc#1012628).
- usb: Move USB_UHCI_BIG_ENDIAN_* out of USB_SUPPORT
  (bnc#1012628).
- x86/mm, mm/hwpoison: Don't unconditionally unmap kernel 1:1
  pages (bnc#1012628).
- ARM: dts: exynos: fix RTC interrupt for exynos5410
  (bnc#1012628).
- ARM: pxa/tosa-bt: add MODULE_LICENSE tag (bnc#1012628).
- arm64: dts: msm8916: Add missing #phy-cells (bnc#1012628).
- ARM: dts: s5pv210: add interrupt-parent for ohci (bnc#1012628).
- arm: dts: mt7623: Update ethsys binding (bnc#1012628).
- arm: dts: mt2701: Add reset-cells (bnc#1012628).
- ARM: dts: Delete bogus reference to the charlcd (bnc#1012628).
- media: r820t: fix r820t_write_reg for KASAN (bnc#1012628).
- mmc: sdhci-of-esdhc: fix eMMC couldn't work after kexec
  (bnc#1012628).
- mmc: sdhci-of-esdhc: fix the mmc error after sleep on ls1046ardb
  (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- commit 078aac5
* Thu Feb 22 2018 lpechacek@suse.com
- rpm/kernel-spec-macros: Try harder to detect Build Service environment (bsc#1078788)
- commit a5f1a4a
* Wed Feb 21 2018 msuchanek@suse.de
- kernel-binary undefine unique_debug_names
  Some tools do not understand names like
  usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
- commit 2b90c1e
* Tue Feb 20 2018 jeffm@suse.com
- config: enable IMA and EVM
- commit 8c97198
* Sun Feb 18 2018 afaerber@suse.de
- config: arm64: Enable MAX77620 for Nvidia Jetson TX1 (boo#1081473)
- commit 5cbffaf
* Sat Feb 17 2018 jslaby@suse.cz
- Linux 4.15.4 (bnc#1012628).
- watchdog: indydog: Add dependency on SGI_HAS_INDYDOG
  (bnc#1012628).
- cifs: Fix missing put_xid in cifs_file_strict_mmap
  (bnc#1012628).
- cifs: Fix autonegotiate security settings mismatch
  (bnc#1012628).
- CIFS: zero sensitive data when freeing (bnc#1012628).
- cpufreq: mediatek: add mediatek related projects into blacklist
  (bnc#1012628).
- dmaengine: dmatest: fix container_of member in dmatest_callback
  (bnc#1012628).
- ssb: Do not disable PCI host on non-Mips (bnc#1012628).
- watchdog: gpio_wdt: set WDOG_HW_RUNNING in gpio_wdt_stop
  (bnc#1012628).
- Revert "drm/i915: mark all device info struct with __initconst"
  (bnc#1012628).
- sched/rt: Use container_of() to get root domain in
  rto_push_irq_work_func() (bnc#1012628).
- sched/rt: Up the root domain ref count when passing it around
  via IPIs (bnc#1012628).
- media: dvb-usb-v2: lmedm04: Improve logic checking of warm start
  (bnc#1012628).
- media: dvb-usb-v2: lmedm04: move ts2020 attach to
  dm04_lme2510_tuner (bnc#1012628).
- media: hdpvr: Fix an error handling path in hdpvr_probe()
  (bnc#1012628).
- arm64: cpu_errata: Add Kryo to Falkor 1003 errata (bnc#1012628).
- arm64: kpti: Make use of nG dependent on
  arm64_kernel_unmapped_at_el0() (bnc#1012628).
- arm64: mm: Permit transitioning from Global to Non-Global
  without BBM (bnc#1012628).
- arm64: kpti: Add ->enable callback to remap swapper using nG
  mappings (bnc#1012628).
- arm64: Force KPTI to be disabled on Cavium ThunderX
  (bnc#1012628).
- arm64: entry: Reword comment about post_ttbr_update_workaround
  (bnc#1012628).
- arm64: idmap: Use "awx" flags for .idmap.text .pushsection
  directives (bnc#1012628).
- arm64: barrier: Add CSDB macros to control data-value prediction
  (bnc#1012628).
- arm64: Implement array_index_mask_nospec() (bnc#1012628).
- arm64: Make USER_DS an inclusive limit (bnc#1012628).
- arm64: Use pointer masking to limit uaccess speculation
  (bnc#1012628).
- arm64: entry: Ensure branch through syscall table is bounded
  under speculation (bnc#1012628).
- arm64: uaccess: Prevent speculative use of the current
  addr_limit (bnc#1012628).
- arm64: uaccess: Don't bother eliding access_ok checks in __{get,
  put}_user (bnc#1012628).
- arm64: uaccess: Mask __user pointers for __arch_{clear,
  copy_*}_user (bnc#1012628).
- arm64: futex: Mask __user pointers prior to dereference
  (bnc#1012628).
- arm64: cpufeature: __this_cpu_has_cap() shouldn't stop early
  (bnc#1012628).
- arm64: entry: Apply BP hardening for high-priority synchronous
  exceptions (bnc#1012628).
- arm64: entry: Apply BP hardening for suspicious interrupts
  from EL0 (bnc#1012628).
- arm64: KVM: Increment PC after handling an SMC trap
  (bnc#1012628).
- arm/arm64: KVM: Consolidate the PSCI include files
  (bnc#1012628).
- arm/arm64: KVM: Add PSCI_VERSION helper (bnc#1012628).
- arm/arm64: KVM: Add smccc accessors to PSCI code (bnc#1012628).
- arm/arm64: KVM: Implement PSCI 1.0 support (bnc#1012628).
- arm/arm64: KVM: Advertise SMCCC v1.1 (bnc#1012628).
- arm/arm64: KVM: Turn kvm_psci_version into a static inline
  (bnc#1012628).
- arm64: KVM: Report SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: KVM: Add SMCCC_ARCH_WORKAROUND_1 fast handling
  (bnc#1012628).
- firmware/psci: Expose PSCI conduit (bnc#1012628).
- firmware/psci: Expose SMCCC version through psci_ops
  (bnc#1012628).
- arm/arm64: smccc: Make function identifiers an unsigned quantity
  (bnc#1012628).
- arm/arm64: smccc: Implement SMCCC v1.1 inline primitive
  (bnc#1012628).
- arm64: Add ARM_SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: Kill PSCI_GET_VERSION as a variant-2 workaround
  (bnc#1012628).
- mtd: cfi: convert inline functions to macros (bnc#1012628).
- mtd: nand: brcmnand: Disable prefetch by default (bnc#1012628).
- mtd: nand: Fix nand_do_read_oob() return value (bnc#1012628).
- mtd: nand: sunxi: Fix ECC strength choice (bnc#1012628).
- ubi: Fix race condition between ubi volume creation and udev
  (bnc#1012628).
- ubi: fastmap: Erase outdated anchor PEBs during attach
  (bnc#1012628).
- ubi: block: Fix locking for idr_alloc/idr_remove (bnc#1012628).
- ubifs: free the encrypted symlink target (bnc#1012628).
- nfs/pnfs: fix nfs_direct_req ref leak when i/o falls back to
  the mds (bnc#1012628).
- nfs41: do not return ENOMEM on LAYOUTUNAVAILABLE (bnc#1012628).
- NFS: Add a cond_resched() to nfs_commit_release_pages()
  (bnc#1012628).
- NFS: Fix nfsstat breakage due to LOOKUPP (bnc#1012628).
- NFS: commit direct writes even if they fail partially
  (bnc#1012628).
- NFS: reject request for id_legacy key without auxdata
  (bnc#1012628).
- NFS: Fix a race between mmap() and O_DIRECT (bnc#1012628).
- nfsd: Detect unhashed stids in nfsd4_verify_open_stid()
  (bnc#1012628).
- kernfs: fix regression in kernfs_fop_write caused by wrong type
  (bnc#1012628).
- ahci: Annotate PCI ids for mobile Intel chipsets as such
  (bnc#1012628).
- ahci: Add PCI ids for Intel Bay Trail, Cherry Trail and Apollo
  Lake AHCI (bnc#1012628).
- ahci: Add Intel Cannon Lake PCH-H PCI ID (bnc#1012628).
- crypto: hash - introduce crypto_hash_alg_has_setkey()
  (bnc#1012628).
- crypto: cryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: mcryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: poly1305 - remove ->setkey() method (bnc#1012628).
- crypto: hash - annotate algorithms taking optional key
  (bnc#1012628).
- crypto: hash - prevent using keyed hashes without setting key
  (bnc#1012628).
- media: v4l2-ioctl.c: use check_fmt for enum/g/s/try_fmt
  (bnc#1012628).
- media: v4l2-ioctl.c: don't copy back the result for -ENOTTY
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: add missing VIDIOC_PREPARE_BUF
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix the indentation (bnc#1012628).
- media: v4l2-compat-ioctl32.c: move 'helper' functions to
  __get/put_v4l2_format32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: avoid sizeof(type) (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy m.userptr in put_v4l2_plane32
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix ctrl_is_pointer (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy clip list in
  put_v4l2_window32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: drop pr_info for unknown buffer
  type (bnc#1012628).
- media: v4l2-compat-ioctl32.c: don't copy back the result for
  certain errors (bnc#1012628).
- media: v4l2-compat-ioctl32.c: refactor compat ioctl32 logic
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: make ctrl_is_pointer work for
  subdevs (bnc#1012628).
- crypto: caam - fix endless loop when DECO acquire fails
  (bnc#1012628).
- crypto: sha512-mb - initialize pending lengths correctly
  (bnc#1012628).
- crypto: talitos - fix Kernel Oops on hashing an empty file
  (bnc#1012628).
- arm: KVM: Fix SMCCC handling of unimplemented SMC/HVC calls
  (bnc#1012628).
- KVM: nVMX: Fix races when sending nested PI while dest
  enters/leaves L2 (bnc#1012628).
- KVM: nVMX: Fix bug of injecting L2 exception into L1
  (bnc#1012628).
- KVM: PPC: Book3S HV: Make sure we don't re-enter guest without
  XIVE loaded (bnc#1012628).
- KVM: PPC: Book3S HV: Drop locks before reading guest memory
  (bnc#1012628).
- KVM: arm/arm64: Handle CPU_PM_ENTER_FAILED (bnc#1012628).
- KVM: PPC: Book3S PR: Fix broken select due to misspelling
  (bnc#1012628).
- ASoC: acpi: fix machine driver selection based on quirk
  (bnc#1012628).
- ASoC: rockchip: i2s: fix playback after runtime resume
  (bnc#1012628).
- ASoC: skl: Fix kernel warning due to zero NHTL entry
  (bnc#1012628).
- ASoC: compress: Correct handling of copy callback (bnc#1012628).
- watchdog: imx2_wdt: restore previous timeout after
  suspend+resume (bnc#1012628).
- afs: Add missing afs_put_cell() (bnc#1012628).
- afs: Need to clear responded flag in addr cursor (bnc#1012628).
- afs: Fix missing cursor clearance (bnc#1012628).
- afs: Fix server list handling (bnc#1012628).
- btrfs: Handle btrfs_set_extent_delalloc failure in fixup worker
  (bnc#1012628).
- Btrfs: raid56: iterate raid56 internal bio with
  bio_for_each_segment_all (bnc#1012628).
- kasan: don't emit builtin calls when sanitization is off
  (bnc#1012628).
- kasan: rework Kconfig settings (bnc#1012628).
- media: dvb_frontend: be sure to init dvb_frontend_handle_ioctl()
  return code (bnc#1012628).
- media: dvb-frontends: fix i2c access helpers for KASAN
  (bnc#1012628).
- media: dt-bindings/media/cec-gpio.txt: mention the CEC/HPD
  max voltages (bnc#1012628).
- media: ts2020: avoid integer overflows on 32 bit machines
  (bnc#1012628).
- media: vivid: fix module load error when enabling fb and
  no_error_inj=1 (bnc#1012628).
- media: cxusb, dib0700: ignore XC2028_I2C_FLUSH (bnc#1012628).
- fs/proc/kcore.c: use probe_kernel_read() instead of memcpy()
  (bnc#1012628).
- kernel/async.c: revert "async: simplify lowest_in_progress()"
  (bnc#1012628).
- kernel/relay.c: revert "kernel/relay.c: fix potential memory
  leak" (bnc#1012628).
- pipe: actually allow root to exceed the pipe buffer limits
  (bnc#1012628).
- pipe: fix off-by-one error when checking buffer limits
  (bnc#1012628).
- HID: quirks: Fix keyboard + touchpad on Toshiba Click Mini
  not working (bnc#1012628).
- Bluetooth: btsdio: Do not bind to non-removable BCM43341
  (bnc#1012628).
- Revert "Bluetooth: btusb: fix QCA Rome suspend/resume"
  (bnc#1012628).
- Bluetooth: btusb: Restore QCA Rome suspend/resume fix with a
  "rewritten" version (bnc#1012628).
- ipmi: use dynamic memory for DMI driver override (bnc#1012628).
- signal/openrisc: Fix do_unaligned_access to send the proper
  signal (bnc#1012628).
- signal/sh: Ensure si_signo is initialized in do_divide_error
  (bnc#1012628).
- alpha: fix crash if pthread_create races with signal delivery
  (bnc#1012628).
- alpha: osf_sys.c: fix put_tv32 regression (bnc#1012628).
- alpha: Fix mixed up args in EXC macro in futex operations
  (bnc#1012628).
- alpha: fix reboot on Avanti platform (bnc#1012628).
- alpha: fix formating of stack content (bnc#1012628).
- xtensa: fix futex_atomic_cmpxchg_inatomic (bnc#1012628).
- EDAC, octeon: Fix an uninitialized variable warning
  (bnc#1012628).
- genirq: Make legacy autoprobing work again (bnc#1012628).
- pinctrl: intel: Initialize GPIO properly when used through
  irqchip (bnc#1012628).
- pinctrl: mcp23s08: fix irq setup order (bnc#1012628).
- pinctrl: sx150x: Unregister the pinctrl on release
  (bnc#1012628).
- pinctrl: sx150x: Register pinctrl before adding the gpiochip
  (bnc#1012628).
- pinctrl: sx150x: Add a static gpio/pinctrl pin range mapping
  (bnc#1012628).
- pktcdvd: Fix pkt_setup_dev() error path (bnc#1012628).
- pktcdvd: Fix a recently introduced NULL pointer dereference
  (bnc#1012628).
- blk-mq: quiesce queue before freeing queue (bnc#1012628).
- clocksource/drivers/stm32: Fix kernel panic with multiple timers
  (bnc#1012628).
- lib/ubsan.c: s/missaligned/misaligned/ (bnc#1012628).
- lib/ubsan: add type mismatch handler for new GCC/Clang
  (bnc#1012628).
- objtool: Fix switch-table detection (bnc#1012628).
- arm64: dts: marvell: add Ethernet aliases (bnc#1012628).
- drm/i915: Avoid PPS HW/SW state mismatch due to rounding
  (bnc#1012628).
- ACPI: sbshc: remove raw pointer from printk() message
  (bnc#1012628).
- acpi, nfit: fix register dimm error handling (bnc#1012628).
- ovl: force r/o mount when index dir creation fails
  (bnc#1012628).
- ovl: fix failure to fsync lower dir (bnc#1012628).
- ovl: take mnt_want_write() for work/index dir setup
  (bnc#1012628).
- ovl: take mnt_want_write() for removing impure xattr
  (bnc#1012628).
- ovl: hash directory inodes for fsnotify (bnc#1012628).
- mn10300/misalignment: Use SIGSEGV SEGV_MAPERR to report a
  failed user copy (bnc#1012628).
- devpts: fix error handling in devpts_mntget() (bnc#1012628).
- ftrace: Remove incorrect setting of glob search field
  (bnc#1012628).
- scsi: core: Ensure that the SCSI error handler gets woken up
  (bnc#1012628).
- scsi: lpfc: Fix crash after bad bar setup on driver attachment
  (bnc#1012628).
- scsi: cxlflash: Reset command ioasc (bnc#1012628).
- rcu: Export init_rcu_head() and destroy_rcu_head() to GPL
  modules (bnc#1012628).
- media: dvb_frontend: fix return error code (git-fixes).
- mtd: ubi: wl: Fix error return code in ubi_wl_init()
  (git-fixes).
- Update config files.
- commit 4d42c34
* Thu Feb 15 2018 jmoreira@suse.de
- Add kernel livepatch-devel package
  Resolving non-exported static symbols in kernel livepatches cannot
  be done implicitly. For such, the relocations of these symbols must
  follow a specially crafted format in the respective elf file. Willing
  to make the task of converting the elf into the right format, a tool
  named klp-convert was proposed. Through a file that maps all kernel
  symbols into their respective kernel object, this tool infers which
  non-exported symbol is relative to a livepatch relocation and
  automatically formats the final elf file.
  Add support to the generation of a map file right after the kernel
  compilation.
  Add the package kernel-<flavour>-livepatch-devel that brings
  the map file.
- commit 0b1b4d3
* Tue Feb 13 2018 jslaby@suse.cz
- Linux 4.15.3 (bnc#1012628).
- crypto: tcrypt - fix S/G table for test_aead_speed()
  (bnc#1012628).
- gpio: uniphier: fix mismatch between license text and
  MODULE_LICENSE (bnc#1012628).
- media: tegra-cec: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- media: soc_camera: soc_scale_crop: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- media: mtk-vcodec: add missing MODULE_LICENSE/DESCRIPTION
  (bnc#1012628).
- net: sched: fix use-after-free in tcf_block_put_ext
  (bnc#1012628).
- net_sched: get rid of rcu_barrier() in tcf_block_put_ext()
  (bnc#1012628).
- soreuseport: fix mem leak in reuseport_add_sock() (bnc#1012628).
- ipv6: Fix SO_REUSEPORT UDP socket with implicit sk_ipv6only
  (bnc#1012628).
- cls_u32: add missing RCU annotation (bnc#1012628).
- tcp_bbr: fix pacing_gain to always be unity when using lt_bw
  (bnc#1012628).
- rocker: fix possible null pointer dereference in
  rocker_router_fib_event_work (bnc#1012628).
- net: ipv6: send unsolicited NA after DAD (bnc#1012628).
- Revert "defer call to mem_cgroup_sk_alloc()" (bnc#1012628).
- ipv6: change route cache aging logic (bnc#1012628).
- ipv6: addrconf: break critical section in addrconf_verify_rtnl()
  (bnc#1012628).
- vhost_net: stop device during reset owner (bnc#1012628).
- tcp: release sk_frag.page in tcp_disconnect (bnc#1012628).
- r8169: fix RTL8168EP take too long to complete driver
  initialization (bnc#1012628).
- qmi_wwan: Add support for Quectel EP06 (bnc#1012628).
- qlcnic: fix deadlock bug (bnc#1012628).
- net: igmp: add a missing rcu locking section (bnc#1012628).
- ip6mr: fix stale iterator (bnc#1012628).
- commit e7bb737
* Tue Feb 13 2018 jslaby@suse.cz
- ext4: llseek, do not crop offset on 32bit (bsc#1079747).
- commit c6ab9c6
* Sun Feb 11 2018 afaerber@suse.de
- config: arm64: Enable Hi6421 PMU (bsc#1080449)
- commit 77a784c
* Fri Feb  9 2018 jslaby@suse.cz
- Update i386 config files.
  Switch from almost unusable UNWINDER_GUESS to UNWINDER_FRAME_POINTER
  (which enables FRAME_POINTERs). It will slow down the kernel a bit,
  but improves the stack traces by the order of magnitude. Sad is that
  we have no ORCs on i386...
- commit 1d39996
* Fri Feb  9 2018 jslaby@suse.cz
- Update config files.
  Sync vanilla configs to 4.15.
- commit 85c7881
* Thu Feb  8 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Also require m4 for build.
- commit 0d7b4b3
* Thu Feb  8 2018 jslaby@suse.cz
- Linux 4.15.2 (bnc#1012628).
- KVM: x86: Make indirect calls in emulator speculation safe
  (bnc#1012628).
- KVM: VMX: Make indirect call speculation safe (bnc#1012628).
- x86/alternative: Print unadorned pointers (bnc#1012628).
- auxdisplay: img-ascii-lcd: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- iio: adc/accel: Fix up module licenses (bnc#1012628).
- pinctrl: pxa: pxa2xx: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- ASoC: pcm512x: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- KVM: nVMX: Eliminate vmcs02 pool (bnc#1012628).
- KVM: VMX: introduce alloc_loaded_vmcs (bnc#1012628).
- objtool: Improve retpoline alternative handling (bnc#1012628).
- objtool: Add support for alternatives at the end of a section
  (bnc#1012628).
- objtool: Warn on stripped section symbol (bnc#1012628).
- x86/mm: Fix overlap of i386 CPU_ENTRY_AREA with FIX_BTMAP
  (bnc#1012628).
- x86/entry/64: Remove the SYSCALL64 fast path (bnc#1012628).
- x86/entry/64: Push extra regs right away (bnc#1012628).
- x86/asm: Move 'status' from thread_struct to thread_info
  (bnc#1012628).
- x86/spectre: Fix spelling mistake: "vunerable"-> "vulnerable"
  (bnc#1012628).
- x86/paravirt: Remove 'noreplace-paravirt' cmdline option
  (bnc#1012628).
- KVM: VMX: make MSR bitmaps per-VCPU (bnc#1012628).
- x86/kvm: Update spectre-v1 mitigation (bnc#1012628).
- x86/retpoline: Avoid retpolines for built-in __init functions
  (bnc#1012628).
- x86/speculation: Fix typo IBRS_ATT, which should be IBRS_ALL
  (bnc#1012628).
- KVM/x86: Update the reverse_cpuid list to include CPUID_7_EDX
  (bnc#1012628).
- KVM/x86: Add IBPB support (bnc#1012628).
- KVM/VMX: Emulate MSR_IA32_ARCH_CAPABILITIES (bnc#1012628).
- KVM/VMX: Allow direct access to MSR_IA32_SPEC_CTRL
  (bnc#1012628).
- KVM/SVM: Allow direct access to MSR_IA32_SPEC_CTRL
  (bnc#1012628).
- serial: core: mark port as initialized after successful IRQ
  change (bnc#1012628).
- fpga: region: release of_parse_phandle nodes after use
  (bnc#1012628).
- commit 54903ae
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: install ksym-provides tool (bsc#1077692).
- commit 679f5c5
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: require bison for build.
  linux-next tends to have outdated generated files so it needs bison to
  regenerate them.
- commit 4ad1ede
* Wed Feb  7 2018 msuchanek@suse.de
- Add ksym-provides tool (bsc#1077692).
- commit 9cd1e1e
* Mon Feb  5 2018 jslaby@suse.cz
- x86/pti: Mark constant arrays as __initconst (bsc#1068032
  CVE-2017-5753).
- x86/cpuid: Fix up "virtual" IBRS/IBPB/STIBP feature bits on
  Intel (bsc#1068032 CVE-2017-5753).
- commit 7d4f257
* Mon Feb  5 2018 jslaby@suse.cz
- x86/speculation: Add basic IBRS support infrastructure
  (bsc#1068032 CVE-2017-5753).
- x86/pti: Do not enable PTI on CPUs which are not vulnerable
  to Meltdown (bsc#1068032 CVE-2017-5753).
- x86/cpufeature: Blacklist SPEC_CTRL/PRED_CMD on early Spectre
  v2 microcodes (bsc#1068032 CVE-2017-5753).
- x86/nospec: Fix header guards names (bsc#1068032 CVE-2017-5753).
- x86/bugs: Drop one "mitigation" from dmesg (bsc#1068032
  CVE-2017-5753).
- x86/cpu/bugs: Make retpoline module warning conditional
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Clean up Spectre v2 related CPUID flags
  (bsc#1068032 CVE-2017-5753).
- x86/retpoline: Simplify vmexit_fill_RSB() (bsc#1068032
  CVE-2017-5753).
- x86/speculation: Simplify indirect_branch_prediction_barrier()
  (bsc#1068032 CVE-2017-5753).
- module/retpoline: Warn about missing retpoline in module
  (bsc#1068032 CVE-2017-5753).
- x86/spectre: Check CONFIG_RETPOLINE in command line parser
  (bsc#1068032 CVE-2017-5753).
- x86/speculation: Use Indirect Branch Prediction Barrier in
  context switch (bsc#1068032 CVE-2017-5753).
- Refresh
  patches.suse/0001-x86-cpufeatures-Add-CPUID_7_EDX-CPUID-leaf.patch.
- Refresh
  patches.suse/0002-x86-cpufeatures-Add-Intel-feature-bits-for-Speculati.patch.
- Refresh
  patches.suse/0003-x86-cpufeatures-Add-AMD-feature-bits-for-Speculation.patch.
- Refresh
  patches.suse/0004-x86-msr-Add-definitions-for-new-speculation-control-.patch.
- Refresh
  patches.suse/0007-x86-speculation-Add-basic-IBPB-Indirect-Branch-Predi.patch.
- Refresh patches.suse/supported-flag.
- Delete
  patches.suse/0005-x86-pti-Do-not-enable-PTI-on-processors-which-are-no.patch.
- Delete
  patches.suse/0006-x86-cpufeature-Blacklist-SPEC_CTRL-on-early-Spectre-.patch.
- Delete patches.suse/0008-x86-kvm-Add-IBPB-support.patch.
- Delete
  patches.suse/0009-x86-speculation-Use-Indirect-Branch-Prediction-Barri.patch.
- Delete
  patches.suse/0010-x86-mm-Only-flush-indirect-branches-when-switching-i.patch.
- Delete
  patches.suse/0011-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Delete
  patches.suse/0017-x86-ibrs-Add-new-helper-macros-to-save-restore-MSR_I-fix.patch.
- Delete
  patches.suse/0017-x86-ibrs-Add-new-helper-macros-to-save-restore-MSR_I.patch.
- Delete
  patches.suse/0018-x86-vmx-Direct-access-to-MSR_IA32_SPEC_CTRL.patch.
  Update to the patches from 4.16-rc1 and the updated IBRS patches from
  the dwmw's repo.
- commit cd20d46
* Mon Feb  5 2018 jslaby@suse.cz
- Documentation: Document array_index_nospec (bsc#1068032
  CVE-2017-5715).
- array_index_nospec: Sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5715).
- x86: Implement array_index_mask_nospec (bsc#1068032
  CVE-2017-5715).
- x86: Introduce barrier_nospec (bsc#1068032 CVE-2017-5715).
- x86: Introduce __uaccess_begin_nospec() and uaccess_try_nospec
  (bsc#1068032 CVE-2017-5715).
- x86/usercopy: Replace open coded stac/clac with
  __uaccess_{begin, end} (bsc#1068032 CVE-2017-5715).
- x86/syscall: Sanitize syscall table de-references under
  speculation (bsc#1068032 CVE-2017-5715).
- nl80211: Sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5715).
- x86/spectre: Report get_user mitigation for spectre_v1
  (bsc#1068032 CVE-2017-5715).
- Delete patches.suse/0001-Documentation-document-array_ptr.patch.
- Delete
  patches.suse/0002-asm-nospec-array_ptr-sanitize-speculative-array-de-r.patch.
- Delete patches.suse/0003-x86-implement-array_ptr_mask.patch.
- Delete
  patches.suse/0004-x86-introduce-__uaccess_begin_nospec-and-ifence.patch.
- Delete
  patches.suse/0007-x86-narrow-out-of-bounds-syscalls-to-sys_read-under-.patch.
- Delete
  patches.suse/0009-kvm-x86-update-spectre-v1-mitigation.patch.
- Delete
  patches.suse/0010-nl80211-sanitize-array-index-in-parse_txq_params.patch.
  Replace by the patches from 4.16-rc1.
- commit 8343cab
* Mon Feb  5 2018 jslaby@suse.cz
- scsi: aacraid: remove redundant setting of variable c
  (git-fixes).
- commit 143e25c
* Sun Feb  4 2018 jslaby@suse.cz
- Linux 4.15.1 (bnc#1012628).
- x86/efi: Clarify that reset attack mitigation needs appropriate
  userspace (bnc#1012628).
- Input: synaptics-rmi4 - do not delete interrupt memory too early
  (bnc#1012628).
- Input: synaptics-rmi4 - unmask F03 interrupts when port is
  opened (bnc#1012628).
- test_firmware: fix missing unlock on error in
  config_num_requests_store() (bnc#1012628).
- iio: chemical: ccs811: Fix output of IIO_CONCENTRATION channels
  (bnc#1012628).
- iio: adc: stm32: fix scan of multiple channels with DMA
  (bnc#1012628).
- spi: imx: do not access registers while clocks disabled
  (bnc#1012628).
- serial: imx: Only wakeup via RTSDEN bit if the system has
  RTS/CTS (bnc#1012628).
- serial: 8250_dw: Revert "Improve clock rate setting"
  (bnc#1012628).
- serial: 8250_uniphier: fix error return code in
  uniphier_uart_probe() (bnc#1012628).
- serial: 8250_of: fix return code when probe function fails to
  get reset (bnc#1012628).
- mei: me: allow runtime pm for platform with D0i3 (bnc#1012628).
- android: binder: use VM_ALLOC to get vm area (bnc#1012628).
- ANDROID: binder: remove waitqueue when thread exits
  (bnc#1012628).
- usb/gadget: Fix "high bandwidth" check in
  usb_gadget_ep_match_desc() (bnc#1012628).
- usb: uas: unconditionally bring back host after reset
  (bnc#1012628).
- usb: f_fs: Prevent gadget unbind if it is already unbound
  (bnc#1012628).
- USB: serial: simple: add Motorola Tetra driver (bnc#1012628).
- usbip: list: don't list devices attached to vhci_hcd
  (bnc#1012628).
- usbip: prevent bind loops on devices attached to vhci_hcd
  (bnc#1012628).
- USB: serial: io_edgeport: fix possible sleep-in-atomic
  (bnc#1012628).
- CDC-ACM: apply quirk for card reader (bnc#1012628).
- USB: cdc-acm: Do not log urb submission errors on disconnect
  (bnc#1012628).
- USB: serial: pl2303: new device id for Chilitag (bnc#1012628).
- usb: option: Add support for FS040U modem (bnc#1012628).
- tty: fix data race between tty_init_dev and flush of buf
  (bnc#1012628).
- staging: ccree: fix fips event irq handling build (bnc#1012628).
- staging: ccree: NULLify backup_info when unused (bnc#1012628).
- staging: lustre: separate a connection destroy from free struct
  kib_conn (bnc#1012628).
- scsi: storvsc: missing error code in storvsc_probe()
  (bnc#1012628).
- scsi: aacraid: Fix hang in kdump (bnc#1012628).
- scsi: aacraid: Fix udev inquiry race condition (bnc#1012628).
- ima/policy: fix parsing of fsuuid (bnc#1012628).
- igb: Free IRQs when device is hotplugged (bnc#1012628).
- mtd: nand: denali_pci: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- gpio: ath79: add missing MODULE_DESCRIPTION/LICENSE
  (bnc#1012628).
- gpio: iop: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- power: reset: zx-reboot: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- HID: wacom: Fix reporting of touch toggle
  (WACOM_HID_WD_MUTE_DEVICE) events (bnc#1012628).
- HID: wacom: EKR: ensure devres groups at higher indexes are
  released (bnc#1012628).
- crypto: af_alg - whitelist mask and type (bnc#1012628).
- crypto: sha3-generic - fixes for alignment and big endian
  operation (bnc#1012628).
- crypto: inside-secure - avoid unmapping DMA memory that was
  not mapped (bnc#1012628).
- crypto: inside-secure - fix hash when length is a multiple of
  a block (bnc#1012628).
- crypto: aesni - Fix out-of-bounds access of the AAD buffer in
  generic-gcm-aesni (bnc#1012628).
- crypto: aesni - Fix out-of-bounds access of the data buffer
  in generic-gcm-aesni (bnc#1012628).
- crypto: aesni - add wrapper for generic gcm(aes) (bnc#1012628).
- crypto: aesni - fix typo in generic_gcmaes_decrypt
  (bnc#1012628).
- crypto: aesni - handle zero length dst buffer (bnc#1012628).
- crypto: ecdh - fix typo in KPP dependency of CRYPTO_ECDH
  (bnc#1012628).
- ALSA: hda - Reduce the suspend time consumption for ALC256
  (bnc#1012628).
- gpio: Fix kernel stack leak to userspace (bnc#1012628).
- gpio: stmpe: i2c transfer are forbiden in atomic context
  (bnc#1012628).
- tools/gpio: Fix build error with musl libc (bnc#1012628).
- Bluetooth: hci_serdev: Init hci_uart proto_lock to avoid oops
  (bnc#1012628).
- commit 671bf29
* Thu Feb  1 2018 matwey.kornilov@gmail.com
- config: arm64: Enable RockChip 8xx
  We need RockChip RK-808 support to run openSUSE on Rock64 board (RK3328).
  Currently, even voltage regulator is missed.
- commit a348749
* Mon Jan 29 2018 jeffm@suse.com
- Update to 4.15-final.
- Eliminated 5 patches.
- commit 36830f7
* Mon Jan 29 2018 jeffm@suse.com
- btrfs: fix btrfs_evict_inode to handle abnormal inodes correctly (bsc#1078019).
- commit d3f1d2c
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- config: arm64: enable UNMAP_KERNEL_AT_EL0 and HARDEN_BRANCH_PREDICTOR
- commit c41900c
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- arm64: Turn on KPTI only on CPUs that need it (bsc#1068032).
- arm64: Branch predictor hardening for Cavium ThunderX2
  (bsc#1068032).
- arm64: Run enable method for errata work arounds on late CPUs
  (bsc#1068032).
- arm64: Move BP hardening to check_and_switch_context
  (bsc#1068032).
- arm: KVM: Invalidate icache on guest exit for Cortex-A15
  (bsc#1068032).
- arm: Invalidate icache on prefetch abort outside of user
  mapping on Cortex-A15 (bsc#1068032).
- arm: Add icache invalidation on switch_mm for Cortex-A15
  (bsc#1068032).
- arm: KVM: Invalidate BTB on guest exit (bsc#1068032).
- arm: Invalidate BTB on prefetch abort outside of user mapping
  on Cortex A8, A9, A12 and A17 (bsc#1068032).
- arm: Add BTB invalidation on switch_mm for Cortex-A9, A12 and
  A17 (bsc#1068032).
- arm64: cputype: Add MIDR values for Cavium ThunderX2 CPUs
  (bsc#1068032).
- arm64: Implement branch predictor hardening for Falkor
  (bsc#1068032).
- arm64: Implement branch predictor hardening for affected
  Cortex-A CPUs (bsc#1068032).
- arm64: cputype: Add missing MIDR values for Cortex-A72 and
  Cortex-A75 (bsc#1068032).
- arm64: KVM: Make PSCI_VERSION a fast path (bsc#1068032).
- arm64: KVM: Use per-CPU vector when BP hardening is enabled
  (bsc#1068032).
- arm64: Add skeleton to harden the branch predictor against
  aliasing attacks (bsc#1068032).
- arm64: Move post_ttbr_update_workaround to C code (bsc#1068032).
- drivers/firmware: Expose psci_get_version through psci_ops
  structure (bsc#1068032).
- arm64: Take into account ID_AA64PFR0_EL1.CSV3 (bsc#1068032).
- arm64: Kconfig: Reword UNMAP_KERNEL_AT_EL0 kconfig entry
  (bsc#1068032).
- arm64: use RET instruction for exiting the trampoline
  (bsc#1068032).
- arm64: capabilities: Handle duplicate entries for a capability
  (bsc#1068032).
- arm64: cpufeature: Pass capability structure to ->enable
  callback (bsc#1068032).
- arm64: kpti: Fix the interaction between ASID switching and
  software PAN (bsc#1068032).
- arm64: kaslr: Put kernel vectors address in separate data page
  (bsc#1068032).
- arm64: mm: Introduce TTBR_ASID_MASK for getting at the ASID
  in the TTBR (bsc#1068032).
- perf: arm_spe: Fail device probe when
  arm64_kernel_unmapped_at_el0() (bsc#1068032).
- arm64: Kconfig: Add CONFIG_UNMAP_KERNEL_AT_EL0 (bsc#1068032).
- arm64: entry: Add fake CPU feature for unmapping the kernel
  at EL0 (bsc#1068032).
- arm64: tls: Avoid unconditional zeroing of tpidrro_el0 for
  native tasks (bsc#1068032).
- arm64: erratum: Work around Falkor erratum #E1003 in trampoline
  code (bsc#1068032).
- arm64: entry: Hook up entry trampoline to exception vectors
  (bsc#1068032).
- arm64: entry: Explicitly pass exception level to kernel_ventry
  macro (bsc#1068032).
- arm64: mm: Map entry trampoline into trampoline and kernel
  page tables (bsc#1068032).
- arm64: entry: Add exception trampoline page for exceptions
  from EL0 (bsc#1068032).
- arm64: mm: Invalidate both kernel and user ASIDs when performing
  TLBI (bsc#1068032).
- arm64: mm: Add arm64_kernel_unmapped_at_el0 helper
  (bsc#1068032).
- arm64: mm: Allocate ASIDs in pairs (bsc#1068032).
- arm64: mm: Fix and re-enable ARM64_SW_TTBR0_PAN (bsc#1068032).
- arm64: mm: Rename post_ttbr0_update_workaround (bsc#1068032).
- arm64: mm: Remove pre_ttbr0_update_workaround for Falkor
  erratum #E1003 (bsc#1068032).
- arm64: mm: Move ASID from TTBR0 to TTBR1 (bsc#1068032).
- arm64: mm: Temporarily disable ARM64_SW_TTBR0_PAN (bsc#1068032).
- arm64: mm: Use non-global mappings for kernel space
  (bsc#1068032).
- commit cdf2ded
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- config: arm64: enable rk3399 missing drivers
  These drivers are required for Rockchip RK3399 Sapphire board
- commit 94b8551
* Fri Jan 26 2018 jslaby@suse.cz
- x86/ibrs: Add new helper macros to save/restore
  MSR_IA32_SPEC_CTRL fix (bsc#1068032 CVE-2017-5753).
- commit 13295d4
* Thu Jan 25 2018 jslaby@suse.cz
- x86/cpufeature: Move processor tracing out of scattered features
  (bsc#1068032 CVE-2017-5753).
- Refresh
  patches.suse/0001-x86-cpufeatures-Add-CPUID_7_EDX-CPUID-leaf.patch.
- Refresh
  patches.suse/0007-x86-speculation-Add-basic-IBPB-Indirect-Branch-Predi.patch.
- commit 8d8b718
* Wed Jan 24 2018 jslaby@suse.cz
- x86/retpoline: Add LFENCE to the retpoline/RSB filling RSB
  macros (bsc#1068032 CVE-2017-5753).
- commit 8dc7c71
* Wed Jan 24 2018 jslaby@suse.cz
- x86/vmx: Direct access to MSR_IA32_SPEC_CTRL (bsc#1068032
  CVE-2017-5753).
- x86/ibrs: Add new helper macros to save/restore
  MSR_IA32_SPEC_CTRL (bsc#1068032 CVE-2017-5753).
- x86/enter: Use IBRS on syscall and interrupts (bsc#1068032
  CVE-2017-5753).
- x86/enter: Create macros to restrict/unrestrict Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5753).
- x86/idle: Control Indirect Branch Speculation in idle
  (bsc#1068032 CVE-2017-5753).
- x86: Simplify spectre_v2 command line parsing (bsc#1068032
  CVE-2017-5753).
- x86/speculation: Add inlines to control Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5753).
- x86/speculation: Add basic IBRS support infrastructure
  (bsc#1068032 CVE-2017-5753).
- x86/mm: Only flush indirect branches when switching into non
  dumpable process (bsc#1068032 CVE-2017-5753).
- x86/speculation: Use Indirect Branch Prediction Barrier in
  context switch (bsc#1068032 CVE-2017-5753).
- x86/kvm: Add IBPB support (bsc#1068032 CVE-2017-5753).
- x86/speculation: Add basic IBPB (Indirect Branch Prediction
  Barrier) support (bsc#1068032 CVE-2017-5753).
- x86/cpufeature: Blacklist SPEC_CTRL on early Spectre v2
  microcodes (bsc#1068032 CVE-2017-5753).
- x86/pti: Do not enable PTI on processors which are not
  vulnerable to Meltdown (bsc#1068032 CVE-2017-5753).
- x86/msr: Add definitions for new speculation control MSRs
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Add AMD feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Add Intel feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Add CPUID_7_EDX CPUID leaf (bsc#1068032
  CVE-2017-5753).
- x86/retpoline: Optimize inline assembler for vmexit_fill_RSB
  (bsc#1068032 CVE-2017-5753).
- x86/retpoline: Fill RSB on context switch for affected CPUs
  (bsc#1068032 CVE-2017-5753).
- commit e36ab4f
* Wed Jan 24 2018 jslaby@suse.cz
- Documentation: document array_ptr (bsc#1068032 CVE-2017-5715).
- asm/nospec, array_ptr: sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5715).
- x86: implement array_ptr_mask() (bsc#1068032 CVE-2017-5715).
- x86: introduce __uaccess_begin_nospec and ifence (bsc#1068032
  CVE-2017-5715).
- x86, __get_user: use __uaccess_begin_nospec (bsc#1068032
  CVE-2017-5715).
- x86, get_user: use pointer masking to limit speculation
  (bsc#1068032 CVE-2017-5715).
- x86: narrow out of bounds syscalls to sys_read under speculation
  (bsc#1068032 CVE-2017-5715).
- vfs, fdtable: prevent bounds-check bypass via speculative
  execution (bsc#1068032 CVE-2017-5715).
- kvm, x86: update spectre-v1 mitigation (bsc#1068032
  CVE-2017-5715).
- nl80211: sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5715).
- Delete
  patches.suse/0003-locking-barriers-introduce-new-observable-speculatio.patch.
- Delete
  patches.suse/0004-bpf-prevent-speculative-execution-in-eBPF-interprete.patch.
- Delete
  patches.suse/0005-x86-bpf-jit-prevent-speculative-execution-when-JIT-i.patch.
- Delete
  patches.suse/0006-uvcvideo-prevent-speculative-execution.patch.
- Delete
  patches.suse/0007-carl9170-prevent-speculative-execution.patch.
- Delete
  patches.suse/0008-p54-prevent-speculative-execution.patch.
- Delete
  patches.suse/0009-qla2xxx-prevent-speculative-execution.patch.
- Delete
  patches.suse/0010-cw1200-prevent-speculative-execution.patch.
- Delete
  patches.suse/0011-Thermal-int340x-prevent-speculative-execution.patch.
- Delete
  patches.suse/0012-ipv4-prevent-speculative-execution.patch.
- Delete
  patches.suse/0013-ipv6-prevent-speculative-execution.patch.
- Delete patches.suse/0014-fs-prevent-speculative-execution.patch.
- Delete
  patches.suse/0015-net-mpls-prevent-speculative-execution.patch.
- Delete
  patches.suse/0016-udf-prevent-speculative-execution.patch.
- Delete
  patches.suse/0017-userns-prevent-speculative-execution.patch.
  Replace by the potential upstream solution.
- commit 804f8a1
* Mon Jan 22 2018 msuchanek@suse.de
- rpm/mkspec-dtb: Remove COPYING file (bsc#1076905).
  It conflicts between different versions of dtb package.
- commit 0e5fcf9
* Thu Jan 18 2018 jslaby@suse.cz
- Update config files (bsc#1068032 CVE-2017-5715).
  Enable RETPOLINE -- the compiler is capable of them already.
- commit 5d5345e
* Wed Jan 17 2018 rjschwei@suse.com
- kernel-obs-build.spec.in: enable xfs module
  This allows the public cloud team to build images with XFS
  as root filesystem
- commit 95a2d6f
* Wed Jan 17 2018 msuchanek@suse.de
- macros.kernel-source: pass -f properly in module subpackage (boo#1076393).
- commit 66bd9b8
* Mon Jan 15 2018 jeffm@suse.com
- Update to 4.15-rc8.
- Eliminated 3 patches.
- Config changes:
  - Security:
  - BPF_JIT_ALWAYS_ON=y
  - RETPOLINE=n (depends on gcc with -mindirect-branch=thunk-extern)
- commit 05e4405
* Fri Jan 12 2018 jslaby@suse.cz
- bpf, array: fix overflow in max_entries and undefined behavior
  in index_mask (bsc#1068032 CVE-2017-5753).
- commit 5fdfc1a
* Fri Jan 12 2018 jslaby@suse.cz
- bpf: prevent out-of-bounds speculation (bsc#1068032
  CVE-2017-5753).
- commit 0eca303
* Thu Jan 11 2018 matwey.kornilov@gmail.com
- config: arm64: Enable Aardvark PCIe controller
  Aardvark PCIe controller is a part of Marvel Armada 3700 SoC.
  This option is required to support PCIe for JeOS-espressobin.
- commit b0bb655
* Thu Jan 11 2018 lpechacek@suse.com
- rpm/kernel-binary.spec.in: more specific kGraft Provides: (fate#323682)
  Follow openSUSE packaging practices described at
  https://en.opensuse.org/openSUSE:Package_dependencies#Renaming_a_package.
- commit 050081b
* Wed Jan 10 2018 jslaby@suse.cz
- x86/cpu/AMD: Make LFENCE a serializing instruction (bsc#1068032
  CVE-2017-5754).
- x86/cpu/AMD: Use LFENCE_RDTSC in preference to MFENCE_RDTSC
  (bsc#1068032 CVE-2017-5754).
- Delete
  patches.suse/0001-x86-cpu-AMD-Make-the-LFENCE-instruction-serialized.patch.
- Delete
  patches.suse/0002-x86-cpu-AMD-Remove-now-unused-definition-of-MFENCE_R.patch.
  Use the variants from upstream (tip tree).
- commit 33b16eb
* Mon Jan  8 2018 msuchanek@suse.de
- kernel-obs-build.spec.in: add --no-hostonly-cmdline to dracut invocation (boo#1062303).
  call dracut with --no-hostonly-cmdline to avoid the random rootfs UUID
  being added into the initrd's /etc/cmdline.d/95root-dev.conf
- commit da5186f
* Mon Jan  8 2018 jeffm@suse.com
- Update to 4.15-rc7.
- Eliminated 1 patch.
- commit b07c570
* Sat Jan  6 2018 jslaby@suse.cz
- rpm/constraints.in: lower kernel-syzkaller's mem requirements
  OBS now reports that it needs only around 2G, so lower the limit to
  8G, so that more compliant workers can be used.
- commit a73399a
* Wed Jan  3 2018 jeffm@suse.com
- config: x86, PAGE_TABLE_ISOLATION=y (bsc#1068032).
- commit 4343d87
* Tue Jan  2 2018 jslaby@suse.cz
- userns: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- udf: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- net: mpls: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- fs: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- ipv6: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- ipv4: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- Thermal/int340x: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- cw1200: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- qla2xxx: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- p54: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- carl9170: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- uvcvideo: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- x86, bpf, jit: prevent speculative execution when JIT is enabled
  (bnc#1068032 CVE-2017-5753).
- bpf: prevent speculative execution in eBPF interpreter
  (bnc#1068032 CVE-2017-5753).
- locking/barriers: introduce new observable speculation barrier
  (bnc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Remove now unused definition of MFENCE_RDTSC
  feature (bnc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Make the LFENCE instruction serialized (bnc#1068032
  CVE-2017-5753).
- commit ee4aa62
* Tue Jan  2 2018 jeffm@suse.com
- Update to 4.15-rc6.
- Config changes:
  - x86: PAGE_TABLE_ISOLATION=n (default, performance)
- commit cd70bd8
* Mon Dec 25 2017 jeffm@suse.com
- config: disable BUG_ON_DATA_CORRUPTION
  On its face this option makes sense but it brings along with it
  DEBUG_LIST, which is very expensive and obvious on benchmarks.
- commit 9fcc9f1
* Mon Dec 25 2017 jeffm@suse.com
- config: refresh i386/default
  Commit 4735d41aeeb added a disabled CONFIG_SPI_INTEL_SPI_PLATFORM option
  that doesn't exist on i386/default (at least in 4.15-rc5).
- commit 84167ae
* Sun Dec 24 2017 jeffm@suse.com
- Update to 4.15-rc5.
- Config changes:
  - i386: NR_CPUS 128->64
  - 7bbcbd3d1cd (x86/Kconfig: Limit NR_CPUS on 32-bit to a sane amount)
- commit 9e8deb3
* Thu Dec 21 2017 msuchanek@suse.de
- kernel-obs-build: use pae and lpae kernels where available
  (bsc#1073579).
- commit 1ac1946
* Thu Dec 21 2017 tiwai@suse.de
- Disable CONFIG_SPI_INTEL_SPI_PCI as well (bsc#1073836)
- commit ddb33b2
* Thu Dec 21 2017 tiwai@suse.de
- Disable CONFIG_SPI_INTEL_SPI_PLATFORM for BIOS breakge on Lenovo laptops
  (bsc#1073836)
- commit 4735d41
* Tue Dec 19 2017 jeffm@suse.com
- Update to 4.15-rc4.
- Eliminated 1 patch.
- Config changes:
  - ARM:
  - QCOM_FALKOR_ERRATUM_E1041=y
  - Overlayfs:
  - OVERLAY_FS_REDIRECT_ALWAYS_FOLLOW=y (preserves existing behavior)
- commit ff8819c
* Fri Dec 15 2017 jslaby@suse.cz
- x86/stacktrace: make clear the success paths (bnc#1058115).
- Refresh
  patches.suse/0003-x86-stacktrace-remove-STACKTRACE_DUMP_ONCE-from-__sa.patch.
- Refresh
  patches.suse/0004-x86-stacktrace-do-not-fail-for-ORC-with-regs-on-stac.patch.
- Delete
  patches.suse/0002-x86-stacktrace-remove-unwind_state-error.patch.
  Fix livepatch to succeed also for kthreads and idle tasks.
- commit 5292470
* Wed Dec 13 2017 msuchanek@suse.de
- s390/sclp: disable FORTIFY_SOURCE for early sclp code (-).
- commit 62412b6
* Mon Dec 11 2017 jeffm@suse.com
- Update to 4.15-rc3.
- Eliminated 1 patch.
- commit 383d72f
* Sat Dec  9 2017 afaerber@suse.de
- config: armv7hl: Enable SUN4I_A10_CCU for Allwinner A20 (boo#1072032)
- commit 170d177
* Fri Dec  8 2017 msuchanek@suse.de
- Add undefine _unique_build_ids (bsc#964063)
- commit 47e91a1
* Tue Dec  5 2017 jslaby@suse.cz
- x86/stacktrace: do now unwind after user regs (bnc#1058115).
- x86/stacktrace: remove unwind_state->error (bnc#1058115).
- x86/stacktrace: remove STACKTRACE_DUMP_ONCE from
  __save_stack_trace_reliable (bnc#1058115).
- x86/stacktrace: do not fail for ORC with regs on stack
  (bnc#1058115).
  More make-ORC-reliable patches.
- commit ef715eb
* Mon Dec  4 2017 jeffm@suse.com
- Update to 4.15-rc2.
- Eliminated 2 patches.
- commit 68549b6
* Thu Nov 30 2017 jslaby@suse.cz
- Refresh
  patches.suse/apparmor-fix-oops-in-audit_signal_cb-hook.patch.
  Update upstream status.
- commit ee861fd
* Thu Nov 30 2017 jslaby@suse.cz
- mmc: sdhci: Avoid swiotlb buffer being full (bnc#1068877).
- commit 2659efd
* Wed Nov 29 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: fix incorrectly moved comment
  While moving # END COMMON DEPS moved following comment with it.
- commit 858b7e7
* Tue Nov 28 2017 afaerber@suse.de
- config: armv7hl: Update to 4.15-rc1
- commit b4c7f19
* Tue Nov 28 2017 afaerber@suse.de
- config: armv6hl: Update to 4.15-rc1
- commit edcdf48
* Tue Nov 28 2017 afaerber@suse.de
- config: arm64: Update to 4.15-rc1
- commit 3278861
* Mon Nov 27 2017 jeffm@suse.com
- Update to 4.15-rc1.
- Eliminated 74 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - CPU_ISOLATION=y
  - GUP_BENCHMARK=n
  - x86:
  - X86_INTEL_UMIP=y
  - PINCTRL_CEDARFORK=m
  - INTEL_SOC_PMIC_CHTDC_TI=m
  - INTEL_WMI_THUNDERBOLT=m
  - DELL_SMBIOS_WMI=m
  - DELL_SMBIOS_SMM=m
  - CHT_DC_TI_PMIC_OPREGION=y
  - RPMSG_CHAR=m
  - i386:
  - IR_SPI=m
  - IR_GPIO_CIR=m
  - IR_GPIO_TX=m
  - IR_PWM_TX=m
  - powerpc:
  - PPC_RADIX_MMU_DEFAULT=y (default)
  - MEM_SOFT_DIRTY=n (needs arch expert review)
  - PINCTRL=n
  - PPC_FAST_ENDIAN_SWITCH=n (default)
  - s390:
  - GCC_PLUGINS=n
  - MEM_SOFT_DIRTY=(needs arch expert review)
  - PINCTRL=n
  - FORTIFY_SOURCE=y
  - s390/zfcpdump:
  - BPF_STREAM_PARSER=n
  - MTD=n
  - Network:
  - NET_SCH_CBS=m
  - VSOCKETS_DIAG=m
  - DP83822_PHY=m
  - RENESAS_PHY=m
  - THUNDERBOLT_NET=m
  - Input:
  - TOUCHSCREEN_EXC3000=m
  - TOUCHSCREEN_HIDEEP=m
  - TOUCHSCREEN_S6SY761=m
  - DRM_I2C_ADV7511_CEC=y
  - Misc:
  - IPMI_PROC_INTERFACE=y
  - GPIO_MAX3191X=m
  - MANAGER_SBS=m
  - W1_SLAVE_DS28E17=m
  - SENSORS_MAX6621=m
  - SENSORS_MAX31785=m
  - CEC_GPIO=m
  - TYPEC_TPS6598X=m
  - RPMSG_VIRTIO=m
  - IIO_CROS_EC_ACCEL_LEGACY=m
  - RFD77402=m
  - NTB_SWITCHTEC=m
  - MMC_SDHCI_OMAP=m
  - Filesystems:
  - XFS_ONLINE_SCRUB=n (still experimental)
  - BTRFS_FS_REF_VERIFY=n
  - CRAMFS_BLOCKDEV=y
  - CRAMFS_MTD=y
  - INTEGRITY_TRUSTED_KEYRING=y
  - Crypto:
  - CRYPTO_SM3=m
  - SIGNED_PE_FILE_VERIFICATION=y
  - SYSTEM_TRUSTED_KEYS (empty)
  - SYSTEM_EXTRA_CERTIFICATE=n
  - SECONDARY_TRUSTED_KEYRING=n
  - LEDS:
  - LEDS_APU=m
  - LEDS_TRIGGER_ACTIVITY=m
  - RTC:
  - RTC_DRV_PCF85363=m
  - Xen:
  - XEN_PVCALLS_FRONTEND=n
  - Graphics:
  - DRM_AMD_DC=y
  - DRM_AMD_DC_PRE_VEGA=y
  - DRM_AMD_DC_FBC=y ?
  - DRM_AMD_DC_DCN1_0=y
  - DEBUG_KERNEL_DC=n
  - NOUVEAU_DEBUG_MMU=n
  - Storage:
  - NVME_MULTIPATH=y
  - IB:
  - MLX4_CORE_GEN2=y
  - Sound:
  - SND_SOC_INTEL_SST_TOPLEVEL=m
  - SND_SOC_INTEL_BAYTRAIL=m
  - Testing:
  - KCOV_ENABLE_COMPARISONS=y (syzkaller)
  - BOOTPARAM_LOCKDEP_CROSSRELEASE_FULLSTACK=n
  - PREEMPTIRQ_EVENTS=y
  - TEST_FIND_BIT=n
  - PKCS7_TEST_KEY=n
  - CHASH_SELFTEST=n
  - CHASH_STATS=n
- commit bc47c49
* Sun Nov 26 2017 afaerber@suse.de
- config: armv6hl: Enable 8250 irq sharing for RPi Zero W (boo#1069828)
- commit 01942c4
* Sat Nov 25 2017 afaerber@suse.de
- config: armv6hl: Enable brcmfmac for RPi Zero W (boo#1069830)
- commit 56423d9
* Sat Nov 25 2017 afaerber@suse.de
- config: armv6hl: Enable 8250 serial console for RPi Zero W (boo#1069828)
- commit 3a3001a
* Fri Nov 24 2017 bp@suse.de
- dvb_frontend: don't use-after-free the frontend struct
  (bsc#1067087 CVE-2017-16648).
- media: dvb-core: always call invoke_release() in fe_free()
  (bsc#1067087).
- commit 2a04ad0
* Fri Nov 24 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Correct supplements for recent SLE products (bsc#1067494)
- commit 8f05b9f
* Fri Nov 24 2017 jbeulich@suse.com
- supported:conf: Remove stale Xen driver entries.
- commit c46464b
* Fri Nov 24 2017 jslaby@suse.cz
- ipmi_si: fix memory leak on new_smi (git-fixes).
- commit 4ca3b35
* Fri Nov 24 2017 jslaby@suse.cz
- Linux 4.14.2 (bnc#1012628).
- af_netlink: ensure that NLMSG_DONE never fails in dumps
  (bnc#1012628).
- vxlan: fix the issue that neigh proxy blocks all icmpv6 packets
  (bnc#1012628).
- net: cdc_ncm: GetNtbFormat endian fix (bnc#1012628).
- fealnx: Fix building error on MIPS (bnc#1012628).
- net/sctp: Always set scope_id in sctp_inet6_skb_msgname
  (bnc#1012628).
- ima: do not update security.ima if appraisal status is not
  INTEGRITY_PASS (bnc#1012628).
- serial: omap: Fix EFR write on RTS deassertion (bnc#1012628).
- serial: 8250_fintek: Fix finding base_port with activated
  SuperIO (bnc#1012628).
- tpm-dev-common: Reject too short writes (bnc#1012628).
- rcu: Fix up pending cbs check in rcu_prepare_for_idle
  (bnc#1012628).
- mm/pagewalk.c: report holes in hugetlb ranges (bnc#1012628).
- ocfs2: fix cluster hang after a node dies (bnc#1012628).
- ocfs2: should wait dio before inode lock in ocfs2_setattr()
  (bnc#1012628).
- ipmi: fix unsigned long underflow (bnc#1012628).
- mm/page_alloc.c: broken deferred calculation (bnc#1012628).
- mm/page_ext.c: check if page_ext is not prepared (bnc#1012628).
- coda: fix 'kernel memory exposure attempt' in fsync
  (bnc#1012628).
- ipmi: Prefer ACPI system interfaces over SMBIOS ones
  (bnc#1012628).
- commit 295c90a
* Thu Nov 23 2017 jslaby@suse.cz
- apparmor: fix oops in audit_signal_cb hook (bnc#1069562).
- Refresh patches.suse/0001-AppArmor-basic-networking-rules.patch.
- commit d091ad8
* Thu Nov 23 2017 jslaby@suse.cz
- bio: ensure __bio_clone_fast copies bi_partno (bnc#1069605).
- commit 59c6ade
* Tue Nov 21 2017 jslaby@suse.cz
- Update config files.
  After renaming the UNWINDER config options, vanilla has the old names
  and they need to be in configs. For example, x86_64 default config
  has CONFIG_UNWINDER_ORC=y, vanilla has CONFIG_ORC_UNWINDER=y.
- commit d0dab46
* Tue Nov 21 2017 jslaby@suse.cz
- objtool: Print top level commands on incorrect usage
  (bnc#1058115).
- commit 6603336
* Tue Nov 21 2017 jslaby@suse.cz
- x86/unwind: Make CONFIG_UNWINDER_ORC=y the default in kconfig
  for 64-bit (bnc#1058115).
- Update config files.
- x86/unwind: Rename unwinder config options to
  'CONFIG_UNWINDER_*' (bnc#1058115).
- Refresh patches.suse/0001-orc-mark-it-as-reliable.patch.
- Update config files.
- x86/unwinder: Make CONFIG_UNWINDER_ORC=y the default in the
  64-bit defconfig (bnc#1058115).
- commit c81ce89
* Tue Nov 21 2017 jslaby@suse.cz
- x86/stacktrace: Avoid recording save_stack_trace() wrappers
  (bnc#1058115).
- commit fa72e96
* Tue Nov 21 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
  Update upstream status.
- commit f655f80
* Tue Nov 21 2017 jslaby@suse.cz
- move all patches to patches.suse/
- commit 6fafae6
* Tue Nov 21 2017 jslaby@suse.cz
- Linux 4.14.1 (bnc#1012628).
- EDAC, sb_edac: Don't create a second memory controller if HA1
  is not present (bnc#1012628).
- dmaengine: dmatest: warn user when dma test times out
  (bnc#1012628).
- crypto: dh - Fix double free of ctx->p (bnc#1012628).
- crypto: dh - Don't permit 'p' to be 0 (bnc#1012628).
- crypto: dh - Don't permit 'key' or 'g' size longer than 'p'
  (bnc#1012628).
- crypto: brcm - Explicity ACK mailbox message (bnc#1012628).
- USB: early: Use new USB product ID and strings for DbC device
  (bnc#1012628).
- USB: usbfs: compute urb->actual_length for isochronous
  (bnc#1012628).
- USB: Add delay-init quirk for Corsair K70 LUX keyboards
  (bnc#1012628).
- usb: gadget: f_fs: Fix use-after-free in ffs_free_inst
  (bnc#1012628).
- USB: serial: metro-usb: stop I/O after failed open
  (bnc#1012628).
- USB: serial: Change DbC debug device binding ID (bnc#1012628).
- USB: serial: qcserial: add pid/vid for Sierra Wireless EM7355
  fw update (bnc#1012628).
- USB: serial: garmin_gps: fix I/O after failed probe and remove
  (bnc#1012628).
- USB: serial: garmin_gps: fix memory leak on probe errors
  (bnc#1012628).
- selftests/x86/protection_keys: Fix syscall NR redefinition
  warnings (bnc#1012628).
- x86/MCE/AMD: Always give panic severity for UC errors in kernel
  context (bnc#1012628).
- platform/x86: peaq-wmi: Add DMI check before binding to the
  WMI interface (bnc#1012628 bsc#1059807).
- platform/x86: peaq_wmi: Fix missing terminating entry for
  peaq_dmi_table (bnc#1012628).
- HID: cp2112: add HIDRAW dependency (bnc#1012628).
- HID: wacom: generic: Recognize WACOM_HID_WD_PEN as a type of
  pen collection (bnc#1012628).
- rpmsg: glink: Add missing MODULE_LICENSE (bnc#1012628).
- staging: wilc1000: Fix bssid buffer offset in Txq (bnc#1012628).
- staging: sm750fb: Fix parameter mistake in poke32 (bnc#1012628).
- staging: ccree: fix 64 bit scatter/gather DMA ops (bnc#1012628).
- staging: greybus: spilib: fix use-after-free after
  deregistration (bnc#1012628).
- staging: vboxvideo: Fix reporting invalid
  suggested-offset-properties (bnc#1012628).
- staging: rtl8188eu: Revert 4 commits breaking ARP (bnc#1012628).
- spi: fix use-after-free at controller deregistration
  (bnc#1012628).
- sparc32: Add cmpxchg64() (bnc#1012628).
- sparc64: mmu_context: Add missing include files (bnc#1012628).
- sparc64: Fix page table walk for PUD hugepages (bnc#1012628).
- commit b1ba0c0
* Wed Nov 15 2017 rgoldwyn@suse.com
- apparmor: Fix quieting of audit messages for network mediation
  (FATE#300516, boo#1065536).
- apparmor: update apparmor-basic-networking-rules for 4.11-rc1
  (FATE#300516, boo#1065536).
- AppArmor: basic networking rules (FATE#300516, boo#1065536).
- commit fca1de8
* Wed Nov 15 2017 rgoldwyn@suse.com
- VFS: Handle lazytime in do_mount() (boo#1068256).
- commit 0f12060
* Mon Nov 13 2017 jeffm@suse.com
- Update to 4.14-final.
- commit c152297
* Thu Nov  9 2017 lpechacek@suse.com
- rpm/kernel-binary.spec.in: rename kGraft to KLP (fate#323682)
- commit 0ed191d
* Wed Nov  8 2017 tiwai@suse.de
- media: dib0700: fix invalid dvb_detach argument (CVE-2017-16646
  bsc#1067105).
- commit c6cd519
* Mon Nov  6 2017 jeffm@suse.com
- Update to 4.14-rc8.
- commit 0fbdeee
* Mon Nov  6 2017 tiwai@suse.de
- media: imon: Fix null-ptr-deref in imon_probe (CVE-2017-16537
  bsc#1066573).
- [media] cx231xx-cards: fix NULL-deref on missing association
  descriptor (CVE-2017-16536 bsc#1066606).
- commit 0cd38c2
* Mon Nov  6 2017 jkosina@suse.cz
- rpm/kernel-binary.spec.in: add explicit dependency of kernel-*-devel on
  libelf-devel.
  Otherwise warning that got turned into error by upstream 3dd40cb3 ("objtool:
  Upgrade libelf-devel warning to error...") would trigger and cause any
  packages being built against kernel-*-devel (such as KMPs, crash) not to have
  the libelf dependency included, and fail to build.
- rpm/kernel-binary.spec.in: add explicit dependency of kernel-*-devel on
  libelf-devel. Otherwise warning that got turned into error by e683952999
  ("objtool: Upgrade libelf-devel warning to error...") would trigger and
  cause any packages being built against kernel-*-devel (such as KMPs,
  crash) not to have the libelf dependency included, and fail to build.
- commit f6c0f80
* Mon Oct 30 2017 neilb@suse.com
- REVERT:  md/bitmap: copy correct data for bitmap super
  (bsc#1062597).
- commit 9382440
* Mon Oct 30 2017 jeffm@suse.com
- Update to 4.14-rc7.
- commit dbf3e9b
* Fri Oct 27 2017 jslaby@suse.cz
- futex: futex_wake_op, fix sign_extend32 sign bits (bnc#1064590).
- commit a6d946f
* Thu Oct 26 2017 neilb@suse.com
- VFS: expedite unmount (bsc#1024412).
- commit 10c4365
* Mon Oct 23 2017 jeffm@suse.com
- Update to 4.14-rc6.
- Eliminated 2 patches.
- commit 8b364ca
* Wed Oct 18 2017 mcgrof@suse.com
- mac80211: accept key reinstall without changing anything (CVE-2017-13080 bsc#1063667).
- commit 19d19fc
* Mon Oct 16 2017 jeffm@suse.com
- Update to 4.14-rc5.
- commit 39eecab
* Fri Oct 13 2017 msuchanek@suse.de
- Revert "rpm/constraints.in: Lower default disk space requirement from 25G to 24G"
  This reverts commit 406abda1467c038842febffe264faae1fa2e3c1d.
  ok, did not wait long enough to see the failure.
- commit ed99981
* Fri Oct 13 2017 msuchanek@suse.de
- rpm/constraints.in: Lower default disk space requirement from 25G to 24G
  25G is rejected by the build service on ARM.
- commit 406abda
* Mon Oct  9 2017 jeffm@suse.com
- Update to 4.14-rc4.
- commit 879f297
* Fri Oct  6 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: add the kernel-binary dependencies to
  kernel-binary-base (bsc#1060333).
- commit 955681c
* Fri Oct  6 2017 pmladek@suse.com
- Delete
  patches.suse/ftrace-x86-xen-use-kernel-identity-mapping-only-when.patch.
  The change is not longer needed with PVOPS Xen (bsc#873195).
- commit 8366b6a
* Thu Oct  5 2017 jeffm@suse.com
- Delete patches.rpmify/cloneconfig.diff.
- commit 437d08e
* Thu Oct  5 2017 jeffm@suse.com
- Only use patches.suse for patches.
  This eliminates patches.arch, patches.drivers, and patches.fixes, and moves
  the patches contained in them to patches.suse.
  Also update feedback for Patch-mainline tags.
- commit 343996e
* Wed Oct  4 2017 jeffm@suse.com
- Delete patches.suse/suse-hv-storvsc-sg_tablesize.patch.
  Per Olaf Hering, this is no longer needed.
- commit 83b19a6
* Wed Oct  4 2017 jslaby@suse.cz
- orc: mark it as reliable (bnc#1058115).
- Update config files.
- commit 3c7d429
* Wed Oct  4 2017 hare@suse.de
- Delete patches.fixes/sd_liberal_28_sense_invalid.diff.
- Delete patches.suse/dm-emulate-blkrrpart-ioctl.
- Delete patches.suse/scsi-netlink-ml.
- commit b8f0083
* Wed Oct  4 2017 agraf@suse.de
- Delete patches.arch/arm-OMAP-Fix-missing-usb.h-include.patch.
  (no longer needed)
- Delete patches.arch/arm-arndale-usb.patch. (no longer needed)
- Delete
  patches.arch/arm64-0006-arm64-Select-reboot-driver-for-X-Gene-platform.patch.
  (not needed, our config already includes the driver)
- Delete patches.arch/ppc64le-build-vmlinux.patch. (no longer needed)
- commit 2b9d327
* Tue Oct  3 2017 jeffm@suse.com
- Disable patches.suse/binutils2_26.patch for testing.
  The issue addressed by this patch should be handled via upstream
  commit 6d92bc9d483 (x86/build: Build compressed x86 kernels as PIE).
- commit f27997b
* Tue Oct  3 2017 neilb@suse.com
- Delete
  patches.fixes/0001-Revert-SUNRPC-xs_sock_mark_closed-does-not-need-to-t.patch.
  Not needed, bug was fixed some other way since that patch
  was created.
- commit d55ee70
* Tue Oct  3 2017 mgorman@suse.de
- Delete patches.suse/connector-read-mostly.
- commit 8ae100a
* Tue Oct  3 2017 jeffm@suse.com
- series.conf: remove commented out lines for removed patches
- commit 7ea9bcc
* Tue Oct  3 2017 jeffm@suse.com
- Delete patches.arch/arm-refresh-mach-types.diff.
  It was marked for refresh in 12/2016 and hasn't been updated.
- commit 8e357d7
* Mon Oct  2 2017 jeffm@suse.com
- Remove s390 message catalog patches.
- Delete patches.arch/kmsg-fix-parameter-limitations.
- Delete patches.arch/s390-message-catalog.diff.
- commit 865e88d
* Mon Oct  2 2017 jeffm@suse.com
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- commit 04a0a7a
* Mon Oct  2 2017 jeffm@suse.com
- Moved powerpc-Blacklist-GCC-5.4-6.1-and-6.2.patch to patches.rpmify.
  It's a compiler blacklist addition and should be applied to vanilla too.
- commit e34eae8
* Mon Oct  2 2017 jeffm@suse.com
- Update to 4.14-rc3.
- Eliminated 2 patches.
- Config changes:
  - Crypto:
  - Crypto changes brought by Kconfig changes:
  - CONFIG_CRYPTO_GHASH=y (Kconfig dependency change)
  - CONFIG_CRYPTO_GCM=y (Kconfig dependency change)
  - armv7hl:
  - DRM_SUN4I_HDMI_CEC=y
  - CONFIG_CEC_PIN=y (dependency)
  - s390x/zfcpdump:
  - Crypto changes brought by Kconfig changes, consistent with other configs:
  - CRYPTO_MANAGER_DISABLE_TESTS=n
  - CRYPTO_DRBG_HASH=y
  - CRYPTO_DRBG_CTR=y
  - Lots of dependencies
- commit 37f329b
* Mon Oct  2 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
- Delete
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
  Update upstream status and drop the dwarf remainder.
- commit 8d5b116
* Thu Sep 28 2017 jeffm@suse.com
- Update to 4.14-rc2.
- Eliminated 21 patches.
- commit b61ed0c
* Mon Sep 25 2017 jslaby@suse.cz
- x86/asm: Fix inline asm call constraints for Clang
  (bnc#1058115).
- objtool: Handle another GCC stack pointer adjustment bug
  (bnc#1058115).
- commit 7544781
* Sun Sep 24 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: only rewrite modules.dep if non-zero in size
  (bsc#1056979).
- commit 75691fd
* Fri Sep 22 2017 jslaby@suse.cz
- crypto: x86/blowfish - Fix RBP usage (bnc#1058115).
- crypto: x86/camellia - Fix RBP usage (bnc#1058115).
- crypto: x86/cast5 - Fix RBP usage (bnc#1058115).
- crypto: x86/cast6 - Fix RBP usage (bnc#1058115).
- crypto: x86/des3_ede - Fix RBP usage (bnc#1058115).
- crypto: x86/sha1-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha1-ssse3 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-avx - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-ssse3 - Fix RBP usage (bnc#1058115).
- crypto: sha512-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/twofish - Fix RBP usage (bnc#1058115).
  Update upstream status.
- commit 6627c5a
* Thu Sep 21 2017 jeffm@suse.com
- drm/tegra: trace: Fix path to include (build fix).
- commit aecd9be
* Wed Sep 20 2017 afaerber@suse.de
- config: armv7hl: Update to 4.14-rc1
- commit 9d284f8
* Wed Sep 20 2017 afaerber@suse.de
- config: armv6hl: Update to 4.14-rc1
- commit 0c2764f
* Wed Sep 20 2017 afaerber@suse.de
- config: arm64: Update to 4.14-rc1
- commit d6909a3
* Wed Sep 20 2017 jeffm@suse.com
- Revert "KVM: Don't accept obviously wrong gsi values via
  KVM_IRQFD" (build fix).
- commit f436aa0
* Wed Sep 20 2017 mcgrof@suse.com
- nl80211: check for the required netlink attributes presence
  (bsc#1058410 CVE-2017-12153).
- commit 6d93561
* Tue Sep 19 2017 lduncan@suse.com
- Fix incorrect backport of compatibility patch (bsc#1053501)
  This fixes commit fe56e414dcf9, which incorrectly placed
  the back-ported macros in libc-compat.h in the wrong place.
  It is important for __UAPI_DEF_IOVEC to be defined
  correctly with and without GLIBC being defined.
- commit 102e6e3
* Tue Sep 19 2017 jslaby@suse.cz
- objtool: Fix object file corruption (bnc#1058115).
- objtool: Do not retrieve data from empty sections (bnc#1058115).
- objtool: Fix memory leak in elf_create_rela_section()
  (bnc#1058115).
- commit 7fb990b
* Tue Sep 19 2017 jslaby@suse.cz
- x86/crypto: Fix RBP usage in twofish-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in sha512-avx2-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-ssse3-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-avx2-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-avx-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha1_ssse3_asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha1_avx2_x86_64_asm.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in des3_ede-asm_64.S (bnc#1058115).
- x86/crypto: Fix RBP usage in cast6-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in cast5-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in camellia-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in blowfish-x86_64-asm_64.S
  (bnc#1058115).
- commit cb96cd5
* Tue Sep 19 2017 jeffm@suse.com
- Update to 4.14-rc1.
- Eliminated 17 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - HMM_MIRROR=n
  - DEVICE_PRIVATE=n
  - DEVICE_PUBLIC=n
  - SQUASHFS_ZSTD=y
  - ZRAM_WRITEBACK=y
  - x86:
  - INTEL_RDT=y (renamed option)
  - XEN_PVCALLS_BACKEND=y
  - X86_5LEVEL=n (will only boot on systems that support it)
  - AMD_MEM_ENCRYPT=y
  - AMD_MEM_ENCRYPT_ACTIVE_BY_DEFAULT=n
  - ppc:
  - PPC_MEMTRACE=y
  - PPC_VAS=y
  - s390:
  - CMA_DEBUG=n
  - CMA_DEBUGFS=n
  - CMA_AREAS=7 (default)
  - DMA_CMA=n
  - VMCP_CMA_SIZE=4 (default)
  - Netfilter:
  - NFT_FIB_NETDEV
  - Hyperv:
  - HYPERV_VSOCKETS
  - Network:
  - NET_NSH
  - BPF_STREAM_PARSER=y (build fix)
  - BNXT_FLOWER_OFFLOAD=y
  - HINIC
  - MLX5_MPFS=y
  - MLX5_ESWITCH=y
  - RMNET=n
  - ROCKCHIP_PHY
  - WIL6210_DEBUGFS=n
  - ATH10K_USB
  - Bluetooth:
  - BT_LEGACY_IOCTL=y (default)
  - SPI:
  - SPI_INTEL_SPI_PCI
  - Misc:
  - INPUT_PWM_VIBRA=m
  - SERIO_GPIO_PS2=m
  - PINCTRL_DENVERTON
  - PINCTRL_LEWISBURG
  - W1_SLAVE_DS2805
  - BATTERY_BQ27XXX_HDQ=m
  - BATTERY_MAX1721X
  - SENSORS_IBM_CFFPS
  - SENSORS_TPS53679
  - CLOCK_THERMAL=y
  - DEVFREQ_THERMAL=y
  - MFD_BD9571MWV=n
  - INTEL_SOC_PMIC_CHTWC=y
  - MFD_TPS68470=n
  - IR_GPIO_TX=n
  - IR_PWM_TX=n
  - DVB_DDBRIDGE
  - DVB_DDBRIDGE_MSIENABLE=n
  - TINYDRM_REPAPER=n
  - TINYDRM_ST7586=n
  - SND_SOC_CS43130=n
  - SND_SOC_WM8524=n
  - MMC_SPI
  - LEDS_AS3645A=n
  - LEDS_PCA955X_GPIO=y
  - INFINIBAND_EXP_USER_ACCESS=y [?]
  - CONFIG_ALTERA_MSGDMA
  - R8822BE
  - PI433=n
  - CLK_HSDK=n
  - EXTCON_USBC_CROS_EC
  - DLN2_ADC=m
  - LTC2471=n
  - CCS811=n
  - RESET_HSDK_V1=n
  - FPGA_MGR_ALTERA_CVP=m
  - FPGA_MGR_ALTERA_PS_SPI=m
  - CRYPTO_DEV_SP_CCP=y
  - I2C_CHT_WC=m
  - RESET_ATTACK_MITIGATION=y
- commit 08ca987
* Tue Sep 19 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
- Delete
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations-fix.patch.
  Update to the submitted v2.
- commit 27de3c0
* Sun Sep 17 2017 jdelvare@suse.de
- drm/amdgpu: revert tile table update for oland (boo#1027378,
  boo#1039806, bko#194761).
- Delete
  patches.fixes/drm-amdgpu-revert-update-tile-table-for-oland-hainan.patch.
- commit 51745cf
* Thu Sep 14 2017 jslaby@suse.cz
- Linux 4.13.2 (bnc#1012628 bsc#1055826).
- Delete
  patches.drivers/rt2800-fix-TX_PIN_CFG-setting-for-non-MT7620-chips.
- Delete
  patches.fixes/Bluetooth-validate-output-buffer-length-for-config-r.patch.
- commit 96d9efa
* Wed Sep 13 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix a thinko for xmlto buildreq condition
- commit 0ef59d3
* Wed Sep 13 2017 jslaby@suse.cz
- Bluetooth: validate output buffer length for config requests
  and responses (bnc#1057389 CVE-2017-1000251).
- commit c0b7e1f
* Tue Sep 12 2017 jslaby@suse.cz
- fix annotations of xen-head.S (bnc#1058115).
- commit d4c88a5
* Tue Sep 12 2017 msuchanek@suse.de
- rpm/kernel-docs.spec.in: make unpack scripts executable
- commit 1ba3766
* Tue Sep 12 2017 jslaby@suse.cz
- x86/head: Add unwind hint annotations (bnc#1058115).
- x86/xen: Add unwind hint annotations (bnc#1058115).
- x86/xen: Fix xen head ELF annotations (bnc#1058115).
- x86/boot: Annotate verify_cpu() as a callable function
  (bnc#1058115).
- x86/head: Fix head ELF function annotations (bnc#1058115).
- x86/head: Remove unused 'bad_address' code (bnc#1058115).
- x86/head: Remove confusing comment (bnc#1058115).
- objtool: Don't report end of section error after an empty
  unwind hint (bnc#1058115).
- commit 53af152
* Tue Sep 12 2017 jslaby@suse.cz
- objtool: Assume unannotated UD2 instructions are dead ends
  (bnc#1058115).
- objtool: Fix gcov check for older versions of GCC (bnc#1058115).
- objtool: Fix objtool fallthrough detection with function padding
  (bnc#1058115).
- objtool: Fix validate_branch() return codes (bnc#1058115).
- objtool: Handle GCC stack pointer adjustment bug (bnc#1058115).
- x86/asm: Add ASM_UNREACHABLE (bnc#1058115).
- x86/asm: Fix UNWIND_HINT_REGS macro for older binutils
  (bnc#1058115).
- x86/asm: Make objtool unreachable macros independent from GCC
  version (bnc#1058115).
- objtool: Skip unreachable warnings for 'alt' instructions
  (bnc#1058115).
- objtool: Track DRAP separately from callee-saved registers
  (bnc#1058115).
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
  Take all ORC upstream patches. This will go to stable & SLE15 too.
- commit 831ca01
* Mon Sep 11 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0002-x86-kconfig-Make-it-easier-to-switch-to-the-new-ORC-.patch.
- Refresh
  patches.suse/0003-x86-dumpstack-Fix-occasionally-missing-registers.patch.
- Refresh
  patches.suse/0003-x86-kconfig-Consolidate-unwinders-into-multiple-choi.patch.
- Refresh
  patches.suse/0004-x86-dumpstack-Fix-interrupt-and-exception-stack-boun.patch.
- Refresh
  patches.suse/0005-objtool-Add-ORC-unwind-table-generation.patch.
- Refresh
  patches.suse/0006-objtool-x86-Add-facility-for-asm-code-to-provide-unw.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-Add-unwind-hint-annotations-to-sync_core.patch.
- Delete
  patches.suse/0001-linkage-new-macros-for-assembler-symbols.patch.
- Delete
  patches.suse/0003-DWARF-EH-frame-based-stack-unwinding.patch.
- Delete patches.suse/stack-unwind-disable-kasan.patch.
  Update upstream status of ORC and drop already-disabled DWARF unwinder.
- commit 2e9b944
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: build ARM on at least 2 cpus
- commit b7edeaf
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: increase memory for kernel-syzkaller
  And see if it helps. If so, push it to packaging...
- commit 7193e65
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable legacy instruction emulation (boo#1029158)
  Needed for execution of older e.g. ARMv6 code.
- commit a4e05e8
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable ACPI_DOCK for consistency
- commit cec354f
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable some network options
- Marvell Armada 7K/8K Ethernet driver
- Microchip ENC28J60 and related SPI Ethernet drivers
- Micrel KS8851 SPI Ethernet driver
- MMIO MDIO mux driver
- commit cf926f4
* Sun Sep 10 2017 jslaby@suse.cz
- Linux 4.13.1 (bnc#1012628).
- commit 8740849
* Fri Sep  8 2017 jslaby@suse.cz
- rpm/kernel-binary.spec.in: package ftrace-mod.o on arm64
  It is needed for building modules since 4.13:
  CC [M]  /suse/jslaby/a/aaa.o
  Building modules, stage 2.
  MODPOST 1 modules
  CC      /suse/jslaby/a/aaa.mod.o
  LD [M]  /suse/jslaby/a/aaa.ko
  ld: cannot find ./arch/arm64/kernel/ftrace-mod.o: No such file or directory
  ...
- commit 07da115
* Thu Sep  7 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Expand kernel tree directly from sources (bsc#1057199)
- commit a61b4d9
* Wed Sep  6 2017 mcgrof@suse.com
- supported.conf: add test_syctl to new kselftests-kmp package FATE#323821
  As per FATE#323821 we will require new FATE requests per each
  new selftest driver. We don't want to support these module on
  production runs but we do want to support them for QA / testing
  uses. The compromise is to package them into its own package,
  this will be the kselftests-kmp package.
  Selftests can also be used as proof of concept vehicle for issues
  by customers or ourselves.
  Vanilla kernels do not get test_sysctl given that driver was
  using built-in defaults, this also means we cannot run sefltests
  on config/s390x/zfcpdump which does not enable modules.
  Likeweise, since we had to *change* the kernel for test_syctl, it
  it also means we can't test test_syctl with vanilla kernels. It
  should be possible with other selftests drivers if they are
  present in vanilla kernels though.
- commit ae8069f
* Wed Sep  6 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Re-add xmlto buildreq conditionally for SLE15 & co
- commit 259b49e
* Wed Sep  6 2017 mchandras@suse.de
- rpm/group-source-files.pl: Add arch/*/tools/* files to the devel package
  Commit b71c9ffb1405 ("powerpc: Add arch/powerpc/tools directory")
  introduced in v4.12-rc1 release, moved the scripts into the tools
  directory. However, this location is not considered for the kernel devel
  package and the following error occurs when building a kmp for powerpc
  make[2]: /usr/src/linux-4.12.9-1/arch/powerpc/tools/gcc-check-mprofile-kernel.sh: Command not found
- commit 5f1ff53
* Tue Sep  5 2017 jeffm@suse.com
- Update to 4.13-final.
- commit 3fdcb17
* Thu Aug 31 2017 tiwai@suse.de
- rt2800: fix TX_PIN_CFG setting for non MT7620 chips
  (bsc#1055826).
- commit 8116757
* Thu Aug 31 2017 jeffm@suse.com
- Update to 4.13-rc7.
- Eliminate 2 patches.
- commit dd00417
* Thu Aug 31 2017 jthumshirn@suse.de
- scsi: qla2xxx: Fix an integer overflow in sysfs code
  (bsc#1056588, CVE-2017-14051).
- commit aacb454
* Tue Aug 29 2017 tiwai@suse.de
- Update config files: enable CONFIG_SPI_PXA2XX for MacBook (bsc#1055817)
- commit 3ce18e9
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Update drm-kmp obsolete for SLE12-SP3/Leap-42.3
- commit 77ccbd0
* Mon Aug 28 2017 tiwai@suse.de
- Refresh patch tags of patches.fixes/Input-ALPS-Fix-Alps-Touchpad-two-finger-scroll-does-
- commit 0b3ef4c
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Disable PDF build again
  ... due to the breakage with the recent TeXLive 2017.
  Also add the missing dependency on texlive-varwidth.
- commit 9f682b5
* Wed Aug 23 2017 tiwai@suse.de
- ALSA: hda - Add stereo mic quirk for Lenovo G50-70 (17aa:3978)
  (bsc#1020657).
- commit 3f6a0b2
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: ice1712: Add support for STAudio ADCIII (bsc#1048934).
- commit 99a99ef
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: hda - Implement mic-mute LED mode enum (bsc#1055013).
- commit a3c362f
* Mon Aug 21 2017 jeffm@suse.com
- Update to 4.13-rc6.
- commit ee50b89
* Fri Aug 18 2017 msuchanek@suse.de
- Do not ship firmware (bsc#1054239).
  Pull firmware from kernel-firmware instead.
- commit 0b0b5c9
* Thu Aug 17 2017 jeffm@suse.com
- supported.conf: clear mistaken external support flag for cifs.ko (bsc#1053802).
- commit 75e287e
* Thu Aug 17 2017 jeffm@suse.com
- supported.conf: mark reiserfs unsupported (FATE#323394).
  ReiserFS is not supported in SLE15.  ReiserFS file systems must be
  transferred or converted before installing.
- commit 8a547c5
* Thu Aug 17 2017 jeffm@suse.com
- Update to 4.13-rc5.
- commit c3fb699
* Tue Aug 15 2017 hare@suse.de
- Delete patches.fixes/scsi-dh-queuedata-accessors.
- commit ee998ab
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/dm-mpath-detach-existing-hardware-handler.
- commit a8291cd
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/no-partition-scan (FATE#323406)
- commit e1cccca
* Sat Aug 12 2017 lduncan@suse.com
- uapi: add a compatibility layer between linux/uio.h and glibc
  (bsc#1053501).
- commit fe56e41
* Thu Aug 10 2017 msuchanek@suse.de
- Refresh vanilla config.
- commit ae18928
* Thu Aug 10 2017 msuchanek@suse.de
- rpm/modules.fips include module list from dracut
- commit f70bab5
* Wed Aug  9 2017 ohering@suse.de
- Delete stale patches.fixes/scsi-ibmvscsi-module_alias.patch.
- Delete stale patches.suse/suse-ppc64-branding.
- commit 1c8934b
* Tue Aug  8 2017 jeffm@suse.com
- Update to 4.13-rc4.
- commit 94b098f
* Wed Aug  2 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix package list and enable building PDFs
  Finally it works!  Added some missing pieces (ImageMagick, some texlive
  subpkgs) in addition to use explicitly python3-Sphinx stuff.
- commit c117a0c
* Tue Aug  1 2017 agraf@suse.de
- Clean up upstreamed patches list. Annotate the remaining ones
  with their current status.
- Delete patches.arch/arm-exynos-dwmmc-modalias.patch.
- Delete
  patches.arch/arm64-Relocate-screen_info.lfb_base-on-PCI-BAR-alloc.patch.
- commit 3f654d5
* Mon Jul 31 2017 jeffm@suse.com
- Update to 4.13-rc3.
- commit 4ef483a
* Thu Jul 27 2017 jslaby@suse.cz
- x86/kconfig: Make it easier to switch to the new ORC unwinder
  (bnc#1018348).
- x86/kconfig: Consolidate unwinders into multiple choice
  selection (bnc#1018348).
- Update config files.
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
  Update to version from -tip. ORC is in -tip completely. So make sure
  we use the upstream version.
- commit 903e200
* Wed Jul 26 2017 jeffm@suse.com
- Update to 4.13-rc2.
- Eliminated 1 patch.
- Config changes:
  - DRM_VBOXVIDEO=m
- commit b545b87
* Wed Jul 26 2017 tiwai@suse.de
- Input: ALPS - Fix Alps Touchpad two finger scroll does not
  work on right side (bsc#1050582).
- commit 474729b
* Sun Jul 23 2017 stefan.bruens@rwth-aachen.de
- config: arm64: Enable RTC and SPI on Allwinner A64/H5
  A64 and H5 share the RTC and SPI functional blocks with older SoCs,
  enable the corresponding drivers.
- commit b5bf58a
* Wed Jul 19 2017 mmarek@suse.cz
- rpm/kernel-binary.spec.in: find-debuginfo.sh should not touch build-id
  This needs rpm-4.14+ (bsc#964063).
- commit f622d60
* Tue Jul 18 2017 afaerber@suse.de
- config: armv7hl: Update to v4.13-rc1
- commit 1d72b01
* Tue Jul 18 2017 afaerber@suse.de
- config: armv6hl: Update to v4.13-rc1
- commit 5ede81f
* Tue Jul 18 2017 afaerber@suse.de
- config: arm64: Update to v4.13-rc1
- commit 7d005f8
* Tue Jul 18 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0003-x86-dumpstack-fix-occasionally-missing-registers.patch.
- Refresh
  patches.suse/0004-x86-dumpstack-fix-interrupt-and-exception-stack-boun.patch.
- Refresh
  patches.suse/0005-objtool-add-ORC-unwind-table-generation.patch.
- Refresh
  patches.suse/0006-objtool-x86-add-facility-for-asm-code-to-provide-unw.patch.
- Refresh
  patches.suse/0007-x86-entry-64-add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-add-unwind-hint-annotations-to-sync_core.patch.
  Update upstream information.
- commit ff15779
* Tue Jul 18 2017 tiwai@suse.de
- Delete patches.fixes/drm-i915-Fix-S4-resume-breakage.
  The workaround wasn't merged to upstream, and it seems becoming
  superfluous with the recent i915 driver, so let's drop this one.
- commit f6f228c
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Drop unnecessary xmlto for 4.13+
- commit e47dc84
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Correct kernel-docs package summary/description
- commit 697b763
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: refresh dependencies for PDF build (bsc#1048129)
  But it still doesn't work with Tex Live 2017, thus disabled yet.
  Also add texlive-anyfontsize for HTML math handling.
- commit ead44a1
* Tue Jul 18 2017 jslaby@suse.cz
- Delete patches.rpmify/drm-i915-disable-KASAN-for-handlers.patch.
  It was never accepted, is under discussion. But we disabled
  CONFIG_DRM_I915_WERROR in commit 5fc7b327348b, so we are safe anyway.
- commit e2957b5
* Tue Jul 18 2017 jslaby@suse.cz
- Delete patches.rpmify/get_builtin_firmware-gcc-7.patch.
  This was never accepted. Instead this seems to be fixed in gcc.
- commit c048497
* Mon Jul 17 2017 jeffm@suse.com
- Updated to 4.13-rc1.
- Eliminated 13 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - SLAB_MERGE_DEFAULT=y (current behavior)
  - REFCOUNT_FULL=n (current behavior)
  - PERCPU_STATS=n (default)
  - FORTIFY_SOURCE=n (needs performance analysis)
  - WARN_ALL_UNSEEDED_RANDOM=n
  - TRACE_EVAL_MAP_FILE=n
  - TEST_SYSCTL=n
  - TEST_KMOD=n
  - Storage:
  - DM_ZONED=m
  - IB:
  - Options for MLX5:
  - MLX5_FPGA
  - MLX5_EN_IPSEC=y
  - MLXFW=m
  - SECURITY_INFINIBAND=y
  - Network:
  - Options for NFP:
  - NFP_APP_FLOWER=y
  - CORTINA_PHY=n (intended for embedded apps)
  - ATH10K_SDIO=m
  - QTNFMAC_PEARL_PCIE=m
  - DRM:
  - DRM_I915_SW_FENCE_CHECK_DAG=n
  - Sound:
  - SND_SOC_INTEL_BYT_CHT_ES8316_MACH=m
  - SND_SOC_INTEL_KBL_RT5663_MAX98927_MACH=m
  - SND_SOC_INTEL_KBL_RT5663_RT5514_MAX98927_MACH=m
  - SND_SOC_ZX_AUD96P22=n
  - HID:
  - HID_ITE=n
  - HID_RETRODE=m
  - USB:
  - TYPEC_UCSI=m
  - UCSI_ACPI=m
  - Misc:
  - RTC_NVMEM=y
  - RTC_DRV_DS3232_HWMON=y
  - WMI_BMOF=m
  - PEAQ_WMI=m
  - INTEL_INT0002_VGPIO=m
  - CROS_EC_LPC_MEC=y
  - EXTCON_INTEL_CHT_WC=m
  - NTB_IDT=m
  - MULTIPLEXER=m
  - KEYBOARD_DLINK_DIR685=n
  - TOUCHSCREEN_STMFTS=n
  - I2C_DESIGNWARE_SLAVE=n
  - SPI_SLAVE=n
  - PINCTRL_MCP23S08=n
  - PINCTRL_CANNONLAKE=m
  - GPIO_XRA1403=n
  - BATTERY_BQ27XXX_DT_UPDATES_NVM=n
  - CHARGER_LTC3651=n
  - SENSORS_IR35221=n
  - WATCHDOG_HANDLE_BOOT_ENABLED=y (default)
  - File Systems:
  - OVERLAY_FS_INDEX=n (mounting on an older kernel read-write will cause unexpected results)
  - CIFS_DEBUG_DUMP_KEYS=n
  - Crypto:
  - CRC4=m
  - X86:
  - INTEL_SOC_PMIC_CHTWC=m
  - CHT_WC_PMIC_OPREGION=y
  - ppc64/ppc64le:
  - CONFIG_IRQ_TIME_ACCOUNTING=n
  - CONFIG_LD_HEAD_STUB_CATCH=n
  - ZONE_DEVICE=y
  - ppc64le:
  - STRICT_KERNEL_RWX=y
  - s390x:
  - CRYPTO_PAES_S390=m
- commit d418532
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.drivers/ppc64-adb.
  This hardware was discontinued in 2006 and the patch was never accepted
  upstream.
- commit 995698b
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.arch/ppc-prom-nodisplay.patch.
  We no longer support 32-bit ppc and this hardware only existed with a
  32-bit CPU.
- commit d94ed1e
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.arch/ppc-pegasos-console-autodetection.patch.
  We no longer support 32-bit ppc and this hardware only existed with a
  32-bit CPU.
- commit b42ddc6
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.suse/ppc-powerbook-usb-fn-key-default.patch.
  We no longer support 32-bit ppc and there were no 64-bit powerbooks.
- commit 9e9a512
* Mon Jul 17 2017 jeffm@suse.com
- Disable patches.suse/pstore-backend-autoaction.
  It needs updating and there now exists a mount option instead of a module
  parameter.
- commit 87a5ab7
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.fixes/block-copy-bi_vcnt-in-_bio_clone_fast.
  This was obsoleted by 764f612c6c3c ("blk-merge: don't compute
  bi_phys_segments from bi_vcnt for cloned bio").
- commit f0c2642
* Mon Jul 17 2017 jslaby@suse.cz
- netfilter: expect: fix crash when putting uninited expectation
  (bnc#1048935).
- commit cc9efac
* Mon Jul 17 2017 mmarek@suse.cz
- Drop multiversion(kernel) from the KMP template (fate#323189)
- commit 71504d8
* Tue Jul 11 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix and cleanup for 4.13 doc build (bsc#1048129)
  The whole DocBook stuff has been deleted.  The PDF build still non-working
  thus the sub-packaging disabled so far.
- commit 8e7de10
* Fri Jun  2 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Fix new include path
  Commit 89de3db69113d58cdab14d2c777de6080eac49dc ("rpm/dtb.spec.in.in:
  Update include path for dt-bindings") introduced an additional include
  path for 4.12. The commit message had it correct, but the spec file
  template lacked a path component, breaking the aarch64 build while
  succeeding on armv7hl. Fix that.
- commit c8d853a
* Wed May 31 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Update include path for dt-bindings
  Kernels before 4.12 had arch/{arm,arm64}/boot/dts/include/ directories
  with a symlink to include/dt-bindings/.
  In 4.12 those include/ directories were dropped.
  Therefore use include/ directly.
  Additionally some cross-architecture .dtsi reuse was introduced, which
  requires scripts/dtc/include-prefixes/ that didn't exist on older kernels.
- commit 466f108
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-zte subpackage
  4.9 added arch/arm64/boot/dts/zte/.
- commit 073d831
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-allwinner subpackage
  4.10 added arch/arm64/boot/dts/allwinner/.
- commit dfeb94a
* Tue Dec 20 2016 xxxxxmichl@googlemail.com
- added De0-Nanos-SoC board support (and others based on Altera SOC).
- commit 9278339
* Tue Apr 26 2016 mmarek@suse.cz
- Drop sysctl files for dropped archs, add ppc64le and arm (bsc#1178838).
  Also correct the page size on ppc64.
- commit 7ec816c
* Wed Feb 17 2016 mmarek@suse.com
- oracleasm: 4.0 compat changes (bsc#962720, bsc#1144700).
- commit bad1828
